(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4393055,     111112]*)
(*NotebookOutlinePosition[   4393756,     111136]*)
(*  CellTagsIndexPosition[   4393712,     111132]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Mixture-of-Gaussians example #1", "Title"],

Cell[TextData[{
  "This notebook illustrates Gaussian mixture modeling for some 2d synthetic \
data, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Specialized data generation and visualization functions", "Subsection"],

Cell[BoxData[
    \(\(AnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {x1\  - \ r2, \ 
              x1 + \ r2}; \[IndentingNewLine]range2\  = \ {x2\  - \ r2, \ 
              x2\  + \ r2}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  < \ 
                  r2\  && \ tst\  > \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AntiAnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {0, \ 
              1}; \[IndentingNewLine]range2\  = \ {0, 
              1}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  > \ 
                  r2\  || \ tst\  < \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Region definitions", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(c1\  = \ { .5,  .5};\) (*\ 
      center\ of\ annular\ region\ *) \[IndentingNewLine]
    \(rr1\  = \  .12;\) (*\ inner\ radius\ *) \[IndentingNewLine]
    \(rr2\  = \  .35;\)\)\( (*\ outer\ radius\ *) \)\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(DrawAnnularRegion2[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          color2_:  White, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {color2, Disk[center, r1]}}], \ 
            AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{class1Color, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, class2Color, \ class1Color, nS]\ , 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize annular region in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Draw annular region in 2d", "Subsubsection"],

Cell[BoxData[
    \(\(DrawAnnularRegion[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {GrayLevel[1. ], 
                  Disk[center, r1]}}], \ AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for annular region", "Subsubsection"],

Cell[BoxData[
    \(\(AnnularAllPlot[center_, \ r1_, \ 
          r2_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ DrawAnnularRegion[center, 
              rr1, rr2, \ pr, LightPink, \ nF, 
              nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data generation and visualization", "Section"],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?o
ooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0
oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooon60?ooO`P0OoooQ03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooNP3ooglP07ooogP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooogD0oomo:@1ooomd0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom`0?ooOc<0OoooK`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
KP3ooglg07ooofd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofX0oomo@01o
oomX0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomW0?ooOdD0OoooIP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooI@3oogm907ooof@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooof<0oomoC@1ooomR0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomQ0?ooOe40OoooH03oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooG`3oogmF07oooed0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooe`0oomoF`1ooomK0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomJ0?oo
Oel0OoooF@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF03oogmS07oooeL0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooeL0oomoI@1ooomF0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomF0?ooOfL0OoooE@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooE03oogm[07oooe<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooe80oomoK`1ooomA0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomA0?ooOg40OoooD03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
D03oogmc07ooodl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodh0oomoM`1o
oom=0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom=0?ooOgP0OoooC@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooC@3oogmi07oood`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood/0oomoO@1ooom:0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom:0?ooOgl0OoooB@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooodP0oomoP`1ooom70?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom70?oo
OhD0OoooAP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodD0oomoR@1ooom40?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom40?ooOh/0Oooo@`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooood80oomoS`1ooom10?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom10?ooOi00Oooo@@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
@@3oognA07oood00oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocl0oomoU@1o
ooln0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooln0?ooOiH0Oooo?P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo?P3oognG07ooocd0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocd0oomoV@1oooll0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooooll0?ooOi/0Oooo>`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo>`3oognL07oooc/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc/0oomoW@1ooolj0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolj0?oo
Oih0Oooo>P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>P3oognO07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocT0oomoX@1ooolh0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolh0?ooOj<0Oooo=`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oognT07ooocL0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomoY@1ooolf0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=P3oognW07ooocD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocD0oomoZ01o
oole0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=03oognZ07oooc@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooc@0oomoZ`1ooolc0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolc0?ooOj`0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<`3oogn/07oooc<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc<0oomo[@1ooolb0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolb0?oo
Ojh0Oooo<P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<P3oogn_07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc40oomo/01ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooola0?ooOk40Oooo<03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<03oognb07oooc00oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc00oomo/`1oool_0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool_0?ooOeD0Oooo2`3oogmD07ooobl0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm?07oooaX0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOdd0Oooo7@3oogm<07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobh0oomoC01ooolQ0?ooOdT0Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;P3oogm:07ooob@0oomoB01oool^0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool^0?ooOdL0Oooo:03oogm807ooobd0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobd0oomoA`1ooolZ0?ooOdL0Oooo;@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo;@3oogm607ooob`0oomoA`1oool/0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00oooool/0?ooOdL0Oooo;@3oogm607ooob`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooob`0oomoAP1oool_0?ooOdD0Oooo;03oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo;03oogm507oooc40oomoA01oool/0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00oooool/0?ooOd@0Oooo<P3oogm407ooob`0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooob`0oomo@`1ooold0?ooOd@0Oooo:`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm407ooocD0oomo@`1oool[0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo=`3oogm207ooob/0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?ooOd40Oooo
:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocT0oomo@P1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd80Oooo>`3oogm1
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?oo
Od40Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0
oomo@@1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo
?P3oogm007ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01o
ooln0?ooOd00Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm0
07oooch0oomo@01ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?oo
Od00Oooo?`3ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0
oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo:P3ooglo07oood40oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolZ0?ooOch0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobX0oomo?`1ooom10?ooOch0Oooo:P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo?`3ooglo07ooobX0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01oooln0?ooOd00Oooo:P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm007oooch0oomo@01ooolZ0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd40Oooo?@3oogm007ooobX0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?ooOd40Oooo
:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0oomo@@1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd40Oooo>P3oogm2
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?oo
Od40Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocP0
oomo@P1oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo
=P3oogm307ooob/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomoA01o
oole0?ooOd<0Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo;03oogm4
07oooc<0oomoA01oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool/0?oo
OdD0Oooo<@3oogm407ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob`0
oomoA@1oool`0?ooOdD0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
;03oogm607ooobh0oomoAP1oool/0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
ool/0?ooOdL0Oooo;03oogm707ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobd0oomoB01ooolY0?ooOdP0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo;@3oogm907ooobL0oomoB01oool]0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool^0?ooOd/0Oooo8`3oogm907ooobd0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobh0oomoC@1ooolO0?ooOdX0Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm>07oooa/0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOe40Oooo5`3oogm>07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;`3oogmF07ooo`T0oomoE@1oool_0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool_0?ooOk@0Oooo;`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<03oognc07ooobl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc00oomo/P1oool`0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooola0?oo
Ok40Oooo<03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<@3oogn`07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc80oomo[`1ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolb0?ooOjh0Oooo<P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<`3oogn]07oooc80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc<0oomo[01ooolc0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooold0?ooOj/0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=03oognZ07oooc@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc@0oomoZP1o
oold0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=@3oognX07ooocD0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocH0oomoY`1ooole0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oognU07ooocH0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocP0oomoX`1ooolg0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooli0?oo
Oj40Oooo>03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>@3oognP07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocX0oomoW`1oooli0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolj0?ooOih0Oooo>P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo>`3oognM07ooocX0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc`0oomoV`1ooolk0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolm0?ooOiT0Oooo?03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
?@3oognH07ooocd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooch0oomoU`1o
oolm0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom00?ooOi<0Oooo?`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo@03oognB07oood00oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood40oomoT@1ooom00?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom20?ooOhl0Oooo@@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooood@0oomoR`1ooom30?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom50?oo
OhT0OoooA03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodL0oomoQ@1ooom60?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom80?ooOh<0OoooA`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooodX0oomoO`1ooom90?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom<0?ooOg/0OoooB`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
C03oogmj07oood`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodd0oomoN@1o
oom<0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom?0?ooOgD0OoooCP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooD03oogmc07ooodl0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooe40oomoL@1ooom@0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomC0?ooOfd0OoooDP3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooE@3oogmY07oooe@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooeH0oomoI`1ooomE0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomG0?oo
OfD0OoooEP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF@3oogmQ07oooeP0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooe/0oomoG@1ooomJ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomM0?ooOeT0OoooG03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooH03oogmD07oooeh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooof80oomoC`1ooomQ0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomT0?ooOd/0OoooH`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
IP3oogm707ooofD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofP0oomo@`1o
oomW0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom[0?ooOch0OoooJ@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooK`3oogle07ooofh0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooog40oomo<@1ooom`0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomf0?ooObL0OoooM@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooN`3ooglN07ooogT0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooohL0oomo1P1ooon50?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?oo
Oa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = AnnularRegion[c1, \ rr1, \ rr2, \ n1];\)\), "\n", 
    \(\(data2\  = AntiAnnularRegion[c1, \ rr1, \ rr2, \ n2];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.21757 .30813 Mdot
.34557 .76951 Mdot
.52032 .81576 Mdot
.56808 .64174 Mdot
.41254 .37503 Mdot
.34481 .55451 Mdot
.62746 .66449 Mdot
.53671 .16518 Mdot
.37318 .20126 Mdot
.31248 .73626 Mdot
.25102 .52515 Mdot
.25538 .73467 Mdot
.18958 .47395 Mdot
.53043 .24979 Mdot
.62017 .25579 Mdot
.34248 .53842 Mdot
.83585 .43444 Mdot
.6489 .53011 Mdot
.61952 .39004 Mdot
.36604 .23545 Mdot
.27189 .55344 Mdot
.72129 .57639 Mdot
.25798 .47747 Mdot
.48888 .65299 Mdot
.28552 .42185 Mdot
.27097 .26259 Mdot
.36742 .45011 Mdot
.53754 .35585 Mdot
.51257 .19978 Mdot
.57356 .6594 Mdot
.39846 .78033 Mdot
.57644 .60976 Mdot
.71394 .35598 Mdot
.69799 .67899 Mdot
.68751 .34714 Mdot
.39495 .35838 Mdot
.6374 .7915 Mdot
.66453 .54212 Mdot
.39017 .60333 Mdot
.67499 .21394 Mdot
.34255 .23809 Mdot
.52502 .22266 Mdot
.73076 .27429 Mdot
.28307 .33759 Mdot
.49181 .26312 Mdot
.19498 .40523 Mdot
.25851 .50293 Mdot
.58228 .25558 Mdot
.69076 .63455 Mdot
.38227 .81898 Mdot
.55748 .67362 Mdot
.49465 .70155 Mdot
.39315 .24452 Mdot
.37771 .4857 Mdot
.53009 .69428 Mdot
.41161 .79515 Mdot
.53469 .27462 Mdot
.64312 .72992 Mdot
.63067 .4301 Mdot
.42227 .40109 Mdot
.73532 .54995 Mdot
.21389 .48445 Mdot
.7103 .40899 Mdot
.18454 .50828 Mdot
.39963 .78479 Mdot
.36336 .81035 Mdot
.56337 .23729 Mdot
.33045 .43796 Mdot
.29796 .67933 Mdot
.40578 .28625 Mdot
.64793 .51705 Mdot
.53862 .72039 Mdot
.28413 .61825 Mdot
.323 .75019 Mdot
.36912 .7311 Mdot
.83568 .46909 Mdot
.28759 .46759 Mdot
.66538 .76552 Mdot
.4828 .79367 Mdot
.57842 .32351 Mdot
.41229 .41646 Mdot
.68615 .41004 Mdot
.41974 .79051 Mdot
.61499 .35828 Mdot
.28901 .47979 Mdot
.79275 .4359 Mdot
.64935 .52926 Mdot
.66599 .39078 Mdot
.78681 .5875 Mdot
.67822 .28125 Mdot
.36525 .42085 Mdot
.77993 .5732 Mdot
.53323 .21387 Mdot
.3218 .37178 Mdot
.40108 .57722 Mdot
.37218 .77902 Mdot
.59486 .20483 Mdot
.65119 .46047 Mdot
.71424 .42072 Mdot
.4428 .19648 Mdot
.24816 .43748 Mdot
.48983 .1921 Mdot
.31137 .70741 Mdot
.83271 .49249 Mdot
.6174 .55661 Mdot
.8038 .35304 Mdot
.30948 .7357 Mdot
.35383 .59078 Mdot
.70982 .69608 Mdot
.26253 .31017 Mdot
.37685 .66085 Mdot
.7943 .44589 Mdot
.42025 .68262 Mdot
.70786 .43848 Mdot
.34419 .39679 Mdot
.27612 .38529 Mdot
.59458 .34974 Mdot
.76542 .63765 Mdot
.72789 .4968 Mdot
.65975 .48434 Mdot
.50791 .67909 Mdot
.3798 .55798 Mdot
.55967 .68825 Mdot
.7243 .27965 Mdot
.51813 .66532 Mdot
.70152 .33784 Mdot
.4885 .79004 Mdot
.40084 .79358 Mdot
.17791 .39246 Mdot
.52941 .36923 Mdot
.5453 .76307 Mdot
.66414 .64029 Mdot
.57086 .24409 Mdot
.71248 .74938 Mdot
.33609 .22426 Mdot
.71954 .60685 Mdot
.63047 .54936 Mdot
.75733 .7245 Mdot
.25792 .33699 Mdot
.36889 .80457 Mdot
.16893 .42759 Mdot
.5479 .32114 Mdot
.44121 .34036 Mdot
.72331 .30684 Mdot
.54408 .23945 Mdot
.69547 .67041 Mdot
.60884 .80876 Mdot
.69464 .24112 Mdot
.48261 .2797 Mdot
.79501 .51334 Mdot
.51066 .32984 Mdot
.21141 .65171 Mdot
.74476 .6035 Mdot
.20698 .51924 Mdot
.5675 .3964 Mdot
.2625 .49313 Mdot
.63279 .43785 Mdot
.59497 .32015 Mdot
.57824 .62928 Mdot
.65618 .42444 Mdot
.56973 .35599 Mdot
.32302 .45666 Mdot
.38513 .75215 Mdot
.63329 .58886 Mdot
.33751 .47388 Mdot
.26973 .41372 Mdot
.40738 .80843 Mdot
.70225 .55669 Mdot
.36835 .31141 Mdot
.28215 .47862 Mdot
.82635 .4024 Mdot
.3664 .37546 Mdot
.34993 .65668 Mdot
.37282 .49225 Mdot
.75915 .48785 Mdot
.80857 .52696 Mdot
.81244 .53078 Mdot
.29548 .51114 Mdot
.73798 .65886 Mdot
.75476 .41333 Mdot
.64694 .65706 Mdot
.61805 .75549 Mdot
.34575 .2644 Mdot
.70203 .4245 Mdot
.38031 .58057 Mdot
.73274 .73686 Mdot
.27398 .6103 Mdot
.59412 .38258 Mdot
.37914 .79457 Mdot
.58078 .35006 Mdot
.77698 .53613 Mdot
.3158 .62378 Mdot
.56006 .67392 Mdot
.4569 .35614 Mdot
.33662 .25021 Mdot
.21949 .48305 Mdot
.68349 .53161 Mdot
.3924 .72979 Mdot
.45855 .35052 Mdot
.46703 .21205 Mdot
.29962 .56988 Mdot
.75011 .38127 Mdot
.68586 .3706 Mdot
.57035 .28792 Mdot
.27542 .75131 Mdot
.50772 .64802 Mdot
.30223 .67146 Mdot
.66737 .27327 Mdot
.45139 .27976 Mdot
.23425 .68644 Mdot
.4658 .65068 Mdot
.34725 .74251 Mdot
.33195 .6341 Mdot
.29204 .28624 Mdot
.7237 .5112 Mdot
.6839 .53823 Mdot
.73934 .44349 Mdot
.66196 .60019 Mdot
.31248 .29431 Mdot
.67419 .739 Mdot
.82367 .50335 Mdot
.69824 .22826 Mdot
.36063 .54866 Mdot
.32286 .55444 Mdot
.54181 .79161 Mdot
.25641 .68816 Mdot
.38688 .7468 Mdot
.38034 .72125 Mdot
.23126 .60936 Mdot
.54929 .82538 Mdot
.31203 .30123 Mdot
.63326 .56521 Mdot
.24832 .61674 Mdot
.73277 .74491 Mdot
.70458 .71307 Mdot
.50929 .18052 Mdot
.63018 .26057 Mdot
.53631 .84083 Mdot
.79287 .66879 Mdot
.54242 .72696 Mdot
.63769 .52442 Mdot
.75229 .31861 Mdot
.64852 .77763 Mdot
.66083 .54502 Mdot
.32608 .57137 Mdot
.44645 .81079 Mdot
.63291 .57368 Mdot
.49672 .29887 Mdot
.24736 .68986 Mdot
.70217 .61758 Mdot
.3382 .52811 Mdot
.21051 .68309 Mdot
.52051 .82623 Mdot
.29476 .65036 Mdot
.56425 .30801 Mdot
.73144 .64129 Mdot
.39504 .57977 Mdot
.44186 .67364 Mdot
.78827 .53163 Mdot
.51477 .31623 Mdot
.33343 .63126 Mdot
.65606 .64817 Mdot
.73769 .42373 Mdot
.24867 .49703 Mdot
.69677 .76039 Mdot
.56439 .79508 Mdot
.61926 .42031 Mdot
.57673 .59494 Mdot
.40016 .80681 Mdot
.58724 .31551 Mdot
.49543 .66162 Mdot
.5999 .38285 Mdot
.64181 .74436 Mdot
.19237 .43091 Mdot
.55031 .83319 Mdot
.41625 .16746 Mdot
.81672 .39512 Mdot
.72623 .50434 Mdot
.38239 .22904 Mdot
.61938 .22061 Mdot
.69208 .5531 Mdot
.82711 .40684 Mdot
.29864 .56304 Mdot
.56773 .39624 Mdot
.32506 .32478 Mdot
.68464 .73504 Mdot
.59477 .73648 Mdot
.45911 .66286 Mdot
.60859 .62054 Mdot
.68287 .59912 Mdot
.2747 .32308 Mdot
.66338 .76137 Mdot
.42575 .61312 Mdot
.67941 .51139 Mdot
.26854 .27201 Mdot
.42704 .38011 Mdot
.81107 .56039 Mdot
.5987 .36828 Mdot
.48087 .20206 Mdot
.46482 .19989 Mdot
.21198 .43207 Mdot
.62855 .53164 Mdot
.77114 .38199 Mdot
.81222 .49984 Mdot
.27876 .47599 Mdot
.83683 .51473 Mdot
.52536 .25441 Mdot
.47024 .66548 Mdot
.38346 .52357 Mdot
.57316 .78365 Mdot
.29364 .48719 Mdot
.81137 .42949 Mdot
.17805 .49647 Mdot
.43664 .18919 Mdot
.49232 .18164 Mdot
.80953 .36685 Mdot
.59199 .24158 Mdot
.42416 .76965 Mdot
.36539 .56115 Mdot
.7259 .55651 Mdot
.7639 .42663 Mdot
.19254 .5663 Mdot
.51772 .1843 Mdot
.79451 .45681 Mdot
.58599 .73879 Mdot
.39944 .2718 Mdot
.51424 .66483 Mdot
.59591 .28866 Mdot
.42169 .19263 Mdot
.26865 .7375 Mdot
.72147 .49424 Mdot
.59406 .71006 Mdot
.34096 .29865 Mdot
.25792 .4942 Mdot
.66986 .47695 Mdot
.58438 .77891 Mdot
.36935 .71803 Mdot
.71982 .75275 Mdot
.22619 .34488 Mdot
.29924 .30744 Mdot
.62526 .43355 Mdot
.5242 .78249 Mdot
.28842 .53184 Mdot
.7622 .65695 Mdot
.79448 .35647 Mdot
.23153 .44686 Mdot
.74522 .62981 Mdot
.79204 .40418 Mdot
.64457 .47044 Mdot
.64258 .18814 Mdot
.51301 .78174 Mdot
.59394 .28165 Mdot
.75141 .67122 Mdot
.62253 .30696 Mdot
.67675 .38122 Mdot
.72045 .52029 Mdot
.56106 .16328 Mdot
.80317 .632 Mdot
.36609 .50721 Mdot
.30746 .27622 Mdot
.58669 .35711 Mdot
.47385 .73814 Mdot
.70937 .67996 Mdot
.58915 .7611 Mdot
.59176 .63891 Mdot
.31555 .4363 Mdot
.74328 .71274 Mdot
.36278 .57198 Mdot
.42629 .81773 Mdot
.49654 .73516 Mdot
.68028 .2135 Mdot
.65219 .30196 Mdot
.62919 .18481 Mdot
.54258 .36555 Mdot
.49185 .37659 Mdot
.52104 .66256 Mdot
.31512 .24744 Mdot
.32229 .5324 Mdot
.66172 .35541 Mdot
.6761 .33066 Mdot
.65725 .4827 Mdot
.64166 .58852 Mdot
.29308 .66327 Mdot
.82109 .5727 Mdot
.72767 .54913 Mdot
.31623 .37415 Mdot
.39938 .23024 Mdot
.40242 .27185 Mdot
.56642 .74271 Mdot
.43291 .7776 Mdot
.63438 .34594 Mdot
.32433 .73781 Mdot
.58443 .26441 Mdot
.34637 .32197 Mdot
.6999 .55842 Mdot
.62772 .67597 Mdot
.7341 .58547 Mdot
.50992 .63533 Mdot
.45805 .65101 Mdot
.66681 .46193 Mdot
.72505 .33957 Mdot
.23924 .35438 Mdot
.53553 .17446 Mdot
.38248 .6391 Mdot
.50539 .22664 Mdot
.76823 .31092 Mdot
.72081 .3938 Mdot
.191 .56859 Mdot
.36775 .60161 Mdot
.57608 .76071 Mdot
.31838 .52422 Mdot
.75241 .45564 Mdot
.43647 .34151 Mdot
.67004 .25813 Mdot
.74407 .32391 Mdot
.39554 .25414 Mdot
.51933 .30811 Mdot
.51787 .70348 Mdot
.30698 .25874 Mdot
.75224 .66508 Mdot
.83174 .57765 Mdot
.55214 .393 Mdot
.32979 .26504 Mdot
.6512 .22595 Mdot
.72851 .64601 Mdot
.41252 .81494 Mdot
.36605 .49477 Mdot
.73779 .26833 Mdot
.72399 .75525 Mdot
.59906 .43194 Mdot
.64213 .61569 Mdot
.39572 .81299 Mdot
.2454 .72973 Mdot
.66672 .5628 Mdot
.50087 .72014 Mdot
.69497 .47264 Mdot
.74495 .44506 Mdot
.72305 .59191 Mdot
.69802 .40612 Mdot
.61972 .53163 Mdot
.38743 .55162 Mdot
.7297 .67462 Mdot
.25804 .49619 Mdot
.37813 .74741 Mdot
.29721 .77119 Mdot
.6707 .54405 Mdot
.35159 .2627 Mdot
.35333 .38988 Mdot
.80729 .55422 Mdot
.40032 .42105 Mdot
.29915 .768 Mdot
.24971 .49317 Mdot
.80613 .51286 Mdot
.62382 .24939 Mdot
.65077 .32788 Mdot
.4543 .78114 Mdot
.21085 .51696 Mdot
.74209 .42916 Mdot
.75483 .5921 Mdot
.64923 .77912 Mdot
.83381 .57152 Mdot
.68625 .42313 Mdot
.36686 .47899 Mdot
.55923 .30797 Mdot
.61011 .59135 Mdot
.26179 .36996 Mdot
.63357 .43946 Mdot
.29611 .26091 Mdot
.30543 .53252 Mdot
.39914 .65119 Mdot
.69146 .35373 Mdot
.37934 .74556 Mdot
.2382 .60552 Mdot
.27442 .53246 Mdot
.44778 .32292 Mdot
.22348 .67945 Mdot
.55629 .31261 Mdot
.77051 .57541 Mdot
.47091 .2383 Mdot
.62194 .19975 Mdot
.22864 .43024 Mdot
.38032 .23337 Mdot
.46089 .24379 Mdot
.29898 .47099 Mdot
.34333 .55447 Mdot
.69434 .30493 Mdot
.27671 .71815 Mdot
.34934 .29961 Mdot
.66714 .75402 Mdot
.57053 .25672 Mdot
.7303 .26736 Mdot
.3719 .40413 Mdot
.42627 .18043 Mdot
.2398 .4691 Mdot
.37858 .62822 Mdot
.80623 .59409 Mdot
.24053 .63591 Mdot
.61376 .45134 Mdot
.41654 .72503 Mdot
.20009 .35149 Mdot
.66431 .40125 Mdot
.31293 .24098 Mdot
.37635 .22084 Mdot
.64685 .59145 Mdot
.75724 .64299 Mdot
.22687 .54602 Mdot
.49756 .7611 Mdot
.67639 .51671 Mdot
.71385 .26728 Mdot
.38397 .51958 Mdot
.16448 .45561 Mdot
.3372 .45842 Mdot
.25261 .37686 Mdot
.42658 .75818 Mdot
.3998 .56364 Mdot
.53021 .81014 Mdot
.36468 .78808 Mdot
.52036 .79029 Mdot
.71124 .48388 Mdot
.66957 .26825 Mdot
.74777 .32605 Mdot
.36681 .74657 Mdot
.67974 .77956 Mdot
.60294 .36054 Mdot
.73483 .71979 Mdot
.73476 .41898 Mdot
.45017 .30781 Mdot
.22205 .30759 Mdot
.40844 .30261 Mdot
.73893 .59377 Mdot
.77131 .44515 Mdot
.27087 .29854 Mdot
.32524 .24148 Mdot
.43354 .36482 Mdot
.57493 .75441 Mdot
.6804 .60116 Mdot
.67913 .3175 Mdot
.72979 .52306 Mdot
.75096 .71549 Mdot
.61578 .38138 Mdot
.58259 .63087 Mdot
.66115 .22897 Mdot
.30591 .42291 Mdot
.59814 .33867 Mdot
.32254 .3659 Mdot
.60031 .59911 Mdot
.75475 .29399 Mdot
.19012 .47489 Mdot
.41748 .25038 Mdot
.42121 .63391 Mdot
.59947 .17828 Mdot
.27216 .36786 Mdot
.40102 .24049 Mdot
.35887 .54733 Mdot
.4811 .24254 Mdot
.44784 .61079 Mdot
.44346 .83169 Mdot
.18723 .51727 Mdot
.42957 .65625 Mdot
.18542 .57263 Mdot
.25647 .7193 Mdot
.2261 .35889 Mdot
.68549 .68411 Mdot
.63834 .70618 Mdot
.77854 .69733 Mdot
.36563 .20679 Mdot
.33707 .4773 Mdot
.37962 .43187 Mdot
.22842 .40456 Mdot
.53314 .27105 Mdot
.36382 .36581 Mdot
.4639 .75529 Mdot
.6687 .20598 Mdot
.58606 .67066 Mdot
.60798 .80129 Mdot
.27973 .52189 Mdot
.38522 .52629 Mdot
.31366 .27858 Mdot
.8001 .41736 Mdot
.42838 .38793 Mdot
.6675 .45608 Mdot
.68546 .56041 Mdot
.36443 .45689 Mdot
.23434 .60226 Mdot
.69225 .23283 Mdot
.59459 .40345 Mdot
.53545 .79738 Mdot
.58561 .19834 Mdot
.30142 .4809 Mdot
.3141 .65355 Mdot
.47706 .18168 Mdot
.47178 .25 Mdot
.26949 .56792 Mdot
.18479 .63292 Mdot
.43335 .38633 Mdot
.16659 .46067 Mdot
.63886 .40023 Mdot
.49431 .76247 Mdot
.26689 .60878 Mdot
.63825 .51564 Mdot
.74776 .3266 Mdot
.40081 .18162 Mdot
.71983 .53681 Mdot
.69876 .60984 Mdot
.44335 .30735 Mdot
.68903 .30603 Mdot
.64762 .75025 Mdot
.42177 .72998 Mdot
.31175 .27806 Mdot
.29292 .25013 Mdot
.38829 .76667 Mdot
.2727 .5808 Mdot
.41708 .81409 Mdot
.57119 .66492 Mdot
.42063 .32912 Mdot
.30628 .77809 Mdot
.26732 .34134 Mdot
.47789 .2082 Mdot
.58611 .32454 Mdot
.36206 .47054 Mdot
.78812 .49958 Mdot
.3738 .67779 Mdot
.47516 .34486 Mdot
.50076 .25365 Mdot
.5951 .19148 Mdot
.38991 .56408 Mdot
.44492 .22136 Mdot
.67702 .28969 Mdot
.22799 .3867 Mdot
.24827 .60349 Mdot
.16047 .487 Mdot
.61624 .41549 Mdot
.77376 .40104 Mdot
.27235 .3187 Mdot
.33552 .36642 Mdot
.3577 .38959 Mdot
.78875 .64548 Mdot
.68368 .26548 Mdot
.42956 .35114 Mdot
.42595 .70728 Mdot
.70368 .77092 Mdot
.31667 .25354 Mdot
.37105 .4512 Mdot
.7135 .71335 Mdot
.51951 .3487 Mdot
.7159 .50874 Mdot
.3597 .25202 Mdot
.36992 .81368 Mdot
.38463 .6738 Mdot
.23989 .64253 Mdot
.67749 .41152 Mdot
.53055 .27324 Mdot
.66265 .59973 Mdot
.29999 .40789 Mdot
.23821 .32798 Mdot
.78343 .31274 Mdot
.71143 .35744 Mdot
.79478 .51192 Mdot
.67649 .58131 Mdot
.40064 .72739 Mdot
.71323 .61102 Mdot
.33635 .57006 Mdot
.67777 .60318 Mdot
.80948 .4026 Mdot
.30129 .49438 Mdot
.48268 .71896 Mdot
.46794 .75621 Mdot
.36881 .38055 Mdot
.2531 .69732 Mdot
.61819 .68935 Mdot
.65185 .44361 Mdot
.69888 .3535 Mdot
.32604 .56779 Mdot
.3878 .44043 Mdot
.244 .57623 Mdot
.762 .69715 Mdot
.71832 .35254 Mdot
.62941 .6808 Mdot
.42236 .74629 Mdot
.53317 .82662 Mdot
.6473 .21381 Mdot
.533 .29246 Mdot
.67726 .7821 Mdot
.66941 .20241 Mdot
.52746 .64451 Mdot
.70709 .27364 Mdot
.4416 .37049 Mdot
.63743 .31355 Mdot
.67502 .68777 Mdot
.64198 .54335 Mdot
.81571 .4978 Mdot
.39029 .18535 Mdot
.18084 .60576 Mdot
.52633 .75484 Mdot
.28278 .64205 Mdot
.2416 .54121 Mdot
.76103 .66182 Mdot
.4473 .38453 Mdot
.64846 .68432 Mdot
.67589 .34337 Mdot
.53682 .66125 Mdot
.44246 .31489 Mdot
.51285 .21236 Mdot
.75926 .40319 Mdot
.38693 .41345 Mdot
.67452 .70511 Mdot
.38409 .47745 Mdot
.38301 .62071 Mdot
.57877 .63627 Mdot
.29476 .55232 Mdot
.74602 .44976 Mdot
.60107 .73421 Mdot
.46043 .29173 Mdot
.24509 .67872 Mdot
.5443 .73168 Mdot
.7013 .42213 Mdot
.38914 .67051 Mdot
.71137 .49747 Mdot
.1609 .46309 Mdot
.26716 .6064 Mdot
.54361 .32823 Mdot
.32076 .50555 Mdot
.2864 .41312 Mdot
.77476 .67818 Mdot
.64384 .70714 Mdot
.76864 .62838 Mdot
.73288 .48806 Mdot
.79012 .52452 Mdot
.34613 .3167 Mdot
.76805 .59684 Mdot
.34682 .72015 Mdot
.60415 .24815 Mdot
.21728 .46389 Mdot
.67253 .41311 Mdot
.41657 .59989 Mdot
.74703 .62786 Mdot
.52279 .64873 Mdot
.68976 .49695 Mdot
.63305 .31753 Mdot
.81786 .37559 Mdot
.25383 .28068 Mdot
.37057 .2843 Mdot
.54118 .71433 Mdot
.61998 .2169 Mdot
.63729 .24333 Mdot
.25405 .4113 Mdot
.79068 .58952 Mdot
.46414 .25063 Mdot
.20476 .61709 Mdot
.23004 .39836 Mdot
.7026 .27091 Mdot
.72998 .3092 Mdot
.31828 .39972 Mdot
.26687 .24916 Mdot
.52412 .31325 Mdot
.52869 .79292 Mdot
.71808 .37284 Mdot
.43464 .19452 Mdot
.60808 .28054 Mdot
.75365 .72441 Mdot
.33393 .3144 Mdot
.64838 .36462 Mdot
.51825 .36116 Mdot
.34973 .65632 Mdot
.75646 .67913 Mdot
.59681 .37581 Mdot
.19524 .46315 Mdot
.31904 .33815 Mdot
.4303 .33947 Mdot
.67818 .73993 Mdot
.23146 .29934 Mdot
.63161 .1982 Mdot
.42622 .77786 Mdot
.27022 .68017 Mdot
.47968 .74573 Mdot
.31851 .53789 Mdot
.31751 .56445 Mdot
.73135 .35528 Mdot
.21003 .4585 Mdot
.40817 .18722 Mdot
.30821 .58013 Mdot
.33168 .75196 Mdot
.79446 .57909 Mdot
.6328 .19806 Mdot
.74459 .68591 Mdot
.62549 .33421 Mdot
.69142 .38428 Mdot
.7911 .36912 Mdot
.42672 .81025 Mdot
.53979 .33876 Mdot
.27537 .38699 Mdot
.36498 .42994 Mdot
.32405 .65104 Mdot
.63293 .76706 Mdot
.35301 .64773 Mdot
.78465 .53965 Mdot
.70839 .25358 Mdot
.39629 .34241 Mdot
.50027 .66677 Mdot
.2291 .53451 Mdot
.53785 .7678 Mdot
.65577 .61337 Mdot
.80654 .46109 Mdot
.40759 .33476 Mdot
.44861 .7317 Mdot
.54233 .23805 Mdot
.20919 .54616 Mdot
.19892 .41442 Mdot
.44224 .24384 Mdot
.20285 .59654 Mdot
.53732 .2431 Mdot
.57392 .62515 Mdot
.28217 .73659 Mdot
.22984 .3473 Mdot
.39823 .30966 Mdot
.24976 .33565 Mdot
.34346 .29515 Mdot
.65065 .24867 Mdot
.29747 .54176 Mdot
.7504 .55859 Mdot
.53942 .38041 Mdot
.48434 .34298 Mdot
.34113 .29653 Mdot
.74264 .73816 Mdot
.44072 .71221 Mdot
.60203 .35327 Mdot
.32739 .70665 Mdot
.69477 .63781 Mdot
.63111 .4831 Mdot
.35656 .50818 Mdot
.45706 .61316 Mdot
.50065 .18339 Mdot
.69817 .41675 Mdot
.33012 .31987 Mdot
.54215 .67991 Mdot
.32516 .68376 Mdot
.63372 .35295 Mdot
.43402 .6879 Mdot
.35106 .24541 Mdot
.69355 .21888 Mdot
.2788 .658 Mdot
.52029 .74214 Mdot
.65298 .37847 Mdot
.40843 .78851 Mdot
.32323 .30579 Mdot
.47281 .24377 Mdot
.71864 .36787 Mdot
.79566 .34476 Mdot
.6001 .33195 Mdot
.55795 .19048 Mdot
.32141 .74719 Mdot
.30639 .24511 Mdot
.64712 .50972 Mdot
.48076 .3608 Mdot
.70208 .41882 Mdot
.2379 .6466 Mdot
.30099 .3852 Mdot
.26936 .38969 Mdot
.66262 .30932 Mdot
.63174 .18575 Mdot
.48493 .34755 Mdot
.6238 .755 Mdot
.18275 .59678 Mdot
.56837 .82587 Mdot
.32381 .33482 Mdot
.48734 .33612 Mdot
.45835 .20388 Mdot
.36561 .50019 Mdot
.72382 .30951 Mdot
.69792 .55587 Mdot
.47758 .2804 Mdot
.53097 .37791 Mdot
.47992 .61878 Mdot
.80417 .46055 Mdot
.27117 .27545 Mdot
.29128 .44242 Mdot
.39049 .80908 Mdot
.24533 .33616 Mdot
.61088 .21262 Mdot
.62064 .26834 Mdot
.35812 .60391 Mdot
.39709 .30022 Mdot
.7455 .70963 Mdot
.26267 .70094 Mdot
.51186 .74368 Mdot
.17421 .52164 Mdot
.81929 .49046 Mdot
.81456 .45829 Mdot
.62896 .35441 Mdot
.47483 .69756 Mdot
.4277 .59363 Mdot
.45816 .71248 Mdot
.18747 .45027 Mdot
.76794 .59247 Mdot
.22464 .61185 Mdot
.25322 .31042 Mdot
.71516 .4074 Mdot
.62153 .45599 Mdot
.44432 .6569 Mdot
.32023 .58665 Mdot
.41371 .36349 Mdot
.60756 .58379 Mdot
.49585 .71277 Mdot
.36532 .53099 Mdot
.6211 .26008 Mdot
.76414 .71723 Mdot
.6933 .77591 Mdot
.28654 .45129 Mdot
.43691 .35311 Mdot
.63383 .58166 Mdot
.35643 .41472 Mdot
.39121 .17932 Mdot
.61325 .76238 Mdot
.31238 .40267 Mdot
.26439 .40636 Mdot
.30751 .41448 Mdot
.68987 .25514 Mdot
.38188 .24943 Mdot
.28391 .59924 Mdot
.7628 .62267 Mdot
.58712 .60407 Mdot
.56711 .59864 Mdot
.65027 .49073 Mdot
.35723 .41426 Mdot
.80353 .39245 Mdot
.67649 .63636 Mdot
.21255 .54216 Mdot
.25075 .63972 Mdot
.46857 .78123 Mdot
.61881 .20631 Mdot
.42329 .6141 Mdot
.20857 .4508 Mdot
.52867 .70459 Mdot
.40144 .80321 Mdot
.3283 .44719 Mdot
.35295 .28236 Mdot
.60769 .77441 Mdot
.29726 .58334 Mdot
.5138 .29155 Mdot
.67183 .64526 Mdot
.4054 .18802 Mdot
.68643 .63444 Mdot
.71987 .32657 Mdot
.44185 .67436 Mdot
.54843 .72251 Mdot
.35235 .59701 Mdot
.39312 .33233 Mdot
.38326 .36841 Mdot
.2979 .32111 Mdot
.69919 .48988 Mdot
.5527 .28818 Mdot
.69837 .38315 Mdot
.35722 .5343 Mdot
.46211 .20768 Mdot
.30212 .52063 Mdot
.762 .30908 Mdot
.59847 .21135 Mdot
.45743 .73338 Mdot
.60138 .40036 Mdot
.28715 .67296 Mdot
.77307 .29552 Mdot
.44089 .80953 Mdot
.62781 .61803 Mdot
.70895 .46581 Mdot
.76796 .49398 Mdot
.24183 .53284 Mdot
.20082 .61128 Mdot
.29781 .59407 Mdot
.18161 .56435 Mdot
.70005 .62767 Mdot
.39694 .78946 Mdot
.75209 .55245 Mdot
.54189 .18634 Mdot
.30182 .24001 Mdot
.61384 .60263 Mdot
.31403 .32718 Mdot
.22018 .41253 Mdot
.48622 .31924 Mdot
.76272 .56855 Mdot
.26132 .55671 Mdot
.37769 .53907 Mdot
.20927 .63193 Mdot
.23273 .45592 Mdot
.46203 .69643 Mdot
.68516 .36499 Mdot
.45449 .23721 Mdot
.62185 .7956 Mdot
.60844 .68645 Mdot
.20555 .34943 Mdot
.50398 .2866 Mdot
.67099 .65349 Mdot
.59512 .35443 Mdot
.45238 .80564 Mdot
.28995 .50113 Mdot
.61036 .59751 Mdot
.6786 .42078 Mdot
.71033 .50281 Mdot
.38008 .80174 Mdot
.66165 .31024 Mdot
.71923 .672 Mdot
0 0 1 r
.97685 .49984 Mdot
.9504 .31221 Mdot
.16064 .70618 Mdot
.31895 .9461 Mdot
.98047 .02485 Mdot
.8447 .59623 Mdot
.17708 .26934 Mdot
.85805 .10619 Mdot
.77511 .02051 Mdot
.51709 .87879 Mdot
.81491 .6985 Mdot
.36625 .18242 Mdot
.52217 .04519 Mdot
.96074 .84346 Mdot
.21302 .08929 Mdot
.38512 .03793 Mdot
.22275 .07424 Mdot
.53061 .4319 Mdot
.05547 .7951 Mdot
.27056 .78439 Mdot
.15547 .44691 Mdot
.44585 .0957 Mdot
.77941 .2743 Mdot
.91387 .06032 Mdot
.71065 .96123 Mdot
.4977 .89679 Mdot
.89313 .95121 Mdot
.45203 .1115 Mdot
.19128 .3173 Mdot
.09451 .1884 Mdot
.73562 .2314 Mdot
.30529 .9043 Mdot
.81195 .18089 Mdot
.48662 .49306 Mdot
.1111 .20986 Mdot
.06288 .10996 Mdot
.15994 .14894 Mdot
.16136 .20157 Mdot
.90996 .51362 Mdot
.96028 .87447 Mdot
.82525 .33503 Mdot
.52976 .42093 Mdot
.41271 .48178 Mdot
.05294 .91806 Mdot
.98026 .81791 Mdot
.69802 .96865 Mdot
.83012 .67877 Mdot
.91036 .17495 Mdot
.57638 .89261 Mdot
.09492 .83012 Mdot
.55535 .419 Mdot
.92921 .75797 Mdot
.51222 .49114 Mdot
.91977 .5076 Mdot
.68223 .97485 Mdot
.76206 .8097 Mdot
.79693 .8185 Mdot
.67695 .96977 Mdot
.45501 .57875 Mdot
.13139 .56058 Mdot
.60937 .07925 Mdot
.8786 .33474 Mdot
.09702 .40602 Mdot
.94902 .81734 Mdot
.57571 .10623 Mdot
.76898 .27793 Mdot
.94638 .62228 Mdot
.82479 .07151 Mdot
.79797 .86858 Mdot
.22522 .98245 Mdot
.90957 .54365 Mdot
.138 .58624 Mdot
.95075 .7165 Mdot
.7232 .17468 Mdot
.09988 .56302 Mdot
.1437 .93093 Mdot
.3091 .86923 Mdot
.09369 .87697 Mdot
.94588 .30053 Mdot
.60439 .51425 Mdot
.23248 .13566 Mdot
.22936 .88437 Mdot
.1424 .56283 Mdot
.98891 .6221 Mdot
.33121 .87963 Mdot
.8371 .11503 Mdot
.60572 .85628 Mdot
.28196 .86466 Mdot
.42736 .4397 Mdot
.4482 .46604 Mdot
.29476 .86706 Mdot
.8249 .91402 Mdot
.50349 .0442 Mdot
.59664 .5019 Mdot
.65659 .91937 Mdot
.98111 .63582 Mdot
.38444 .06451 Mdot
.34088 .08007 Mdot
.90371 .63056 Mdot
.26847 .23825 Mdot
.92047 .28003 Mdot
.72607 .01663 Mdot
.87944 .29616 Mdot
.9041 .36342 Mdot
.86199 .89688 Mdot
.48013 .05879 Mdot
.53929 .39795 Mdot
.07807 .02991 Mdot
.39673 .14154 Mdot
.18344 .06878 Mdot
.31026 .18626 Mdot
.31164 .1621 Mdot
.82032 .13727 Mdot
.76255 .75435 Mdot
.94933 .37303 Mdot
.98449 .92081 Mdot
.88107 .35292 Mdot
.05304 .56478 Mdot
.08277 .08254 Mdot
.25264 .93547 Mdot
.95924 .64833 Mdot
.96257 .58676 Mdot
.01971 .2851 Mdot
.96828 .65615 Mdot
.12883 .92237 Mdot
.38051 .85728 Mdot
.89235 .30842 Mdot
.98749 .60808 Mdot
.84911 .73384 Mdot
.91453 .53534 Mdot
.12732 .33116 Mdot
.15828 .67303 Mdot
.69931 .01311 Mdot
.14837 .39773 Mdot
.02934 .46556 Mdot
.12719 .16694 Mdot
.35324 .86219 Mdot
.15076 .10194 Mdot
.98268 .41911 Mdot
.0579 .73348 Mdot
.84411 .03118 Mdot
.96653 .90626 Mdot
.6231 .05388 Mdot
.44872 .96558 Mdot
.204 .70742 Mdot
.30776 .87344 Mdot
.44678 .96084 Mdot
.46135 .44275 Mdot
.08162 .83122 Mdot
.62698 .87713 Mdot
.10528 .91516 Mdot
.90998 .48825 Mdot
.47238 .87108 Mdot
.47107 .51287 Mdot
.27818 .17346 Mdot
.17312 .62963 Mdot
.8216 .20282 Mdot
.84804 .17531 Mdot
.43272 .95586 Mdot
.36091 .13445 Mdot
.75971 .83582 Mdot
.26543 .20949 Mdot
.83992 .35737 Mdot
.37866 .83469 Mdot
.21534 .21486 Mdot
.68347 .95231 Mdot
.3575 .04936 Mdot
.26055 .98665 Mdot
.9512 .3168 Mdot
.88984 .862 Mdot
.35157 .12362 Mdot
.84116 .34352 Mdot
.96311 .27913 Mdot
.33609 .18839 Mdot
.75756 .07407 Mdot
.40987 .03451 Mdot
.25737 .24653 Mdot
.8484 .68588 Mdot
.896 .13271 Mdot
.01704 .35216 Mdot
.92309 .84378 Mdot
.67115 .17358 Mdot
.17533 .77951 Mdot
.03814 .93751 Mdot
.75566 .7548 Mdot
.3166 .0567 Mdot
.15365 .36929 Mdot
.06903 .80037 Mdot
.16322 .67747 Mdot
.23033 .82388 Mdot
.60725 .16747 Mdot
.0648 .05417 Mdot
.93285 .49285 Mdot
.97294 .24267 Mdot
.789 .13337 Mdot
.91371 .43249 Mdot
.50336 .44996 Mdot
.76029 .74522 Mdot
.22496 .12852 Mdot
.53977 .91153 Mdot
.60791 .95125 Mdot
.48477 .86717 Mdot
.03879 .7409 Mdot
.09614 .25785 Mdot
.29733 .13429 Mdot
.28897 .91225 Mdot
.56901 .55581 Mdot
.96931 .25549 Mdot
.9513 .59476 Mdot
.92231 .84406 Mdot
.83597 .59601 Mdot
.10623 .43657 Mdot
.54845 .47153 Mdot
.75448 .7872 Mdot
.19527 .24119 Mdot
.31927 .1018 Mdot
.81512 .71347 Mdot
.30206 .78277 Mdot
.51602 .92235 Mdot
.41959 .49559 Mdot
.89803 .71523 Mdot
.60234 .97126 Mdot
.15336 .91823 Mdot
.94828 .68684 Mdot
.98469 .54158 Mdot
.72392 .06002 Mdot
.17937 .8183 Mdot
.65355 .88614 Mdot
.96558 .0807 Mdot
.07736 .35566 Mdot
.9142 .42763 Mdot
.95611 .73098 Mdot
.16359 .41604 Mdot
.50024 .52009 Mdot
.82514 .35222 Mdot
.26628 .12953 Mdot
.75759 .98676 Mdot
.307 .91471 Mdot
.86768 .82814 Mdot
.96403 .68037 Mdot
.63548 .15718 Mdot
.81024 .27414 Mdot
.82515 .72426 Mdot
.00981 .38185 Mdot
.06334 .62452 Mdot
.42869 .91429 Mdot
.13149 .98977 Mdot
.52153 .9686 Mdot
.15766 .31921 Mdot
.87625 .82123 Mdot
.33761 .05487 Mdot
.0609 .10677 Mdot
.0276 .30082 Mdot
.0609 .71512 Mdot
.95445 .66649 Mdot
.80868 .33963 Mdot
.41947 .52328 Mdot
.88813 .54487 Mdot
.02169 .71384 Mdot
.91862 .38836 Mdot
.95098 .61688 Mdot
.90083 .09734 Mdot
.89989 .89196 Mdot
.93657 .42104 Mdot
.10101 .56213 Mdot
.67174 .04866 Mdot
.98712 .91621 Mdot
.76193 .77034 Mdot
.80248 .11404 Mdot
.80114 .16326 Mdot
.89185 .0265 Mdot
.89145 .2615 Mdot
.94547 .59565 Mdot
.80024 .68957 Mdot
.54447 .91702 Mdot
.1383 .65072 Mdot
.54754 .01061 Mdot
.35469 .16654 Mdot
.01417 .40399 Mdot
.77201 .23294 Mdot
.11252 .38729 Mdot
.87076 .96163 Mdot
.15724 .78183 Mdot
.08032 .28186 Mdot
.60297 .85502 Mdot
.93221 .62134 Mdot
.06523 .85421 Mdot
.58732 .46461 Mdot
.01417 .08802 Mdot
.24422 .942 Mdot
.23235 .84528 Mdot
.14151 .56451 Mdot
.35179 .87384 Mdot
.97446 .77287 Mdot
.38129 .90805 Mdot
.33926 .97063 Mdot
.32586 .06365 Mdot
.08708 .69806 Mdot
.83305 .74626 Mdot
.51522 .58254 Mdot
.70135 .19155 Mdot
.17323 .69889 Mdot
.88215 .10692 Mdot
.55269 .12648 Mdot
.02954 .43717 Mdot
.93266 .72931 Mdot
.07279 .17303 Mdot
.10941 .97325 Mdot
.54776 .58069 Mdot
.38433 .87199 Mdot
.33558 .89161 Mdot
.92988 .6582 Mdot
.13892 .06716 Mdot
.07594 .88433 Mdot
.86571 .94075 Mdot
.14385 .43166 Mdot
.85876 .6567 Mdot
.70199 .97897 Mdot
.57287 .9216 Mdot
.50673 .04708 Mdot
.90558 .71547 Mdot
.97855 .72382 Mdot
.04967 .76491 Mdot
.84451 .30197 Mdot
.83573 .21659 Mdot
.96717 .55009 Mdot
.91817 .72502 Mdot
.2449 .88048 Mdot
.32952 .17482 Mdot
.43288 .95412 Mdot
.37573 .02656 Mdot
.86509 .36033 Mdot
.0527 .28561 Mdot
.93712 .62551 Mdot
.52568 .92797 Mdot
.10261 .96404 Mdot
.19842 .8204 Mdot
.14831 .29514 Mdot
.28716 .01326 Mdot
.27342 .92501 Mdot
.94839 .11183 Mdot
.19378 .09558 Mdot
.02507 .63495 Mdot
.05527 .79064 Mdot
.77204 .85583 Mdot
.49365 .90383 Mdot
.45534 .55633 Mdot
.06699 .5813 Mdot
.10879 .47927 Mdot
.94651 .78713 Mdot
.71707 .90091 Mdot
.58603 .9214 Mdot
.93522 .05488 Mdot
.10219 .02737 Mdot
.48969 .48874 Mdot
.04501 .43627 Mdot
.82536 .30394 Mdot
.92641 .94719 Mdot
.86905 .50701 Mdot
.11632 .79586 Mdot
.28285 .19667 Mdot
.38945 .88514 Mdot
.44442 .84007 Mdot
.94493 .36112 Mdot
.12937 .06699 Mdot
.62321 .84483 Mdot
.03602 .10508 Mdot
.14399 .74452 Mdot
.74336 .8986 Mdot
.74474 .84957 Mdot
.06615 .64294 Mdot
.31012 .01931 Mdot
.46171 .40485 Mdot
.89248 .59323 Mdot
.9755 .05082 Mdot
.84131 .2965 Mdot
.10638 .43712 Mdot
.44335 .10178 Mdot
.97184 .68712 Mdot
.08916 .1037 Mdot
.21487 .18804 Mdot
.22956 .14702 Mdot
.37844 .84072 Mdot
.06734 .95745 Mdot
.61419 .86548 Mdot
.4856 .97599 Mdot
.05453 .21636 Mdot
.55319 .09427 Mdot
.82986 .03813 Mdot
.6101 .88131 Mdot
.19567 .0368 Mdot
.24146 .05039 Mdot
.13813 .06955 Mdot
.94979 .62718 Mdot
.87179 .01591 Mdot
.42927 .43482 Mdot
.3284 .91184 Mdot
.9697 .51539 Mdot
.38964 .16547 Mdot
.26132 .10573 Mdot
.77845 .83782 Mdot
.73738 .90165 Mdot
.31426 .20624 Mdot
.85579 .89555 Mdot
.87519 .76161 Mdot
.53719 .97391 Mdot
.95189 .79124 Mdot
.31588 .83973 Mdot
.59032 .55926 Mdot
.18038 .73913 Mdot
.30474 .20414 Mdot
.21869 .93809 Mdot
.97905 .3546 Mdot
.42083 .97007 Mdot
.74294 .14449 Mdot
.16573 .13189 Mdot
.04498 .41184 Mdot
.5656 .56282 Mdot
.8548 .66291 Mdot
.28181 .02369 Mdot
.01889 .4125 Mdot
.85118 .04382 Mdot
.93025 .50514 Mdot
.07381 .45917 Mdot
.89507 .1031 Mdot
.49841 .88654 Mdot
.05008 .43038 Mdot
.94592 .51398 Mdot
.10455 .47996 Mdot
.865 .88891 Mdot
.75242 .1579 Mdot
.84754 .06461 Mdot
.08465 .02513 Mdot
.42272 .90906 Mdot
.12892 .50135 Mdot
.04726 .616 Mdot
.03418 .03119 Mdot
.34498 .95295 Mdot
.15938 .13248 Mdot
.046 .14975 Mdot
.90834 .13543 Mdot
.95154 .13442 Mdot
.83242 .62327 Mdot
.45796 .59077 Mdot
.12278 .62802 Mdot
.795 .07311 Mdot
.87686 .92788 Mdot
.47993 .88862 Mdot
.92347 .14014 Mdot
.01342 .80754 Mdot
.68392 .03109 Mdot
.48527 .61585 Mdot
.09786 .84349 Mdot
.21717 .94725 Mdot
.60812 .94507 Mdot
.28389 .81692 Mdot
.93623 .65833 Mdot
.93262 .84099 Mdot
.18332 .63543 Mdot
.25851 .81971 Mdot
.68825 .02938 Mdot
.09944 .34141 Mdot
.87247 .38435 Mdot
.15211 .64637 Mdot
.59838 .55763 Mdot
.20607 .97824 Mdot
.14459 .24304 Mdot
.26365 .14705 Mdot
.95146 .5978 Mdot
.01495 .31754 Mdot
.16666 .8532 Mdot
.18337 .24662 Mdot
.3011 .85247 Mdot
.06786 .61755 Mdot
.55814 .07141 Mdot
.59687 .4638 Mdot
.78926 .17256 Mdot
.33367 .87577 Mdot
.1601 .63895 Mdot
.23577 .0576 Mdot
.8492 .77668 Mdot
.96184 .44221 Mdot
.90379 .81486 Mdot
.11919 .34436 Mdot
.01107 .94663 Mdot
.32013 .1816 Mdot
.6676 .08066 Mdot
.67793 .86224 Mdot
.51731 .4319 Mdot
.56673 .55738 Mdot
.89408 .74334 Mdot
.89281 .78691 Mdot
.14701 .05103 Mdot
.01712 .35474 Mdot
.0594 .63873 Mdot
.52699 .9629 Mdot
.54757 .47515 Mdot
.95046 .41533 Mdot
.74107 .92529 Mdot
.36572 .16109 Mdot
.89664 .9723 Mdot
.79815 .9153 Mdot
.88933 .62736 Mdot
.21079 .80142 Mdot
.5573 .08922 Mdot
.89915 .05662 Mdot
.80643 .15412 Mdot
.54323 .88572 Mdot
.30038 .92527 Mdot
.63679 .90362 Mdot
.49243 .01978 Mdot
.53309 .91238 Mdot
.95365 .38229 Mdot
.96599 .83296 Mdot
.06431 .33547 Mdot
.16936 .68864 Mdot
.51127 .43994 Mdot
.85917 .75356 Mdot
.86468 .52652 Mdot
.13682 .25026 Mdot
.63267 .02979 Mdot
.10938 .10761 Mdot
.78823 .24637 Mdot
.13358 .26485 Mdot
.73372 .90109 Mdot
.95442 .5664 Mdot
.10505 .80304 Mdot
.35777 .93463 Mdot
.7187 .06926 Mdot
.09583 .04927 Mdot
.46927 .08513 Mdot
.97665 .93186 Mdot
.67123 .82895 Mdot
.85288 .67682 Mdot
.92771 .91806 Mdot
.88866 .12022 Mdot
.79341 .30738 Mdot
.08452 .24792 Mdot
.13634 .80851 Mdot
.97888 .20845 Mdot
.01203 .26679 Mdot
.97623 .89443 Mdot
.14935 .58016 Mdot
.05832 .96657 Mdot
.97617 .01678 Mdot
.37296 .91445 Mdot
.84963 .19846 Mdot
.24249 .86885 Mdot
.98179 .40891 Mdot
.81455 .06521 Mdot
.82858 .05824 Mdot
.18076 .32228 Mdot
.96914 .84997 Mdot
.41445 .14766 Mdot
.57044 .84326 Mdot
.18176 .269 Mdot
.19017 .85029 Mdot
.74989 .17435 Mdot
.98436 .90047 Mdot
.42372 .06701 Mdot
.0924 .29757 Mdot
.0209 .77901 Mdot
.89242 .43747 Mdot
.42282 .56602 Mdot
.26578 .8141 Mdot
.88238 .0967 Mdot
.13129 .81839 Mdot
.88821 .18643 Mdot
.85713 .27143 Mdot
.4743 .12923 Mdot
.77454 .96406 Mdot
.87231 .53639 Mdot
.05019 .76459 Mdot
.81604 .19949 Mdot
.58706 .1094 Mdot
.82762 .10967 Mdot
.12257 .97037 Mdot
.06289 .13581 Mdot
.60917 .86536 Mdot
.55465 .86732 Mdot
.74684 .22602 Mdot
.04405 .31614 Mdot
.16958 .12642 Mdot
.20662 .21628 Mdot
.05682 .14625 Mdot
.15353 .09027 Mdot
.39745 .49669 Mdot
.96294 .49085 Mdot
.54656 .1291 Mdot
.6795 .9263 Mdot
.78992 .89328 Mdot
.44844 .41349 Mdot
.19549 .15332 Mdot
.33197 .83236 Mdot
.40721 .52198 Mdot
.90406 .22843 Mdot
.85084 .40269 Mdot
.07072 .49961 Mdot
.14067 .25888 Mdot
.83783 .08273 Mdot
.82615 .91606 Mdot
.65215 .91961 Mdot
.50398 .0935 Mdot
.59011 .85527 Mdot
.3941 .01455 Mdot
.77644 .90037 Mdot
.8926 .78219 Mdot
.06457 .70926 Mdot
.80962 .72543 Mdot
.15767 .38222 Mdot
.71553 .77666 Mdot
.4304 .86253 Mdot
.528 .09014 Mdot
.91817 .64244 Mdot
.11835 .90721 Mdot
.08042 .58143 Mdot
.7931 .27528 Mdot
.91294 .20901 Mdot
.08738 .48882 Mdot
.16897 .82173 Mdot
.72877 .9494 Mdot
.15405 .97157 Mdot
.21058 .86906 Mdot
.11754 .42192 Mdot
.65693 .91655 Mdot
.31463 .15644 Mdot
.57501 .8858 Mdot
.83644 .9266 Mdot
.63567 .06735 Mdot
.14894 .07221 Mdot
.89833 .54976 Mdot
.04121 .64049 Mdot
.50722 .89627 Mdot
.9224 .02027 Mdot
.97025 .45334 Mdot
.09576 .08387 Mdot
.61484 .0618 Mdot
.45029 .02633 Mdot
.47571 .97979 Mdot
.54216 .46676 Mdot
.30076 .83354 Mdot
.71773 .84544 Mdot
.78374 .92747 Mdot
.23802 .02901 Mdot
.85154 .917 Mdot
.76558 .84293 Mdot
.3251 .82641 Mdot
.71331 .18497 Mdot
.48218 .52611 Mdot
.98578 .32972 Mdot
.8273 .66204 Mdot
.07152 .8093 Mdot
.86629 .23079 Mdot
.73662 .97308 Mdot
.95369 .61343 Mdot
.98556 .52155 Mdot
.48131 .09712 Mdot
.98998 .20163 Mdot
.24222 .8813 Mdot
.94576 .82664 Mdot
.72301 .15625 Mdot
.88404 .02714 Mdot
.84692 .91566 Mdot
.15722 .04425 Mdot
.14805 .22875 Mdot
.15268 .6974 Mdot
.1529 .50558 Mdot
.90995 .82542 Mdot
.90087 .61447 Mdot
.95438 .98897 Mdot
.08015 .97164 Mdot
.91312 .93719 Mdot
.1927 .32362 Mdot
.04982 .61641 Mdot
.03638 .20208 Mdot
.88712 .12064 Mdot
.11663 .36686 Mdot
.97645 .49636 Mdot
.15244 .36808 Mdot
.79859 .03814 Mdot
.0821 .38664 Mdot
.47745 .48578 Mdot
.15917 .43965 Mdot
.29455 .17197 Mdot
.42018 .90387 Mdot
.37136 .92875 Mdot
.14414 .97666 Mdot
.56297 .90041 Mdot
.07184 .59983 Mdot
.09533 .42444 Mdot
.90287 .16998 Mdot
.79097 .26228 Mdot
.1087 .5349 Mdot
.19843 .28161 Mdot
.81212 .19016 Mdot
.81727 .34306 Mdot
.67778 .20369 Mdot
.17857 .01821 Mdot
.22038 .18738 Mdot
.82175 .04921 Mdot
.12149 .64268 Mdot
.55176 .98188 Mdot
.98643 .66458 Mdot
.38299 .97348 Mdot
.015 .23715 Mdot
.08258 .06293 Mdot
.18345 .19775 Mdot
.95129 .41045 Mdot
.54052 .43016 Mdot
.66152 .93832 Mdot
.72467 .01543 Mdot
.05935 .67968 Mdot
.18272 .02374 Mdot
.06312 .02491 Mdot
.78992 .04046 Mdot
.76016 .7746 Mdot
.78473 .79351 Mdot
.08036 .18521 Mdot
.07458 .37271 Mdot
.34589 .17958 Mdot
.02503 .68322 Mdot
.17298 .16564 Mdot
.9521 .66812 Mdot
.37325 .13498 Mdot
.20175 .88372 Mdot
.95784 .7163 Mdot
.76846 .84141 Mdot
.88728 .5409 Mdot
.72656 .12718 Mdot
.02456 .0901 Mdot
.03986 .07142 Mdot
.4684 .04213 Mdot
.2616 .2202 Mdot
.57131 .49143 Mdot
.02993 .13012 Mdot
.84984 .93658 Mdot
.63211 .90504 Mdot
.13309 .81921 Mdot
.61735 .82474 Mdot
.19112 .08591 Mdot
.55861 .53374 Mdot
.71292 .05358 Mdot
.15141 .55235 Mdot
.13128 .43203 Mdot
.88926 .63528 Mdot
.48937 .51719 Mdot
.76598 .80627 Mdot
.86221 .68264 Mdot
.18711 .22071 Mdot
.95817 .56275 Mdot
.81657 .02021 Mdot
.66391 .14667 Mdot
.21552 .07099 Mdot
.88813 .3306 Mdot
.71082 .11969 Mdot
.10193 .43272 Mdot
.68483 .20926 Mdot
.77045 .0789 Mdot
.85845 .19885 Mdot
.21728 .29696 Mdot
.17317 .61067 Mdot
.94784 .54948 Mdot
.64563 .81969 Mdot
.925 .7098 Mdot
.95153 .40873 Mdot
.83287 .28689 Mdot
.27651 .20928 Mdot
.07223 .21779 Mdot
.40825 .02023 Mdot
.84515 .91103 Mdot
.28724 .84046 Mdot
.65596 .93125 Mdot
.72115 .23125 Mdot
.87848 .93456 Mdot
.43525 .07113 Mdot
.81605 .72657 Mdot
.03681 .06071 Mdot
.96111 .80574 Mdot
.65952 .0548 Mdot
.01337 .11374 Mdot
.83158 .14116 Mdot
.28242 .87269 Mdot
.13942 .86076 Mdot
.39413 .92833 Mdot
.69436 .79943 Mdot
.87544 .10718 Mdot
.92804 .35103 Mdot
.92447 .24709 Mdot
.04784 .72701 Mdot
.10189 .81888 Mdot
.1626 .62963 Mdot
.22977 .24037 Mdot
.24285 .18762 Mdot
.56811 .86597 Mdot
.82348 .88324 Mdot
.12789 .40771 Mdot
.08985 .6709 Mdot
.51903 .40573 Mdot
.91745 .05107 Mdot
.36479 .91827 Mdot
.15503 .69831 Mdot
.14482 .6877 Mdot
.90238 .5205 Mdot
.0887 .62745 Mdot
.95101 .22954 Mdot
.64541 .14782 Mdot
.87096 .54884 Mdot
.13618 .73229 Mdot
.9437 .50758 Mdot
.76159 .80422 Mdot
.79848 .79947 Mdot
.62657 .12632 Mdot
.8863 .28877 Mdot
.06946 .30458 Mdot
.79332 .92235 Mdot
.84659 .43178 Mdot
.15772 .78434 Mdot
.96582 .87313 Mdot
.03134 .06185 Mdot
.03192 .37535 Mdot
.25995 .24783 Mdot
.62357 .13132 Mdot
.76078 .88478 Mdot
.61287 .11025 Mdot
.59134 .0582 Mdot
.65619 .93573 Mdot
.12462 .10214 Mdot
.15371 .85231 Mdot
.60448 .46655 Mdot
.38312 .95773 Mdot
.94074 .27254 Mdot
.76044 .85728 Mdot
.27223 .94185 Mdot
.17891 .80888 Mdot
.60624 .01593 Mdot
.82792 .01812 Mdot
.17369 .62667 Mdot
.1299 .32926 Mdot
.05887 .53433 Mdot
.96639 .46715 Mdot
.44458 .07759 Mdot
.59307 .49962 Mdot
.82283 .63254 Mdot
.23161 .8436 Mdot
.65372 .81385 Mdot
.61557 .83747 Mdot
.816 .80554 Mdot
.7197 .02873 Mdot
.94823 .60868 Mdot
.13643 .51931 Mdot
.3038 .87697 Mdot
.24219 .95023 Mdot
.64028 .07292 Mdot
.61682 .12256 Mdot
.81448 .25758 Mdot
.17493 .89215 Mdot
.12839 .7617 Mdot
.76251 .22549 Mdot
.27225 .23327 Mdot
.95865 .3465 Mdot
.11789 .83354 Mdot
.50389 .0356 Mdot
.32614 .81883 Mdot
.55383 .60315 Mdot
.97662 .51152 Mdot
.73956 .98634 Mdot
.74572 .93174 Mdot
.91366 .63236 Mdot
.90997 .20668 Mdot
.55174 .85675 Mdot
.18021 .21053 Mdot
.77132 .01775 Mdot
.09184 .63696 Mdot
.65468 .96899 Mdot
.69038 .02986 Mdot
.22658 .22003 Mdot
.20286 .95856 Mdot
.30681 .02316 Mdot
.64132 .11161 Mdot
.1364 .80283 Mdot
.72172 .87655 Mdot
.85536 .15598 Mdot
.07684 .89776 Mdot
.17478 .13593 Mdot
.9384 .90609 Mdot
.14277 .59277 Mdot
.6414 .89274 Mdot
.49165 .49096 Mdot
.5148 .09971 Mdot
.67809 .95785 Mdot
.16933 .29502 Mdot
.94657 .09111 Mdot
.30417 .14885 Mdot
.87954 .18355 Mdot
.13919 .02272 Mdot
.19099 .10683 Mdot
.42055 .02965 Mdot
.9191 .52888 Mdot
.03479 .11438 Mdot
.85565 .80955 Mdot
.84176 .68375 Mdot
.50211 .14483 Mdot
.95688 .10368 Mdot
.25921 .76183 Mdot
.8175 .11404 Mdot
.71003 .11376 Mdot
.57658 .54367 Mdot
.86564 .18739 Mdot
.19929 .91608 Mdot
.1294 .71209 Mdot
.98751 .83003 Mdot
.71571 .07398 Mdot
.98867 .29584 Mdot
.84027 .87679 Mdot
.22158 .98101 Mdot
.65078 .95091 Mdot
.13707 .63205 Mdot
.16219 .75509 Mdot
.13976 .79221 Mdot
.85029 .15705 Mdot
.84267 .07594 Mdot
.14438 .09287 Mdot
.84419 .77029 Mdot
.29431 .20627 Mdot
.93643 .51989 Mdot
.80916 .87803 Mdot
.20936 .01348 Mdot
.67921 .09563 Mdot
.34926 .84662 Mdot
.82674 .0295 Mdot
.21469 .76356 Mdot
.97274 .2494 Mdot
.91058 .56709 Mdot
.40389 .93042 Mdot
.91511 .56277 Mdot
.58493 .06219 Mdot
.89591 .95676 Mdot
.07898 .93707 Mdot
.17121 .92931 Mdot
.09643 .69748 Mdot
.7365 .24717 Mdot
.95436 .05048 Mdot
.04905 .47791 Mdot
.74768 .25455 Mdot
.32369 .909 Mdot
.84196 .28798 Mdot
.93779 .21614 Mdot
.77638 .27703 Mdot
.53535 .89521 Mdot
.93986 .39646 Mdot
.57118 .85453 Mdot
.60725 .09933 Mdot
.84976 .83497 Mdot
.01761 .55679 Mdot
.23502 .22549 Mdot
.48428 .97446 Mdot
.53905 .58186 Mdot
.93912 .08905 Mdot
.97234 .10568 Mdot
.83601 .82849 Mdot
.13238 .2609 Mdot
.12458 .69431 Mdot
.36712 .11919 Mdot
.87976 .47862 Mdot
.87304 .13493 Mdot
.35051 .88696 Mdot
.92411 .05568 Mdot
.71036 .98286 Mdot
.09239 .62199 Mdot
.64225 .18165 Mdot
.83263 .38747 Mdot
.89871 .34159 Mdot
.54042 .57353 Mdot
.76145 .95804 Mdot
.12467 .61326 Mdot
.5496 .88616 Mdot
.58305 .95299 Mdot
.82432 .38337 Mdot
.931 .78114 Mdot
.98189 .9861 Mdot
.09299 .65431 Mdot
.10865 .92272 Mdot
.73084 .15349 Mdot
.33739 .95488 Mdot
.10846 .62573 Mdot
.0594 .10144 Mdot
.94094 .16891 Mdot
.89941 .55249 Mdot
.80076 .91695 Mdot
.40063 .843 Mdot
.2615 .197 Mdot
.0821 .85667 Mdot
.0325 .76504 Mdot
.17348 .77453 Mdot
.08176 .60593 Mdot
.26426 .23184 Mdot
.45861 .41151 Mdot
.06778 .5587 Mdot
.20201 .11789 Mdot
.29683 .10434 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`2Hooooo`?o003oP?ooool1o`00007o
oooo00000ol0003oooooooooo`0gooooo`?o003o5?ooool3o`00oa_ooooo0ol00?lXooooo`Go003o
:?ooool3o`00o`Cooooo0ol00?lWooooo`?o003o8oooool1o`00007ooooo00000ol0003ooooooooo
o`0_ooooo`?o003o1?ooool5o`00oa;ooooo1Ol00?l2ooooo`?o003o5?ooool5o`00obOooooo1Ol0
0?l=ooooo`?o003o5oooool5o`00o`;ooooo1Ol00?l9ooooo`?o003o3_ooool3o`00o`Sooooo1Ol0
0?lJooooo`?o003o1Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`?o003o2?ooool5
o`00o`?ooooo1Ol00?lBooooo`Go003o00?oooooo`00ool00?l00ol00?lCooooo`So003o5_ooool3
o`00o`_ooooo1Ol00?l<ooooo`Go003o5_ooool5o`00o`;ooooo1_l00?l7ooooo`Ko003o2?ooool8
o`00o`Oooooo1Ol00?l;ooooo`?o003o2oooool5o`00o`Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool03Oooool3o`00o`Cooooo0ol00?l;ooooo`Go003o1oooool5o`00o`?ooooo1Ol00?lAoooo
o`Ko003o00?oooooo`00ool00?l00ol00?lCooooo`Wo003o2?ooool3o`00o`Wooooo1Ol00?l;oooo
o`?o003o3Oooool5o`00oaKooooo1Ol00?l2ooooo`Ko003o1oooool7o`00o`Kooooo2Ol00?l7oooo
o`Go003o2_ooool5o`00o`[ooooo1Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00co
oooo1Ol00?l2ooooo`Go003o00Coooooo`00ool00?oo003o1_ooool5o`00o`Oooooo1_l00?l3oooo
o`?o003o1_ooool3o`00o`Sooooo1_l00?l00ooooooo003oo`00o`04o`00o`oooooo0ol00?l2oooo
o`_o003o1?ooool5o`00o`Sooooo1Ol00?lKooooo`Go003o1?ooool3o`00o`gooooo1_l00?l3oooo
o`Ko003o1oooool7o`00o`Kooooo2Ol00?l8ooooo`?o003o00?oooooo`00ool00?l00ol00?l5oooo
o`Go003o2_ooool6o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3o`00o`Co
oooo1Ol00?l00ooooooo003oo`00o`09o`00o`Gooooo1Ol00?l8ooooo`Go003o2oooool5o`00o`Oo
oooo1Ol00?l2ooooo`Go003o3oooool5o`00o`Cooooo2Ol00?l3ooooo`Go003o2?ooool5o`00oaco
oooo0ol00?l4ooooo`Go003o2_ooool6o`00o`Cooooo1_l00?l9ooooo`Ko003o1_ooool8o`00o`04
ooooool00?oo003oo`00o`Sooooo1ol00?l4ooooo`Go003o2oooool5o`00o`?ooooo0Ol00001oooo
o`0000?o0000ooooooooool01?ooool5o`00o`?ooooo4Ol00?l6ooooo`?o003o2Oooool7o`00o`Wo
oooo1Ol00?l7ooooo`Go003o0_ooool5o`00o`oooooo1Ol00?l5ooooo`So003o0oooool5o`00o`Wo
oooo1_l00?lQooooo`Go003o2Oooool7o`00o`Cooooo1Ol00?l<ooooo`?o003o2?ooool<o`00o`Oo
oooo1ol00?l5ooooo`?o003o3?ooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
1?ooool5o`00o`Cooooo0ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o00?o003o
4oooool7o`00o`Sooooo1Ol00?l8ooooo`?o003o1?ooool3o`00oa3ooooo1ol00?l3ooooo`So003o
1?ooool3o`00o`cooooo1Ol00?lPooooo`Go003o2Oooool7o`00o`Cooooo1Ol00?lBooooo`?o003o
1?ooool:o`00o`Oooooo1ol00?lEooooo`?o003o1?ooool1o`00007ooooo00000ol0003ooooooooo
o`04ooooo`Go003o2?ooool5o`00o`?ooooo0ol00?lFooooo`Go003o2Oooool3o`00obCooooo1ol0
0?l2ooooo`Oo003o2oooool3o`00o`Kooooo1Ol00?lQooooo`?o003o2_ooool6o`00o`Kooooo0ol0
0?lAooooo`Ko003o1?ooool9o`00o`Sooooo1Ol00?lMooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo0ol00?l:ooooo`?o003o4oooool3o`00o`Oooooo1Ol00?lbooooo`Go003o0_ooool5
o`00o`cooooo1Ol00?l5ooooo`Go003o00Coooooo`00ool00?oo003o:oooool3o`00oa_ooooo1ol0
0?l4ooooo`[o003o:Oooool1o`00007ooooo00000ol0003oooooooooo`0Gooooo`?o003o3Oooool5
o`00o`Oooooo0ol00?l;ooooo`?o003o7_ooool3o`00o`Cooooo1Ol00?l3ooooo`?o003o3Oooool5
o`00o`Gooooo2_l00?lWooooo`?o003o7_ooool7o`00o`?ooooo1_l00?l00ooooooo003oo`00o`03
o`00oa[ooooo0ol00?l;ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo0ol00?l5oooo
o`Go003o2_ooool7o`00oaCooooo1Ol00?lLooooo`Go003o1?ooool3o`00oaCooooo1Ol00?l5oooo
o`[o003o6Oooool3o`00o`[ooooo1Ol00?l8ooooo`?o003o4_ooool6o`00o`?ooooo1_l00?l2oooo
o`Go003o3oooool3o`00o`Oooooo1Ol00?l2ooooo`?o003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`0=ooooo`Go003o1?ooool5o`00o`Wooooo2?l00?lCooooo`Ko003o4Oooool3o`00o`?o
oooo0ol00?l2ooooo`Go003o7?ooool3o`00o`Kooooo2_l00?lHooooo`Go003o1_ooool8o`00o`Oo
oooo1Ol00?lBooooo`?o003o1Oooool5o`00o`?ooooo1Ol00?l:ooooo`?o003o00?oooooo`00ool0
0?l01ol00?l2ooooo`Go003o00?oooooo`00ool00?l00ol00?l4ooooo`7o00000Oooool00003o`00
0?oooooooooo00Kooooo0ol00?l4ooooo`Go003o1?ooool5o`00o`Wooooo1ol00?lCooooo`Oo003o
4?ooool5o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l00ol00?lOooooo`?o003o
1?ooool4o`00o`04ooooool00?oo003oo`00oa7ooooo0ol00?l5ooooo`Go003o1Oooool9o`00o`Oo
oooo1ol00?lHooooo`Ko003o0oooool3o`00o`[ooooo3ol00?l00ooooooo003oo`00o`03o`00o`03
ooooool00?oo003o00?o003o1?ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Ko003o
0oooool5o`00o`05ooooool00?oo003oo`00ooooool00ol00?l:ooooo`Go003o5Oooool6o`00oa7o
oooo2ol00?l2ooooo`?o003o1Oooool3o`00oaOooooo1Ol00?lJooooo`Ko003o0oooool6o`00o`Go
oooo2?l00?l8ooooo`So003o6?ooool6o`00o`04ooooool00?oo003oo`00o`_ooooo3ol00?l2oooo
o`?o003o0_ooool5o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool7o`00o`Co
oooo0ol00?l00ooooooo003oo`00o`03o`00o`Wooooo2?l00?lFooooo`Go003o4_ooool;o`00o`Wo
oooo1Ol00?l7ooooo`?o003o3?ooool5o`00oaWooooo1ol00?l2ooooo`Ko003o00Coooooo`00ool0
0?oo003o0_ooool5o`00o`cooooo1ol00?lFooooo`go003o2_ooool?o`00o`Sooooo0ol00?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooo1ol00?l8ooooo`Go003o2?ooool8o`00o`Wo
oooo0ol00?l6ooooo`?o003o0oooool3o`00oaCooooo2Ol00?l:ooooo`Go003o1_ooool7o`00o`Wo
oooo1Ol00?lBooooo`?o003o1?ooool7o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`;o
oooo0ol00?l>ooooo`Ko003o5Oooool>o`00o`_ooooo3Ol00?lAooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo2?l00?l7ooooo`Go003o2?ooool:o`00o`Kooooo1Ol00?l4ooooo`Ko003o
6_ooool5o`00o`cooooo1Ol00?l6ooooo`So003o2Oooool3o`00oa;ooooo1Ol00?l3ooooo`Ko003o
0oooool5o`00o`03ooooool00?oo003o00?o003o4_ooool6o`00o`Oooooo0ol00?l7ooooo`?o003o
0_ooool8o`00o`03ooooool00?oo003o00?o003o3oooool3o`00oaOooooo0Ol00001ooooo`0000?o
0000ooooooooool01?ooool7o`00o`Sooooo0ol00?l9ooooo`_o003o1Oooool5o`00o`Cooooo1ol0
0?lJooooo`?o003o3_ooool3o`00o`Oooooo2_l00?lLooooo`Go003o1?ooool3o`00o`Kooooo0ol0
0?l2ooooo`Ko003o4Oooool5o`00o`Oooooo1Ol00?l5ooooo`Go003o00?oooooo`00ool00?l01_l0
0?l00ooooooo003oo`00o`02o`00ob[ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5
o`00oaGooooo2_l00?l5ooooo`Go003o1?ooool7o`00oakooooo0ol00?lEooooo`[o003o6oooool5
o`00o`_ooooo0ol00?l5ooooo`Go003o1?ooool3o`00o`[ooooo1Ol00?l7ooooo`Oo003o0oooool5
o`00o`;ooooo3?l00?lOooooo`?o003o2?ooool1o`00007ooooo00000ol0003oooooooooo`07oooo
o`?o003o2Oooool3o`00o`04ooooool00?oo003oo`00o`Wooooo1ol00?l6ooooo`?o003o1_ooool6
o`00oagooooo1Ol00?lGooooo`Oo003o0oooool3o`00oaKooooo0ol00?l;ooooo`Go003o1?ooool5
o`00o`?ooooo1Ol00?l9ooooo`Go003o1oooool8o`00o`;ooooo1Ol00?l5ooooo`?o003o00?ooooo
o`00ool00?l00ol00?lNooooo`Go003o1oooool1o`00007ooooo00000ol0003oooooo`00o`02o`00
oa3ooooo2Ol00?l;ooooo`?o003o2Oooool3o`00o`Kooooo0ol00?lNooooo`Go003o6Oooool5o`00
o`;ooooo1Ol00?lSooooo`Go003o1Oooool3o`00o`Cooooo1Ol00?l:ooooo`?o003o2Oooool7o`00
o`?ooooo0ol00?l9ooooo`Ko003o6?ooool3o`00o`?ooooo1Ol00?l7ooooo`7o00000Oooool00003
o`000?l00?oo003o00Go003o3Oooool9o`00o`cooooo0ol00?l7ooooo`Go003o0_ooool3o`00ob7o
oooo1Ol00?lJooooo`?o003o0oooool5o`00o`gooooo0ol00?l5ooooo`?o003o2oooool5o`00o`co
oooo1Ol00?lHooooo`Go003o3oooool5o`00oaSooooo1_l00?l00ooooooo003oo`00o`03o`00o`Oo
oooo0Ol00001ooooo`0000?o0000o`00ool00?l01_l00?l<ooooo`Wo003o2_ooool6o`00o`Kooooo
1Ol00?l00ooooooo003oo`00o`03o`00ob7ooooo0ol00?lKooooo`?o003o0oooool5o`00o`Kooooo
0ol00?l3ooooo`Go003o0oooool5o`00o`_ooooo0ol00?l>ooooo`Ko003o5oooool3o`00oa3ooooo
1Ol00?lHooooo`Oo003o00Coooooo`00ool00?oo003o2?ooool1o`00007ooooo00000ol0003o003o
o`00o`06o`00o`gooooo0ol00?l01?oooooo003oo`00ool00?l:ooooo`Oo003o1_ooool;o`00ocko
oooo1Ol00?l3ooooo`Ko003o0oooool5o`00o`;ooooo1Ol00?l2ooooo`Ko003o2_ooool3o`00oa7o
oooo1Ol00?lZooooo`?o003o2Oooool3o`00o`?ooooo0ol00?l7ooooo`Oo003o3?ooool1o`00007o
oooo00000ol0003oooooo`00o`06o`00o`Kooooo0ol00?l@ooooo`?o003o0_ooool7o`00o`Oooooo
2_l00?lKooooo`?o003o8?ooool5o`00o`Gooooo1Ol00?l2ooooo`co003o0_ooool6o`00o`Wooooo
1Ol00?l@ooooo`Go003o=Oooool5o`00o`03ooooool00?oo003o00?o003o1oooool6o`00o`cooooo
0Ol00001ooooo`0000?o0000ooooooooool00_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo
1Ol00?l5ooooo`?o003o1_ooool5o`00o`03ooooool00?oo003o00Go003o1oooool5o`00o`04oooo
ool00?oo003oo`00o`_ooooo0ol00?l7ooooo`?o003o0oooool5o`00oakooooo1_l00?l5ooooo`Go
003o0_ooool;o`00o`?ooooo1Ol00?l2ooooo`?o003o1Oooool5o`00oa3ooooo1Ol00?l_ooooo`?o
003o0oooool;o`00o`Wooooo1_l00?l01?oooooo003oo`00ool00?l6ooooo`7o00000Oooool00003
o`000?oooooooooo00Gooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Cooooo1Ol00?l2ooooo`So
003o0_ooool6o`00o`Oooooo1?l00?l?ooooo`Go003o1Oooool5o`00o`;ooooo1Ol00?lNooooo`Go
003o1_ooool5o`00o`?ooooo1ol00?l7ooooo`?o003o0_ooool8o`00o`03ooooool00?oo003o00?o
003o4Oooool3o`00obSooooo0ol00?l4ooooo`Go003o00?oooooo`00ool00?l02_l00?l;ooooo`Wo
003o1Oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`Go003o00?oooooo`00ool00?l0
1?l00?l3ooooo`Go003o00?oooooo`00ool00?l01ol00?l3ooooo`Go003o1_ooool5o`00o`oooooo
1Ol00?l5ooooo`Go003o0_ooool5o`00oakooooo1ol00?l5ooooo`?o003o1_ooool5o`00o`cooooo
2Ol00?l00ooooooo003oo`00o`03o`00o`Gooooo0ol00?lbooooo`Go003o0ooooolAo`00o`[ooooo
2ol00?l5ooooo`7o00000Oooool00003o`000?oooooo003o00;o003o0oooool5o`00o`;ooooo1Ol0
0?l3ooooo`Go003o00?oooooo`00ool00?l01_l00?l5ooooo`?o003o1oooool5o`00o`oooooo1Ol0
0?l5ooooo`Go003o0oooool3o`00ob3ooooo1ol00?l>ooooo`?o003o3Oooool9o`00o`;ooooo1Ol0
0?l3ooooo`Go003o4?ooool3o`00oaOooooo0ol00?l2ooooo`So003o0_ooool@o`00o`[ooooo3?l0
0?l5ooooo`7o00000Oooool00003o`000?l00?oo003o00?o003o00?oooooo`00ool00?l00ol00?l3
ooooo`Go003o1?ooool3o`00o`;ooooo1Ol00?lBooooo`Oo003o3_ooool3o`00o`Oooooo0ol00?lB
ooooo`?o003o5?ooool5o`00oaoooooo2?l00?l2ooooo`Go003o0oooool5o`00o`oooooo1Ol00?lE
ooooo`oo003o0_ooool3o`00o`03ooooool00?oo003o00So003o2oooool7o`00o`04ooooool00?oo
003oo`00o`Kooooo0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?l00ooooooo003oo`00o`03
o`00o`Cooooo0ol00?l;ooooo`?o003o5?ooool7o`00obOooooo0ol00?l00ooooooo003oo`00o`03
o`00oa?ooooo1Ol00?lSooooo`?o003o0oooool5o`00o`?ooooo1Ol00?l?ooooo`Go003o5Oooool?
o`00o`Oooooo2?l00?l<ooooo`Go003o3?ooool1o`00007ooooo00000ol0003o003oo`00o`03o`00
o`03ooooool00?oo003o00?o003o8oooool3o`00o`Gooooo1Ol00?lVooooo`[o003o5?ooool3o`00
oa[ooooo0ol00?l>ooooo`Oo003o00Coooooo`00ool00?oo003o4?ooool5o`00o`04ooooool00?oo
003oo`00oa7ooooo3ol00?l:ooooo`Go003o3Oooool3o`00o`gooooo0Ol00001ooooo`0000?o0000
ooooool00?l00_l00?l2ooooo`Co003o8oooool5o`00o`Cooooo1Ol00?l3ooooo`?o003o2Oooool3
o`00oaCooooo2_l00?lJooooo`?o003o4_ooool6o`00o`gooooo2?l00?lCooooo`[o003o4Oooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o2oooool5o`00oagooooo0Ol00001ooooo`0000?o0000oooo
ooooool00oooool5o`00ob7ooooo1ol00?l5ooooo`?o003o0oooool5o`00o`Oooooo1Ol00?l5oooo
o`?o003o2oooool9o`00oa[ooooo1Ol00?l@ooooo`Oo003o3Oooool8o`00oaCooooo0ol00?l00ooo
oooo003oo`00o`03o`00o`kooooo0ol00?lHooooo`Ko003o3Oooool3o`00o`cooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool5o`00o`Gooooo0ol00?lHooooo`So003o2oooool6o`00o`Ko
oooo1Ol00?l4ooooo`Go003o2oooool9o`00oaWooooo1Ol00?l@ooooo`Oo003o3_ooool7o`00oaSo
oooo1Ol00?l=ooooo`Go003o1Oooool3o`00o`cooooo0ol00?l00ooooooo003oo`00o`07o`00o`So
oooo1Ol00?l;ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1Ol00?l4ooooo`Go003o
5oooool9o`00o`[ooooo1ol00?l5ooooo`Go003o1?ooool5o`00o`gooooo2?l00?lHooooo`Go003o
4?ooool6o`00oa3ooooo1Ol00?lJooooo`?o003o3_ooool5o`00o`Cooooo1ol00?l8ooooo`Go003o
00?oooooo`00ool00?l02_l00?l4ooooo`Go003o2oooool1o`00007ooooo00000ol0003ooooooooo
o`04ooooo`?o003o1Oooool5o`00oaOooooo2Ol00?l;ooooo`Ko003o1_ooool3o`00o`Gooooo1Ol0
0?l=ooooo`So003o0oooool3o`00oa?ooooo0ol00?l5ooooo`?o003o2_ooool3o`00oa;ooooo1Ol0
0?lNooooo`?o003o2_ooool5o`00o`Cooooo2?l00?l7ooooo`Go003o00?oooooo`00ool00?l02ol0
0?l3ooooo`Go003o2oooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`Go003o6?ooool8
o`00o`cooooo1Ol00?l5ooooo`?o003o1oooool3o`00o`oooooo1ol00?l2ooooo`Go003o00Cooooo
o`00ool00?oo003o5Oooool5o`00oaoooooo0ol00?l3ooooo`?o003o0oooool3o`00oa;ooooo1Ol0
0?l:ooooo`?o003o1Oooool8o`00o`Oooooo1Ol00?l2ooooo`co003o1?ooool3o`00o`cooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool7o`00oaWooooo0ol00?l01?oooooo003oo`00ool0
0?l<ooooo`Go003o1Oooool5o`00o`Sooooo0ol00?l@ooooo`?o003o0oooool:o`00oaCooooo1Ol0
0?lTooooo`Go003o00?oooooo`00ool00?l00ol00?lAooooo`Go003o4oooool7o`00o`Sooooo0ol0
0?l7ooooo`So003o4oooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`So003o6?ooool5
o`00o`Kooooo0ol00?l6ooooo`Go003o1Oooool5o`00o`Oooooo1Ol00?lEooooo`[o003o5?ooool5
o`00obCooooo1Ol00?l00ooooooo003oo`00o`03o`00o`oooooo1ol00?l?ooooo`?o003o1?ooool3
o`00oaOooooo0ol00?lDooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo2?l00?lHoooo
o`Go003o1Oooool5o`00o`Gooooo1Ol00?l5ooooo`Go003o1oooool7o`00oaCooooo0ol00?l00ooo
oooo003oo`00o`03o`00oaGooooo0ol00?lTooooo`Ko003o00?oooooo`00ool00?l00ol00?l=oooo
o`_o003o3?ooool5o`00o`Sooooo1Ol00?lWooooo`7o00000Oooool00003o`000?oooooooooo00So
oooo1ol00?lIooooo`Go003o1Oooool5o`00o`Kooooo0ol00?l7ooooo`?o003o2?ooool8o`00o`[o
oooo0ol00?l;ooooo`?o003o??ooool6o`00o`?ooooo0ol00?l=ooooo`Oo003o00?oooooo`00ool0
0?l00ol00?l;ooooo`Go003o1oooool7o`00obKooooo0Ol00001ooooo`0000?o0000ooooooooool0
2Oooool3o`00oagooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`Go003o7?ooool7o`00o`Wo
oooo1Ol00?l3ooooo`?o003o9oooool3ool000Cooooo0ooo000Booooo`Go003o5?ooool7o`00o`03
ooooool00?oo003o00?o003o2_ooool6o`00o`Oooooo1ol00?lVooooo`7o00000Oooool00003o`00
0?oooooooooo023ooooo0ol00?l9ooooo`Go003o0_ooool3o`00oakooooo1_l00?l7ooooo`Oo003o
0_ooool5o`00o`Cooooo0ooo000Nooooo`Goo`000_ooool5ool000Wooooo0ol00?l5ooooo`Go003o
5?ooool6o`00o`;ooooo1Ol00?l9ooooo`Ko003o2?ooool7o`00oaCooooo0ol00?l?ooooo`7o0000
0Oooool00003o`000?oooooooooo01oooooo1Ol00?l8ooooo`Go003o7oooool3o`00o`03ooooool0
0?oo003o00?o003o1oooool8o`00o`;ooooo1Ol00?l3ooooo`Goo`007Oooool5ool000;ooooo1Ooo
0008ooooo`Go003o1Oooool3o`00oaKooooo0ol00?l5ooooo`?o003o2?ooool7o`00o`[ooooo1Ol0
0?l:ooooo`?o003o1oooool5o`00o`kooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool3
o`00o`cooooo1Ol00?l8ooooo`Go003o6_ooool3o`00o`03ooooool00?oo003o00?o003o00Cooooo
o`00ool00?oo003o0_ooool3o`00o`?ooooo1ol00?l3ooooo`Go003o0oooool5ool001gooooo1Ooo
0002ooooo`Goo`002?ooool5o`00o`oooooo0ol00?l<ooooo`?o003o1?ooool3o`00o`Sooooo2?l0
0?l9ooooo`?o003o3?ooool6o`00o`Gooooo1Ol00?l>ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo1Ol00?l;ooooo`Go003o2Oooool3o`00oa[ooooo2_l00?l5ooooo`co003o1_ooool3
o`00o`Cooooo1Ooo000Mooooo`Goo`000oooool3ool000Sooooo00?oo`00o`00ool00?l00ol00?l>
ooooo`Go003o2_ooool5o`00o`;ooooo1Ol00?l7ooooo`Oo003o2Oooool5o`00o`_ooooo1ol00?l4
ooooo`Go003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Go003o3?ooool3o`00
obOooooo2_l00?l3oooooa3o003o0oooool7ool000;ooooo1_oo000;ooooo`?oo`0000Coooooool0
0?oo003oo`000_ooool3ool000Cooooo1Ooo000=ooooo`?oo`000ol00?l7ooooo`?o003o1Oooool5
o`00o`[ooooo1Ol00?l2ooooo`Go003o1oooool5o`00o`;ooooo0ol00?l6ooooo`Go003o2oooool7
o`00o`Gooooo0ol00?l?ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo1_l00?leoooo
o`Go003o00Goooooo`00ool00?oo003oooooo`0>o`00o`03ooooool00?oo003o00?o003o0_ooool8
ool000?ooooo1Ooo0009oooooa3oo`0000?oooooool00?oo00001?oo000<ooooo`Goo`001Oooool2
ool000Go003o1?ooool5o`00o`Sooooo1ol00?l2ooooo`Go003o2?ooool3o`00o`;ooooo1Ol00?l5
ooooo`Go003o1_ooool5o`00o`03ooooool00?oo003o00Co003o5oooool1o`00007ooooo00000ol0
003oooooooooo`0@ooooo`Wo003o8?ooool5o`00o`?ooooo0ol00?l7ooooo`?o003o1Oooool?o`00
o`03ooooool00?oo003o00?o003o0_ooool9ool000;ooooo1ooo0007oooooa7oo`0000?oooooool0
0?oo00001?oo000;ooooo`Goo`001?ooool3ool000Go003o1Oooool3o`00o`Sooooo1ol00?l4oooo
o`?o003o3_ooool5o`00o`Kooooo0ol00?l3ooooo`[o003o0_ooool3o`00oaSooooo0Ol00001oooo
o`0000?o0000ooooooooool04Oooool9o`00oakooooo1ol00?l00ooooooo003oo`00o`03o`00o`ko
oooo3_l00?l2ooooo`Go003o0_oooolCool000Kooooo4Ooo0002ooooo`Soo`002?ooool4ool000Go
oooo0ooo0005o`00o`03ool00?oooooooooo00[ooooo2?l00?lGooooo`Go003o2oooool;o`00oago
oooo0Ol00001ooooo`0000?o0000ooooooooool04Oooool9o`00oakooooo1ol00?l00ooooooo003o
o`00o`03o`00o`04ooooool00?oo003oo`00o`?ooooo0ol00?l4ooooo`Oo003o00?oooooo`00ool0
0?l00ol00?l4ooooo`?o003o0ooooolCool000Oooooo4?oo0002ooooo`Woo`001_ooool5ool000Go
oooo1?oo0003o`00o`;oo`002oooool9o`00oaOooooo1Ol00?l;ooooo`_o003o7Oooool1o`00007o
oooo00000ol0003oooooooooo`0Booooo`So003o5_ooool3o`00o`Gooooo1ol00?l00ooooooo003o
o`00o`08o`00o`03ooooool00?oo003o00?o003o1?ooool3o`00o`Cooooo1Ol00?l;ooooo`?oo`00
00?oooooool00?oo00003Ooo0003ooooo`?oo`000oooool<ool000Cooooo2?oo0004ooooo`Ooo`00
1?ooool:ool000_ooooo2?l00?lHooooo`Go003o1oooool>o`00oakooooo0Ol00001ooooo`0000?o
0000ooooooooool01_ooool3o`00o`gooooo0ol00?lAooooo`?o003o0_ooool5o`00o`Gooooo1Ol0
0?l3ooooo`?o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`03o`00o`?ooooo0ol0
0?l6ooooo`?o003o1oooool3ool000Oooooo3_oo00000oooooooo`00ool0000;ool00003oooooooo
003oo`0000?oo`002?ooool5ool000?ooooo2?oo0003ooooo`[oo`001?ooool3ool000?o003o0_oo
ool5o`00oacooooo1_l00?l4ooooo`Wo003o8?ooool3o`00o`7ooooo0Ol00001ooooo`0000?o0000
ooooooooool01Oooool5o`00oaoooooo1Ol00?l00ooooooo003oo`00o`03o`00oa7ooooo1Ol00?l0
0ooooooo003oo`00o`0;o`00o`cooooo1_oo000:oooooaOoo`000_ooool5ool000Wooooo0ooo0004
ooooo`Ooo`001?ooool8ool000Gooooo0ooo0005o`00o`;ooooo0ol00?lMooooo`Oo003o0oooool7
o`00o`_ooooo0ol00?lCooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00
oa7ooooo0ol00?l;ooooo`Go003o00?oooooo`00ool00?l00ol00?lBooooo`Co003o00?oooooo`00
ool00?l03?l00?l:ooooo`Ooo`003_ooool5ool00003oooooooo003oo`0000Woo`001?ooool5ool0
013ooooo2?oo0002ooooo`Woo`001Oooool3ool000Ko003o8Oooool7o`00o`?ooooo1ol00?l:oooo
o`Go003o4?ooool7o`00o`7o00000Oooool00003o`000?oooooooooo00Gooooo1Ol00?l@ooooo`Go
003o2_ooool:o`00oa?ooooo4ol00?l:ooooo`Ooo`005?ooool;ool000Gooooo0ooo0003ooooo`?o
o`003?oooolAool00004oooooooo003oo`00ool000;ooooo0ooo0007o`00ob7ooooo1_l00?l4oooo
o`Go003o2oooool6o`00o`kooooo2?l00?l1o`00007ooooo00000ol0003oooooooooo`06ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l7ooooo`Go003o2oooool3o`00o`03ooooool00?oo003o00?o
003o1?ooool5o`00o`[ooooo4ol00?l:ooooo`Koo`005_ooool9ool000Gooooo1Ooo00000ooooooo
o`00ool00003ool000gooooo3?oo0003ooooo`Goo`0000?oooooool00?oo00000_oo0006o`00ob?o
oooo0ol00?l01?oooooo003oo`00ool00?lAooooo`Ko003o0oooool3o`00o`Sooooo1ol00?l1oooo
o`7o00000Oooool00003o`000?oooooooooo00[ooooo2_l00?l6ooooo`Go003o3oooool6o`00o`;o
oooo2Ol00?l7ooooo`Wo003o00Coooooo`00ool00?oo003o0_ooool3o`00o`cooooo1_oo000Aoooo
o`?oo`000_ooool8ool000Gooooo1Ooo00000oooooooo`00ool00003ool000kooooo2ooo0003oooo
o`Goo`000_ooool4ool000Go003o00?oo`00ooooooooool08oooool5o`00oa7ooooo1Ol00?l2oooo
o`Go003o1oooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool:o`00o`Oo
oooo0ol00?lAooooo`Ko003o00?oooooo`00ool00?l02?l00?l5ooooo`Go003o00Coooooo`00ool0
0?oo003o3_ooool3ool000Oooooo1Ooo000?ooooo`Goo`0000?oooooool00?oo00001Ooo0006oooo
o`_oo`003_ooool;ool000?ooooo1Ooo0003ooooo`Coo`000ol00?l3ool002Cooooo1Ol00?lBoooo
o`?o003o0oooool5o`00o`Sooooo0ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00[o
oooo2_l00?lLooooo`Go003o00?oooooo`00ool00?l02_l00?l3ooooo`Go003o4Oooool5ool000Ko
oooo1Ooo000?ooooo`Goo`000_ooool3ool000Sooooo2ooo000@ooooo`[oo`001?ooool4ool000Co
oooo2_oo000:ooooo`?o003o0_ooool3o`00oa7ooooo1Ol00?l@ooooo`?o003o1Oooool5o`00o`oo
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool3o`00o`;ooooo0ol00?lCooooo`?o003o
1oooool5o`00o`;ooooo3?l00?l2ooooo`Go003o4Oooool5ool000Kooooo1_oo0002ooooo`?oo`00
2Oooool5ool000cooooo1Ooo00000oooooooo`00ool00003ool001Kooooo1Ooo0004ooooo`Ooo`00
1Oooool7ool000;ooooo0ol00?l00ooooooo003oo`00o`0:o`00oa7ooooo0ol00?l6ooooo`?o003o
1oooool5o`00o`Gooooo0ol00?l01?oooooo003oo`00ool00?l<ooooo`7o00000Oooool00003o`00
0?oooooooooo02Gooooo1Ol00?l7ooooo`?o003o2?ooool7o`00o`?ooooo1_l00?l?ooooo`Goo`00
1?ooool>ool000Wooooo0ooo000=ooooo`Goo`0000?oooooool00?oo00000ooo000Gooooo`?oo`00
1Oooool8ool000Gooooo1_oo00000ooooooo003oo`00o`0Ao`00oaOooooo1Ol00?l6ooooo`Go003o
2?ooool5o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool00ol00?lRooooo`Go003o5?oo
ool5o`00o`?ooooo1ol00?l?ooooo`Goo`000_ooool?ool000cooooo0ooo00001?ooooooo`00ool0
0?oo0006ooooo`Goo`000_ooool3ool000;ooooo0ooo0003ooooo`?oo`005Oooool8ool000Cooooo
1ooo00000ooooooo003oo`00o`0Bo`00oaKooooo1Ol00?l6ooooo`Go003o2?ooool5o`00o`_ooooo
0Ol00001ooooo`0000?o0000ooooool00?l01?l00?lQooooo`Go003o2Oooool3o`00o`Oooooo1Ol0
0?l4ooooo`Oo003o1Oooool6ool00005oooooooo003oo`00ool00?ooool01Ooo00000oooooooo`00
ool0000=ool000_ooooo2ooo0004ooooo`?oo`001oooool5ool00003oooooooo003oo`0000?oo`00
1?ooool3ool000kooooo1ooo0004ooooo`Koo`000_ooool;o`00o`;ooooo1ol00?lFooooo`Go003o
1oooool3o`00o`Wooooo1Ol00?l;ooooo`7o00000Oooool00003o`000?oooooo003o00Co003o8Ooo
ool4o`00o`Wooooo1Ol00?l5ooooo`Go003o1_ooool6o`00o`Cooooo8Ooo0008ooooo`ooo`003?oo
ool6ool00003oooooooo003oo`0000Coo`000_ooool5ool000Wooooo0ooo0004ooooo`?oo`001Ooo
ool6ool000?ooooo0ol00?l01?oooooo003oo`00ool00?l7ooooo`Go003o5oooool3o`00oaGooooo
0ol00?l3ooooo`?o003o1_ooool1o`00007ooooo00000ol0003oooooo`00o`04o`00oa3ooooo0ol0
0?l=ooooo`Go003o1oooool7o`00o`Gooooo1Ol00?l4ooooo`Oo003o1OoooolFool00003oooooooo
003oo`0000Soo`001oooool@ool000_ooooo1ooo00000oooooooo`00ool00005ool00003oooooooo
003oo`0000Koo`000_ooool;ool000Wooooo1Ooo0008ooooo`?o003o1oooool3o`00o`04ooooool0
0?oo003oo`00obCooooo0ol00?l:ooooo`Go003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`03o`00oa3ooooo1Ol00?l;ooooo`Ko003o1_ooool8o`00o`Gooooo1Ol00?l3ooooo`Oo003o00Co
o`00oooooooooooooooo5_oo0003ooooo`[oo`0000Coooooool00?oo003oo`000oooool@ool000[o
oooo2?oo0002ooooo`Koo`0000?oooooool00?oo00005?oo0008ooooo`Goo`001oooool5o`00o`Wo
oooo1Ol00?lRooooo`Go003o2Oooool5o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
4oooool5o`00o`[ooooo1ol00?l6ooooo`Oo003o1oooool3o`00o`Cooooo1_l00?l2ool000;ooooo
6?oo0002ooooo`Woo`0000?oooooool00?oo00000ooo0002ooooo`ooo`000oooool3ool000Cooooo
2?oo0004oooooacoo`001oooool8ool000Gooooo1ol00?l7ooooo`Go003o8_ooool5o`00o`Wooooo
1Ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo1ol00?l8ooooo`Ko003o1ooo
ool5o`00oa3ooooo1_l00?l2ool000;ooooo3?oo00000oooooooo`00ool00009ool000;ooooo2Ooo
00000oooooooo`00ool00003ool000?ooooo0ooo0002ooooo`Soo`000oooool5ool000;ooooo1ooo
0007ooooo`Ooo`000_oooolBool00004oooooooo003oo`00ool000;ooooo2_oo0004ooooo`So003o
1_ooool5o`00o`Cooooo0ol00?lKooooo`Go003o2?ooool6o`00o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool05?ooool7o`00o`Kooooo1ol00?l8ooooo`?o003o4_ooool4o`00o`?oo`000_oo
ool<ool00003oooooooo003oo`0000Woo`000oooool8ool00003oooooooo003oo`0000?oo`002?oo
ool8ool00003oooooooo003oo`0000Goo`000_ooool6ool000Oooooo2?oo0003ooooo`[oo`000ooo
ool3ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00002?oo0005ooooo`Oo003o1ooo
ool4o`00o`?ooooo1Ol00?lBooooo`?o003o1_ooool3o`00o`Wooooo1Ol00?l6ooooo`7o00000Ooo
ool00003o`000?oooooo003o00;o003o5?ooool5o`00o`Gooooo2?l00?lPooooo`Goo`000_oooolF
ool000Oooooo1Ooo0002ooooo`?oo`002_ooool6ool00003oooooooo003oo`0000Koo`000_ooool5
ool000Sooooo2?oo0006ooooo`Soo`001_ooool@ool000Oooooo1Ol00?l7ooooo`Go003o0_ooool5
o`00oa7ooooo1Ol00?lAooooo`Go003o1_ooool1o`00007ooooo00000ol0003o003oo`00o`03o`00
oa?ooooo1Ol00?l5ooooo`So003o1_ooool4o`00oaKooooo1Ooo0002oooooaGoo`002Oooool3ool0
01Oooooo1ooo0004ooooo`?oo`002Oooool9ool000Gooooo2?oo0006ooooo`[oo`000_ooool5ool0
00;ooooo1Ooo0003o`00o`Sooooo1Ol00?l2ooooo`Go003o4Oooool5o`00oa;ooooo0ol00?l7oooo
o`7o00000Oooool00003o`000?l00?oo003o00?o003o5?ooool3o`00o`Kooooo1ol00?l6ooooo`Ko
003o5Oooool5ool000;ooooo1ooo0003ooooo`_oo`002_ooool4ool001Gooooo1Ooo0007ooooo`Co
o`002?ooool8ool000Gooooo2?oo0006ooooo`Woo`000_ooool>ool000[ooooo1Ol00?l3ooooo`?o
003o2Oooool3o`00o`Kooooo1Ol00?l:ooooo`?o003o3oooool1o`00007ooooo00000ol0003o003o
o`00o`03o`00oakooooo1Ol00?l7ooooo`Ko003o5?ooool5ool000Cooooo1_oo0003ooooo`[oo`00
2_ooool6ool001Gooooo0ooo0007ooooo`Koo`002_ooool5ool000Gooooo1ooo0007ooooo`Woo`00
00?oooooool00?oo00003Ooo0007ooooo`So003o0_ooool3o`00o`Wooooo1Ol00?l6ooooo`?o003o
2_ooool5o`00o`kooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l00?lPooooo`?o003o2?oo
ool6o`00oa7ooooo2Ooo0005ooooo`Koo`000_ooool3ool00004oooooooo003oo`00ool000cooooo
1_oo000:ooooo`?oo`001?ooool5ool000Wooooo1ooo000:ooooo`?oo`001?ooool7ool000Wooooo
2?oo0002ooooo`ooo`001Oooool@o`00o`Sooooo1Ol00?l>ooooo`?o003o0_ooool5o`00o`;ooooo
0ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo01;ooooo0ol00?lIooooo`Co003o0_oo
ool3o`00o`cooooo2_oo0005ooooo`Ooo`002?ooool3ool000;ooooo0ooo0004ooooo`Koo`002Ooo
ool5ool000;ooooo1ooo0008ooooo`Ooo`003Oooool:ool000[ooooo1ooo0003ooooo`koo`001Ooo
oolAo`00o`Sooooo1Ol00?l=ooooo`Go003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00
o`03o`00o`Sooooo0Ol00001ooooo`0000Co0000oooooooooooooooo0ol00?l6ooooo`?o003o1?oo
ool5o`00oagooooo1Ol00?l;ooooo`[oo`000_ooool:ool000Oooooo2_oo0004ooooo`Goo`002Ooo
ool5ool000;ooooo1ooo0002ooooo`?oo`001?ooool6ool000Kooooo0ooo0003ooooo`Woo`003Ooo
ool7ool000?ooooo1?oo00000oooooooo`00ool00005ool000Kooooo4Ol00?l2ooooo`?o003o1?oo
ool3o`00o`kooooo1Ol00?l2ooooo`?o003o0_ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01Ol00?l4ooooo`Go003o0oooool5o`00oagooooo1Ol00?l;ooooo`Goo`0000Cooooo
ool00?oo003oo`000_ooool;ool000Oooooo2_oo0005ooooo`Goo`002?ooool5ool000;ooooo1ooo
00000oooooooo`00ool00003ool000Gooooo0ooo0002ooooo`?oo`0000?oooooool00?oo00000ooo
0002ooooo`Woo`003oooool5ool000Sooooo1_oo0007ooooo`Oo003o00Coooooo`00ool00?oo003o
0_ooool3o`00o`;ooooo1ol00?l9ooooo`?o003o1_ooool5o`00o`Oooooo1Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00Go003o1?ooool5o`00o`?ooooo1Ol00?lMooooo`Go003o3?oo
ool3ool000Oooooo1Ooo0002ooooo`?oo`002?ooool:ool000Gooooo1Ooo0009ooooo`Goo`000_oo
ool5ool000;ooooo1ooo0002ooooo`?oo`000_ooool:ool000;ooooo2?oo000?ooooo`Koo`002Ooo
ool3ool000Kooooo0ooo00001?oooooo003oo`00ool00?l>ooooo`So003o1oooool5o`00o`Kooooo
0ol00?l9ooooo`?o003o2Oooool1o`00007ooooo00000ol0003oooooooooo`05o`00o`Cooooo1Ol0
0?l4ooooo`?o003o00Coooooo`00ool00?oo003o3Oooool3o`00o`?ooooo0ol00?l5ooooo`?o003o
0oooool3o`00oa7ooooo1Ooo00000oooooooo`00ool00003ool000Cooooo1ooo0002ooooo`?oo`00
1_ooool5ool000[ooooo1Ooo0008ooooo`goo`0000?oooooool00?oo00002?oo0002ooooo`Goo`00
4_ooool5ool001;ooooo1Ooo00001?ooooooo`00ool00?oo000=ooooo`So003o1_ooool6o`00oa[o
oooo0ol00?l1ooooo`7o00000Oooool00004o`000?ooooooooooooooo`Go003o1?ooool3o`00o`So
oooo1Ol00?l;ooooo`Go003o00?oooooo`00ool00?l00ol00?l9ooooo`Go003o0ooo0008ooooo`?o
o`000oooool3ool000;ooooo1Ooo0003ooooo`Koo`002oooool6ool000_ooooo1Ooo0007ooooo`ko
o`0000?oooooool00?oo00000ooo00001?ooooooo`00ool00?oo0003ooooo`Goo`004_ooool5ool0
01;ooooo2_oo000=ooooo`Oo003o1Oooool7o`00o`kooooo0ol00?l8ooooo`Go003o0Ol00001oooo
o`0000?o0000ooooooooool00_ooool5o`00o`Sooooo0ol00?l3ooooo`Go003o2oooool5o`00o`03
ooooool00?oo003o00?o003o2Oooool5o`00o`Coo`001_ooool5ool000Oooooo1Ooo0003ooooo`Oo
o`002Oooool7ool000_ooooo1Ooo0006ooooo`ooo`000_ooool3ool000Wooooo0ooo000=ooooo`?o
o`001?ooool3ool000;ooooo0ooo000>ooooo`[oo`002oooool3o`00o`03ooooool00?oo003o00?o
003o1Oooool6o`00o`kooooo1Ol00?l7ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool0
0_ooool5o`00o`Oooooo1Ol00?l2ooooo`Go003o2oooool5o`00o`03ooooool00?oo003o00?o003o
2Oooool5o`00o`Coo`001_ooool5ool000Cooooo2_oo00000oooooooo`00ool00005ool000Wooooo
2?oo0006ooooo`Soo`001oooool5ool00003oooooooo003oo`0000;oo`0000Coooooool00?oo003o
o`001Oooool4ool000kooooo0ooo0004ooooo`Goo`001oooool5ool000Gooooo0ooo0006ooooo`?o
o`0000?oooooool00?oo00000ooo0002ooooo`?o003o1Oooool:o`00o`Gooooo2?l00?l<ooooo`Go
003o1oooool5o`00o`7o00000Oooool00003o`000?oooooooooo00;ooooo1Ol00?l7ooooo`Go003o
0oooool3o`00o`gooooo0ol00?l3ooooo`?o003o2_ooool01?oo003o003oo`00ool00?l5ool000;o
oooo2Ooo0003oooooa?oo`000_ooool3ool000Cooooo2?oo0005ooooo`Ooo`002Oooool5ool00003
oooooooo003oo`0000?oo`001oooool6ool000cooooo1Ooo0003ooooo`Ooo`001?ooool6ool000Co
oooo1_oo0006ooooo`Koo`000_ooool5o`00o`Cooooo2_l00?l6ooooo`So003o2oooool5o`00o`So
oooo0ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo0ol00?l8ooooo`Go003o
9_ooool8ool000;ooooo2Ooo0004oooooa;oo`000_ooool5ool000Cooooo1ooo0005ooooo`Ooo`00
2_ooool3ool000;ooooo1_oo0006ooooo`Koo`000oooool3ool000Kooooo4?oo0003ooooo`Koo`00
1?ooool7ool000Cooooo2Ooo0005o`00o`Cooooo2_l00?l9ooooo`Go003o3?ooool5o`00o`_ooooo
0Ol00001ooooo`0000?o0000ooooooooool00ol00?l5ooooo`?o003o1?ooool3o`00oaOooooo0ol0
0?l6ooooo`?o003o1?ooool6ool000Cooooo2Ooo0004ooooo`Goo`000_ooool;ool000;ooooo1Ooo
0004ooooo`Koo`001_ooool7ool000Oooooo0ooo0005ooooo`Ooo`001?ooool7ool000;ooooo1Ooo
0005oooooa3oo`0000?oooooool00?oo00001Ooo0005ooooo`Ooo`000_ooool;ool000Go003o1Ooo
ool3o`00o`;ooooo0ol00?l:ooooo`Go003o3?ooool5o`00o`_ooooo0Ol00001ooooo`0000?o0000
ooooool00?l01?l00?l3ooooo`Go003o7?ooool5o`00o`;ooooo1ol00?l4ooooo`Coo`001Oooool:
ool000Cooooo0ooo0004ooooo`_oo`0000?oooooool00?oo00000ooo0004ooooo`Goo`001oooool6
ool000Oooooo1Ooo0003ooooo`Soo`000_ooool8ool000?ooooo1_oo0005ooooo`Soo`000_ooool<
ool000Kooooo1ooo00000oooooooo`00ool0000;ool000?o003o6Oooool3o`00o`gooooo1Ol00?l;
ooooo`7o00000Oooool00003o`000?oooooo003o00Co003o0oooool5o`00oacooooo1Ol00?l00ooo
oooo003oo`00o`06o`00o`kooooo2Ooo0003ooooo`Goo`001?ooool:ool000;ooooo0ooo0006oooo
o`?oo`002?ooool6ool000Oooooo1Ooo0003ooooo`Soo`0000?oooooool00?oo00001_oo0002oooo
o`Woo`001_ooool6ool000?ooooo0ooo00000oooooooo`00ool00003ool000Wooooo1Ooo00000ooo
ooooo`00ool0000=ool002_ooooo1Ol00?l;ooooo`7o00000Oooool00003o`000?oooooo003o00Co
003o0oooool5o`00oaGooooo0ol00?l4ooooo`Go003o00?oooooo`00ool00?l01ol00?l9ooooo`?o
o`001Oooool6ool000;ooooo4ooo000Aooooo`?oo`000oooool6ool000Kooooo1Ooo0003ooooo`Oo
o`000_ooool7ool000;ooooo2_oo0006ooooo`Goo`0000Coooooool00?oo003oo`001?ooool5ool0
00Sooooo0ooo0003ooooo`Ooo`001Oooool3ool002cooooo1Ol00?l6ooooo`?o003o0_ooool1o`00
007ooooo00000ol0003oooooooooo`03o`00o`Gooooo0ol00?lEooooo`Go003o1?ooool3o`00o`;o
oooo2Ol00?l8ooooo`Goo`001Oooool5ool000;ooooo4ooo0009ooooo`?oo`001?ooool5ool000?o
oooo1Ooo0007ooooo`?oo`001?ooool4ool000Cooooo1_oo0004ooooo`[oo`001oooool3ool00003
oooooooo003oo`0000?oo`000oooool4ool000Sooooo1Ooo0002ooooo`Koo`009?ooool3o`00o`oo
oooo0ol00?l6ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`?o003o
3_ooool6o`00o`[ooooo2?l00?l8ooooo`Ooo`000oooool5ool000?ooooo3?oo0002ooooo`?oo`00
2Oooool=ool000?ooooo1Ooo0007ooooo`?oo`000oooool5ool000Cooooo1Ooo0005ooooo`_oo`00
1?ooool3ool000?ooooo1Ooo0002ooooo`Goo`002?ooool5ool000;ooooo1_oo000Booooo`?o003o
3?ooool7o`00oaOooooo1Ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo1Ol0
0?l=ooooo`Ko003o3_ooool3o`00o`Wooooo2Ooo0002ooooo`Goo`001Oooool8ool000oooooo3ooo
0002ooooo`?oo`001oooool5ool000;ooooo1Ooo0004ooooo`Goo`001_ooool:ool000?ooooo1Ooo
0002ooooo`Goo`000_ooool5ool000?ooooo0ooo0002ooooo`Goo`000oooool5ool000gooooo0ol0
0?l00ooooooo003oo`00o`03o`00o`[ooooo2?l00?lGooooo`Go003o0Oooool1o`00007ooooo0000
0ol0003oooooooooo`0=ooooo`Go003o1_ooool3o`00o`Cooooo1Ol00?lLoooooa3oo`001Oooool7
ool000oooooo4_oo0009ooooo`Goo`000_ooool5ool000?ooooo1Ooo000<ooooo`Goo`000oooool5
ool000?ooooo0ooo0003ooooo`Goo`000_ooool5ool000;ooooo1Ooo0003ooooo`?oo`003Oooool:
o`00o`04ooooool00?oo003oo`00o`Kooooo2_l00?lFooooo`?o003o0_ooool1o`00007ooooo0000
0ol0003oooooooooo`0=ooooo`Go003o1Oooool5o`00o`03ooooool00?oo003o00Co003o6Oooool3
ool000;ooooo3ooo0006ooooo`Koo`004?ooool8ool000;ooooo2?oo0006ooooo`Ooo`000oooool3
ool000Cooooo1Ooo000<ooooo`Goo`000oooool6ool000Sooooo3?oo0002ooooo`Goo`004?ooool3
ool000oo003o1Oooool;o`00o`gooooo0ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo
00kooooo0ol00?l6ooooo`[o003o5Oooool3ool000;ooooo1Ooo0002ooooo`koo`001_ooool5ool0
017ooooo1ooo0003ooooo`Soo`0000Goooooool00?oo003oo`00ooooo`07ool000Kooooo0ooo0002
ooooo`Goo`002?ooool3ool00003oooooooo003oo`0000?oo`001?ooool6ool000Oooooo3?oo0002
ooooo`Goo`003oooool4ool000Wo003o00?oooooo`00ool00?l00ol00?l6ooooo`?o003o0_ooool5
o`00o`cooooo1Ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00?o003o5?ooool:o`00
oaCooooo1Ooo00000oooooooo`00ool00004ool000Cooooo2_oo0008ooooo`?oo`004_ooool5ool0
00Gooooo5?oo0005ooooo`Goo`000_ooool3ool000Sooooo2_oo0005ooooo`Goo`001oooool;ool0
00;ooooo1Ooo000@ooooo`Goo`002?l00?l00ooooooo003oo`00o`03o`00o`Oooooo0ol00?l00ooo
oooo003oo`00o`03o`00o`Cooooo0ol00?l5ooooo`Go003o2Oooool1o`00007ooooo00000ol0003o
ooooo`00o`04o`00o`gooooo0ol00?l4ooooo`?o003o00?oooooo`00ool00?l00ol00?lCooooo`Ko
o`0000?oooooool00?oo00001_oo0005ooooo`?oo`008_ooool3ool000Gooooo2?oo00000ooooooo
o`00ool0000:ool000Gooooo1Ooo00001?ooooooo`00ool00?oo0007ooooo`goo`001?ooool5ool0
00Cooooo0ooo00000oooooooo`00ool0000Aool000kooooo2?oo000:o`00o`Oooooo1Ol00?l01?oo
oooo003oo`00ool00?l4ooooo`Go003o1?ooool5o`00o`;ooooo0ol00?l4ooooo`7o00000Oooool0
0003o`000?oooooo003o00Co003o3?ooool5o`00o`Sooooo0ol00?lDooooo`Koo`000_ooool8ool0
02Wooooo0ooo0005ooooo`koo`0000?oooooool00?oo00001?oo0005ooooo`[oo`001OoooolGool0
00?ooooo1Ooo0003oooooa7oo`003Oooool8ool00003ooooool00?oo003o00Oo003o0oooool3o`00
o`03ooooool00?oo003o00?o003o2?ooool5o`00o`05ooooool00?oo003oo`00ooooool00ol00?l2
ooooo`Go003o0oooool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`cooooo1Ol00?lOoooo
o`Goo`000_ooool9ool002Sooooo1Ooo00000oooooooo`00ool0000>ool000;ooooo1Ooo0006oooo
o`[oo`001OoooolOool000Cooooo4?oo000=ooooo`Soo`0000?oooooo`00ool00?l01ol00?l2oooo
o`[o003o0oooool3o`00o`;ooooo2_l00?l5ooooo`Go003o0oooool1o`00007ooooo00000ol0003o
ooooo`00o`04o`00o`cooooo1Ol00?l8ooooo`?o003o1oooool3o`00o`_ooooo0ooo0003ooooo`Wo
o`001Oooool3ool000cooooo0ooo00001?ooooooo`00ool00?oo0005ooooo`?oo`001Oooool@ool0
0003oooooooo003oo`0000?oo`000_ooool5ool000Kooooo2ooo0004oooooaooo`000ooooolAool0
00gooooo2?oo0002ooooo`So003o0_ooool5o`00o`04ooooool00?oo003oo`00o`?ooooo1Ol00?l2
ooooo`?o003o00?oooooo`00ool00?l00ol00?l5ooooo`Go003o0oooool1o`00007ooooo00000ol0
003oooooooooo`03o`00o`kooooo0ol00?l8ooooo`Go003o1Oooool5o`00oa3ooooo2?oo0003oooo
o`Ooo`002_ooool9ool000?ooooo1Ooo00000oooooooo`00ool0000;ool00003oooooooo003oo`00
00Coo`0000Coooooool00?oo003oo`000oooool5ool000Kooooo3?oo0004ooooo`?oo`000_ooool?
ool00003oooooooo003oo`0000Koo`000oooool5ool000?ooooo2Ooo000>ooooo`Woo`001Oooool3
o`00o`?ooooo1Ol00?l7ooooo`Go003o1_ooool5o`00o`Kooooo0ol00?l4ooooo`7o00000Oooool0
0003o`000?oooooooooo017ooooo0ol00?l8ooooo`Go003o1Oooool5o`00oa7ooooo0ooo0006oooo
o`Soo`002Oooool:ool000?ooooo3Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`00
00Goo`001oooool3ool000Sooooo2ooo000;ooooo`Goo`0000Coooooool00?oo003oo`001Oooool5
ool000Kooooo1Ooo0004ooooo`Goo`004?ooool:ool000cooooo0ol00?l8ooooo`Go003o1oooool5
o`00o`cooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool3o`00o`Wooooo1Ol00?l7oooo
o`Go003o1Oooool5o`00oaWooooo2Ooo0008ooooo`_oo`000oooool:ool000Cooooo1Ooo00000ooo
ooooo`00ool00005ool000[ooooo0ooo0007ooooo`Woo`002oooool5ool000[ooooo1Ooo0005oooo
o`Goo`001?ooool5ool0013ooooo3?oo000Fooooo`?o003o2Oooool5o`00o`_ooooo0Ol00001oooo
o`0000Co0000o`00ool00?oo003o0_ooool5o`00o`Sooooo1Ol00?l8ooooo`?o003o1_ooool5o`00
oaSooooo2Ooo0009ooooo`[oo`001?ooool:ool000Cooooo3Ooo0009ooooo`Goo`001_ooool8ool0
00_ooooo1_oo00001?ooooooo`00ool00?oo0007ooooo`Goo`000_ooool7ool000Cooooo1Ooo0005
ooooo`?oo`000oooool3ool000;ooooo1Ooo00000oooooooo`00ool00005ool0027ooooo1Ol00?l;
ooooo`7o00000Oooool000Go003o00?oooooo`00ool00?l00ol00?l8ooooo`Go003o4_ooool5o`00
oaOooooo1_oo00001?ooooooo`00ool00?oo0005ooooo`[oo`001oooool9ool000Gooooo3_oo0008
ooooo`Goo`001oooool7ool000_ooooo1Ooo00000oooooooo`00ool00003ool000Kooooo1Ooo0000
0oooooooo`00ool00009ool00003oooooooo003oo`0000?oo`001?ooool5ool00003oooooooo003o
o`0000?oo`000_ooool3ool000Cooooo0ooo0003o`00o`[ooooo0ol00?lCooooo`Go003o2oooool1
o`00007ooooo0005o`00o`03ooooool00?oo003o00?o003o2Oooool5o`00o`Kooooo0ol00?l9oooo
o`Go003o4?ooool3ool000?ooooo1Ooo00000oooooooo`00ool00003ool000?ooooo2_oo0008oooo
o`Koo`002Oooool>ool000Oooooo1Ooo0007ooooo`Ooo`002oooool;ool000Kooooo1Ooo00000ooo
ooooo`00ool0000:ool00004oooooooo003oo`00ool000Gooooo1Ooo00000oooooooo`00ool00003
ool000Wooooo0_oo0006o`00o`Oooooo1Ol00?l:ooooo`?o003o1_ooool5o`00o`[ooooo0Ol00001
ooooo`001Ol00?l2ooooo`?o003o2oooool5o`00o`Cooooo1Ol00?l8ooooo`Go003o00Coooooool0
0?oo003oo`002oooool5ool000?ooooo0ooo0002ooooo`Goo`000oooool5ool000_ooooo2?oo000<
ooooo`_oo`002?ooool3ool000Wooooo1_oo000;ooooo`_oo`001ooooolAool000Wooooo1Ooo0000
0oooooooo`00ool00003ool000Kooooo0ooo00000oooooooo`00o`00o`06o`00o`Kooooo1Ol00?l9
ooooo`Go003o1Oooool5o`00o`[ooooo0Ol00001ooooo`0000Co0000o`00ool00?oo003o4Oooool5
o`00o`Cooooo1Ol00?l8ooooo`Go003o1Ooo000:ooooo`Goo`001oooool6ool000?ooooo1Ooo000:
ooooo`Soo`003Oooool;ool001Kooooo0ooo00001?ooooooo`00ool00?oo0008ooooo`Koo`0000?o
ooooool00?oo00000ooo0008ooooo`Ooo`0000?oooooool00?oo00001Ooo0002ooooo`?oo`001Ooo
ool3ool000?ooooo0ooo0006ooooo`Koo`001ol00?l6ooooo`Go003o2Oooool5o`00o`Gooooo1Ol0
0?l:ooooo`7o00000Oooool00003o`000?oooooooooo01;ooooo1Ol00?l4ooooo`Go003o1_ooool6
o`00o`03oooooooo003oo`0000?oo`002_ooool5ool000Oooooo1_oo0004ooooo`?oo`002Oooool8
ool000oooooo2_oo000Gooooo`?o003o2?oo0005ooooo`Coo`000_ooool5ool000Sooooo1Ooo0004
ooooo`Goo`000_ooool5ool001?ooooo1ooo0006o`00o`Oooooo0ol00?l:ooooo`Go003o0_ooool3
o`00o`04ooooool00?oo003oo`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool3
o`00o`Kooooo0ol00?l6ooooo`Go003o0oooool5ool000[ooooo1Ooo0007ooooo`Goo`002?ooool5
ool000?ooooo2Ooo000>ooooo`Ooo`006_ooool5o`00o`Soo`001_ooool3ool00003oooooooo003o
o`0000?oo`000_ooool3ool000?ooooo1Ooo000;ooooo`Goo`002oooool3ool000Gooooo2Ooo0003
o`00o`;ooooo0ol00?lAooooo`?o003o0_ooool5o`00o`kooooo0Ol00001ooooo`0000?o0000oooo
ool00?l00_l00?lEooooo`?o003o2oooool5o`00o`Cooooo0ooo0002ooooo`?oo`001_ooool5ool0
00Kooooo1Ooo0008ooooo`Ooo`000_ooool8ool00004oooooooo003oo`00ool000[ooooo1Ooo0008
ooooo`?o003o3Oooool3o`00o`;ooooo1Ol00?l8ool000Cooooo1_oo00001?ooooooo`00ool00?oo
0002ooooo`Goo`000_ooool5ool000Gooooo0ooo0003ooooo`Goo`001oooool8ool00005oooooooo
003oo`00ool00?ooool02_oo0002ooooo`Go003o5Oooool5o`00o`kooooo0Ol00001ooooo`0000?o
0000o`00ool00?l00ol00?lCooooo`Go003o1Oooool3o`00o`;ooooo1Ol00?l8ooooo`Goo`001Ooo
ool5ool000Gooooo1Ooo0006ooooo`[oo`000_ooool5ool000?ooooo1Ooo0009ooooo`Goo`001ooo
ool5o`00o`_ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Soo`000oooool7ool000Kooooo1Ooo
0002ooooo`Goo`001?ooool;ool000Oooooo6?oo0002ooooo`Go003o5Oooool7o`00o`Kooooo0ol0
0?l3ooooo`7o00000Oooool00003o`000?l00?oo003o00Co003o1?ooool3o`00o`_ooooo1Ol00?l4
ooooo`Go003o0_ooool3o`00o`Wooooo1Ooo0003ooooo`Ooo`000oooool7ool000;ooooo3_oo0003
ooooo`?oo`001?ooool8ool000Kooooo1Ooo0007ooooo`Go003o2oooool5o`00o`;ooooo0ol00?l5
ooooo`?oo`001?ooool7ool000Kooooo1Ooo0002oooooa?oo`002?oooolHool000;ooooo1Ol00?lF
ooooo`Oo003o1?ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000o`00ool00?l01Ol00?l2oooo
o`Go003o2_ooool5o`00o`Cooooo1Ol00?l6ooooo`?o003o1Oooool5ool000;ooooo2?oo0002oooo
oaOoo`002?ooool<ool000Cooooo1Ooo0005ooooo`So003o2oooool5o`00oa7ooooo1_oo00001?oo
ooooo`00ool00?oo0004ooooo`?oo`001?oooolBool000Oooooo2Ooo00000oooooooo`00ool00003
ool00005oooooooo003oo`00ool00?ooool01Ooo0003ooooo`?o003o6Oooool5o`00o`Cooooo1Ol0
0?l2ooooo`7o00000Oooool00003o`000?oooooo003o00Go003o0_ooool5o`00o`_ooooo0ol00?l5
ooooo`Go003o1Oooool5o`00o`Gooooo1Ooo00000oooooooo`00ool00005ool000?ooooo5?oo000:
ooooo`goo`000oooool5ool000Gooooo2?l00?l=ooooo`?o003o2?ooool3o`00o`Sooooo0ooo0002
ooooo`Goo`002ooooolAool000;ooooo0ooo0002ooooo`Goo`001_ooool6ool000?ooooo1Ooo000O
ooooo`Go003o1?ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l2oooo
o`Go003o4Oooool6o`00o`Kooooo1Ol00?l5ooooo`Goo`0000?oooooool00?oo00000ooo0005oooo
oaCoo`002_ooool6ool000;ooooo3Ooo0005ooooo`So003o4?ooool3o`00o`Cooooo1Ol00?l<oooo
o`Koo`002_ooool@ool000;ooooo1Ooo00000oooooooo`00ool00003ool000Sooooo1Ooo0003oooo
o`?oo`007Oooool8o`00o`Cooooo1Ol00?l2ooooo`7o00000Oooool00004o`000?oooooooooooooo
o`?o003o1?ooool3o`00o`cooooo0ol00?l2ooooo`Go003o2?ooool5o`00o`Gooooo1Ooo0002oooo
o`?oo`001oooool3ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00000ooo000:oooo
o`Ooo`000_ooool<ool000Gooooo1ol00?l@ooooo`Go003o0oooool5o`00o`cooooo1_oo0006oooo
o`?oo`000_ooool@ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00000ooo0007oooo
o`Goo`008_ooool9o`00o`Cooooo1Ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00[o
oooo0ol00?l9ooooo`Go003o00?oooooo`00ool00?l00ol00?l9ooooo`?o003o0_oo0003ooooo`Go
o`001_ooool3ool000Wooooo2?oo00000oooooooo`00ool00003ool000_ooooo1_oo0005ooooo`So
o`001oooool3o`00oa?ooooo1ol00?l00ooooooo003oo`00o`03o`00o`gooooo1ooo0003ooooo`Go
o`000_ooool?ool00003oooooooo003oo`0000Coo`000_ooool5ool000Kooooo1ooo000Jooooo`?o
003o0oooool8o`00o`Gooooo1Ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo
1Ol00?l8ooooo`ko003o00Coooooo`00ool00?oo003o0oooool5ool00003oooooooo003oo`0000?o
o`000_ooool3ool00003oooooooo003oo`0000?oo`002oooool5ool00003oooooooo003oo`0000?o
o`003?ooool8ool000;ooooo1Ooo000Nooooo`[o003o00Coooooo`00ool00?oo003o2Oooool3ool0
00?ooooo1ooo0002ooooo`Goo`000_ooool?ool000;ooooo1_oo00000oooooooo`00ool00003ool0
00Oooooo1ooo0006ooooo`?o003o3oooool5o`00o`;ooooo1Ol00?l9ooooo`?o003o0oooool1o`00
007ooooo00000ol0003oooooooooo`04ooooo`?o003o00?oooooo`00ool00?l01?l00?l8oooooa?o
003o0_ooool5ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00002?oo00001?oooooo
o`00ool00?oo0008ooooo`?oo`000oooool6ool000[ooooo2Ooo0002ooooo`?oo`001Oooool3o`00
oaKooooo2ol00?l<ooooo`Goo`000oooool6ool000;ooooo1Ooo0003ooooo`Goo`0000?oooooool0
0?oo00001Ooo0004ooooo`Goo`0000?oooooool00?oo00000ooo0005ooooo`?oo`0000?oooooool0
0?oo00000ooo0003ooooo`;oo`001Ol00?l9ooooo`?o003o0_ooool5o`00o`?ooooo0ol00?l@oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooo2ol00?l9ooooo`Oo003o0_ooool<o`00o`Co
o`0000?oooooool00?oo00000ooo00000oooooooo`00ool0000=ool000oooooo2?oo0006ooooo`_o
o`001oooool5o`00oaCooooo3?l00?l<ooooo`Goo`000oooool7ool000;ooooo0ooo000;ooooo`Co
o`001_ooool5ool000;ooooo0ooo0005ooooo`[oo`000_ooool3ool000Go003o2?ooool5o`00o`03
ooooool00?oo003o00?o003o5_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`[o003o
2oooool6o`00o`;ooooo3Ol00?l2ool000?ooooo0ooo0002ooooo`Goo`0000Goooooool00?oo003o
o`00ooooo`05ool000Wooooo0ooo0003ooooo`Woo`001_ooool;ool000Kooooo1Ol00?l6ooooo`?o
003o2_ooool<o`00o`gooooo1Ooo0003ooooo`Ooo`0000Coooooool00?oo003oo`003?ooool5ool0
00Gooooo1?oo000;ooooo`Goo`0000Coooooool00?oo003oo`000oooool3ool000Go003o2?ooool5
o`00o`03ooooool00?oo003o00?o003o2_ooool3o`00o`Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool00oooool9o`00o`gooooo1Ol00?l3ooooo`?o003o00?oooooo`00ool00?l01_l00?l;oooo
o`?oo`000oooool8ool000Sooooo1Ooo0002ooooo`Woo`002_ooool7ool000Kooooo1Ol00?l5oooo
o`Go003o2Oooool9o`00oa7ooooo0ooo0005ooooo`_oo`002oooool5ool000Cooooo1_oo0004oooo
o`?oo`000oooool5ool000Oooooo1?oo0003o`00o`Wooooo1Ol00?l2ooooo`?o003o2_ooool5o`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool3o`00o`04ooooool00?oo003oo`00
o`oooooo0ol00?l:ooooo`Ko003o1?ooool3ool000?ooooo0ooo0003ooooo`Soo`002?ooool6ool0
00?ooooo2?oo0007ooooo`Coo`0000?oooooool00?oo00000ooo0006ooooo`Go003o1Oooool5o`00
o`Sooooo1_l00?lIooooo`?oo`000_ooool:ool000_ooooo1Ooo0004ooooo`Ooo`000_ooool5ool0
00;ooooo1Ooo0008ooooo`?oo`003Oooool3o`00oa3ooooo1Ol00?l8ooooo`7o00000Oooool00003
o`000?oooooooooo02Oooooo1Ol00?l4ooooo`Goo`0000?oooooool00?oo00000ooo0002ooooo`Go
o`002_ooool7ool000Gooooo1Ooo0007ooooo`Koo`0000Coooooool00?oo003oo`002?ooool3o`00
o`Kooooo1Ol00?l7ooooo`Ko003o6Oooool5ool000;ooooo0ooo00000oooooooo`00ool00003ool0
00cooooo0ooo0005ooooo`Ooo`000_ooool5ool000;ooooo1Ooo000[ooooo`Oo003o1_ooool1o`00
007ooooo00000ol0003oooooooooo`0Wooooo`Go003o00Coo`00oooooooooooooooo1Ooo00000ooo
ooooo`00ool00003ool000;ooooo1Ooo000:ooooo`Koo`001_ooool7ool000Gooooo1_oo000Foooo
o`?o003o2?ooool5o`00oa[ooooo1ooo0005ooooo`?oo`000_ooool3ool0017ooooo1ooo00000ooo
ooooo`00ool00003ool000;ooooo1Ooo0002ooooo`?oo`009oooool7o`00o`Gooooo0Ol00001oooo
o`0000?o0000ooooooooool04?ooool3o`00oaGooooo0ol00?l3ool000;ooooo1Ooo00000ooooooo
o`00ool00004ool00003oooooooo003oo`0000?oo`002_ooool5ool000Kooooo2Ooo0003ooooo`Oo
o`008Oooool5o`00oa[ooooo2?oo0004ooooo`?oo`0000?oooooool00?oo00000ooo000Aooooo`Oo
o`0000Coooooool00?oo003oo`000oooool;ool002Sooooo1Ol00?l5ooooo`7o00000Oooool00003
o`000?oooooooooo00Cooooo0ol00?l8ooooo`Go003o5Oooool6ool000;ooooo1Ooo00000ooooooo
o`00ool00009ool000_ooooo0ooo0007ooooo`Woo`000oooool6ool002?ooooo0ol00?lEooooo`Go
003o0_ooool7ool000?ooooo2_oo000Booooo`Koo`001oooool;ool002Sooooo1Ol00?l5ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo1Ol00?l7ooooo`Go003o5?ooool7ool000?ooooo
4Ooo000;ooooo`?oo`001_ooool9ool000?ooooo1Ooo000Dooooo`?o003o6?ooool3o`00o`Wooooo
2Ol00?l00oooooooo`00ool00003ool000?ooooo2_oo0008ooooo`?oo`002?ooool5ool000Oooooo
2ooo0002ooooo`?oo`008_ooool5o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ool5o`00o`Oooooo1Ol00?lDooooo`Ooo`000oooool5ool00003oooooooo003oo`0000[oo`002Ooo
ool7ool000Cooooo0ooo00001?ooooooo`00ool00?oo0004ooooo`Coo`005?ooool5o`00oaKooooo
1_l00?l7ooooo`[o003o00Coooooool00?oo003oo`000oooool;ool000Cooooo2?oo0008ooooo`?o
o`002Oooool9ool000;ooooo1Ooo000Pooooo`Go003o1oooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooo`Go003o2?ooool3o`00oaGooooo1_oo0004ooooo`Goo`000_ooool5ool00003oooo
oooo003oo`0000?oo`001oooool:ool000Oooooo0ooo0003ooooo`Goo`005?ooool5o`00oaKooooo
1ol00?l6ooooo`[o003o1_ooool6ool000;ooooo0ooo0004ooooo`Woo`005oooool4ool000Cooooo
1Ooo000Pooooo`Go003o1oooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`?o003o0_oo
ool3o`00o`oooooo0ol00?l;ooooo`?oo`001Oooool5ool000Cooooo0ooo0002ooooo`Goo`0000Co
ooooool00?oo003oo`000_ooool;ool000Kooooo1Ooo0002ooooo`Koo`0000Coooooool00?oo003o
o`003oooool5o`00oaKooooo1ol00?l7ooooo`Wo003o1_ooool5ool000?ooooo0ooo0004ooooo`Wo
o`007oooool5ool000Wooooo0ol00?lDooooo`Go003o1oooool1o`00007ooooo00000ol0003ooooo
ooooo`08ooooo`Go003o3?ooool6o`00oa;ooooo1Ooo0004ooooo`?oo`000oooool3ool00003oooo
oooo003oo`0000?oo`0000?oooooool00?oo00002Ooo0006ooooo`Goo`000_ooool;ool000Gooooo
0ol00?l7ooooo`?o003o6?ooool6o`00o`cooooo0ol00?l4ooooo`ooo`000oooool8ool0027ooooo
0ooo0009ooooo`Go003o5?ooool3o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?oo
ool5o`00o`_ooooo1ol00?lBooooo`Goo`000oooool5ool000Kooooo1Ooo00000oooooooo`00ool0
000:ool000Gooooo1Ooo0003ooooo`[oo`001?ooool5o`00o`kooooo0ol00?l@ooooo`Go003o4ooo
ool@ool000Cooooo0ooo00001?ooooooo`00ool00?oo000]ooooo`Go003o7oooool1o`00007ooooo
00000ol0003oooooooooo`08ooooo`Go003o1oooool3o`00o`03ooooool00?oo003o00Go003o2_oo
ool3ool000Kooooo0ooo0003ooooo`Koo`001_ooool5ool000;ooooo2ooo0005ooooo`Goo`001?oo
ool9ool000Cooooo1Ol00?l=ooooo`So003o3Oooool3o`00oaCooooo1Ooo0003ooooo`Soo`001Ooo
ool7ool000;ooooo0ooo0005ooooo`?oo`007oooool5o`00o`Cooooo0ol00?lHooooo`7o00000Ooo
ool00003o`000?oooooooooo00Wooooo0ol00?l7ooooo`_o003o2_ooool5ool000_ooooo1_oo0005
ooooo`Ooo`000_ooool:ool000Kooooo0ooo0006ooooo`Ooo`001Oooool5o`00o`gooooo2Ol00?l2
ooooo`?o003o3_ooool3o`00o`gooooo1Ooo0002ooooo`Soo`001Oooool8ool00003oooooooo003o
o`0000?oo`000oooool5ool000gooooo0ooo00001?ooooooo`00ool00?oo000;ooooo`?o003o1?oo
ool5o`00o`?ooooo0ol00?l5ooooo`?o003o2Oooool1o`00007ooooo00000ol0003oooooooooo`0C
ooooo`Go003o00Coooooo`00ool00?oo003o3?ooool5ool00004oooooooo003oo`00ool000Oooooo
1Ooo0005ooooo`Woo`000oooool7ool000oooooo2?oo00001?oooooo003oo`00ool00?l2ooooo`Go
003o3?ooool9o`00o`03ooooool00?oo003o00?o003o3?ooool5o`00o`gooooo0ooo0002ooooo`Oo
o`001Oooool@ool000?ooooo1ooo000:ooooo`Woo`004Oooool5o`00o`;ooooo1Ol00?l3ooooo`So
003o1Oooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`So003o4?ooool:ool000Oooooo
0ooo0006ooooo`Woo`001?ooool7ool000gooooo2?oo00000ooooooo003oo`00o`03o`00o`;ooooo
1Ol00?l<ooooo`So003o00?oooooo`00ool00?l00ol00?l<ooooo`Go003o0_ooool3o`00o`gooooo
1_oo0005oooooa7oo`000oooool8ool00004oooooooo003oo`00ool000Cooooo2_oo000Aooooo`Go
003o0_ooool5o`00o`?ooooo2Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo
2?l00?l9ooooo`?o003o1_ooool3ool00003oooooooo003oo`0000?oo`004?ooool9ool000?ooooo
2?oo000=ooooo`Ooo`000_ooool5o`00o`;ooooo1Ol00?l>ooooo`Ko003o00?oooooo`00ool00?l0
0ol00?l<ooooo`Go003o00?oooooo`00ool00?l00ol00?l<ooooo`Goo`001_ooool@ool000Gooooo
3?oo0002ooooo`_oo`004_ooool3o`00o`?ooooo1Ol00?l3ooooo`Wo003o1?ooool1o`00007ooooo
00000ol0003oooooooooo`0?ooooo`Go003o2oooool5o`00o`?ooooo0ol00?l3ooooo`Goo`004?oo
ool8ool000?ooooo2Ooo00001?ooooooo`00ool00?oo0009ooooo`Koo`000oooool5o`00o`;ooooo
1Ol00?l?ooooo`Co003o0oooool3o`00o`kooooo0ol00?l2ooooo`Ko003o3?ooool3ool000Oooooo
1Ooo00000oooooooo`00ool00008ool000Oooooo2_oo0002ooooo`[oo`002?ooool3o`00o`_ooooo
2_l00?l2ooooo`So003o1?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Go003o2ooo
ool5o`00o`;ooooo1Ol00?l3ooooo`Goo`004?ooool6ool000Cooooo2?oo00000oooooooo`00ool0
0003ool000Oooooo1_oo0005ooooo`?o003o1?ooool3o`00obgooooo1_l00?l;ooooo`?oo`002Ooo
ool3ool000;ooooo2_oo0008ooooo`?oo`0000?oooooool00?oo00000ooo0002ooooo`Woo`002?oo
ool5o`00o`Wooooo3?l00?l4ooooo`Go003o1?ooool1o`00007ooooo00000ol0003oooooooooo`0@
ooooo`?o003o3?ooool5o`00o`;ooooo1Ol00?l4ooooo`Goo`004?ooool5ool000Cooooo1_oo0003
ooooo`Goo`001_ooool7ool001[ooooo0ol00?lPooooo`Oo003o2?ooool5ool000Gooooo0ooo0005
ooooo`[oo`003Oooool?ool000Sooooo1Ol00?l7ooooo`ko003o1Oooool3o`00o`Gooooo0Ol00001
ooooo`0000?o0000ooooooooool08?ooool3o`00o`?ooooo1Ol00?l4ooooo`Goo`001?ooool3ool0
00[ooooo0ooo0006ooooo`Koo`000_ooool5ool000Kooooo1ooo000Iooooo`Go003o0_ooool3o`00
oa_ooooo1ol00?l5ooooo`Ooo`001?ooool5ool000Gooooo2Ooo000>ooooo`Soo`000_ooool6ool0
00Kooooo1Ol00?l6oooooa3o003o0_ooool6o`00o`Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool08_ooool3o`00o`;ooooo0ol00?l5ooooo`Koo`000_ooool5ool001?ooooo1_oo0002ooooo`?o
o`001oooool6ool000;ooooo0ooo000Eooooo`Go003o00?oooooo`00ool00?l01Ol00?lJooooo`Go
003o1?ooool8ool000?ooooo1_oo0006ooooo`Ooo`003oooool8ool000Cooooo1Ooo0006ooooo`?o
003o1_oooolAo`00o`03ooooool00?oo003o00Oo003o0_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Qooooo`Go003o1oooool8ool00003oooooooo003oo`0000Coo`004?ooool:ool00004oooo
oooo003oo`00ool000Sooooo0ooo0003ooooo`Goo`000oooool3o`00o`04ooooool00?oo003oo`00
o`[ooooo1Ol00?l00ooooooo003oo`00o`06o`00oaWooooo1Ol00?l4ooooo`Soo`000oooool6ool0
00Oooooo1ooo000>ooooo`Soo`001?ooool5ool000kooooo1ol00?l3ooooo`So003o00?oooooo`00
ool00?l02?l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo027ooooo1Ol00?l6ooooo`Wo
o`0000?oooooool00?oo00001?oo0007ooooo`?oo`001Oooool@ool00004oooooooo003oo`00ool0
00Wooooo1Ooo0002ooooo`Wo003o2_ooool3o`00o`03ooooool00?oo003o00Oo003o6_ooool3o`00
o`Gooooo2?oo0003ooooo`Goo`002?ooool8ool000cooooo2Ooo0004ooooo`Goo`001?ooool3o`00
o`Oooooo1_l00?l4ooooo`Oo003o0_ooool:o`00o`7ooooo0Ol00001ooooo`0000?o0000oooooooo
ool08Oooool5o`00o`Kooooo2?oo0002ooooo`Goo`001oooool5ool000Cooooo5Ooo0004ooooo`?o
o`0000?oooooool00?oo00001?oo00000ooooooo003oo`00o`07o`00o`gooooo2_l00?lNooooo`co
o`001?ooool5ool000Oooooo2?oo000<ooooo`[oo`001?ooool3ool000Cooooo1Ol00?l6ooooo`Go
003o00Goooooo`00ool00?oo003oooooo`05o`00o`Gooooo0ol00?l00ooooooo003oo`00o`03o`00
o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool3o`00o`_ooooo0ol00?l5ooooo`?o
003o1oooool5ool000Kooooo0ooo0003ooooo`?oo`0000?oooooool00?oo00001?oo0003oooooaKo
o`000_ooool<ool00003ooooool00?oo003o00Oo003o3Oooool5o`00o`04ooooool00?oo003oo`00
o`gooooo0ol00?l>ooooo`koo`001?ooool5ool000Oooooo1ooo000;ooooo`coo`002_ooool5o`00
o`Oooooo0ol00?l00ooooooo003oo`00o`03o`00o`04ooooool00?oo003oo`00o`_ooooo0ol00?l2
ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo1Ol00?l9ooooo`Go003o3oooool3ool0
00cooooo2ooo0002oooooaooo`0000?oooooool00?oo00000ooo0002ooooo`?o003o00Coooooo`00
ool00?oo003o3_ooool5o`00oa3ooooo1Ol00?l=ooooo`koo`001?ooool5ool000Oooooo1_oo000:
ooooo`Ooo`0000?oooooool00?oo00001?oo000:ooooo`Ko003o2Oooool6o`00oaCooooo0Ol00001
ooooo`0000?o0000ooooooooool02oooool5o`00o`Wooooo1Ol00?lJooooo`?oo`0000?oooooool0
0?oo00002?oo0003ooooobCoo`006Oooool3o`00oa7ooooo1Ol00?l=oooooa7oo`0000?oooooool0
0?oo00000ooo0006ooooo`Goo`002oooool8ool000;ooooo1Ooo000;ooooo`Ko003o00Coooooo`00
ool00?oo003o1?ooool6o`00o`oooooo0ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo
00_ooooo1Ol00?l9ooooo`Go003o6Oooool>ool000Cooooo4ooo00000oooooooo`00ool0000=ool0
02kooooo1Ol00?l2ooooo`?o003o2OoooolFool000Kooooo1Ooo000;ooooo`Ooo`001?ooool3ool0
00gooooo2_l00?l2ooooo`Ko003o3oooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000oooooooo
ool03?ooool3o`00o`_ooooo0ol00?lJooooo`koo`001Oooool3ool000?ooooo2ooo0002ooooo`Wo
o`0000?oooooool00?oo00000ooo000_ooooo`?o003o0_ooool5o`00o`_ooooo1ooo00000ooooooo
o`00ool00009ool000Kooooo1_oo000:ooooo`Ooo`005?ooool:o`00o`03ooooool00?oo003o00Co
003o1_ooool3o`00o`Oooooo1Ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo
0ol00?l<ooooo`ooo`002oooool5ool000;ooooo0ooo0004ooooo`ooo`00<oooool5o`00o`[ooooo
2?oo00000oooooooo`00ool00008ool000Sooooo1ooo0002ooooo`?oo`001?ooool6ool001Cooooo
4?l00?l6ooooo`Go003o0_ooool3o`00o`03ooooool00?oo003o00?o003o0Oooool1o`00007ooooo
00000ol0003oooooooooo`0Vooooo`Go003o2oooool:ool00004oooooooo003oo`00ool000Gooooo
0ooo0003ooooo`Goo`001?ooool3ool000?ooooo2Ooo00000oooooooo`00ool00004ool0013ooooo
0ol00?lMooooo`Oo003o2_ooool8ool00003oooooooo003oo`0000Koo`000_ooool4ool000Gooooo
3?oo0005ooooo`?oo`001?ooool3ool000kooooo4?l00?l6ooooo`Go003o00?oooooo`00ool00?l0
0ol00?l01?oooooo003oo`00ool00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00?o003o
3?ooool3o`00oaCooooo1Ol00?l;ooooo`[oo`001_ooool7ool000;ooooo1Ooo0003ooooo`Goo`00
00?oooooool00?oo00002?oo00000oooooooo`00ool00004ool000oooooo1Ol00?lKooooo`Oo003o
00?oooooo`00ool00?l00ol00?l2ooooo`[oo`000oooool6ool000;ooooo1ooo0003ooooo`coo`00
2oooool5ool000gooooo1Ol00?l00ooooooo003oo`00o`07o`00o`Oooooo1Ol00?l00ooooooo003o
o`00o`03o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooool00?l01?l00?l:ooooo`Go003o1Ooo
ool3o`00o`Kooooo2_l00?l<ooooo`?oo`000_ooool3ool000Kooooo2?oo0002ooooo`Goo`000ooo
ool5ool00003oooooooo003oo`0000ooo`003oooool5o`00oa_ooooo1Ol00?l2ooooo`Oo003o2?oo
0007ooooo`?oo`000oooool9ool00003oooooooo003oo`0000_oo`002oooool5ool000kooooo0ol0
0?l4ooooo`Go003o00Coooooo`00ool00?oo003o1_ooool:o`00o`Kooooo0Ol00001ooooo`0000?o
0000ooooool00?l01?l00?l7ooooo`So003o1?ooool5o`00o`Cooooo2_l00?l5ooooo`?oo`0000Co
ooooool00?oo003oo`003oooool8ool000?ooooo1Ooo00000oooooooo`00ool00004ool00003oooo
oooo003oo`0000?oo`0000?oooooool00?oo00003?oo0004ooooo`?o003o1Oooool5o`00oa_ooooo
1Ol00?l2ooooo`Oo003o1Ooo00001?ooooooo`00ool00?oo0005ooooo`Goo`0000?oooooool00?oo
00002?oo00000oooooooo`00ool0000:ool000cooooo1_oo000Eooooo`?o003o00?oooooo`00ool0
0?l00ol00?l7ooooo`Oo003o1oooool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`Kooooo
2Ol00?l4ooooo`Go003o1?ooool8o`00o`Kooooo2Ooo000>ooooo`Ooo`001?oooolAool000;ooooo
3ooo0002ooooo`Go003o1Oooool3o`00oacooooo1Ol00?l2ooooo`Oo003o2_oo0004ooooo`Goo`00
00?oooooool00?oo00002?oo00000oooooooo`00ool00003ool000;ooooo2?oo000:ooooo`Goo`00
6?ooool6o`00o`Kooooo1_l00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00?o003o1ooo
ool8o`00o`Gooooo1Ol00?l4ooooo`So003o1_ooool9ool000oooooo1ooo0003oooooa3oo`000ooo
ool?ool000;ooooo1Ol00?lMooooo`?o003o1?ooool5o`00o`?ooooo1Ol00?l2ooooo`?oo`0000?o
ooooool00?oo00000ooo0004ooooo`Goo`0000?oooooool00?oo00001ooo0003ooooo`?oo`001?oo
ool8ool00004oooooooo003oo`00ool000Gooooo2_oo000Booooo`Oo003o1_ooool6o`00o`Wooooo
0Ol00001ooooo`0000?o0000ooooooooool02_ooool5o`00o`Wooooo0ol00?l6ooooo`Oo003o1_oo
ool9ool000[ooooo0ooo0004ooooo`Goo`000oooool@ool000;ooooo1Ooo0003ooooo`Soo`000_oo
ool5o`00oacooooo1Ol00?l4ooooo`?o003o3oooool5ool000Gooooo0ooo0003ooooo`?oo`001ooo
ool3ool000Sooooo2_oo0005ooooo`[oo`004Oooool6o`00o`Oooooo1Ol00?l:ooooo`7o00000Ooo
ool00003o`000?oooooooooo00_ooooo0ol00?lFooooo`Go003o1_ooool7ool000[ooooo1Ooo0003
ooooo`Goo`000oooool@ool000;ooooo1Ooo00000oooooooo`00ool00008ool000?ooooo0ol00?l6
ooooo`?o003o5?ooool6o`00oaGooooo1Ooo000Dooooo`Goo`001oooool=ool000Cooooo2?oo000A
ooooo`Go003o2Oooool3o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool6o`00
oa3ooooo1Ol00?l5ooooo`Koo`002oooool5ool000Cooooo1Ooo0003ooooo`koo`000oooool@ool0
00_ooooo1Ol00?l=ooooo`?o003o0oooool7o`00o`kooooo0ooo0003ooooo`Goo`002?ooool3ool0
00Wooooo1Ooo0008ooooo`goo`000oooool8ool001;ooooo0ol00?lHooooo`7o00000Oooool00003
o`000?oooooooooo00kooooo2?l00?l=ooooo`Oo003o1_ooool3ool000gooooo1Ooo0004ooooo`Go
o`000_ooool<ool000Oooooo0ooo00000oooooooo`00ool00009ool000_ooooo1Ol00?l<ooooo`Go
003o0_ooool7o`00o`gooooo1Ooo0002ooooo`Goo`001oooool5ool000Sooooo2?oo0006ooooo`co
o`001?ooool7ool0027ooooo0ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo
2?l00?l<ooooo`So003o5oooool3ool000Gooooo1Ooo0002ooooo`_oo`001_ooool3ool000?ooooo
2_oo000<ooooo`Go003o3?ooool5o`00o`;ooooo1ol00?l=ooooo`Goo`000_ooool6ool000Kooooo
1Ooo0009ooooo`Soo`001_ooool3ool00003oooooooo003oo`0000Goo`001_ooool5ool0023ooooo
1Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo2?l00?l<ooooo`Oo003o8Ooo
ool3ool000?ooooo2ooo0005ooooo`Goo`000oooool3ool000;ooooo0ooo0006ooooo`?oo`001Ooo
ool5o`00o`_ooooo1Ol00?l2ooooo`Ko003o3_ooool5ool000;ooooo2?oo0004ooooo`Goo`002_oo
ool7ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00Koo`0000Coooooool00?oo003o
o`001?ooool3ool000kooooo0ol00?l>ooooo`Oo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0?ooooo`Ko003o3Oooool6o`00o`Sooooo0ooo0002ooooo`?oo`006?ooool5ool00003oooo
oooo003oo`0000?oo`001Oooool5ool0013ooooo1Ooo0004ooooo`Go003o3?ooool3o`00o`Cooooo
0ol00?l8ooooo`?oo`001Oooool5ool000;ooooo2Ooo0004ooooo`?oo`002_oooolMool000Cooooo
1_l00?l9ooooo`Go003o2oooool9o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?oo
ool3o`00oa3ooooo1Ol00?l7ooooo`[oo`005?ooool8ool000;ooooo0ooo0005ooooo`Woo`002ooo
ool7ool000Cooooo1Ol00?lKooooo`Ooo`000_ooool7ool000;ooooo3?oo0002ooooo`Coo`002?oo
oolBool00003oooooooo003oo`0000Soo`000oooool8o`00o`Sooooo1Ol00?l:ooooo`Wo003o2Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Go003o3oooool5o`00o`Oooooo2_oo0006
ooooo`?oo`0000Coooooool00?oo003oo`001_ooool9ool000[ooooo2_oo0002ooooo`?oo`001?oo
ool8ool000Gooooo0ol00?lHooooo`?o003o4Ooo0003oooooa;oo`001ooooolBool000;ooooo0ooo
00000oooooooo`00ool00003ool000?ooooo2?l00?l8ooooo`Go003o2_ooool7o`00o`_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool03oooool7o`00o`kooooo0ol00?l8ooooo`[oo`001Oooool9
ool00005oooooooo003oo`00ool00?ooool02?oo000;ooooo`[oo`0000?oooooool00?oo00000ooo
0003ooooo`Ooo`008?ooool5o`00oa7oo`001_ooool>ool000Oooooo1?oo00000oooooooo`00ool0
000;ool000Oooooo0ooo0004ooooo`So003o2Oooool3o`00o`_ooooo1ol00?l6ooooo`?o003o0_oo
ool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`So003o5_ooool3o`00o`?oo`000_ooool3
ool000Cooooo5Ooo000?ooooo`Woo`0000?oooooool00?oo00000ooo0003ooooo`Goo`001Oooool3
ool001[ooooo1Ol00?lAool000Wooooo2ooo00001Oooooooo`00ool00?oo003ooooo00Koo`000_oo
ool5ool000?ooooo0ooo000@ooooo`Ko003o6Oooool5o`00o`Kooooo1Ol00?l1ooooo`7o00000Ooo
ool00003o`000?oooooooooo013ooooo1ol00?l8ooooo`?o003o2_ooool5o`00o`;oo`0000?ooooo
ool00?oo00000ooo0002oooooaGoo`004Oooool7ool000;ooooo1Ooo0004ooooo`Goo`000oooool6
ool001Sooooo1Ol00?lAool000Cooooo0ooo00000oooooooo`00ool00003ool00003oooooooo003o
o`0000?oo`0000?oooooool00?oo00002Ooo0002ooooo`Goo`00:Oooool3o`00o`Wooooo1_l00?l5
ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`Co003o0_ooool8o`00
o`Oooooo1Ol00?l9ooooo`Go003o0_oo00000oooooooo`00ool00003ool000;ooooo2ooo00000ooo
ooooo`00ool00007ool001;ooooo0ooo0006ooooo`?oo`001_ooool5ool000;ooooo1ooo0003oooo
o`04ool00?l00?oo003oo`00oa7ooooo0ol00?l3ooooo`Ooo`001?ooool3ool00003oooooooo003o
o`0000[oo`000oooool3ool000;ooooo2ooo0003ooooo`?oo`00:Oooool5o`00o`Sooooo1ol00?l4
ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`08oooooa7o003o1Oooool5o`00
o`Wooooo1Ol00?l00ooo003oooooooooo`06ool00003oooooooo003oo`0001Coo`006?ooool3ool0
00Sooooo1Ooo0002ooooo`Ooo`000_ooool00ooo003o003oo`00o`03o`00oaKooooo1Ooo0005oooo
o`?oo`0000?oooooool00?oo00002ooo0008ooooo`[oo`002Oooool3ool002Cooooo1Ol00?l5oooo
o`?o003o00?oooooo`00ool00?l01?l00?l5ooooo`Co003o0Oooool1o`00007ooooo00000ol0003o
ooooooooo`08ooooo`_o003o0_ooool8o`00o`03ooooool00?oo003o00?o003o2_ooool3o`00o`Go
oooo1Ooo0002ooooo`Goo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00007ool000Go
oooo0ooo000?ooooo`Goo`001oooool5ool000?ooooo1_oo0002ooooo`03ool00?l00?oo003o00?o
003o5_ooool4ool000Gooooo4_oo0009ooooo`Ooo`002_ooool5ool0013ooooo0ol00?l@ooooo`Go
003o1?ooool;o`00o`Gooooo1Ol00?l1o`00007ooooo00000ol0003oooooooooo`08ooooo`_o003o
0_ooool9o`00o`04ooooool00?oo003oo`00o`Sooooo1_l00?l5ooooo`Goo`002?ooool5ool000Go
oooo1Ooo0004ooooo`Goo`003_ooool5ool000Sooooo0ooo0006ooooo`?oo`000oooool00ooo003o
003oo`00o`03o`00oaGooooo1Ooo0005ooooo`goo`0000Coooooool00?oo003oo`002_ooool5ool0
00Wooooo2Ooo000>ooooo`Go003o3?ooool3o`00o`04ooooool00?oo003oo`00o`Gooooo2_l00?l6
ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool02Oooool9o`00o`;ooooo4_l00?l3oooo
o`So003o0_oo0003ooooo`Coo`002Oooool3ool000Oooooo0ooo0005ooooo`Goo`0000Coooooool0
0?oo003oo`002Oooool6ool001Sooooo00Coo`00o`00ool00?oo003o5_ooool6ool000Cooooo1Ooo
00001?ooooooo`00ool00?oo000Aooooo`Goo`002Oooool;ool000Kooooo0ooo0002ooooo`Oo003o
2oooool;o`00o`;ooooo2_l00?l6ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool00ooo
ool3o`00o`Kooooo1Ol00?l3oooooa?o003o0_ooool:o`00o`03ool00?oooooooooo00Goo`001Ooo
ool3ool001;ooooo2_oo0008ooooo`Goo`002?ooool3ool001Oooooo0ooo000>ooooo`Ooo`001?oo
ool3ool0013ooooo2ooo0008ooooo`coo`001Oooool5ool000So003o2oooool<o`00o`;ooooo2Ol0
0?l5ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Go003o1Oooool4
o`00o`Cooooo1Ol00?l01Ooooooo003oo`00ool00?oooooo00Wo003o0_ooool;o`00o`;ooooo1Ooo
0004ooooo`Ooo`004?ooool3ool00003oooooooo003oo`0000?oo`002?ooool5ool000Oooooo1Ooo
000Eooooo`Goo`003_ooool8ool001Cooooo3?oo0008ooooo`Koo`0000?oooooool00?oo00000ooo
0005ooooo`Goo`001ol00?l<ooooo`co003o0oooool8o`00o`Cooooo1Ol00?l2ooooo`7o00000Ooo
ool00003o`000?oooooooooo00;ooooo2?l00?l00ooooooo003oo`00o`04o`00o`Cooooo1Ol00?l4
ooooo`Wo003o00?oooooo`00ool00?l02_l00?l2ooooo`Goo`001?ooool8ool000Gooooo0ooo000;
ooooo`Goo`002Oooool5ool000Kooooo1Ooo000Eooooo`Goo`003?ooool;ool0017ooooo3Ooo0006
ooooo`koo`001_ooool5ool000Go003o3_ooool=o`00o`Kooooo0ol00?l5ooooo`Go003o0_ooool1
o`00007ooooo00000ol0003oooooooooo`02oooooa3o003o0oooool5o`00o`?ooooo1Ol00?l01Ooo
oooo003oo`00ool00?oooooo00Ko003o0_ooool5o`00o`?ooooo0ooo0005ooooo`Soo`001?ooool5
ool000[ooooo1Ooo0009ooooo`Goo`001_ooool5ool001Gooooo1Ooo00001?ooooooo`00ool00?oo
0007ooooo`coo`004?ooool>ool000Gooooo3ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ol0
0?l?ooooo`ko003o3Oooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool?
o`00o`?ooooo1Ol00?l3ooooo`Go003o1?ooool7o`00o`?ooooo0ol00?l<ooooo`Soo`001?ooool8
ool000Sooooo0ooo0003ooooo`?oo`001?ooool5ool000Oooooo0ooo000Fooooo`[oo`001_ooool<
ool000kooooo4?oo0004ooooo`Koo`000_ooool8ool00003oooooooo003oo`0000?oo`006Oooool3
o`00o`Gooooo1Ol00?l7ooooo`?o003o1?ooool3o`00o`?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool01_ooool5o`00o`03ooooool00?oo003o00Co003o1?ooool3o`00o`Cooooo1Ol00?l00ooo
oooo003oo`00o`07o`00o`cooooo0ooo0004ooooo`Ooo`001Oooool9ool00003oooooooo003oo`00
00Coo`001Oooool5ool000Cooooo0ooo0002ooooo`?oo`003_ooool5ool000Cooooo0ooo00000ooo
ooooo`00ool00009ool000Kooooo1Ooo0003ooooo`?oo`003_ooool:ool000?ooooo0ooo0005oooo
o`Koo`000_ooool7ool000;ooooo1Ooo000Qooooo`Go003o1_ooool5o`00o`Wooooo0Ol00001oooo
o`0000?o0000ooooooooool01oooool3o`00o`Cooooo0ol00?l5ooooo`?o003o1Oooool3o`00o`03
ooooool00?oo003o00Oo003o3?ooool5ool000?ooooo1Ooo0008oooooa3oo`001?ooool5ool000So
oooo1Ooo0004ooooo`?oo`000_ooool:ool000;ooooo4?oo0007ooooo`?oo`005?ooool;ool000_o
oooo1Ooo0004ooooo`Goo`000oooool5ool0017ooooo0ol00?l>ooooo`?o003o1oooool7o`00o`Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool5o`00o`Sooooo2?l00?l=ooooo`Goo`00
1?ooool3ool000Sooooo0ooo00000oooooooo`00ool0000;ool000?ooooo1_oo0002ooooo`?oo`00
0oooool5ool000?ooooo4?oo0002ooooo`ooo`002_ooool3ool0017ooooo3?oo000<ooooo`Koo`00
0oooool5ool000?ooooo0ooo000Aooooo`Go003o4?ooool5o`00o`;ooooo2?l00?l6ooooo`7o0000
0Oooool00003o`000?oooooooooo01Gooooo1Ol00?l8ooooo`Go003o4?ooool5ool000kooooo2Ooo
00000oooooooo`00ool00006ool000?ooooo1Ooo0002ooooo`Goo`000_ooool5ool000?ooooo4?oo
0002ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000Oo
oooo1Ooo000;ooooo`?oo`000_ooool6ool00003oooooooo003oo`0000?oo`003_ooool5ool000;o
oooo1Ooo000?ooooo`?o003o1?ooool6o`00o`oooooo1ol00?l2ooooo`Oo003o1_ooool1o`00007o
oooo00000ol0003oooooooooo`0Eooooo`Go003o2Oooool3o`00oa;ooooo0ooo000?ooooo`Woo`00
0_ooool6ool000Cooooo1Ooo0002ooooo`Goo`000oooool3ool000Cooooo4?oo0003ooooo`Koo`00
00?oooooool00?oo00002?oo0006ooooo`Goo`002_ooool5ool00003oooooooo003oo`0000?oo`00
0oooool3ool000oooooo3?oo000>ooooo`Go003o0_ooool7o`00o`oooooo1ol00?l00ooooooo003o
o`00o`06o`00o`04ooooool00?oo003oo`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
5Oooool4o`00oc7ooooo2ooo000;ooooo`?oo`000oooool8ool000Sooooo0ooo0002ooooo`_oo`00
0_oooolAool000Gooooo2?oo0008ooooo`Goo`000_ooool3ool000_ooooo0ooo0008ooooo`coo`00
1Oooool3ool000Kooooo1Ol00?l2ooooo`Ko003o4?ooool?o`00o`03ooooool00?oo003o00?o003o
0Oooool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`Go003o4?ooool3o`00oaoooooo2ooo
000Aooooo`Soo`002oooool3ool00003oooooooo003oo`0000Koo`000_oooolAool000;ooooo3?oo
0007ooooo`Goo`003oooool5ool000?ooooo4?oo0004ooooo`Goo`001Oooool5o`00o`;ooooo1Ol0
0?lBooooo`_o003o1?ooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool5
o`00o`oooooo1Ol00?lPooooo`Woo`004Oooool8ool000[ooooo1Ooo00000oooooooo`00ool00005
ool000?ooooo2ooo00001?ooooooo`00ool00?oo0002ooooo`goo`002?ooool3ool0013ooooo1Ooo
0002ooooo`Soo`0000?oooooool00?oo00002?oo0002ooooo`Goo`001_ooool3o`00o`Cooooo0ol0
0?lHooooo`Ko003o1?ooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool3
o`00o`Gooooo1Ol00?l?ooooo`Ko003o3Oooool3ool000Cooooo0ooo0004ooooo`?oo`0000?ooooo
ool00?oo00001ooo000@ooooo`Woo`002_ooool5ool000Cooooo0ooo0006ooooo`Soo`001?ooool@
ool000Oooooo1Ooo000?ooooo`ooo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00003
ool00003oooooooo003oo`0000?oo`001_ooool3o`00o`?ooooo1Ol00?lGooooo`So003o0oooool3
o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool3o`00o`Kooooo1Ol00?l5oooo
o`?o003o4?ooool6o`00o`[ooooo1ooo0002ooooo`Goo`000_ooool=ool000Cooooo0ooo000:oooo
o`Soo`001_ooool3ool000;ooooo1Ooo000>ooooo`Goo`001Oooool:ool000?ooooo0ooo0008oooo
o`Koo`0000Coooooool00?oo003oo`002?oooolAool000;ooooo2_oo0002ooooo`?oo`001_ooool>
o`00oaKooooo2?l00?l7ooooo`7o00000Oooool00004o`000?ooooooooooooooo`Go003o1Oooool5
o`00oaGooooo0ol00?l00ooooooo003oo`00o`04o`00o`Sooooo5_oo00000oooooooo`00ool00005
ool000?ooooo1Ooo0009ooooo`Ooo`001_ooool:ool000oooooo1Ooo0005ooooo`Woo`002oooool3
ool00003oooooooo003oo`0000Woo`001?oooolCool00003oooooooo003oo`0000[oo`002oooool?
o`00oaCooooo0ol00?l00ooooooo003oo`00o`04o`00o`Kooooo0Ol00001ooooo`0000Co0000oooo
oooooooooooo1Ol00?l5ooooo`Go003o5?ooool5o`00o`03ooooool00?oo003o00Co003o1ooooolF
ool000?ooooo1Ooo0003ooooo`Goo`002_ooool3ool000Wooooo2Ooo000@ooooo`Goo`001Oooool:
ool000Wooooo4?oo0003ooooo`ooo`001Oooool8ool00004oooooooo003oo`00ool000Gooooo0ol0
0?l4ooooo`oo003o4oooool<o`00o`Gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo1Ol0
0?l6ooooo`?o003o4?ooool3o`00o`;ooooo1Ol00?l2ooooo`Go003o1ooooolEool000Gooooo0ooo
0004ooooo`Goo`005_ooool9ool0017ooooo0ooo0003ooooo`?oo`0000Goooooool00?oo003oo`00
ooooo`05ool000Wooooo2_oo00000oooooooo`00ool00003ool000?ooooo2_oo00001?ooooooo`00
ool00?oo0006ooooo`Ooo`002Oooool5o`00o`Cooooo3_l00?lCooooo`Go003o00?oooooo`00ool0
0?l01?l00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0ol00?l?ooooo`Ko003o
1?ooool5o`00o`03ooooool00?oo003o00[o003o2?ooool3ool000;ooooo3?oo000@ooooo`?oo`00
6?ooool8ool000Cooooo1_oo000<ooooo`Goo`001?ooool5ool000Wooooo2?oo0004ooooo`?oo`00
1?ooool7ool000Cooooo0ooo0006ooooo`Goo`0000Coooooool00?oo003oo`000_ooool3ool000;o
oooo2?l00?l5ooooo`Wo003o5?ooool5o`00o`;ooooo1Ol00?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo01?ooooo2?l00?l3ooooo`Go003o0_ooool<o`00o`gooooo3?oo000^ooooo`?oo`00
1?ooool8ool000;ooooo0ooo0006ooooo`Goo`001Oooool3ool000_ooooo1ooo000<ooooo`?oo`00
1_ooool5ool000Kooooo0ooo00000oooooooo`00ool00008ool00003ooooool00?oo003o00Oo003o
1_ooool3o`00oaWooooo0ol00?l4ooooo`?o003o1_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Cooooo`So003o0oooool5o`00o`?ooooo2ol00?lAooooo`Woo`00=?ooool8ool00003oooooooo
003oo`0000?oo`000oooool7ool001Kooooo0ooo0002ooooo`?oo`002?ooool3ool000Kooooo1Ooo
000:ooooo`[oo`000_ooool8o`00oc;ooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool3
o`00o`;ooooo2?l00?l4ooooo`?o003o1?ooool;o`00o`Gooooo0ol00?l:ooooo`Soo`002_ooool3
ool00004oooooooo003oo`00ool001Wooooo0ooo0007ooooo`Soo`0000?oooooool00?oo00000ooo
0002ooooo`Soo`006_ooool6ool000Gooooo1Ooo0005ooooo`Goo`001_ooool3ool00003oooooooo
003oo`0000Soo`001Oooool5o`00oacooooo0ol00?lCooooo`7o00000Oooool00003o`000?oooooo
oooo00gooooo1Ol00?l2ooooo`Ko003o1_ooool3o`00o`Cooooo2Ol00?l5ooooo`Go003o2_ooool7
ool000Wooooo2Ooo000Gooooo`Goo`0000Coooooool00?oo003oo`000_ooool7ool000;ooooo1Ooo
0002ooooo`Soo`003oooool3ool000Sooooo1ooo0004ooooo`Goo`001?ooool6ool000Gooooo1Ooo
00001?ooooooo`00ool00?oo0002ooooo`?oo`001oooool3o`00oacooooo1Ol00?lBooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo0ol00?l8ooooo`Go003o3Oooool5o`00o`Cooooo1Ol0
0?l8ooooo`Go003o3Oooool3ool000[ooooo2Ooo000Gooooo`ooo`001Oooool5ool000;ooooo2_oo
000<ooooo`Goo`001oooool7ool000Cooooo1Ooo0003ooooo`Soo`000oooool7ool000oooooo0ol0
0?lEooooo`Go003o0_ooool5o`00o`?ooooo1Ol00?l:ooooo`7o00000Oooool00004o`000?oooooo
ooooooooo`Go003o1_ooool6o`00o`gooooo1Ol00?l5ooooo`?o003o2Oooool5o`00o`_ooooo0ooo
0003ooooo`?oo`001_ooool9ool000;ooooo0ooo0003ooooo`?oo`003?ooool?ool000?ooooo2?oo
0002ooooo`[oo`002oooool5ool000Sooooo1_oo0005ooooo`?oo`001?ooool8ool000;ooooo2ooo
000;ooooo`Go003o4oooool7o`00o`03ooooool00?oo003o00?o003o0_ooool7o`00o`Wooooo0Ol0
0001ooooo`0000Co0000oooooooooooooooo1Ol00?l6ooooo`Go003o3_ooool5o`00oa;ooooo0ol0
0?l;ooooo`Goo`0000?oooooool00?oo00000ooo0006ooooo`?oo`0000Coooooool00?oo003oo`00
0_ooool5ool00003oooooooo003oo`0000Goo`002_ooool3ool00003oooooooo003oo`0000Soo`00
0_ooool:ool000Kooooo1ooo0009ooooo`Goo`002_ooool3ool000gooooo2?oo00000oooooooo`00
ool0000;ool000[ooooo1Ol00?lCooooo`Oo003o0_ooool3o`00o`?ooooo1ol00?l2ooooo`?o003o
1?ooool1o`00007ooooo00001?l0003oooooooooooooool5o`00o`?ooooo2?l00?l?ooooo`?o003o
8Oooool5ool00003oooooooo003oo`0000?oo`003oooool5ool00003oooooooo003oo`0000Koo`00
1oooool3ool000Cooooo0ooo0002ooooo`?oo`000oooool:ool000Kooooo2?oo0009ooooo`?oo`00
7?ooool6ool000;ooooo3Ooo0009ooooo`So003o4Oooool:o`00o`Gooooo1ol00?l00ooooooo003o
o`00o`03o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool3o`00o`?ooooo2?l0
0?lbooooo`Ooo`0000?oooooool00?oo00000ooo000?ooooo`Goo`0000?oooooool00?oo00002ooo
00000oooooooo`00ool00003ool000kooooo2_oo0006ooooo`Soo`005oooool3ool001Kooooo3Ooo
0008ooooo`[o003o4Oooool=o`00o`;ooooo1Ol00?l2ooooo`Go003o0oooool1o`00007ooooo0000
0ol0003oooooooooo`08ooooo`Oo003o4oooool3o`00oacooooo1ooo0003ooooo`?oo`004Oooool3
ool000?ooooo4ooo0004ooooo`Goo`001Oooool3ool000;ooooo0ooo0007ooooo`Soo`002oooool3
ool000Sooooo1Ooo000Fooooo`?oo`0000?oooooool00?oo00001Ooo0009ooooo`[o003o0oooool3
o`00oa3ooooo2Ol00?l2ooooo`?o003o0oooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool8o`00oa7ooooo1Ol00?lKooooo`[oo`0000Coooooool00?oo003oo`001Oooool4
ool000cooooo5?oo0003ooooo`Ooo`002?ooool3ool000Wooooo1_oo000:ooooo`Koo`001oooool5
ool000Sooooo0ooo000:ooooo`?oo`000_ooool6ool000[ooooo2_l00?l2ooooo`Go003o3oooool9
o`00o`03ooooool00?oo003o00?o003o0oooool3o`00o`Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool01_ooool:o`00oa7ooooo1Ol00?l9ooooo`?o003o3oooool?ool000?ooooo2?oo0009oooo
o`Goo`000_ooool7ool00003oooooooo003oo`0000?oo`000oooool7ool00004oooooooo003oo`00
ool000?ooooo1Ooo0008ooooo`Goo`002?ooool9ool000Oooooo1Ooo0005ooooo`Ooo`002?ooool;
ool000cooooo2?l00?l3ooooo`Go003o4?ooool8o`00o`03ooooool00?oo003o00?o003o2_ooool1
o`00007ooooo00000ol0003oooooooooo`05ooooo`Go003o00?oooooo`00ool00?l00ol00?lAoooo
o`Oo003o1_ooool5o`00o`oooooo3_oo0003ooooo`Woo`000oooool3ool000;ooooo1Ooo0003oooo
o`Goo`000oooool3ool000Cooooo3?oo0002ooooo`_oo`000_ooool5ool000?ooooo0ooo00000ooo
ooooo`00ool00008ool000Oooooo1?oo0005ooooo`Soo`002?ooool8ool001[ooooo1Ol00?l9oooo
o`?o003o2?ooool3o`00o`;ooooo1Ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo00Go
oooo1Ol00?l2ooooo`?o003o4oooool7o`00o`Gooooo1Ol00?lAooooo`coo`000oooool9ool000;o
oooo1Ooo00000oooooooo`00ool00007ool000Oooooo0ooo0005ooooo`Goo`0000?oooooool00?oo
00001?oo00000oooooooo`00ool0000:ool000;ooooo0ooo0003ooooo`koo`001oooool5ool000Go
oooo2?oo0008ooooo`Soo`0000Coooooo`00ool00?oo003o4_ooool3o`00o`;ooooo0ol00?l9oooo
o`Go003o3Oooool3o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00oa[o
oooo1Ol00?l5ooooo`Go003o4_ooool:ool000Gooooo2?oo0002oooooa3oo`001Oooool5ool000[o
oooo1ooo00000oooooooo`00ool00009ool000Sooooo3?oo0009ooooo`Koo`001?ooool7ool000Go
oooo0ooo00000oooooooo`00ool00006ool000Go003o4?ooool5o`00o`gooooo1Ol00?lKooooo`7o
00000Oooool00003o`000?oooooooooo00Kooooo0ol00?lKooooo`Go003o00Coooooo`00ool00?oo
003o0_ooool3o`00oaOooooo1Ooo0008ooooo`Ooo`0000?oooooool00?oo00003_oo0005ooooo`Go
o`002oooool6ool000Cooooo2?oo0008ooooo`Woo`002?ooool3ool00003oooooooo003oo`0000Go
o`000_ooool6ool000Kooooo3?oo00000ooooooo003oo`00o`03o`00oa3ooooo1Ol00?l4ooooo`?o
003o1_ooool5o`00oa_ooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool3o`00o`03oooo
ool00?oo003o00?o003o6oooool5ool000Sooooo2?oo00001Oooooooo`00ool00?oo003ooooo00_o
o`001Oooool6ool000Oooooo2Ooo0005ooooo`Soo`002?ooool6ool000Wooooo1Ooo00000ooooooo
o`00ool00004ool00003oooooooo003oo`0000?oo`002?ooool:ool000;ooooo1ol00?l?ooooo`Go
003o0oooool5o`00o`Kooooo0ol00?l7ooooo`?o003o4_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Pooooo`?o003o1_ooool5o`00oaSooooo0ol00?l5ool000Wooooo1ooo0006ooooo`?oo`00
00?oooooool00?oo00001?oo0006ooooo`Koo`001Oooool9ool000;ooooo0ooo0004ooooo`Goo`00
2Oooool8ool000Gooooo1_oo0002ooooo`Goo`0000?oooooool00?oo00000ooo0004ooooo`?oo`00
00?oooooool00?oo00001ooo0003ooooo`Oo003o4?ooool3o`00o`Cooooo2?l00?l<ooooo`Go003o
4Oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?o003o0_ooool3o`00oa;ooooo1Ol0
0?l5ooooo`Go003o2oooool3o`00o`Wooooo1Ol00?l3ool000_ooooo1_oo000;ooooo`Goo`001ooo
ool5ool000Gooooo1_oo0004ooooo`Goo`000oooool5ool000;ooooo0ooo0004ooooo`Woo`000ooo
ool7ool000?ooooo0ooo00000oooooooo`00ool00004ool000?ooooo1Ooo00000oooooooo`00ool0
0005ool000Cooooo1ol00?lGooooo`Wo003o2oooool5o`00oa7ooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool:o`00oa7ooooo1Ol00?l6ooooo`?o003o2oooool5o`00o`Sooooo1Ol00?l7
ooooo`?oo`001_ooool3ool000gooooo1?oo0007ooooo`Goo`001Oooool6ool000?ooooo1_oo0004
ooooo`?oo`0000?oooooool00?oo00001?oo0004ooooo`Soo`000_ooool:ool000Gooooo1Ooo0004
ooooo`Goo`000oooool5ool000Gooooo1Ol00?lIooooo`So003o2oooool5o`00oa7ooooo0Ol00001
ooooo`0000?o0000ooooooooool01?ooool:o`00oa7ooooo1Ol00?lDooooo`Go003o2?ooool5o`00
o`Kooooo1Ooo0009ooooo`?oo`002Oooool5ool000Kooooo1?oo0007ooooo`Coo`001?ooool6ool0
00Oooooo1ooo0004ooooo`Soo`000_ooool;ool000Cooooo1Ooo0004ooooo`Koo`000oooool3ool0
00Sooooo0ol00?lDooooo`?o003o1Oooool5o`00o`cooooo0ol00?lBooooo`7o00000Oooool00003
o`000?oooooooooo00Cooooo2_l00?lBooooo`?o003o2_ooool3o`00o`Sooooo1Ol00?l9ooooo`?o
003o1oooool5ool000Sooooo1Ooo0008ooooo`Goo`001Oooool5ool000oooooo1Ooo0008ooooo`Oo
o`001Oooool6ool000?ooooo1Ooo00000oooooooo`00ool00003ool000Cooooo1Ooo0004ooooo`Oo
o`003?ooool5o`00oa;ooooo1Ol00?l5ooooo`?o003o6_ooool3o`00o`Gooooo0Ol00001ooooo`00
00Co0000oooooooooooooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o7oooool5o`00
o`Sooooo0ol00?lDooooo`Koo`001oooool5ool000Cooooo0ooo00000oooooooo`00ool00003ool0
00Gooooo1_oo000?ooooo`?oo`002Oooool6ool000Sooooo0ooo0003ooooo`Goo`000_ooool8ool0
00;ooooo0ooo00000oooooooo`00ool00008ool000?o003o2Oooool6o`00oa;ooooo1_l00?lPoooo
o`Go003o1?ooool1o`00007ooooo00000ol0003oooooooooo`05o`00ob?ooooo0ol00?l00ooooooo
003oo`00o`04o`00oakooooo0_oo0003o`00o`;oo`001_ooool5ool000?ooooo1Ooo00000ooooooo
o`00ool00004ool000?ooooo1ooo0003ooooo`?oo`0000Coooooool00?oo003oo`002Oooool3ool0
0005oooooooo003oo`00ool00?ooool00ooo0009ooooo`Goo`000_ooool5ool000?ooooo2?oo0004
ooooo`[oo`001Ol00?l8ooooo`Ko003o4_ooool7o`00o`Sooooo0ol00?l8ooooo`?o003o2Oooool5
o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?lRooooo`_o003o5oooool3o`00
o`Gooooo1Ol00?l00ooo003oooooooooo`05ooooo`?oo`001?ooool5ool000?ooooo1Ooo0003oooo
o`Koo`000_ooool9ool000Oooooo2Ooo000:ooooo`Ooo`000_ooool5ool000Kooooo1Ooo0004oooo
o`[oo`001Ol00?l8ooooo`Go003o5?ooool6o`00o`Oooooo1Ol00?l6ooooo`Go003o2?ooool5o`00
o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?lRooooo`_o003o5_ooool5o`00o`Co
oooo1Ol00?l00ooo003oooooooooo`0;ooooo`Koo`000oooool6ool000;ooooo1_oo0002ooooo`Wo
o`0000Coooooool00?oo003oo`000oooool9ool000Wooooo2?oo0003ooooo`?oo`001oooool5ool0
00Cooooo2?oo0002ooooo`Go003o2?ooool4o`00oaKooooo1Ol00?l7ooooo`Go003o1_ooool5o`00
o`04ooooool00?oo003oo`00o`Gooooo0ol00?l5ooooo`7o00000Oooool00004o`000?oooooooooo
ooooo`?o003o1oooool3o`00oaGooooo0ol00?l00ooooooo003oo`00o`04o`00o`04ooooool00?oo
003oo`00oaOooooo1Ol00?l4ooooo`Go003o3Oooool6ool000?ooooo3_oo0003ooooo`koo`000_oo
ool9ool00004oooooooo003oo`00ool000Gooooo1ooo000<ooooo`Koo`001Oooool5ool000Kooooo
0ol00?l8ooooo`Go003o1?ooool3o`00oa3ooooo0ol00?l8ooooo`Go003o1_ooool:o`00o`cooooo
0Ol00001ooooo`0000?o0000ooooooooool02_ooool5o`00o`kooooo0ol00?l2ooooo`Go003o00?o
ooooo`00ool00?l00ol00?lKooooo`Go003o1Oooool3o`00o`kooooo2?oo00000oooooooo`00ool0
000:ool000Kooooo0ooo00001Oooooooo`00ool00?oo003ooooo00Goo`000oooool=ool000;ooooo
1ooo000:ooooo`Soo`002?ooool3ool001;ooooo1Ol00?l3ooooo`Go003o6_ooool5o`00o`Oooooo
0ol00?l00ooooooo003oo`00o`04o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool02_oo
ool8o`00o`[ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`;ooooo0ol00?lMooooo`?o003o5ooo
oolEool000gooooo1_oo0005ooooo`_oo`0000?oooooool00?oo00001Ooo000:ooooo`Woo`003?oo
ool3o`00o`kooooo1Ol00?l3ooooo`So003o5oooool5o`00o`_ooooo1_l00?l;ooooo`7o00000Ooo
ool00003o`000?oooooooooo00[ooooo2Ol00?l6ooooo`So003o00?oooooo`00ool00?l00ol00?lA
ooooo`?o003o:Oooool8ool00003oooooooo003oo`0000Woo`003Oooool5ool000Kooooo2ooo0000
0oooooooo`00ool00003ool000Wooooo3?oo000;ooooo`Go003o3_ooool3o`00o`Cooooo2Ol00?lG
ooooo`?o003o3Oooool5o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l00?l8oooo
o`Wo003o1Oooool>o`00oa7ooooo1Ol00?lYooooo`Ooo`0000?oooooool00?oo00002?oo0006oooo
o`?oo`001Oooool5ool000Oooooo2Ooo0002ooooo`Goo`002?ooool<ool000cooooo1Ol00?l@oooo
o`Co003o0_ooool8o`00o`04ooooool00?oo003oo`00obCooooo1_l00?l9ooooo`7o00000Oooool0
0003o`000?l00?oo003o00?o003o2?ooool8o`00o`Gooooo2?l00?l00ooooooo003oo`00o`03o`00
o`Wooooo0ol00?l5ooooo`Go003o:?ooool@ool000;ooooo0ooo00000oooooooo`00ool00005ool0
00Gooooo0ooo000:ooooo`Koo`001?ooool3ool000Wooooo2?oo000@ooooo`Go003o3oooool6o`00
o`Cooooo2_l00?l8ooooo`?o003o6_ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000o`00ool0
0?l00ol00?l<ooooo`Go003o1?ooool5o`00o`Cooooo1Ol00?l8ooooo`Go003o1?ooool5o`00o`co
oooo0ol00?lHoooooakoo`004Oooool6ool0017ooooo1Ooo0009ooooo`?o003o2?ooool3o`00oa3o
oooo1_l00?l5ooooo`?o003o00?oooooo`00ool00?l00ol00?l7ooooo`Go003o6Oooool5o`00o`So
oooo0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?l<ooooo`Go003o1Oooool3o`00o`Gooooo
1Ol00?l8ooooo`Go003o1Oooool3o`00o`cooooo1Ol00?l01?oooooo003oo`00ool00?lCoooooako
o`004?ooool6ool001;ooooo1Ooo0008ooooo`Go003o6_ooool6o`00o`Wooooo1Ol00?l7ooooo`Go
003o2Oooool3o`00o`[ooooo2?l00?l01?oooooo003oo`00ool00?l4ooooo`7o00000Oooool00003
o`000?oooooo003o00;o003o3Oooool5o`00o`Gooooo0ol00?l5ooooo`Go003o2?ooool5o`00o`04
ooooool00?oo003oo`00o`kooooo3?l00?l8ooooo`?o003o1ooooolMool0013ooooo1ooo000Boooo
o`Goo`001_ooool7o`00oa[ooooo1Ol00?l6ooooo`?o003o0_ooool3o`00o`Sooooo1Ol00?l2oooo
o`?o003o0oooool5o`00o`Sooooo2?l00?l00ooooooo003oo`00o`03o`00o`?ooooo0Ol00001oooo
o`0000?o0000ooooooooool04?ooool3o`00o`Gooooo1Ol00?l3ooooo`Go003o1oooool<o`00o`Go
oooo0ol00?l4ooooo`go003o1oooool5o`00o`Oooooo6_oo000Booooo`Koo`005?ooool2ool000?o
003o1?ooool8o`00oa_ooooo0ol00?l6ooooo`Go003o3Oooool3o`00o`;ooooo1Ol00?l2ooooo`Go
003o2?ooool5o`00o`Cooooo1Ol00?l3ooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo
1Ol00?l3ooooo`Go003o1_ooool=o`00o`Cooooo1Ol00?l3ooooo`Oo003o00?oooooo`00ool00?l0
0ol00?l7ooooo`Go003o2?ooool;ool00003oooooooo003oo`0000Ooo`005_ooool7ool000;ooooo
0ooo0002ooooo`?oo`002_ooool5o`00o`?ooooo1ol00?lUooooo`Go003o4?ooool7o`00o`;ooooo
1_l00?l7ooooo`Go003o1?ooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool04ooo
ool3o`00o`03ooooool00?oo003o00Co003o0oooool5o`00o`Kooooo3Ol00?l4ooooo`Go003o0ooo
ool5o`00o`Cooooo0ol00?l8ooooo`Go003o2oooool5ool000Gooooo0ooo00001Oooooooo`00ool0
0?oo003ooooo00?oo`004ooooolBool000Wooooo1Ol00?l3ooooo`Go003o1?ooool3o`00ob3ooooo
1Ol00?l7ooooo`?o003o1Oooool8o`00o`?ooooo1_l00?l6ooooo`Go003o1Oooool5o`00o`;ooooo
0Ol00001ooooo`0000?o0000ooooooooool04_ooool:o`00o`05ooooool00?oo003oo`00ooooool0
0ol00?l7ooooo`Oo003o0_ooool3o`00o`Gooooo1Ol00?l4ooooo`?o003o2_ooool3o`00o`?ooooo
1_l00?l:ooooo`?o003o00?oo`00ooooooooool02oooool5ool001;ooooo4_oo0009ooooo`Go003o
1?ooool3o`00o`Cooooo1Ol00?lPooooo`?o003o1oooool8o`00o`03ooooool00?oo003o00Go003o
1Oooool5o`00o`Kooooo1Ol00?l01?oooooo003oo`00ool00?l2ooooo`Go003o0Oooool1o`00007o
oooo00000ol0003oooooooooo`0Booooo`Wo003o00?oooooo`00ool00?l00ol00?l;ooooo`?o003o
3_ooool3o`00oa7ooooo1Ol00?l2ooooo`Oo003o2?ooool5o`00o`gooooo1Ooo000Boooooa;oo`00
2_ooool3o`00o`cooooo1Ol00?lEooooo`?o003o0oooool3o`00o`cooooo3_l00?l7ooooo`Go003o
1_ooool:o`00o`03ooooool00?oo003o00?o003o0Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Booooo`Wo003o00?oooooo`00ool00?l00ol00?l]oooooa7o003o2?ooool5o`00o`gooooo0_oo
0003o`00oa?ooooo3?oo00001?ooooooo`00ool00?oo000:ooooo`Go003o2oooool5o`00oaCooooo
2ol00?l;ooooo`Wo003o00Coooooo`00ool00?oo003o2Oooool3o`00o`Cooooo0ol00?l01Ooooooo
003oo`00ool00?oooooo00Go003o00?oooooo`00ool00?l00ol00?l1ooooo`7o00000Oooool00003
o`000?oooooooooo01?ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`Go003o7Oooool3o`00
o`cooooo4_l00?l8ooooo`Go003o0_ooool3o`00o`Wooooo1Ol00?lEooooo`Woo`000_ooool3o`00
o`Wooooo1_l00?l;ooooo`?o003o2_ooool3o`00o`Sooooo2ol00?l<ooooo`So003o4Oooool7o`00
o`Cooooo1Ol00?l2ooooo`?o003o0_ooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`Go
003o0_ooool3o`00oagooooo1Ol00?l;ooooo`go003o00Goooooo`00ool00?oo003oooooo`03o`00
o`Gooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Sooooo1Ol00?lEooooo`Soo`000_ooool5o`00
o`Sooooo1ol00?lFooooo`Go003o1oooool;o`00oa3ooooo0ol00?lAooooo`So003o0oooool5o`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool5o`00o`cooooo0ol00?l8ooooo`?o
003o2?ooool5o`00o`_ooooo3Ol00?l4ooooo`Go003o1?ooool5o`00o`03ooooool00?oo003o00?o
003o2?ooool5o`00oaGooooo1Ooo0005ooooo`Go003o2Oooool6o`00oaKooooo1Ol00?l4ooooo`?o
003o00?oooooo`00ool00?l01ol00?lUooooo`So003o0oooool6o`00o`Oooooo0Ol00001ooooo`00
00?o0000ooooooooool03_ooool3o`00o`Gooooo1Ol00?l;ooooo`So003o0oooool5o`00o`Oooooo
1Ol00?l<ooooo`_o003o1Oooool5o`00o`Gooooo0ol00?l2ooooo`Go003o2Oooool3o`00oaOooooo
0ooo0006ooooo`Go003o0_ooool7o`00o`03ooooool00?oo003o00?o003o5_ooool5o`00o`?ooooo
1Ol00?l00ooooooo003oo`00o`04o`00obOooooo1ol00?l4ooooo`Oo003o1_ooool1o`00007ooooo
00000ol0003oooooooooo`0=ooooo`Go003o00Goooooo`00ool00?oo003oooooo`03o`00o`cooooo
2Ol00?l2ooooo`Go003o2?ooool3o`00oa3ooooo1Ol00?l8ooooo`Go003o1Oooool3o`00o`?ooooo
0ol00?lYooooo`?o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`07o`00o`04oooo
ool00?oo003oo`00oaSooooo0ol00?l4ooooo`go003o9oooool3o`00o`Sooooo1_l00?l6ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo2_l00?l<ooooo`co003o0_ooool5o`00oa_ooooo
1Ol00?l9ooooo`Go003o0oooool5o`00o`_ooooo0ol00?lOooooo`[o003o00?oooooo`00ool00?l0
1ol00?lAooooo`?o003o3oooool=o`00oagooooo0ol00?lCooooo`Go003o1_ooool1o`00007ooooo
00000ol0003oooooooooo`0=ooooo`[o003o2oooool=o`00o`?ooooo0ol00?lGooooo`?o003o0ooo
ool3o`00o`_ooooo1Ol00?l2ooooo`Go003o2_ooool5o`00oakooooo2_l00?l00ooooooo003oo`00
o`08o`00o`oooooo1Ol00?l?ooooo`co003o7?ooool5o`00oa?ooooo0ol00?l7ooooo`7o00000Ooo
ool00003o`000?oooooooooo00kooooo0ol00?l00ooooooo003oo`00o`03o`00o`_ooooo1Ol00?l4
ooooo`?o003o2_ooool3o`00o`Kooooo0ol00?l7ooooo`So003o00Coooooo`00ool00?oo003o2Ooo
ool5o`00o`;ooooo1Ol00?l:ooooo`Go003o2oooool3o`00oa3ooooo2Ol00?l3ooooo`[o003o3_oo
ool5o`00oa;ooooo2?l00?l4ooooo`?o003o5_ooool5o`00oagooooo0Ol00001ooooo`0000?o0000
ooooooooool04oooool3o`00o`cooooo1Ol00?l@ooooo`Go003o1?ooool5o`00o`Kooooo3Ol00?l8
ooooo`Go003o0oooool5o`00o`Wooooo1Ol00?l8ooooo`Oo003o3oooool9o`00o`Oooooo1_l00?l>
ooooo`Go003o4oooool3o`00o`Oooooo1Ol00?lEooooo`Go003o4_ooool3o`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool05_ooool3o`00o`[ooooo0ol00?lAooooo`Go003o1?ooool5o`00
o`Kooooo3Ol00?l3ooooo`?o003o0_ooool4o`00o`Gooooo1Ol00?l9ooooo`?o003o2?ooool8o`00
o`oooooo2Ol00?l7ooooo`Wo003o3?ooool3o`00o`Wooooo0ol00?lBooooo`Go003o2?ooool3o`00
o`_ooooo0ol00?lBooooo`Go003o1oooool1o`00007ooooo00000ol0003oooooooooo`0Eooooo`Go
003o7Oooool5o`00o`Cooooo1Ol00?l6ooooo`go003o0_ooool:o`00o`Gooooo1Ol00?lDooooo`So
003o1_ooool3o`00o`Kooooo2?l00?l9ooooo`Wo003o5_ooool5o`00oa7ooooo1ol00?l5ooooo`Go
003o7_ooool6o`00o`Oooooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool5o`00oa_ooooo
1_l00?l6ooooo`Go003o1Oooool=o`00o`03ooooool00?oo003o00Wo003o1Oooool5o`00oaCooooo
1ol00?l6ooooo`Go003o1_ooool3o`00o`gooooo0ol00?l00ooooooo003oo`00o`03o`00oaKooooo
1Ol00?lBooooo`[o003o00?oooooo`00ool00?l00ol00?lNooooo`Ko003o1oooool1o`00007ooooo
00000ol0003oooooooooo`0Aooooo`?o003o00?oooooo`00ool00?l00ol00?lJooooo`Go003o1?oo
ool9o`00o`Kooooo0ol00?l2ooooo`Ko003o0_ooool;o`00o`Kooooo1?l00?lEooooo`?o003o1?oo
ool3o`00o`;ooooo1Ol00?l3ooooo`Go003o1?ooool3o`00o`Kooooo2_l00?l4ooooo`?o003o3ooo
ool5o`00o`Oooooo0ol00?l:ooooo`ko003o7_ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool04?ooool5o`00o`04ooooool00?oo003oo`00oa_ooooo1Ol00?l3ooooo`[o003o3?oo
ool3o`00o`Cooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Kooooo1Ol00?lFooooo`?o003o00?o
ooooo`00ool00?l00ol00?l00ooooooo003oo`00o`03o`00o`;ooooo1ol00?l2ooooo`Go003o1Ooo
ool5o`00o`04ooooool00?oo003oo`00o`Cooooo1Ol00?l?ooooo`?o003o1oooool5o`00o`Wooooo
2Ol00?l01?oooooo003oo`00ool00?l4ooooo`?o003o6Oooool3o`00o`Wooooo0Ol00001ooooo`00
00?o0000ooooooooool04?ooool5o`00oaSooooo0ol00?l4ooooo`Go003o0oooool9o`00oaGooooo
2_l00?l6ooooo`Go003o5Oooool:o`00o`;ooooo0ol00?l3ooooo`Oo003o0_ooool5o`00o`Gooooo
1Ol00?l5ooooo`So003o6Oooool5o`00o`Gooooo0ol00?l2ooooo`So003o1oooool5o`00o`Kooooo
0ol00?lCooooo`?o003o1Oooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`Go003o5ooo
ool5o`00o`Cooooo0ol00?l4ooooo`So003o5oooool9o`00o`Kooooo1Ol00?lEooooo`co003o1Ooo
ool8o`00o`;ooooo1_l00?l5ooooo`?o003o1Oooool9o`00oaWooooo1Ol00?l4ooooo`Go003o1Ooo
ool3o`00o`Oooooo1_l00?l5ooooo`Go003o4Oooool5o`00o`Cooooo0Ol00001ooooo`0000?o0000
ooooooooool04?ooool5o`00oaOooooo1Ol00?l<ooooo`?o003o6oooool8o`00o`Sooooo0ol00?lF
ooooo`go003o0oooool8o`00o`03ooooool00?oo003o00Ko003o3Oooool8o`00o`oooooo0ol00?l2
ooooo`Go003o0_ooool3o`00o`;ooooo2?l00?l>ooooo`Oo003o1Oooool5o`00oa7ooooo1ol00?l2
ooooo`7o00000Oooool00003o`000?oooooooooo013ooooo1Ol00?lGooooo`Go003o8_ooool3o`00
o`Gooooo1Ol00?lDooooo`?o003o3_ooool3o`00o`03ooooool00?oo003o00Ko003o0oooool5o`00
o`?ooooo2Ol00?l<ooooo`Ko003o4Oooool<o`00o`Gooooo2Ol00?l>ooooo`Ko003o1_ooool5o`00
oa7ooooo2?l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo013ooooo1Ol00?l8ooooo`?o
003o3Oooool3o`00ob;ooooo1Ol00?l5ooooo`?o003o2_ooool3o`00o`Oooooo1Ol00?l@ooooo`Wo
003o0oooool5o`00o`?ooooo2?l00?l<ooooo`Ko003o4_ooool<o`00o`Gooooo2?l00?l?ooooo`Ko
003o1oooool3o`00o`Sooooo0ol00?l5ooooo`[o003o0Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Aooooo`?o003o2?ooool5o`00oc7ooooo1Ol00?l00ooooooo003oo`00o`02o`00o`cooooo
1Ol00?l6ooooo`Go003o4?ooool8o`00o`Gooooo1?l00?l3ooooo`Go003o3oooool6o`00oa;ooooo
3?l00?l5ooooo`Go003o4?ooool7o`00oa;ooooo1Ol00?l3ooooo`Go003o00?oooooo`00ool00?l0
0ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo1ol00?l]ooooo`?o003o00?o
ooooo`00ool00?l02Ol00?l9ooooo`Oo003o1_ooool6o`00o`oooooo1Ol00?l7ooooo`Ko003o0ooo
ool3o`00oa3ooooo1_l00?lCooooo`?o003o0_ooool5o`00o`Oooooo0ol00?l3ooooo`?o003o1Ooo
ool3o`00o`;ooooo1Ol00?lEooooo`Go003o0oooool5o`00o`;ooooo0ol00?l2ooooo`7o00000Ooo
ool00003o`000?oooooooooo00[ooooo0ol00?l<ooooo`So003o1_ooool3o`00o`[ooooo0ol00?lF
oooooa3o003o1oooool9o`00o`Oooooo1_l00?l?ooooo`?o003o1oooool7o`00oaOooooo1?l00?l3
ooooo`?o003o9?ooool5o`00o`?ooooo1Ol00?l00ooooooo003oo`00o`03o`00oa?ooooo1ol00?l3
ooooo`Go003o0_ooool3o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool5o`00
o`_ooooo2_l00?l3ooooo`Go003o2?ooool5o`00oaGooooo4?l00?l6ooooo`Wo003o2?ooool6o`00
oaGooooo0ol00?l00ooooooo003oo`00o`06o`00o`Gooooo1_l00?l@ooooo`Ko003o8oooool6o`00
o`;ooooo1Ol00?l00ooooooo003oo`00o`04o`00oa7ooooo1ol00?l5ooooo`?o003o0_ooool5o`00
o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool5o`00o`_ooooo1Ol00?l00ooooooo
003oo`00o`03o`00o`;ooooo1Ol00?l8ooooo`Go003o4_ooool=o`00o`03ooooool00?oo003o00;o
003o1oooool7o`00o`_ooooo1Ol00?lDooooo`go003o1?ooool8o`00o`kooooo1ol00?lDooooo`?o
003o2oooool7o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`04o`00oa7ooooo1Ol00?l<ooooo`Go
003o0Oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`Go003o2oooool5o`00o`03oooo
ool00?oo003o00?o003o0_ooool5o`00o`04ooooool00?oo003oo`00o`Cooooo1Ol00?lAooooo`go
003o3Oooool6o`00o`?ooooo0ol00?l7ooooo`?o003o5Oooool=o`00o`Cooooo2?l00?l>ooooo`Oo
003o0_ooool3o`00o`kooooo1Ol00?l8ooooo`Wo003o0_ooool<o`00o`Cooooo0ol00?l:ooooo`Go
003o3?ooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool3o`00o`cooooo
1Ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l0
0ol00?l4ooooo`?o003o4_ooool5o`00o`;ooooo1Ol00?l?ooooo`Ko003o00?oooooo`00ool00?l0
1Ol00?lLooooo`So003o00Coooooo`00ool00?oo003o1Oooool8o`00o`kooooo1ol00?l00ooooooo
003oo`00o`03o`00o`gooooo1Ol00?l7ooooo`Wo003o1?ooool:o`00o`Cooooo1Ol00?l:ooooo`?o
003o2oooool7o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool5o`00o`;ooooo
0ol00?l00ooooooo003oo`00o`03o`00o`;ooooo1Ol00?lDooooo`?o003o0_ooool5o`00o`;ooooo
1Ol00?l=ooooo`So003o00?oooooo`00ool00?l01_l00?lLooooo`Oo003o2_ooool6o`00oa3ooooo
1Ol00?l2ooooo`Go003o3Oooool6o`00o`Kooooo1ol00?l8ooooo`So003o1?ooool5o`00oaOooooo
1ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo0ol00?l9ooooo`?o003o1Ooo
ool3o`00o`Oooooo1Ol00?l2ooooo`Go003o2_ooool3o`00o`Kooooo1Ol00?l2ooooo`?o003o1?oo
ool3o`00o`gooooo2Ol00?l00ooooooo003oo`00o`06o`00oakooooo1Ol00?lPooooo`Ko003o00?o
ooooo`00ool00?l00ol00?l>ooooo`Go003o1_ooool5o`00o`[ooooo2Ol00?l3ooooo`Go003o1_oo
ool3o`00o`kooooo1Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1Ol00?l7
ooooo`Go003o3_ooool5o`00o`?ooooo0ol00?l:ooooo`Go003o0oooool7o`00o`04ooooool00?oo
003oo`00oaGooooo2?l00?l3ooooo`Oo003o7oooool3o`00ob7ooooo1ol00?l01?oooooo003oo`00
ool00?l?ooooo`Go003o1oooool3o`00o`cooooo2?l00?l00ooooooo003oo`00o`05o`00o`Gooooo
1Ol00?l=ooooo`Go003o1?ooool1o`00007ooooo00001?l0003o003oo`00ool00?l4ooooo`Go003o
1oooool5o`00o`oooooo0ol00?lAooooo`Go003o0_ooool=o`00o`[ooooo0ol00?l7ooooo`Go003o
2Oooool3o`00ocSooooo0ol00?l9ooooo`Oo003o5?ooool3o`00oa[ooooo3Ol00?l5ooooo`Go003o
3_ooool3o`00o`Gooooo0Ol00001ooooo`001Ol00?l3ooooo`Go003o1oooool5o`00ob?ooooo1Ol0
0?l2ooooo`Oo003o00?oooooo`00ool00?l00ol00?l9ooooo`Go003o1oooool3o`00odCooooo1Ol0
0?l9ooooo`Ko003o3oooool3o`00ob3ooooo0ol00?l00ooooooo003oo`00o`05o`00o`Kooooo2?l0
0?lCooooo`7o00000Oooool000Go003o1?ooool3o`00o`Wooooo0ol00?lTooooo`Go003o0_ooool5
o`00o`?ooooo1Ol00?l9ooooo`Go003o0oooool3o`00od;ooooo0ol00?l3ooooo`Go003o2?ooool6
o`00o`?ooooo0ol00?l9ooooo`Go003o8oooool5o`00o`?ooooo0ol00?l3ooooo`So003o4_ooool1
o`00007ooooo0005o`00o`gooooo0ol00?lWooooo`Go003o0_ooool5o`00o`Cooooo0ol00?l:oooo
o`Go003o00?oooooo`00ool00?l01?l00?lEooooo`?o003o:?ooool5o`00o`;ooooo1Ol00?l7oooo
o`Go003o1?ooool5o`00o`Sooooo1Ol00?lTooooo`?o003o0oooool5o`00o`Gooooo1Ol00?lBoooo
o`7o00000Oooool00004o`000?l00?oo003oo`00o`gooooo1Ol00?lRooooo`?o003o00?oooooo`00
ool00?l00ol00?l2ooooo`Go003o4_ooool3o`00o`03ooooool00?oo003o00Go003o1oooool3o`00
o`[ooooo2?l00?lTooooo`Go003o0_ooool5o`00o`Oooooo1Ol00?l4ooooo`Go003o2?ooool5o`00
o`Kooooo0ol00?lQooooo`Ko003o1?ooool5o`00oa;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool03_ooool5o`00o`Kooooo0ol00?lHooooo`Go003o00Coooooo`00ool00?oo003o1?ooool3o`00
oaOooooo1ol00?l6ooooo`Go003o2Oooool9o`00oa?ooooo0ol00?l=ooooo`Go003o0_ooool5o`00
o`Oooooo1Ol00?l3ooooo`Ko003o1?ooool3o`00o`;ooooo0ol00?l6ooooo`Oo003o6Oooool3o`00
o`;ooooo1_l00?l5ooooo`?o003o4oooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`Oo
003o1Oooool5o`00oaOooooo1Ol00?lRooooo`Ko003o1oooool5o`00o`Wooooo2Ol00?lBooooo`Go
003o3Oooool3o`00o`Cooooo0ol00?l9ooooo`?o003o1?ooool5o`00o`Cooooo1Ol00?l:ooooo`So
003o5oooool5o`00o`;ooooo1Ol00?lKooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo
1ol00?l6ooooo`Go003o00Coooooo`00ool00?oo003o4oooool5o`00ob?ooooo1?l00?l8ooooo`Go
003o1oooool<o`00oa7ooooo1Ol00?lBooooo`?o003o3?ooool3o`00o`?ooooo1Ol00?l00ooooooo
003oo`00o`06o`00o`[ooooo2?l00?lGooooo`Go003o0oooool3o`00oacooooo0Ol00001ooooo`00
00?o0000ooooooooool02oooool5o`00o`;ooooo0ol00?l3ooooo`[o003o1Oooool3o`00o`_ooooo
0ol00?lTooooo`Go003o2?ooool3o`00o`Oooooo1Ol00?l3ooooo`Go003o1_ooool3o`00o`Oooooo
2?l00?l?ooooo`Go003o2_ooool5o`00o`03ooooool00?oo003o00go003o1?ooool3o`00o`Cooooo
1ol00?lGooooo`Go003o0oooool3o`00oacooooo0Ol00001ooooo`0000?o0000ooooooooool02ooo
ool5o`00o`03ooooool00?oo003o00?o003o0oooool9o`00o`?ooooo1_l00?l;ooooo`?o003o8ooo
ool5o`00o`Oooooo1Ol00?l6ooooo`Go003o0oooool5o`00o`Gooooo1Ol00?l6ooooo`Wo003o3_oo
ool5o`00o`[ooooo1Ol00?l00ooooooo003oo`00o`0<o`00o`Cooooo1Ol00?l6ooooo`?o003o6Ooo
ool3o`00o`?ooooo1Ol00?lKooooo`7o00000Oooool00003o`000?oooooooooo00cooooo0ol00?l2
ooooo`Go003o1?ooool8o`00o`;ooooo1ol00?l:ooooo`Go003o00Coooooo`00ool00?oo003o7_oo
ool5o`00o`Oooooo1Ol00?l6ooooo`Go003o1?ooool3o`00o`Gooooo1ol00?l5ooooo`Wo003o00Co
ooooo`00ool00?oo003o2_ooool5o`00o`[ooooo1Ol00?l00ooooooo003oo`00o`0:o`00o`Kooooo
1Ol00?lXooooo`Go003o6oooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`Go003o1?oo
ool7o`00o`?ooooo1ol00?l:ooooo`[o003o7_ooool3o`00o`Sooooo1Ol00?l7ooooo`?o003o3?oo
ool8o`00o`Kooooo3Ol00?l:ooooo`?o003o3?ooool3o`00o`?ooooo3Ol00?l4ooooo`Go003o:?oo
ool5o`00oa_ooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool3o`00o`Kooooo0ol00?l6
ooooo`Ko003o2oooool;o`00o`Kooooo0ol00?lPooooo`?o003o5oooool8o`00o`[ooooo0ol00?l0
0ooooooo003oo`00o`03o`00ob7ooooo0ol00?l2ooooo`Oo003o1?ooool3o`00o`?ooooo0ol00?lT
ooooo`?o003o5_ooool3o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool08Oooool3o`00
o`04ooooool00?oo003oo`00o`kooooo0ol00?l00ooooooo003oo`00o`04o`00o`Gooooo1Ol00?li
ooooo`Oo003o3oooool5o`00obKooooo1ol00?l3ooooo`Go003o00?oooooo`00ool00?l00ol00?ld
ooooo`?o003o1?ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool5o`00
oaKooooo1Ol00?l5ooooo`Go003o>_ooool3o`00oa?ooooo0ol00?lXooooo`Ko003o0oooool5o`00
o`03ooooool00?oo003o00?o003o<oooool5o`00o`?ooooo1Ol00?l2ooooo`7o00000Oooool00003
o`000?oooooooooo023ooooo1Ol00?lGooooo`?o003o1_ooool5o`00oggooooo0ol00?l4ooooo`Go
003o00?oooooo`00ool00?l00ol00?lcooooo`Go003o0oooool5o`00o`;ooooo0Ol00001ooooo`00
00?o0000ooooooooool08?ooool5o`00ob7ooooo0ol00?n6ooooo`?o003o0oooool3o`00ocCooooo
1Ol00?l4ooooo`?o003o0oooool1o`00007ooooo000To`0000?o003ojOl00003o`00o`co00000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #1: red class, scalar covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 7;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes scalar covariances", "Subsubsection"],

Cell[BoxData[
    \(\(initScalar\  = \ EMInitializationScalar[data1, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initScalar, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.28999999999999204`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.55769 .13084 m
.57692 .12342 L
.59615 .11857 L
.61538 .11605 L
.63462 .11565 L
.65385 .11718 L
.67308 .12044 L
.69231 .12514 L
.71154 .13089 L
.7231 .13462 L
.73077 .13752 L
.75 .14532 L
.76923 .15347 L
.77012 .15385 L
.78846 .16336 L
.80585 .17308 L
.80769 .17427 L
.82692 .18798 L
.83241 .19231 L
.84615 .20505 L
.85218 .21154 L
.86538 .22821 L
.86702 .23077 L
.87768 .25 L
.88462 .26655 L
.88537 .26923 L
.88967 .28846 L
.89157 .30769 L
.89094 .32692 L
.8878 .34615 L
.88462 .35862 L
.88186 .36538 L
.87235 .38462 L
.86538 .39582 L
.85918 .40385 L
.84615 .41794 L
.84052 .42308 L
.82692 .43338 L
.8129 .44231 L
.80769 .44485 L
.78846 .45313 L
.76923 .45945 L
.76143 .46154 L
.75 .46331 L
.73077 .46537 L
.71154 .46605 L
.69231 .46536 L
.67308 .46344 L
.65992 .46154 L
.65385 .46017 L
.63462 .45518 L
.61538 .44923 L
.59615 .4429 L
.59519 .44231 L
.57692 .43626 L
.55769 .43166 L
.53846 .43301 L
.52417 .44231 L
.51923 .44785 L
.50928 .46154 L
.5 .47808 L
.49837 .48077 L
.48644 .5 L
.48077 .50868 L
.47302 .51923 L
.46154 .53343 L
.45702 .53846 L
.44231 .55323 L
.43738 .55769 L
.42308 .56924 L
.4124 .57692 L
.40385 .58226 L
.38462 .5928 L
.37755 .59615 L
.36538 .60086 L
.34615 .60685 L
.32692 .61088 L
.30769 .61289 L
.28846 .61283 L
.26923 .61065 L
.25 .6063 L
.23077 .59972 L
.22237 .59615 L
.21154 .59045 L
.19231 .5781 L
.1907 .57692 L
.17308 .56174 L
.16903 .55769 L
.15385 .54004 L
.15267 .53846 L
.14001 .51923 L
.13462 .50959 L
.13008 .5 L
.12235 .48077 L
.11642 .46154 L
.11538 .45767 L
.11248 .44231 L
.11012 .42308 L
.10931 .40385 L
.11009 .38462 L
.11249 .36538 L
.11538 .35067 L
.11668 .34615 L
.1231 .32692 L
.13166 .30769 L
.13462 .30203 L
.14308 .28846 L
.15385 .27401 L
.15798 .26923 L
.17308 .25417 L
.17794 .25 L
.19231 .23937 L
.20628 .23077 L
.21154 .22807 L
.23077 .21969 L
.25 .2135 L
.25743 .21154 L
.26923 .20953 L
.28846 .20745 L
.30769 .207 L
.32692 .20808 L
.34615 .21052 L
.35243 .21154 L
.36538 .2143 L
.38462 .219 L
.40385 .22377 L
.42308 .22728 L
.44231 .22691 L
.46154 .21785 L
.4692 .21154 L
.48077 .19771 L
.48527 .19231 L
.5 .1747 L
.50149 .17308 L
.51923 .15573 L
.52145 .15385 L
.53846 .1414 L
.54994 .13462 L
F
0 g
.55769 .13084 m
.57692 .12342 L
.59615 .11857 L
.61538 .11605 L
.63462 .11565 L
.65385 .11718 L
.67308 .12044 L
.69231 .12514 L
.71154 .13089 L
.7231 .13462 L
.73077 .13752 L
.75 .14532 L
.76923 .15347 L
.77012 .15385 L
.78846 .16336 L
.80585 .17308 L
.80769 .17427 L
.82692 .18798 L
.83241 .19231 L
.84615 .20505 L
.85218 .21154 L
.86538 .22821 L
.86702 .23077 L
.87768 .25 L
.88462 .26655 L
.88537 .26923 L
.88967 .28846 L
.89157 .30769 L
.89094 .32692 L
.8878 .34615 L
.88462 .35862 L
.88186 .36538 L
.87235 .38462 L
.86538 .39582 L
.85918 .40385 L
.84615 .41794 L
.84052 .42308 L
.82692 .43338 L
.8129 .44231 L
.80769 .44485 L
.78846 .45313 L
.76923 .45945 L
.76143 .46154 L
.75 .46331 L
.73077 .46537 L
.71154 .46605 L
.69231 .46536 L
.67308 .46344 L
.65992 .46154 L
.65385 .46017 L
Mistroke
.63462 .45518 L
.61538 .44923 L
.59615 .4429 L
.59519 .44231 L
.57692 .43626 L
.55769 .43166 L
.53846 .43301 L
.52417 .44231 L
.51923 .44785 L
.50928 .46154 L
.5 .47808 L
.49837 .48077 L
.48644 .5 L
.48077 .50868 L
.47302 .51923 L
.46154 .53343 L
.45702 .53846 L
.44231 .55323 L
.43738 .55769 L
.42308 .56924 L
.4124 .57692 L
.40385 .58226 L
.38462 .5928 L
.37755 .59615 L
.36538 .60086 L
.34615 .60685 L
.32692 .61088 L
.30769 .61289 L
.28846 .61283 L
.26923 .61065 L
.25 .6063 L
.23077 .59972 L
.22237 .59615 L
.21154 .59045 L
.19231 .5781 L
.1907 .57692 L
.17308 .56174 L
.16903 .55769 L
.15385 .54004 L
.15267 .53846 L
.14001 .51923 L
.13462 .50959 L
.13008 .5 L
.12235 .48077 L
.11642 .46154 L
.11538 .45767 L
.11248 .44231 L
.11012 .42308 L
.10931 .40385 L
.11009 .38462 L
Mistroke
.11249 .36538 L
.11538 .35067 L
.11668 .34615 L
.1231 .32692 L
.13166 .30769 L
.13462 .30203 L
.14308 .28846 L
.15385 .27401 L
.15798 .26923 L
.17308 .25417 L
.17794 .25 L
.19231 .23937 L
.20628 .23077 L
.21154 .22807 L
.23077 .21969 L
.25 .2135 L
.25743 .21154 L
.26923 .20953 L
.28846 .20745 L
.30769 .207 L
.32692 .20808 L
.34615 .21052 L
.35243 .21154 L
.36538 .2143 L
.38462 .219 L
.40385 .22377 L
.42308 .22728 L
.44231 .22691 L
.46154 .21785 L
.4692 .21154 L
.48077 .19771 L
.48527 .19231 L
.5 .1747 L
.50149 .17308 L
.51923 .15573 L
.52145 .15385 L
.53846 .1414 L
.54994 .13462 L
.55769 .13084 L
Mfstroke
.2 g
.26923 .24875 m
.28846 .24588 L
.30769 .24516 L
.32692 .24645 L
.34615 .24966 L
.34777 .25 L
.36538 .2549 L
.38462 .262 L
.40056 .26923 L
.40385 .27088 L
.42308 .28165 L
.43293 .28846 L
.44231 .2942 L
.45929 .30769 L
.46154 .309 L
.47835 .32692 L
.48077 .32859 L
.48482 .34615 L
.48482 .36538 L
.48193 .38462 L
.48077 .3964 L
.47926 .40385 L
.47449 .42308 L
.46829 .44231 L
.46154 .45897 L
.46029 .46154 L
.44972 .48077 L
.44231 .49202 L
.43626 .5 L
.42308 .515 L
.41883 .51923 L
.40385 .53226 L
.39554 .53846 L
.38462 .5455 L
.36538 .55559 L
.3607 .55769 L
.34615 .56279 L
.32692 .56746 L
.30769 .56969 L
.28846 .56942 L
.26923 .56658 L
.25 .561 L
.24158 .55769 L
.23077 .55223 L
.21154 .53961 L
.21007 .53846 L
.19231 .5218 L
.19003 .51923 L
.17567 .5 L
.17308 .49584 L
.16514 .48077 L
.15741 .46154 L
.15385 .45 L
.15213 .44231 L
.14907 .42308 L
.14802 .40385 L
.149 .38462 L
.15212 .36538 L
.15385 .35785 L
.15766 .34615 L
.16601 .32692 L
.17308 .31451 L
.17774 .30769 L
.19231 .29039 L
.19424 .28846 L
.21154 .27396 L
.2185 .26923 L
.23077 .26232 L
.25 .25412 L
.26329 .25 L
F
0 g
.26923 .24875 m
.28846 .24588 L
.30769 .24516 L
.32692 .24645 L
.34615 .24966 L
.34777 .25 L
.36538 .2549 L
.38462 .262 L
.40056 .26923 L
.40385 .27088 L
.42308 .28165 L
.43293 .28846 L
.44231 .2942 L
.45929 .30769 L
.46154 .309 L
.47835 .32692 L
.48077 .32859 L
.48482 .34615 L
.48482 .36538 L
.48193 .38462 L
.48077 .3964 L
.47926 .40385 L
.47449 .42308 L
.46829 .44231 L
.46154 .45897 L
.46029 .46154 L
.44972 .48077 L
.44231 .49202 L
.43626 .5 L
.42308 .515 L
.41883 .51923 L
.40385 .53226 L
.39554 .53846 L
.38462 .5455 L
.36538 .55559 L
.3607 .55769 L
.34615 .56279 L
.32692 .56746 L
.30769 .56969 L
.28846 .56942 L
.26923 .56658 L
.25 .561 L
.24158 .55769 L
.23077 .55223 L
.21154 .53961 L
.21007 .53846 L
.19231 .5218 L
.19003 .51923 L
.17567 .5 L
.17308 .49584 L
Mistroke
.16514 .48077 L
.15741 .46154 L
.15385 .45 L
.15213 .44231 L
.14907 .42308 L
.14802 .40385 L
.149 .38462 L
.15212 .36538 L
.15385 .35785 L
.15766 .34615 L
.16601 .32692 L
.17308 .31451 L
.17774 .30769 L
.19231 .29039 L
.19424 .28846 L
.21154 .27396 L
.2185 .26923 L
.23077 .26232 L
.25 .25412 L
.26329 .25 L
.26923 .24875 L
Mfstroke
.3 g
.25 .28107 m
.26923 .27436 L
.28846 .27068 L
.30769 .26967 L
.32692 .27115 L
.34615 .27508 L
.36538 .28152 L
.38047 .28846 L
.38462 .29074 L
.40385 .30349 L
.40895 .30769 L
.42308 .32153 L
.42734 .32692 L
.43925 .34615 L
.44231 .35234 L
.44599 .36538 L
.44892 .38462 L
.44872 .40385 L
.44575 .42308 L
.44231 .43676 L
.44004 .44231 L
.43131 .46154 L
.42308 .47529 L
.41916 .48077 L
.40385 .49863 L
.40247 .5 L
.38462 .51513 L
.37878 .51923 L
.36538 .52709 L
.34615 .53554 L
.3384 .53846 L
.32692 .54084 L
.30769 .54321 L
.28846 .5427 L
.26923 .53915 L
.2665 .53846 L
.25 .53214 L
.23077 .52103 L
.22826 .51923 L
.21154 .50433 L
.20763 .5 L
.19375 .48077 L
.19231 .47836 L
.18414 .46154 L
.17768 .44231 L
.17393 .42308 L
.17308 .41453 L
.17269 .40385 L
.17308 .39315 L
.17394 .38462 L
.17783 .36538 L
.18471 .34615 L
.19231 .33146 L
.19523 .32692 L
.21093 .30769 L
.21154 .30709 L
.23077 .29148 L
.23549 .28846 L
F
0 g
.25 .28107 m
.26923 .27436 L
.28846 .27068 L
.30769 .26967 L
.32692 .27115 L
.34615 .27508 L
.36538 .28152 L
.38047 .28846 L
.38462 .29074 L
.40385 .30349 L
.40895 .30769 L
.42308 .32153 L
.42734 .32692 L
.43925 .34615 L
.44231 .35234 L
.44599 .36538 L
.44892 .38462 L
.44872 .40385 L
.44575 .42308 L
.44231 .43676 L
.44004 .44231 L
.43131 .46154 L
.42308 .47529 L
.41916 .48077 L
.40385 .49863 L
.40247 .5 L
.38462 .51513 L
.37878 .51923 L
.36538 .52709 L
.34615 .53554 L
.3384 .53846 L
.32692 .54084 L
.30769 .54321 L
.28846 .5427 L
.26923 .53915 L
.2665 .53846 L
.25 .53214 L
.23077 .52103 L
.22826 .51923 L
.21154 .50433 L
.20763 .5 L
.19375 .48077 L
.19231 .47836 L
.18414 .46154 L
.17768 .44231 L
.17393 .42308 L
.17308 .41453 L
.17269 .40385 L
.17308 .39315 L
.17394 .38462 L
Mistroke
.17783 .36538 L
.18471 .34615 L
.19231 .33146 L
.19523 .32692 L
.21093 .30769 L
.21154 .30709 L
.23077 .29148 L
.23549 .28846 L
.25 .28107 L
Mfstroke
.4 g
.25 .30377 m
.26923 .29544 L
.28846 .29092 L
.30769 .28961 L
.32692 .29126 L
.34615 .29589 L
.36538 .30377 L
.37265 .30769 L
.38462 .31571 L
.39741 .32692 L
.40385 .33395 L
.41243 .34615 L
.42146 .36538 L
.42308 .3706 L
.42589 .38462 L
.42656 .40385 L
.42384 .42308 L
.42308 .42698 L
.41767 .44231 L
.40772 .46154 L
.40385 .46741 L
.39302 .48077 L
.38462 .48912 L
.37102 .5 L
.36538 .50367 L
.34615 .51349 L
.32853 .51923 L
.32692 .51952 L
.30769 .52208 L
.28846 .52126 L
.27762 .51923 L
.26923 .51683 L
.25 .50816 L
.2378 .5 L
.23077 .49395 L
.21866 .48077 L
.21154 .47065 L
.20645 .46154 L
.1986 .44231 L
.19415 .42308 L
.19272 .40385 L
.19426 .38462 L
.19898 .36538 L
.20746 .34615 L
.21154 .33931 L
.22103 .32692 L
.23077 .31722 L
.24333 .30769 L
F
0 g
.25 .30377 m
.26923 .29544 L
.28846 .29092 L
.30769 .28961 L
.32692 .29126 L
.34615 .29589 L
.36538 .30377 L
.37265 .30769 L
.38462 .31571 L
.39741 .32692 L
.40385 .33395 L
.41243 .34615 L
.42146 .36538 L
.42308 .3706 L
.42589 .38462 L
.42656 .40385 L
.42384 .42308 L
.42308 .42698 L
.41767 .44231 L
.40772 .46154 L
.40385 .46741 L
.39302 .48077 L
.38462 .48912 L
.37102 .5 L
.36538 .50367 L
.34615 .51349 L
.32853 .51923 L
.32692 .51952 L
.30769 .52208 L
.28846 .52126 L
.27762 .51923 L
.26923 .51683 L
.25 .50816 L
.2378 .5 L
.23077 .49395 L
.21866 .48077 L
.21154 .47065 L
.20645 .46154 L
.1986 .44231 L
.19415 .42308 L
.19272 .40385 L
.19426 .38462 L
.19898 .36538 L
.20746 .34615 L
.21154 .33931 L
.22103 .32692 L
.23077 .31722 L
.24333 .30769 L
.25 .30377 L
s
.5 g
.30769 .3076 m
.31127 .30769 L
.32692 .30948 L
.34615 .31503 L
.36538 .32494 L
.36833 .32692 L
.38462 .34127 L
.38867 .34615 L
.40018 .36538 L
.40385 .37558 L
.40596 .38462 L
.40724 .40385 L
.40444 .42308 L
.40385 .42602 L
.39746 .44231 L
.38554 .46154 L
.38462 .46273 L
.36647 .48077 L
.36538 .4816 L
.34615 .49343 L
.32875 .5 L
.32692 .50036 L
.30769 .50317 L
.28846 .50198 L
.27964 .5 L
.26923 .49642 L
.25 .48542 L
.24422 .48077 L
.23077 .46602 L
.22769 .46154 L
.21783 .44231 L
.21246 .42308 L
.21154 .4168 L
.2108 .40385 L
.21154 .392 L
.21269 .38462 L
.21848 .36538 L
.22928 .34615 L
.23077 .34414 L
.2481 .32692 L
.25 .32554 L
.26923 .3149 L
.28846 .30928 L
.30285 .30769 L
F
0 g
.30769 .3076 m
.31127 .30769 L
.32692 .30948 L
.34615 .31503 L
.36538 .32494 L
.36833 .32692 L
.38462 .34127 L
.38867 .34615 L
.40018 .36538 L
.40385 .37558 L
.40596 .38462 L
.40724 .40385 L
.40444 .42308 L
.40385 .42602 L
.39746 .44231 L
.38554 .46154 L
.38462 .46273 L
.36647 .48077 L
.36538 .4816 L
.34615 .49343 L
.32875 .5 L
.32692 .50036 L
.30769 .50317 L
.28846 .50198 L
.27964 .5 L
.26923 .49642 L
.25 .48542 L
.24422 .48077 L
.23077 .46602 L
.22769 .46154 L
.21783 .44231 L
.21246 .42308 L
.21154 .4168 L
.2108 .40385 L
.21154 .392 L
.21269 .38462 L
.21848 .36538 L
.22928 .34615 L
.23077 .34414 L
.2481 .32692 L
.25 .32554 L
.26923 .3149 L
.28846 .30928 L
.30285 .30769 L
.30769 .3076 L
s
.6 g
.30769 .32518 m
.32456 .32692 L
.32692 .32743 L
.34615 .33433 L
.36363 .34615 L
.36538 .34774 L
.37928 .36538 L
.38462 .37721 L
.38681 .38462 L
.38872 .40385 L
.38562 .42308 L
.38462 .42741 L
.37731 .44231 L
.36538 .45816 L
.36199 .46154 L
.34615 .47338 L
.33077 .48077 L
.32692 .48167 L
.30769 .48486 L
.28846 .48313 L
.28025 .48077 L
.26923 .47595 L
.25063 .46154 L
.25 .46085 L
.23721 .44231 L
.23077 .42505 L
.23048 .42308 L
.22844 .40385 L
.23077 .38494 L
.23085 .38462 L
.23823 .36538 L
.25 .34914 L
.253 .34615 L
.26923 .33458 L
.28846 .32738 L
.29059 .32692 L
F
0 g
.30769 .32518 m
.32456 .32692 L
.32692 .32743 L
.34615 .33433 L
.36363 .34615 L
.36538 .34774 L
.37928 .36538 L
.38462 .37721 L
.38681 .38462 L
.38872 .40385 L
.38562 .42308 L
.38462 .42741 L
.37731 .44231 L
.36538 .45816 L
.36199 .46154 L
.34615 .47338 L
.33077 .48077 L
.32692 .48167 L
.30769 .48486 L
.28846 .48313 L
.28025 .48077 L
.26923 .47595 L
.25063 .46154 L
.25 .46085 L
.23721 .44231 L
.23077 .42505 L
.23048 .42308 L
.22844 .40385 L
.23077 .38494 L
.23085 .38462 L
.23823 .36538 L
.25 .34914 L
.253 .34615 L
.26923 .33458 L
.28846 .32738 L
.29059 .32692 L
.30769 .32518 L
s
.7 g
.30769 .34387 m
.32462 .34615 L
.32692 .34677 L
.34615 .35626 L
.35585 .36538 L
.36538 .38186 L
.3664 .38462 L
.36928 .40385 L
.36551 .42308 L
.36538 .42354 L
.35462 .44231 L
.34615 .45077 L
.32734 .46154 L
.32692 .46165 L
.30769 .46554 L
.28846 .46292 L
.28466 .46154 L
.26923 .45283 L
.25919 .44231 L
.25 .42327 L
.24994 .42308 L
.24718 .40385 L
.25 .38617 L
.25046 .38462 L
.26086 .36538 L
.26923 .35711 L
.28846 .34692 L
.29121 .34615 L
F
0 g
.30769 .34387 m
.32462 .34615 L
.32692 .34677 L
.34615 .35626 L
.35585 .36538 L
.36538 .38186 L
.3664 .38462 L
.36928 .40385 L
.36551 .42308 L
.36538 .42354 L
.35462 .44231 L
.34615 .45077 L
.32734 .46154 L
.32692 .46165 L
.30769 .46554 L
.28846 .46292 L
.28466 .46154 L
.26923 .45283 L
.25919 .44231 L
.25 .42327 L
.24994 .42308 L
.24718 .40385 L
.25 .38617 L
.25046 .38462 L
.26086 .36538 L
.26923 .35711 L
.28846 .34692 L
.29121 .34615 L
.30769 .34387 L
s
.8 g
.28846 .36953 m
.30769 .366 L
.32692 .36878 L
.34329 .38462 L
.34591 .40385 L
.3426 .42308 L
.32692 .43898 L
.30769 .44216 L
.28846 .44006 L
.27189 .42308 L
.26962 .40385 L
.27304 .38462 L
F
0 g
.28846 .36953 m
.30769 .366 L
.32692 .36878 L
.34329 .38462 L
.34591 .40385 L
.3426 .42308 L
.32692 .43898 L
.30769 .44216 L
.28846 .44006 L
.27189 .42308 L
.26962 .40385 L
.27304 .38462 L
.28846 .36953 L
s
.2 g
.57692 .17245 m
.59615 .16433 L
.61538 .15945 L
.63462 .15717 L
.65385 .15704 L
.67308 .1587 L
.69231 .16184 L
.71154 .16621 L
.73077 .17159 L
.73562 .17308 L
.75 .17838 L
.76923 .18667 L
.78073 .19231 L
.78846 .19678 L
.80769 .20978 L
.80996 .21154 L
.82692 .22728 L
.83004 .23077 L
.84409 .25 L
.84615 .25341 L
.85339 .26923 L
.8591 .28846 L
.86146 .30769 L
.86052 .32692 L
.85622 .34615 L
.84834 .36538 L
.84615 .36953 L
.83574 .38462 L
.82692 .39454 L
.81663 .40385 L
.80769 .41038 L
.78846 .42142 L
.78497 .42308 L
.76923 .42875 L
.75 .43359 L
.73077 .43627 L
.71154 .43693 L
.69231 .4357 L
.67308 .43266 L
.65385 .4279 L
.63885 .42308 L
.63462 .4214 L
.61538 .41271 L
.5988 .40385 L
.59615 .40229 L
.57692 .38984 L
.57017 .38462 L
.55769 .37575 L
.54626 .36538 L
.53846 .36013 L
.52311 .34615 L
.51923 .34241 L
.5078 .32692 L
.50339 .30769 L
.50536 .28846 L
.50866 .26923 L
.51397 .25 L
.51923 .2357 L
.52173 .23077 L
.53298 .21154 L
.53846 .20414 L
.54934 .19231 L
.55769 .185 L
.57573 .17308 L
F
0 g
.57692 .17245 m
.59615 .16433 L
.61538 .15945 L
.63462 .15717 L
.65385 .15704 L
.67308 .1587 L
.69231 .16184 L
.71154 .16621 L
.73077 .17159 L
.73562 .17308 L
.75 .17838 L
.76923 .18667 L
.78073 .19231 L
.78846 .19678 L
.80769 .20978 L
.80996 .21154 L
.82692 .22728 L
.83004 .23077 L
.84409 .25 L
.84615 .25341 L
.85339 .26923 L
.8591 .28846 L
.86146 .30769 L
.86052 .32692 L
.85622 .34615 L
.84834 .36538 L
.84615 .36953 L
.83574 .38462 L
.82692 .39454 L
.81663 .40385 L
.80769 .41038 L
.78846 .42142 L
.78497 .42308 L
.76923 .42875 L
.75 .43359 L
.73077 .43627 L
.71154 .43693 L
.69231 .4357 L
.67308 .43266 L
.65385 .4279 L
.63885 .42308 L
.63462 .4214 L
.61538 .41271 L
.5988 .40385 L
.59615 .40229 L
.57692 .38984 L
.57017 .38462 L
.55769 .37575 L
.54626 .36538 L
.53846 .36013 L
Mistroke
.52311 .34615 L
.51923 .34241 L
.5078 .32692 L
.50339 .30769 L
.50536 .28846 L
.50866 .26923 L
.51397 .25 L
.51923 .2357 L
.52173 .23077 L
.53298 .21154 L
.53846 .20414 L
.54934 .19231 L
.55769 .185 L
.57573 .17308 L
.57692 .17245 L
Mfstroke
.3 g
.61538 .18784 m
.63462 .18332 L
.65385 .18142 L
.67308 .18161 L
.69231 .18351 L
.71154 .18693 L
.73077 .19174 L
.73275 .19231 L
.75 .19839 L
.76923 .20701 L
.77772 .21154 L
.78846 .21838 L
.80423 .23077 L
.80769 .23402 L
.82154 .25 L
.82692 .25785 L
.83277 .26923 L
.83941 .28846 L
.84208 .30769 L
.84091 .32692 L
.83576 .34615 L
.82692 .36416 L
.82607 .36538 L
.80997 .38462 L
.80769 .3867 L
.78846 .40058 L
.7826 .40385 L
.76923 .40958 L
.75 .41529 L
.73077 .41834 L
.71154 .41904 L
.69231 .41754 L
.67308 .41389 L
.65385 .40811 L
.64289 .40385 L
.63462 .39994 L
.61538 .38901 L
.60887 .38462 L
.59615 .37488 L
.58571 .36538 L
.57692 .35641 L
.5687 .34615 L
.55769 .32967 L
.55637 .32692 L
.54874 .30769 L
.54513 .28846 L
.54552 .26923 L
.5499 .25 L
.55769 .23248 L
.55886 .23077 L
.57441 .21154 L
.57692 .20922 L
.59615 .19589 L
.60338 .19231 L
F
0 g
.61538 .18784 m
.63462 .18332 L
.65385 .18142 L
.67308 .18161 L
.69231 .18351 L
.71154 .18693 L
.73077 .19174 L
.73275 .19231 L
.75 .19839 L
.76923 .20701 L
.77772 .21154 L
.78846 .21838 L
.80423 .23077 L
.80769 .23402 L
.82154 .25 L
.82692 .25785 L
.83277 .26923 L
.83941 .28846 L
.84208 .30769 L
.84091 .32692 L
.83576 .34615 L
.82692 .36416 L
.82607 .36538 L
.80997 .38462 L
.80769 .3867 L
.78846 .40058 L
.7826 .40385 L
.76923 .40958 L
.75 .41529 L
.73077 .41834 L
.71154 .41904 L
.69231 .41754 L
.67308 .41389 L
.65385 .40811 L
.64289 .40385 L
.63462 .39994 L
.61538 .38901 L
.60887 .38462 L
.59615 .37488 L
.58571 .36538 L
.57692 .35641 L
.5687 .34615 L
.55769 .32967 L
.55637 .32692 L
.54874 .30769 L
.54513 .28846 L
.54552 .26923 L
.5499 .25 L
.55769 .23248 L
.55886 .23077 L
Mistroke
.57441 .21154 L
.57692 .20922 L
.59615 .19589 L
.60338 .19231 L
.61538 .18784 L
Mfstroke
.4 g
.61538 .21151 m
.63462 .20412 L
.65385 .20027 L
.67308 .19902 L
.69231 .1999 L
.71154 .20265 L
.73077 .20724 L
.74425 .21154 L
.75 .21387 L
.76923 .22323 L
.78122 .23077 L
.78846 .23628 L
.80268 .25 L
.80769 .25599 L
.81599 .26923 L
.82366 .28846 L
.82666 .30769 L
.82524 .32692 L
.81913 .34615 L
.80769 .36492 L
.8073 .36538 L
.78846 .38314 L
.78638 .38462 L
.76923 .3941 L
.75 .40083 L
.7347 .40385 L
.73077 .40432 L
.71154 .40507 L
.69561 .40385 L
.69231 .40337 L
.67308 .39913 L
.65385 .39226 L
.63832 .38462 L
.63462 .38244 L
.61538 .36876 L
.6115 .36538 L
.59615 .34957 L
.59349 .34615 L
.58115 .32692 L
.57692 .31976 L
.5735 .30769 L
.57017 .28846 L
.57122 .26923 L
.57692 .25062 L
.5772 .25 L
.5899 .23077 L
.59615 .22448 L
.61533 .21154 L
F
0 g
.61538 .21151 m
.63462 .20412 L
.65385 .20027 L
.67308 .19902 L
.69231 .1999 L
.71154 .20265 L
.73077 .20724 L
.74425 .21154 L
.75 .21387 L
.76923 .22323 L
.78122 .23077 L
.78846 .23628 L
.80268 .25 L
.80769 .25599 L
.81599 .26923 L
.82366 .28846 L
.82666 .30769 L
.82524 .32692 L
.81913 .34615 L
.80769 .36492 L
.8073 .36538 L
.78846 .38314 L
.78638 .38462 L
.76923 .3941 L
.75 .40083 L
.7347 .40385 L
.73077 .40432 L
.71154 .40507 L
.69561 .40385 L
.69231 .40337 L
.67308 .39913 L
.65385 .39226 L
.63832 .38462 L
.63462 .38244 L
.61538 .36876 L
.6115 .36538 L
.59615 .34957 L
.59349 .34615 L
.58115 .32692 L
.57692 .31976 L
.5735 .30769 L
.57017 .28846 L
.57122 .26923 L
.57692 .25062 L
.5772 .25 L
.5899 .23077 L
.59615 .22448 L
.61533 .21154 L
.61538 .21151 L
s
.5 g
.63462 .2228 m
.65385 .2166 L
.67308 .21385 L
.69231 .21374 L
.71154 .21592 L
.73077 .22038 L
.75 .22737 L
.75733 .23077 L
.76923 .23769 L
.78501 .25 L
.78846 .25329 L
.80089 .26923 L
.80769 .28112 L
.80971 .28846 L
.81304 .30769 L
.81133 .32692 L
.80769 .33855 L
.80412 .34615 L
.78948 .36538 L
.78846 .36637 L
.76923 .38014 L
.76025 .38462 L
.75 .38803 L
.73077 .39204 L
.71154 .39293 L
.69231 .39097 L
.67308 .38616 L
.66846 .38462 L
.65385 .37815 L
.63462 .36618 L
.63356 .36538 L
.61538 .3485 L
.61342 .34615 L
.60051 .32692 L
.59615 .32116 L
.59295 .30769 L
.59024 .28846 L
.59259 .26923 L
.59615 .25618 L
.60125 .25 L
.61538 .23433 L
.62022 .23077 L
F
0 g
.63462 .2228 m
.65385 .2166 L
.67308 .21385 L
.69231 .21374 L
.71154 .21592 L
.73077 .22038 L
.75 .22737 L
.75733 .23077 L
.76923 .23769 L
.78501 .25 L
.78846 .25329 L
.80089 .26923 L
.80769 .28112 L
.80971 .28846 L
.81304 .30769 L
.81133 .32692 L
.80769 .33855 L
.80412 .34615 L
.78948 .36538 L
.78846 .36637 L
.76923 .38014 L
.76025 .38462 L
.75 .38803 L
.73077 .39204 L
.71154 .39293 L
.69231 .39097 L
.67308 .38616 L
.66846 .38462 L
.65385 .37815 L
.63462 .36618 L
.63356 .36538 L
.61538 .3485 L
.61342 .34615 L
.60051 .32692 L
.59615 .32116 L
.59295 .30769 L
.59024 .28846 L
.59259 .26923 L
.59615 .25618 L
.60125 .25 L
.61538 .23433 L
.62022 .23077 L
.63462 .2228 L
s
.6 g
.67308 .22748 m
.69231 .22634 L
.71154 .228 L
.72832 .23077 L
.73077 .23237 L
.75 .23989 L
.76685 .25 L
.76923 .25178 L
.78632 .26923 L
.78846 .27117 L
.7966 .28846 L
.80037 .30769 L
.79827 .32692 L
.78953 .34615 L
.78846 .34782 L
.77064 .36538 L
.76923 .36635 L
.75 .37603 L
.73077 .38076 L
.71154 .38182 L
.69231 .37959 L
.67308 .37399 L
.65533 .36538 L
.65385 .36447 L
.63462 .3495 L
.63142 .34615 L
.61741 .32692 L
.61538 .32295 L
.60984 .30769 L
.60786 .28846 L
.61194 .26923 L
.61538 .26062 L
.62443 .25 L
.63462 .24137 L
.65385 .23198 L
.6555 .23077 L
F
0 g
.67308 .22748 m
.69231 .22634 L
.71154 .228 L
.72832 .23077 L
.73077 .23237 L
.75 .23989 L
.76685 .25 L
.76923 .25178 L
.78632 .26923 L
.78846 .27117 L
.7966 .28846 L
.80037 .30769 L
.79827 .32692 L
.78953 .34615 L
.78846 .34782 L
.77064 .36538 L
.76923 .36635 L
.75 .37603 L
.73077 .38076 L
.71154 .38182 L
.69231 .37959 L
.67308 .37399 L
.65533 .36538 L
.65385 .36447 L
.63462 .3495 L
.63142 .34615 L
.61741 .32692 L
.61538 .32295 L
.60984 .30769 L
.60786 .28846 L
.61194 .26923 L
.61538 .26062 L
.62443 .25 L
.63462 .24137 L
.65385 .23198 L
.6555 .23077 L
.67308 .22748 L
s
.7 g
.65385 .24768 m
.67308 .24069 L
.69231 .23836 L
.71154 .2395 L
.73077 .24398 L
.74603 .25 L
.75 .25233 L
.76923 .26696 L
.7713 .26923 L
.78363 .28846 L
.78791 .30769 L
.7853 .32692 L
.77441 .34615 L
.76923 .35171 L
.75 .36397 L
.74634 .36538 L
.73077 .36968 L
.71154 .371 L
.69231 .36843 L
.6799 .36538 L
.67308 .36193 L
.65385 .35019 L
.64914 .34615 L
.63462 .32934 L
.6333 .32692 L
.62549 .30769 L
.62433 .28846 L
.63071 .26923 L
.63462 .26269 L
.64972 .25 L
F
0 g
.65385 .24768 m
.67308 .24069 L
.69231 .23836 L
.71154 .2395 L
.73077 .24398 L
.74603 .25 L
.75 .25233 L
.76923 .26696 L
.7713 .26923 L
.78363 .28846 L
.78791 .30769 L
.7853 .32692 L
.77441 .34615 L
.76923 .35171 L
.75 .36397 L
.74634 .36538 L
.73077 .36968 L
.71154 .371 L
.69231 .36843 L
.6799 .36538 L
.67308 .36193 L
.65385 .35019 L
.64914 .34615 L
.63462 .32934 L
.6333 .32692 L
.62549 .30769 L
.62433 .28846 L
.63071 .26923 L
.63462 .26269 L
.64972 .25 L
.65385 .24768 L
s
.8 g
.65385 .26568 m
.67308 .25435 L
.69231 .25061 L
.71154 .25113 L
.73077 .25568 L
.75 .26574 L
.75453 .26923 L
.76923 .28657 L
.76995 .28846 L
.77509 .30769 L
.77158 .32692 L
.76923 .33158 L
.75714 .34615 L
.75 .351 L
.73077 .35847 L
.71154 .36011 L
.69231 .35714 L
.67308 .34892 L
.66862 .34615 L
.65385 .33383 L
.64925 .32692 L
.64086 .30769 L
.64071 .28846 L
.65061 .26923 L
F
0 g
.65385 .26568 m
.67308 .25435 L
.69231 .25061 L
.71154 .25113 L
.73077 .25568 L
.75 .26574 L
.75453 .26923 L
.76923 .28657 L
.76995 .28846 L
.77509 .30769 L
.77158 .32692 L
.76923 .33158 L
.75714 .34615 L
.75 .351 L
.73077 .35847 L
.71154 .36011 L
.69231 .35714 L
.67308 .34892 L
.66862 .34615 L
.65385 .33383 L
.64925 .32692 L
.64086 .30769 L
.64071 .28846 L
.65061 .26923 L
.65385 .26568 L
s
.9 g
.69231 .26379 m
.71154 .26352 L
.73077 .26912 L
.73105 .26923 L
.75 .28062 L
.7546 .28846 L
.76112 .30769 L
.75607 .32692 L
.75 .33759 L
.73077 .34585 L
.72786 .34615 L
.71154 .34789 L
.69932 .34615 L
.69231 .34486 L
.67308 .33432 L
.6667 .32692 L
.65705 .30769 L
.65828 .28846 L
.67308 .27126 L
.67658 .26923 L
F
0 g
.69231 .26379 m
.71154 .26352 L
.73077 .26912 L
.73105 .26923 L
.75 .28062 L
.7546 .28846 L
.76112 .30769 L
.75607 .32692 L
.75 .33759 L
.73077 .34585 L
.72786 .34615 L
.71154 .34789 L
.69932 .34615 L
.69231 .34486 L
.67308 .33432 L
.6667 .32692 L
.65705 .30769 L
.65828 .28846 L
.67308 .27126 L
.67658 .26923 L
.69231 .26379 L
s
1 g
.69231 .28164 m
.71154 .27513 L
.73077 .28606 L
.73338 .28846 L
.74558 .30769 L
.73229 .32692 L
.73077 .32842 L
.71154 .33465 L
.69231 .32722 L
.69175 .32692 L
.67435 .30769 L
.68222 .28846 L
F
0 g
.69231 .28164 m
.71154 .27513 L
.73077 .28606 L
.73338 .28846 L
.74558 .30769 L
.73229 .32692 L
.73077 .32842 L
.71154 .33465 L
.69231 .32722 L
.69175 .32692 L
.67435 .30769 L
.68222 .28846 L
.69231 .28164 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.66 .742 .91 r
.39897 .59944 .40507 .60509 .41532 .6021 .40924 .59643 Mtetra
.40924 .59643 .41532 .6021 .4256 .5991 .41955 .59341 Mtetra
.41955 .59341 .4256 .5991 .43593 .59608 .4299 .59037 Mtetra
.4299 .59037 .43593 .59608 .44629 .59305 .44029 .58733 Mtetra
.661 .742 .91 r
.44029 .58733 .44629 .59305 .4567 .59001 .45072 .58426 Mtetra
.45072 .58426 .4567 .59001 .46715 .58696 .46119 .58119 Mtetra
.46119 .58119 .46715 .58696 .47763 .58389 .4717 .5781 Mtetra
.4717 .5781 .47763 .58389 .48816 .58081 .48225 .575 Mtetra
.48225 .575 .48816 .58081 .49873 .57771 .49285 .57188 Mtetra
.49285 .57188 .49873 .57771 .50934 .57459 .50349 .56874 Mtetra
.661 .743 .91 r
.50349 .56874 .50934 .57459 .51999 .57146 .51417 .56559 Mtetra
.51417 .56559 .51999 .57146 .53068 .56831 .52489 .56242 Mtetra
.52489 .56242 .53068 .56831 .54142 .56515 .53565 .55923 Mtetra
.662 .743 .91 r
.53565 .55923 .54142 .56515 .5522 .56197 .54646 .55603 Mtetra
.54646 .55603 .5522 .56197 .56302 .55877 .5573 .55281 Mtetra
.5573 .55281 .56302 .55877 .57388 .55555 .5682 .54956 Mtetra
.5682 .54956 .57388 .55555 .58479 .55231 .57913 .5463 Mtetra
.663 .743 .91 r
.57913 .5463 .58479 .55231 .59574 .54905 .59011 .54302 Mtetra
.59011 .54302 .59574 .54905 .60673 .54577 .60113 .53972 Mtetra
.60113 .53972 .60673 .54577 .61776 .54248 .61219 .5364 Mtetra
.61219 .5364 .61776 .54248 .62884 .53916 .6233 .53306 Mtetra
.663 .744 .91 r
.6233 .53306 .62884 .53916 .63997 .53582 .63446 .5297 Mtetra
.664 .744 .91 r
.63446 .5297 .63997 .53582 .65113 .53247 .64565 .52632 Mtetra
.664 .744 .909 r
.64565 .52632 .65113 .53247 .66234 .52909 .65689 .52291 Mtetra
.65689 .52291 .66234 .52909 .6736 .52569 .66818 .51949 Mtetra
.66818 .51949 .6736 .52569 .6849 .52228 .67951 .51605 Mtetra
.665 .744 .909 r
.67951 .51605 .6849 .52228 .69624 .51884 .69089 .51259 Mtetra
.69089 .51259 .69624 .51884 .70763 .51538 .70231 .5091 Mtetra
.70231 .5091 .70763 .51538 .71907 .51191 .71378 .5056 Mtetra
.71378 .5056 .71907 .51191 .73055 .50841 .72529 .50208 Mtetra
.72529 .50208 .73055 .50841 .74207 .5049 .73685 .49854 Mtetra
.73685 .49854 .74207 .5049 .75364 .50137 .74845 .49498 Mtetra
.666 .744 .909 r
.74845 .49498 .75364 .50137 .76526 .49782 .7601 .4914 Mtetra
.7601 .4914 .76526 .49782 .77693 .49425 .7718 .4878 Mtetra
.666 .744 .908 r
.7718 .4878 .77693 .49425 .78864 .49066 .78355 .48419 Mtetra
.78355 .48419 .78864 .49066 .8004 .48706 .79534 .48056 Mtetra
.79534 .48056 .8004 .48706 .8122 .48344 .80718 .47691 Mtetra
.80718 .47691 .8122 .48344 .82406 .4798 .81907 .47324 Mtetra
.81907 .47324 .82406 .4798 .83596 .47615 .831 .46956 Mtetra
.831 .46956 .83596 .47615 .84791 .47249 .84299 .46587 Mtetra
.84299 .46587 .84791 .47249 .85991 .4688 .85502 .46216 Mtetra
.85502 .46216 .85991 .4688 .87195 .46511 .86711 .45843 Mtetra
.86711 .45843 .87195 .46511 .88405 .46139 .87924 .45469 Mtetra
.666 .743 .908 r
.87924 .45469 .88405 .46139 .8962 .45767 .89142 .45093 Mtetra
.89142 .45093 .8962 .45767 .90839 .45393 .90366 .44716 Mtetra
.90366 .44716 .90839 .45393 .92064 .45018 .91594 .44338 Mtetra
.91594 .44338 .92064 .45018 .93294 .44641 .92828 .43958 Mtetra
.92828 .43958 .93294 .44641 .94529 .44263 .94066 .43577 Mtetra
.94066 .43577 .94529 .44263 .95769 .43884 .9531 .43195 Mtetra
.9531 .43195 .95769 .43884 .97014 .43503 .96559 .42811 Mtetra
.66 .742 .91 r
.39282 .59375 .39897 .59944 .40924 .59643 .40311 .59072 Mtetra
.40311 .59072 .40924 .59643 .41955 .59341 .41345 .58768 Mtetra
.41345 .58768 .41955 .59341 .4299 .59037 .42382 .58462 Mtetra
.42382 .58462 .4299 .59037 .44029 .58733 .43424 .58155 Mtetra
.43424 .58155 .44029 .58733 .45072 .58426 .44469 .57847 Mtetra
.661 .742 .91 r
.44469 .57847 .45072 .58426 .46119 .58119 .45519 .57538 Mtetra
.45519 .57538 .46119 .58119 .4717 .5781 .46573 .57227 Mtetra
.46573 .57227 .4717 .5781 .48225 .575 .47631 .56914 Mtetra
.47631 .56914 .48225 .575 .49285 .57188 .48693 .566 Mtetra
.48693 .566 .49285 .57188 .50349 .56874 .49759 .56284 Mtetra
.49759 .56284 .50349 .56874 .51417 .56559 .5083 .55967 Mtetra
.5083 .55967 .51417 .56559 .52489 .56242 .51905 .55648 Mtetra
.661 .743 .91 r
.51905 .55648 .52489 .56242 .53565 .55923 .52984 .55327 Mtetra
.662 .743 .91 r
.52984 .55327 .53565 .55923 .54646 .55603 .54067 .55004 Mtetra
.54067 .55004 .54646 .55603 .5573 .55281 .55155 .5468 Mtetra
.55155 .5468 .5573 .55281 .5682 .54956 .56247 .54353 Mtetra
.56247 .54353 .5682 .54956 .57913 .5463 .57343 .54025 Mtetra
.663 .743 .91 r
.57343 .54025 .57913 .5463 .59011 .54302 .58444 .53694 Mtetra
.58444 .53694 .59011 .54302 .60113 .53972 .59549 .53362 Mtetra
.59549 .53362 .60113 .53972 .61219 .5364 .60658 .53027 Mtetra
.60658 .53027 .61219 .5364 .6233 .53306 .61772 .52691 Mtetra
.61772 .52691 .6233 .53306 .63446 .5297 .6289 .52352 Mtetra
.664 .743 .909 r
.6289 .52352 .63446 .5297 .64565 .52632 .64013 .52011 Mtetra
.64013 .52011 .64565 .52632 .65689 .52291 .6514 .51668 Mtetra
.664 .744 .909 r
.6514 .51668 .65689 .52291 .66818 .51949 .66272 .51324 Mtetra
.66272 .51324 .66818 .51949 .67951 .51605 .67408 .50977 Mtetra
.665 .744 .909 r
.67408 .50977 .67951 .51605 .69089 .51259 .68549 .50628 Mtetra
.68549 .50628 .69089 .51259 .70231 .5091 .69695 .50277 Mtetra
.69695 .50277 .70231 .5091 .71378 .5056 .70844 .49924 Mtetra
.70844 .49924 .71378 .5056 .72529 .50208 .71999 .49569 Mtetra
.71999 .49569 .72529 .50208 .73685 .49854 .73158 .49212 Mtetra
.666 .744 .909 r
.73158 .49212 .73685 .49854 .74845 .49498 .74322 .48853 Mtetra
.74322 .48853 .74845 .49498 .7601 .4914 .7549 .48493 Mtetra
.666 .744 .908 r
.7549 .48493 .7601 .4914 .7718 .4878 .76664 .4813 Mtetra
.76664 .4813 .7718 .4878 .78355 .48419 .77841 .47766 Mtetra
.77841 .47766 .78355 .48419 .79534 .48056 .79024 .474 Mtetra
.79024 .474 .79534 .48056 .80718 .47691 .80212 .47032 Mtetra
.80212 .47032 .80718 .47691 .81907 .47324 .81404 .46663 Mtetra
.81404 .46663 .81907 .47324 .831 .46956 .82601 .46292 Mtetra
.82601 .46292 .831 .46956 .84299 .46587 .83803 .45919 Mtetra
.83803 .45919 .84299 .46587 .85502 .46216 .8501 .45545 Mtetra
.8501 .45545 .85502 .46216 .86711 .45843 .86222 .4517 Mtetra
.666 .743 .908 r
.86222 .4517 .86711 .45843 .87924 .45469 .87439 .44793 Mtetra
.87439 .44793 .87924 .45469 .89142 .45093 .88661 .44414 Mtetra
.88661 .44414 .89142 .45093 .90366 .44716 .89888 .44034 Mtetra
.89888 .44034 .90366 .44716 .91594 .44338 .91121 .43653 Mtetra
.91121 .43653 .91594 .44338 .92828 .43958 .92358 .4327 Mtetra
.92358 .4327 .92828 .43958 .94066 .43577 .936 .42886 Mtetra
.936 .42886 .94066 .43577 .9531 .43195 .94848 .425 Mtetra
.94848 .425 .9531 .43195 .96559 .42811 .96101 .42113 Mtetra
.66 .742 .91 r
.38662 .58802 .39282 .59375 .40311 .59072 .39694 .58497 Mtetra
.39694 .58497 .40311 .59072 .41345 .58768 .4073 .5819 Mtetra
.4073 .5819 .41345 .58768 .42382 .58462 .4177 .57883 Mtetra
.4177 .57883 .42382 .58462 .43424 .58155 .42814 .57574 Mtetra
.42814 .57574 .43424 .58155 .44469 .57847 .43862 .57263 Mtetra
.43862 .57263 .44469 .57847 .45519 .57538 .44915 .56952 Mtetra
.661 .742 .91 r
.44915 .56952 .45519 .57538 .46573 .57227 .45971 .56638 Mtetra
.45971 .56638 .46573 .57227 .47631 .56914 .47032 .56324 Mtetra
.47032 .56324 .47631 .56914 .48693 .566 .48097 .56007 Mtetra
.48097 .56007 .48693 .566 .49759 .56284 .49166 .5569 Mtetra
.49166 .5569 .49759 .56284 .5083 .55967 .50239 .5537 Mtetra
.50239 .5537 .5083 .55967 .51905 .55648 .51316 .55049 Mtetra
.51316 .55049 .51905 .55648 .52984 .55327 .52398 .54725 Mtetra
.662 .742 .91 r
.52398 .54725 .52984 .55327 .54067 .55004 .53485 .544 Mtetra
.662 .743 .91 r
.53485 .544 .54067 .55004 .55155 .5468 .54575 .54073 Mtetra
.54575 .54073 .55155 .5468 .56247 .54353 .5567 .53745 Mtetra
.5567 .53745 .56247 .54353 .57343 .54025 .56769 .53414 Mtetra
.663 .743 .91 r
.56769 .53414 .57343 .54025 .58444 .53694 .57873 .53081 Mtetra
.57873 .53081 .58444 .53694 .59549 .53362 .58981 .52746 Mtetra
.58981 .52746 .59549 .53362 .60658 .53027 .60093 .52409 Mtetra
.663 .743 .909 r
.60093 .52409 .60658 .53027 .61772 .52691 .6121 .5207 Mtetra
.6121 .5207 .61772 .52691 .6289 .52352 .62331 .51729 Mtetra
.664 .743 .909 r
.62331 .51729 .6289 .52352 .64013 .52011 .63457 .51386 Mtetra
.63457 .51386 .64013 .52011 .6514 .51668 .64587 .5104 Mtetra
.64587 .5104 .6514 .51668 .66272 .51324 .65722 .50693 Mtetra
.65722 .50693 .66272 .51324 .67408 .50977 .66862 .50343 Mtetra
.665 .743 .909 r
.66862 .50343 .67408 .50977 .68549 .50628 .68006 .49992 Mtetra
.665 .744 .909 r
.68006 .49992 .68549 .50628 .69695 .50277 .69154 .49638 Mtetra
.69154 .49638 .69695 .50277 .70844 .49924 .70307 .49282 Mtetra
.70307 .49282 .70844 .49924 .71999 .49569 .71465 .48925 Mtetra
.71465 .48925 .71999 .49569 .73158 .49212 .72627 .48565 Mtetra
.666 .744 .908 r
.72627 .48565 .73158 .49212 .74322 .48853 .73795 .48204 Mtetra
.73795 .48204 .74322 .48853 .7549 .48493 .74966 .4784 Mtetra
.74966 .4784 .7549 .48493 .76664 .4813 .76143 .47475 Mtetra
.76143 .47475 .76664 .4813 .77841 .47766 .77324 .47108 Mtetra
.77324 .47108 .77841 .47766 .79024 .474 .78511 .46739 Mtetra
.78511 .46739 .79024 .474 .80212 .47032 .79702 .46368 Mtetra
.79702 .46368 .80212 .47032 .81404 .46663 .80897 .45996 Mtetra
.80897 .45996 .81404 .46663 .82601 .46292 .82098 .45622 Mtetra
.82098 .45622 .82601 .46292 .83803 .45919 .83304 .45247 Mtetra
.666 .743 .908 r
.83304 .45247 .83803 .45919 .8501 .45545 .84514 .4487 Mtetra
.84514 .4487 .8501 .45545 .86222 .4517 .8573 .44491 Mtetra
.8573 .44491 .86222 .4517 .87439 .44793 .86951 .44111 Mtetra
.86951 .44111 .87439 .44793 .88661 .44414 .88176 .43729 Mtetra
.88176 .43729 .88661 .44414 .89888 .44034 .89407 .43346 Mtetra
.89407 .43346 .89888 .44034 .91121 .43653 .90643 .42962 Mtetra
.90643 .42962 .91121 .43653 .92358 .4327 .91884 .42576 Mtetra
.91884 .42576 .92358 .4327 .936 .42886 .93131 .42189 Mtetra
.93131 .42189 .936 .42886 .94848 .425 .94382 .418 Mtetra
.94382 .418 .94848 .425 .96101 .42113 .95639 .4141 Mtetra
.66 .741 .91 r
.38038 .58224 .38662 .58802 .39694 .58497 .39073 .57917 Mtetra
.39073 .57917 .39694 .58497 .4073 .5819 .40111 .57608 Mtetra
.66 .742 .91 r
.40111 .57608 .4073 .5819 .4177 .57883 .41154 .57298 Mtetra
.41154 .57298 .4177 .57883 .42814 .57574 .422 .56987 Mtetra
.422 .56987 .42814 .57574 .43862 .57263 .43251 .56675 Mtetra
.43251 .56675 .43862 .57263 .44915 .56952 .44306 .56361 Mtetra
.661 .742 .91 r
.44306 .56361 .44915 .56952 .45971 .56638 .45365 .56046 Mtetra
.45365 .56046 .45971 .56638 .47032 .56324 .46428 .55729 Mtetra
.46428 .55729 .47032 .56324 .48097 .56007 .47496 .5541 Mtetra
.47496 .5541 .48097 .56007 .49166 .5569 .48568 .5509 Mtetra
.48568 .5509 .49166 .5569 .50239 .5537 .49644 .54768 Mtetra
.49644 .54768 .50239 .5537 .51316 .55049 .50724 .54444 Mtetra
.50724 .54444 .51316 .55049 .52398 .54725 .51809 .54119 Mtetra
.662 .742 .91 r
.51809 .54119 .52398 .54725 .53485 .544 .52898 .53792 Mtetra
.52898 .53792 .53485 .544 .54575 .54073 .53991 .53462 Mtetra
.53991 .53462 .54575 .54073 .5567 .53745 .55089 .53131 Mtetra
.662 .743 .91 r
.55089 .53131 .5567 .53745 .56769 .53414 .56191 .52798 Mtetra
.663 .743 .91 r
.56191 .52798 .56769 .53414 .57873 .53081 .57297 .52463 Mtetra
.663 .743 .909 r
.57297 .52463 .57873 .53081 .58981 .52746 .58408 .52125 Mtetra
.58408 .52125 .58981 .52746 .60093 .52409 .59524 .51786 Mtetra
.59524 .51786 .60093 .52409 .6121 .5207 .60643 .51444 Mtetra
.60643 .51444 .6121 .5207 .62331 .51729 .61768 .511 Mtetra
.664 .743 .909 r
.61768 .511 .62331 .51729 .63457 .51386 .62897 .50755 Mtetra
.62897 .50755 .63457 .51386 .64587 .5104 .6403 .50407 Mtetra
.6403 .50407 .64587 .5104 .65722 .50693 .65168 .50057 Mtetra
.65168 .50057 .65722 .50693 .66862 .50343 .66311 .49705 Mtetra
.665 .743 .909 r
.66311 .49705 .66862 .50343 .68006 .49992 .67458 .4935 Mtetra
.67458 .4935 .68006 .49992 .69154 .49638 .6861 .48994 Mtetra
.6861 .48994 .69154 .49638 .70307 .49282 .69766 .48636 Mtetra
.665 .743 .908 r
.69766 .48636 .70307 .49282 .71465 .48925 .70927 .48275 Mtetra
.70927 .48275 .71465 .48925 .72627 .48565 .72093 .47913 Mtetra
.666 .743 .908 r
.72093 .47913 .72627 .48565 .73795 .48204 .73263 .47548 Mtetra
.73263 .47548 .73795 .48204 .74966 .4784 .74439 .47182 Mtetra
.74439 .47182 .74966 .4784 .76143 .47475 .75618 .46814 Mtetra
.75618 .46814 .76143 .47475 .77324 .47108 .76803 .46444 Mtetra
.76803 .46444 .77324 .47108 .78511 .46739 .77993 .46072 Mtetra
.77993 .46072 .78511 .46739 .79702 .46368 .79187 .45699 Mtetra
.79187 .45699 .79702 .46368 .80897 .45996 .80387 .45324 Mtetra
.80387 .45324 .80897 .45996 .82098 .45622 .81591 .44947 Mtetra
.81591 .44947 .82098 .45622 .83304 .45247 .828 .44568 Mtetra
.828 .44568 .83304 .45247 .84514 .4487 .84015 .44188 Mtetra
.84015 .44188 .84514 .4487 .8573 .44491 .85234 .43806 Mtetra
.85234 .43806 .8573 .44491 .86951 .44111 .86458 .43423 Mtetra
.86458 .43423 .86951 .44111 .88176 .43729 .87688 .43039 Mtetra
.87688 .43039 .88176 .43729 .89407 .43346 .88922 .42653 Mtetra
.88922 .42653 .89407 .43346 .90643 .42962 .90162 .42265 Mtetra
.90162 .42265 .90643 .42962 .91884 .42576 .91407 .41876 Mtetra
.91407 .41876 .91884 .42576 .93131 .42189 .92657 .41486 Mtetra
.92657 .41486 .93131 .42189 .94382 .418 .93913 .41094 Mtetra
.93913 .41094 .94382 .418 .95639 .4141 .95174 .40701 Mtetra
.66 .741 .91 r
.3741 .57641 .38038 .58224 .39073 .57917 .38447 .57332 Mtetra
.38447 .57332 .39073 .57917 .40111 .57608 .39488 .57021 Mtetra
.39488 .57021 .40111 .57608 .41154 .57298 .40533 .56709 Mtetra
.40533 .56709 .41154 .57298 .422 .56987 .41582 .56396 Mtetra
.41582 .56396 .422 .56987 .43251 .56675 .42635 .56081 Mtetra
.42635 .56081 .43251 .56675 .44306 .56361 .43693 .55765 Mtetra
.661 .742 .91 r
.43693 .55765 .44306 .56361 .45365 .56046 .44755 .55448 Mtetra
.44755 .55448 .45365 .56046 .46428 .55729 .45821 .55129 Mtetra
.45821 .55129 .46428 .55729 .47496 .5541 .46891 .54808 Mtetra
.46891 .54808 .47496 .5541 .48568 .5509 .47965 .54485 Mtetra
.47965 .54485 .48568 .5509 .49644 .54768 .49044 .54161 Mtetra
.49044 .54161 .49644 .54768 .50724 .54444 .50127 .53835 Mtetra
.50127 .53835 .50724 .54444 .51809 .54119 .51215 .53507 Mtetra
.662 .742 .91 r
.51215 .53507 .51809 .54119 .52898 .53792 .52306 .53178 Mtetra
.52306 .53178 .52898 .53792 .53991 .53462 .53402 .52846 Mtetra
.53402 .52846 .53991 .53462 .55089 .53131 .54503 .52512 Mtetra
.662 .742 .909 r
.54503 .52512 .55089 .53131 .56191 .52798 .55608 .52177 Mtetra
.663 .742 .909 r
.55608 .52177 .56191 .52798 .57297 .52463 .56718 .51839 Mtetra
.56718 .51839 .57297 .52463 .58408 .52125 .57831 .51499 Mtetra
.663 .743 .909 r
.57831 .51499 .58408 .52125 .59524 .51786 .5895 .51157 Mtetra
.5895 .51157 .59524 .51786 .60643 .51444 .60073 .50813 Mtetra
.664 .743 .909 r
.60073 .50813 .60643 .51444 .61768 .511 .612 .50467 Mtetra
.612 .50467 .61768 .511 .62897 .50755 .62332 .50118 Mtetra
.62332 .50118 .62897 .50755 .6403 .50407 .63469 .49768 Mtetra
.63469 .49768 .6403 .50407 .65168 .50057 .6461 .49415 Mtetra
.6461 .49415 .65168 .50057 .66311 .49705 .65756 .4906 Mtetra
.665 .743 .909 r
.65756 .4906 .66311 .49705 .67458 .4935 .66906 .48703 Mtetra
.665 .743 .908 r
.66906 .48703 .67458 .4935 .6861 .48994 .68061 .48344 Mtetra
.68061 .48344 .6861 .48994 .69766 .48636 .69221 .47983 Mtetra
.69221 .47983 .69766 .48636 .70927 .48275 .70385 .4762 Mtetra
.70385 .4762 .70927 .48275 .72093 .47913 .71554 .47255 Mtetra
.666 .743 .908 r
.71554 .47255 .72093 .47913 .73263 .47548 .72728 .46888 Mtetra
.72728 .46888 .73263 .47548 .74439 .47182 .73906 .46519 Mtetra
.73906 .46519 .74439 .47182 .75618 .46814 .7509 .46148 Mtetra
.7509 .46148 .75618 .46814 .76803 .46444 .76278 .45775 Mtetra
.76278 .45775 .76803 .46444 .77993 .46072 .77471 .454 Mtetra
.77471 .454 .77993 .46072 .79187 .45699 .78669 .45024 Mtetra
.78669 .45024 .79187 .45699 .80387 .45324 .79872 .44645 Mtetra
.79872 .44645 .80387 .45324 .81591 .44947 .8108 .44266 Mtetra
.8108 .44266 .81591 .44947 .828 .44568 .82293 .43884 Mtetra
.82293 .43884 .828 .44568 .84015 .44188 .83511 .43501 Mtetra
.83511 .43501 .84015 .44188 .85234 .43806 .84734 .43116 Mtetra
.84734 .43116 .85234 .43806 .86458 .43423 .85962 .4273 Mtetra
.85962 .4273 .86458 .43423 .87688 .43039 .87195 .42342 Mtetra
.87195 .42342 .87688 .43039 .88922 .42653 .88434 .41953 Mtetra
.88434 .41953 .88922 .42653 .90162 .42265 .89677 .41563 Mtetra
.89677 .41563 .90162 .42265 .91407 .41876 .90926 .41171 Mtetra
.90926 .41171 .91407 .41876 .92657 .41486 .9218 .40777 Mtetra
.9218 .40777 .92657 .41486 .93913 .41094 .9344 .40382 Mtetra
.9344 .40382 .93913 .41094 .95174 .40701 .94705 .39986 Mtetra
.66 .741 .91 r
.36778 .57054 .3741 .57641 .38447 .57332 .37817 .56743 Mtetra
.37817 .56743 .38447 .57332 .39488 .57021 .3886 .5643 Mtetra
.3886 .5643 .39488 .57021 .40533 .56709 .39908 .56116 Mtetra
.39908 .56116 .40533 .56709 .41582 .56396 .40959 .558 Mtetra
.40959 .558 .41582 .56396 .42635 .56081 .42015 .55483 Mtetra
.42015 .55483 .42635 .56081 .43693 .55765 .43075 .55165 Mtetra
.43075 .55165 .43693 .55765 .44755 .55448 .4414 .54845 Mtetra
.661 .741 .91 r
.4414 .54845 .44755 .55448 .45821 .55129 .45208 .54524 Mtetra
.45208 .54524 .45821 .55129 .46891 .54808 .46281 .54201 Mtetra
.661 .742 .91 r
.46281 .54201 .46891 .54808 .47965 .54485 .47358 .53876 Mtetra
.47358 .53876 .47965 .54485 .49044 .54161 .4844 .53549 Mtetra
.4844 .53549 .49044 .54161 .50127 .53835 .49526 .53221 Mtetra
.49526 .53221 .50127 .53835 .51215 .53507 .50616 .52891 Mtetra
.662 .742 .91 r
.50616 .52891 .51215 .53507 .52306 .53178 .51711 .52559 Mtetra
.662 .742 .909 r
.51711 .52559 .52306 .53178 .53402 .52846 .5281 .52224 Mtetra
.5281 .52224 .53402 .52846 .54503 .52512 .53913 .51888 Mtetra
.53913 .51888 .54503 .52512 .55608 .52177 .55021 .5155 Mtetra
.663 .742 .909 r
.55021 .5155 .55608 .52177 .56718 .51839 .56134 .5121 Mtetra
.56134 .5121 .56718 .51839 .57831 .51499 .5725 .50868 Mtetra
.5725 .50868 .57831 .51499 .5895 .51157 .58372 .50523 Mtetra
.58372 .50523 .5895 .51157 .60073 .50813 .59498 .50176 Mtetra
.664 .742 .909 r
.59498 .50176 .60073 .50813 .612 .50467 .60628 .49827 Mtetra
.664 .743 .909 r
.60628 .49827 .612 .50467 .62332 .50118 .61763 .49476 Mtetra
.61763 .49476 .62332 .50118 .63469 .49768 .62903 .49123 Mtetra
.62903 .49123 .63469 .49768 .6461 .49415 .64047 .48768 Mtetra
.664 .743 .908 r
.64047 .48768 .6461 .49415 .65756 .4906 .65196 .4841 Mtetra
.665 .743 .908 r
.65196 .4841 .65756 .4906 .66906 .48703 .6635 .48051 Mtetra
.6635 .48051 .66906 .48703 .68061 .48344 .67508 .47689 Mtetra
.67508 .47689 .68061 .48344 .69221 .47983 .68671 .47325 Mtetra
.68671 .47325 .69221 .47983 .70385 .4762 .69839 .46959 Mtetra
.69839 .46959 .70385 .4762 .71554 .47255 .71011 .46591 Mtetra
.666 .743 .908 r
.71011 .46591 .71554 .47255 .72728 .46888 .72188 .46221 Mtetra
.72188 .46221 .72728 .46888 .73906 .46519 .7337 .45849 Mtetra
.7337 .45849 .73906 .46519 .7509 .46148 .74557 .45475 Mtetra
.74557 .45475 .7509 .46148 .76278 .45775 .75749 .45099 Mtetra
.75749 .45099 .76278 .45775 .77471 .454 .76946 .44722 Mtetra
.76946 .44722 .77471 .454 .78669 .45024 .78147 .44343 Mtetra
.78147 .44343 .78669 .45024 .79872 .44645 .79354 .43961 Mtetra
.79354 .43961 .79872 .44645 .8108 .44266 .80565 .43579 Mtetra
.80565 .43579 .8108 .44266 .82293 .43884 .81782 .43194 Mtetra
.81782 .43194 .82293 .43884 .83511 .43501 .83003 .42808 Mtetra
.83003 .42808 .83511 .43501 .84734 .43116 .8423 .4242 Mtetra
.8423 .4242 .84734 .43116 .85962 .4273 .85462 .42031 Mtetra
.85462 .42031 .85962 .4273 .87195 .42342 .86699 .4164 Mtetra
.86699 .4164 .87195 .42342 .88434 .41953 .87941 .41248 Mtetra
.666 .743 .907 r
.87941 .41248 .88434 .41953 .89677 .41563 .89189 .40854 Mtetra
.666 .743 .908 r
.89189 .40854 .89677 .41563 .90926 .41171 .90441 .40459 Mtetra
.90441 .40459 .90926 .41171 .9218 .40777 .91699 .40063 Mtetra
.91699 .40063 .9218 .40777 .9344 .40382 .92963 .39665 Mtetra
.92963 .39665 .9344 .40382 .94705 .39986 .94232 .39265 Mtetra
.66 .741 .91 r
.3614 .56463 .36778 .57054 .37817 .56743 .37182 .56149 Mtetra
.37182 .56149 .37817 .56743 .3886 .5643 .38228 .55834 Mtetra
.38228 .55834 .3886 .5643 .39908 .56116 .39278 .55517 Mtetra
.39278 .55517 .39908 .56116 .40959 .558 .40332 .552 Mtetra
.40332 .552 .40959 .558 .42015 .55483 .41391 .5488 Mtetra
.41391 .5488 .42015 .55483 .43075 .55165 .42453 .5456 Mtetra
.42453 .5456 .43075 .55165 .4414 .54845 .4352 .54237 Mtetra
.661 .741 .91 r
.4352 .54237 .4414 .54845 .45208 .54524 .44592 .53914 Mtetra
.44592 .53914 .45208 .54524 .46281 .54201 .45667 .53588 Mtetra
.45667 .53588 .46281 .54201 .47358 .53876 .46747 .53261 Mtetra
.46747 .53261 .47358 .53876 .4844 .53549 .47831 .52932 Mtetra
.47831 .52932 .4844 .53549 .49526 .53221 .4892 .52601 Mtetra
.661 .742 .909 r
.4892 .52601 .49526 .53221 .50616 .52891 .50013 .52269 Mtetra
.662 .742 .909 r
.50013 .52269 .50616 .52891 .51711 .52559 .51111 .51934 Mtetra
.51111 .51934 .51711 .52559 .5281 .52224 .52213 .51598 Mtetra
.52213 .51598 .5281 .52224 .53913 .51888 .53319 .51259 Mtetra
.53319 .51259 .53913 .51888 .55021 .5155 .5443 .50918 Mtetra
.663 .742 .909 r
.5443 .50918 .55021 .5155 .56134 .5121 .55545 .50575 Mtetra
.55545 .50575 .56134 .5121 .5725 .50868 .56665 .50231 Mtetra
.56665 .50231 .5725 .50868 .58372 .50523 .57789 .49883 Mtetra
.57789 .49883 .58372 .50523 .59498 .50176 .58918 .49534 Mtetra
.664 .742 .909 r
.58918 .49534 .59498 .50176 .60628 .49827 .60052 .49183 Mtetra
.60052 .49183 .60628 .49827 .61763 .49476 .6119 .48829 Mtetra
.664 .742 .908 r
.6119 .48829 .61763 .49476 .62903 .49123 .62333 .48473 Mtetra
.62333 .48473 .62903 .49123 .64047 .48768 .6348 .48115 Mtetra
.665 .743 .908 r
.6348 .48115 .64047 .48768 .65196 .4841 .64633 .47755 Mtetra
.64633 .47755 .65196 .4841 .6635 .48051 .65789 .47392 Mtetra
.65789 .47392 .6635 .48051 .67508 .47689 .66951 .47028 Mtetra
.66951 .47028 .67508 .47689 .68671 .47325 .68117 .46661 Mtetra
.68117 .46661 .68671 .47325 .69839 .46959 .69288 .46292 Mtetra
.666 .743 .908 r
.69288 .46292 .69839 .46959 .71011 .46591 .70464 .45922 Mtetra
.70464 .45922 .71011 .46591 .72188 .46221 .71645 .45549 Mtetra
.71645 .45549 .72188 .46221 .7337 .45849 .7283 .45174 Mtetra
.7283 .45174 .7337 .45849 .74557 .45475 .7402 .44797 Mtetra
.7402 .44797 .74557 .45475 .75749 .45099 .75216 .44419 Mtetra
.75216 .44419 .75749 .45099 .76946 .44722 .76416 .44038 Mtetra
.76416 .44038 .76946 .44722 .78147 .44343 .77621 .43656 Mtetra
.666 .743 .907 r
.77621 .43656 .78147 .44343 .79354 .43961 .78831 .43272 Mtetra
.78831 .43272 .79354 .43961 .80565 .43579 .80046 .42886 Mtetra
.80046 .42886 .80565 .43579 .81782 .43194 .81266 .42498 Mtetra
.81266 .42498 .81782 .43194 .83003 .42808 .82492 .42109 Mtetra
.82492 .42109 .83003 .42808 .8423 .4242 .83722 .41718 Mtetra
.83722 .41718 .8423 .4242 .85462 .42031 .84958 .41326 Mtetra
.84958 .41326 .85462 .42031 .86699 .4164 .86198 .40932 Mtetra
.86198 .40932 .86699 .4164 .87941 .41248 .87445 .40537 Mtetra
.87445 .40537 .87941 .41248 .89189 .40854 .88696 .4014 Mtetra
.88696 .4014 .89189 .40854 .90441 .40459 .89953 .39742 Mtetra
.89953 .39742 .90441 .40459 .91699 .40063 .91215 .39342 Mtetra
.91215 .39342 .91699 .40063 .92963 .39665 .92482 .38941 Mtetra
.92482 .38941 .92963 .39665 .94232 .39265 .93755 .38538 Mtetra
.66 .741 .91 r
.35498 .55866 .3614 .56463 .37182 .56149 .36543 .5555 Mtetra
.36543 .5555 .37182 .56149 .38228 .55834 .37591 .55233 Mtetra
.37591 .55233 .38228 .55834 .39278 .55517 .38644 .54914 Mtetra
.38644 .54914 .39278 .55517 .40332 .552 .39701 .54594 Mtetra
.39701 .54594 .40332 .552 .41391 .5488 .40762 .54272 Mtetra
.40762 .54272 .41391 .5488 .42453 .5456 .41827 .53949 Mtetra
.41827 .53949 .42453 .5456 .4352 .54237 .42897 .53625 Mtetra
.661 .741 .91 r
.42897 .53625 .4352 .54237 .44592 .53914 .43971 .53299 Mtetra
.43971 .53299 .44592 .53914 .45667 .53588 .45049 .52971 Mtetra
.661 .741 .909 r
.45049 .52971 .45667 .53588 .46747 .53261 .46131 .52641 Mtetra
.46131 .52641 .46747 .53261 .47831 .52932 .47218 .5231 Mtetra
.47218 .5231 .47831 .52932 .4892 .52601 .4831 .51977 Mtetra
.4831 .51977 .4892 .52601 .50013 .52269 .49406 .51642 Mtetra
.662 .741 .909 r
.49406 .51642 .50013 .52269 .51111 .51934 .50506 .51305 Mtetra
.50506 .51305 .51111 .51934 .52213 .51598 .51611 .50965 Mtetra
.662 .742 .909 r
.51611 .50965 .52213 .51598 .53319 .51259 .5272 .50624 Mtetra
.5272 .50624 .53319 .51259 .5443 .50918 .53834 .50281 Mtetra
.663 .742 .909 r
.53834 .50281 .5443 .50918 .55545 .50575 .54952 .49936 Mtetra
.54952 .49936 .55545 .50575 .56665 .50231 .56075 .49588 Mtetra
.56075 .49588 .56665 .50231 .57789 .49883 .57203 .49238 Mtetra
.57203 .49238 .57789 .49883 .58918 .49534 .58335 .48886 Mtetra
.664 .742 .908 r
.58335 .48886 .58918 .49534 .60052 .49183 .59471 .48532 Mtetra
.59471 .48532 .60052 .49183 .6119 .48829 .60613 .48176 Mtetra
.60613 .48176 .6119 .48829 .62333 .48473 .61759 .47817 Mtetra
.61759 .47817 .62333 .48473 .6348 .48115 .62909 .47457 Mtetra
.665 .742 .908 r
.62909 .47457 .6348 .48115 .64633 .47755 .64065 .47094 Mtetra
.64065 .47094 .64633 .47755 .65789 .47392 .65225 .46728 Mtetra
.65225 .46728 .65789 .47392 .66951 .47028 .66389 .46361 Mtetra
.665 .743 .908 r
.66389 .46361 .66951 .47028 .68117 .46661 .67559 .45992 Mtetra
.67559 .45992 .68117 .46661 .69288 .46292 .68733 .4562 Mtetra
.666 .743 .908 r
.68733 .4562 .69288 .46292 .70464 .45922 .69913 .45246 Mtetra
.69913 .45246 .70464 .45922 .71645 .45549 .71097 .44871 Mtetra
.71097 .44871 .71645 .45549 .7283 .45174 .72285 .44493 Mtetra
.666 .743 .907 r
.72285 .44493 .7283 .45174 .7402 .44797 .73479 .44113 Mtetra
.73479 .44113 .7402 .44797 .75216 .44419 .74678 .43732 Mtetra
.74678 .43732 .75216 .44419 .76416 .44038 .75882 .43348 Mtetra
.75882 .43348 .76416 .44038 .77621 .43656 .7709 .42963 Mtetra
.7709 .42963 .77621 .43656 .78831 .43272 .78304 .42576 Mtetra
.78304 .42576 .78831 .43272 .80046 .42886 .79523 .42187 Mtetra
.79523 .42187 .80046 .42886 .81266 .42498 .80747 .41797 Mtetra
.80747 .41797 .81266 .42498 .82492 .42109 .81976 .41404 Mtetra
.81976 .41404 .82492 .42109 .83722 .41718 .8321 .41011 Mtetra
.8321 .41011 .83722 .41718 .84958 .41326 .84449 .40615 Mtetra
.84449 .40615 .84958 .41326 .86198 .40932 .85694 .40218 Mtetra
.85694 .40218 .86198 .40932 .87445 .40537 .86944 .3982 Mtetra
.86944 .3982 .87445 .40537 .88696 .4014 .88199 .3942 Mtetra
.88199 .3942 .88696 .4014 .89953 .39742 .8946 .39018 Mtetra
.8946 .39018 .89953 .39742 .91215 .39342 .90726 .38616 Mtetra
.90726 .38616 .91215 .39342 .92482 .38941 .91997 .38211 Mtetra
.91997 .38211 .92482 .38941 .93755 .38538 .93274 .37805 Mtetra
.66 .741 .91 r
.34852 .55265 .35498 .55866 .36543 .5555 .35899 .54947 Mtetra
.35899 .54947 .36543 .5555 .37591 .55233 .3695 .54627 Mtetra
.3695 .54627 .37591 .55233 .38644 .54914 .38005 .54306 Mtetra
.38005 .54306 .38644 .54914 .39701 .54594 .39064 .53983 Mtetra
.39064 .53983 .39701 .54594 .40762 .54272 .40128 .53659 Mtetra
.40128 .53659 .40762 .54272 .41827 .53949 .41196 .53334 Mtetra
.66 .741 .909 r
.41196 .53334 .41827 .53949 .42897 .53625 .42268 .53007 Mtetra
.661 .741 .909 r
.42268 .53007 .42897 .53625 .43971 .53299 .43345 .52679 Mtetra
.43345 .52679 .43971 .53299 .45049 .52971 .44426 .52348 Mtetra
.44426 .52348 .45049 .52971 .46131 .52641 .45511 .52016 Mtetra
.45511 .52016 .46131 .52641 .47218 .5231 .46601 .51683 Mtetra
.46601 .51683 .47218 .5231 .4831 .51977 .47695 .51347 Mtetra
.47695 .51347 .4831 .51977 .49406 .51642 .48794 .51009 Mtetra
.662 .741 .909 r
.48794 .51009 .49406 .51642 .50506 .51305 .49897 .5067 Mtetra
.49897 .5067 .50506 .51305 .51611 .50965 .51005 .50328 Mtetra
.51005 .50328 .51611 .50965 .5272 .50624 .52117 .49984 Mtetra
.52117 .49984 .5272 .50624 .53834 .50281 .53234 .49638 Mtetra
.663 .742 .909 r
.53234 .49638 .53834 .50281 .54952 .49936 .54355 .4929 Mtetra
.54355 .4929 .54952 .49936 .56075 .49588 .55481 .4894 Mtetra
.55481 .4894 .56075 .49588 .57203 .49238 .56611 .48588 Mtetra
.663 .742 .908 r
.56611 .48588 .57203 .49238 .58335 .48886 .57747 .48233 Mtetra
.664 .742 .908 r
.57747 .48233 .58335 .48886 .59471 .48532 .58886 .47876 Mtetra
.58886 .47876 .59471 .48532 .60613 .48176 .60031 .47517 Mtetra
.60031 .47517 .60613 .48176 .61759 .47817 .6118 .47156 Mtetra
.6118 .47156 .61759 .47817 .62909 .47457 .62334 .46792 Mtetra
.665 .742 .908 r
.62334 .46792 .62909 .47457 .64065 .47094 .63492 .46427 Mtetra
.63492 .46427 .64065 .47094 .65225 .46728 .64656 .46059 Mtetra
.64656 .46059 .65225 .46728 .66389 .46361 .65824 .45688 Mtetra
.65824 .45688 .66389 .46361 .67559 .45992 .66997 .45316 Mtetra
.66997 .45316 .67559 .45992 .68733 .4562 .68174 .44942 Mtetra
.666 .742 .907 r
.68174 .44942 .68733 .4562 .69913 .45246 .69357 .44565 Mtetra
.69357 .44565 .69913 .45246 .71097 .44871 .70544 .44187 Mtetra
.70544 .44187 .71097 .44871 .72285 .44493 .71737 .43806 Mtetra
.666 .743 .907 r
.71737 .43806 .72285 .44493 .73479 .44113 .72934 .43423 Mtetra
.72934 .43423 .73479 .44113 .74678 .43732 .74136 .43039 Mtetra
.74136 .43039 .74678 .43732 .75882 .43348 .75344 .42653 Mtetra
.75344 .42653 .75882 .43348 .7709 .42963 .76556 .42264 Mtetra
.76556 .42264 .7709 .42963 .78304 .42576 .77773 .41874 Mtetra
.77773 .41874 .78304 .42576 .79523 .42187 .78996 .41482 Mtetra
.78996 .41482 .79523 .42187 .80747 .41797 .80223 .41089 Mtetra
.80223 .41089 .80747 .41797 .81976 .41404 .81456 .40694 Mtetra
.81456 .40694 .81976 .41404 .8321 .41011 .82694 .40297 Mtetra
.82694 .40297 .8321 .41011 .84449 .40615 .83937 .39898 Mtetra
.83937 .39898 .84449 .40615 .85694 .40218 .85186 .39498 Mtetra
.85186 .39498 .85694 .40218 .86944 .3982 .8644 .39097 Mtetra
.8644 .39097 .86944 .3982 .88199 .3942 .87699 .38694 Mtetra
.87699 .38694 .88199 .3942 .8946 .39018 .88963 .38289 Mtetra
.88963 .38289 .8946 .39018 .90726 .38616 .90233 .37883 Mtetra
.666 .742 .907 r
.90233 .37883 .90726 .38616 .91997 .38211 .91509 .37475 Mtetra
.91509 .37475 .91997 .38211 .93274 .37805 .9279 .37066 Mtetra
.66 .741 .909 r
.34201 .54659 .34852 .55265 .35899 .54947 .3525 .54338 Mtetra
.3525 .54338 .35899 .54947 .3695 .54627 .36304 .54016 Mtetra
.36304 .54016 .3695 .54627 .38005 .54306 .37361 .53693 Mtetra
.37361 .53693 .38005 .54306 .39064 .53983 .38423 .53368 Mtetra
.38423 .53368 .39064 .53983 .40128 .53659 .3949 .53042 Mtetra
.3949 .53042 .40128 .53659 .41196 .53334 .4056 .52714 Mtetra
.4056 .52714 .41196 .53334 .42268 .53007 .41635 .52384 Mtetra
.661 .741 .909 r
.41635 .52384 .42268 .53007 .43345 .52679 .42714 .52054 Mtetra
.42714 .52054 .43345 .52679 .44426 .52348 .43798 .51721 Mtetra
.43798 .51721 .44426 .52348 .45511 .52016 .44886 .51387 Mtetra
.44886 .51387 .45511 .52016 .46601 .51683 .45979 .5105 Mtetra
.45979 .5105 .46601 .51683 .47695 .51347 .47076 .50712 Mtetra
.47076 .50712 .47695 .51347 .48794 .51009 .48177 .50372 Mtetra
.662 .741 .909 r
.48177 .50372 .48794 .51009 .49897 .5067 .49283 .5003 Mtetra
.49283 .5003 .49897 .5067 .51005 .50328 .50394 .49686 Mtetra
.50394 .49686 .51005 .50328 .52117 .49984 .51509 .49339 Mtetra
.51509 .49339 .52117 .49984 .53234 .49638 .52629 .48991 Mtetra
.663 .741 .909 r
.52629 .48991 .53234 .49638 .54355 .4929 .53753 .4864 Mtetra
.663 .742 .909 r
.53753 .4864 .54355 .4929 .55481 .4894 .54882 .48287 Mtetra
.663 .742 .908 r
.54882 .48287 .55481 .4894 .56611 .48588 .56016 .47932 Mtetra
.56016 .47932 .56611 .48588 .57747 .48233 .57154 .47574 Mtetra
.664 .742 .908 r
.57154 .47574 .57747 .48233 .58886 .47876 .58297 .47214 Mtetra
.58297 .47214 .58886 .47876 .60031 .47517 .59444 .46853 Mtetra
.59444 .46853 .60031 .47517 .6118 .47156 .60597 .46488 Mtetra
.60597 .46488 .6118 .47156 .62334 .46792 .61754 .46122 Mtetra
.665 .742 .908 r
.61754 .46122 .62334 .46792 .63492 .46427 .62915 .45754 Mtetra
.62915 .45754 .63492 .46427 .64656 .46059 .64082 .45383 Mtetra
.64082 .45383 .64656 .46059 .65824 .45688 .65253 .4501 Mtetra
.665 .742 .907 r
.65253 .4501 .65824 .45688 .66997 .45316 .6643 .44635 Mtetra
.6643 .44635 .66997 .45316 .68174 .44942 .67611 .44257 Mtetra
.666 .742 .907 r
.67611 .44257 .68174 .44942 .69357 .44565 .68797 .43878 Mtetra
.68797 .43878 .69357 .44565 .70544 .44187 .69988 .43497 Mtetra
.69988 .43497 .70544 .44187 .71737 .43806 .71184 .43113 Mtetra
.71184 .43113 .71737 .43806 .72934 .43423 .72384 .42728 Mtetra
.72384 .42728 .72934 .43423 .74136 .43039 .7359 .4234 Mtetra
.7359 .4234 .74136 .43039 .75344 .42653 .74801 .41951 Mtetra
.74801 .41951 .75344 .42653 .76556 .42264 .76017 .4156 Mtetra
.76017 .4156 .76556 .42264 .77773 .41874 .77238 .41166 Mtetra
.77238 .41166 .77773 .41874 .78996 .41482 .78464 .40772 Mtetra
.666 .743 .907 r
.78464 .40772 .78996 .41482 .80223 .41089 .79695 .40375 Mtetra
.79695 .40375 .80223 .41089 .81456 .40694 .80932 .39977 Mtetra
.80932 .39977 .81456 .40694 .82694 .40297 .82174 .39577 Mtetra
.82174 .39577 .82694 .40297 .83937 .39898 .83421 .39175 Mtetra
.666 .742 .907 r
.83421 .39175 .83937 .39898 .85186 .39498 .84673 .38772 Mtetra
.84673 .38772 .85186 .39498 .8644 .39097 .85931 .38367 Mtetra
.85931 .38367 .8644 .39097 .87699 .38694 .87194 .37961 Mtetra
.87194 .37961 .87699 .38694 .88963 .38289 .88463 .37553 Mtetra
.88463 .37553 .88963 .38289 .90233 .37883 .89737 .37144 Mtetra
.89737 .37144 .90233 .37883 .91509 .37475 .91016 .36733 Mtetra
.91016 .36733 .91509 .37475 .9279 .37066 .92301 .36321 Mtetra
.66 .74 .909 r
.33545 .54048 .34201 .54659 .3525 .54338 .34597 .53725 Mtetra
.34597 .53725 .3525 .54338 .36304 .54016 .35653 .53401 Mtetra
.35653 .53401 .36304 .54016 .37361 .53693 .36713 .53075 Mtetra
.36713 .53075 .37361 .53693 .38423 .53368 .37778 .52747 Mtetra
.37778 .52747 .38423 .53368 .3949 .53042 .38847 .52419 Mtetra
.66 .741 .909 r
.38847 .52419 .3949 .53042 .4056 .52714 .3992 .52089 Mtetra
.3992 .52089 .4056 .52714 .41635 .52384 .40997 .51757 Mtetra
.40997 .51757 .41635 .52384 .42714 .52054 .42079 .51424 Mtetra
.661 .741 .909 r
.42079 .51424 .42714 .52054 .43798 .51721 .43166 .51089 Mtetra
.43166 .51089 .43798 .51721 .44886 .51387 .44257 .50752 Mtetra
.44257 .50752 .44886 .51387 .45979 .5105 .45352 .50414 Mtetra
.45352 .50414 .45979 .5105 .47076 .50712 .46452 .50074 Mtetra
.46452 .50074 .47076 .50712 .48177 .50372 .47556 .49731 Mtetra
.662 .741 .909 r
.47556 .49731 .48177 .50372 .49283 .5003 .48665 .49387 Mtetra
.662 .742 .909 r
.48665 .49387 .49283 .5003 .50394 .49686 .49779 .4904 Mtetra
.49779 .4904 .50394 .49686 .51509 .49339 .50897 .4869 Mtetra
.50897 .4869 .51509 .49339 .52629 .48991 .5202 .48339 Mtetra
.663 .742 .909 r
.5202 .48339 .52629 .48991 .53753 .4864 .53147 .47985 Mtetra
.53147 .47985 .53753 .4864 .54882 .48287 .54279 .47629 Mtetra
.663 .742 .908 r
.54279 .47629 .54882 .48287 .56016 .47932 .55415 .4727 Mtetra
.55415 .4727 .56016 .47932 .57154 .47574 .56557 .4691 Mtetra
.664 .742 .908 r
.56557 .4691 .57154 .47574 .58297 .47214 .57703 .46547 Mtetra
.57703 .46547 .58297 .47214 .59444 .46853 .58853 .46182 Mtetra
.58853 .46182 .59444 .46853 .60597 .46488 .60009 .45815 Mtetra
.60009 .45815 .60597 .46488 .61754 .46122 .61169 .45446 Mtetra
.665 .742 .908 r
.61169 .45446 .61754 .46122 .62915 .45754 .62334 .45075 Mtetra
.665 .742 .907 r
.62334 .45075 .62915 .45754 .64082 .45383 .63504 .44701 Mtetra
.63504 .44701 .64082 .45383 .65253 .4501 .64679 .44325 Mtetra
.64679 .44325 .65253 .4501 .6643 .44635 .65858 .43947 Mtetra
.65858 .43947 .6643 .44635 .67611 .44257 .67043 .43567 Mtetra
.666 .742 .907 r
.67043 .43567 .67611 .44257 .68797 .43878 .68232 .43185 Mtetra
.68232 .43185 .68797 .43878 .69988 .43497 .69427 .42801 Mtetra
.69427 .42801 .69988 .43497 .71184 .43113 .70626 .42414 Mtetra
.70626 .42414 .71184 .43113 .72384 .42728 .7183 .42026 Mtetra
.7183 .42026 .72384 .42728 .7359 .4234 .7304 .41635 Mtetra
.7304 .41635 .7359 .4234 .74801 .41951 .74254 .41243 Mtetra
.74254 .41243 .74801 .41951 .76017 .4156 .75474 .40849 Mtetra
.75474 .40849 .76017 .4156 .77238 .41166 .76699 .40453 Mtetra
.76699 .40453 .77238 .41166 .78464 .40772 .77928 .40055 Mtetra
.77928 .40055 .78464 .40772 .79695 .40375 .79163 .39655 Mtetra
.79163 .39655 .79695 .40375 .80932 .39977 .80404 .39254 Mtetra
.80404 .39254 .80932 .39977 .82174 .39577 .81649 .38851 Mtetra
.81649 .38851 .82174 .39577 .83421 .39175 .829 .38446 Mtetra
.829 .38446 .83421 .39175 .84673 .38772 .84157 .3804 Mtetra
.84157 .3804 .84673 .38772 .85931 .38367 .85418 .37632 Mtetra
.85418 .37632 .85931 .38367 .87194 .37961 .86685 .37222 Mtetra
.86685 .37222 .87194 .37961 .88463 .37553 .87958 .36811 Mtetra
.87958 .36811 .88463 .37553 .89737 .37144 .89236 .36399 Mtetra
.89236 .36399 .89737 .37144 .91016 .36733 .9052 .35985 Mtetra
.9052 .35985 .91016 .36733 .92301 .36321 .91809 .35569 Mtetra
.66 .74 .909 r
.32884 .53433 .33545 .54048 .34597 .53725 .33939 .53107 Mtetra
.33939 .53107 .34597 .53725 .35653 .53401 .34997 .5278 Mtetra
.34997 .5278 .35653 .53401 .36713 .53075 .3606 .52452 Mtetra
.3606 .52452 .36713 .53075 .37778 .52747 .37127 .52122 Mtetra
.37127 .52122 .37778 .52747 .38847 .52419 .38199 .51791 Mtetra
.38199 .51791 .38847 .52419 .3992 .52089 .39275 .51459 Mtetra
.66 .741 .909 r
.39275 .51459 .3992 .52089 .40997 .51757 .40355 .51125 Mtetra
.40355 .51125 .40997 .51757 .42079 .51424 .4144 .5079 Mtetra
.66 .741 .91 r
.4144 .5079 .42079 .51424 .43166 .51089 .42529 .50453 Mtetra
.42529 .50453 .43166 .51089 .44257 .50752 .43622 .50115 Mtetra
.661 .741 .91 r
.43622 .50115 .44257 .50752 .45352 .50414 .44721 .49775 Mtetra
.661 .742 .91 r
.44721 .49775 .45352 .50414 .46452 .50074 .45823 .49433 Mtetra
.45823 .49433 .46452 .50074 .47556 .49731 .46931 .49088 Mtetra
.46931 .49088 .47556 .49731 .48665 .49387 .48042 .48741 Mtetra
.662 .742 .91 r
.48042 .48741 .48665 .49387 .49779 .4904 .49159 .48391 Mtetra
.662 .743 .91 r
.49159 .48391 .49779 .4904 .50897 .4869 .5028 .48039 Mtetra
.663 .743 .909 r
.5028 .48039 .50897 .4869 .5202 .48339 .51406 .47684 Mtetra
.663 .742 .909 r
.51406 .47684 .5202 .48339 .53147 .47985 .52536 .47327 Mtetra
.52536 .47327 .53147 .47985 .54279 .47629 .53671 .46967 Mtetra
.53671 .46967 .54279 .47629 .55415 .4727 .54811 .46605 Mtetra
.664 .742 .908 r
.54811 .46605 .55415 .4727 .56557 .4691 .55955 .46241 Mtetra
.55955 .46241 .56557 .4691 .57703 .46547 .57104 .45875 Mtetra
.57104 .45875 .57703 .46547 .58853 .46182 .58258 .45507 Mtetra
.58258 .45507 .58853 .46182 .60009 .45815 .59417 .45137 Mtetra
.664 .741 .908 r
.59417 .45137 .60009 .45815 .61169 .45446 .6058 .44764 Mtetra
.665 .741 .907 r
.6058 .44764 .61169 .45446 .62334 .45075 .61749 .4439 Mtetra
.665 .742 .907 r
.61749 .4439 .62334 .45075 .63504 .44701 .62922 .44014 Mtetra
.62922 .44014 .63504 .44701 .64679 .44325 .641 .43635 Mtetra
.641 .43635 .64679 .44325 .65858 .43947 .65283 .43254 Mtetra
.65283 .43254 .65858 .43947 .67043 .43567 .66471 .42871 Mtetra
.666 .742 .907 r
.66471 .42871 .67043 .43567 .68232 .43185 .67664 .42486 Mtetra
.67664 .42486 .68232 .43185 .69427 .42801 .68861 .42098 Mtetra
.68861 .42098 .69427 .42801 .70626 .42414 .70064 .41709 Mtetra
.70064 .41709 .70626 .42414 .7183 .42026 .71272 .41318 Mtetra
.71272 .41318 .7183 .42026 .7304 .41635 .72485 .40924 Mtetra
.72485 .40924 .7304 .41635 .74254 .41243 .73703 .40529 Mtetra
.73703 .40529 .74254 .41243 .75474 .40849 .74926 .40132 Mtetra
.74926 .40132 .75474 .40849 .76699 .40453 .76155 .39733 Mtetra
.76155 .39733 .76699 .40453 .77928 .40055 .77388 .39332 Mtetra
.77388 .39332 .77928 .40055 .79163 .39655 .78627 .38929 Mtetra
.78627 .38929 .79163 .39655 .80404 .39254 .79871 .38524 Mtetra
.79871 .38524 .80404 .39254 .81649 .38851 .81121 .38118 Mtetra
.81121 .38118 .81649 .38851 .829 .38446 .82376 .3771 Mtetra
.82376 .3771 .829 .38446 .84157 .3804 .83636 .37301 Mtetra
.83636 .37301 .84157 .3804 .85418 .37632 .84901 .3689 Mtetra
.84901 .3689 .85418 .37632 .86685 .37222 .86172 .36477 Mtetra
.86172 .36477 .86685 .37222 .87958 .36811 .87449 .36063 Mtetra
.87449 .36063 .87958 .36811 .89236 .36399 .88731 .35647 Mtetra
.88731 .35647 .89236 .36399 .9052 .35985 .90019 .3523 Mtetra
.90019 .3523 .9052 .35985 .91809 .35569 .91312 .34811 Mtetra
.66 .74 .909 r
.32219 .52812 .32884 .53433 .33939 .53107 .33276 .52484 Mtetra
.33276 .52484 .33939 .53107 .34997 .5278 .34337 .52155 Mtetra
.34337 .52155 .34997 .5278 .3606 .52452 .35402 .51824 Mtetra
.35402 .51824 .3606 .52452 .37127 .52122 .36472 .51492 Mtetra
.36472 .51492 .37127 .52122 .38199 .51791 .37546 .51159 Mtetra
.37546 .51159 .38199 .51791 .39275 .51459 .38625 .50825 Mtetra
.66 .741 .91 r
.38625 .50825 .39275 .51459 .40355 .51125 .39708 .5049 Mtetra
.39708 .5049 .40355 .51125 .4144 .5079 .40795 .50153 Mtetra
.40795 .50153 .4144 .5079 .42529 .50453 .41887 .49816 Mtetra
.66 .742 .911 r
.41887 .49816 .42529 .50453 .43622 .50115 .42983 .49477 Mtetra
.42983 .49477 .43622 .50115 .44721 .49775 .44084 .49136 Mtetra
.66 .743 .911 r
.44084 .49136 .44721 .49775 .45823 .49433 .4519 .48792 Mtetra
.661 .744 .912 r
.4519 .48792 .45823 .49433 .46931 .49088 .463 .48446 Mtetra
.463 .48446 .46931 .49088 .48042 .48741 .47415 .48097 Mtetra
.662 .745 .911 r
.47415 .48097 .48042 .48741 .49159 .48391 .48534 .47744 Mtetra
.48534 .47744 .49159 .48391 .5028 .48039 .49658 .47388 Mtetra
.663 .745 .911 r
.49658 .47388 .5028 .48039 .51406 .47684 .50787 .47029 Mtetra
.664 .744 .91 r
.50787 .47029 .51406 .47684 .52536 .47327 .5192 .46667 Mtetra
.5192 .46667 .52536 .47327 .53671 .46967 .53058 .46303 Mtetra
.664 .743 .909 r
.53058 .46303 .53671 .46967 .54811 .46605 .54201 .45937 Mtetra
.54201 .45937 .54811 .46605 .55955 .46241 .55349 .45568 Mtetra
.664 .742 .908 r
.55349 .45568 .55955 .46241 .57104 .45875 .56501 .45198 Mtetra
.56501 .45198 .57104 .45875 .58258 .45507 .57658 .44826 Mtetra
.57658 .44826 .58258 .45507 .59417 .45137 .5882 .44453 Mtetra
.665 .742 .907 r
.5882 .44453 .59417 .45137 .6058 .44764 .59987 .44077 Mtetra
.665 .741 .907 r
.59987 .44077 .6058 .44764 .61749 .4439 .61158 .437 Mtetra
.61158 .437 .61749 .4439 .62922 .44014 .62335 .4332 Mtetra
.62335 .4332 .62922 .44014 .641 .43635 .63516 .42938 Mtetra
.63516 .42938 .641 .43635 .65283 .43254 .64703 .42554 Mtetra
.64703 .42554 .65283 .43254 .66471 .42871 .65894 .42168 Mtetra
.665 .742 .907 r
.65894 .42168 .66471 .42871 .67664 .42486 .6709 .4178 Mtetra
.666 .742 .907 r
.6709 .4178 .67664 .42486 .68861 .42098 .68292 .4139 Mtetra
.68292 .4139 .68861 .42098 .70064 .41709 .69498 .40998 Mtetra
.69498 .40998 .70064 .41709 .71272 .41318 .70709 .40603 Mtetra
.70709 .40603 .71272 .41318 .72485 .40924 .71926 .40207 Mtetra
.71926 .40207 .72485 .40924 .73703 .40529 .73148 .39809 Mtetra
.73148 .39809 .73703 .40529 .74926 .40132 .74375 .39408 Mtetra
.74375 .39408 .74926 .40132 .76155 .39733 .75607 .39006 Mtetra
.75607 .39006 .76155 .39733 .77388 .39332 .76844 .38602 Mtetra
.76844 .38602 .77388 .39332 .78627 .38929 .78087 .38196 Mtetra
.78087 .38196 .78627 .38929 .79871 .38524 .79335 .37789 Mtetra
.79335 .37789 .79871 .38524 .81121 .38118 .80588 .3738 Mtetra
.80588 .3738 .81121 .38118 .82376 .3771 .81847 .36969 Mtetra
.81847 .36969 .82376 .3771 .83636 .37301 .83111 .36556 Mtetra
.83111 .36556 .83636 .37301 .84901 .3689 .8438 .36142 Mtetra
.8438 .36142 .84901 .3689 .86172 .36477 .85655 .35726 Mtetra
.85655 .35726 .86172 .36477 .87449 .36063 .86936 .35309 Mtetra
.86936 .35309 .87449 .36063 .88731 .35647 .88222 .3489 Mtetra
.88222 .3489 .88731 .35647 .90019 .3523 .89514 .34469 Mtetra
.89514 .34469 .90019 .3523 .91312 .34811 .90812 .34047 Mtetra
.66 .74 .909 r
.31548 .52187 .32219 .52812 .33276 .52484 .32608 .51856 Mtetra
.32608 .51856 .33276 .52484 .34337 .52155 .33671 .51524 Mtetra
.33671 .51524 .34337 .52155 .35402 .51824 .34739 .51191 Mtetra
.34739 .51191 .35402 .51824 .36472 .51492 .35812 .50858 Mtetra
.66 .74 .91 r
.35812 .50858 .36472 .51492 .37546 .51159 .36889 .50523 Mtetra
.659 .741 .91 r
.36889 .50523 .37546 .51159 .38625 .50825 .3797 .50188 Mtetra
.3797 .50188 .38625 .50825 .39708 .5049 .39055 .49852 Mtetra
.659 .742 .911 r
.39055 .49852 .39708 .5049 .40795 .50153 .40145 .49516 Mtetra
.658 .742 .912 r
.40145 .49516 .40795 .50153 .41887 .49816 .4124 .49179 Mtetra
.658 .743 .913 r
.4124 .49179 .41887 .49816 .42983 .49477 .42339 .48841 Mtetra
.659 .745 .914 r
.42339 .48841 .42983 .49477 .44084 .49136 .43443 .48501 Mtetra
.659 .746 .914 r
.43443 .48501 .44084 .49136 .4519 .48792 .44551 .48158 Mtetra
.66 .747 .915 r
.44551 .48158 .4519 .48792 .463 .48446 .45664 .47812 Mtetra
.661 .748 .915 r
.45664 .47812 .463 .48446 .47415 .48097 .46782 .47461 Mtetra
.662 .749 .915 r
.46782 .47461 .47415 .48097 .48534 .47744 .47904 .47105 Mtetra
.663 .749 .914 r
.47904 .47105 .48534 .47744 .49658 .47388 .49031 .46745 Mtetra
.664 .749 .913 r
.49031 .46745 .49658 .47388 .50787 .47029 .50163 .46381 Mtetra
.665 .748 .912 r
.50163 .46381 .50787 .47029 .5192 .46667 .513 .46013 Mtetra
.665 .747 .911 r
.513 .46013 .5192 .46667 .53058 .46303 .52441 .45642 Mtetra
.665 .746 .91 r
.52441 .45642 .53058 .46303 .54201 .45937 .53587 .45269 Mtetra
.665 .745 .91 r
.53587 .45269 .54201 .45937 .55349 .45568 .54738 .44894 Mtetra
.665 .744 .909 r
.54738 .44894 .55349 .45568 .56501 .45198 .55893 .44519 Mtetra
.665 .743 .908 r
.55893 .44519 .56501 .45198 .57658 .44826 .57053 .44142 Mtetra
.665 .742 .908 r
.57053 .44142 .57658 .44826 .5882 .44453 .58219 .43764 Mtetra
.665 .742 .907 r
.58219 .43764 .5882 .44453 .59987 .44077 .59389 .43385 Mtetra
.665 .741 .907 r
.59389 .43385 .59987 .44077 .61158 .437 .60563 .43003 Mtetra
.60563 .43003 .61158 .437 .62335 .4332 .61743 .42621 Mtetra
.61743 .42621 .62335 .4332 .63516 .42938 .62928 .42236 Mtetra
.62928 .42236 .63516 .42938 .64703 .42554 .64118 .41849 Mtetra
.64118 .41849 .64703 .42554 .65894 .42168 .65313 .4146 Mtetra
.65313 .4146 .65894 .42168 .6709 .4178 .66512 .41069 Mtetra
.666 .741 .907 r
.66512 .41069 .6709 .4178 .68292 .4139 .67717 .40676 Mtetra
.67717 .40676 .68292 .4139 .69498 .40998 .68927 .4028 Mtetra
.666 .742 .907 r
.68927 .4028 .69498 .40998 .70709 .40603 .70142 .39883 Mtetra
.70142 .39883 .70709 .40603 .71926 .40207 .71362 .39483 Mtetra
.71362 .39483 .71926 .40207 .73148 .39809 .72588 .39082 Mtetra
.72588 .39082 .73148 .39809 .74375 .39408 .73818 .38679 Mtetra
.73818 .38679 .74375 .39408 .75607 .39006 .75054 .38274 Mtetra
.75054 .38274 .75607 .39006 .76844 .38602 .76295 .37867 Mtetra
.76295 .37867 .76844 .38602 .78087 .38196 .77542 .37458 Mtetra
.77542 .37458 .78087 .38196 .79335 .37789 .78793 .37047 Mtetra
.78793 .37047 .79335 .37789 .80588 .3738 .80051 .36635 Mtetra
.80051 .36635 .80588 .3738 .81847 .36969 .81313 .3622 Mtetra
.81313 .3622 .81847 .36969 .83111 .36556 .82581 .35805 Mtetra
.82581 .35805 .83111 .36556 .8438 .36142 .83855 .35387 Mtetra
.83855 .35387 .8438 .36142 .85655 .35726 .85134 .34968 Mtetra
.85134 .34968 .85655 .35726 .86936 .35309 .86419 .34548 Mtetra
.86419 .34548 .86936 .35309 .88222 .3489 .87709 .34125 Mtetra
.87709 .34125 .88222 .3489 .89514 .34469 .89005 .33701 Mtetra
.89005 .33701 .89514 .34469 .90812 .34047 .90307 .33276 Mtetra
.66 .74 .909 r
.30873 .51556 .31548 .52187 .32608 .51856 .31935 .51223 Mtetra
.31935 .51223 .32608 .51856 .33671 .51524 .33001 .50889 Mtetra
.33001 .50889 .33671 .51524 .34739 .51191 .34072 .50555 Mtetra
.659 .74 .91 r
.34072 .50555 .34739 .51191 .35812 .50858 .35147 .5022 Mtetra
.35147 .5022 .35812 .50858 .36889 .50523 .36226 .49885 Mtetra
.658 .741 .911 r
.36226 .49885 .36889 .50523 .3797 .50188 .3731 .4955 Mtetra
.658 .742 .912 r
.3731 .4955 .3797 .50188 .39055 .49852 .38398 .49216 Mtetra
.657 .743 .913 r
.38398 .49216 .39055 .49852 .40145 .49516 .3949 .48883 Mtetra
.656 .744 .915 r
.3949 .48883 .40145 .49516 .4124 .49179 .40588 .4855 Mtetra
.656 .746 .917 r
.40588 .4855 .4124 .49179 .42339 .48841 .41689 .48216 Mtetra
.656 .749 .918 r
.41689 .48216 .42339 .48841 .43443 .48501 .42796 .47881 Mtetra
.656 .751 .92 r
.42796 .47881 .43443 .48501 .44551 .48158 .43907 .47542 Mtetra
.658 .754 .921 r
.43907 .47542 .44551 .48158 .45664 .47812 .45023 .47197 Mtetra
.66 .756 .921 r
.45023 .47197 .45664 .47812 .46782 .47461 .46144 .46845 Mtetra
.662 .757 .921 r
.46144 .46845 .46782 .47461 .47904 .47105 .47269 .46487 Mtetra
.664 .757 .92 r
.47269 .46487 .47904 .47105 .49031 .46745 .484 .4612 Mtetra
.666 .757 .918 r
.484 .4612 .49031 .46745 .50163 .46381 .49535 .45748 Mtetra
.667 .755 .917 r
.49535 .45748 .50163 .46381 .513 .46013 .50674 .4537 Mtetra
.667 .753 .915 r
.50674 .4537 .513 .46013 .52441 .45642 .51819 .4499 Mtetra
.668 .751 .913 r
.51819 .4499 .52441 .45642 .53587 .45269 .52968 .44607 Mtetra
.667 .749 .911 r
.52968 .44607 .53587 .45269 .54738 .44894 .54122 .44223 Mtetra
.667 .747 .91 r
.54122 .44223 .54738 .44894 .55893 .44519 .55281 .4384 Mtetra
.666 .745 .909 r
.55281 .4384 .55893 .44519 .57053 .44142 .56444 .43456 Mtetra
.666 .744 .908 r
.56444 .43456 .57053 .44142 .58219 .43764 .57612 .43072 Mtetra
.666 .743 .908 r
.57612 .43072 .58219 .43764 .59389 .43385 .58786 .42688 Mtetra
.665 .742 .907 r
.58786 .42688 .59389 .43385 .60563 .43003 .59964 .42302 Mtetra
.665 .741 .907 r
.59964 .42302 .60563 .43003 .61743 .42621 .61147 .41916 Mtetra
.61147 .41916 .61743 .42621 .62928 .42236 .62335 .41527 Mtetra
.62335 .41527 .62928 .42236 .64118 .41849 .63528 .41137 Mtetra
.63528 .41137 .64118 .41849 .65313 .4146 .64727 .40745 Mtetra
.64727 .40745 .65313 .4146 .66512 .41069 .6593 .40351 Mtetra
.666 .741 .907 r
.6593 .40351 .66512 .41069 .67717 .40676 .67138 .39955 Mtetra
.67138 .39955 .67717 .40676 .68927 .4028 .68352 .39556 Mtetra
.666 .741 .906 r
.68352 .39556 .68927 .4028 .70142 .39883 .6957 .39156 Mtetra
.6957 .39156 .70142 .39883 .71362 .39483 .70794 .38754 Mtetra
.70794 .38754 .71362 .39483 .72588 .39082 .72023 .38349 Mtetra
.666 .742 .906 r
.72023 .38349 .72588 .39082 .73818 .38679 .73258 .37943 Mtetra
.73258 .37943 .73818 .38679 .75054 .38274 .74497 .37535 Mtetra
.666 .742 .907 r
.74497 .37535 .75054 .38274 .76295 .37867 .75742 .37124 Mtetra
.75742 .37124 .76295 .37867 .77542 .37458 .76992 .36712 Mtetra
.76992 .36712 .77542 .37458 .78793 .37047 .78248 .36299 Mtetra
.78248 .36299 .78793 .37047 .80051 .36635 .79509 .35883 Mtetra
.79509 .35883 .80051 .36635 .81313 .3622 .80776 .35466 Mtetra
.80776 .35466 .81313 .3622 .82581 .35805 .82048 .35047 Mtetra
.82048 .35047 .82581 .35805 .83855 .35387 .83325 .34626 Mtetra
.83325 .34626 .83855 .35387 .85134 .34968 .84609 .34204 Mtetra
.84609 .34204 .85134 .34968 .86419 .34548 .85897 .3378 Mtetra
.85897 .3378 .86419 .34548 .87709 .34125 .87192 .33354 Mtetra
.87192 .33354 .87709 .34125 .89005 .33701 .88492 .32927 Mtetra
.88492 .32927 .89005 .33701 .90307 .33276 .89798 .32498 Mtetra
.66 .74 .909 r
.30193 .50921 .30873 .51556 .31935 .51223 .31257 .50586 Mtetra
.31257 .50586 .31935 .51223 .33001 .50889 .32326 .5025 Mtetra
.659 .74 .91 r
.32326 .5025 .33001 .50889 .34072 .50555 .33399 .49914 Mtetra
.33399 .49914 .34072 .50555 .35147 .5022 .34476 .49579 Mtetra
.658 .741 .911 r
.34476 .49579 .35147 .5022 .36226 .49885 .35558 .49245 Mtetra
.656 .742 .913 r
.35558 .49245 .36226 .49885 .3731 .4955 .36644 .48914 Mtetra
.655 .743 .915 r
.36644 .48914 .3731 .4955 .38398 .49216 .37735 .48585 Mtetra
.653 .745 .917 r
.37735 .48585 .38398 .49216 .3949 .48883 .3883 .4826 Mtetra
.651 .748 .92 r
.3883 .4826 .3949 .48883 .40588 .4855 .39929 .47936 Mtetra
.65 .752 .924 r
.39929 .47936 .40588 .4855 .41689 .48216 .41034 .47613 Mtetra
.65 .756 .927 r
.41034 .47613 .41689 .48216 .42796 .47881 .42143 .47288 Mtetra
.651 .761 .929 r
.42143 .47288 .42796 .47881 .43907 .47542 .43257 .46958 Mtetra
.654 .765 .931 r
.43257 .46958 .43907 .47542 .45023 .47197 .44376 .46619 Mtetra
.657 .769 .932 r
.44376 .46619 .45023 .47197 .46144 .46845 .45499 .46269 Mtetra
.661 .771 .931 r
.45499 .46269 .46144 .46845 .47269 .46487 .46628 .45907 Mtetra
.665 .772 .93 r
.46628 .45907 .47269 .46487 .484 .4612 .47762 .45533 Mtetra
.668 .771 .927 r
.47762 .45533 .484 .4612 .49535 .45748 .48901 .45148 Mtetra
.671 .769 .924 r
.48901 .45148 .49535 .45748 .50674 .4537 .50044 .44755 Mtetra
.672 .765 .921 r
.50044 .44755 .50674 .4537 .51819 .4499 .51192 .44358 Mtetra
.672 .761 .917 r
.51192 .44358 .51819 .4499 .52968 .44607 .52344 .4396 Mtetra
.671 .756 .915 r
.52344 .4396 .52968 .44607 .54122 .44223 .53501 .43562 Mtetra
.67 .752 .912 r
.53501 .43562 .54122 .44223 .55281 .4384 .54663 .43165 Mtetra
.669 .749 .91 r
.54663 .43165 .55281 .4384 .56444 .43456 .5583 .42771 Mtetra
.668 .746 .909 r
.5583 .42771 .56444 .43456 .57612 .43072 .57002 .42379 Mtetra
.667 .744 .908 r
.57002 .42379 .57612 .43072 .58786 .42688 .58178 .41987 Mtetra
.666 .743 .908 r
.58178 .41987 .58786 .42688 .59964 .42302 .5936 .41597 Mtetra
.666 .742 .907 r
.5936 .41597 .59964 .42302 .61147 .41916 .60546 .41205 Mtetra
.665 .741 .907 r
.60546 .41205 .61147 .41916 .62335 .41527 .61738 .40813 Mtetra
.61738 .40813 .62335 .41527 .63528 .41137 .62934 .4042 Mtetra
.62934 .4042 .63528 .41137 .64727 .40745 .64136 .40024 Mtetra
.665 .741 .906 r
.64136 .40024 .64727 .40745 .6593 .40351 .65343 .39627 Mtetra
.666 .741 .906 r
.65343 .39627 .6593 .40351 .67138 .39955 .66555 .39228 Mtetra
.66555 .39228 .67138 .39955 .68352 .39556 .67772 .38826 Mtetra
.67772 .38826 .68352 .39556 .6957 .39156 .68994 .38423 Mtetra
.68994 .38423 .6957 .39156 .70794 .38754 .70222 .38018 Mtetra
.70222 .38018 .70794 .38754 .72023 .38349 .71454 .3761 Mtetra
.71454 .3761 .72023 .38349 .73258 .37943 .72692 .37201 Mtetra
.72692 .37201 .73258 .37943 .74497 .37535 .73936 .36789 Mtetra
.666 .742 .906 r
.73936 .36789 .74497 .37535 .75742 .37124 .75184 .36376 Mtetra
.75184 .36376 .75742 .37124 .76992 .36712 .76438 .35961 Mtetra
.76438 .35961 .76992 .36712 .78248 .36299 .77698 .35544 Mtetra
.666 .742 .907 r
.77698 .35544 .78248 .36299 .79509 .35883 .78963 .35125 Mtetra
.78963 .35125 .79509 .35883 .80776 .35466 .80234 .34705 Mtetra
.80234 .34705 .80776 .35466 .82048 .35047 .8151 .34283 Mtetra
.8151 .34283 .82048 .35047 .83325 .34626 .82791 .33859 Mtetra
.82791 .33859 .83325 .34626 .84609 .34204 .84079 .33433 Mtetra
.84079 .33433 .84609 .34204 .85897 .3378 .85372 .33006 Mtetra
.85372 .33006 .85897 .3378 .87192 .33354 .8667 .32577 Mtetra
.8667 .32577 .87192 .33354 .88492 .32927 .87975 .32146 Mtetra
.87975 .32146 .88492 .32927 .89798 .32498 .89285 .31714 Mtetra
.66 .74 .909 r
.29507 .50281 .30193 .50921 .31257 .50586 .30574 .49944 Mtetra
.659 .74 .909 r
.30574 .49944 .31257 .50586 .32326 .5025 .31646 .49607 Mtetra
.658 .74 .91 r
.31646 .49607 .32326 .5025 .33399 .49914 .32721 .49271 Mtetra
.657 .741 .911 r
.32721 .49271 .33399 .49914 .34476 .49579 .33801 .48937 Mtetra
.655 .741 .913 r
.33801 .48937 .34476 .49579 .35558 .49245 .34885 .48608 Mtetra
.652 .743 .916 r
.34885 .48608 .35558 .49245 .36644 .48914 .35973 .48284 Mtetra
.649 .745 .92 r
.35973 .48284 .36644 .48914 .37735 .48585 .37066 .47967 Mtetra
.646 .749 .924 r
.37066 .47967 .37735 .48585 .3883 .4826 .38163 .47656 Mtetra
.642 .754 .93 r
.38163 .47656 .3883 .4826 .39929 .47936 .39265 .47351 Mtetra
.64 .76 .935 r
.39265 .47351 .39929 .47936 .41034 .47613 .40371 .47049 Mtetra
.639 .768 .941 r
.40371 .47049 .41034 .47613 .42143 .47288 .41483 .46745 Mtetra
.64 .776 .946 r
.41483 .46745 .42143 .47288 .43257 .46958 .42599 .46432 Mtetra
.644 .784 .949 r
.42599 .46432 .43257 .46958 .44376 .46619 .43721 .46106 Mtetra
.65 .791 .95 r
.43721 .46106 .44376 .46619 .45499 .46269 .44848 .45761 Mtetra
.658 .796 .949 r
.44848 .45761 .45499 .46269 .46628 .45907 .45981 .45395 Mtetra
.666 .798 .945 r
.45981 .45395 .46628 .45907 .47762 .45533 .47118 .45009 Mtetra
.672 .796 .941 r
.47118 .45009 .47762 .45533 .48901 .45148 .48261 .44605 Mtetra
.677 .792 .935 r
.48261 .44605 .48901 .45148 .50044 .44755 .49408 .44189 Mtetra
.679 .785 .93 r
.49408 .44189 .50044 .44755 .51192 .44358 .50559 .43766 Mtetra
.679 .777 .925 r
.50559 .43766 .51192 .44358 .52344 .4396 .51715 .43342 Mtetra
.678 .769 .92 r
.51715 .43342 .52344 .4396 .53501 .43562 .52876 .4292 Mtetra
.676 .762 .916 r
.52876 .4292 .53501 .43562 .54663 .43165 .54041 .42504 Mtetra
.673 .756 .913 r
.54041 .42504 .54663 .43165 .5583 .42771 .55211 .42093 Mtetra
.671 .751 .911 r
.55211 .42093 .5583 .42771 .57002 .42379 .56386 .41687 Mtetra
.669 .747 .909 r
.56386 .41687 .57002 .42379 .58178 .41987 .57566 .41286 Mtetra
.668 .745 .908 r
.57566 .41286 .58178 .41987 .5936 .41597 .58751 .40888 Mtetra
.667 .743 .907 r
.58751 .40888 .5936 .41597 .60546 .41205 .59941 .40491 Mtetra
.666 .742 .907 r
.59941 .40491 .60546 .41205 .61738 .40813 .61136 .40094 Mtetra
.666 .741 .907 r
.61136 .40094 .61738 .40813 .62934 .4042 .62336 .39696 Mtetra
.666 .741 .906 r
.62336 .39696 .62934 .4042 .64136 .40024 .63541 .39298 Mtetra
.63541 .39298 .64136 .40024 .65343 .39627 .64751 .38897 Mtetra
.64751 .38897 .65343 .39627 .66555 .39228 .65967 .38495 Mtetra
.65967 .38495 .66555 .39228 .67772 .38826 .67187 .3809 Mtetra
.67187 .3809 .67772 .38826 .68994 .38423 .68413 .37684 Mtetra
.68413 .37684 .68994 .38423 .70222 .38018 .69644 .37275 Mtetra
.69644 .37275 .70222 .38018 .71454 .3761 .70881 .36865 Mtetra
.70881 .36865 .71454 .3761 .72692 .37201 .72122 .36452 Mtetra
.72122 .36452 .72692 .37201 .73936 .36789 .7337 .36037 Mtetra
.7337 .36037 .73936 .36789 .75184 .36376 .74622 .35621 Mtetra
.74622 .35621 .75184 .36376 .76438 .35961 .7588 .35203 Mtetra
.7588 .35203 .76438 .35961 .77698 .35544 .77144 .34783 Mtetra
.666 .742 .906 r
.77144 .34783 .77698 .35544 .78963 .35125 .78413 .34361 Mtetra
.78413 .34361 .78963 .35125 .80234 .34705 .79687 .33937 Mtetra
.666 .742 .907 r
.79687 .33937 .80234 .34705 .8151 .34283 .80967 .33512 Mtetra
.80967 .33512 .8151 .34283 .82791 .33859 .82253 .33084 Mtetra
.82253 .33084 .82791 .33859 .84079 .33433 .83544 .32656 Mtetra
.83544 .32656 .84079 .33433 .85372 .33006 .84842 .32225 Mtetra
.84842 .32225 .85372 .33006 .8667 .32577 .86145 .31793 Mtetra
.86145 .31793 .8667 .32577 .87975 .32146 .87453 .31359 Mtetra
.87453 .31359 .87975 .32146 .89285 .31714 .88768 .30923 Mtetra
.659 .74 .909 r
.28817 .49636 .29507 .50281 .30574 .49944 .29886 .49298 Mtetra
.658 .74 .91 r
.29886 .49298 .30574 .49944 .31646 .49607 .3096 .4896 Mtetra
.657 .74 .911 r
.3096 .4896 .31646 .49607 .32721 .49271 .32038 .48626 Mtetra
.654 .741 .913 r
.32038 .48626 .32721 .49271 .33801 .48937 .3312 .48297 Mtetra
.651 .742 .916 r
.3312 .48297 .33801 .48937 .34885 .48608 .34206 .47976 Mtetra
.646 .744 .921 r
.34206 .47976 .34885 .48608 .35973 .48284 .35296 .47667 Mtetra
.64 .748 .927 r
.35296 .47667 .35973 .48284 .37066 .47967 .36391 .47369 Mtetra
.633 .754 .935 r
.36391 .47369 .37066 .47967 .38163 .47656 .37489 .47086 Mtetra
.625 .762 .944 r
.37489 .47086 .38163 .47656 .39265 .47351 .38593 .46813 Mtetra
.619 .772 .954 r
.38593 .46813 .39265 .47351 .40371 .47049 .39701 .46547 Mtetra
.615 .785 .963 r
.39701 .46547 .40371 .47049 .41483 .46745 .40814 .46278 Mtetra
.615 .799 .97 r
.40814 .46278 .41483 .46745 .42599 .46432 .41933 .45997 Mtetra
.621 .813 .974 r
.41933 .45997 .42599 .46432 .43721 .46106 .43058 .45694 Mtetra
.632 .826 .975 r
.43058 .45694 .43721 .46106 .44848 .45761 .44189 .4536 Mtetra
.647 .835 .973 r
.44189 .4536 .44848 .45761 .45981 .45395 .45325 .44991 Mtetra
.662 .838 .967 r
.45325 .44991 .45981 .45395 .47118 .45009 .46467 .44588 Mtetra
.676 .836 .96 r
.46467 .44588 .47118 .45009 .48261 .44605 .47614 .44155 Mtetra
.686 .828 .952 r
.47614 .44155 .48261 .44605 .49408 .44189 .48765 .43702 Mtetra
.69 .817 .943 r
.48765 .43702 .49408 .44189 .50559 .43766 .49921 .43239 Mtetra
.691 .804 .935 r
.49921 .43239 .50559 .43766 .51715 .43342 .51081 .42774 Mtetra
.689 .79 .927 r
.51081 .42774 .51715 .43342 .52876 .4292 .52246 .42315 Mtetra
.685 .778 .921 r
.52246 .42315 .52876 .4292 .54041 .42504 .53414 .41866 Mtetra
.681 .767 .917 r
.53414 .41866 .54041 .42504 .55211 .42093 .54588 .41429 Mtetra
.676 .759 .913 r
.54588 .41429 .55211 .42093 .56386 .41687 .55766 .41004 Mtetra
.673 .752 .911 r
.55766 .41004 .56386 .41687 .57566 .41286 .56949 .40587 Mtetra
.67 .748 .909 r
.56949 .40587 .57566 .41286 .58751 .40888 .58137 .40178 Mtetra
.668 .745 .908 r
.58137 .40178 .58751 .40888 .59941 .40491 .5933 .39773 Mtetra
.667 .743 .907 r
.5933 .39773 .59941 .40491 .61136 .40094 .60529 .3937 Mtetra
.666 .742 .907 r
.60529 .3937 .61136 .40094 .62336 .39696 .61732 .38968 Mtetra
.666 .741 .906 r
.61732 .38968 .62336 .39696 .63541 .39298 .62941 .38565 Mtetra
.62941 .38565 .63541 .39298 .64751 .38897 .64155 .38161 Mtetra
.64155 .38161 .64751 .38897 .65967 .38495 .65374 .37755 Mtetra
.65374 .37755 .65967 .38495 .67187 .3809 .66598 .37348 Mtetra
.66598 .37348 .67187 .3809 .68413 .37684 .67827 .36938 Mtetra
.67827 .36938 .68413 .37684 .69644 .37275 .69062 .36526 Mtetra
.69062 .36526 .69644 .37275 .70881 .36865 .70302 .36113 Mtetra
.70302 .36113 .70881 .36865 .72122 .36452 .71548 .35697 Mtetra
.71548 .35697 .72122 .36452 .7337 .36037 .72799 .35279 Mtetra
.72799 .35279 .7337 .36037 .74622 .35621 .74055 .3486 Mtetra
.74055 .3486 .74622 .35621 .7588 .35203 .75317 .34438 Mtetra
.75317 .34438 .7588 .35203 .77144 .34783 .76585 .34015 Mtetra
.76585 .34015 .77144 .34783 .78413 .34361 .77858 .3359 Mtetra
.77858 .3359 .78413 .34361 .79687 .33937 .79136 .33163 Mtetra
.79136 .33163 .79687 .33937 .80967 .33512 .8042 .32734 Mtetra
.666 .742 .907 r
.8042 .32734 .80967 .33512 .82253 .33084 .8171 .32304 Mtetra
.8171 .32304 .82253 .33084 .83544 .32656 .83006 .31871 Mtetra
.83006 .31871 .83544 .32656 .84842 .32225 .84307 .31437 Mtetra
.84307 .31437 .84842 .32225 .86145 .31793 .85614 .31002 Mtetra
.85614 .31002 .86145 .31793 .87453 .31359 .86927 .30565 Mtetra
.86927 .30565 .87453 .31359 .88768 .30923 .88246 .30126 Mtetra
.659 .74 .91 r
.28121 .48987 .28817 .49636 .29886 .49298 .29193 .48648 Mtetra
.657 .74 .911 r
.29193 .48648 .29886 .49298 .3096 .4896 .30269 .48312 Mtetra
.654 .74 .913 r
.30269 .48312 .3096 .4896 .32038 .48626 .31349 .47981 Mtetra
.65 .741 .916 r
.31349 .47981 .32038 .48626 .3312 .48297 .32433 .47661 Mtetra
.644 .743 .921 r
.32433 .47661 .3312 .48297 .34206 .47976 .33521 .47355 Mtetra
.635 .746 .928 r
.33521 .47355 .34206 .47976 .35296 .47667 .34613 .47069 Mtetra
.624 .752 .938 r
.34613 .47069 .35296 .47667 .36391 .47369 .35708 .46805 Mtetra
.609 .76 .951 r
.35708 .46805 .36391 .47369 .37489 .47086 .36808 .46564 Mtetra
.593 .771 .965 r
.36808 .46564 .37489 .47086 .38593 .46813 .37911 .46343 Mtetra
.576 .786 .978 r
.37911 .46343 .38593 .46813 .39701 .46547 .3902 .46134 Mtetra
.562 .804 .99 r
.3902 .46134 .39701 .46547 .40814 .46278 .40135 .45923 Mtetra
.555 .824 .996 r
.40135 .45923 .40814 .46278 .41933 .45997 .41256 .45694 Mtetra
.56 .846 .997 r
.41256 .45694 .41933 .45997 .43058 .45694 .42384 .45429 Mtetra
.579 .867 .995 r
.42384 .45429 .43058 .45694 .44189 .4536 .43518 .45115 Mtetra
.608 .883 .991 r
.43518 .45115 .44189 .4536 .45325 .44991 .44659 .44744 Mtetra
.642 .892 .985 r
.44659 .44744 .45325 .44991 .46467 .44588 .45806 .44317 Mtetra
.672 .892 .977 r
.45806 .44317 .46467 .44588 .47614 .44155 .46958 .43842 Mtetra
.694 .882 .968 r
.46958 .43842 .47614 .44155 .48765 .43702 .48115 .43334 Mtetra
.706 .865 .957 r
.48115 .43334 .48765 .43702 .49921 .43239 .49276 .42809 Mtetra
.709 .844 .947 r
.49276 .42809 .49921 .43239 .51081 .42774 .50441 .42282 Mtetra
.707 .822 .937 r
.50441 .42282 .51081 .42774 .52246 .42315 .5161 .41766 Mtetra
.7 .802 .928 r
.5161 .41766 .52246 .42315 .53414 .41866 .52782 .41268 Mtetra
.693 .785 .922 r
.52782 .41268 .53414 .41866 .54588 .41429 .53959 .40791 Mtetra
.686 .771 .916 r
.53959 .40791 .54588 .41429 .55766 .41004 .55141 .40335 Mtetra
.679 .761 .913 r
.55141 .40335 .55766 .41004 .56949 .40587 .56327 .39896 Mtetra
.674 .753 .91 r
.56327 .39896 .56949 .40587 .58137 .40178 .57519 .3947 Mtetra
.671 .748 .909 r
.57519 .3947 .58137 .40178 .5933 .39773 .58715 .39054 Mtetra
.668 .745 .908 r
.58715 .39054 .5933 .39773 .60529 .3937 .59917 .38643 Mtetra
.667 .743 .907 r
.59917 .38643 .60529 .3937 .61732 .38968 .61124 .38235 Mtetra
.666 .742 .907 r
.61124 .38235 .61732 .38968 .62941 .38565 .62336 .37827 Mtetra
.666 .741 .906 r
.62336 .37827 .62941 .38565 .64155 .38161 .63553 .37419 Mtetra
.63553 .37419 .64155 .38161 .65374 .37755 .64776 .3701 Mtetra
.64776 .3701 .65374 .37755 .66598 .37348 .66004 .36599 Mtetra
.66004 .36599 .66598 .37348 .67827 .36938 .67237 .36187 Mtetra
.67237 .36187 .67827 .36938 .69062 .36526 .68476 .35772 Mtetra
.68476 .35772 .69062 .36526 .70302 .36113 .6972 .35355 Mtetra
.6972 .35355 .70302 .36113 .71548 .35697 .70969 .34936 Mtetra
.70969 .34936 .71548 .35697 .72799 .35279 .72224 .34515 Mtetra
.72224 .34515 .72799 .35279 .74055 .3486 .73484 .34092 Mtetra
.73484 .34092 .74055 .3486 .75317 .34438 .7475 .33667 Mtetra
.7475 .33667 .75317 .34438 .76585 .34015 .76021 .33241 Mtetra
.76021 .33241 .76585 .34015 .77858 .3359 .77298 .32812 Mtetra
.77298 .32812 .77858 .3359 .79136 .33163 .78581 .32382 Mtetra
.78581 .32382 .79136 .33163 .8042 .32734 .79869 .3195 Mtetra
.666 .741 .907 r
.79869 .3195 .8042 .32734 .8171 .32304 .81163 .31516 Mtetra
.81163 .31516 .8171 .32304 .83006 .31871 .82463 .31081 Mtetra
.82463 .31081 .83006 .31871 .84307 .31437 .83768 .30643 Mtetra
.666 .742 .907 r
.83768 .30643 .84307 .31437 .85614 .31002 .85079 .30204 Mtetra
.85079 .30204 .85614 .31002 .86927 .30565 .86397 .29764 Mtetra
.86397 .29764 .86927 .30565 .88246 .30126 .8772 .29321 Mtetra
.658 .74 .91 r
.2742 .48334 .28121 .48987 .29193 .48648 .28494 .47995 Mtetra
.655 .74 .912 r
.28494 .47995 .29193 .48648 .30269 .48312 .29573 .47661 Mtetra
.651 .74 .915 r
.29573 .47661 .30269 .48312 .31349 .47981 .30655 .47338 Mtetra
.644 .742 .92 r
.30655 .47338 .31349 .47981 .32433 .47661 .3174 .47032 Mtetra
.633 .744 .928 r
.3174 .47032 .32433 .47661 .33521 .47355 .32829 .46749 Mtetra
.618 .748 .939 r
.32829 .46749 .33521 .47355 .34613 .47069 .33922 .46498 Mtetra
.596 .754 .954 r
.33922 .46498 .34613 .47069 .35708 .46805 .35017 .46284 Mtetra
.567 .764 .971 r
.35017 .46284 .35708 .46805 .36808 .46564 .36116 .46108 Mtetra
.528 .775 .988 r
.36116 .46108 .36808 .46564 .37911 .46343 .3722 .45965 Mtetra
.483 .788 .998 r
.3722 .45965 .37911 .46343 .3902 .46134 .38328 .45843 Mtetra
.436 .8 .995 r
.38328 .45843 .3902 .46134 .40135 .45923 .39443 .45719 Mtetra
.401 .812 .977 r
.39443 .45719 .40135 .45923 .41256 .45694 .40566 .45568 Mtetra
.393 .829 .953 r
.40566 .45568 .41256 .45694 .42384 .45429 .41696 .45363 Mtetra
.422 .855 .936 r
.41696 .45363 .42384 .45429 .43518 .45115 .42834 .45081 Mtetra
.483 .89 .934 r
.42834 .45081 .43518 .45115 .44659 .44744 .43981 .44711 Mtetra
.559 .923 .944 r
.43981 .44711 .44659 .44744 .45806 .44317 .45134 .44252 Mtetra
.633 .943 .955 r
.45134 .44252 .45806 .44317 .46958 .43842 .46292 .43718 Mtetra
.688 .943 .962 r
.46292 .43718 .46958 .43842 .48115 .43334 .47456 .43131 Mtetra
.72 .926 .96 r
.47456 .43131 .48115 .43334 .49276 .42809 .48623 .42517 Mtetra
.732 .898 .954 r
.48623 .42517 .49276 .42809 .50441 .42282 .49794 .41899 Mtetra
.731 .867 .944 r
.49794 .41899 .50441 .42282 .5161 .41766 .50967 .41299 Mtetra
.723 .837 .935 r
.50967 .41299 .5161 .41766 .52782 .41268 .52145 .40728 Mtetra
.711 .811 .927 r
.52145 .40728 .52782 .41268 .53959 .40791 .53326 .40192 Mtetra
.699 .789 .92 r
.53326 .40192 .53959 .40791 .55141 .40335 .54511 .3969 Mtetra
.689 .773 .915 r
.54511 .3969 .55141 .40335 .56327 .39896 .55701 .39218 Mtetra
.681 .761 .912 r
.55701 .39218 .56327 .39896 .57519 .3947 .56896 .38768 Mtetra
.675 .753 .91 r
.56896 .38768 .57519 .3947 .58715 .39054 .58095 .38336 Mtetra
.671 .748 .908 r
.58095 .38336 .58715 .39054 .59917 .38643 .593 .37914 Mtetra
.668 .745 .907 r
.593 .37914 .59917 .38643 .61124 .38235 .60511 .37498 Mtetra
.667 .743 .907 r
.60511 .37498 .61124 .38235 .62336 .37827 .61726 .37085 Mtetra
.666 .742 .907 r
.61726 .37085 .62336 .37827 .63553 .37419 .62947 .36673 Mtetra
.666 .741 .907 r
.62947 .36673 .63553 .37419 .64776 .3701 .64173 .3626 Mtetra
.64173 .3626 .64776 .3701 .66004 .36599 .65405 .35846 Mtetra
.65405 .35846 .66004 .36599 .67237 .36187 .66642 .3543 Mtetra
.66642 .3543 .67237 .36187 .68476 .35772 .67884 .35012 Mtetra
.67884 .35012 .68476 .35772 .6972 .35355 .69132 .34592 Mtetra
.69132 .34592 .6972 .35355 .70969 .34936 .70385 .3417 Mtetra
.666 .741 .906 r
.70385 .3417 .70969 .34936 .72224 .34515 .71644 .33745 Mtetra
.71644 .33745 .72224 .34515 .73484 .34092 .72908 .33319 Mtetra
.72908 .33319 .73484 .34092 .7475 .33667 .74178 .32891 Mtetra
.74178 .32891 .7475 .33667 .76021 .33241 .75453 .3246 Mtetra
.75453 .3246 .76021 .33241 .77298 .32812 .76734 .32028 Mtetra
.76734 .32028 .77298 .32812 .78581 .32382 .7802 .31595 Mtetra
.7802 .31595 .78581 .32382 .79869 .3195 .79313 .31159 Mtetra
.79313 .31159 .79869 .3195 .81163 .31516 .80611 .30722 Mtetra
.666 .741 .907 r
.80611 .30722 .81163 .31516 .82463 .31081 .81915 .30283 Mtetra
.81915 .30283 .82463 .31081 .83768 .30643 .83225 .29842 Mtetra
.83225 .29842 .83768 .30643 .85079 .30204 .8454 .294 Mtetra
.8454 .294 .85079 .30204 .86397 .29764 .85862 .28956 Mtetra
.85862 .28956 .86397 .29764 .8772 .29321 .8719 .2851 Mtetra
.656 .74 .911 r
.26713 .47676 .2742 .48334 .28494 .47995 .2779 .47339 Mtetra
.652 .74 .914 r
.2779 .47339 .28494 .47995 .29573 .47661 .2887 .4701 Mtetra
.646 .74 .918 r
.2887 .4701 .29573 .47661 .30655 .47338 .29954 .46699 Mtetra
.635 .742 .926 r
.29954 .46699 .30655 .47338 .3174 .47032 .31041 .46413 Mtetra
.617 .744 .937 r
.31041 .46413 .3174 .47032 .32829 .46749 .32131 .46163 Mtetra
.59 .748 .952 r
.32131 .46163 .32829 .46749 .33922 .46498 .33223 .45962 Mtetra
.549 .753 .972 r
.33223 .45962 .33922 .46498 .35017 .46284 .34317 .45818 Mtetra
.487 .757 .99 r
.34317 .45818 .35017 .46284 .36116 .46108 .35414 .45734 Mtetra
.397 .753 .993 r
.35414 .45734 .36116 .46108 .3722 .45965 .36516 .45701 Mtetra
.279 .729 .959 r
.36516 .45701 .3722 .45965 .38328 .45843 .37622 .457 Mtetra
.156 .682 .873 r
.37622 .457 .38328 .45843 .39443 .45719 .38736 .45701 Mtetra
.071 .633 .762 r
.38736 .45701 .39443 .45719 .40566 .45568 .39859 .45663 Mtetra
0 0 0 r
.39859 .45663 .40566 .45568 .41696 .45363 .40991 .45544 Mtetra
.40991 .45544 .41696 .45363 .42834 .45081 .42134 .45312 Mtetra
.42134 .45312 .42834 .45081 .43981 .44711 .43286 .44947 Mtetra
.347 .813 .725 r
.43286 .44947 .43981 .44711 .45134 .44252 .44447 .44449 Mtetra
.501 .905 .806 r
.44447 .44449 .45134 .44252 .46292 .43718 .45614 .43836 Mtetra
.63 .963 .876 r
.45614 .43836 .46292 .43718 .47456 .43131 .46786 .43141 Mtetra
.714 .976 .92 r
.46786 .43141 .47456 .43131 .48623 .42517 .47961 .42404 Mtetra
.753 .957 .939 r
.47961 .42404 .48623 .42517 .49794 .41899 .49139 .4166 Mtetra
.762 .921 .942 r
.49139 .4166 .49794 .41899 .50967 .41299 .50318 .40942 Mtetra
.753 .881 .937 r
.50318 .40942 .50967 .41299 .52145 .40728 .51501 .40268 Mtetra
.737 .844 .93 r
.51501 .40268 .52145 .40728 .53326 .40192 .52687 .39648 Mtetra
.719 .813 .924 r
.52687 .39648 .53326 .40192 .54511 .3969 .53876 .39081 Mtetra
.703 .789 .918 r
.53876 .39081 .54511 .3969 .55701 .39218 .55069 .3856 Mtetra
.691 .772 .914 r
.55069 .3856 .55701 .39218 .56896 .38768 .56267 .38077 Mtetra
.681 .76 .911 r
.56267 .38077 .56896 .38768 .58095 .38336 .57471 .37622 Mtetra
.675 .752 .909 r
.57471 .37622 .58095 .38336 .593 .37914 .58679 .37185 Mtetra
.67 .747 .908 r
.58679 .37185 .593 .37914 .60511 .37498 .59893 .3676 Mtetra
.668 .745 .908 r
.59893 .3676 .60511 .37498 .61726 .37085 .61112 .36341 Mtetra
.667 .743 .907 r
.61112 .36341 .61726 .37085 .62947 .36673 .62336 .35924 Mtetra
.666 .742 .907 r
.62336 .35924 .62947 .36673 .64173 .3626 .63566 .35508 Mtetra
.63566 .35508 .64173 .3626 .65405 .35846 .64802 .3509 Mtetra
.64802 .3509 .65405 .35846 .66642 .3543 .66042 .34671 Mtetra
.66042 .34671 .66642 .3543 .67884 .35012 .67288 .3425 Mtetra
.67288 .3425 .67884 .35012 .69132 .34592 .6854 .33826 Mtetra
.666 .743 .907 r
.6854 .33826 .69132 .34592 .70385 .3417 .69797 .334 Mtetra
.69797 .334 .70385 .3417 .71644 .33745 .71059 .32972 Mtetra
.666 .742 .907 r
.71059 .32972 .71644 .33745 .72908 .33319 .72327 .32542 Mtetra
.72327 .32542 .72908 .33319 .74178 .32891 .73601 .3211 Mtetra
.73601 .3211 .74178 .32891 .75453 .3246 .7488 .31675 Mtetra
.7488 .31675 .75453 .3246 .76734 .32028 .76165 .31239 Mtetra
.76165 .31239 .76734 .32028 .7802 .31595 .77456 .30801 Mtetra
.77456 .30801 .7802 .31595 .79313 .31159 .78752 .30362 Mtetra
.666 .741 .907 r
.78752 .30362 .79313 .31159 .80611 .30722 .80054 .29921 Mtetra
.80054 .29921 .80611 .30722 .81915 .30283 .81363 .29479 Mtetra
.81363 .29479 .81915 .30283 .83225 .29842 .82677 .29034 Mtetra
.82677 .29034 .83225 .29842 .8454 .294 .83997 .28588 Mtetra
.83997 .28588 .8454 .294 .85862 .28956 .85322 .28141 Mtetra
.665 .741 .907 r
.85322 .28141 .85862 .28956 .8719 .2851 .86655 .27691 Mtetra
.654 .739 .912 r
.26001 .47015 .26713 .47676 .2779 .47339 .2708 .4668 Mtetra
.648 .74 .916 r
.2708 .4668 .2779 .47339 .2887 .4701 .28163 .46359 Mtetra
.638 .74 .922 r
.28163 .46359 .2887 .4701 .29954 .46699 .29248 .46063 Mtetra
.621 .741 .932 r
.29248 .46063 .29954 .46699 .31041 .46413 .30335 .45805 Mtetra
.594 .742 .947 r
.30335 .45805 .31041 .46413 .32131 .46163 .31424 .456 Mtetra
.548 .743 .967 r
.31424 .456 .32131 .46163 .33223 .45962 .32515 .45466 Mtetra
.471 .739 .986 r
.32515 .45466 .33223 .45962 .34317 .45818 .33607 .45415 Mtetra
.343 .716 .985 r
.33607 .45415 .34317 .45818 .35414 .45734 .34701 .45451 Mtetra
.149 .644 .914 r
.34701 .45451 .35414 .45734 .36516 .45701 .35798 .45564 Mtetra
0 .511 .738 r
.35798 .45564 .36516 .45701 .37622 .457 .36901 .45727 Mtetra
.229 0 0 r
.36901 .45727 .37622 .457 .38736 .45701 .38012 .45893 Mtetra
.292 0 0 r
.38012 .45893 .38736 .45701 .39859 .45663 .39133 .46007 Mtetra
.28 0 0 r
.39133 .46007 .39859 .45663 .40991 .45544 .40267 .46009 Mtetra
.21 0 0 r
.40267 .46009 .40991 .45544 .42134 .45312 .41414 .45848 Mtetra
.089 0 0 r
.41414 .45848 .42134 .45312 .43286 .44947 .42573 .45496 Mtetra
0 0 0 r
.42573 .45496 .43286 .44947 .44447 .44449 .43743 .44951 Mtetra
.43743 .44951 .44447 .44449 .45614 .43836 .4492 .44238 Mtetra
.497 .875 .67 r
.4492 .44238 .45614 .43836 .46786 .43141 .46102 .43404 Mtetra
.662 .968 .797 r
.46102 .43404 .46786 .43141 .47961 .42404 .47287 .42505 Mtetra
.756 .993 .876 r
.47287 .42505 .47961 .42404 .49139 .4166 .48474 .41595 Mtetra
.79 .97 .914 r
.48474 .41595 .49139 .4166 .50318 .40942 .49662 .40719 Mtetra
.788 .928 .927 r
.49662 .40719 .50318 .40942 .51501 .40268 .50851 .39907 Mtetra
.769 .883 .928 r
.50851 .39907 .51501 .40268 .52687 .39648 .52041 .39172 Mtetra
.745 .843 .924 r
.52041 .39172 .52687 .39648 .53876 .39081 .53235 .38517 Mtetra
.723 .81 .919 r
.53235 .38517 .53876 .39081 .55069 .3856 .54433 .37931 Mtetra
.704 .786 .915 r
.54433 .37931 .55069 .3856 .56267 .38077 .55634 .37403 Mtetra
.69 .769 .912 r
.55634 .37403 .56267 .38077 .57471 .37622 .56841 .36918 Mtetra
.68 .758 .91 r
.56841 .36918 .57471 .37622 .58679 .37185 .58053 .36462 Mtetra
.673 .751 .909 r
.58053 .36462 .58679 .37185 .59893 .3676 .5927 .36025 Mtetra
.669 .747 .909 r
.5927 .36025 .59893 .3676 .61112 .36341 .60493 .35598 Mtetra
.667 .745 .909 r
.60493 .35598 .61112 .36341 .62336 .35924 .61721 .35177 Mtetra
.666 .745 .909 r
.61721 .35177 .62336 .35924 .63566 .35508 .62954 .34757 Mtetra
.665 .745 .909 r
.62954 .34757 .63566 .35508 .64802 .3509 .64193 .34337 Mtetra
.64193 .34337 .64802 .3509 .66042 .34671 .65438 .33915 Mtetra
.666 .745 .91 r
.65438 .33915 .66042 .34671 .67288 .3425 .66688 .33491 Mtetra
.66688 .33491 .67288 .3425 .6854 .33826 .67943 .33064 Mtetra
.666 .746 .909 r
.67943 .33064 .6854 .33826 .69797 .334 .69204 .32634 Mtetra
.667 .745 .909 r
.69204 .32634 .69797 .334 .71059 .32972 .7047 .32202 Mtetra
.7047 .32202 .71059 .32972 .72327 .32542 .71742 .31766 Mtetra
.667 .745 .908 r
.71742 .31766 .72327 .32542 .73601 .3211 .7302 .31328 Mtetra
.667 .744 .908 r
.7302 .31328 .73601 .3211 .7488 .31675 .74303 .30888 Mtetra
.74303 .30888 .7488 .31675 .76165 .31239 .75592 .30447 Mtetra
.667 .743 .907 r
.75592 .30447 .76165 .31239 .77456 .30801 .76886 .30004 Mtetra
.666 .742 .907 r
.76886 .30004 .77456 .30801 .78752 .30362 .78187 .2956 Mtetra
.78187 .2956 .78752 .30362 .80054 .29921 .79493 .29114 Mtetra
.79493 .29114 .80054 .29921 .81363 .29479 .80806 .28668 Mtetra
.666 .741 .907 r
.80806 .28668 .81363 .29479 .82677 .29034 .82124 .2822 Mtetra
.82124 .2822 .82677 .29034 .83997 .28588 .83448 .2777 Mtetra
.665 .741 .907 r
.83448 .2777 .83997 .28588 .85322 .28141 .84779 .27319 Mtetra
.84779 .27319 .85322 .28141 .86655 .27691 .86115 .26866 Mtetra
.652 .739 .913 r
.25284 .46349 .26001 .47015 .2708 .4668 .26365 .46018 Mtetra
.644 .739 .918 r
.26365 .46018 .2708 .4668 .28163 .46359 .27449 .45708 Mtetra
.629 .739 .927 r
.27449 .45708 .28163 .46359 .29248 .46063 .28535 .45432 Mtetra
.604 .739 .94 r
.28535 .45432 .29248 .46063 .30335 .45805 .29623 .45208 Mtetra
.561 .737 .958 r
.29623 .45208 .30335 .45805 .31424 .456 .3071 .4506 Mtetra
.483 .729 .979 r
.3071 .4506 .31424 .456 .32515 .45466 .31798 .45009 Mtetra
.343 .697 .983 r
.31798 .45009 .32515 .45466 .33607 .45415 .32886 .45074 Mtetra
.105 .598 .905 r
.32886 .45074 .33607 .45415 .34701 .45451 .33974 .45261 Mtetra
.191 0 0 r
.33974 .45261 .34701 .45451 .35798 .45564 .35065 .45556 Mtetra
.404 0 0 r
.35065 .45556 .35798 .45564 .36901 .45727 .36161 .45923 Mtetra
.491 0 0 r
.36161 .45923 .36901 .45727 .38012 .45893 .37267 .463 Mtetra
.498 0 0 r
.37267 .463 .38012 .45893 .39133 .46007 .38386 .46608 Mtetra
.457 0 .005 r
.38386 .46608 .39133 .46007 .40267 .46009 .39521 .46765 Mtetra
.379 0 .009 r
.39521 .46765 .40267 .46009 .41414 .45848 .40672 .467 Mtetra
.261 0 0 r
.40672 .467 .41414 .45848 .42573 .45496 .41839 .46371 Mtetra
.098 0 0 r
.41839 .46371 .42573 .45496 .43743 .44951 .43019 .45774 Mtetra
0 0 0 r
.43019 .45774 .43743 .44951 .4492 .44238 .44208 .44942 Mtetra
.44208 .44942 .4492 .44238 .46102 .43404 .45403 .43938 Mtetra
.578 .892 .62 r
.45403 .43938 .46102 .43404 .47287 .42505 .46601 .42838 Mtetra
.734 .983 .764 r
.46601 .42838 .47287 .42505 .48474 .41595 .47799 .41719 Mtetra
.809 .997 .853 r
.47799 .41719 .48474 .41595 .49662 .40719 .48996 .40644 Mtetra
.823 .967 .897 r
.48996 .40644 .49662 .40719 .50851 .39907 .50193 .39656 Mtetra
.806 .921 .914 r
.50193 .39656 .50851 .39907 .52041 .39172 .5139 .38776 Mtetra
.777 .874 .919 r
.5139 .38776 .52041 .39172 .53235 .38517 .52589 .38007 Mtetra
.747 .834 .918 r
.52589 .38007 .53235 .38517 .54433 .37931 .5379 .37338 Mtetra
.721 .803 .916 r
.5379 .37338 .54433 .37931 .55634 .37403 .54996 .36751 Mtetra
.701 .781 .914 r
.54996 .36751 .55634 .37403 .56841 .36918 .56206 .36228 Mtetra
.686 .766 .912 r
.56206 .36228 .56841 .36918 .58053 .36462 .57422 .35748 Mtetra
.676 .757 .912 r
.57422 .35748 .58053 .36462 .5927 .36025 .58643 .35297 Mtetra
.67 .752 .912 r
.58643 .35297 .5927 .36025 .60493 .35598 .59869 .34864 Mtetra
.667 .75 .912 r
.59869 .34864 .60493 .35598 .61721 .35177 .61101 .34439 Mtetra
.665 .749 .913 r
.61101 .34439 .61721 .35177 .62954 .34757 .62338 .34019 Mtetra
.665 .75 .914 r
.62338 .34019 .62954 .34757 .64193 .34337 .63581 .33598 Mtetra
.665 .751 .914 r
.63581 .33598 .64193 .34337 .65438 .33915 .64829 .33176 Mtetra
.665 .752 .915 r
.64829 .33176 .65438 .33915 .66688 .33491 .66083 .3275 Mtetra
.666 .752 .915 r
.66083 .3275 .66688 .33491 .67943 .33064 .67343 .3232 Mtetra
.667 .753 .915 r
.67343 .3232 .67943 .33064 .69204 .32634 .68608 .31886 Mtetra
.668 .753 .914 r
.68608 .31886 .69204 .32634 .7047 .32202 .69878 .31446 Mtetra
.668 .752 .913 r
.69878 .31446 .7047 .32202 .71742 .31766 .71154 .31003 Mtetra
.669 .751 .912 r
.71154 .31003 .71742 .31766 .7302 .31328 .72435 .30556 Mtetra
.669 .749 .911 r
.72435 .30556 .7302 .31328 .74303 .30888 .73722 .30107 Mtetra
.668 .748 .91 r
.73722 .30107 .74303 .30888 .75592 .30447 .75014 .29657 Mtetra
.668 .746 .909 r
.75014 .29657 .75592 .30447 .76886 .30004 .76313 .29206 Mtetra
.667 .744 .908 r
.76313 .29206 .76886 .30004 .78187 .2956 .77617 .28754 Mtetra
.667 .743 .907 r
.77617 .28754 .78187 .2956 .79493 .29114 .78928 .28303 Mtetra
.666 .742 .907 r
.78928 .28303 .79493 .29114 .80806 .28668 .80244 .27851 Mtetra
.80244 .27851 .80806 .28668 .82124 .2822 .81567 .27399 Mtetra
.81567 .27399 .82124 .2822 .83448 .2777 .82895 .26945 Mtetra
.666 .741 .907 r
.82895 .26945 .83448 .2777 .84779 .27319 .8423 .2649 Mtetra
.665 .741 .907 r
.8423 .2649 .84779 .27319 .86115 .26866 .85571 .26033 Mtetra
.649 .739 .915 r
.24561 .4568 .25284 .46349 .26365 .46018 .25644 .45354 Mtetra
.638 .738 .921 r
.25644 .45354 .26365 .46018 .27449 .45708 .26729 .45056 Mtetra
.618 .737 .931 r
.26729 .45056 .27449 .45708 .28535 .45432 .27816 .44803 Mtetra
.582 .734 .947 r
.27816 .44803 .28535 .45432 .29623 .45208 .28903 .44621 Mtetra
.517 .726 .968 r
.28903 .44621 .29623 .45208 .3071 .4506 .29989 .44538 Mtetra
.393 .698 .982 r
.29989 .44538 .3071 .4506 .31798 .45009 .31072 .44585 Mtetra
.16 .606 .934 r
.31072 .44585 .31798 .45009 .32886 .45074 .32154 .44786 Mtetra
0 .391 .716 r
.32154 .44786 .32886 .45074 .33974 .45261 .33235 .45149 Mtetra
.468 0 0 r
.33235 .45149 .33974 .45261 .35065 .45556 .34317 .45659 Mtetra
.592 .043 0 r
.34317 .45659 .35065 .45556 .36161 .45923 .35405 .46267 Mtetra
.62 .118 .038 r
.35405 .46267 .36161 .45923 .37267 .463 .36503 .46893 Mtetra
.599 .133 .117 r
.36503 .46893 .37267 .463 .38386 .46608 .37618 .47434 Mtetra
.548 .104 .148 r
.37618 .47434 .38386 .46608 .39521 .46765 .38751 .4778 Mtetra
.466 .039 .143 r
.38751 .4778 .39521 .46765 .40672 .467 .39906 .47837 Mtetra
.349 0 .103 r
.39906 .47837 .40672 .467 .41839 .46371 .41081 .47544 Mtetra
.188 0 .022 r
.41081 .47544 .41839 .46371 .43019 .45774 .42273 .46894 Mtetra
0 0 0 r
.42273 .46894 .43019 .45774 .44208 .44942 .43477 .45928 Mtetra
.43477 .45928 .44208 .44942 .45403 .43938 .44688 .44727 Mtetra
.44688 .44727 .45403 .43938 .46601 .42838 .459 .43393 Mtetra
.714 .946 .648 r
.459 .43393 .46601 .42838 .47799 .41719 .47111 .42028 Mtetra
.821 .997 .773 r
.47111 .42028 .47799 .41719 .48996 .40644 .4832 .40716 Mtetra
.854 .988 .848 r
.4832 .40716 .48996 .40644 .50193 .39656 .49526 .39517 Mtetra
.843 .949 .887 r
.49526 .39517 .50193 .39656 .5139 .38776 .50731 .38461 Mtetra
.811 .902 .905 r
.50731 .38461 .5139 .38776 .52589 .38007 .51936 .37553 Mtetra
.774 .857 .912 r
.51936 .37553 .52589 .38007 .5379 .37338 .53143 .36783 Mtetra
.741 .821 .914 r
.53143 .36783 .5379 .37338 .54996 .36751 .54352 .36126 Mtetra
.714 .794 .915 r
.54352 .36126 .54996 .36751 .56206 .36228 .55566 .35558 Mtetra
.693 .776 .915 r
.55566 .35558 .56206 .36228 .57422 .35748 .56786 .35052 Mtetra
.68 .765 .916 r
.56786 .35052 .57422 .35748 .58643 .35297 .5801 .34589 Mtetra
.671 .76 .917 r
.5801 .34589 .58643 .35297 .59869 .34864 .5924 .34152 Mtetra
.665 .758 .919 r
.5924 .34152 .59869 .34864 .61101 .34439 .60476 .33729 Mtetra
.662 .758 .921 r
.60476 .33729 .61101 .34439 .62338 .34019 .61718 .33313 Mtetra
.661 .76 .923 r
.61718 .33313 .62338 .34019 .63581 .33598 .62965 .32898 Mtetra
.662 .763 .925 r
.62965 .32898 .63581 .33598 .64829 .33176 .64218 .3248 Mtetra
.663 .766 .927 r
.64218 .3248 .64829 .33176 .66083 .3275 .65476 .32057 Mtetra
.665 .769 .927 r
.65476 .32057 .66083 .3275 .67343 .3232 .6674 .31625 Mtetra
.667 .77 .927 r
.6674 .31625 .67343 .3232 .68608 .31886 .68009 .31185 Mtetra
.669 .77 .925 r
.68009 .31185 .68608 .31886 .69878 .31446 .69283 .30735 Mtetra
.671 .769 .923 r
.69283 .30735 .69878 .31446 .71154 .31003 .70562 .30277 Mtetra
.673 .766 .92 r
.70562 .30277 .71154 .31003 .72435 .30556 .71847 .29814 Mtetra
.673 .762 .917 r
.71847 .29814 .72435 .30556 .73722 .30107 .73137 .29347 Mtetra
.673 .758 .915 r
.73137 .29347 .73722 .30107 .75014 .29657 .74434 .2888 Mtetra
.671 .753 .912 r
.74434 .2888 .75014 .29657 .76313 .29206 .75735 .28414 Mtetra
.67 .75 .91 r
.75735 .28414 .76313 .29206 .77617 .28754 .77043 .27951 Mtetra
.669 .746 .909 r
.77043 .27951 .77617 .28754 .78928 .28303 .78358 .2749 Mtetra
.667 .744 .908 r
.78358 .2749 .78928 .28303 .80244 .27851 .79678 .2703 Mtetra
.667 .743 .907 r
.79678 .2703 .80244 .27851 .81567 .27399 .81005 .26572 Mtetra
.666 .742 .907 r
.81005 .26572 .81567 .27399 .82895 .26945 .82338 .26113 Mtetra
.82338 .26113 .82895 .26945 .8423 .2649 .83677 .25654 Mtetra
.665 .741 .907 r
.83677 .25654 .8423 .2649 .85571 .26033 .85022 .25193 Mtetra
.646 .738 .916 r
.23832 .45006 .24561 .4568 .25644 .45354 .24917 .44686 Mtetra
.631 .737 .924 r
.24917 .44686 .25644 .45354 .26729 .45056 .26004 .44401 Mtetra
.605 .734 .936 r
.26004 .44401 .26729 .45056 .27816 .44803 .27091 .44175 Mtetra
.556 .727 .954 r
.27091 .44175 .27816 .44803 .28903 .44621 .28176 .44038 Mtetra
.462 .707 .974 r
.28176 .44038 .28903 .44621 .29989 .44538 .29259 .44027 Mtetra
.277 .644 .966 r
.29259 .44027 .29989 .44538 .31072 .44585 .30338 .44181 Mtetra
0 .466 .828 r
.30338 .44181 .31072 .44585 .32154 .44786 .31413 .4453 Mtetra
.426 0 0 r
.31413 .4453 .32154 .44786 .33235 .45149 .32484 .45087 Mtetra
.626 .068 0 r
.32484 .45087 .33235 .45149 .34317 .45659 .33555 .45832 Mtetra
.689 .185 .04 r
.33555 .45832 .34317 .45659 .35405 .46267 .34632 .46706 Mtetra
.69 .227 .149 r
.34632 .46706 .35405 .46267 .36503 .46893 .35721 .4761 Mtetra
.659 .223 .203 r
.35721 .4761 .36503 .46893 .37618 .47434 .36829 .48413 Mtetra
.602 .184 .222 r
.36829 .48413 .37618 .47434 .38751 .4778 .37961 .48975 Mtetra
.517 .112 .211 r
.37961 .48975 .38751 .4778 .39906 .47837 .39119 .49173 Mtetra
.395 0 .168 r
.39119 .49173 .39906 .47837 .41081 .47544 .40302 .4893 Mtetra
.223 0 .086 r
.40302 .4893 .41081 .47544 .42273 .46894 .41507 .48231 Mtetra
0 0 0 r
.41507 .48231 .42273 .46894 .43477 .45928 .42727 .47124 Mtetra
.42727 .47124 .43477 .45928 .44688 .44727 .43955 .45711 Mtetra
.43955 .45711 .44688 .44727 .459 .43393 .45184 .4412 Mtetra
.731 .925 .579 r
.45184 .4412 .459 .43393 .47111 .42028 .46412 .42481 Mtetra
.843 .986 .71 r
.46412 .42481 .47111 .42028 .4832 .40716 .47634 .40905 Mtetra
.883 .99 .797 r
.47634 .40905 .4832 .40716 .49526 .39517 .48851 .39468 Mtetra
.876 .962 .852 r
.48851 .39468 .49526 .39517 .50731 .38461 .50065 .38213 Mtetra
.844 .92 .884 r
.50065 .38213 .50731 .38461 .51936 .37553 .51277 .3715 Mtetra
.802 .876 .901 r
.51277 .3715 .51936 .37553 .53143 .36783 .52489 .36266 Mtetra
.762 .838 .91 r
.52489 .36266 .53143 .36783 .54352 .36126 .53703 .35532 Mtetra
.727 .809 .916 r
.53703 .35532 .54352 .36126 .55566 .35558 .54921 .34917 Mtetra
.7 .789 .919 r
.54921 .34917 .55566 .35558 .56786 .35052 .56144 .34387 Mtetra
.681 .777 .923 r
.56144 .34387 .56786 .35052 .5801 .34589 .57373 .33917 Mtetra
.668 .772 .928 r
.57373 .33917 .5801 .34589 .5924 .34152 .58607 .33485 Mtetra
.659 .772 .933 r
.58607 .33485 .5924 .34152 .60476 .33729 .59848 .33075 Mtetra
.654 .775 .938 r
.59848 .33075 .60476 .33729 .61718 .33313 .61094 .32677 Mtetra
.651 .781 .943 r
.61094 .32677 .61718 .33313 .62965 .32898 .62346 .32281 Mtetra
.652 .789 .948 r
.62346 .32281 .62965 .32898 .64218 .3248 .63604 .31879 Mtetra
.654 .796 .951 r
.63604 .31879 .64218 .3248 .65476 .32057 .64868 .31467 Mtetra
.659 .803 .952 r
.64868 .31467 .65476 .32057 .6674 .31625 .66136 .31037 Mtetra
.665 .807 .951 r
.66136 .31037 .6674 .31625 .68009 .31185 .6741 .30589 Mtetra
.672 .807 .948 r
.6741 .30589 .68009 .31185 .69283 .30735 .68688 .30121 Mtetra
.677 .804 .943 r
.68688 .30121 .69283 .30735 .70562 .30277 .69971 .29637 Mtetra
.681 .798 .937 r
.69971 .29637 .70562 .30277 .71847 .29814 .71259 .29141 Mtetra
.683 .789 .93 r
.71259 .29141 .71847 .29814 .73137 .29347 .72552 .2864 Mtetra
.682 .779 .924 r
.72552 .2864 .73137 .29347 .74434 .2888 .73851 .28139 Mtetra
.679 .769 .919 r
.73851 .28139 .74434 .2888 .75735 .28414 .75155 .27645 Mtetra
.676 .76 .914 r
.75155 .27645 .75735 .28414 .77043 .27951 .76466 .27158 Mtetra
.673 .753 .911 r
.76466 .27158 .77043 .27951 .78358 .2749 .77784 .2668 Mtetra
.67 .748 .909 r
.77784 .2668 .78358 .2749 .79678 .2703 .79108 .26208 Mtetra
.668 .745 .908 r
.79108 .26208 .79678 .2703 .81005 .26572 .80438 .25741 Mtetra
.667 .743 .907 r
.80438 .25741 .81005 .26572 .82338 .26113 .81775 .25276 Mtetra
.666 .742 .907 r
.81775 .25276 .82338 .26113 .83677 .25654 .83119 .24811 Mtetra
.83119 .24811 .83677 .25654 .85022 .25193 .84469 .24347 Mtetra
.642 .737 .918 r
.23098 .44327 .23832 .45006 .24917 .44686 .24185 .44013 Mtetra
.624 .735 .926 r
.24185 .44013 .24917 .44686 .26004 .44401 .25272 .43742 Mtetra
.591 .73 .94 r
.25272 .43742 .26004 .44401 .27091 .44175 .26359 .43543 Mtetra
.527 .717 .959 r
.26359 .43543 .27091 .44175 .28176 .44038 .27444 .43451 Mtetra
.401 .681 .974 r
.27444 .43451 .28176 .44038 .29259 .44027 .28524 .43514 Mtetra
.149 .571 .93 r
.28524 .43514 .29259 .44027 .30338 .44181 .29597 .43776 Mtetra
0 .31 .695 r
.29597 .43776 .30338 .44181 .31413 .4453 .30663 .44276 Mtetra
.576 0 0 r
.30663 .44276 .31413 .4453 .32484 .45087 .31724 .45029 Mtetra
.712 .188 0 r
.31724 .45029 .32484 .45087 .33555 .45832 .32783 .46014 Mtetra
.746 .271 .119 r
.32783 .46014 .33555 .45832 .34632 .46706 .33848 .47161 Mtetra
.737 .295 .203 r
.33848 .47161 .34632 .46706 .35721 .4761 .34926 .4835 Mtetra
.703 .281 .243 r
.34926 .4835 .35721 .4761 .36829 .48413 .36025 .49425 Mtetra
.644 .235 .254 r
.36025 .49425 .36829 .48413 .37961 .48975 .37153 .50214 Mtetra
.553 .153 .236 r
.37153 .50214 .37961 .48975 .39119 .49173 .38313 .50567 Mtetra
.417 .025 .185 r
.38313 .50567 .39119 .49173 .40302 .4893 .39505 .50384 Mtetra
.217 0 .09 r
.39505 .50384 .40302 .4893 .41507 .48231 .40723 .49643 Mtetra
0 0 0 r
.40723 .49643 .41507 .48231 .42727 .47124 .41959 .484 Mtetra
.41959 .484 .42727 .47124 .43955 .45711 .43206 .46774 Mtetra
.62 .827 .426 r
.43206 .46774 .43955 .45711 .45184 .4412 .44455 .44922 Mtetra
.794 .935 .574 r
.44455 .44922 .45184 .4412 .46412 .42481 .45699 .43002 Mtetra
.884 .978 .682 r
.45699 .43002 .46412 .42481 .47634 .40905 .46937 .41152 Mtetra
.914 .98 .761 r
.46937 .41152 .47634 .40905 .48851 .39468 .48167 .39468 Mtetra
.904 .958 .818 r
.48167 .39468 .48851 .39468 .50065 .38213 .49391 .38007 Mtetra
.871 .924 .859 r
.49391 .38007 .50065 .38213 .51277 .3715 .5061 .36782 Mtetra
.827 .887 .886 r
.5061 .36782 .51277 .3715 .52489 .36266 .51828 .35781 Mtetra
.781 .852 .904 r
.51828 .35781 .52489 .36266 .53703 .35532 .53048 .34971 Mtetra
.739 .824 .917 r
.53048 .34971 .53703 .35532 .54921 .34917 .54271 .34314 Mtetra
.704 .804 .927 r
.54271 .34314 .54921 .34917 .56144 .34387 .55498 .3377 Mtetra
.677 .793 .937 r
.55498 .3377 .56144 .34387 .57373 .33917 .56731 .33308 Mtetra
.656 .79 .946 r
.56731 .33308 .57373 .33917 .58607 .33485 .5797 .32899 Mtetra
.639 .794 .957 r
.5797 .32899 .58607 .33485 .59848 .33075 .59216 .32526 Mtetra
.627 .804 .967 r
.59216 .32526 .59848 .33075 .61094 .32677 .60468 .32171 Mtetra
.618 .817 .977 r
.60468 .32171 .61094 .32677 .62346 .32281 .61727 .31819 Mtetra
.614 .833 .984 r
.61727 .31819 .62346 .32281 .63604 .31879 .62991 .31457 Mtetra
.616 .85 .987 r
.62991 .31457 .63604 .31879 .64868 .31467 .64261 .31073 Mtetra
.626 .864 .987 r
.64261 .31073 .64868 .31467 .66136 .31037 .65536 .30654 Mtetra
.642 .874 .984 r
.65536 .30654 .66136 .31037 .6741 .30589 .66815 .30195 Mtetra
.661 .878 .979 r
.66815 .30195 .6741 .30589 .68688 .30121 .68097 .29696 Mtetra
.68 .873 .971 r
.68097 .29696 .68688 .30121 .69971 .29637 .69384 .29161 Mtetra
.694 .861 .962 r
.69384 .29161 .69971 .29637 .71259 .29141 .70674 .28603 Mtetra
.7 .842 .951 r
.70674 .28603 .71259 .29141 .72552 .2864 .71968 .28036 Mtetra
.7 .821 .94 r
.71968 .28036 .72552 .2864 .73851 .28139 .73268 .27472 Mtetra
.695 .799 .93 r
.73268 .27472 .73851 .28139 .75155 .27645 .74574 .26923 Mtetra
.688 .781 .921 r
.74574 .26923 .75155 .27645 .76466 .27158 .75886 .26393 Mtetra
.681 .767 .916 r
.75886 .26393 .76466 .27158 .77784 .2668 .77206 .25883 Mtetra
.676 .756 .912 r
.77206 .25883 .77784 .2668 .79108 .26208 .78533 .25389 Mtetra
.671 .749 .909 r
.78533 .25389 .79108 .26208 .80438 .25741 .79868 .24908 Mtetra
.668 .745 .908 r
.79868 .24908 .80438 .25741 .81775 .25276 .81208 .24434 Mtetra
.667 .743 .907 r
.81208 .24434 .81775 .25276 .83119 .24811 .82556 .23963 Mtetra
.666 .742 .907 r
.82556 .23963 .83119 .24811 .84469 .24347 .8391 .23493 Mtetra
.639 .736 .919 r
.22358 .43642 .23098 .44327 .24185 .44013 .23446 .43334 Mtetra
.618 .733 .928 r
.23446 .43334 .24185 .44013 .25272 .43742 .24535 .43076 Mtetra
.578 .725 .943 r
.24535 .43076 .25272 .43742 .26359 .43543 .25622 .42901 Mtetra
.5 .705 .962 r
.25622 .42901 .26359 .43543 .27444 .43451 .26706 .42852 Mtetra
.343 .65 .968 r
.26706 .42852 .27444 .43451 .28524 .43514 .27782 .42982 Mtetra
.036 .493 .883 r
.27782 .42982 .28524 .43514 .29597 .43776 .2885 .43345 Mtetra
.382 0 0 r
.2885 .43345 .29597 .43776 .30663 .44276 .29908 .43985 Mtetra
.66 .105 0 r
.29908 .43985 .30663 .44276 .31724 .45029 .30958 .4492 Mtetra
.762 .261 .019 r
.30958 .4492 .31724 .45029 .32783 .46014 .32005 .46127 Mtetra
.786 .326 .15 r
.32005 .46127 .32783 .46014 .33848 .47161 .33057 .47527 Mtetra
.775 .341 .219 r
.33057 .47527 .33848 .47161 .34926 .4835 .34123 .48983 Mtetra
.742 .322 .251 r
.34123 .48983 .34926 .4835 .36025 .49425 .35214 .50315 Mtetra
.682 .268 .254 r
.35214 .50315 .36025 .49425 .37153 .50214 .36337 .51322 Mtetra
.584 .171 .226 r
.36337 .51322 .37153 .50214 .38313 .50567 .37498 .51826 Mtetra
.421 .012 .156 r
.37498 .51826 .38313 .50567 .39505 .50384 .38697 .51709 Mtetra
.159 0 .025 r
.38697 .51709 .39505 .50384 .40723 .49643 .39927 .50937 Mtetra
0 0 0 r
.39927 .50937 .40723 .49643 .41959 .484 .41181 .49573 Mtetra
.41181 .49573 .41959 .484 .43206 .46774 .42446 .47754 Mtetra
.77 .908 .518 r
.42446 .47754 .43206 .46774 .44455 .44922 .43714 .4566 Mtetra
.885 .957 .617 r
.43714 .4566 .44455 .44922 .45699 .43002 .44977 .43478 Mtetra
.932 .967 .687 r
.44977 .43478 .45699 .43002 .46937 .41152 .46231 .4137 Mtetra
.941 .958 .744 r
.46231 .4137 .46937 .41152 .48167 .39468 .47474 .39454 Mtetra
.924 .94 .793 r
.47474 .39454 .48167 .39468 .49391 .38007 .48708 .37798 Mtetra
.89 .916 .835 r
.48708 .37798 .49391 .38007 .5061 .36782 .49936 .36423 Mtetra
.845 .888 .87 r
.49936 .36423 .5061 .36782 .51828 .35781 .51161 .35317 Mtetra
.795 .861 .898 r
.51161 .35317 .51828 .35781 .53048 .34971 .52387 .34445 Mtetra
.746 .838 .921 r
.52387 .34445 .53048 .34971 .54271 .34314 .53614 .33762 Mtetra
.7 .822 .94 r
.53614 .33762 .54271 .34314 .55498 .3377 .54846 .33226 Mtetra
.659 .814 .958 r
.54846 .33226 .55498 .3377 .56731 .33308 .56085 .32797 Mtetra
.62 .815 .975 r
.56085 .32797 .56731 .33308 .5797 .32899 .57329 .32447 Mtetra
.58 .823 .99 r
.57329 .32447 .5797 .32899 .59216 .32526 .58582 .32149 Mtetra
.538 .835 .999 r
.58582 .32149 .59216 .32526 .60468 .32171 .59841 .31882 Mtetra
.493 .846 .994 r
.59841 .31882 .60468 .32171 .61727 .31819 .61108 .3162 Mtetra
.453 .853 .972 r
.61108 .3162 .61727 .31819 .62991 .31457 .62381 .31339 Mtetra
.43 .859 .939 r
.62381 .31339 .62991 .31457 .64261 .31073 .6366 .31012 Mtetra
.438 .871 .912 r
.6366 .31012 .64261 .31073 .65536 .30654 .64943 .30618 Mtetra
.48 .895 .904 r
.64943 .30618 .65536 .30654 .66815 .30195 .66228 .30145 Mtetra
.548 .926 .917 r
.66228 .30145 .66815 .30195 .68097 .29696 .67516 .29591 Mtetra
.623 .948 .939 r
.67516 .29591 .68097 .29696 .69384 .29161 .68805 .28967 Mtetra
.684 .95 .956 r
.68805 .28967 .69384 .29161 .70674 .28603 .70096 .28297 Mtetra
.719 .928 .96 r
.70096 .28297 .70674 .28603 .71968 .28036 .71389 .2761 Mtetra
.729 .892 .954 r
.71389 .2761 .71968 .28036 .73268 .27472 .72688 .26932 Mtetra
.724 .852 .942 r
.72688 .26932 .73268 .27472 .74574 .26923 .73993 .26284 Mtetra
.711 .817 .931 r
.73993 .26284 .74574 .26923 .75886 .26393 .75306 .25677 Mtetra
.697 .789 .922 r
.75306 .25677 .75886 .26393 .77206 .25883 .76626 .25111 Mtetra
.686 .77 .915 r
.76626 .25111 .77206 .25883 .78533 .25389 .77955 .24581 Mtetra
.677 .757 .911 r
.77955 .24581 .78533 .25389 .79868 .24908 .79293 .24077 Mtetra
.671 .749 .909 r
.79293 .24077 .79868 .24908 .81208 .24434 .80637 .23588 Mtetra
.668 .745 .908 r
.80637 .23588 .81208 .24434 .82556 .23963 .81989 .23108 Mtetra
.666 .743 .907 r
.81989 .23108 .82556 .23963 .8391 .23493 .83347 .22632 Mtetra
.636 .735 .92 r
.21613 .4295 .22358 .43642 .23446 .43334 .22703 .42646 Mtetra
.612 .73 .929 r
.22703 .42646 .23446 .43334 .24535 .43076 .23793 .42399 Mtetra
.567 .719 .944 r
.23793 .42399 .24535 .43076 .25622 .42901 .2488 .42244 Mtetra
.477 .692 .962 r
.2488 .42244 .25622 .42901 .26706 .42852 .25963 .4223 Mtetra
.298 .619 .959 r
.25963 .4223 .26706 .42852 .27782 .42982 .27036 .42415 Mtetra
0 .43 .846 r
.27036 .42415 .27782 .42982 .2885 .43345 .28099 .4286 Mtetra
.451 0 0 r
.28099 .4286 .2885 .43345 .29908 .43985 .2915 .43613 Mtetra
.7 .161 0 r
.2915 .43613 .29908 .43985 .30958 .4492 .30191 .44696 Mtetra
.793 .301 .026 r
.30191 .44696 .30958 .4492 .32005 .46127 .31227 .46084 Mtetra
.817 .36 .143 r
.31227 .46084 .32005 .46127 .33057 .47527 .32267 .47691 Mtetra
.81 .372 .203 r
.32267 .47691 .33057 .47527 .34123 .48983 .33322 .49367 Mtetra
.781 .349 .226 r
.33322 .49367 .34123 .48983 .35214 .50315 .34404 .50911 Mtetra
.723 .288 .216 r
.34404 .50911 .35214 .50315 .36337 .51322 .35523 .52101 Mtetra
.612 .165 .165 r
.35523 .52101 .36337 .51322 .37498 .51826 .36684 .52735 Mtetra
.392 0 .043 r
.36684 .52735 .37498 .51826 .38697 .51709 .37889 .52678 Mtetra
0 0 0 r
.37889 .52678 .38697 .51709 .39927 .50937 .3913 .51889 Mtetra
.3913 .51889 .39927 .50937 .41181 .49573 .40398 .50434 Mtetra
.797 .937 .578 r
.40398 .50434 .41181 .49573 .42446 .47754 .41681 .48461 Mtetra
.914 .961 .637 r
.41681 .48461 .42446 .47754 .43714 .4566 .42967 .46172 Mtetra
.954 .951 .672 r
.42967 .46172 .43714 .4566 .44977 .43478 .44248 .43775 Mtetra
.962 .937 .704 r
.44248 .43775 .44977 .43478 .46231 .4137 .45517 .41455 Mtetra
.953 .923 .738 r
.45517 .41455 .46231 .4137 .47474 .39454 .46774 .39348 Mtetra
.931 .91 .777 r
.46774 .39348 .47474 .39454 .48708 .37798 .48019 .37533 Mtetra
.898 .895 .817 r
.48019 .37533 .48708 .37798 .49936 .36423 .49256 .36041 Mtetra
.854 .88 .857 r
.49256 .36041 .49936 .36423 .51161 .35317 .50488 .34859 Mtetra
.802 .864 .895 r
.50488 .34859 .51161 .35317 .52387 .34445 .51719 .33953 Mtetra
.744 .85 .929 r
.51719 .33953 .52387 .34445 .53614 .33762 .52951 .33276 Mtetra
.68 .841 .96 r
.52951 .33276 .53614 .33762 .54846 .33226 .54189 .32782 Mtetra
.608 .835 .986 r
.54189 .32782 .54846 .33226 .56085 .32797 .55433 .32431 Mtetra
.516 .829 1 r
.55433 .32431 .56085 .32797 .57329 .32447 .56684 .3219 Mtetra
.392 .805 .977 r
.56684 .3219 .57329 .32447 .58582 .32149 .57945 .3203 Mtetra
.231 .74 .885 r
.57945 .3203 .58582 .32149 .59841 .31882 .59214 .31918 Mtetra
.07 .633 .722 r
.59214 .31918 .59841 .31882 .61108 .3162 .60491 .31815 Mtetra
.04 0 0 r
.60491 .31815 .61108 .3162 .62381 .31339 .61777 .31676 Mtetra
.081 0 0 r
.61777 .31676 .62381 .31339 .6366 .31012 .63068 .31454 Mtetra
.059 0 0 r
.63068 .31454 .6366 .31012 .64943 .30618 .64361 .31108 Mtetra
0 0 0 r
.64361 .31108 .64943 .30618 .66228 .30145 .65656 .30614 Mtetra
.65656 .30614 .66228 .30145 .67516 .29591 .66949 .2997 Mtetra
.66949 .2997 .67516 .29591 .68805 .28967 .6824 .29198 Mtetra
.522 .9 .725 r
.6824 .29198 .68805 .28967 .70096 .28297 .6953 .2834 Mtetra
.677 .978 .856 r
.6953 .2834 .70096 .28297 .71389 .2761 .70821 .27452 Mtetra
.752 .975 .923 r
.70821 .27452 .71389 .2761 .72688 .26932 .72115 .26583 Mtetra
.764 .927 .941 r
.72115 .26583 .72688 .26932 .73993 .26284 .73416 .25772 Mtetra
.747 .871 .937 r
.73416 .25772 .73993 .26284 .75306 .25677 .74726 .25038 Mtetra
.724 .824 .927 r
.74726 .25038 .75306 .25677 .76626 .25111 .76045 .24382 Mtetra
.703 .79 .919 r
.76045 .24382 .76626 .25111 .77955 .24581 .77375 .23792 Mtetra
.687 .768 .913 r
.77375 .23792 .77955 .24581 .79293 .24077 .78714 .23251 Mtetra
.677 .755 .91 r
.78714 .23251 .79293 .24077 .80637 .23588 .80061 .22741 Mtetra
.671 .747 .908 r
.80061 .22741 .80637 .23588 .81989 .23108 .81417 .22249 Mtetra
.667 .744 .907 r
.81417 .22249 .81989 .23108 .83347 .22632 .8278 .21765 Mtetra
.635 .734 .92 r
.20861 .42251 .21613 .4295 .22703 .42646 .21953 .41949 Mtetra
.609 .728 .93 r
.21953 .41949 .22703 .42646 .23793 .42399 .23045 .41708 Mtetra
.56 .714 .944 r
.23045 .41708 .23793 .42399 .2488 .42244 .24134 .41566 Mtetra
.464 .681 .96 r
.24134 .41566 .2488 .42244 .25963 .4223 .25216 .41575 Mtetra
.276 .597 .95 r
.25216 .41575 .25963 .4223 .27036 .42415 .26288 .41796 Mtetra
0 .396 .831 r
.26288 .41796 .27036 .42415 .28099 .4286 .27347 .42295 Mtetra
.46 0 0 r
.27347 .42295 .28099 .4286 .2915 .43613 .28393 .43123 Mtetra
.705 .177 0 r
.28393 .43123 .2915 .43613 .30191 .44696 .29427 .44303 Mtetra
.805 .314 0 r
.29427 .44303 .30191 .44696 .31227 .46084 .30455 .45808 Mtetra
.837 .374 .095 r
.30455 .45808 .31227 .46084 .32267 .47691 .31486 .4755 Mtetra
.839 .388 .145 r
.31486 .4755 .32267 .47691 .33322 .49367 .32533 .49368 Mtetra
.817 .363 .152 r
.32533 .49368 .33322 .49367 .34404 .50911 .33608 .51051 Mtetra
.762 .286 .111 r
.33608 .51051 .34404 .50911 .35523 .52101 .34723 .52362 Mtetra
.626 .106 0 r
.34723 .52362 .35523 .52101 .36684 .52735 .35884 .53086 Mtetra
.244 0 0 r
.35884 .53086 .36684 .52735 .37889 .52678 .37093 .53074 Mtetra
.477 .874 .702 r
.37093 .53074 .37889 .52678 .3913 .51889 .38342 .52282 Mtetra
.852 .996 .764 r
.38342 .52282 .3913 .51889 .40398 .50434 .39623 .50774 Mtetra
.943 .959 .73 r
.39623 .50774 .40398 .50434 .41681 .48461 .4092 .48707 Mtetra
.964 .922 .709 r
.4092 .48707 .41681 .48461 .42967 .46172 .42221 .46293 Mtetra
.966 .898 .705 r
.42221 .46293 .42967 .46172 .44248 .43775 .43517 .43759 Mtetra
.959 .883 .714 r
.43517 .43759 .44248 .43775 .45517 .41455 .448 .41301 Mtetra
.945 .874 .735 r
.448 .41301 .45517 .41455 .46774 .39348 .46068 .39071 Mtetra
.924 .869 .766 r
.46068 .39071 .46774 .39348 .48019 .37533 .47323 .37159 Mtetra
.894 .866 .804 r
.47323 .37159 .48019 .37533 .49256 .36041 .48568 .35601 Mtetra
.853 .864 .849 r
.48568 .35601 .49256 .36041 .50488 .34859 .49807 .34391 Mtetra
.798 .862 .897 r
.49807 .34391 .50488 .34859 .51719 .33953 .51044 .33495 Mtetra
.726 .861 .945 r
.51044 .33495 .51719 .33953 .52951 .33276 .52282 .32868 Mtetra
.626 .855 .986 r
.52282 .32868 .52951 .33276 .54189 .32782 .53525 .32466 Mtetra
.473 .827 .996 r
.53525 .32466 .54189 .32782 .55433 .32431 .54775 .32251 Mtetra
.234 .731 .911 r
.54775 .32251 .55433 .32431 .56684 .3219 .56035 .32189 Mtetra
.059 0 0 r
.56035 .32189 .56684 .3219 .57945 .3203 .57305 .32248 Mtetra
.281 0 0 r
.57305 .32248 .57945 .3203 .59214 .31918 .58586 .32383 Mtetra
.386 0 0 r
.58586 .32383 .59214 .31918 .60491 .31815 .59878 .32531 Mtetra
.415 0 0 r
.59878 .32531 .60491 .31815 .61777 .31676 .61179 .32618 Mtetra
.397 0 .053 r
.61179 .32618 .61777 .31676 .63068 .31454 .62486 .32563 Mtetra
.348 0 .078 r
.62486 .32563 .63068 .31454 .64361 .31108 .63795 .32293 Mtetra
.269 0 .064 r
.63795 .32293 .64361 .31108 .65656 .30614 .65101 .31769 Mtetra
.154 0 .008 r
.65101 .31769 .65656 .30614 .66949 .2997 .66401 .30986 Mtetra
0 0 0 r
.66401 .30986 .66949 .2997 .6824 .29198 .67694 .29984 Mtetra
.67694 .29984 .6824 .29198 .6953 .2834 .68981 .28839 Mtetra
.493 .825 .528 r
.68981 .28839 .6953 .2834 .70821 .27452 .70265 .27643 Mtetra
.708 .974 .757 r
.70265 .27643 .70821 .27452 .72115 .26583 .71551 .26483 Mtetra
.797 .99 .883 r
.71551 .26483 .72115 .26583 .73416 .25772 .72844 .25424 Mtetra
.795 .934 .923 r
.72844 .25424 .73416 .25772 .74726 .25038 .74147 .24499 Mtetra
.762 .869 .926 r
.74147 .24499 .74726 .25038 .76045 .24382 .75463 .23707 Mtetra
.728 .818 .921 r
.75463 .23707 .76045 .24382 .77375 .23792 .76791 .23029 Mtetra
.702 .783 .915 r
.76791 .23029 .77375 .23792 .78714 .23251 .78131 .22435 Mtetra
.685 .763 .911 r
.78131 .22435 .78714 .23251 .80061 .22741 .79481 .21894 Mtetra
.674 .751 .909 r
.79481 .21894 .80061 .22741 .81417 .22249 .8084 .21385 Mtetra
.669 .745 .908 r
.8084 .21385 .81417 .22249 .8278 .21765 .82207 .20892 Mtetra
.634 .733 .919 r
.20104 .41544 .20861 .42251 .21953 .41949 .21199 .41241 Mtetra
.607 .726 .929 r
.21199 .41241 .21953 .41949 .23045 .41708 .22293 .41001 Mtetra
.558 .71 .942 r
.22293 .41001 .23045 .41708 .24134 .41566 .23383 .40862 Mtetra
.462 .674 .956 r
.23383 .40862 .24134 .41566 .25216 .41575 .24466 .40879 Mtetra
.28 .588 .945 r
.24466 .40879 .25216 .41575 .26288 .41796 .25538 .41113 Mtetra
0 .396 .841 r
.25538 .41113 .26288 .41796 .27347 .42295 .26596 .4163 Mtetra
0 .104 .584 r
.26596 .4163 .27347 .42295 .28393 .43123 .2764 .42483 Mtetra
.666 .149 0 r
.2764 .42483 .28393 .43123 .29427 .44303 .28671 .43696 Mtetra
.785 .294 0 r
.28671 .43696 .29427 .44303 .30455 .45808 .29695 .4524 Mtetra
.831 .36 0 r
.29695 .4524 .30455 .45808 .31486 .4755 .30722 .47025 Mtetra
.841 .375 .023 r
.30722 .47025 .31486 .4755 .32533 .49368 .31764 .48889 Mtetra
.82 .34 0 r
.31764 .48889 .32533 .49368 .33608 .51051 .32835 .50617 Mtetra
.741 .22 0 r
.32835 .50617 .33608 .51051 .34723 .52362 .33948 .51968 Mtetra
.459 0 0 r
.33948 .51968 .34723 .52362 .35884 .53086 .35109 .52725 Mtetra
.298 .723 .971 r
.35109 .52725 .35884 .53086 .37093 .53074 .3632 .52735 Mtetra
.77 .894 .931 r
.3632 .52735 .37093 .53074 .38342 .52282 .37575 .51951 Mtetra
.886 .87 .817 r
.37575 .51951 .38342 .52282 .39623 .50774 .38863 .50436 Mtetra
.919 .843 .753 r
.38863 .50436 .39623 .50774 .4092 .48707 .4017 .48346 Mtetra
.93 .827 .722 r
.4017 .48346 .4092 .48707 .42221 .46293 .41482 .45898 Mtetra
.932 .818 .711 r
.41482 .45898 .42221 .46293 .43517 .43759 .42788 .43322 Mtetra
.928 .815 .714 r
.42788 .43322 .43517 .43759 .448 .41301 .44082 .40824 Mtetra
.919 .817 .73 r
.44082 .40824 .448 .41301 .46068 .39071 .4536 .38561 Mtetra
.903 .822 .758 r
.4536 .38561 .46068 .39071 .47323 .37159 .46623 .36631 Mtetra
.878 .831 .796 r
.46623 .36631 .47323 .37159 .48568 .35601 .47875 .35077 Mtetra
.841 .843 .846 r
.47875 .35077 .48568 .35601 .49807 .34391 .49119 .33899 Mtetra
.782 .856 .906 r
.49119 .33899 .49807 .34391 .51044 .33495 .50361 .33068 Mtetra
.684 .864 .967 r
.50361 .33068 .51044 .33495 .52282 .32868 .51605 .32546 Mtetra
.502 .839 .998 r
.51605 .32546 .52282 .32868 .53525 .32466 .52854 .32294 Mtetra
.173 .692 .884 r
.52854 .32294 .53525 .32466 .54775 .32251 .54111 .32282 Mtetra
.217 0 0 r
.54111 .32282 .54775 .32251 .56035 .32189 .55379 .3248 Mtetra
.452 0 0 r
.55379 .3248 .56035 .32189 .57305 .32248 .5666 .32851 Mtetra
.543 .044 .019 r
.5666 .32851 .57305 .32248 .58586 .32383 .57956 .33334 Mtetra
.563 .114 .142 r
.57956 .33334 .58586 .32383 .59878 .32531 .59266 .33839 Mtetra
.547 .134 .211 r
.59266 .33839 .59878 .32531 .61179 .32618 .60587 .34245 Mtetra
.507 .122 .244 r
.60587 .34245 .61179 .32618 .62486 .32563 .61915 .34423 Mtetra
.449 .084 .252 r
.61915 .34423 .62486 .32563 .63795 .32293 .63242 .34261 Mtetra
.368 .02 .237 r
.63242 .34261 .63795 .32293 .65101 .31769 .64563 .33691 Mtetra
.261 0 .194 r
.64563 .33691 .65101 .31769 .66401 .30986 .65871 .32709 Mtetra
.117 0 .114 r
.65871 .32709 .66401 .30986 .67694 .29984 .67165 .31384 Mtetra
0 0 0 r
.67165 .31384 .67694 .29984 .68981 .28839 .68447 .29836 Mtetra
.68447 .29836 .68981 .28839 .70265 .27643 .69721 .28212 Mtetra
.617 .865 .512 r
.69721 .28212 .70265 .27643 .71551 .26483 .70995 .26651 Mtetra
.802 .992 .751 r
.70995 .26651 .71551 .26483 .72844 .25424 .72276 .25253 Mtetra
.843 .979 .872 r
.72276 .25253 .72844 .25424 .74147 .24499 .7357 .24066 Mtetra
.808 .912 .91 r
.7357 .24066 .74147 .24499 .75463 .23707 .7488 .23091 Mtetra
.76 .847 .916 r
.7488 .23091 .75463 .23707 .76791 .23029 .76205 .22294 Mtetra
.721 .8 .914 r
.76205 .22294 .76791 .23029 .78131 .22435 .77545 .21628 Mtetra
.695 .772 .91 r
.77545 .21628 .78131 .22435 .79481 .21894 .78897 .21048 Mtetra
.68 .755 .909 r
.78897 .21048 .79481 .21894 .8084 .21385 .80259 .20518 Mtetra
.671 .747 .908 r
.80259 .20518 .8084 .21385 .82207 .20892 .81629 .20012 Mtetra
.634 .732 .919 r
.19342 .40828 .20104 .41544 .21199 .41241 .20439 .40521 Mtetra
.609 .724 .927 r
.20439 .40521 .21199 .41241 .22293 .41001 .21535 .40276 Mtetra
.561 .707 .939 r
.21535 .40276 .22293 .41001 .23383 .40862 .22628 .40131 Mtetra
.472 .671 .95 r
.22628 .40131 .23383 .40862 .24466 .40879 .23713 .40138 Mtetra
.31 .59 .943 r
.23713 .40138 .24466 .40879 .25538 .41113 .24787 .40359 Mtetra
.039 .424 .866 r
.24787 .40359 .25538 .41113 .26596 .4163 .25848 .40856 Mtetra
0 .17 .673 r
.25848 .40856 .26596 .4163 .2764 .42483 .26893 .41682 Mtetra
.56 .07 0 r
.26893 .41682 .2764 .42483 .28671 .43696 .27925 .42856 Mtetra
.701 .222 0 r
.27925 .42856 .28671 .43696 .29695 .4524 .2895 .44354 Mtetra
.756 .292 0 r
.2895 .44354 .29695 .4524 .30722 .47025 .29978 .46082 Mtetra
.751 .295 0 r
.29978 .46082 .30722 .47025 .31764 .48889 .3102 .47887 Mtetra
.669 .218 0 r
.3102 .47887 .31764 .48889 .32835 .50617 .32092 .49557 Mtetra
0 0 .554 r
.32092 .49557 .32835 .50617 .33948 .51968 .33205 .50861 Mtetra
.085 .359 .828 r
.33205 .50861 .33948 .51968 .35109 .52725 .34367 .51588 Mtetra
.52 .602 .876 r
.34367 .51588 .35109 .52725 .3632 .52735 .3558 .51592 Mtetra
.72 .685 .815 r
.3558 .51592 .3632 .52735 .37575 .51951 .36837 .50826 Mtetra
.806 .712 .761 r
.36837 .50826 .37575 .51951 .38863 .50436 .38128 .49349 Mtetra
.848 .724 .727 r
.38128 .49349 .38863 .50436 .4017 .48346 .39439 .47313 Mtetra
.87 .733 .708 r
.39439 .47313 .4017 .48346 .41482 .45898 .40756 .44926 Mtetra
.881 .741 .703 r
.40756 .44926 .41482 .45898 .42788 .43322 .42067 .42415 Mtetra
.885 .75 .708 r
.42067 .42415 .42788 .43322 .44082 .40824 .43367 .39981 Mtetra
.882 .761 .724 r
.43367 .39981 .44082 .40824 .4536 .38561 .44651 .37782 Mtetra
.872 .775 .752 r
.44651 .37782 .4536 .38561 .46623 .36631 .45919 .35922 Mtetra
.853 .794 .793 r
.45919 .35922 .46623 .36631 .47875 .35077 .47176 .34449 Mtetra
.817 .817 .85 r
.47176 .34449 .47875 .35077 .49119 .33899 .48425 .33369 Mtetra
.748 .843 .922 r
.48425 .33369 .49119 .33899 .50361 .33068 .49672 .32663 Mtetra
.6 .849 .991 r
.49672 .32663 .50361 .33068 .51605 .32546 .5092 .32302 Mtetra
.265 .737 .941 r
.5092 .32302 .51605 .32546 .52854 .32294 .52174 .32259 Mtetra
.219 0 0 r
.52174 .32259 .52854 .32294 .54111 .32282 .53438 .32513 Mtetra
.514 0 0 r
.53438 .32513 .54111 .32282 .55379 .3248 .54715 .33043 Mtetra
.619 .126 .06 r
.54715 .33043 .55379 .3248 .5666 .32851 .56008 .33809 Mtetra
.645 .205 .19 r
.56008 .33809 .5666 .32851 .57956 .33334 .5732 .34732 Mtetra
.636 .233 .263 r
.5732 .34732 .57956 .33334 .59266 .33839 .5865 .35683 Mtetra
.605 .229 .303 r
.5865 .35683 .59266 .33839 .60587 .34245 .59994 .36487 Mtetra
.557 .202 .322 r
.59994 .36487 .60587 .34245 .61915 .34423 .61345 .36955 Mtetra
.49 .153 .322 r
.61345 .36955 .61915 .34423 .63242 .34261 .62695 .3692 Mtetra
.402 .082 .304 r
.62695 .3692 .63242 .34261 .64563 .33691 .64033 .36284 Mtetra
.285 0 .264 r
.64033 .36284 .64563 .33691 .65871 .32709 .65351 .35044 Mtetra
.131 0 .191 r
.65351 .35044 .65871 .32709 .67165 .31384 .66646 .33305 Mtetra
0 0 .07 r
.66646 .33305 .67165 .31384 .68447 .29836 .67921 .31248 Mtetra
0 0 0 r
.67921 .31248 .68447 .29836 .69721 .28212 .69183 .29092 Mtetra
.69183 .29092 .69721 .28212 .70995 .26651 .70443 .27035 Mtetra
.812 .958 .626 r
.70443 .27035 .70995 .26651 .72276 .25253 .7171 .25221 Mtetra
.883 .99 .799 r
.7171 .25221 .72276 .25253 .7357 .24066 .72993 .23717 Mtetra
.854 .938 .877 r
.72993 .23717 .7357 .24066 .7488 .23091 .74294 .22519 Mtetra
.795 .869 .903 r
.74294 .22519 .7488 .23091 .76205 .22294 .75615 .21579 Mtetra
.743 .815 .908 r
.75615 .21579 .76205 .22294 .77545 .21628 .76954 .20828 Mtetra
.707 .78 .908 r
.76954 .20828 .77545 .21628 .78897 .21048 .78307 .20201 Mtetra
.686 .76 .908 r
.78307 .20201 .78897 .21048 .80259 .20518 .79672 .19645 Mtetra
.674 .749 .907 r
.79672 .19645 .80259 .20518 .81629 .20012 .81047 .19126 Mtetra
.636 .732 .917 r
.18574 .40103 .19342 .40828 .20439 .40521 .19674 .39789 Mtetra
.612 .723 .925 r
.19674 .39789 .20439 .40521 .21535 .40276 .20773 .39533 Mtetra
.569 .707 .935 r
.20773 .39533 .21535 .40276 .22628 .40131 .21869 .39372 Mtetra
.492 .672 .944 r
.21869 .39372 .22628 .40131 .23713 .40138 .22958 .39354 Mtetra
.356 .601 .94 r
.22958 .39354 .23713 .40138 .24787 .40359 .24036 .39535 Mtetra
.14 .467 .892 r
.24036 .39535 .24787 .40359 .25848 .40856 .25102 .39976 Mtetra
0 .266 .767 r
.25102 .39976 .25848 .40856 .26893 .41682 .26153 .40723 Mtetra
0 .058 .599 r
.26153 .40723 .26893 .41682 .27925 .42856 .27191 .41794 Mtetra
0 0 .47 r
.27191 .41794 .27925 .42856 .2895 .44354 .28223 .43162 Mtetra
0 0 .423 r
.28223 .43162 .2895 .44354 .29978 .46082 .29257 .44742 Mtetra
0 0 .465 r
.29257 .44742 .29978 .46082 .3102 .47887 .30305 .46388 Mtetra
0 .009 .585 r
.30305 .46388 .3102 .47887 .32092 .49557 .31382 .47905 Mtetra
.027 .208 .714 r
.31382 .47905 .32092 .49557 .33205 .50861 .32499 .4908 Mtetra
.339 .393 .771 r
.32499 .4908 .33205 .50861 .34367 .51588 .33663 .49718 Mtetra
.55 .51 .764 r
.33663 .49718 .34367 .51588 .3558 .51592 .34875 .49688 Mtetra
.672 .576 .739 r
.34875 .49688 .3558 .51592 .36837 .50826 .36131 .48947 Mtetra
.743 .615 .715 r
.36131 .48947 .36837 .50826 .38128 .49349 .3742 .4755 Mtetra
.787 .64 .7 r
.3742 .4755 .38128 .49349 .39439 .47313 .38729 .45636 Mtetra
.814 .66 .692 r
.38729 .45636 .39439 .47313 .40756 .44926 .40045 .434 Mtetra
.831 .677 .692 r
.40045 .434 .40756 .44926 .42067 .42415 .41357 .41051 Mtetra
.84 .694 .701 r
.41357 .41051 .42067 .42415 .43367 .39981 .42657 .3878 Mtetra
.842 .711 .719 r
.42657 .3878 .43367 .39981 .44651 .37782 .43942 .3674 Mtetra
.837 .732 .749 r
.43942 .3674 .44651 .37782 .45919 .35922 .45213 .35033 Mtetra
.82 .757 .793 r
.45213 .35033 .45919 .35922 .47176 .34449 .46473 .33712 Mtetra
.781 .788 .858 r
.46473 .33712 .47176 .34449 .48425 .33369 .47725 .32792 Mtetra
.692 .818 .943 r
.47725 .32792 .48425 .33369 .49672 .32663 .48974 .32263 Mtetra
.459 .796 .999 r
.48974 .32263 .49672 .32663 .5092 .32302 .50226 .32109 Mtetra
0 .524 .777 r
.50226 .32109 .5092 .32302 .52174 .32259 .51485 .32316 Mtetra
.483 0 0 r
.51485 .32316 .52174 .32259 .53438 .32513 .52754 .32878 Mtetra
.649 .135 .009 r
.52754 .32878 .53438 .32513 .54715 .33043 .5404 .33783 Mtetra
.697 .243 .171 r
.5404 .33783 .54715 .33043 .56008 .33809 .55345 .34987 Mtetra
.701 .288 .26 r
.55345 .34987 .56008 .33809 .5732 .34732 .56673 .36394 Mtetra
.682 .297 .311 r
.56673 .36394 .5732 .34732 .5865 .35683 .58022 .37832 Mtetra
.644 .28 .339 r
.58022 .37832 .5865 .35683 .59994 .36487 .5939 .39067 Mtetra
.588 .242 .35 r
.5939 .39067 .59994 .36487 .61345 .36955 .60766 .39842 Mtetra
.509 .18 .345 r
.60766 .39842 .61345 .36955 .62695 .3692 .62138 .3993 Mtetra
.401 .091 .321 r
.62138 .3993 .62695 .3692 .64033 .36284 .63494 .392 Mtetra
.255 0 .271 r
.63494 .392 .64033 .36284 .65351 .35044 .64823 .37657 Mtetra
.063 0 .185 r
.64823 .37657 .65351 .35044 .66646 .33305 .6612 .35447 Mtetra
0 0 .05 r
.6612 .35447 .66646 .33305 .67921 .31248 .67389 .32825 Mtetra
0 0 0 r
.67389 .32825 .67921 .31248 .69183 .29092 .6864 .30084 Mtetra
.704 .818 .364 r
.6864 .30084 .69183 .29092 .70443 .27035 .69885 .2749 Mtetra
.871 .944 .582 r
.69885 .2749 .70443 .27035 .7171 .25221 .71139 .25231 Mtetra
.924 .975 .744 r
.71139 .25231 .7171 .25221 .72993 .23717 .7241 .23388 Mtetra
.891 .938 .838 r
.7241 .23388 .72993 .23717 .74294 .22519 .73703 .21955 Mtetra
.826 .877 .882 r
.73703 .21955 .74294 .22519 .75615 .21579 .7502 .20864 Mtetra
.764 .823 .898 r
.7502 .20864 .75615 .21579 .76954 .20828 .76358 .20024 Mtetra
.719 .785 .904 r
.76358 .20024 .76954 .20828 .78307 .20201 .77713 .19347 Mtetra
.692 .762 .906 r
.77713 .19347 .78307 .20201 .79672 .19645 .79081 .18765 Mtetra
.677 .75 .906 r
.79081 .18765 .79672 .19645 .81047 .19126 .80459 .18232 Mtetra
.639 .732 .916 r
.178 .39371 .18574 .40103 .19674 .39789 .18903 .39047 Mtetra
.618 .724 .922 r
.18903 .39047 .19674 .39789 .20773 .39533 .20006 .38775 Mtetra
.581 .708 .93 r
.20006 .38775 .20773 .39533 .21869 .39372 .21106 .38588 Mtetra
.516 .677 .937 r
.21106 .38588 .21869 .39372 .22958 .39354 .222 .3853 Mtetra
.41 .618 .936 r
.222 .3853 .22958 .39354 .24036 .39535 .23285 .38652 Mtetra
.249 .515 .908 r
.23285 .38652 .24036 .39535 .25102 .39976 .24358 .39005 Mtetra
.048 .365 .835 r
.24358 .39005 .25102 .39976 .26153 .40723 .25418 .39631 Mtetra
0 .206 .733 r
.25418 .39631 .26153 .40723 .27191 .41794 .26467 .40543 Mtetra
0 .091 .649 r
.26467 .40543 .27191 .41794 .28223 .43162 .2751 .41717 Mtetra
0 .051 .618 r
.2751 .41717 .28223 .43162 .29257 .44742 .28556 .43074 Mtetra
0 .089 .641 r
.28556 .43074 .29257 .44742 .30305 .46388 .29616 .44483 Mtetra
.049 .185 .686 r
.29616 .44483 .30305 .46388 .31382 .47905 .30702 .45772 Mtetra
.257 .301 .716 r
.30702 .45772 .31382 .47905 .32499 .4908 .31825 .46753 Mtetra
.433 .399 .721 r
.31825 .46753 .32499 .4908 .33663 .49718 .32991 .47258 Mtetra
.559 .471 .712 r
.32991 .47258 .33663 .49718 .34875 .49688 .34203 .47172 Mtetra
.644 .521 .699 r
.34203 .47172 .34875 .49688 .36131 .48947 .35455 .46462 Mtetra
.702 .558 .688 r
.35455 .46462 .36131 .48947 .3742 .4755 .36738 .45176 Mtetra
.742 .586 .681 r
.36738 .45176 .3742 .4755 .38729 .45636 .3804 .43439 Mtetra
.769 .609 .68 r
.3804 .43439 .38729 .45636 .40045 .434 .3935 .41422 Mtetra
.788 .63 .685 r
.3935 .41422 .40045 .434 .41357 .41051 .40656 .39312 Mtetra
.8 .65 .696 r
.40656 .39312 .41357 .41051 .42657 .3878 .41952 .37283 Mtetra
.804 .671 .717 r
.41952 .37283 .42657 .3878 .43942 .3674 .43236 .35474 Mtetra
.799 .694 .749 r
.43236 .35474 .43942 .3674 .45213 .35033 .44506 .33986 Mtetra
.78 .722 .798 r
.44506 .33986 .45213 .35033 .46473 .33712 .45765 .32873 Mtetra
.733 .754 .869 r
.45765 .32873 .46473 .33712 .47725 .32792 .47018 .32156 Mtetra
.611 .777 .96 r
.47018 .32156 .47725 .32792 .48974 .32263 .48269 .31838 Mtetra
.273 .689 .969 r
.48269 .31838 .48974 .32263 .50226 .32109 .49524 .31914 Mtetra
.296 0 0 r
.49524 .31914 .50226 .32109 .51485 .32316 .50785 .32385 Mtetra
.616 .058 0 r
.50785 .32385 .51485 .32316 .52754 .32878 .5206 .33256 Mtetra
.719 .23 .081 r
.5206 .33256 .52754 .32878 .5404 .33783 .53353 .34523 Mtetra
.747 .307 .206 r
.53353 .34523 .5404 .33783 .55345 .34987 .54667 .36142 Mtetra
.744 .336 .277 r
.54667 .36142 .55345 .34987 .56673 .36394 .56008 .37995 Mtetra
.722 .335 .317 r
.56008 .37995 .56673 .36394 .58022 .37832 .57375 .39875 Mtetra
.68 .31 .338 r
.57375 .39875 .58022 .37832 .5939 .39067 .58763 .41493 Mtetra
.615 .259 .343 r
.58763 .41493 .5939 .39067 .60766 .39842 .6016 .42526 Mtetra
.515 .175 .329 r
.6016 .42526 .60766 .39842 .62138 .3993 .61554 .42696 Mtetra
.364 .047 .288 r
.61554 .42696 .62138 .3993 .63494 .392 .62926 .41845 Mtetra
.144 0 .207 r
.62926 .41845 .63494 .392 .64823 .37657 .64265 .39989 Mtetra
0 0 .073 r
.64265 .39989 .64823 .37657 .6612 .35447 .65566 .37321 Mtetra
0 0 0 r
.65566 .37321 .6612 .35447 .67389 .32825 .66832 .34162 Mtetra
.714 .781 .294 r
.66832 .34162 .67389 .32825 .6864 .30084 .68074 .30878 Mtetra
.876 .89 .464 r
.68074 .30878 .6864 .30084 .69885 .2749 .69309 .27794 Mtetra
.95 .938 .607 r
.69309 .27794 .69885 .2749 .71139 .25231 .70552 .25132 Mtetra
.956 .942 .722 r
.70552 .25132 .71139 .25231 .7241 .23388 .71815 .22987 Mtetra
.912 .913 .806 r
.71815 .22987 .7241 .23388 .73703 .21955 .73103 .21345 Mtetra
.845 .867 .858 r
.73103 .21345 .73703 .21955 .7502 .20864 .74418 .20121 Mtetra
.779 .821 .885 r
.74418 .20121 .7502 .20864 .76358 .20024 .75756 .19202 Mtetra
.729 .785 .898 r
.75756 .19202 .76358 .20024 .77713 .19347 .77112 .18481 Mtetra
.697 .763 .903 r
.77112 .18481 .77713 .19347 .79081 .18765 .78484 .17875 Mtetra
.679 .751 .905 r
.78484 .17875 .79081 .18765 .80459 .18232 .79866 .17329 Mtetra
.642 .732 .914 r
.1702 .3863 .178 .39371 .18903 .39047 .18127 .38294 Mtetra
.624 .724 .919 r
.18127 .38294 .18903 .39047 .20006 .38775 .19234 .38003 Mtetra
.594 .71 .924 r
.19234 .38003 .20006 .38775 .21106 .38588 .20339 .37786 Mtetra
.543 .683 .93 r
.20339 .37786 .21106 .38588 .222 .3853 .21439 .37678 Mtetra
.463 .636 .93 r
.21439 .37678 .222 .3853 .23285 .38652 .22532 .37724 Mtetra
.349 .558 .913 r
.22532 .37724 .23285 .38652 .24358 .39005 .23614 .37968 Mtetra
.212 .45 .871 r
.23614 .37968 .24358 .39005 .25418 .39631 .24687 .38444 Mtetra
.088 .335 .809 r
.24687 .38444 .25418 .39631 .26467 .40543 .2575 .39162 Mtetra
.022 .248 .751 r
.2575 .39162 .26467 .40543 .2751 .41717 .26808 .40098 Mtetra
.035 .214 .718 r
.26808 .40098 .2751 .41717 .28556 .43074 .2787 .41184 Mtetra
.12 .233 .708 r
.2787 .41184 .28556 .43074 .29616 .44483 .28945 .42307 Mtetra
.244 .286 .707 r
.28945 .42307 .29616 .44483 .30702 .45772 .30043 .43322 Mtetra
.372 .349 .704 r
.30043 .43322 .30702 .45772 .31825 .46753 .31175 .44071 Mtetra
.481 .407 .696 r
.31175 .44071 .31825 .46753 .32991 .47258 .32345 .44416 Mtetra
.565 .455 .687 r
.32345 .44416 .32991 .47258 .34203 .47172 .33555 .44264 Mtetra
.628 .494 .679 r
.33555 .44264 .34203 .47172 .35455 .46462 .34802 .43589 Mtetra
.675 .525 .674 r
.34802 .43589 .35455 .46462 .36738 .45176 .36076 .42434 Mtetra
.71 .552 .672 r
.36076 .42434 .36738 .45176 .3804 .43439 .37367 .40905 Mtetra
.735 .575 .674 r
.37367 .40905 .3804 .43439 .3935 .41422 .38666 .39149 Mtetra
.754 .596 .682 r
.38666 .39149 .3935 .41422 .40656 .39312 .39963 .37324 Mtetra
.765 .618 .696 r
.39963 .37324 .40656 .39312 .41952 .37283 .41252 .35583 Mtetra
.768 .639 .719 r
.41252 .35583 .41952 .37283 .43236 .35474 .4253 .34051 Mtetra
.761 .663 .754 r
.4253 .34051 .43236 .35474 .44506 .33986 .43796 .32819 Mtetra
.737 .69 .806 r
.43796 .32819 .44506 .33986 .45765 .32873 .45054 .31942 Mtetra
.674 .716 .88 r
.45054 .31942 .45765 .32873 .47018 .32156 .46306 .31449 Mtetra
.51 .716 .965 r
.46306 .31449 .47018 .32156 .48269 .31838 .47558 .3135 Mtetra
.098 .558 .911 r
.47558 .3135 .48269 .31838 .49524 .31914 .48813 .31648 Mtetra
.429 0 0 r
.48813 .31648 .49524 .31914 .50785 .32385 .50077 .32356 Mtetra
.679 .134 0 r
.50077 .32356 .50785 .32385 .5206 .33256 .51355 .33486 Mtetra
.762 .275 .077 r
.51355 .33486 .5206 .33256 .53353 .34523 .52652 .35038 Mtetra
.787 .34 .186 r
.52652 .35038 .53353 .34523 .54667 .36142 .53973 .36963 Mtetra
.787 .365 .246 r
.53973 .36963 .54667 .36142 .56008 .37995 .55323 .39131 Mtetra
.768 .36 .279 r
.55323 .39131 .56008 .37995 .57375 .39875 .56701 .41304 Mtetra
.726 .326 .291 r
.56701 .41304 .57375 .39875 .58763 .41493 .58102 .43156 Mtetra
.647 .252 .282 r
.58102 .43156 .58763 .41493 .6016 .42526 .59515 .44324 Mtetra
.498 .111 .238 r
.59515 .44324 .6016 .42526 .61554 .42696 .60923 .44497 Mtetra
.213 0 .128 r
.60923 .44497 .61554 .42696 .62926 .41845 .62308 .43506 Mtetra
0 0 0 r
.62308 .43506 .62926 .41845 .64265 .39989 .63657 .41382 Mtetra
.656 .764 .286 r
.63657 .41382 .64265 .39989 .65566 .37321 .64963 .38356 Mtetra
.873 .869 .424 r
.64963 .38356 .65566 .37321 .66832 .34162 .6623 .348 Mtetra
.958 .894 .51 r
.6623 .348 .66832 .34162 .68074 .30878 .67471 .31127 Mtetra
.985 .898 .579 r
.67471 .31127 .68074 .30878 .69309 .27794 .68703 .27702 Mtetra
.983 .895 .647 r
.68703 .27702 .69309 .27794 .70552 .25132 .69943 .24764 Mtetra
.958 .886 .717 r
.69943 .24764 .70552 .25132 .71815 .22987 .71203 .22415 Mtetra
.911 .868 .783 r
.71203 .22415 .71815 .22987 .73103 .21345 .7249 .20632 Mtetra
.849 .84 .836 r
.7249 .20632 .73103 .21345 .74418 .20121 .73806 .19319 Mtetra
.785 .808 .871 r
.73806 .19319 .74418 .20121 .75756 .19202 .75146 .18346 Mtetra
.734 .78 .89 r
.75146 .18346 .75756 .19202 .77112 .18481 .76506 .17595 Mtetra
.7 .761 .899 r
.76506 .17595 .77112 .18481 .78484 .17875 .77881 .16972 Mtetra
.681 .75 .904 r
.77881 .16972 .78484 .17875 .79866 .17329 .79268 .16417 Mtetra
.646 .733 .912 r
.16234 .37883 .1702 .3863 .18127 .38294 .17344 .37534 Mtetra
.632 .726 .916 r
.17344 .37534 .18127 .38294 .19234 .38003 .18456 .37222 Mtetra
.608 .713 .92 r
.18456 .37222 .19234 .38003 .20339 .37786 .19566 .3697 Mtetra
.569 .691 .923 r
.19566 .3697 .20339 .37786 .21439 .37678 .20673 .36807 Mtetra
.511 .653 .923 r
.20673 .36807 .21439 .37678 .22532 .37724 .21775 .36771 Mtetra
.432 .595 .912 r
.21775 .36771 .22532 .37724 .23614 .37968 .22869 .36896 Mtetra
.34 .516 .884 r
.22869 .36896 .23614 .37968 .24687 .38444 .23955 .37208 Mtetra
.26 .431 .842 r
.23955 .37208 .24687 .38444 .2575 .39162 .25034 .37715 Mtetra
.217 .363 .797 r
.25034 .37715 .2575 .39162 .26808 .40098 .2611 .38396 Mtetra
.227 .328 .759 r
.2611 .38396 .26808 .40098 .2787 .41184 .27191 .39193 Mtetra
.281 .328 .733 r
.27191 .39193 .2787 .41184 .28945 .42307 .28283 .40014 Mtetra
.359 .351 .714 r
.28283 .40014 .28945 .42307 .30043 .43322 .29396 .4074 Mtetra
.44 .384 .7 r
.29396 .4074 .30043 .43322 .31175 .44071 .30537 .41248 Mtetra
.512 .42 .688 r
.30537 .41248 .31175 .44071 .32345 .44416 .31712 .41427 Mtetra
.572 .453 .679 r
.31712 .41427 .32345 .44416 .33555 .44264 .32921 .41207 Mtetra
.62 .482 .672 r
.32921 .41207 .33555 .44264 .34802 .43589 .3416 .40568 Mtetra
.658 .508 .669 r
.3416 .40568 .34802 .43589 .36076 .42434 .35424 .3955 Mtetra
.687 .532 .67 r
.35424 .3955 .36076 .42434 .37367 .40905 .36703 .38239 Mtetra
.71 .554 .675 r
.36703 .38239 .37367 .40905 .38666 .39149 .37989 .36755 Mtetra
.726 .575 .685 r
.37989 .36755 .38666 .39149 .39963 .37324 .39274 .3523 Mtetra
.735 .596 .701 r
.39274 .3523 .39963 .37324 .41252 .35583 .40553 .3379 Mtetra
.736 .617 .726 r
.40553 .3379 .41252 .35583 .4253 .34051 .41823 .32545 Mtetra
.725 .639 .763 r
.41823 .32545 .4253 .34051 .43796 .32819 .43085 .31576 Mtetra
.691 .661 .816 r
.43085 .31576 .43796 .32819 .45054 .31942 .44339 .30937 Mtetra
.609 .675 .888 r
.44339 .30937 .45054 .31942 .46306 .31449 .4559 .30658 Mtetra
.411 .643 .952 r
.4559 .30658 .46306 .31449 .47558 .3135 .4684 .30755 Mtetra
0 .454 .864 r
.4684 .30755 .47558 .3135 .48813 .31648 .48096 .31237 Mtetra
.457 0 0 r
.48096 .31237 .48813 .31648 .50077 .32356 .49361 .32117 Mtetra
.689 .145 0 r
.49361 .32117 .50077 .32356 .51355 .33486 .50641 .33409 Mtetra
.779 .278 0 r
.50641 .33409 .51355 .33486 .52652 .35038 .5194 .35108 Mtetra
.815 .343 .091 r
.5194 .35108 .52652 .35038 .53973 .36963 .53264 .37161 Mtetra
.825 .368 .139 r
.53264 .37161 .53973 .36963 .55323 .39131 .54617 .39428 Mtetra
.816 .36 .149 r
.54617 .39428 .55323 .39131 .56701 .41304 .56 .41662 Mtetra
.779 .307 .116 r
.56 .41662 .56701 .41304 .58102 .43156 .57405 .43526 Mtetra
.67 .154 .001 r
.57405 .43526 .58102 .43156 .59515 .44324 .58824 .44652 Mtetra
.262 0 0 r
.58824 .44652 .59515 .44324 .60923 .44497 .60238 .44728 Mtetra
.674 .968 .776 r
.60238 .44728 .60923 .44497 .62308 .43506 .6163 .43596 Mtetra
.951 .953 .711 r
.6163 .43596 .62308 .43506 .63657 .41382 .62985 .41304 Mtetra
.984 .883 .646 r
.62985 .41304 .63657 .41382 .64963 .38356 .64298 .38103 Mtetra
.985 .844 .62 r
.64298 .38103 .64963 .38356 .6623 .348 .65572 .34382 Mtetra
.98 .825 .619 r
.65572 .34382 .6623 .348 .67471 .31127 .6682 .30568 Mtetra
.97 .818 .635 r
.6682 .30568 .67471 .31127 .68703 .27702 .68058 .27029 Mtetra
.955 .817 .668 r
.68058 .27029 .68703 .27702 .69943 .24764 .69304 .24006 Mtetra
.929 .817 .714 r
.69304 .24006 .69943 .24764 .71203 .22415 .7057 .21597 Mtetra
.89 .815 .768 r
.7057 .21597 .71203 .22415 .7249 .20632 .71863 .19774 Mtetra
.837 .805 .819 r
.71863 .19774 .7249 .20632 .73806 .19319 .73183 .18435 Mtetra
.781 .788 .858 r
.73183 .18435 .73806 .19319 .75146 .18346 .74527 .17446 Mtetra
.733 .77 .883 r
.74527 .17446 .75146 .18346 .76506 .17595 .75892 .16684 Mtetra
.7 .757 .896 r
.75892 .16684 .76506 .17595 .77881 .16972 .77272 .16054 Mtetra
.681 .748 .902 r
.77272 .16054 .77881 .16972 .79268 .16417 .78664 .15493 Mtetra
.649 .734 .911 r
.15442 .3713 .16234 .37883 .17344 .37534 .16556 .36768 Mtetra
.639 .728 .913 r
.16556 .36768 .17344 .37534 .18456 .37222 .17672 .36434 Mtetra
.62 .717 .916 r
.17672 .36434 .18456 .37222 .19566 .3697 .18788 .36147 Mtetra
.592 .699 .917 r
.18788 .36147 .19566 .3697 .20673 .36807 .19902 .3593 Mtetra
.551 .67 .916 r
.19902 .3593 .20673 .36807 .21775 .36771 .21013 .35811 Mtetra
.497 .625 .907 r
.21013 .35811 .21775 .36771 .22869 .36896 .22119 .35817 Mtetra
.436 .567 .887 r
.22119 .35817 .22869 .36896 .23955 .37208 .23219 .35968 Mtetra
.382 .502 .856 r
.23219 .35968 .23955 .37208 .25034 .37715 .24315 .36268 Mtetra
.352 .446 .817 r
.24315 .36268 .25034 .37715 .2611 .38396 .2541 .367 Mtetra
.355 .41 .78 r
.2541 .367 .2611 .38396 .27191 .39193 .2651 .37217 Mtetra
.386 .396 .748 r
.2651 .37217 .27191 .39193 .28283 .40014 .2762 .37747 Mtetra
.433 .401 .723 r
.2762 .37747 .28283 .40014 .29396 .4074 .28748 .38199 Mtetra
.486 .417 .704 r
.28748 .38199 .29396 .4074 .30537 .41248 .29899 .38478 Mtetra
.536 .438 .69 r
.29899 .38478 .30537 .41248 .31712 .41427 .31079 .38502 Mtetra
.58 .46 .681 r
.31079 .38502 .31712 .41427 .32921 .41207 .32286 .38219 Mtetra
.617 .482 .675 r
.32286 .38219 .32921 .41207 .3416 .40568 .33519 .37618 Mtetra
.647 .504 .673 r
.33519 .37618 .3416 .40568 .35424 .3955 .34772 .36732 Mtetra
.672 .524 .676 r
.34772 .36732 .35424 .3955 .36703 .38239 .36038 .35628 Mtetra
.691 .544 .682 r
.36038 .35628 .36703 .38239 .37989 .36755 .3731 .34402 Mtetra
.704 .564 .694 r
.3731 .34402 .37989 .36755 .39274 .3523 .38583 .3316 Mtetra
.711 .584 .712 r
.38583 .3316 .39274 .3523 .40553 .3379 .39852 .32004 Mtetra
.707 .604 .739 r
.39852 .32004 .40553 .3379 .41823 .32545 .41114 .31027 Mtetra
.689 .623 .776 r
.41114 .31027 .41823 .32545 .43085 .31576 .4237 .30299 Mtetra
.644 .637 .828 r
.4237 .30299 .43085 .31576 .44339 .30937 .4362 .2987 Mtetra
.545 .634 .89 r
.4362 .2987 .44339 .30937 .4559 .30658 .44869 .29771 Mtetra
.341 .578 .929 r
.44869 .29771 .4559 .30658 .4684 .30755 .46119 .30017 Mtetra
0 .404 .85 r
.46119 .30017 .4684 .30755 .48096 .31237 .47374 .30616 Mtetra
0 .138 .61 r
.47374 .30616 .48096 .31237 .49361 .32117 .4864 .31577 Mtetra
.611 .08 0 r
.4864 .31577 .49361 .32117 .50641 .33409 .4992 .32905 Mtetra
.722 .209 0 r
.4992 .32905 .50641 .33409 .5194 .35108 .5122 .34585 Mtetra
.768 .274 0 r
.5122 .34585 .5194 .35108 .53264 .37161 .52544 .36557 Mtetra
.77 .286 0 r
.52544 .36557 .53264 .37161 .54617 .39428 .53896 .38679 Mtetra
.709 .228 0 r
.53896 .38679 .54617 .39428 .56 .41662 .55275 .40715 Mtetra
0 0 .507 r
.55275 .40715 .56 .41662 .57405 .43526 .56677 .42352 Mtetra
.065 .344 .819 r
.56677 .42352 .57405 .43526 .58824 .44652 .58091 .43252 Mtetra
.553 .593 .848 r
.58091 .43252 .58824 .44652 .60238 .44728 .59502 .43141 Mtetra
.753 .663 .762 r
.59502 .43141 .60238 .44728 .6163 .43596 .60894 .41892 Mtetra
.832 .683 .698 r
.60894 .41892 .6163 .43596 .62985 .41304 .62254 .39567 Mtetra
.87 .693 .66 r
.62254 .39567 .62985 .41304 .64298 .38103 .63575 .36413 Mtetra
.89 .701 .642 r
.63575 .36413 .64298 .38103 .65572 .34382 .64861 .32798 Mtetra
.9 .711 .638 r
.64861 .32798 .65572 .34382 .6682 .30568 .66123 .29122 Mtetra
.903 .723 .648 r
.66123 .29122 .6682 .30568 .68058 .27029 .67377 .25724 Mtetra
.898 .737 .673 r
.67377 .25724 .68058 .27029 .69304 .24006 .68638 .22826 Mtetra
.884 .751 .711 r
.68638 .22826 .69304 .24006 .7057 .21597 .69916 .20514 Mtetra
.856 .763 .759 r
.69916 .20514 .7057 .21597 .71863 .19774 .7122 .1876 Mtetra
.815 .768 .809 r
.7122 .1876 .71863 .19774 .73183 .18435 .72549 .17463 Mtetra
.769 .766 .85 r
.72549 .17463 .73183 .18435 .74527 .17446 .73901 .16498 Mtetra
.727 .758 .878 r
.73901 .16498 .74527 .17446 .75892 .16684 .75272 .15747 Mtetra
.697 .751 .893 r
.75272 .15747 .75892 .16684 .77272 .16054 .76657 .15121 Mtetra
.68 .746 .901 r
.76657 .15121 .77272 .16054 .78664 .15493 .78054 .14558 Mtetra
.653 .735 .91 r
.14643 .36372 .15442 .3713 .16556 .36768 .15761 .35997 Mtetra
.645 .73 .911 r
.15761 .35997 .16556 .36768 .17672 .36434 .16881 .35643 Mtetra
.632 .722 .912 r
.16881 .35643 .17672 .36434 .18788 .36147 .18003 .35324 Mtetra
.611 .707 .913 r
.18003 .35324 .18788 .36147 .19902 .3593 .19124 .35056 Mtetra
.583 .684 .911 r
.19124 .35056 .19902 .3593 .21013 .35811 .20244 .34861 Mtetra
.546 .651 .903 r
.20244 .34861 .21013 .35811 .22119 .35817 .21362 .34758 Mtetra
.505 .607 .888 r
.21362 .34758 .22119 .35817 .23219 .35968 .22476 .34762 Mtetra
.469 .557 .863 r
.22476 .34762 .23219 .35968 .24315 .36268 .23588 .34874 Mtetra
.446 .51 .83 r
.23588 .34874 .24315 .36268 .2541 .367 .24701 .35081 Mtetra
.443 .474 .796 r
.24701 .35081 .2541 .367 .2651 .37217 .25819 .35348 Mtetra
.459 .453 .764 r
.25819 .35348 .2651 .37217 .2762 .37747 .26946 .3562 Mtetra
.488 .447 .737 r
.26946 .3562 .2762 .37747 .28748 .38199 .28088 .3583 Mtetra
.522 .451 .717 r
.28088 .3583 .28748 .38199 .29899 .38478 .2925 .3591 Mtetra
.557 .461 .702 r
.2925 .3591 .29899 .38478 .31079 .38502 .30434 .358 Mtetra
.589 .475 .692 r
.30434 .358 .31079 .38502 .32286 .38219 .31641 .35465 Mtetra
.618 .492 .686 r
.31641 .35465 .32286 .38219 .33519 .37618 .32867 .349 Mtetra
.642 .509 .685 r
.32867 .349 .33519 .37618 .34772 .36732 .34111 .3413 Mtetra
.662 .527 .689 r
.34111 .3413 .34772 .36732 .36038 .35628 .35365 .33209 Mtetra
.678 .545 .696 r
.35365 .33209 .36038 .35628 .3731 .34402 .36625 .32209 Mtetra
.687 .563 .71 r
.36625 .32209 .3731 .34402 .38583 .3316 .37887 .31213 Mtetra
.69 .582 .729 r
.37887 .31213 .38583 .3316 .39852 .32004 .39146 .30301 Mtetra
.682 .599 .757 r
.39146 .30301 .39852 .32004 .41114 .31027 .404 .2955 Mtetra
.657 .613 .794 r
.404 .2955 .41114 .31027 .4237 .30299 .41651 .29019 Mtetra
.602 .618 .84 r
.41651 .29019 .4237 .30299 .4362 .2987 .42898 .28754 Mtetra
.496 .601 .887 r
.42898 .28754 .4362 .2987 .44869 .29771 .44144 .28781 Mtetra
.314 .535 .907 r
.44144 .28781 .44869 .29771 .46119 .30017 .45394 .29113 Mtetra
.058 .401 .856 r
.45394 .29113 .46119 .30017 .47374 .30616 .4665 .29752 Mtetra
0 .225 .732 r
.4665 .29752 .47374 .30616 .4864 .31577 .47916 .30695 Mtetra
0 .073 .602 r
.47916 .30695 .4864 .31577 .4992 .32905 .49197 .31933 Mtetra
0 0 .526 r
.49197 .31933 .4992 .32905 .5122 .34585 .50497 .33437 Mtetra
0 0 .523 r
.50497 .33437 .5122 .34585 .52544 .36557 .51818 .35139 Mtetra
0 .013 .587 r
.51818 .35139 .52544 .36557 .53896 .38679 .53165 .36908 Mtetra
0 .139 .674 r
.53165 .36908 .53896 .38679 .55275 .40715 .54537 .38536 Mtetra
.215 .285 .721 r
.54537 .38536 .55275 .40715 .56677 .42352 .55928 .39758 Mtetra
.439 .399 .717 r
.55928 .39758 .56677 .42352 .58091 .43252 .57331 .40303 Mtetra
.584 .472 .692 r
.57331 .40303 .58091 .43252 .59502 .43141 .58733 .39959 Mtetra
.676 .521 .668 r
.58733 .39959 .59502 .43141 .60894 .41892 .60119 .38638 Mtetra
.736 .555 .649 r
.60119 .38638 .60894 .41892 .62254 .39567 .6148 .36413 Mtetra
.776 .583 .637 r
.6148 .36413 .62254 .39567 .63575 .36413 .62809 .33506 Mtetra
.805 .606 .633 r
.62809 .33506 .63575 .36413 .64861 .32798 .64111 .30233 Mtetra
.825 .628 .637 r
.64111 .30233 .64861 .32798 .66123 .29122 .65392 .26932 Mtetra
.838 .651 .65 r
.65392 .26932 .66123 .29122 .67377 .25724 .66668 .23891 Mtetra
.842 .674 .674 r
.66668 .23891 .67377 .25724 .68638 .22826 .67949 .21293 Mtetra
.837 .698 .711 r
.67949 .21293 .68638 .22826 .69916 .20514 .69246 .19211 Mtetra
.819 .721 .757 r
.69246 .19211 .69916 .20514 .7122 .1876 .70564 .17615 Mtetra
.789 .737 .805 r
.70564 .17615 .7122 .1876 .72549 .17463 .71905 .16418 Mtetra
.752 .746 .847 r
.71905 .16418 .72549 .17463 .73901 .16498 .73266 .1551 Mtetra
.717 .747 .875 r
.73266 .1551 .73901 .16498 .75272 .15747 .74645 .14787 Mtetra
.692 .745 .892 r
.74645 .14787 .75272 .15747 .76657 .15121 .76036 .14172 Mtetra
.677 .743 .901 r
.76036 .14172 .76657 .15121 .78054 .14558 .77439 .13613 Mtetra
.656 .736 .909 r
.13838 .35609 .14643 .36372 .15761 .35997 .14959 .35223 Mtetra
.65 .732 .909 r
.14959 .35223 .15761 .35997 .16881 .35643 .16084 .34851 Mtetra
.641 .726 .91 r
.16084 .34851 .16881 .35643 .18003 .35324 .17211 .34503 Mtetra
.627 .715 .91 r
.17211 .34503 .18003 .35324 .19124 .35056 .18339 .34192 Mtetra
.608 .698 .907 r
.18339 .34192 .19124 .35056 .20244 .34861 .19467 .33931 Mtetra
.583 .673 .901 r
.19467 .33931 .20244 .34861 .21362 .34758 .20595 .33735 Mtetra
.556 .64 .889 r
.20595 .33735 .21362 .34758 .22476 .34762 .21722 .33614 Mtetra
.531 .601 .869 r
.21722 .33614 .22476 .34762 .23588 .34874 .2285 .33567 Mtetra
.514 .562 .842 r
.2285 .33567 .23588 .34874 .24701 .35081 .23979 .33586 Mtetra
.508 .529 .813 r
.23979 .33586 .24701 .35081 .25819 .35348 .25113 .33643 Mtetra
.515 .505 .783 r
.25113 .33643 .25819 .35348 .26946 .3562 .26256 .33702 Mtetra
.531 .492 .757 r
.26256 .33702 .26946 .3562 .28088 .3583 .27411 .33713 Mtetra
.553 .488 .736 r
.27411 .33713 .28088 .3583 .2925 .3591 .28581 .33631 Mtetra
.577 .491 .721 r
.28581 .33631 .2925 .3591 .30434 .358 .2977 .33414 Mtetra
.6 .499 .711 r
.2977 .33414 .30434 .358 .31641 .35465 .30976 .33039 Mtetra
.622 .51 .706 r
.30976 .33039 .31641 .35465 .32867 .349 .32198 .32506 Mtetra
.641 .524 .705 r
.32198 .32506 .32867 .349 .34111 .3413 .33433 .31833 Mtetra
.657 .539 .709 r
.33433 .31833 .34111 .3413 .35365 .33209 .34678 .31061 Mtetra
.669 .556 .718 r
.34678 .31061 .35365 .33209 .36625 .32209 .35928 .30244 Mtetra
.675 .572 .732 r
.35928 .30244 .36625 .32209 .37887 .31213 .3718 .29444 Mtetra
.674 .589 .752 r
.3718 .29444 .37887 .31213 .39146 .30301 .38431 .28725 Mtetra
.661 .603 .78 r
.38431 .28725 .39146 .30301 .404 .2955 .3968 .28147 Mtetra
.629 .612 .814 r
.3968 .28147 .404 .2955 .41651 .29019 .40927 .27759 Mtetra
.569 .607 .851 r
.40927 .27759 .41651 .29019 .42898 .28754 .42172 .276 Mtetra
.47 .58 .883 r
.42172 .276 .42898 .28754 .44144 .28781 .43417 .27693 Mtetra
.327 .518 .891 r
.43417 .27693 .44144 .28781 .45394 .29113 .44667 .28043 Mtetra
.163 .425 .862 r
.44667 .28043 .45394 .29113 .4665 .29752 .45924 .28646 Mtetra
.022 .323 .809 r
.45924 .28646 .4665 .29752 .47916 .30695 .47191 .29483 Mtetra
0 .244 .758 r
.47191 .29483 .47916 .30695 .49197 .31933 .48473 .30531 Mtetra
0 .206 .729 r
.48473 .30531 .49197 .31933 .50497 .33437 .49772 .31747 Mtetra
.026 .213 .719 r
.49772 .31747 .50497 .33437 .51818 .35139 .51092 .33059 Mtetra
.157 .253 .713 r
.51092 .33059 .51818 .35139 .53165 .36908 .52432 .34351 Mtetra
.299 .307 .701 r
.52432 .34351 .53165 .36908 .54537 .38536 .53794 .35459 Mtetra
.422 .359 .682 r
.53794 .35459 .54537 .38536 .55928 .39758 .55173 .36183 Mtetra
.519 .405 .663 r
.55173 .36183 .55928 .39758 .57331 .40303 .56561 .36329 Mtetra
.591 .442 .647 r
.56561 .36329 .57331 .40303 .58733 .39959 .57949 .35756 Mtetra
.647 .474 .636 r
.57949 .35756 .58733 .39959 .60119 .38638 .59327 .34421 Mtetra
.69 .502 .628 r
.59327 .34421 .60119 .38638 .6148 .36413 .60687 .32398 Mtetra
.723 .528 .626 r
.60687 .32398 .6148 .36413 .62809 .33506 .62024 .29868 Mtetra
.75 .553 .628 r
.62024 .29868 .62809 .33506 .64111 .30233 .63341 .27082 Mtetra
.771 .578 .637 r
.63341 .27082 .64111 .30233 .65392 .26932 .64643 .243 Mtetra
.787 .604 .653 r
.64643 .243 .65392 .26932 .66668 .23891 .65942 .21741 Mtetra
.795 .632 .679 r
.65942 .21741 .66668 .23891 .67949 .21293 .67246 .19549 Mtetra
.795 .662 .716 r
.67246 .19549 .67949 .21293 .69246 .19211 .68564 .17773 Mtetra
.784 .691 .762 r
.68564 .17773 .69246 .19211 .70564 .17615 .699 .1639 Mtetra
.762 .715 .809 r
.699 .1639 .70564 .17615 .71905 .16418 .71254 .15326 Mtetra
.733 .731 .849 r
.71254 .15326 .71905 .16418 .73266 .1551 .72625 .14494 Mtetra
.706 .738 .876 r
.72625 .14494 .73266 .1551 .74645 .14787 .74011 .1381 Mtetra
.686 .741 .892 r
.74011 .1381 .74645 .14787 .76036 .14172 .7541 .13212 Mtetra
.675 .741 .901 r
.7541 .13212 .76036 .14172 .77439 .13613 .76818 .12657 Mtetra
.658 .737 .908 r
.13026 .34842 .13838 .35609 .14959 .35223 .14151 .34446 Mtetra
.654 .734 .908 r
.14151 .34446 .14959 .35223 .16084 .34851 .15279 .34059 Mtetra
.648 .729 .908 r
.15279 .34059 .16084 .34851 .17211 .34503 .16411 .33687 Mtetra
.639 .721 .908 r
.16411 .33687 .17211 .34503 .18339 .34192 .17545 .3334 Mtetra
.626 .709 .905 r
.17545 .3334 .18339 .34192 .19467 .33931 .18681 .33027 Mtetra
.61 .691 .9 r
.18681 .33027 .19467 .33931 .20595 .33735 .19818 .32756 Mtetra
.592 .666 .891 r
.19818 .32756 .20595 .33735 .21722 .33614 .20957 .32534 Mtetra
.575 .637 .875 r
.20957 .32534 .21722 .33614 .2285 .33567 .22097 .32362 Mtetra
.562 .606 .855 r
.22097 .32362 .2285 .33567 .23979 .33586 .2324 .32232 Mtetra
.556 .577 .83 r
.2324 .32232 .23979 .33586 .25113 .33643 .24388 .32126 Mtetra
.558 .554 .805 r
.24388 .32126 .25113 .33643 .26256 .33702 .25544 .32018 Mtetra
.567 .538 .782 r
.25544 .32018 .26256 .33702 .27411 .33713 .2671 .31876 Mtetra
.58 .529 .762 r
.2671 .31876 .27411 .33713 .28581 .33631 .27889 .3167 Mtetra
.596 .527 .747 r
.27889 .3167 .28581 .33631 .2977 .33414 .29081 .31372 Mtetra
.613 .53 .737 r
.29081 .31372 .2977 .33414 .30976 .33039 .30287 .30969 Mtetra
.629 .538 .732 r
.30287 .30969 .30976 .33039 .32198 .32506 .31506 .30462 Mtetra
.643 .548 .732 r
.31506 .30462 .32198 .32506 .33433 .31833 .32736 .29864 Mtetra
.655 .561 .737 r
.32736 .29864 .33433 .31833 .34678 .31061 .33974 .29206 Mtetra
.663 .575 .746 r
.33974 .29206 .34678 .31061 .35928 .30244 .35216 .28527 Mtetra
.666 .59 .761 r
.35216 .28527 .35928 .30244 .3718 .29444 .36462 .27872 Mtetra
.661 .604 .78 r
.36462 .27872 .3718 .29444 .38431 .28725 .37707 .27291 Mtetra
.644 .614 .805 r
.37707 .27291 .38431 .28725 .3968 .28147 .38952 .2683 Mtetra
.609 .617 .834 r
.38952 .2683 .3968 .28147 .40927 .27759 .40197 .26529 Mtetra
.551 .606 .861 r
.40197 .26529 .40927 .27759 .42172 .276 .41441 .2642 Mtetra
.467 .574 .879 r
.41441 .2642 .42172 .276 .43417 .27693 .42688 .26519 Mtetra
.366 .522 .879 r
.42688 .26519 .43417 .27693 .44667 .28043 .43939 .26829 Mtetra
.271 .457 .861 r
.43939 .26829 .44667 .28043 .45924 .28646 .45198 .27333 Mtetra
.208 .398 .831 r
.45198 .27333 .45924 .28646 .47191 .29483 .46467 .28004 Mtetra
.194 .358 .8 r
.46467 .28004 .47191 .29483 .48473 .30531 .4775 .28804 Mtetra
.227 .34 .771 r
.4775 .28804 .48473 .30531 .49772 .31747 .4905 .2968 Mtetra
.291 .341 .742 r
.4905 .2968 .49772 .31747 .51092 .33059 .50367 .30562 Mtetra
.367 .354 .713 r
.50367 .30562 .51092 .33059 .52432 .34351 .51702 .31356 Mtetra
.44 .373 .686 r
.51702 .31356 .52432 .34351 .53794 .35459 .53054 .31941 Mtetra
.503 .395 .663 r
.53054 .31941 .53794 .35459 .55173 .36183 .5442 .32186 Mtetra
.556 .417 .646 r
.5442 .32186 .55173 .36183 .56561 .36329 .55794 .31971 Mtetra
.6 .438 .634 r
.55794 .31971 .56561 .36329 .57949 .35756 .57169 .3122 Mtetra
.636 .459 .627 r
.57169 .3122 .57949 .35756 .59327 .34421 .58538 .29926 Mtetra
.667 .481 .624 r
.58538 .29926 .59327 .34421 .60687 .32398 .59896 .28158 Mtetra
.693 .503 .625 r
.59896 .28158 .60687 .32398 .62024 .29868 .61239 .26054 Mtetra
.716 .526 .631 r
.61239 .26054 .62024 .29868 .63341 .27082 .6257 .23795 Mtetra
.735 .551 .644 r
.6257 .23795 .63341 .27082 .64643 .243 .63892 .21566 Mtetra
.75 .579 .663 r
.63892 .21566 .64643 .243 .65942 .21741 .65213 .1952 Mtetra
.76 .61 .692 r
.65213 .1952 .65942 .21741 .67246 .19549 .6654 .17753 Mtetra
.762 .643 .73 r
.6654 .17753 .67246 .19549 .68564 .17773 .67877 .16301 Mtetra
.754 .676 .775 r
.67877 .16301 .68564 .17773 .699 .1639 .69229 .15141 Mtetra
.737 .703 .819 r
.69229 .15141 .699 .1639 .71254 .15326 .70597 .14218 Mtetra
.716 .722 .855 r
.70597 .14218 .71254 .15326 .72625 .14494 .71978 .13466 Mtetra
.695 .733 .88 r
.71978 .13466 .72625 .14494 .74011 .1381 .73372 .12822 Mtetra
.68 .738 .894 r
.73372 .12822 .74011 .1381 .7541 .13212 .74777 .12242 Mtetra
.672 .74 .902 r
.74777 .12242 .7541 .13212 .76818 .12657 .76191 .11693 Mtetra
.66 .738 .908 r
.12207 .3407 .13026 .34842 .14151 .34446 .13335 .33665 Mtetra
.657 .736 .908 r
.13335 .33665 .14151 .34446 .15279 .34059 .14468 .33266 Mtetra
.653 .733 .908 r
.14468 .33266 .15279 .34059 .16411 .33687 .15604 .32876 Mtetra
.647 .727 .907 r
.15604 .32876 .16411 .33687 .17545 .3334 .16743 .32501 Mtetra
.639 .718 .905 r
.16743 .32501 .17545 .3334 .18681 .33027 .17886 .32147 Mtetra
.629 .705 .901 r
.17886 .32147 .18681 .33027 .19818 .32756 .19031 .3182 Mtetra
.618 .688 .893 r
.19031 .3182 .19818 .32756 .20957 .32534 .20179 .31523 Mtetra
.607 .667 .882 r
.20179 .31523 .20957 .32534 .22097 .32362 .21329 .31257 Mtetra
.598 .643 .867 r
.21329 .31257 .22097 .32362 .2324 .32232 .22484 .31016 Mtetra
.592 .62 .848 r
.22484 .31016 .2324 .32232 .24388 .32126 .23643 .30789 Mtetra
.592 .599 .828 r
.23643 .30789 .24388 .32126 .25544 .32018 .2481 .30559 Mtetra
.596 .583 .809 r
.2481 .30559 .25544 .32018 .2671 .31876 .25985 .30306 Mtetra
.604 .573 .792 r
.25985 .30306 .2671 .31876 .27889 .3167 .2717 .3001 Mtetra
.615 .568 .778 r
.2717 .3001 .27889 .3167 .29081 .31372 .28367 .29655 Mtetra
.626 .568 .769 r
.28367 .29655 .29081 .31372 .30287 .30969 .29574 .29233 Mtetra
.637 .572 .765 r
.29574 .29233 .30287 .30969 .31506 .30462 .30792 .28744 Mtetra
.648 .58 .765 r
.30792 .28744 .31506 .30462 .32736 .29864 .32018 .28201 Mtetra
.656 .591 .77 r
.32018 .28201 .32736 .29864 .33974 .29206 .33251 .27624 Mtetra
.661 .603 .779 r
.33251 .27624 .33974 .29206 .35216 .28527 .34489 .27041 Mtetra
.66 .615 .793 r
.34489 .27041 .35216 .28527 .36462 .27872 .3573 .26485 Mtetra
.652 .625 .81 r
.3573 .26485 .36462 .27872 .37707 .27291 .36973 .25992 Mtetra
.633 .631 .831 r
.36973 .25992 .37707 .27291 .38952 .2683 .38216 .25597 Mtetra
.598 .629 .852 r
.38216 .25597 .38952 .2683 .40197 .26529 .39461 .25334 Mtetra
.547 .613 .87 r
.39461 .25334 .40197 .26529 .41441 .2642 .40706 .25226 Mtetra
.482 .581 .878 r
.40706 .25226 .41441 .2642 .42688 .26519 .41955 .25286 Mtetra
.415 .538 .872 r
.41955 .25286 .42688 .26519 .43939 .26829 .43209 .25509 Mtetra
.363 .491 .854 r
.43209 .25509 .43939 .26829 .45198 .27333 .44471 .25875 Mtetra
.339 .452 .829 r
.44471 .25875 .45198 .27333 .46467 .28004 .45743 .26349 Mtetra
.347 .425 .8 r
.45743 .26349 .46467 .28004 .4775 .28804 .47029 .26884 Mtetra
.379 .412 .769 r
.47029 .26884 .4775 .28804 .4905 .2968 .48329 .27425 Mtetra
.424 .408 .737 r
.48329 .27425 .4905 .2968 .50367 .30562 .49644 .27908 Mtetra
.47 .41 .708 r
.49644 .27908 .50367 .30562 .51702 .31356 .50975 .2826 Mtetra
.512 .415 .682 r
.50975 .2826 .51702 .31356 .53054 .31941 .5232 .28404 Mtetra
.55 .424 .661 r
.5232 .28404 .53054 .31941 .5442 .32186 .53675 .28262 Mtetra
.582 .435 .646 r
.53675 .28262 .5442 .32186 .55794 .31971 .55038 .27778 Mtetra
.61 .447 .637 r
.55038 .27778 .55794 .31971 .57169 .3122 .56402 .26921 Mtetra
.635 .462 .632 r
.56402 .26921 .57169 .3122 .58538 .29926 .57764 .2571 Mtetra
.657 .478 .631 r
.57764 .2571 .58538 .29926 .59896 .28158 .5912 .24205 Mtetra
.677 .497 .635 r
.5912 .24205 .59896 .28158 .61239 .26054 .60468 .22506 Mtetra
.695 .518 .644 r
.60468 .22506 .61239 .26054 .6257 .23795 .6181 .20733 Mtetra
.711 .543 .659 r
.6181 .20733 .6257 .23795 .63892 .21566 .63149 .19006 Mtetra
.725 .572 .682 r
.63149 .19006 .63892 .21566 .65213 .1952 .64489 .17421 Mtetra
.733 .604 .714 r
.64489 .17421 .65213 .1952 .6654 .17753 .65834 .16038 Mtetra
.735 .639 .752 r
.65834 .16038 .6654 .17753 .67877 .16301 .6719 .14876 Mtetra
.729 .673 .795 r
.6719 .14876 .67877 .16301 .69229 .15141 .68556 .13916 Mtetra
.716 .701 .834 r
.68556 .13916 .69229 .15141 .70597 .14218 .69936 .13119 Mtetra
.7 .72 .865 r
.69936 .13119 .70597 .14218 .71978 .13466 .71327 .12438 Mtetra
.685 .731 .885 r
.71327 .12438 .71978 .13466 .73372 .12822 .72728 .11831 Mtetra
.675 .737 .897 r
.72728 .11831 .73372 .12822 .74777 .12242 .74139 .11265 Mtetra
.669 .739 .903 r
.74139 .11265 .74777 .12242 .76191 .11693 .75558 .10721 Mtetra
.661 .739 .908 r
.11382 .33293 .12207 .3407 .13335 .33665 .12513 .32882 Mtetra
.659 .737 .908 r
.12513 .32882 .13335 .33665 .14468 .33266 .13649 .32473 Mtetra
.657 .735 .907 r
.13649 .32473 .14468 .33266 .15604 .32876 .14789 .32069 Mtetra
.653 .731 .906 r
.14789 .32069 .15604 .32876 .16743 .32501 .15933 .31673 Mtetra
.648 .725 .905 r
.15933 .31673 .16743 .32501 .17886 .32147 .17081 .31289 Mtetra
.642 .717 .902 r
.17081 .31289 .17886 .32147 .19031 .3182 .18233 .30921 Mtetra
.635 .705 .897 r
.18233 .30921 .19031 .3182 .20179 .31523 .19388 .30571 Mtetra
.628 .69 .889 r
.19388 .30571 .20179 .31523 .21329 .31257 .20547 .30238 Mtetra
.622 .674 .878 r
.20547 .30238 .21329 .31257 .22484 .31016 .21711 .29919 Mtetra
.619 .656 .865 r
.21711 .29919 .22484 .31016 .23643 .30789 .22879 .29608 Mtetra
.618 .64 .85 r
.22879 .29608 .23643 .30789 .2481 .30559 .24054 .29293 Mtetra
.62 .626 .835 r
.24054 .29293 .2481 .30559 .25985 .30306 .25237 .28963 Mtetra
.624 .616 .822 r
.25237 .28963 .25985 .30306 .2717 .3001 .26428 .28606 Mtetra
.631 .61 .811 r
.26428 .28606 .2717 .3001 .28367 .29655 .27628 .28212 Mtetra
.638 .608 .803 r
.27628 .28212 .28367 .29655 .29574 .29233 .28837 .27776 Mtetra
.646 .611 .8 r
.28837 .27776 .29574 .29233 .30792 .28744 .30055 .27301 Mtetra
.653 .616 .8 r
.30055 .27301 .30792 .28744 .32018 .28201 .31279 .26795 Mtetra
.658 .625 .805 r
.31279 .26795 .32018 .28201 .33251 .27624 .3251 .26271 Mtetra
.66 .634 .813 r
.3251 .26271 .33251 .27624 .34489 .27041 .33746 .25748 Mtetra
.657 .643 .825 r
.33746 .25748 .34489 .27041 .3573 .26485 .34986 .25252 Mtetra
.647 .65 .839 r
.34986 .25252 .3573 .26485 .36973 .25992 .36228 .24807 Mtetra
.628 .651 .854 r
.36228 .24807 .36973 .25992 .38216 .25597 .37472 .2444 Mtetra
.597 .644 .868 r
.37472 .2444 .38216 .25597 .39461 .25334 .38718 .24177 Mtetra
.556 .626 .877 r
.38718 .24177 .39461 .25334 .40706 .25226 .39966 .24035 Mtetra
.509 .597 .877 r
.39966 .24035 .40706 .25226 .41955 .25286 .41218 .24023 Mtetra
.465 .56 .868 r
.41218 .24023 .41955 .25286 .43209 .25509 .42476 .24133 Mtetra
.436 .523 .849 r
.42476 .24133 .43209 .25509 .44471 .25875 .43742 .24343 Mtetra
.428 .493 .824 r
.43742 .24343 .44471 .25875 .45743 .26349 .45018 .24615 Mtetra
.441 .471 .795 r
.45018 .24615 .45743 .26349 .47029 .26884 .46306 .24903 Mtetra
.467 .459 .766 r
.46306 .24903 .47029 .26884 .48329 .27425 .47608 .25151 Mtetra
.498 .453 .737 r
.47608 .25151 .48329 .27425 .49644 .27908 .48923 .25307 Mtetra
.529 .45 .711 r
.48923 .25307 .49644 .27908 .50975 .2826 .50251 .25318 Mtetra
.557 .451 .688 r
.50251 .25318 .50975 .2826 .5232 .28404 .51591 .25138 Mtetra
.582 .454 .671 r
.51591 .25138 .5232 .28404 .53675 .28262 .52939 .24733 Mtetra
.603 .459 .658 r
.52939 .24733 .53675 .28262 .55038 .27778 .54293 .24083 Mtetra
.622 .467 .65 r
.54293 .24083 .55038 .27778 .56402 .26921 .5565 .23194 Mtetra
.639 .477 .647 r
.5565 .23194 .56402 .26921 .57764 .2571 .57007 .22091 Mtetra
.655 .49 .649 r
.57007 .22091 .57764 .2571 .5912 .24205 .58362 .20828 Mtetra
.67 .507 .655 r
.58362 .20828 .5912 .24205 .60468 .22506 .59715 .19471 Mtetra
.684 .527 .667 r
.59715 .19471 .60468 .22506 .6181 .20733 .61066 .18095 Mtetra
.697 .552 .686 r
.61066 .18095 .6181 .20733 .63149 .19006 .62417 .16771 Mtetra
.708 .581 .711 r
.62417 .16771 .63149 .19006 .64489 .17421 .63772 .15555 Mtetra
.714 .614 .744 r
.63772 .15555 .64489 .17421 .65834 .16038 .65133 .14477 Mtetra
.715 .648 .782 r
.65133 .14477 .65834 .16038 .6719 .14876 .66503 .13544 Mtetra
.71 .68 .819 r
.66503 .13544 .6719 .14876 .68556 .13916 .67882 .12741 Mtetra
.699 .705 .852 r
.67882 .12741 .68556 .13916 .69936 .13119 .69271 .12043 Mtetra
.687 .722 .876 r
.69271 .12043 .69936 .13119 .71327 .12438 .7067 .11417 Mtetra
.678 .732 .891 r
.7067 .11417 .71327 .12438 .72728 .11831 .72079 .10837 Mtetra
.671 .737 .9 r
.72079 .10837 .72728 .11831 .74139 .11265 .73496 .10283 Mtetra
.667 .739 .904 r
.73496 .10283 .74139 .11265 .75558 .10721 .7492 .09741 Mtetra
.662 .739 .908 r
.10549 .32512 .11382 .33293 .12513 .32882 .11684 .32094 Mtetra
.661 .738 .907 r
.11684 .32094 .12513 .32882 .13649 .32473 .12823 .31678 Mtetra
.659 .737 .907 r
.12823 .31678 .13649 .32473 .14789 .32069 .13967 .31263 Mtetra
.657 .734 .907 r
.13967 .31263 .14789 .32069 .15933 .31673 .15115 .30852 Mtetra
.654 .731 .905 r
.15115 .30852 .15933 .31673 .17081 .31289 .16268 .30448 Mtetra
.651 .725 .903 r
.16268 .30448 .17081 .31289 .18233 .30921 .17425 .30051 Mtetra
.647 .718 .9 r
.17425 .30051 .18233 .30921 .19388 .30571 .18586 .29664 Mtetra
.643 .708 .894 r
.18586 .29664 .19388 .30571 .20547 .30238 .19752 .29286 Mtetra
.639 .697 .887 r
.19752 .29286 .20547 .30238 .21711 .29919 .20922 .28916 Mtetra
.637 .685 .879 r
.20922 .28916 .21711 .29919 .22879 .29608 .22098 .28548 Mtetra
.636 .673 .869 r
.22098 .28548 .22879 .29608 .24054 .29293 .2328 .28177 Mtetra
.637 .662 .858 r
.2328 .28177 .24054 .29293 .25237 .28963 .24469 .27796 Mtetra
.639 .654 .849 r
.24469 .27796 .25237 .28963 .26428 .28606 .25665 .27399 Mtetra
.643 .649 .841 r
.25665 .27399 .26428 .28606 .27628 .28212 .26869 .26979 Mtetra
.648 .647 .835 r
.26869 .26979 .27628 .28212 .28837 .27776 .2808 .26534 Mtetra
.653 .648 .833 r
.2808 .26534 .28837 .27776 .30055 .27301 .29298 .26067 Mtetra
.657 .652 .834 r
.29298 .26067 .30055 .27301 .31279 .26795 .30523 .25582 Mtetra
.66 .658 .837 r
.30523 .25582 .31279 .26795 .3251 .26271 .31754 .2509 Mtetra
.659 .664 .844 r
.31754 .2509 .3251 .26271 .33746 .25748 .32989 .24603 Mtetra
.655 .67 .852 r
.32989 .24603 .33746 .25748 .34986 .25252 .34229 .24137 Mtetra
.645 .673 .862 r
.34229 .24137 .34986 .25252 .36228 .24807 .35473 .23711 Mtetra
.629 .671 .872 r
.35473 .23711 .36228 .24807 .37472 .2444 .36719 .23345 Mtetra
.604 .662 .88 r
.36719 .23345 .37472 .2444 .38718 .24177 .37968 .23057 Mtetra
.573 .644 .883 r
.37968 .23057 .38718 .24177 .39966 .24035 .3922 .22861 Mtetra
.539 .617 .879 r
.3922 .22861 .39966 .24035 .41218 .24023 .40477 .22761 Mtetra
.511 .586 .866 r
.40477 .22761 .41218 .24023 .42476 .24133 .4174 .22749 Mtetra
.493 .554 .847 r
.4174 .22749 .42476 .24133 .43742 .24343 .4301 .22803 Mtetra
.491 .528 .823 r
.4301 .22803 .43742 .24343 .45018 .24615 .44291 .2289 Mtetra
.502 .509 .796 r
.44291 .2289 .45018 .24615 .46306 .24903 .45582 .22964 Mtetra
.522 .497 .77 r
.45582 .22964 .46306 .24903 .47608 .25151 .46885 .2298 Mtetra
.545 .49 .745 r
.46885 .2298 .47608 .25151 .48923 .25307 .48201 .22895 Mtetra
.569 .486 .722 r
.48201 .22895 .48923 .25307 .50251 .25318 .49528 .22671 Mtetra
.589 .485 .704 r
.49528 .22671 .50251 .25318 .51591 .25138 .50864 .22287 Mtetra
.607 .486 .689 r
.50864 .22287 .51591 .25138 .52939 .24733 .52208 .21731 Mtetra
.622 .49 .679 r
.52208 .21731 .52939 .24733 .54293 .24083 .53557 .21009 Mtetra
.636 .495 .674 r
.53557 .21009 .54293 .24083 .5565 .23194 .5491 .20141 Mtetra
.648 .504 .673 r
.5491 .20141 .5565 .23194 .57007 .22091 .56265 .19156 Mtetra
.659 .516 .677 r
.56265 .19156 .57007 .22091 .58362 .20828 .5762 .18096 Mtetra
.67 .532 .687 r
.5762 .18096 .58362 .20828 .59715 .19471 .58977 .17005 Mtetra
.681 .552 .702 r
.58977 .17005 .59715 .19471 .61066 .18095 .60335 .15926 Mtetra
.69 .576 .723 r
.60335 .15926 .61066 .18095 .62417 .16771 .61697 .14897 Mtetra
.697 .605 .75 r
.61697 .14897 .62417 .16771 .63772 .15555 .63063 .13945 Mtetra
.701 .636 .781 r
.63063 .13945 .63772 .15555 .65133 .14477 .64436 .13085 Mtetra
.7 .667 .814 r
.64436 .13085 .65133 .14477 .66503 .13544 .65816 .12314 Mtetra
.694 .693 .845 r
.65816 .12314 .66503 .13544 .67882 .12741 .67205 .11623 Mtetra
.686 .713 .869 r
.67205 .11623 .67882 .12741 .69271 .12043 .68603 .10993 Mtetra
.678 .726 .886 r
.68603 .10993 .69271 .12043 .7067 .11417 .70009 .10405 Mtetra
.672 .734 .896 r
.70009 .10405 .7067 .11417 .72079 .10837 .71424 .09843 Mtetra
.668 .738 .902 r
.71424 .09843 .72079 .10837 .73496 .10283 .72846 .09295 Mtetra
.666 .74 .905 r
.72846 .09295 .73496 .10283 .7492 .09741 .74276 .08753 Mtetra
.662 .74 .908 r
.0971 .31725 .10549 .32512 .11684 .32094 .10847 .31302 Mtetra
.662 .739 .907 r
.10847 .31302 .11684 .32094 .12823 .31678 .1199 .30879 Mtetra
.661 .738 .907 r
.1199 .30879 .12823 .31678 .13967 .31263 .13137 .30456 Mtetra
.66 .737 .907 r
.13137 .30456 .13967 .31263 .15115 .30852 .14289 .30035 Mtetra
.658 .734 .906 r
.14289 .30035 .15115 .30852 .16268 .30448 .15446 .29616 Mtetra
.656 .731 .905 r
.15446 .29616 .16268 .30448 .17425 .30051 .16607 .29201 Mtetra
.654 .726 .902 r
.16607 .29201 .17425 .30051 .18586 .29664 .17773 .28789 Mtetra
.652 .721 .899 r
.17773 .28789 .18586 .29664 .19752 .29286 .18945 .28382 Mtetra
.65 .713 .895 r
.18945 .28382 .19752 .29286 .20922 .28916 .20121 .27978 Mtetra
.648 .706 .889 r
.20121 .27978 .20922 .28916 .22098 .28548 .21303 .27574 Mtetra
.648 .698 .883 r
.21303 .27574 .22098 .28548 .2328 .28177 .2249 .27168 Mtetra
.648 .691 .876 r
.2249 .27168 .2328 .28177 .24469 .27796 .23684 .26755 Mtetra
.65 .685 .87 r
.23684 .26755 .24469 .27796 .25665 .27399 .24884 .26331 Mtetra
.652 .681 .865 r
.24884 .26331 .25665 .27399 .26869 .26979 .26091 .25894 Mtetra
.655 .68 .862 r
.26091 .25894 .26869 .26979 .2808 .26534 .27305 .25443 Mtetra
.658 .68 .86 r
.27305 .25443 .2808 .26534 .29298 .26067 .28525 .2498 Mtetra
.66 .683 .861 r
.28525 .2498 .29298 .26067 .30523 .25582 .29751 .24507 Mtetra
.661 .686 .863 r
.29751 .24507 .30523 .25582 .31754 .2509 .30983 .2403 Mtetra
.659 .69 .868 r
.30983 .2403 .31754 .2509 .32989 .24603 .3222 .2356 Mtetra
.655 .693 .873 r
.3222 .2356 .32989 .24603 .34229 .24137 .33462 .23106 Mtetra
.647 .693 .879 r
.33462 .23106 .34229 .24137 .35473 .23711 .34708 .22681 Mtetra
.633 .69 .885 r
.34708 .22681 .35473 .23711 .36719 .23345 .35957 .223 Mtetra
.615 .68 .888 r
.35957 .223 .36719 .23345 .37968 .23057 .3721 .21975 Mtetra
.592 .663 .887 r
.3721 .21975 .37968 .23057 .3922 .22861 .38468 .21717 Mtetra
.569 .639 .881 r
.38468 .21717 .3922 .22861 .40477 .22761 .3973 .21526 Mtetra
.55 .612 .868 r
.3973 .21526 .40477 .22761 .4174 .22749 .40998 .21397 Mtetra
.538 .585 .85 r
.40998 .21397 .4174 .22749 .4301 .22803 .42274 .21311 Mtetra
.537 .562 .827 r
.42274 .21311 .4301 .22803 .44291 .2289 .43558 .21237 Mtetra
.546 .544 .804 r
.43558 .21237 .44291 .2289 .45582 .22964 .44853 .21141 Mtetra
.56 .532 .78 r
.44853 .21141 .45582 .22964 .46885 .2298 .46159 .20984 Mtetra
.578 .525 .759 r
.46159 .20984 .46885 .2298 .48201 .22895 .47475 .20733 Mtetra
.596 .522 .741 r
.47475 .20733 .48201 .22895 .49528 .22671 .48802 .20365 Mtetra
.613 .521 .726 r
.48802 .20365 .49528 .22671 .50864 .22287 .50137 .1987 Mtetra
.627 .522 .715 r
.50137 .1987 .50864 .22287 .52208 .21731 .51479 .19251 Mtetra
.639 .526 .709 r
.51479 .19251 .52208 .21731 .53557 .21009 .52826 .18522 Mtetra
.65 .532 .707 r
.52826 .18522 .53557 .21009 .5491 .20141 .54177 .17708 Mtetra
.659 .54 .709 r
.54177 .17708 .5491 .20141 .56265 .19156 .55532 .16836 Mtetra
.667 .553 .716 r
.55532 .16836 .56265 .19156 .5762 .18096 .56889 .15937 Mtetra
.674 .568 .728 r
.56889 .15937 .5762 .18096 .58977 .17005 .5825 .1504 Mtetra
.681 .588 .745 r
.5825 .1504 .58977 .17005 .60335 .15926 .59614 .14166 Mtetra
.687 .612 .767 r
.59614 .14166 .60335 .15926 .61697 .14897 .60984 .13336 Mtetra
.69 .638 .792 r
.60984 .13336 .61697 .14897 .63063 .13945 .62358 .12559 Mtetra
.69 .664 .819 r
.62358 .12559 .63063 .13945 .64436 .13085 .6374 .1184 Mtetra
.688 .688 .845 r
.6374 .1184 .64436 .13085 .65816 .12314 .65129 .11173 Mtetra
.683 .708 .867 r
.65129 .11173 .65816 .12314 .67205 .11623 .66526 .10552 Mtetra
.677 .722 .883 r
.66526 .10552 .67205 .11623 .68603 .10993 .6793 .09964 Mtetra
.672 .731 .894 r
.6793 .09964 .68603 .10993 .70009 .10405 .69343 .09399 Mtetra
.668 .736 .901 r
.69343 .09399 .70009 .10405 .71424 .09843 .70763 .08847 Mtetra
.666 .739 .904 r
.70763 .08847 .71424 .09843 .72846 .09295 .72191 .08302 Mtetra
.665 .74 .906 r
.72191 .08302 .72846 .09295 .74276 .08753 .73627 .07758 Mtetra
.663 .74 .908 r
.08863 .30932 .0971 .31725 .10847 .31302 .10004 .30505 Mtetra
.662 .74 .907 r
.10004 .30505 .10847 .31302 .1199 .30879 .11149 .30077 Mtetra
.662 .739 .907 r
.11149 .30077 .1199 .30879 .13137 .30456 .12299 .29648 Mtetra
.661 .738 .907 r
.12299 .29648 .13137 .30456 .14289 .30035 .13455 .29218 Mtetra
.66 .737 .906 r
.13455 .29218 .14289 .30035 .15446 .29616 .14615 .28789 Mtetra
.659 .735 .906 r
.14615 .28789 .15446 .29616 .16607 .29201 .15781 .28361 Mtetra
.658 .732 .904 r
.15781 .28361 .16607 .29201 .17773 .28789 .16951 .27934 Mtetra
.657 .729 .902 r
.16951 .27934 .17773 .28789 .18945 .28382 .18127 .27508 Mtetra
.656 .725 .9 r
.18127 .27508 .18945 .28382 .20121 .27978 .19308 .27083 Mtetra
.655 .72 .896 r
.19308 .27083 .20121 .27978 .21303 .27574 .20494 .26657 Mtetra
.655 .715 .893 r
.20494 .26657 .21303 .27574 .2249 .27168 .21686 .26228 Mtetra
.655 .711 .889 r
.21686 .26228 .2249 .27168 .23684 .26755 .22884 .25794 Mtetra
.656 .708 .885 r
.22884 .25794 .23684 .26755 .24884 .26331 .24088 .25354 Mtetra
.657 .705 .882 r
.24088 .25354 .24884 .26331 .26091 .25894 .25299 .24906 Mtetra
.659 .704 .88 r
.25299 .24906 .26091 .25894 .27305 .25443 .26515 .2445 Mtetra
.66 .704 .879 r
.26515 .2445 .27305 .25443 .28525 .2498 .27738 .23987 Mtetra
.661 .705 .88 r
.27738 .23987 .28525 .2498 .29751 .24507 .28967 .23519 Mtetra
.661 .707 .882 r
.28967 .23519 .29751 .24507 .30983 .2403 .30201 .23049 Mtetra
.66 .709 .884 r
.30201 .23049 .30983 .2403 .3222 .2356 .3144 .22584 Mtetra
.656 .71 .888 r
.3144 .22584 .3222 .2356 .33462 .23106 .32685 .2213 Mtetra
.649 .709 .891 r
.32685 .2213 .33462 .23106 .34708 .22681 .33934 .21697 Mtetra
.64 .704 .893 r
.33934 .21697 .34708 .22681 .35957 .223 .35187 .21293 Mtetra
.626 .695 .894 r
.35187 .21293 .35957 .223 .3721 .21975 .36445 .20929 Mtetra
.611 .681 .891 r
.36445 .20929 .3721 .21975 .38468 .21717 .37708 .2061 Mtetra
.595 .661 .884 r
.37708 .2061 .38468 .21717 .3973 .21526 .38975 .20337 Mtetra
.582 .638 .872 r
.38975 .20337 .3973 .21526 .40998 .21397 .40249 .20105 Mtetra
.574 .615 .856 r
.40249 .20105 .40998 .21397 .42274 .21311 .4153 .19899 Mtetra
.573 .594 .837 r
.4153 .19899 .42274 .21311 .43558 .21237 .42819 .19696 Mtetra
.578 .578 .816 r
.42819 .19696 .43558 .21237 .44853 .21141 .44118 .19469 Mtetra
.589 .567 .797 r
.44118 .19469 .44853 .21141 .46159 .20984 .45426 .19189 Mtetra
.603 .56 .779 r
.45426 .19189 .46159 .20984 .47475 .20733 .46744 .18833 Mtetra
.617 .557 .765 r
.46744 .18833 .47475 .20733 .48802 .20365 .48071 .18385 Mtetra
.631 .557 .754 r
.48071 .18385 .48802 .20365 .50137 .1987 .49406 .17843 Mtetra
.643 .56 .747 r
.49406 .17843 .50137 .1987 .51479 .19251 .50748 .17214 Mtetra
.653 .565 .744 r
.50748 .17214 .51479 .19251 .52826 .18522 .52095 .16514 Mtetra
.661 .573 .745 r
.52095 .16514 .52826 .18522 .54177 .17708 .53447 .15766 Mtetra
.668 .583 .751 r
.53447 .15766 .54177 .17708 .55532 .16836 .54803 .14993 Mtetra
.674 .596 .76 r
.54803 .14993 .55532 .16836 .56889 .15937 .56163 .14215 Mtetra
.678 .612 .774 r
.56163 .14215 .56889 .15937 .5825 .1504 .57528 .13451 Mtetra
.682 .63 .791 r
.57528 .13451 .5825 .1504 .59614 .14166 .58898 .12713 Mtetra
.683 .65 .811 r
.58898 .12713 .59614 .14166 .60984 .13336 .60273 .12007 Mtetra
.684 .671 .832 r
.60273 .12007 .60984 .13336 .62358 .12559 .61655 .11337 Mtetra
.682 .691 .852 r
.61655 .11337 .62358 .12559 .6374 .1184 .63043 .10701 Mtetra
.679 .707 .87 r
.63043 .10701 .6374 .1184 .65129 .11173 .64439 .10096 Mtetra
.675 .72 .883 r
.64439 .10096 .65129 .11173 .66526 .10552 .65842 .09514 Mtetra
.671 .729 .893 r
.65842 .09514 .66526 .10552 .6793 .09964 .67253 .0895 Mtetra
.668 .735 .9 r
.67253 .0895 .6793 .09964 .69343 .09399 .68672 .08396 Mtetra
.666 .738 .904 r
.68672 .08396 .69343 .09399 .70763 .08847 .70097 .07847 Mtetra
.665 .74 .906 r
.70097 .07847 .70763 .08847 .72191 .08302 .7153 .07301 Mtetra
.664 .74 .907 r
.7153 .07301 .72191 .08302 .73627 .07758 .72971 .06754 Mtetra
.663 .74 .908 r
.0801 .30133 .08863 .30932 .10004 .30505 .09153 .29702 Mtetra
.663 .74 .907 r
.09153 .29702 .10004 .30505 .11149 .30077 .10301 .29269 Mtetra
.662 .74 .907 r
.10301 .29269 .11149 .30077 .12299 .29648 .11455 .28835 Mtetra
.662 .739 .907 r
.11455 .28835 .12299 .29648 .13455 .29218 .12613 .28399 Mtetra
.662 .738 .907 r
.12613 .28399 .13455 .29218 .14615 .28789 .13777 .27963 Mtetra
.661 .737 .906 r
.13777 .27963 .14615 .28789 .15781 .28361 .14946 .27526 Mtetra
.661 .736 .906 r
.14946 .27526 .15781 .28361 .16951 .27934 .1612 .27089 Mtetra
.66 .734 .904 r
.1612 .27089 .16951 .27934 .18127 .27508 .173 .26651 Mtetra
.659 .732 .903 r
.173 .26651 .18127 .27508 .19308 .27083 .18485 .26212 Mtetra
.659 .729 .901 r
.18485 .26212 .19308 .27083 .20494 .26657 .19675 .25771 Mtetra
.659 .727 .899 r
.19675 .25771 .20494 .26657 .21686 .26228 .20871 .25329 Mtetra
.659 .724 .897 r
.20871 .25329 .21686 .26228 .22884 .25794 .22073 .24882 Mtetra
.66 .722 .895 r
.22073 .24882 .22884 .25794 .24088 .25354 .23281 .24432 Mtetra
.66 .721 .893 r
.23281 .24432 .24088 .25354 .25299 .24906 .24495 .23976 Mtetra
.661 .72 .892 r
.24495 .23976 .25299 .24906 .26515 .2445 .25714 .23515 Mtetra
.662 .72 .892 r
.25714 .23515 .26515 .2445 .27738 .23987 .2694 .2305 Mtetra
.662 .721 .892 r
.2694 .2305 .27738 .23987 .28967 .23519 .28171 .22582 Mtetra
.662 .722 .893 r
.28171 .22582 .28967 .23519 .30201 .23049 .29408 .22113 Mtetra
.66 .722 .895 r
.29408 .22113 .30201 .23049 .3144 .22584 .30651 .21647 Mtetra
.658 .722 .896 r
.30651 .21647 .3144 .22584 .32685 .2213 .31898 .21188 Mtetra
.653 .72 .898 r
.31898 .21188 .32685 .2213 .33934 .21697 .33151 .20742 Mtetra
.646 .716 .899 r
.33151 .20742 .33934 .21697 .35187 .21293 .34409 .20316 Mtetra
.637 .708 .898 r
.34409 .20316 .35187 .21293 .36445 .20929 .35672 .19914 Mtetra
.627 .696 .895 r
.35672 .19914 .36445 .20929 .37708 .2061 .36939 .19543 Mtetra
.616 .681 .888 r
.36939 .19543 .37708 .2061 .38975 .20337 .38213 .19201 Mtetra
.607 .663 .878 r
.38213 .19201 .38975 .20337 .40249 .20105 .39492 .18885 Mtetra
.601 .644 .865 r
.39492 .18885 .40249 .20105 .4153 .19899 .40778 .18584 Mtetra
.6 .626 .849 r
.40778 .18584 .4153 .19899 .42819 .19696 .42072 .18282 Mtetra
.604 .612 .832 r
.42072 .18282 .42819 .19696 .44118 .19469 .43375 .17958 Mtetra
.611 .601 .816 r
.43375 .17958 .44118 .19469 .45426 .19189 .44686 .17594 Mtetra
.621 .595 .802 r
.44686 .17594 .45426 .19189 .46744 .18833 .46006 .17172 Mtetra
.633 .593 .792 r
.46006 .17172 .46744 .18833 .48071 .18385 .47335 .16685 Mtetra
.644 .594 .784 r
.47335 .16685 .48071 .18385 .49406 .17843 .48671 .16131 Mtetra
.654 .599 .781 r
.48671 .16131 .49406 .17843 .50748 .17214 .50013 .15518 Mtetra
.662 .605 .781 r
.50013 .15518 .50748 .17214 .52095 .16514 .51361 .14861 Mtetra
.669 .614 .785 r
.51361 .14861 .52095 .16514 .53447 .15766 .52715 .14176 Mtetra
.674 .626 .793 r
.52715 .14176 .53447 .15766 .54803 .14993 .54073 .13481 Mtetra
.677 .639 .804 r
.54073 .13481 .54803 .14993 .56163 .14215 .55437 .12791 Mtetra
.679 .653 .817 r
.55437 .12791 .56163 .14215 .57528 .13451 .56806 .12115 Mtetra
.68 .669 .832 r
.56806 .12115 .57528 .13451 .58898 .12713 .58181 .11461 Mtetra
.679 .684 .848 r
.58181 .11461 .58898 .12713 .60273 .12007 .59562 .10829 Mtetra
.678 .699 .862 r
.59562 .10829 .60273 .12007 .61655 .11337 .60949 .10219 Mtetra
.675 .712 .876 r
.60949 .10219 .61655 .11337 .63043 .10701 .62344 .0963 Mtetra
.672 .722 .886 r
.62344 .0963 .63043 .10701 .64439 .10096 .63745 .09056 Mtetra
.67 .729 .894 r
.63745 .09056 .64439 .10096 .65842 .09514 .65154 .08494 Mtetra
.668 .734 .9 r
.65154 .08494 .65842 .09514 .67253 .0895 .66571 .0794 Mtetra
.666 .737 .903 r
.66571 .0794 .67253 .0895 .68672 .08396 .67994 .0739 Mtetra
.665 .739 .905 r
.67994 .0739 .68672 .08396 .70097 .07847 .69425 .06842 Mtetra
.664 .74 .906 r
.69425 .06842 .70097 .07847 .7153 .07301 .70863 .06293 Mtetra
.664 .741 .907 r
.70863 .06293 .7153 .07301 .72971 .06754 .72309 .05742 Mtetra
.663 .74 .908 r
.07149 .29328 .0801 .30133 .09153 .29702 .08295 .28893 Mtetra
.08295 .28893 .09153 .29702 .10301 .29269 .09446 .28456 Mtetra
.663 .74 .907 r
.09446 .28456 .10301 .29269 .11455 .28835 .10603 .28017 Mtetra
.10603 .28017 .11455 .28835 .12613 .28399 .11764 .27576 Mtetra
.662 .739 .907 r
.11764 .27576 .12613 .28399 .13777 .27963 .12931 .27134 Mtetra
.12931 .27134 .13777 .27963 .14946 .27526 .14104 .26691 Mtetra
.662 .738 .906 r
.14104 .26691 .14946 .27526 .1612 .27089 .15281 .26246 Mtetra
.662 .737 .906 r
.15281 .26246 .1612 .27089 .173 .26651 .16465 .258 Mtetra
.661 .736 .905 r
.16465 .258 .173 .26651 .18485 .26212 .17653 .25352 Mtetra
.661 .734 .904 r
.17653 .25352 .18485 .26212 .19675 .25771 .18847 .24903 Mtetra
.661 .733 .903 r
.18847 .24903 .19675 .25771 .20871 .25329 .20047 .24451 Mtetra
.661 .732 .902 r
.20047 .24451 .20871 .25329 .22073 .24882 .21252 .23996 Mtetra
.661 .731 .901 r
.21252 .23996 .22073 .24882 .23281 .24432 .22463 .23538 Mtetra
.662 .73 .9 r
.22463 .23538 .23281 .24432 .24495 .23976 .2368 .23076 Mtetra
.2368 .23076 .24495 .23976 .25714 .23515 .24903 .22611 Mtetra
.662 .73 .899 r
.24903 .22611 .25714 .23515 .2694 .2305 .26132 .22143 Mtetra
.662 .73 .9 r
.26132 .22143 .2694 .2305 .28171 .22582 .27366 .21672 Mtetra
.27366 .21672 .28171 .22582 .29408 .22113 .28607 .21201 Mtetra
.661 .73 .901 r
.28607 .21201 .29408 .22113 .30651 .21647 .29852 .20731 Mtetra
.659 .73 .902 r
.29852 .20731 .30651 .21647 .31898 .21188 .31104 .20264 Mtetra
.656 .728 .902 r
.31104 .20264 .31898 .21188 .33151 .20742 .32361 .19806 Mtetra
.652 .724 .902 r
.32361 .19806 .33151 .20742 .34409 .20316 .33623 .19359 Mtetra
.646 .718 .901 r
.33623 .19359 .34409 .20316 .35672 .19914 .3489 .18927 Mtetra
.639 .709 .898 r
.3489 .18927 .35672 .19914 .36939 .19543 .36163 .18513 Mtetra
.632 .698 .892 r
.36163 .18513 .36939 .19543 .38213 .19201 .37441 .18117 Mtetra
.626 .684 .885 r
.37441 .18117 .38213 .19201 .39492 .18885 .38726 .17736 Mtetra
.622 .669 .874 r
.38726 .17736 .39492 .18885 .40778 .18584 .40017 .17364 Mtetra
.621 .655 .862 r
.40017 .17364 .40778 .18584 .42072 .18282 .41316 .16988 Mtetra
.623 .643 .849 r
.41316 .16988 .42072 .18282 .43375 .17958 .42623 .16596 Mtetra
.628 .634 .837 r
.42623 .16596 .43375 .17958 .44686 .17594 .43937 .16175 Mtetra
.636 .629 .827 r
.43937 .16175 .44686 .17594 .46006 .17172 .4526 .15714 Mtetra
.644 .628 .819 r
.4526 .15714 .46006 .17172 .47335 .16685 .46591 .15208 Mtetra
.652 .63 .814 r
.46591 .15208 .47335 .16685 .48671 .16131 .47928 .14658 Mtetra
.66 .635 .813 r
.47928 .14658 .48671 .16131 .50013 .15518 .49272 .14069 Mtetra
.667 .642 .816 r
.49272 .14069 .50013 .15518 .51361 .14861 .50623 .13452 Mtetra
.672 .651 .821 r
.50623 .13452 .51361 .14861 .52715 .14176 .51979 .1282 Mtetra
.675 .662 .829 r
.51979 .1282 .52715 .14176 .54073 .13481 .5334 .12183 Mtetra
.677 .674 .839 r
.5334 .12183 .54073 .13481 .55437 .12791 .54708 .11553 Mtetra
.677 .686 .851 r
.54708 .11553 .55437 .12791 .56806 .12115 .56081 .10933 Mtetra
.676 .697 .862 r
.56081 .10933 .56806 .12115 .58181 .11461 .57461 .10328 Mtetra
.675 .708 .873 r
.57461 .10328 .58181 .11461 .59562 .10829 .58847 .09738 Mtetra
.673 .717 .882 r
.58847 .09738 .59562 .10829 .60949 .10219 .6024 .09161 Mtetra
.67 .725 .89 r
.6024 .09161 .60949 .10219 .62344 .0963 .61639 .08594 Mtetra
.668 .731 .896 r
.61639 .08594 .62344 .0963 .63745 .09056 .63046 .08035 Mtetra
.667 .735 .901 r
.63046 .08035 .63745 .09056 .65154 .08494 .64461 .07482 Mtetra
.666 .737 .904 r
.64461 .07482 .65154 .08494 .66571 .0794 .65882 .0693 Mtetra
.665 .739 .905 r
.65882 .0693 .66571 .0794 .67994 .0739 .67311 .0638 Mtetra
.664 .74 .906 r
.67311 .0638 .67994 .0739 .69425 .06842 .68747 .05829 Mtetra
.664 .741 .907 r
.68747 .05829 .69425 .06842 .70863 .06293 .7019 .05276 Mtetra
.7019 .05276 .70863 .06293 .72309 .05742 .71641 .0472 Mtetra
.663 .74 .908 r
.06281 .28516 .07149 .29328 .08295 .28893 .0743 .28077 Mtetra
.0743 .28077 .08295 .28893 .09446 .28456 .08584 .27636 Mtetra
.663 .74 .907 r
.08584 .27636 .09446 .28456 .10603 .28017 .09743 .27193 Mtetra
.09743 .27193 .10603 .28017 .11764 .27576 .10908 .26748 Mtetra
.10908 .26748 .11764 .27576 .12931 .27134 .12078 .26301 Mtetra
.12078 .26301 .12931 .27134 .14104 .26691 .13254 .25853 Mtetra
.663 .739 .907 r
.13254 .25853 .14104 .26691 .15281 .26246 .14435 .25402 Mtetra
.662 .739 .907 r
.14435 .25402 .15281 .26246 .16465 .258 .15621 .2495 Mtetra
.662 .738 .906 r
.15621 .2495 .16465 .258 .17653 .25352 .16813 .24496 Mtetra
.662 .737 .906 r
.16813 .24496 .17653 .25352 .18847 .24903 .1801 .24039 Mtetra
.662 .737 .905 r
.1801 .24039 .18847 .24903 .20047 .24451 .19214 .23581 Mtetra
.662 .736 .905 r
.19214 .23581 .20047 .24451 .21252 .23996 .20422 .2312 Mtetra
.662 .736 .904 r
.20422 .2312 .21252 .23996 .22463 .23538 .21637 .22656 Mtetra
.663 .735 .904 r
.21637 .22656 .22463 .23538 .2368 .23076 .22857 .2219 Mtetra
.663 .735 .903 r
.22857 .2219 .2368 .23076 .24903 .22611 .24083 .2172 Mtetra
.24083 .2172 .24903 .22611 .26132 .22143 .25315 .21248 Mtetra
.25315 .21248 .26132 .22143 .27366 .21672 .26553 .20774 Mtetra
.662 .735 .904 r
.26553 .20774 .27366 .21672 .28607 .21201 .27797 .20299 Mtetra
.27797 .20299 .28607 .21201 .29852 .20731 .29046 .19823 Mtetra
.661 .734 .904 r
.29046 .19823 .29852 .20731 .31104 .20264 .30301 .1935 Mtetra
.659 .733 .904 r
.30301 .1935 .31104 .20264 .32361 .19806 .31562 .18879 Mtetra
.656 .73 .904 r
.31562 .18879 .32361 .19806 .33623 .19359 .32828 .18415 Mtetra
.652 .726 .903 r
.32828 .18415 .33623 .19359 .3489 .18927 .341 .17959 Mtetra
.648 .72 .9 r
.341 .17959 .3489 .18927 .36163 .18513 .35378 .17513 Mtetra
.644 .711 .896 r
.35378 .17513 .36163 .18513 .37441 .18117 .36661 .17078 Mtetra
.64 .702 .891 r
.36661 .17078 .37441 .18117 .38726 .17736 .37951 .1665 Mtetra
.637 .691 .883 r
.37951 .1665 .38726 .17736 .40017 .17364 .39247 .16226 Mtetra
.637 .68 .875 r
.39247 .16226 .40017 .17364 .41316 .16988 .40551 .15799 Mtetra
.638 .671 .865 r
.40551 .15799 .41316 .16988 .42623 .16596 .41862 .1536 Mtetra
.641 .664 .857 r
.41862 .1536 .42623 .16596 .43937 .16175 .4318 .14901 Mtetra
.646 .66 .849 r
.4318 .14901 .43937 .16175 .4526 .15714 .44505 .14416 Mtetra
.652 .659 .844 r
.44505 .14416 .4526 .15714 .46591 .15208 .45839 .13901 Mtetra
.658 .661 .842 r
.45839 .13901 .46591 .15208 .47928 .14658 .47179 .13358 Mtetra
.664 .666 .842 r
.47179 .13358 .47928 .14658 .49272 .14069 .48525 .12791 Mtetra
.668 .673 .845 r
.48525 .12791 .49272 .14069 .50623 .13452 .49878 .12206 Mtetra
.672 .681 .85 r
.49878 .12206 .50623 .13452 .51979 .1282 .51237 .11611 Mtetra
.674 .69 .857 r
.51237 .11611 .51979 .1282 .5334 .12183 .52603 .11015 Mtetra
.674 .699 .865 r
.52603 .11015 .5334 .12183 .54708 .11553 .53974 .10423 Mtetra
.674 .708 .874 r
.53974 .10423 .54708 .11553 .56081 .10933 .55352 .09837 Mtetra
.672 .716 .881 r
.55352 .09837 .56081 .10933 .57461 .10328 .56736 .09261 Mtetra
.671 .723 .888 r
.56736 .09261 .57461 .10328 .58847 .09738 .58127 .08692 Mtetra
.669 .728 .894 r
.58127 .08692 .58847 .09738 .6024 .09161 .59525 .08131 Mtetra
.668 .733 .899 r
.59525 .08131 .6024 .09161 .61639 .08594 .6093 .07574 Mtetra
.666 .736 .902 r
.6093 .07574 .61639 .08594 .63046 .08035 .62342 .0702 Mtetra
.665 .738 .904 r
.62342 .0702 .63046 .08035 .64461 .07482 .63761 .06468 Mtetra
.665 .739 .906 r
.63761 .06468 .64461 .07482 .65882 .0693 .65187 .05916 Mtetra
.664 .74 .906 r
.65187 .05916 .65882 .0693 .67311 .0638 .66621 .05362 Mtetra
.664 .741 .907 r
.66621 .05362 .67311 .0638 .68747 .05829 .68062 .04807 Mtetra
.68062 .04807 .68747 .05829 .7019 .05276 .69511 .0425 Mtetra
.69511 .0425 .7019 .05276 .71641 .0472 .70967 .0369 Mtetra
.663 .74 .908 r
.05406 .27698 .06281 .28516 .0743 .28077 .06557 .27255 Mtetra
.06557 .27255 .0743 .28077 .08584 .27636 .07714 .2681 Mtetra
.07714 .2681 .08584 .27636 .09743 .27193 .08877 .26363 Mtetra
.663 .74 .907 r
.08877 .26363 .09743 .27193 .10908 .26748 .10045 .25914 Mtetra
.10045 .25914 .10908 .26748 .12078 .26301 .11218 .25462 Mtetra
.11218 .25462 .12078 .26301 .13254 .25853 .12396 .25009 Mtetra
.12396 .25009 .13254 .25853 .14435 .25402 .1358 .24554 Mtetra
.1358 .24554 .14435 .25402 .15621 .2495 .1477 .24097 Mtetra
.663 .739 .907 r
.1477 .24097 .15621 .2495 .16813 .24496 .15965 .23637 Mtetra
.15965 .23637 .16813 .24496 .1801 .24039 .17166 .23176 Mtetra
.663 .739 .906 r
.17166 .23176 .1801 .24039 .19214 .23581 .18372 .22712 Mtetra
.663 .738 .906 r
.18372 .22712 .19214 .23581 .20422 .2312 .19584 .22246 Mtetra
.19584 .22246 .20422 .2312 .21637 .22656 .20802 .21777 Mtetra
.20802 .21777 .21637 .22656 .22857 .2219 .22026 .21306 Mtetra
.22026 .21306 .22857 .2219 .24083 .2172 .23255 .20833 Mtetra
.663 .738 .905 r
.23255 .20833 .24083 .2172 .25315 .21248 .24491 .20357 Mtetra
.663 .738 .906 r
.24491 .20357 .25315 .21248 .26553 .20774 .25732 .19879 Mtetra
.25732 .19879 .26553 .20774 .27797 .20299 .26979 .19399 Mtetra
.662 .738 .906 r
.26979 .19399 .27797 .20299 .29046 .19823 .28232 .18918 Mtetra
.662 .737 .906 r
.28232 .18918 .29046 .19823 .30301 .1935 .29491 .18437 Mtetra
.661 .736 .906 r
.29491 .18437 .30301 .1935 .31562 .18879 .30755 .17957 Mtetra
.659 .734 .905 r
.30755 .17957 .31562 .18879 .32828 .18415 .32026 .17479 Mtetra
.657 .731 .904 r
.32026 .17479 .32828 .18415 .341 .17959 .33302 .17006 Mtetra
.654 .727 .902 r
.33302 .17006 .341 .17959 .35378 .17513 .34584 .16537 Mtetra
.652 .722 .9 r
.34584 .16537 .35378 .17513 .36661 .17078 .35873 .16073 Mtetra
.65 .715 .896 r
.35873 .16073 .36661 .17078 .37951 .1665 .37167 .15613 Mtetra
.648 .708 .891 r
.37167 .15613 .37951 .1665 .39247 .16226 .38468 .15153 Mtetra
.647 .701 .885 r
.38468 .15153 .39247 .16226 .40551 .15799 .39776 .1469 Mtetra
.648 .694 .879 r
.39776 .1469 .40551 .15799 .41862 .1536 .41091 .14219 Mtetra
.65 .689 .873 r
.41091 .14219 .41862 .1536 .4318 .14901 .42413 .13735 Mtetra
.653 .686 .868 r
.42413 .13735 .4318 .14901 .44505 .14416 .43742 .13235 Mtetra
.657 .686 .865 r
.43742 .13235 .44505 .14416 .45839 .13901 .45078 .12716 Mtetra
.661 .687 .864 r
.45078 .12716 .45839 .13901 .47179 .13358 .46421 .12178 Mtetra
.665 .691 .865 r
.46421 .12178 .47179 .13358 .48525 .12791 .47771 .11626 Mtetra
.668 .696 .867 r
.47771 .11626 .48525 .12791 .49878 .12206 .49127 .11063 Mtetra
.67 .702 .872 r
.49127 .11063 .49878 .12206 .51237 .11611 .5049 .10493 Mtetra
.671 .709 .877 r
.5049 .10493 .51237 .11611 .52603 .11015 .51859 .09922 Mtetra
.671 .716 .882 r
.51859 .09922 .52603 .11015 .53974 .10423 .53235 .09352 Mtetra
.67 .722 .888 r
.53235 .09352 .53974 .10423 .55352 .09837 .54617 .08786 Mtetra
.669 .727 .893 r
.54617 .08786 .55352 .09837 .56736 .09261 .56006 .08224 Mtetra
.668 .731 .897 r
.56006 .08224 .56736 .09261 .58127 .08692 .57401 .07666 Mtetra
.667 .734 .9 r
.57401 .07666 .58127 .08692 .59525 .08131 .58804 .07111 Mtetra
.666 .737 .903 r
.58804 .07111 .59525 .08131 .6093 .07574 .60214 .06557 Mtetra
.665 .738 .905 r
.60214 .06557 .6093 .07574 .62342 .0702 .61631 .06004 Mtetra
.665 .739 .906 r
.61631 .06004 .62342 .0702 .63761 .06468 .63055 .0545 Mtetra
.664 .74 .907 r
.63055 .0545 .63761 .06468 .65187 .05916 .64486 .04894 Mtetra
.664 .741 .907 r
.64486 .04894 .65187 .05916 .66621 .05362 .65925 .04337 Mtetra
.65925 .04337 .66621 .05362 .68062 .04807 .67371 .03777 Mtetra
.67371 .03777 .68062 .04807 .69511 .0425 .68825 .03214 Mtetra
.68825 .03214 .69511 .0425 .70967 .0369 .70286 .02649 Mtetra
.663 .741 .908 r
.04523 .26874 .05406 .27698 .06557 .27255 .05677 .26426 Mtetra
.05677 .26426 .06557 .27255 .07714 .2681 .06837 .25977 Mtetra
.663 .74 .908 r
.06837 .25977 .07714 .2681 .08877 .26363 .08003 .25526 Mtetra
.08003 .25526 .08877 .26363 .10045 .25914 .09173 .25073 Mtetra
.663 .74 .907 r
.09173 .25073 .10045 .25914 .11218 .25462 .1035 .24617 Mtetra
.1035 .24617 .11218 .25462 .12396 .25009 .11531 .2416 Mtetra
.11531 .2416 .12396 .25009 .1358 .24554 .12718 .237 Mtetra
.12718 .237 .1358 .24554 .1477 .24097 .13911 .23239 Mtetra
.13911 .23239 .1477 .24097 .15965 .23637 .1511 .22775 Mtetra
.1511 .22775 .15965 .23637 .17166 .23176 .16314 .22309 Mtetra
.16314 .22309 .17166 .23176 .18372 .22712 .17523 .2184 Mtetra
.663 .739 .907 r
.17523 .2184 .18372 .22712 .19584 .22246 .18739 .21369 Mtetra
.18739 .21369 .19584 .22246 .20802 .21777 .1996 .20896 Mtetra
.1996 .20896 .20802 .21777 .22026 .21306 .21187 .20421 Mtetra
.21187 .20421 .22026 .21306 .23255 .20833 .2242 .19943 Mtetra
.663 .739 .906 r
.2242 .19943 .23255 .20833 .24491 .20357 .23658 .19462 Mtetra
.23658 .19462 .24491 .20357 .25732 .19879 .24903 .1898 Mtetra
.663 .739 .907 r
.24903 .1898 .25732 .19879 .26979 .19399 .26154 .18495 Mtetra
.26154 .18495 .26979 .19399 .28232 .18918 .2741 .18009 Mtetra
.662 .739 .906 r
.2741 .18009 .28232 .18918 .29491 .18437 .28673 .17522 Mtetra
.662 .738 .906 r
.28673 .17522 .29491 .18437 .30755 .17957 .29941 .17034 Mtetra
.661 .737 .906 r
.29941 .17034 .30755 .17957 .32026 .17479 .31216 .16547 Mtetra
.66 .735 .905 r
.31216 .16547 .32026 .17479 .33302 .17006 .32496 .1606 Mtetra
.658 .732 .904 r
.32496 .1606 .33302 .17006 .34584 .16537 .33783 .15575 Mtetra
.657 .729 .902 r
.33783 .15575 .34584 .16537 .35873 .16073 .35076 .15091 Mtetra
.656 .725 .9 r
.35076 .15091 .35873 .16073 .37167 .15613 .36375 .14609 Mtetra
.655 .72 .897 r
.36375 .14609 .37167 .15613 .38468 .15153 .3768 .14125 Mtetra
.654 .716 .893 r
.3768 .14125 .38468 .15153 .39776 .1469 .38992 .13639 Mtetra
.655 .711 .889 r
.38992 .13639 .39776 .1469 .41091 .14219 .40311 .13147 Mtetra
.656 .708 .886 r
.40311 .13147 .41091 .14219 .42413 .13735 .41637 .12646 Mtetra
.658 .706 .883 r
.41637 .12646 .42413 .13735 .43742 .13235 .4297 .12134 Mtetra
.66 .706 .881 r
.4297 .12134 .43742 .13235 .45078 .12716 .4431 .11612 Mtetra
.662 .707 .88 r
.4431 .11612 .45078 .12716 .46421 .12178 .45656 .11077 Mtetra
.665 .709 .881 r
.45656 .11077 .46421 .12178 .47771 .11626 .47009 .10534 Mtetra
.666 .713 .883 r
.47009 .10534 .47771 .11626 .49127 .11063 .48369 .09983 Mtetra
.667 .717 .886 r
.48369 .09983 .49127 .11063 .5049 .10493 .49736 .09427 Mtetra
.668 .722 .889 r
.49736 .09427 .5049 .10493 .51859 .09922 .51109 .0887 Mtetra
.668 .726 .893 r
.51109 .0887 .51859 .09922 .53235 .09352 .52489 .08313 Mtetra
.667 .73 .896 r
.52489 .08313 .53235 .09352 .54617 .08786 .53875 .07756 Mtetra
.667 .733 .899 r
.53875 .07756 .54617 .08786 .56006 .08224 .55269 .072 Mtetra
.666 .736 .902 r
.55269 .072 .56006 .08224 .57401 .07666 .56669 .06646 Mtetra
.665 .737 .904 r
.56669 .06646 .57401 .07666 .58804 .07111 .58077 .06092 Mtetra
.665 .739 .905 r
.58077 .06092 .58804 .07111 .60214 .06557 .59491 .05537 Mtetra
.664 .74 .906 r
.59491 .05537 .60214 .06557 .61631 .06004 .60913 .04981 Mtetra
.664 .74 .907 r
.60913 .04981 .61631 .06004 .63055 .0545 .62342 .04424 Mtetra
.664 .741 .907 r
.62342 .04424 .63055 .0545 .64486 .04894 .63779 .03864 Mtetra
.63779 .03864 .64486 .04894 .65925 .04337 .65222 .03302 Mtetra
.65222 .03302 .65925 .04337 .67371 .03777 .66674 .02737 Mtetra
.66674 .02737 .67371 .03777 .68825 .03214 .68132 .02169 Mtetra
.664 .741 .908 r
.68132 .02169 .68825 .03214 .70286 .02649 .69599 .01599 Mtetra
.663 .741 .908 r
.03632 .26042 .04523 .26874 .05677 .26426 .0479 .25591 Mtetra
.0479 .25591 .05677 .26426 .06837 .25977 .05953 .25138 Mtetra
.05953 .25138 .06837 .25977 .08003 .25526 .07121 .24683 Mtetra
.07121 .24683 .08003 .25526 .09173 .25073 .08295 .24225 Mtetra
.663 .74 .908 r
.08295 .24225 .09173 .25073 .1035 .24617 .09474 .23766 Mtetra
.663 .74 .907 r
.09474 .23766 .1035 .24617 .11531 .2416 .10659 .23304 Mtetra
.10659 .23304 .11531 .2416 .12718 .237 .11849 .2284 Mtetra
.11849 .2284 .12718 .237 .13911 .23239 .13045 .22374 Mtetra
.13045 .22374 .13911 .23239 .1511 .22775 .14246 .21906 Mtetra
.14246 .21906 .1511 .22775 .16314 .22309 .15454 .21435 Mtetra
.15454 .21435 .16314 .22309 .17523 .2184 .16667 .20962 Mtetra
.16667 .20962 .17523 .2184 .18739 .21369 .17885 .20487 Mtetra
.17885 .20487 .18739 .21369 .1996 .20896 .1911 .2001 Mtetra
.1911 .2001 .1996 .20896 .21187 .20421 .2034 .1953 Mtetra
.2034 .1953 .21187 .20421 .2242 .19943 .21576 .19048 Mtetra
.21576 .19048 .2242 .19943 .23658 .19462 .22819 .18563 Mtetra
.22819 .18563 .23658 .19462 .24903 .1898 .24067 .18076 Mtetra
.24067 .18076 .24903 .1898 .26154 .18495 .25321 .17587 Mtetra
.25321 .17587 .26154 .18495 .2741 .18009 .26581 .17096 Mtetra
.663 .739 .907 r
.26581 .17096 .2741 .18009 .28673 .17522 .27847 .16603 Mtetra
.27847 .16603 .28673 .17522 .29941 .17034 .2912 .16108 Mtetra
.662 .738 .907 r
.2912 .16108 .29941 .17034 .31216 .16547 .30398 .15613 Mtetra
.661 .737 .906 r
.30398 .15613 .31216 .16547 .32496 .1606 .31683 .15117 Mtetra
.661 .736 .905 r
.31683 .15117 .32496 .1606 .33783 .15575 .32973 .1462 Mtetra
.66 .734 .904 r
.32973 .1462 .33783 .15575 .35076 .15091 .3427 .14123 Mtetra
.659 .731 .903 r
.3427 .14123 .35076 .15091 .36375 .14609 .35574 .13625 Mtetra
.659 .729 .901 r
.35574 .13625 .36375 .14609 .3768 .14125 .36883 .13126 Mtetra
.659 .726 .899 r
.36883 .13126 .3768 .14125 .38992 .13639 .382 .12624 Mtetra
.659 .723 .897 r
.382 .12624 .38992 .13639 .40311 .13147 .39523 .12117 Mtetra
.659 .721 .895 r
.39523 .12117 .40311 .13147 .41637 .12646 .40853 .11605 Mtetra
.661 .72 .893 r
.40853 .11605 .41637 .12646 .4297 .12134 .42189 .11085 Mtetra
.662 .72 .892 r
.42189 .11085 .4297 .12134 .4431 .11612 .43533 .10559 Mtetra
.663 .721 .892 r
.43533 .10559 .4431 .11612 .45656 .11077 .44883 .10025 Mtetra
.664 .722 .892 r
.44883 .10025 .45656 .11077 .47009 .10534 .4624 .09484 Mtetra
.665 .724 .893 r
.4624 .09484 .47009 .10534 .48369 .09983 .47604 .08939 Mtetra
.666 .727 .895 r
.47604 .08939 .48369 .09983 .49736 .09427 .48975 .0839 Mtetra
.666 .73 .897 r
.48975 .0839 .49736 .09427 .51109 .0887 .50352 .07839 Mtetra
.666 .733 .899 r
.50352 .07839 .51109 .0887 .52489 .08313 .51736 .07286 Mtetra
.666 .735 .901 r
.51736 .07286 .52489 .08313 .53875 .07756 .53127 .06733 Mtetra
.665 .737 .903 r
.53127 .06733 .53875 .07756 .55269 .072 .54525 .06179 Mtetra
.665 .738 .905 r
.54525 .06179 .55269 .072 .56669 .06646 .5593 .05624 Mtetra
.665 .739 .906 r
.5593 .05624 .56669 .06646 .58077 .06092 .57342 .05068 Mtetra
.664 .74 .906 r
.57342 .05068 .58077 .06092 .59491 .05537 .58762 .04511 Mtetra
.664 .74 .907 r
.58762 .04511 .59491 .05537 .60913 .04981 .60189 .03951 Mtetra
.664 .741 .907 r
.60189 .03951 .60913 .04981 .62342 .04424 .61623 .03389 Mtetra
.61623 .03389 .62342 .04424 .63779 .03864 .63064 .02824 Mtetra
.63064 .02824 .63779 .03864 .65222 .03302 .64513 .02257 Mtetra
.64513 .02257 .65222 .03302 .66674 .02737 .65969 .01687 Mtetra
.664 .741 .908 r
.65969 .01687 .66674 .02737 .68132 .02169 .67433 .01114 Mtetra
.67433 .01114 .68132 .02169 .69599 .01599 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.6806 .23839 m
.7064 .23805 L
.71954 .242 L
.7322 .24728 L
.75242 .2678 L
.758 .28164 L
.76132 .2936 L
.76068 .3194 L
.758 .32821 L
.75044 .3452 L
.7322 .36251 L
.70946 .371 L
.7064 .37166 L
.6806 .37131 L
.67922 .371 L
.6548 .36137 L
.63836 .3452 L
.629 .32295 L
.62808 .3194 L
.62744 .2936 L
.629 .2869 L
.63627 .2678 L
.6548 .24832 L
.66914 .242 L
.6806 .23839 L
s
.5774 .18599 m
.6032 .17577 L
.629 .17426 L
.6548 .18081 L
.67353 .1904 L
.6806 .19718 L
.6954 .2162 L
.70515 .242 L
.7064 .25009 L
.70664 .2678 L
.7064 .27006 L
.70053 .2936 L
.68335 .3194 L
.6806 .32216 L
.6548 .33943 L
.63251 .3452 L
.629 .34561 L
.60968 .3452 L
.6032 .34416 L
.5774 .3345 L
.55804 .3194 L
.5516 .31275 L
.54174 .2936 L
.53526 .2678 L
.53682 .242 L
.54711 .2162 L
.5516 .20885 L
.57012 .1904 L
.5774 .18599 L
s
.3194 .31272 m
.3452 .30587 L
.371 .30736 L
.3968 .31783 L
.39952 .3194 L
.4226 .34184 L
.42465 .3452 L
.43559 .371 L
.43745 .3968 L
.43105 .4226 L
.4226 .44007 L
.41477 .4484 L
.3968 .46236 L
.371 .47224 L
.3452 .47363 L
.3194 .46724 L
.2936 .44912 L
.2929 .4484 L
.27544 .4226 L
.2694 .3968 L
.27115 .371 L
.28162 .3452 L
.2936 .32962 L
.30521 .3194 L
.3194 .31272 L
s
.758 .24139 m
.77172 .242 L
.7838 .24436 L
.8096 .25989 L
.81634 .2678 L
.82873 .2936 L
.82967 .3194 L
.82015 .3452 L
.8096 .35921 L
.78958 .371 L
.7838 .37338 L
.758 .37702 L
.73442 .371 L
.7322 .37027 L
.7064 .34843 L
.70452 .3452 L
.69444 .3194 L
.69547 .2936 L
.7064 .27031 L
.70729 .2678 L
.7322 .24721 L
.75227 .242 L
.758 .24139 L
s
.2678 .36867 m
.2936 .36682 L
.31339 .371 L
.3194 .37307 L
.3452 .38983 L
.35166 .3968 L
.3665 .4226 L
.371 .44547 L
.37116 .4484 L
.371 .45712 L
.36825 .4742 L
.35626 .5 L
.3452 .51316 L
.32858 .5258 L
.3194 .52943 L
.2936 .5359 L
.2678 .53407 L
.24633 .5258 L
.242 .52359 L
.21711 .5 L
.2162 .49842 L
.20474 .4742 L
.20162 .4484 L
.20661 .4226 L
.2162 .40095 L
.221 .3968 L
.242 .37875 L
.25969 .371 L
.2678 .36867 L
s
.76008 .9902 m
.77215 .9644 L
.78199 .9386 L
.7838 .93325 L
.7898 .9128 L
.79569 .887 L
.79976 .8612 L
.80206 .8354 L
.80262 .8096 L
.80146 .7838 L
.79855 .758 L
.79385 .7322 L
.7873 .7064 L
.7838 .69493 L
.7788 .6806 L
.7682 .6548 L
.758 .63397 L
.75531 .629 L
.73986 .6032 L
.7322 .5919 L
.72145 .5774 L
.7064 .55922 L
.6995 .5516 L
.6806 .53263 L
.67311 .5258 L
.6548 .51052 L
.64072 .5 L
.629 .49198 L
.6032 .47642 L
.59912 .4742 L
.5774 .46343 L
.5516 .45275 L
.53936 .4484 L
.5258 .44417 L
.5 .43754 L
.4742 .43278 L
.4484 .4298 L
.4226 .42856 L
.3968 .42906 L
.371 .43128 L
.3452 .43528 L
.3194 .4411 L
.29486 .4484 L
.2936 .44883 L
.2678 .45859 L
.242 .47056 L
.23502 .4742 L
.2162 .48498 L
.19344 .5 L
.1904 .50219 L
Mistroke
.1646 .52268 L
.16104 .5258 L
.1388 .5472 L
.13465 .5516 L
.113 .57702 L
.11271 .5774 L
.09429 .6032 L
.0872 .61445 L
.07884 .629 L
.06595 .6548 L
.0614 .66518 L
.05535 .6806 L
.04685 .7064 L
.0403 .7322 L
.03561 .758 L
.0356 .75801 L
.0327 .7838 L
.03153 .8096 L
.0321 .8354 L
.03439 .8612 L
.0356 .87095 L
.03846 .887 L
.04435 .9128 L
.05216 .9386 L
.0614 .96298 L
.06201 .9644 L
.07407 .9902 L
Mfstroke
.242 .28923 m
.2678 .28364 L
.2936 .28635 L
.31163 .2936 L
.3194 .29777 L
.34141 .3194 L
.3452 .32618 L
.35337 .3452 L
.35646 .371 L
.3513 .3968 L
.3452 .41314 L
.33685 .4226 L
.3194 .43803 L
.29635 .4484 L
.2936 .4492 L
.2678 .45193 L
.24797 .4484 L
.242 .44654 L
.2162 .43112 L
.20787 .4226 L
.19298 .3968 L
.1904 .38754 L
.18807 .371 L
.1904 .34818 L
.19111 .3452 L
.20287 .3194 L
.2162 .30425 L
.22992 .2936 L
.242 .28923 L
s
0 g
.03 w
.69434 .30493 Mdot
.6211 .26008 Mdot
.35333 .38988 Mdot
.762 .30908 Mdot
.28654 .45129 Mdot
.41708 .81409 Mdot
.27216 .36786 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.69608 .27736 m
.71569 .27072 L
.73529 .28187 L
.73796 .28431 L
.7504 .30392 L
.73685 .32353 L
.73529 .32506 L
.71569 .33141 L
.69608 .32384 L
.69551 .32353 L
.67777 .30392 L
.68579 .28431 L
.69608 .27736 L
s
.69608 .25916 m
.71569 .25888 L
.73529 .2646 L
.73558 .26471 L
.7549 .27632 L
.75959 .28431 L
.76624 .30392 L
.76109 .32353 L
.7549 .33441 L
.73529 .34283 L
.73233 .34314 L
.71569 .3449 L
.70323 .34314 L
.69608 .34181 L
.67647 .33107 L
.66997 .32353 L
.66013 .30392 L
.66139 .28431 L
.67647 .26678 L
.68005 .26471 L
.69608 .25916 L
s
.28431 .36697 m
.30392 .36338 L
.32353 .3662 L
.34022 .38235 L
.34289 .40196 L
.33952 .42157 L
.32353 .43778 L
.30392 .44102 L
.28431 .43889 L
.26742 .42157 L
.26511 .40196 L
.26859 .38235 L
.28431 .36697 L
s
.65686 .26108 m
.67647 .24953 L
.69608 .24572 L
.71569 .24625 L
.73529 .25089 L
.7549 .26114 L
.75952 .26471 L
.77451 .28238 L
.77524 .28431 L
.78048 .30392 L
.77691 .32353 L
.77451 .32828 L
.76218 .34314 L
.7549 .34807 L
.73529 .3557 L
.71569 .35737 L
.69608 .35434 L
.67647 .34596 L
.67193 .34314 L
.65686 .33058 L
.65217 .32353 L
.64362 .30392 L
.64347 .28431 L
.65357 .26471 L
.65686 .26108 L
s
.30392 .34081 m
.32118 .34314 L
.32353 .34377 L
.34314 .35344 L
.35302 .36275 L
.36275 .37954 L
.36378 .38235 L
.36672 .40196 L
.36287 .42157 L
.36275 .42204 L
.35177 .44118 L
.34314 .4498 L
.32396 .46078 L
.32353 .4609 L
.30392 .46487 L
.28431 .46219 L
.28044 .46078 L
.26471 .4519 L
.25447 .44118 L
.2451 .42177 L
.24504 .42157 L
.24223 .40196 L
.2451 .38394 L
.24557 .38235 L
.25617 .36275 L
.26471 .3543 L
.28431 .34391 L
.28711 .34314 L
.30392 .34081 L
s
.65686 .24273 m
.67647 .2356 L
.69608 .23323 L
.71569 .23439 L
.73529 .23896 L
.75086 .2451 L
.7549 .24747 L
.77451 .26239 L
.77662 .26471 L
.78919 .28431 L
.79356 .30392 L
.7909 .32353 L
.77979 .34314 L
.77451 .3488 L
.7549 .3613 L
.75117 .36275 L
.73529 .36713 L
.71569 .36847 L
.69608 .36585 L
.68343 .36275 L
.67647 .35922 L
.65686 .34726 L
.65206 .34314 L
.63725 .32599 L
.63592 .32353 L
.62795 .30392 L
.62677 .28431 L
.63327 .26471 L
.63725 .25804 L
.65266 .2451 L
.65686 .24273 L
s
.30392 .32175 m
.32112 .32353 L
.32353 .32404 L
.34314 .33108 L
.36096 .34314 L
.36275 .34475 L
.37692 .36275 L
.38235 .37481 L
.38459 .38235 L
.38653 .40196 L
.38337 .42157 L
.38235 .42598 L
.3749 .44118 L
.36275 .45734 L
.35928 .46078 L
.34314 .47285 L
.32745 .48039 L
.32353 .48132 L
.30392 .48456 L
.28431 .4828 L
.27594 .48039 L
.26471 .47548 L
.24574 .46078 L
.2451 .46009 L
.23206 .44118 L
.22549 .42358 L
.2252 .42157 L
.22311 .40196 L
.22549 .38268 L
.22557 .38235 L
.23309 .36275 L
.2451 .34618 L
.24816 .34314 L
.26471 .33134 L
.28431 .324 L
.28648 .32353 L
.30392 .32175 L
s
.67647 .22213 m
.69608 .22098 L
.71569 .22267 L
.7328 .22549 L
.73529 .22712 L
.7549 .23479 L
.77208 .2451 L
.77451 .24691 L
.79194 .26471 L
.79412 .26668 L
.80241 .28431 L
.80626 .30392 L
.80412 .32353 L
.79521 .34314 L
.79412 .34484 L
.77595 .36275 L
.77451 .36373 L
.7549 .37359 L
.73529 .37842 L
.71569 .3795 L
.69608 .37723 L
.67647 .37152 L
.65838 .36275 L
.65686 .36181 L
.63725 .34655 L
.63399 .34314 L
.61972 .32353 L
.61765 .31948 L
.612 .30392 L
.60997 .28431 L
.61413 .26471 L
.61765 .25593 L
.62687 .2451 L
.63725 .2363 L
.65686 .22672 L
.65855 .22549 L
.67647 .22213 L
s
.30392 .30383 m
.30757 .30392 L
.32353 .30575 L
.34314 .3114 L
.36275 .32151 L
.36575 .32353 L
.38235 .33816 L
.38649 .34314 L
.39822 .36275 L
.40196 .37314 L
.40412 .38235 L
.40542 .40196 L
.40256 .42157 L
.40196 .42457 L
.39545 .44118 L
.3833 .46078 L
.38235 .462 L
.36385 .48039 L
.36275 .48124 L
.34314 .4933 L
.3254 .5 L
.32353 .50037 L
.30392 .50324 L
.28431 .50202 L
.27532 .5 L
.26471 .49635 L
.2451 .48514 L
.23921 .48039 L
.22549 .46535 L
.22235 .46078 L
.2123 .44118 L
.20683 .42157 L
.20588 .41517 L
.20513 .40196 L
.20588 .38988 L
.20705 .38235 L
.21296 .36275 L
.22397 .34314 L
.22549 .34109 L
.24317 .32353 L
.2451 .32212 L
.26471 .31127 L
.28431 .30554 L
.29898 .30392 L
.30392 .30383 L
s
.63725 .21736 m
.65686 .21105 L
.67647 .20824 L
.69608 .20813 L
.71569 .21035 L
.73529 .2149 L
.7549 .22202 L
.76237 .22549 L
.77451 .23254 L
.7906 .2451 L
.79412 .24845 L
.80679 .26471 L
.81373 .27683 L
.81578 .28431 L
.81918 .30392 L
.81743 .32353 L
.81373 .33538 L
.81009 .34314 L
.79516 .36275 L
.79412 .36374 L
.77451 .37779 L
.76535 .38235 L
.7549 .38583 L
.73529 .38992 L
.71569 .39083 L
.69608 .38883 L
.67647 .38392 L
.67176 .38235 L
.65686 .37576 L
.63725 .36356 L
.63618 .36275 L
.61765 .34553 L
.61565 .34314 L
.60248 .32353 L
.59804 .31765 L
.59477 .30392 L
.59201 .28431 L
.59441 .26471 L
.59804 .2514 L
.60323 .2451 L
.61765 .22912 L
.62257 .22549 L
.63725 .21736 L
s
.2451 .29992 m
.26471 .29143 L
.28431 .28682 L
.30392 .28548 L
.32353 .28717 L
.34314 .29188 L
.36275 .29992 L
.37016 .30392 L
.38235 .3121 L
.39539 .32353 L
.40196 .3307 L
.41072 .34314 L
.41992 .36275 L
.42157 .36807 L
.42444 .38235 L
.42512 .40196 L
.42235 .42157 L
.42157 .42555 L
.41606 .44118 L
.40591 .46078 L
.40196 .46677 L
.39092 .48039 L
.38235 .48891 L
.36849 .5 L
.36275 .50374 L
.34314 .51375 L
.32516 .51961 L
.32353 .5199 L
.30392 .52251 L
.28431 .52168 L
.27326 .51961 L
.26471 .51716 L
.2451 .50832 L
.23266 .5 L
.22549 .49383 L
.21315 .48039 L
.20588 .47007 L
.20069 .46078 L
.19269 .44118 L
.18815 .42157 L
.1867 .40196 L
.18826 .38235 L
.19307 .36275 L
.20172 .34314 L
.20588 .33616 L
.21556 .32353 L
.22549 .31364 L
.2383 .30392 L
.2451 .29992 L
s
.61765 .20586 m
.63725 .19832 L
.65686 .19439 L
.67647 .19312 L
.69608 .19401 L
.71569 .19682 L
.73529 .2015 L
.74904 .20588 L
.7549 .20826 L
.77451 .2178 L
.78673 .22549 L
.79412 .23111 L
.80862 .2451 L
.81373 .25121 L
.82218 .26471 L
.83001 .28431 L
.83306 .30392 L
.83162 .32353 L
.82539 .34314 L
.81373 .36227 L
.81332 .36275 L
.79412 .38085 L
.792 .38235 L
.77451 .39203 L
.7549 .39888 L
.7393 .40196 L
.73529 .40244 L
.71569 .40321 L
.69945 .40196 L
.69608 .40148 L
.67647 .39715 L
.65686 .39015 L
.64103 .38235 L
.63725 .38013 L
.61765 .36618 L
.61369 .36275 L
.59804 .34662 L
.59532 .34314 L
.58274 .32353 L
.57843 .31622 L
.57494 .30392 L
.57155 .28431 L
.57261 .26471 L
.57843 .24573 L
.57872 .2451 L
.59166 .22549 L
.59804 .21907 L
.61759 .20588 L
.61765 .20586 L
s
.2451 .27678 m
.26471 .26994 L
.28431 .26618 L
.30392 .26515 L
.32353 .26666 L
.34314 .27067 L
.36275 .27723 L
.37813 .28431 L
.38235 .28664 L
.40196 .29964 L
.40717 .30392 L
.42157 .31803 L
.42592 .32353 L
.43806 .34314 L
.44118 .34944 L
.44494 .36275 L
.44792 .38235 L
.44772 .40196 L
.44469 .42157 L
.44118 .43552 L
.43887 .44118 L
.42997 .46078 L
.42157 .4748 L
.41758 .48039 L
.40196 .4986 L
.40056 .5 L
.38235 .51543 L
.3764 .51961 L
.36275 .52762 L
.34314 .53623 L
.33523 .53922 L
.32353 .54164 L
.30392 .54406 L
.28431 .54353 L
.26471 .53992 L
.26192 .53922 L
.2451 .53277 L
.22549 .52144 L
.22294 .51961 L
.20588 .50441 L
.2019 .5 L
.18774 .48039 L
.18627 .47793 L
.17794 .46078 L
.17136 .44118 L
.16753 .42157 L
.16667 .41286 L
.16628 .40196 L
.16667 .39105 L
.16755 .38235 L
Mistroke
.17152 .36275 L
.17852 .34314 L
.18627 .32815 L
.18926 .32353 L
.20526 .30392 L
.20588 .3033 L
.22549 .28739 L
.23031 .28431 L
.2451 .27678 L
Mfstroke
.61765 .18172 m
.63725 .17711 L
.65686 .17518 L
.67647 .17536 L
.69608 .17731 L
.71569 .18079 L
.73529 .1857 L
.73731 .18627 L
.7549 .19248 L
.77451 .20127 L
.78316 .20588 L
.79412 .21286 L
.8102 .22549 L
.81373 .2288 L
.82784 .2451 L
.83333 .2531 L
.8393 .26471 L
.84607 .28431 L
.84879 .30392 L
.8476 .32353 L
.84235 .34314 L
.83333 .3615 L
.83247 .36275 L
.81605 .38235 L
.81373 .38448 L
.79412 .39863 L
.78814 .40196 L
.77451 .40781 L
.7549 .41363 L
.73529 .41674 L
.71569 .41745 L
.69608 .41592 L
.67647 .4122 L
.65686 .4063 L
.64569 .40196 L
.63725 .39798 L
.61765 .38684 L
.611 .38235 L
.59804 .37243 L
.58739 .36275 L
.57843 .3536 L
.57005 .34314 L
.55882 .32633 L
.55748 .32353 L
.5497 .30392 L
.54601 .28431 L
.54641 .26471 L
.55088 .2451 L
.55882 .22724 L
.56001 .22549 L
Mistroke
.57587 .20588 L
.57843 .20352 L
.59804 .18993 L
.60541 .18627 L
.61765 .18172 L
Mfstroke
.26471 .24382 m
.28431 .2409 L
.30392 .24016 L
.32353 .24148 L
.34314 .24475 L
.34479 .2451 L
.36275 .25009 L
.38235 .25733 L
.39861 .26471 L
.40196 .26639 L
.42157 .27737 L
.43162 .28431 L
.44118 .29016 L
.45849 .30392 L
.46078 .30525 L
.47792 .32353 L
.48039 .32523 L
.48452 .34314 L
.48452 .36275 L
.48157 .38235 L
.48039 .39437 L
.47885 .40196 L
.47399 .42157 L
.46766 .44118 L
.46078 .45817 L
.45951 .46078 L
.44874 .48039 L
.44118 .49186 L
.43501 .5 L
.42157 .5153 L
.41724 .51961 L
.40196 .5329 L
.3935 .53922 L
.38235 .54639 L
.36275 .55668 L
.35796 .55882 L
.34314 .56402 L
.32353 .56879 L
.30392 .57105 L
.28431 .57078 L
.26471 .56789 L
.2451 .5622 L
.23651 .55882 L
.22549 .55325 L
.20588 .54039 L
.20438 .53922 L
.18627 .52222 L
.18395 .51961 L
.16931 .5 L
.16667 .49576 L
Mistroke
.15858 .48039 L
.1507 .46078 L
.14706 .44902 L
.14531 .44118 L
.14218 .42157 L
.14111 .40196 L
.14212 .38235 L
.14529 .36275 L
.14706 .35506 L
.15095 .34314 L
.15946 .32353 L
.16667 .31087 L
.17143 .30392 L
.18627 .28628 L
.18824 .28431 L
.20588 .26953 L
.21298 .26471 L
.22549 .25766 L
.2451 .2493 L
.25865 .2451 L
.26471 .24382 L
Mfstroke
.57843 .16603 m
.59804 .15775 L
.61765 .15277 L
.63725 .15045 L
.65686 .15032 L
.67647 .15201 L
.69608 .15521 L
.71569 .15966 L
.73529 .16515 L
.74024 .16667 L
.7549 .17208 L
.77451 .18052 L
.78624 .18627 L
.79412 .19083 L
.81373 .20409 L
.81604 .20588 L
.83333 .22193 L
.83651 .22549 L
.85083 .2451 L
.85294 .24857 L
.86032 .26471 L
.86614 .28431 L
.86855 .30392 L
.86759 .32353 L
.8632 .34314 L
.85517 .36275 L
.85294 .36697 L
.84232 .38235 L
.83333 .39247 L
.82283 .40196 L
.81373 .40862 L
.79412 .41988 L
.79056 .42157 L
.77451 .42736 L
.7549 .43229 L
.73529 .43502 L
.71569 .43569 L
.69608 .43444 L
.67647 .43134 L
.65686 .42649 L
.64158 .42157 L
.63725 .41986 L
.61765 .411 L
.60074 .40196 L
.59804 .40037 L
.57843 .38768 L
.57154 .38235 L
.55882 .37332 L
.54716 .36275 L
.53922 .35739 L
Mistroke
.52356 .34314 L
.51961 .33932 L
.50795 .32353 L
.50346 .30392 L
.50546 .28431 L
.50883 .26471 L
.51425 .2451 L
.51961 .23052 L
.52215 .22549 L
.53363 .20588 L
.53922 .19834 L
.55031 .18627 L
.55882 .17883 L
.57722 .16667 L
.57843 .16603 L
Mfstroke
.55882 .1236 m
.57843 .11604 L
.59804 .11109 L
.61765 .10852 L
.63725 .10811 L
.65686 .10968 L
.67647 .113 L
.69608 .11779 L
.71569 .12365 L
.72748 .12745 L
.73529 .13042 L
.7549 .13837 L
.77451 .14667 L
.77542 .14706 L
.79412 .15676 L
.81185 .16667 L
.81373 .16789 L
.83333 .18186 L
.83893 .18627 L
.85294 .19927 L
.85908 .20588 L
.87255 .22288 L
.87421 .22549 L
.88509 .2451 L
.89216 .26197 L
.89292 .26471 L
.89731 .28431 L
.89925 .30392 L
.89861 .32353 L
.8954 .34314 L
.89216 .35584 L
.88935 .36275 L
.87965 .38235 L
.87255 .39378 L
.86622 .40196 L
.85294 .41633 L
.8472 .42157 L
.83333 .43207 L
.81904 .44118 L
.81373 .44377 L
.79412 .45221 L
.77451 .45866 L
.76655 .46078 L
.7549 .46259 L
.73529 .46469 L
.71569 .46538 L
.69608 .46468 L
.67647 .46272 L
.66306 .46078 L
.65686 .45939 L
Mistroke
.63725 .4543 L
.61765 .44823 L
.59804 .44178 L
.59705 .44118 L
.57843 .43501 L
.55882 .43032 L
.53922 .43169 L
.52464 .44118 L
.51961 .44683 L
.50947 .46078 L
.5 .47765 L
.49834 .48039 L
.48618 .5 L
.48039 .50885 L
.47249 .51961 L
.46078 .53409 L
.45618 .53922 L
.44118 .55428 L
.43616 .55882 L
.42157 .5706 L
.41068 .57843 L
.40196 .58387 L
.38235 .59462 L
.37515 .59804 L
.36275 .60284 L
.34314 .60894 L
.32353 .61306 L
.30392 .6151 L
.28431 .61504 L
.26471 .61282 L
.2451 .60838 L
.22549 .60167 L
.21693 .59804 L
.20588 .59223 L
.18627 .57963 L
.18463 .57843 L
.16667 .56295 L
.16254 .55882 L
.14706 .54083 L
.14586 .53922 L
.13295 .51961 L
.12745 .50977 L
.12283 .5 L
.11495 .48039 L
.1089 .46078 L
.10784 .45684 L
.10488 .44118 L
.10248 .42157 L
.10165 .40196 L
.10244 .38235 L
Mistroke
.10489 .36275 L
.10784 .34774 L
.10916 .34314 L
.11571 .32353 L
.12444 .30392 L
.12745 .29815 L
.13608 .28431 L
.14706 .26958 L
.15127 .26471 L
.16667 .24935 L
.17162 .2451 L
.18627 .23426 L
.20052 .22549 L
.20588 .22274 L
.22549 .21419 L
.2451 .20788 L
.25268 .20588 L
.26471 .20384 L
.28431 .20171 L
.30392 .20126 L
.32353 .20236 L
.34314 .20484 L
.34953 .20588 L
.36275 .20869 L
.38235 .21349 L
.40196 .21835 L
.42157 .22193 L
.44118 .22155 L
.46078 .21232 L
.46859 .20588 L
.48039 .19179 L
.48499 .18627 L
.5 .16833 L
.50152 .16667 L
.51961 .14898 L
.52187 .14706 L
.53922 .13436 L
.55092 .12745 L
.55882 .1236 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`00
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`00
0010ooooo`002Oooool01000003ooooooooooooooomZ000000/06ATI>0000004ooooo`0300000?oo
oooooooo07kooooo0_l00003ooooo`WoZKgX00Co0000ojVmj?oooooo0000?oooool000Wooooo00@0
0000ooooooooooooooooH`00000F01TI6C@000001?ooool00`00003oooooooooo`1kooooo`?o0000
0_ooool<ojVmj005o`000?nY_NSoooooooooool00000?_ooool000Wooooo00@00000oooooooooooo
ooooHP00000J01TI6@<0000000?o0000000000000000:`000004ooooo`0300000?oooooooooo07Wo
oooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY_NSoooooo`00000nooooo`002Oooool01000003o
oooooooooooooomO000002406ATI;@000004ooooo`0300000?oooooooooo07Kooooo0ol00002oooo
oa7oZKgX00Ko0000ojVmj?nY_NSoZKgXooooool0000mooooo`002Oooool01000003ooooooooooooo
oomN000002D06ATI:P000004ooooo`0300000?oooooooooo07Cooooo0_l00002ooooo`;oZKgW4_nY
_NP00ol0003oZKgXojVmj002ojVmj003o`000?oooooooooo03_ooooo0009ooooo`0400000?oooooo
oooooooooe`00000:P0I6ATW000000Cooooo00<00000ooooooooool0LOooool3o`0000;ooooo00?o
Z[gWojVmionY_NL00_nY_NL00onY_NSoZKgWojVmi`0>ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o
ooooo`000?ooool0>oooool000Wooooo00@00000ooooooooooooooooF`00000/01TI6BH000001?oo
ool00`00003oooooooooo`1^ooooo`?o00000_ooool2ojZli`?oZ[gW0_nY_NL00onZ_NOoZKgWojVm
i`02ojVmi`03ojVmj?nZ_NOoZKgX00GoZKgX00?oZKgWojVmj?nY_NP00_nY_NP00ol0003oZKgXojVm
j003ojVmj003ooooool0003ooooo03[ooooo0009ooooo`0400000?oooooooooooooooeX00000400I
6ATB000000d06ATI90000004ooooo`0300000?oooooooooo06cooooo0_l00003ooooo`GoZ[cW00?o
Z[gWojZlionZ_NL00onZ_NL2ojVmi`04ojZlionZ_NOoZ[gWojZmi`;oZKgX00?oZ[gWojVmionY_NL0
0_nY_NL01OnY_NSoZKgWojVmionY_NOo000000GoZKgX00?o0000ooooooooool0>Oooool000Wooooo
00@00000ooooooooooooooooF@00000=01TI6@@000004P0c<c<4000000/06ATI8P000004ooooo`03
00000?oooooooooo06Wooooo0ol00002ooooo`03ojZli_nZ_>OoZ[cW00CoZ[cW00CoZ[cVojZlionZ
_>OoZ[cW0_nZ_NL5ojZli`03ojZmionZ_>OoZ[cW00?oZ[gW0_nY_NL2ojZmi`;oZKgW00CoZ[gWo`00
0?nY_NOoZKgW0onY_NP00ooooooo0000ooooo`0iooooo`002Oooool01000003ooooooooooooooomH
000000`06ATI00?o00000000000c<c<06@0c<c<01?l00000000000000000000:01TI6@03o`000000
0000000001`000001?ooool00`00003oooooooooo`1Wooooo`;o00000oooool01?nZ^nKoZ[cVojZl
i_nZ_>H2ojZli`03ojZki_nZ_>KoZ[cV00;oZ[cV00?oZ[cWojZki_nZ^nH01OnZ_>L00onZ_>KoZ[cW
ojZli`02ojZli`03ojZmionZ_>OoZ[cW00;oZ[gW00KoZ[cWojZmionZ_NOoZ[gWo`000?nY_NL2ojZm
i`?oZKgX00?oooooo`000?ooool0>?ooool000Wooooo00@00000ooooooooooooooooEP0000000ol0
00006ATI01TI6@0:01TI6@030000000c<c<0<c<c01h0<c<c0P00000801TI6Al000001?ooool00`00
003oooooooooo`1Tooooo`?o00000_ooool00onZ^^GoZ[_VojZkiP02ojZkiP03ojZli_nZ^^GoZ[[U
00?oZ[_V0_nZ_>H00on[^nGoZ[_VojZkiP02ojZkiP03ojZlion[^nKoZk_V00?oZ[cV0_nZ_>L2ojZl
iP03ojZlion[^nKoZk_V00?oZ[cW0_nZ_NL00ol0003oZ[gWojZmi`02ojZmi`04ojVmj?nZ_NOooooo
o`0003Wooooo0009ooooo`0400000?oooooooooooooooeL000002`0I6AT00`000000<c<c03<c<`08
03<c<`l000002P0c<c<00`0000006ATI01TI6@0701TI6Ad000001?ooool00`00003oooooooooo`1R
ooooo`;o00000oooool4ojZji@;oZ[_V00?oZkWTojZjiOnZ^^D00_nZ^^D00onZ^nKoZk[Toj^ji003
oj^ki@;oZ[_V00?oZk[Toj^ki_n[^nH00_n[^nH00onZ_>KoZk_UojZliP02ojZliP03oj^ji?n[^nKo
Zk_V00;oZk_V00KoZ[cWoj^li_nZ_>OoZ[cWo`000?nZ_>L6ojZmi`03ooooool0003ooooo03Oooooo
0009ooooo`0400000?oooooooooooooooeH000002P0I6AT2000000P0<c<c0`00000?04a<C0@00000
1`0c<c<2000000T06ATI00?o000000000000000060000004ooooo`0300000?oooooooooo05oooooo
0ol00002ooooo`;oZ[WT1?nZ^^D2oj^hh`?oZkWT0_nZ^^D00on[^>?oZk[Toj^ji002oj^ji003oj^k
iOn[^N?oZk[T00?oZk[T0_n[^nH01On[^N?oZk_Uoj^kiOn[^nGoZ[cV00?oZk[T0_n[^nH01on[^^Co
ZkcVoj^li_n[_>KoZ[cWo`000?n[_>H01onZ_NL00ooooooo0000ooooo`0fooooo`002Oooool01000
003ooooooooooooooomE000000X06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00D
04a<C004o`00000000000000000000D0<c<c0P00000801TI6AX000001?ooool00`00003ooooooooo
o`1Mooooo`;o00000oooool00onY^>CoZ[WTojZii002ojZii003ojZjiOnZ]n;oZkSS00?oZkSS00?o
ZkWToj^ghOn[]n400on[^><2oj^ji004ojbghOn[^N?oZkWSoj^ih`;oZk[T00?o[;OQoj^ihon[^N<0
0_n[^N<01_n[^nGo[;SRojbhh_n/^>;oZk[TojbhhPCoZk[T00CoZkcVojbki?n/^nCo00000_n[_>H2
ojZmi`03oj^li_nZ_NOoZ[gW00;oZ[gW00?o0000ooooooooool0=Oooool000Wooooo00@00000oooo
ooooooooooooD`0000000ol000006ATI01TI6@0801TI6@030000000c<c<0<c<c00H0<c<c00<00000
o`00001<C4`01`1<C4`;o`0000P0C4a<0P00000503<c<`8000001`0I6ATI000000Cooooo00<00000
ooooooooool0F_ooool3o`0000;ooooo1OnY^>@2ojZii004ojZfh_nZ]n;oZ[ORojZghP;oZkSS00?o
ZkGPoj^ghOn[]n400_n[]n400on[^>?o[;GOojbgh@03ojbgh@03oj^ihon/]Moo[;GO00?o[;OQ0_n[
^N<2ojbfh0;o[;SR00Co[KCNojbhh_n/^>;o[;SR0_n[^^@01on]^>;o[;_Tojbki?n/^nCo0000oj^l
i_n/^nD01?n[_>H3ojZmi`03ooooool0003ooooo03Gooooo0009ooooo`0400000?oooooooooooooo
oe<000002P0I6AT00`000000<c<c03<c<`0503<c<`8000001P1<C4`4o`0000/0IVIV1?l0000604a<
C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000E0000
00Cooooo00<00000ooooooooool0Eoooool3o`0000?ooooo1_nY^>@00onZ]N7oZ[KRojZfhP02ojZf
hP03ojZgh_n[/mooZk?O00?oZkGP0_n[]n401?n//]go[;GOojbegon/]Ml2ojbgh@03ojfbg?n/]Moo
[;GO00;o[;GO00?o[;OQojfbg?n]/]`00on/]^04ojfdgP03ojbhh_n^]Mgo[[GM00?o[KSR0_n/^n@0
1?l0003o[;_UojbkiOn/^nD4oj^liP?oZ[gW00?oooooo`000?ooool0=?ooool000Wooooo00@00000
oooooooooooooooo>`0000000ol0000000000000000D000000X06ATI00?o000003<c<`0c<c<01@0c
<c<00`000000C4a<04a<C00404a<C0;o00004`1VIVH4o`0000<0C4a<0`00000403<c<`8000001P0I
6ATG000000Cooooo00<00000ooooooooool0EOooool2o`0000?ooooo1onY^>@01?nY]>7oZ[GQojZe
hOnZ]N42ojZfhP03oj^bgOn[/mooZk?O00;oZk?O00?oZkGPojb`fon//=/00on//]d00on/]Moo[JoI
ojf_f@03ojfbg0;o[;GO00?o[JoIojfbg?n]/]`00_n]/]`00on/]^3o[[3Jojj`fP02ojfdgP03ok2`
f?n^]Mgo[[GM00;o[[GM00Oo[KSRojnfg_n]^N;o[KWRo`000?n]^N;o[;_U00;o[K_T0on[_>H4oj^m
i`03o`000?oooooooooo03?ooooo0009ooooo`0400000?ooooooooooooooobX00000500I6ATD0000
00X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C003o`00001VIVH0IVIV
00@0IVIV3ol0000406IVIP?o00000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI
00<06ATI5`000004ooooo`0300000?oooooooooo05;ooooo0ol00003ooooo`03ojRhiOnY^>CoZKST
00?oZKST0_nX]>43ojVdh@03ojZehOnZ/=goZ[3M00?oZk;M0_n[/ml00on/[]Wo[;3Kojb`f`02ojb`
f`03ojbbgOn][=Ko[JoI00?o[JoI00?o[K;Lojj[e?n^Zm@00on][mT2ojfbg005ojn[e?n^/=[o[[3J
ojj`f_n]]=h00on`/=P2ojjeg@07ok6af?n_]]ko[kKNojnfg_n]^N;o0000ojnhh004ojfki003oj^l
i_n/_>Go[;cU00;oZkgW00?o[;gVooooool00000=?ooool000Wooooo00@00000oooooooooooooooo
:000000I01TI6A0000002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<
00?o000006IVIP1VIVH00P1VIVH3o`0000l0Ogmo0ol0000406IVIP05o`00001<C4`0C4a<04a<C000
00001@0c<c<00`0000006ATI01TI6@0301TI6AH000001?ooool00`00003oooooooooo`1@ooooo`;o
00001?ooool01?nX^NGoZ;SUojRhiOnX^>D2ojVhi003ojRdh_nX]>7oZ;CQ00;oZ;CQ00?oZKCQojV_
gOnZ/=d00onZ/=d00on[/]goZjcHoj^/f003ojb^f@;o[;3K00Co[:WDojf/e_n][=Ko[JcF0_n][mT0
0on]Ym7o[Z_Dojj[e002ojj[e003ojf_fOn^Y/oo[j_D00?o[j_D00?o[[3Jok2YdOn`ZM400on`/=P4
ok6af004ojnfg_nb]=[o/[CJo`0000;o[kSP0_n]^n@2ojnkhP03ojbliOn^_>Co[;gV00?o[;gV00?o
0000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo9000000Q01TI6@T000003@0I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1V
IVH00ol00000Ogmo07moO`0507moO`_o00000`1oOgl2o`0000<0IVIV00Go000004a<C01<C4`0C4a<
0000000503<c<`03o`00000I6AT06ATI00<06ATI00?o00000000000000004P000004ooooo`030000
0?oooooooooo04gooooo0ol00003ooooo`;oZ;WV0onX^ND00onX^>GoYkGRojNehP03ojRdhP;oZ;CQ
00CoZ:oMojV_gOnY[mgoZJoM0_nZ/=d00onYZ]OoZjcHoj^/f002oj^/f003ojb^fOn/Y];o[:WD00?o
[:WD0_n][=H4ojfWd@;o[Z_D00Co[Z7:ojjVcon^Y/oo[ZK?0_n_Zm@00on`Xl[o/:WAok2Yd@02ok2Y
d@03ok2`f?ncZ]3o/j[@00;o/K7H00Ko]JkAok:df_nb]=[o/[CJo`000?n_^>02ok>hg@;o[k_R00Co
/K_Qojjli?n^_>Co[[cT0on/_NH00ooooooo0000ooooo`0booooo`002Oooool01000003ooooooooo
oooooolQ00000003o`00000I6AT06ATI03H06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00304a<C004o`00001VIVH0IVIV06IVIP;o0000101oOgl4o`0000/0VIVI0ol0000207moO`;o
00000P1VIVH2o`000080C4a<00?o00000000000c<c<00P0c<c<00`0000006ATI01TI6@0401TI6A@0
00001?ooool00`00003oooooooooo`1;ooooo`;o00001?ooool00onX^^KoZ;WVojRiiP02ojRiiP03
ojRiiOnW]^?oYkGR00?oYkGR00?oZ;CRojN_g_nW[mh00onX[md00onY[mgoZ:WGojVZe`03ojVZe`;o
ZjcH00CoZZC@ojbVd_n/Y];o[:KB0on/ZM@00on][=Ko[J?=ojfSc@03ojfWd@Co[Z7:0_n^Y/l4ok2S
bP;o/:WA00Go/j;7ok>Zd?ncZ]3o/j[@ok6af003okF^d@;o/[CJ00Co0000ok>hgOnc^=go/kSM1?na
^n400on^_>Co[kgTojnmi003ojbmiP03ooooool0003ooooo037ooooo0009ooooo`0400000?oooooo
ooooooooob000000>P0I6AT00ol00000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00?o
000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00D0VIVI2?l0
000309VIV@?o000000<0Ogmoo`000?l000000P1VIVH01Ol00000C4a<04a<C01<C4`0000000<0<c<c
00<0000001TI6@0I6AT00`0I6ATD000000Cooooo00<00000ooooooooool0B?ooool3o`0000?ooooo
0_nX^nL3ojRjiP;oZ;WV00CoYkOTojNfhonW]^?oYkKS0_nW]N800onV/=ooYjoNojN_gP02ojN_gP03
ojR_gOnVZ=SoZ:WG00;oZ:WG0onYZ]L01?n[[=SoZZC@ojZTd?nZY=02ojbVdP;o[:WD00?o[:3;ojfS
cOn]Xld00_n]Xld00on]Ym7o[Ic6ojfLaP03ojjQbP03ojjVcon_W<Co[ic400?o/:?:1?ncX/L00onc
Z]3o]jG8okNUb003okF^d@;o]k?E00?o0000okNceOnc^=d00_ng^=X2ok6kh@03okBlh?n__NCo[kgT
00;o[kgT00Co[;gVojfni_n]_^Ko0000<_ooool000Wooooo00@00000oooooooooooooooo7P00000D
01TI6@D000008`0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00?o0000
06IVIP1VIVH00P1VIVH01?l00000Ogmo07moO`1oOgl2o`0000@0VIVI1?l000080;>c/`?o00000`2I
VIT01?l00000Ogmo07moOol0000206IVIP05o`00001<C4`0C4a<04a<C00000000`0c<c<00`000000
6ATI01TI6@0301TI6A<000001?ooool00`00003oooooooooo`15ooooo`?o00001?ooool5ojRki`03
ojRji_nW^>GoYkSU00?oYkOT00?oYkKSojFahOnU/N400onV/=l2ojN_gP04ojFXfOnVZ=SoYZSHojJX
f0?oZ:WG00?oZJ[GojRRd?nZY=000onZY=000on/Y];oZig8ojbPb`03ojbPb`;o[J?=00Co[9S2ojfL
a_n]W<Ko[Ic60_n^XLX00on^U[ko[ic4ojnLa002ojnLa003ok2Sb_nbV[oo/YZo00;o/j;700?o]Yfn
okNUb?ngYLP00_ngYLP01_ne[]7o^Zc;okZ/bong/mGo0000okbcd@?o]kSJ00Co^k_IokBlh?nd_>3o
];cP0_n__N@2ok6ni004ojfni_n^_^Koooooo`00037ooooo0009ooooo`0400000?oooooooooooooo
oad000003P0I6AT00`00003o0000o`000004000000D0<c<c1`00000K01TI6@030000000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0206IVIP05o`00001oOgl0Ogmo
07moOol00000102IVIT2o`0000@0/k>c1?l000070;>c/`05o`00002IVIT0VIVI09VIVOl000000P1o
Ogl01?l00000IVIV06IVI_l0000304a<C0050000000c<c<0<c<c03<c<ol000001@0I6ATB000000Co
oooo00<00000ooooooooool0@oooool2o`0000;ooooo1OnY_>L00onX^nOoZ;[VojRjiP03ojNiiP?o
YkSU00?oYkOTojFch_nU/N400onU/N400onV/=ooY:WKojBYf`03ojFXf@;oYZSH0_nXZML01?nVXM3o
Z:;@ojRRd?nXX]02ojZTd004ojVJaon[WLSoZig8oj^Mb0?o[:3;1?n/V<82ojfLaPCo[YJn0_n_W<@0
1On`TkWo/YZook:J_onbV[oo/j;700?o]Yfn0_ngYLP01_nlXl3o^Zc;okZ/bonj[<_o]k?Eo`0000;o
_;?A00Ko]kSJok^kfOnk^mWo^k_IokBlh?ng_ml3ok6ni006ok;0i?n^_^Ko[[kVojjni_oooooo0000
<?ooool000Wooooo00@00000oooooooooooooooo6`0000000ol000006ATI01TI6@0:01TI6@<00000
4`0c<c<3000001P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C005o`00
001VIVH0IVIV06IVI_l000000`1oOgl00ol00000VIVI09VIV@0209VIV@04o`00002c/k<0/k>c0;>c
/`?o0000103<c<`6o`000080/k>c0_l000000`2IVIWo000007moO`0207moO`04o`00001VIVH0IVIV
o`000080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6A8000001?ooool00`00003ooooooooo
o`10ooooo`?o00000_ooool00onY_>SoZKcWojVli`03ojVli`;oZ;_W0onX^^H00onW^NKoY[OUojJg
i@03ojFei0;oYK?R0_nU/N400onSZmgoY:WKojBYf`02ojBYf`;oYJSI00?oYZSHojBPdOnTX=400onV
XM000onXX]3oYiW7ojVJa`03ojVJa`?oZig800?o[:3;oj^E`?n/V<800on/V<800on]W<Ko[96jojbA
^P03ojjF_P04ojnLa?n`TkWo/9>iok2C^@;o/YZo1?nfWKh01?ngYLSo_:?0okbS`?nlXl02okZ/b`04
okbcdOl0003o_;?Aol>gc`?o^k_I00Go`;kHokNogong_moo]koOok6ni003ok;0i004ojjni_n^_nKo
ooooo`00033ooooo0009ooooo`0400000?oooooooooooooooa`000002`0I6AT00`000000<c<c03<c
<`0G03<c<`<000005@0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00Go
000006IVIP1VIVH0IVIVo`00000207moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<0
0_l0000=0<c<c0;o00000P2c/k<00ol00000VIVIo`00000207moO`04o`00001VIVH0IVIVo`0000<0
C4a<00@0000003<c<`0c<c<000001P0I6ATA000000Cooooo00<00000ooooooooool0?_ooool2o`00
00?ooooo00CoZKgXojVlj?nY_>SoZKcX0_nY_>L00onX_>OoZ;_WojRki`02ojRki`03ojRji_nV^>Ko
Y[OU00?oY[OU00?oYKGToj>`h_nS[]l00_nS[]l3oj>[g@;oY:WK00?oX:;Foj:QdonRXM<01?nTX=40
0onVXM3oY9S8ojNIa`02ojNIa`?oZI[70_n[WLP01?nYT[koZiG0oj^E`?n[UL02ojbH`P04ojZ=]on/
TK[o[96jojbA^P?o[YJn1?n`TkT00onbV[oo]IBfokFD]P03okJM_PCo_:?000Co^Zc;ol6]a_o1[LKo
00000oo3]ll01Onk^mWo`;kHol2nf?o0_]So]koO00;o^/;P0_nb`>@01_nc`NGo[[oVojjoi_n^_nKo
ooooo`0002oooooo0009ooooo`0400000?oooooooooooooooa/000002P0I6AT2000001d0<c<c00<0
000001TI6@0I6AT04@0I6AT00`000000<c<c03<c<`0403<c<`050000001<C4`0C4a<04a<C?l00000
0`1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0VIVI00Co00000;>c/`2c/k?o00001@3<c<`8o`00
00@0c<c<00Ko00000;>c/`2c/k?o000009VIVOl0000207moO`04o`00001VIVH0IVIVo`000080C4a<
00D0000003<c<`0c<c<0<c<c0000000501TI6@03o`0000000000000000h000001?ooool00`00003o
ooooooooo`0kooooo`?o00000_ooool5ojVmj003ojVlj?nY_>OoZKcW00?oZ;cW0_nX^nL01?nW^^Ko
Y[SVojJhi_nV^>H2ojJgi@04oj>ci?nS/>;oXk3Roj>`hP?oXjkO00?oXj_MoinTfOnPX]H00onPX]H2
oj:Qd`;oY:3A00CoXYO:ojBHb?nTV<SoY9S80onWVLL00onYV/OoYi2nojVB_P03ojVB_P;oZiG000?o
[9S2ojZ=]onZSKL01?n/TKX00on^U[ko[Xfcok2C^@03ok2C^@?o]IBf0onfWKh01?nkV[Ko_:?0okbS
`?o3Y;X3ol6]aP04o`000?o3]loo`kO?ol>gc`?o`;kH00Coa<CIok[2h?nj`^3o^/;P1?nc`ND01On^
_nKo[[oWojjoion^_nOo000002kooooo0009ooooo`0400000?oooooooooooooooaX000002@0I6AT2
000000X0<c<c2`00000;03<c<`8000004@0I6AT00`000000<c<c03<c<`0403<c<`050000001<C4`0
C4a<04a<C?l000000`1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Go00000;>c/`2c/k<0
/k>co`0000030<c<c0;o0000203Vi^H2o`000080c<c<00Co00000;>c/`2c/k?o00000P2IVIT2o`00
000507moOol00000IVIV06IVI_l000000P1<C4`010000000<c<c03<c<`00000501TI6A4000001?oo
ool00`00003oooooooooo`0iooooo`;o00000oooool6ojVmj0GoZKcW00?oZ;cWojRkionX^nL00onW
^^H00onV^>KoY;KUojBfi@03oj>ci0;oXk3R0_nS[]l01?nNYmcoWjCIoinTfOnOY=T3oj2ReP03oj:Q
donNV<goXYO:00?oXYO:0_nTV<P2ojNIa`04ojB?_onWT;koYi2nojN@_P?oZI:n00?oZiG0ojR:]OnZ
SKL00onZSKL2ojbA^P04oj^8[on^SK?o[Xfcojj=/`;o/9>i00?o/Xf_okFD]_neU;H00_neU;H01?nf
WKko^iZfok^J]_nlXl03ol>T^P05ol6]a_o8/<?o0000olR``oo3]ll00_o9_<h01Oo0_]Soa<CIolC4
fOo4a=Wo^/;P00;o^lGR0_nc`ND2ok?2iP;o[[oW00?o[L3Wo`000?ooool0;Oooool000Wooooo00@0
0000oooooooooooooooo600000000ol000006ATI01TI6@0601TI6@800000200c<c<4000000/0C4a<
1000000903<c<`8000003`0I6AT00`000000<c<c03<c<`0403<c<`050000001<C4`0C4a<04a<C?l0
00000`1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Go00000;>c/`2c/k<0/k>co`000002
0<c<c003o`00003Vi^H0i^KV00<0i^KV1?l000030>KViP;o000000D0c<c<o`00002c/k<0/k>co`00
000209VIV@03o`00001oOgoo00000080IVIV00Co000004a<C01<C4`000000P0c<c<00`0000006ATI
01TI6@0301TI6A4000001?ooool00`00003oooooooooo`0fooooo`?o00000oooool6ojVmj0;oZKgW
1?nY_>L5ojRki`03ojNji_nU^>KoY;KU00?oY;KU00?oXk?Toj2_h_nOZml00_nOZml3oijWg0;oWjCI
0_nPX]H01?nLVM3oWYS=oijHcOnNV<d3oj:GbP03ojBHb?nQS/7oY8no00;oY8no0onWT;h3ojVB_P?o
Z8Ze0onZSKL00on/TK[oZhR_oj^8[`03ojj=/`04ok2C^OnbSJoo/Xf_ok:=[`?o]IBf0onkV[H4ol>T
^P;ob;3300?o0000olR``oo9_<h00_o9_<h00oo@a<ooa<CIolC4f@02olO9f`03ok_5h_nkan?o^lOS
00?o/l;V1?n]`>L00ol0003oooooooooo`0[ooooo`002Oooool01000003ooooooooooooooolH0000
00P06ATI00<0000003<c<`0c<c<01@0c<c<3000001<0C4a<0`00000803<c<`03o`00000I6AT06ATI
00/06ATI00<0000003<c<`0c<c<01@0c<c<01@000000C4a<04a<C01<C4co000000<0IVIV00Co0000
07moO`1oOgoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k?o00000080c<c<00Co00000>KViP3Vi^H0
i^KV0ol000040?ooo`03o`00003Vi^H0i^KV0080i^KV00?o00000<c<c?l000000P2c/k<01_l00000
VIVI09VIVOl00000Ogmoo`000080IVIV00Co000004a<C01<C4`000000P0c<c<00`0000006ATI01TI
6@0301TI6A0000001?ooool00`00003oooooooooo`0cooooo`?o00001?ooool8ojVmj003ojVmionY
_>OoZKcW00?oZKcW00?oZ;_WojNjionW^^L00onV^NL2ojFhiP;oY;KU00CoXK;Toj2_h_nP[n;oX:oR
0onOZml00onNYmcoVJ3IoiZLe002oiZLe0?oW9W@0onNV<d00onRUl[oWHk3oj6>`@02oj6>`@?oY8no
0onWT;h00onYT[koYXRdojR:]@02ojR:]@?oZXfg1?n[R:l2ojj=/`Co/Xf_0_neU;H2okVB[P;o^iZf
00Oo`Ybaol>T^_o3Y;[o`jBjol^Y]oo8/<?o000000;odKS100CobKc>om34coo@a<ooe/kA0oo7bM/4
ok_7h`03ok?2i_nb`nOo//?W00;o[L3W00?o[KoWo`000?ooool0;?ooool000Wooooo00@00000oooo
oooooooooooo5`00000801TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0201<C4`5
o`0000X0C4a<00?o000003<c<`0c<c<01P0c<c<2000000/06ATI00<0000003<c<`0c<c<01@0c<c<0
1@000000C4a<04a<C01<C4co000000<0IVIV00Co000007moO`1oOgoo00000P2IVIT01?l00000/k>c
0;>c/ol000020<c<c005o`00003Vi^H0i^KV0>KVi_l00000203oool2o`000080i^KV00Co00000<c<
c03<c<co00000P2c/k<01Ol00000VIVIo`00001oOgoo00000080IVIV00Co000004a<C01<C4`00000
0P0c<c<00`0000006ATI01TI6@0301TI6A0000001?ooool00`00003oooooooooo`0aooooo`;o0000
1?ooool4ojVmj0;oZKgW1?nY_NP6ojVli`;oZ;_W0onW^^L00onV^NOoYKOVojFgiP03oj>ei@;oXK;T
00?oX:oRoi^Yh?nKZN000_nIY=d3oiVPf@?oVYcD0_nLVM02oijHc@03oiZ?aonMS/?oWHk300?oXHk1
0onTSkl2ojN@_P04oj>6]OnVR;CoYXRdojJ8]0?oZ8Ze00?oZXfgojR4[OnXQ:d00on[R:l00on^SK?o
[hJZojn6ZP03ok:=[`05okFD]_niTZko^I:^okVB[_nkV[H00oo2W;401oo3Y;[objVgol^Y]oo8/<?o
dKS1o`000?oA^<400oo@a<l2omK>d@03olO9foo8c]kob<kN00;o^lOS0_njb>D00onb`nOo/L?Wojfo
i`03ojfoi`03o`000?oooooooooo02[ooooo0009ooooo`0400000?oooooooooooooooaL00000200I
6AT00ol00000<c<c03<c<`0303<c<`0300000?l00000C4a<00L0C4a<0ol0000506IVIP?o0000201<
C4`2000000P0<c<c00<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0503<c<`050000001<
C4`0C4a<04a<C?l000000`1VIVH01?l00000Ogmo07moOol0000209VIV@04o`00002c/k<0/k>co`00
0080c<c<00Go00000>KViP3Vi^H0i^KVo`0000090?ooo`04o`00003Vi^H0i^KVo`000080c<c<00So
00000;>c/`2c/k?o000009VIVOl00000Ogmoo`000080IVIV00Co000004a<C01<C4`000000P0c<c<0
0`0000006ATI01TI6@0301TI6A0000001?ooool00`00003oooooooooo`0^ooooo`?o00000_ooool6
ojVmj0GoZKgW00?oZKgXojVlionY_>L01?nY_>L00onY^nOoZ;_WojRki`02ojRki`03ojNjionV^NKo
YKOV00?oYKOV00?oXkGUoj2biOnM[^<00_nM[^<3oi^Yh0;oVJCM0_nIX=T2oiZLe003oi>Cd?nFTLco
UY7<00?oVXo70onMS/<3oj6>`@03ojB?_onPQKOoXhJe00;oXhJe0onVR;@2ojR:]@04ojF1[?nXQ:go
Z8B]ojR4[@?oZhR_0on_QZX3ok:=[`Co^I:^1?o2W;43ol^Y]`06omJb]_oA^<7o0000om6h`OoK`l;o
d<C?0_oFc]401OoIemKob<kNolS>g_o8c]koam;R00;o^/SU00Co^<SWok73iona`nOo/L?W0_n]_nL2
ojboj003o`000?oooooooooo02Wooooo0009ooooo`0400000?oooooooooooooooaH00000200I6AT0
0`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00@0C4a<1?l0000;06IVIPCo00001P1<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<01@0c<c<0
1@000000C4a<04a<C01<C4co000000<0IVIV00Co000007moO`1oOgoo00000P2IVIT01?l00000/k>c
0;>c/ol000020<c<c005o`00003Vi^H0i^KV0>KVi_l000002P3oool01_l00000i^KV0>KVi_l00000
c<c<o`000080/k>c00Go000009VIVOl00000Ogmoo`00000206IVIP04o`00001<C4`0C4a<00000080
<c<c00<0000001TI6@0I6AT00`0I6AT@000000Cooooo00<00000ooooooooool0;?ooool2o`0000?o
oooo1onY_NP5ojVmi`OoZKcW0onY^nL2ojRki`04ojNji_nV^NKoY[WVojJiiP;oYKOV00CoXkGUoj2b
iOnP/^GoX;;U0onM[^<01?nKZN3oU:?Ooi:MfonBWM/2oi:HePCoTi?@0_nFTL`3oiZ?a`;oWHk30_nQ
S/400onLQKWoX8Fgoj25]`04oj>6]@;oYXRd00?oZ8ZeojF1[?nUPJ`00onXQ:d3oj^8[`?o[hJZ0onb
SJl01?nfRjSo^I:^okVB[_niTZh4ol:L/@?objVg0_oF/[H01Ol0003ofl?2om_3`_oSd<Coe/kA00?o
fMOF00?ob<kNolOBh_o7d^801?nhb>L00ona`nOo[l;Xojo2j002ojboj003oj^oj?l0003ooooo02[o
oooo0009ooooo`0400000?oooooooooooooooaD00000200I6AT00`000000<c<c03<c<`0303<c<`03
0000001<C4`0C4a<00<0C4a<0_l0000C06IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c
<c<01P0c<c<00`0000006ATI01TI6@0601TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`00P1<C4`01?l00000IVIV06IVI_l0000207moO`04o`00002IVIT0VIVIo`000080/k>c00Co0000
0<c<c03<c<co00000P3Vi^H00ol00000oooo0?ooo`090?ooo`04o`00003Vi^H0i^KVo`000080c<c<
00?o00000;>c/ol000000P2IVIT01Ol00000Ogmoo`00001VIVKo00000080C4a<00D0000003<c<`0c
<c<0<c<c0000000401TI6A0000001?ooool00`00003oooooooooo`0Yooooo`?o00000_ooool;ojVm
j003ojVmionY_>OoZKcW00WoZKcW00CoZK_WojRji_nX^^KoZ;[V0_nW^^H00onV^NKoYKOVojFgiP03
oj>ei@03oj2biOnL[^CoW:kT00;oV:WR0onDXml2oi:Mf`;oTYSF0onCTm03oiJAc0;oVXo700?oWHk3
oiR5_OnLQKT00_nLQKT3oj25]`?oXhJe00?oYXRdoj9n[?nUPJ`00onUPJ`3ojR4[@03oj^8[on[PJOo
[hJZ00?o[hJZ00?o/Xf_okJ;Z?nfRjP00_niTZh2oknDZ@;o`Yba0_o;XJd01Oo;ZKOoe[:fomJb]_oF
/[Ko000000;ofl?200Cohm34omWGe_oIemKofMOF0_oHgM/00oo7d^;o`m;Uol?Bi@02okS8i`;o]<OX
00?o[l;Xojk1j?n[_nP00on[_nP00ol0003oooooooooo`0Xooooo`002Oooool01000003ooooooooo
oooooolD00000003o`00000I6AT06ATI00D06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<
04a<C00204a<C0;o00001P1VIVH;o`0000D0IVIV0ol0000404a<C08000001`0c<c<00ol000000000
01TI6@0501TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`01?l00000IVIV
06IVI_l0000207moO`04o`00002IVIT0VIVIo`000080/k>c00Co00000<c<c03<c<co00000P3Vi^H0
0ol00000oooo0?ooo`0:0?ooo`08o`00003Vi^H0i^KVo`00003<c<co00000;>c/ol0000209VIV@05
o`00001oOgoo000006IVI_l000000P1<C4`01@000000<c<c03<c<`0c<c<0000000@06ATI40000004
ooooo`0300000?oooooooooo02Oooooo0_l00003ooooo`coZKgX2_nY_>L4ojVjiP;oZ;[V00CoZ;SU
ojNhiOnW^>GoYkSU0onU]nH00onS]NGoX;7Toib^i003oib^i0;oV:WR0_nDXml2oi:Mf`?oTYSF00?o
Ti?@oh^;cOn?R<L00_n?R<L2oi>6`P?oV8Fm0onLQKT2oj25]`;oXhJe00CoWgf]oj9n[?nROZcoXWj/
0onUPJ`2ojR4[@04ojMmY_n[PJOoZh6Woj^1Y`?o[hJZ1?nfRjP01?niTZko_iBYoknDZOo2W;43ol^Q
[@06ol^Y]ooF/[Koe[:fomJb]_l0003ofl?20_oSd<@01?oYg/SofMOFomSMfooHgM/2om?Ph@03ol?B
iOnnd>So_]3X00;o]<OX00Co/LGXojk1j?n^`NSo[/7X0_n[_nP2oj^nj003o`000?oooooooooo02Oo
oooo0009ooooo`0400000?oooooooooooooooaD000001P0I6AT00ol00000<c<c03<c<`0303<c<`03
0000001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00`1VIVH3o`0000/0Ogmo0ol0000506IVIP03
o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0301TI6@03
0000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`01?l00000IVIV06IVI_l0000207mo
O`04o`00002IVIT0VIVIo`000080/k>c00Co00000<c<c03<c<co00000`3Vi^H00ol00000oooo0?oo
o`080?ooo`09o`00003Vi^H0i^KV0>KVi_l00000c<c<o`00002c/k?o00000080VIVI00Go000007mo
Ool00000IVIVo`00000204a<C0050000000c<c<0<c<c03<c<`000000100I6AT@000000Cooooo00<0
0000ooooooooool09?ooool3o`0000?ooooo3?nY_NP:ojVli`GoZK[V1OnX^>D00onW^>GoY[GTojJe
i003oj>di0;oX;7T0_nL[^@00onGZN?oTJ?Qoi6Sh@03ohbLgP;oRIGI0_n9Sm<2oh^;c@?oShS70_nC
Q/83oiR5_@?oW8Fi00?oX8Fgoi]l/?nOOJd00_nOOJd3oj9n[0?oYH6/00?oZ8B]ojMmY_nWOJH00on[
PJL2ojn6ZP03ok64Y?nfRjSo]X^X00;o]X^X0onoU:T4ol^Q[@?oe[:f00Coh/2fo`000?oSd<Cohm34
0_oYg/P01?oYjLkof=gKom?PhOoCh>42ol_Ni`03okk@j?nhc>Wo/LGX00?o/LGX00?o[/7Xojc0j?n/
`>P00_n[_^P00onZ_^So0000ooooo`0Xooooo`002Oooool01000003ooooooooooooooolD000000L0
6ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C003o`00001VIVH0IVIV0080
IVIV0_l0000A07moO`03o`00001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000
<c<c03<c<`0603<c<`030000000I6AT06ATI00<06ATI00<0000003<c<`0c<c<01@0c<c<01@000000
C4a<04a<C01<C4co000000<0IVIV00Co000007moO`1oOgoo00000P2IVIT01?l00000/k>c0;>c/ol0
00020<c<c005o`00003Vi^H0i^KV0>KVi_l00000203oool01Ol00000i^KV0>KViP3Vi^Ko00000080
c<c<00Go00000;>c/ol00000VIVIo`00000207moO`03o`00001VIVKo00000080C4a<00D0000003<c
<`0c<c<0<c<c0000000401TI6A0000001?ooool00`00003oooooooooo`0Rooooo`;o00001?ooool9
ojVmj0coZKcW1_nY^^H2ojVhi0CoZ;SU0_nW]N<3ojJei003oj>di?nR/>;oWJkS00;oWJkS0onGZN<2
oi6Sh@?oS9cN0_n9UMT2ohV?d`;oRh_=0on?R<L2oi>6`P?oV8Fm00?oW8FioiIl]?nKO;000_nKO;02
oimm[@?oXWj/0onUPJ`3ojMmYP?oZh6W00Co[hJZok64Y?naQ:Co/HBT0onfRjP3oknDZ@06olVJYoo;
XJgobj6]ol^Q[OoG[:coe[:f0_oR`;H00ol0003okM6fon?@a002onWNb003onWYc_oTl=Kodn3Q00;o
bmkW00Co`]SZokS<jOnhc>Wo^<cY0_naaNP2ojo3j@03ojc0j?n[_nSoZ[kX00?oZ[kX00?o0000oooo
ooooool09_ooool000Wooooo00@00000oooooooooooooooo4`00000701TI6@030000000c<c<0<c<c
0080<c<c00<0000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo
00<0Ogmo2_l0000507moO`;o0000101VIVH00ol00000C4a<04a<C00204a<C0030000000c<c<0<c<c
00L0<c<c00?o000001TI6@0I6AT00P0I6AT00`000000<c<c03<c<`0603<c<`050000001<C4`0C4a<
04a<C?l000000`1VIVH01?l00000Ogmoo`000?l0000209VIV@03o`00002c/k?o000000<0c<c<00Co
00000>KViP3Vi^H0i^KV0_l000040?ooo`;o0000103Vi^H02?l00000c<c<0<c<c?l00000/k>co`00
002IVIWo00000P1oOgl00ol00000IVIVo`00000204a<C0050000000c<c<0<c<c03<c<`000000100I
6AT@000000Cooooo00<00000ooooooooool07oooool3o`000003oooooonY_NSoZKgX00[oZKgX0_nY
_NL:ojVli`KoZK[V1OnY^>@00onX^>GoZ;GRojNeh`03ojNeh`03ojJei?nU/N7oX[3R00;oX[3R0onM
[^<01?nGZN?oTZCRohVMhOn9WN43oh:Fg@;oOXgH0_mmQm82oh^;c@?oShS70_nCQ/82oiR5_@03oi5l
^?nFO;CoUWbd00?oVgb`0onOOJd3oj9n[003ojF1[?nSNZGoYgfV00?oYgfV0_n[PJL4ok64Y0;o]X^X
0_nlSJ@00onoU:WobIZWolVJY`02ol^Q[@;oejb/0ooR`;H01Ol0003okM6fooGR]ooYg/SojNW>00;o
i?3F00?of_3Pol_Nioo2f>X00_o2f>X00onhc>Wo/lSZok?8jP02ojo3j@04ojg1j?n[_nSoZkoXoj^o
j0?oZ[kX00?oooooo`000?ooool09_ooool000Wooooo00@00000oooooooooooooooo4`00000701TI
6@030000000c<c<0<c<c0080<c<c00Go000004a<C01<C4`0C4a<o`00000406IVIP03o`00001oOgl0
Ogmo00<0Ogmo00?o000009VIV@2IVIT0202IVIT2o`0000D0Ogmo00?o000006IVIP1VIVH00P1VIVH0
1Ol00000C4a<04a<C01<C4`0000000T0<c<c00<0000001TI6@0I6AT00P0I6AT00`000000<c<c03<c
<`0603<c<`05o`00001<C4`0C4a<04a<C?l000000`1VIVH01?l00000Ogmo07moOol0000209VIV@04
o`00002c/k<0/k>co`000080c<c<00?o00000>KViP3Vi^H00`3Vi^H2o`0000030?ooool00000i^KV
00D0i^KV00?o00000<c<c?l000000P2c/k<00ol00000VIVIo`00000207moO`03o`00001VIVKo0000
0080C4a<00D0000003<c<`0c<c<0<c<c0000000401TI6A0000001?ooool00`00003oooooooooo`0L
ooooo`?o00000_ooool>ojVmj0?oZKgW1onY_>L6ojVjiPKoZKST00CoZKCQojReh_nX]N;oZ;GR0_nW
]N<01OnW/MooYK7QojFahOnU/N7oX[3R00;oXJ_O0_nJZN43oi:ThP;oRIgQ0on2U]d2ogj=f003ogf7
d_n0P/_oP8;;00?oQGo50_n;OKh3oi5l^0;oUWbd0onKO;03oimm[@;oXWj/00CoWgNVoj=jYOnSNZGo
XgZU0onWOJH2oj^1Y`05ojeoX_naQ:Co/HBTok64Y?nfRjP00onlSJ@01OnoU:WobIZWolVJYoo9VZOo
bj6]00;oejb/00WoiKb/on;0]_o]dKKo0000ongA]_oeh[Oom?6honci__oTl=H00_oJl>02olkYj005
ol;Hj_njdN_o^]7[ok?8j_n_a>T01?n]`NP00on[_nSoZkkXoj^nj003ojZnj003o`000?oooooooooo
02Gooooo0009ooooo`0400000?oooooooooooooooa<000001`0I6AT00`000000<c<c03<c<`0203<c
<`040000001<C4`0C4a<o`0000@0IVIV00?o000007moO`1oOgl00P1oOgl2o`0000d0VIVI0_l00004
07moO`05o`00001VIVH0IVIV06IVI_l00000101<C4`00`000000<c<c03<c<`0603<c<`030000000I
6AT06ATI00<06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<C005o`00001V
IVH0IVIV06IVI_l000000P1oOgl00ol00000VIVIo`0000030;>c/`03o`00003<c<`0c<c<00?o0000
103Vi^H00ol00000i^KV0>KViP030>KViP;o00000P3<c<`00ol00000/k>co`00000209VIV@03o`00
001oOgoo00000080IVIV00Co000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6A00
00001?ooool00`00003oooooooooo`0Jooooo`;o00000ooooolAojVmj003ojVmionY_>OoZKcW00Co
ZKcW0_nY^nH00onY^^KoZ;STojRhi006ojVhi0GoZKCQ00?oZ;GRojR`g_nX/=h00onW/Ml00onU/N7o
YJcLojF/g003oj6[g`;oVZWQ0_nBY>83ohVMh@;oPYKM0_mnSMP2ogf7dP;oP8;;0_n5OlD3oh]m_P?o
TGbh0_nFO;@3oi]l/0;oWgf]00?oXWj/oimgY_nOMjH00onSNZD3ojMmYP03oj^1Yon]Oj;o[GnR00?o
/HBT1?nlSJ@01?noU:WobIZWolVJYoo9VZL2omN/[0;oiKb/00?oh/2fongA]_l000000_oeh[L01?od
lKSok?Vnon;mc?oJl>02olkYj0;o`mk]00?o^]7[ok?:jon_a>T00_n_a>T2ojg1j0;oZkoX00?oZkkX
ojZnj?nZ_NP00onZ_NP00ol0003oooooooooo`0Tooooo`002Oooool01000003ooooooooooooooolB
000000L06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4co000000<0IVIV00?o
000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0509VIV@Co00001P2IVIT00ol00000Ogmo07mo
O`0207moO`05o`00001VIVH0IVIV06IVI_l000000`1<C4`00`000000<c<c03<c<`0703<c<`030000
000I6AT06ATI00<06ATI00<0000003<c<`0c<c<01@0c<c<01@000000C4a<04a<C01<C4co000000<0
IVIV00Co000007moO`1oOgoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000@0c<c<00?o0000
0>KViP3Vi^H01@3Vi^H2o`0000<0c<c<00Ko00000;>c/`2c/k?o000009VIVOl0000207moO`03o`00
001VIVKo00000080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6A0000001?ooool00`00003o
ooooooooo`0Gooooo`?o00000oooool?ojVmj0KoZKcW0_nY^nL4ojVkiP;oZ;SU0onX^>@00onY^>Co
Z;CQojRdh@03ojRdh@04ojVdhOnX[]coZJoLojV_g0CoZ;3N00?oYk7OojN[f_nU[=`00onU[=`01?nQ
ZmooX:KJoiRTg_nHY=h3ohjPh0;oPYSP0_mgSmh2ofn5f@;oKGkB0on0P//2ohEoa@;oRgfn0onAO;P2
oiIl]0?oVgb`00?oWgf]oiYeZ?nOMjH00_nOMjH3oj=jY@?oYgfV0on]Oj83ok64Y004okN6XOnlSJCo
_8fTokb=Y0CobIZW0_oG[:`2onFl[005ooCAZol0003o0000ooGR]oodlKP00_o/nKh00ooRoLcoeo[O
ol__k002ol?Nk@05okWBkOncb^_o/l[[ok?:jon_a>T00on]`NT00on[_nSoZkkXojZnj002ojZnj0?o
Z[gX00?oooooo`000?ooool09?ooool000Wooooo00@00000oooooooooooooooo4P00000701TI6@03
0000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP03o`00001oOgl0Ogmo
00;o0000102IVIT4o`0000@0/k>c0_l0000509VIV@05o`00001oOgl0Ogmo07moOol00000101VIVH0
1Ol00000C4a<04a<C01<C4co000000P0<c<c00<0000001TI6@0I6AT0100I6AT00ol00000<c<c03<c
<`0503<c<`040000001<C4`0C4a<04a<C0;o00000P1VIVH2o`00000407moOol0003o000009VIV@?o
000000@0/k>co`000?l0003o00000P3<c<`7o`0000@0c<c<00Go00000;>c/`2c/k?o000009VIV@02
o`00000507moOol00000IVIV06IVI_l000000P1<C4`01@000000<c<c03<c<`0c<c<0000000D06ATI
40000004ooooo`0300000?oooooooooo01Kooooo0_l00003oooooa7oZKgX1?nY_>L5ojVki`03ojVk
i_nX^NGoZ;SU00?oZ;SU00?oZ;STojRdhOnX]>401?nX]>44ojR^g0;oZJoL0_nX/=h01?nXZMSoYj_J
ojN[f_nWZmX2ojF/g004ojFVe_nPY][oX:KJoj2VfP;oV:CN0on>X>02oh:Hh0;oMhoN0_m_QMT01?m]
O];oL7S;og1hbom`N</2ogMea0?oRgfn0_nAO;P2oiIl]0;oVgb`00CoU7B[oiYeZ?nJMJSoVWFX0onO
MjH3oj=jY@;oYgfV1?n]Oj800onaQ:Co]hJQokN6X@03okb=Y0?obIZW0_oFYZH02ooG[:co0000o`00
0?l0003om=6[o`000?oeh[Oom?6honci__oRoLcoeo[O00;obno/1?nid^d00oncb^_o[lGZojo5jP02
ojg1j@05oj^oj?n[_^SoZkkXoj^nj?nZ_^P01OnZ_NP00ol0003oooooooooo`0Sooooo`002Oooool0
1000003ooooooooooooooolA00000003o`00000I6AT06ATI00D06ATI00<0000003<c<`0c<c<00P0c
<c<01@000000C4a<04a<C01<C4co000000<0IVIV00Co000007moO`1oOgoo0000102IVIT00ol00000
/k>c0;>c/`080;>c/`;o0000102IVIT01?l00000Ogmo07moOol0000406IVIP03o`00001<C4`0C4a<
0080C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0501TI6@030000000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`00`1<C4`01Ol00000IVIV06IVIP1VIVKo00000080Ogmo00Go0000
09VIV@2IVIT0VIVIo`0000030;>c/`03o`00003<c<`0c<c<00L0c<c<0ol000001@2c/k?o0000o`00
002IVIWo000000<0Ogmo00Co000006IVIP1VIVKo00000P1<C4`01@000000<c<c03<c<`0c<c<00000
00D06ATI40000004ooooo`0300000?oooooooooo01Kooooo00?o0000ojVmj?nY_NP05?nY_NP2ojVl
i`GoZK_W00CoZ;[VojRiiOnX^NGoZ;WU0_nX^>D00onW]N;oZ;CQojRdh@02ojRdh@;oYjkL1?nX[]`0
1?nXY]GoZ:SFojRXe_nXZ=H3ojRYf003ojN[f_nXY=?oZ:CC00?oYJKF00?oX:KJoj:Qe?nIXMX00_nI
XMX2ohbLgP;oNiCP0_mZRMl2oeamfP;oKGkB0_m`N</2ogMea0?oOg>l0_n7LkH2ohic/0?oU7B[0onJ
MJP3oimgYP?oXgZU00?oYgfVojQjXOn]Oj800on]Oj800onaQ:Co]hJQokN6X@02okb=Y0;oaI>S0_o9
VZL3o`000008onFl[?oddJ_om=6[ooCAZookiJGo0000omkaU?o=oL02olcmhP03ol__k?nog^oo_mk_
00;o^M;]0_nbbN`00on_aN[o[L7Yoj^oj003oj^oj003oj^nj?nZ_^SoZ[kX00KoZ[gX00?o0000oooo
ooooool08_ooool000Wooooo00@00000oooooooooooooooo4P00000601TI6@030000000c<c<0<c<c
0080<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP04o`00001oOgl0Ogmoo`0000<0VIVI0_l0
000=0;>c/`03o`00002IVIT0VIVI0080VIVI00Co000007moO`1oOgoo0000101VIVH01Ol00000C4a<
04a<C01<C4`0000000L0<c<c00<0000001TI6@0I6AT01P0I6AT2000000D0<c<c0P00000404a<C005
o`00001VIVH0IVIV06IVI_l000000P1oOgl01Ol00000VIVI09VIV@2IVIWo000000<0/k>c2Ol00003
0;>c/`04o`00002IVIT0VIVIo`0000<0Ogmo00Co000006IVIP1VIVKo00000P1<C4`01@000000<c<c
03<c<`0c<c<0000000D06ATI00?o00000000000000003P000004ooooo`0300000?oooooooooo01Ko
oooo00?o0000ojVmj?nY_NP04onY_NP4ojVli`;oZK_W1?nX^^H00onX^NGoYkKSojNfh`03ojNehP03
ojRdhOnV[]goYZkM00?oYjkL00?oZ:kLojNUeOnXY]D00_nXY]D3ojRXeP03ojRYf?nXX]3oZ:CC00?o
Z:CC00?oYJKFojJOconRXM@00_nRXM@3oiVQfP;oS9cN0_mkU>02ofZ9g`04oeamf_mFLmCoEW?DoeIc
e0;oL7S;00CoMgG4ogmc_?moLkcoOg>l0_n7LkH3ohic/0;oU7B[0onJMJP3oimgYP;oXgZU00CoXWJQ
ojQjXOnXNZ7oZ7ZQ0on]Oj84okN6X@03okb=Y?o5Tj?o000000;o00000_oFYZH2onFl[0;om=6[0_ok
iJD01?ocl9_o0000olcmh_o<oN82ol?]l003okoNkonfdNko]]7^00;o//W/0_n^a>X2ojg1j@;oZkoX
0_n[_^P00onZ_^SoZ[gXojZmj005ojZmj003o`000?oooooooooo02;ooooo0009ooooo`0400000?oo
oooooooooooooa4000001`0I6AT01Ol00000<c<c03<c<`0c<c<0000000<0C4a<00Go000006IVIP1V
IVH0IVIVo`00000207moO`05o`00002IVIT0VIVI09VIVOl000001P2c/k<5o`0000D0/k>c00?o0000
09VIV@2IVIT00P2IVIT01?l00000Ogmo07moOol0000306IVIP03o`00001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00P1<C4`01?l00000IVIV06IVIP1VIVH2o`00000507moOol0003o0000o`00002I
VIT00ol000090;>c/`?o000000<0VIVIo`000?l000000P1oOgl2o`000080IVIV00Go000004a<C01<
C4`00000o`00000203<c<`03o`00000I6AT06ATI00<06ATI4P000004ooooo`0300000?oooooooooo
01Kooooo00?o0000ojVmj?nY_NP04?nY_NP4ojVli`GoZ;_W00?oZ;[VojNhiOnW^>D00onW]n@2ojNf
h`03ojNeh_nV[mkoYZkM00?oYZkM00?oYjkLojFUeOnWYMD00_nWYMD3ojRVe@03ojRXe_nXWlkoZ:;@
00;oZ:;@0_nXY=<01?nXWL_oYYo?ojJOconVWll2oj:Qe0;oVJ7J00?oVigEohfKg?n=Vm`00omgT^42
oef5h@03oeamf_mFLmCoEW?D00;oF6c<0_mgML@3ogmc_0;oQg>f0_n>Lk03oiAdZ`?oVWFX0_nOMjH0
0onSNZGoXWJQoj9fX@03ojQjX@?o[GnR0ongQZ43o`000003olFCXoo9VZOoeZJV00;oeZJV00?oikVU
onFl[?oddJ/00_okiJD01_ocl9_oWMf3okGi`Ol0003o`?W/ol?]l0;o^M[a00?o]]7^ok37jon`an/0
0_n^a>X01?n/`>WoZkoXoj^oj?n[_nP2oj^nj003ojZnj?nZ_NSoZ[gX00OoZ[gX00?o0000oooooooo
ool08Oooool000Wooooo00@00000oooooooooooooooo4@00000701TI6@050000000c<c<0<c<c03<c
<`0000000`1<C4`01Ol00000IVIV06IVIP1VIVKo00000080Ogmo00Go000009VIV@2IVIT0VIVIo`00
00040;>c/`;o00001@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI0080VIVI00Co
000007moO`1oOgoo0000101VIVH01Ol00000C4a<04a<C01<C4`0000000H0<c<c00<0000001TI6@0I
6AT02@0I6AT00`000000<c<c03<c<`0403<c<`040000001<C4`0C4a<04a<C0;o0000101VIVH01Ol0
0000Ogmo07moO`1oOgoo000000<0VIVI2Ol0000309VIV@05o`00001oOgl0Ogmo07moOol000000`1V
IVH01Ol00000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT00`0I6ATB000000Cooooo
00<00000ooooooooool05Oooool01?l0003ooooooooooooooolAojVmj0?oZKcW1?nX^nL00onW^NKo
YkSUojNhi@02ojNhi@03ojNgi?nU/^;oYK3P00;oYK3P0_nV[mh2ojJ^g@04ojBVeonUYMGoYJGEojFU
e@;oYjGE0_nXY]D01_nWWLcoZ9o>ojROc_nXWlkoZ:;@ojVJa`CoZ9g;0_nVWll3ojBMcP?oVigE0_n=
Vm`3ogNBh@03oef5hOm5M=coAGCL00;oEW?D00?oF6c<of5Ya?mQJL@00omoLk`2ohMc]P;oSW>`0onD
M:/3oiYeZ003oimgY_nLLZ?oXWJQ00;oXWJQ0onXNZ42ojeoXP05ok60Wol0003o0000o`000?ngQZ40
0oo5Tj<3omJVYP;oikVU00Son=6RooCAZookiJGolo2Ko`000?nenL7o`?W/o`0000;o^^Cd00Go^M[a
ok7<k_nac>ko/<O[ojg2j@04ojc0j@03oj^oj?nZ_^SoZ[kX00?oZ[kX2OnZ_NP00ol0003ooooooooo
o`0Pooooo`002Oooool01000003ooooooooooooooolA000000L06ATI00D0000003<c<`0c<c<0<c<c
0000000304a<C005o`00001VIVH0IVIV06IVI_l000000P1oOgl01?l00000VIVI09VIVOl000040;>c
/`03o`00003<c<`0c<c<00H0c<c<00?o00000;>c/`2c/k<00P2c/k<00ol00000VIVI09VIV@0209VI
V@04o`00001oOgl0Ogmoo`0000<0IVIV00Go000004a<C01<C4`0C4a<0000000603<c<`030000000I
6AT06ATI00X06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0;o00000`1V
IVH2o`000080Ogmo0ol0000909VIV@?o00000`1oOgl01Ol00000IVIV06IVIP1VIVKo000000<0C4a<
00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0301TI6A8000001?ooool00`00003ooooo
ooooo`0Eooooo`04o`000?oooooooooooooooa3oZKgX1OnY_>L00onX^nOoZ;[VojRjiP02ojNiiP;o
YkSU00KoYKCSojFbh_nU/^;oYK;RojF`h?nSZM/3oj>Wf@?oY:KG00?oYJGEoj>KcOnUW<`00_nUW<`3
ojNMc003ojROc_nWUlGoZI[700;oZI[70onXWL/00onVWlooZI[7ojVJa`03ojBMcP03oi^MeOnQW=3o
TI_I00;oTI_I0_mhU>82oe>4i003odEdg?leIMCo=FGD00;oF6c<00CoHFW4ofaX_?m/J;coK6Rl0_n7
LkH3ohic/0;oU7B[0_nJMJP00onDKjGoW7:SoiabX`04oj9fX@;oZ7ZQ0ol000001?naP9oo]hJQokN6
XOngQZ43olFCX`03om>PXooFYZKoeZJV00;oikVU00Gon=6RoocUU?oPhgKo]=5Mojgjf`02okS]m@06
ok[Tm?l0003o/m;`ok?Bl?nac>ko[LC[0on]`^T2ojc0j@;oZkkX1?nZ_^P:ojZmj003o`000?oooooo
oooo023ooooo0009ooooo`0400000?oooooooooooooooa4000001P0I6AT00`000000<c<c03<c<`02
03<c<`040000001<C4`0C4a<o`0000<0IVIV00Co000007moO`1oOgoo00000`2IVIT01Ol00000/k>c
0;>c/`2c/k?o000000X0c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIWo0000
0080Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C0030000000c<c<0<c<c00<0<c<c00<00000
01TI6@0I6AT0300I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00?o0000
06IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`Wo0000101oOgl2o`0000<0IVIV00Go0000
04a<C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00<06ATI4`000004ooooo`0300000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool<ojVmj0?oZKcX0_nY_>L01OnX_>OoZ;_WojRk
ionX^nOoZ;[V00;oY[SV0onV]^D2ojFdh`03ojFbh_nR[=koXZcN00;oXjWK0onSYmT00onTY]OoXIc?
oj>Kc@02oj>Kc@?oYIc<00?oYig<ojFD`onWUlD00_nWUlD3ojVJa`03ojRMbonZUl;oZI[700?oZI[7
00?oY9g>ojVJaonQW=000_nQW=03oi6Kf@;oN9CR00CoDhCTobU/g?lYK=co=FGD0_laFl`2of5Ya0;o
K6Rl0_mhJ;D3oh=Z[P03oiAdZon<K:WoU6nU00;oU6nU0_nLLZ<3oj9fX@?o00001?naP9l2okN6X@03
okn=X?o5Tj?oaI>S00;odj2S0_oFYZH01OoW^JGon=6RooSAX_oliICoh>=f00;o[o?d00Go^>geok?G
lonceo?o/m;`o`000002ojk7k0;o[LC[00?o[L;Yoj^oj?n[_nP00_n[_^P00onZ_^SoZ[gXojZmj00=
ojZmj003o`000?oooooooooo01oooooo0009ooooo`0400000?oooooooooooooooa4000001P0I6AT0
0`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<o`0000<0IVIV00Co000007moO`1oOgoo0000
0P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000`0c<c<00Go00000;>c/`2c/k<0/k>co`00000309VI
V@04o`00001oOgl0Ogmoo`0000<0IVIV00Go000004a<C01<C4`0C4a<0000000503<c<`030000000I
6AT06ATI00d06ATI00<0000003<c<`0c<c<0100c<c<00`00003o00000000000204a<C0?o00000`1V
IVH4o`0000T0Ogmo1?l0000306IVIP;o00000`1<C4`00`000000<c<c03<c<`0203<c<`03o`00000I
6AT06ATI00@06ATI4`000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool01?oo
ool;ojVmj003ojVlj?nX_>OoZ;cW00?oZ;cW00?oZ;_WojNii_nW^NH00onV^>H01?nV]^GoXk;Soj>_
hOnS[n44oj:/gP;oXjWK00?oXjOIoinMd_nQW<l00_nQW<l3oj>Kc@03ojFLc?nST/?oYIC300;oYIC3
0_nWUlD2ojVJa`04ojVC__nZUl;oZYO2ojZG`P;oZI[700Co[9K0ojVJaonYV/OoZI[70_nQW=02oi6K
f@03oiZNeomnVN?oOYWS00;oD8SX00Co:FcLo`EBcol5D/oo<E_<0_ljElD2ofaX_0?oN6Re0_n3JZh2
oha/Z@?oU6nU0_nLLZ<3o`000003oj9fXOnXNZ7oZ7ZQ00Co/H2O00Go]hJQokn=X?noSJ3o_hfPolFC
X`03om>PX`;oikVU00Gon=6RoocUU?oPhgKo]=5Mojocm002ok7LmP06ok?Glon^bNko[/W^ojk7k?l0
003o[<;Z0on[`>T00on[_nSoZ[kXojZnj003ojZnj0ooZ[gX00?o0000ooooooooool07_ooool000Wo
oooo00@00000oooooooooooooooo4@00000601TI6@050000000c<c<0<c<c03<c<ol000000`1<C4`0
1?l00000IVIV06IVI_l0000307moO`04o`00002IVIT0VIVIo`0000<0/k>c00?o00000<c<c03<c<`0
2P3<c<`01Ol00000/k>c0;>c/`2c/k?o000000<0VIVI00Co000007moO`1oOgoo00000`1VIVH01Ol0
0000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT03P0I6AT00ol00000000003<c<`06
03<c<`8000000`1<C4`3o`0000@0IVIV2Ol0000406IVIP?o0000101<C4`00`000000<c<c03<c<`02
03<c<`030000000I6AT06ATI00@06ATI50000004ooooo`0300000?oooooooooo01Gooooo00?o0000
ooooooooool01?ooool:ojVmj0?oZKcX0onX_>L3ojNki`;oYkWV00?oY[SVojBei?nS/^<00_nS/^<2
oj>_h@;oXZcN00?oWZ?IoijPeOnNX=D00onOWM82oj6Lc`;oXi_=00CoX974oj>B`onST/?oXi;30_nU
U<<00onWUlGoYhnlojVC_P03ojVC_P;oZYO21?n/U/02ojVJa`03oj6Ld?nXW<_oZ9c;00?oVYkG0_mn
VN<2oe28j004o`iVfol5D/oo03k2o`0n`P;o>UO50_m/J;`2ogQX]@;oPfZ^0_n<K:T3oiA_Y@;o0000
00GoW7:Soj9fXOnRMZ7oXWJQojQjX@02ojYkW`?o/H2O00Go]hJQokn=X?noSJ3o_hfPolFCX`03om>P
X`;oikVU00?on=6RoocUU?oPhgH00_n^goP01onag?Ko[/c_ojk<kon^bNko[<?Zojc2j_l000000_n/
`^X00on[`>WoZkkXoj^nj004ojZnj13oZ[gX00?o0000ooooooooool07_ooool000Wooooo00@00000
oooooooooooooooo4@00000601TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`01?l00000IVIV
06IVI_l0000207moO`05o`00002IVIT0VIVI09VIVOl000000`2c/k<00ol00000c<c<0<c<c00;0<c<
c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV00Go
000004a<C01<C4`0C4a<0000000503<c<`03o`00000I6AT06ATI01006ATI0P00000703<c<`030000
001<C4`0C4a<00<0C4a<1?l0000<06IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0
0P0c<c<00`0000006ATI01TI6@0401TI6@03o`00000000000000018000001?ooool00`00003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo2_nY_NP00onY_>SoZ;cXojRki`02ojRki`;oYk_W
00CoY[WWojFgi_nU]nKoYKOV0_nT]N@00onS/^?oWjcPoin/h002oijWg@?oWZ?I0_nNX=D01?nOWM;o
VY;:oifAaonMTLL4oj2Aa0;oXi;300?oYIC3ojB<^onWSk`00_nWSk`3ojVC_P03ojZG`_n/T[_o[9:k
00?o[9K000?oZI[7ojjI`OnXW</00onXW</01?nJW]OoY:?Coh^Rhon;X^<3oeNCk@05o`1WfOl0>K_o
03k2o`0n`_ljElD00_m:Ekd2ogQX]@;oPfZ^0_n<K:T3o`000003oiA_YOnLLZ?oW7:S00?oXWJQ0onZ
Nil3ok60W`Co_hfP1?oCX:<01_oV]Z?on=6RooSAX_oliICoh>=fojkOn0;o[Lga00?o[/c_ojc4jon/
a>/00_n/`nX01_n/`^[o0000oj^oj?n[_nSoZkkXojZnj1GoZ[gX00?o0000ooooooooool07Oooool0
00Wooooo00@00000oooooooooooooooo4@00000601TI6@050000000c<c<0<c<c03<c<`0000000`1<
C4`01?l00000IVIV06IVI_l0000207moO`05o`00002IVIT0VIVI09VIVOl000000`2c/k<00ol00000
c<c<0<c<c00;0<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01Ol00000Ogmo07moO`1oOgoo
00000080IVIV00Go000004a<C01<C4`0C4a<0000000503<c<`030000000I6AT06ATI01806ATI0P00
000603<c<`03o`0000000000C4a<00H0C4a<3?l0000404a<C080000000Co000003<c<`0c<c<0<c<c
0P00000601TI6AH000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo
1onY_NP01OnY_>SoZ;cXojRlj?nX_>SoZ;_W00;oYk_W0onV^NL00onU]nKoX[CUoj:di@02oj2`h`?o
WjcP0_nNYmd01?nNXmWoUiWCoiREconHULl3oiZBbP;oWI770onPTL@01?nST/?oXHVkojB<^onTS;/4
ojN?_003ojVC__n[S[Oo[9:k00;o[9:k0on/U/03ojjI`@;oZ9c;00Co/9o6ojBSdonTXm?oY:?C0_n;
X^<3oeNCk@04o`1WfOl0>K_o03k2ocYGa@;oBUNm0_mMF[H01OmhJ;Go0000o`000?l0003oS6bY00?o
U6nU0_nLLZ<2oj9fX@04oj9eX?nZNiooZW^OojYkW`?o/H2O1?noSJ03om>PX`;oi[JS00Con]>NoocU
U?oPhgKo[<kb0_n]cO42oj_4k003ojc4jon[`>WoZkoY00;oZkoY00?oZkoXo`000?nZ_^P00onZ_^PE
ojZmj003o`000?oooooooooo01cooooo0009ooooo`0400000?oooooooooooooooa4000001P0I6AT0
1@000000<c<c03<c<`0c<c<0000000<0C4a<00Co000006IVIP1VIVKo00000P1oOgl01Ol00000VIVI
09VIV@2IVIWo000000<0/k>c00?o00000<c<c03<c<`02`3<c<`01Ol00000/k>c0;>c/`2c/k?o0000
0080VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP05o`00001<C4`0C4a<04a<C00000001@0c
<c<00`0000006ATI01TI6@0D01TI6@030000000c<c<0<c<c00D0<c<c0`00000A04a<C0<00000100c
<c<2000000P06ATI5P000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02Ooo
ool6ojVmj0;oZKcX00CoZ;cXojRkj?nX^nSoZ;_X0_nW^nL00onV^NOoY;OVoj:di@03oj:di@;oX;3S
00CoWjcPoiVTgOnGW]WoUikI0onGVM<2oiREc`;oVY;:0onMTLL01?nPTLCoW8Nloj69^onQRK/3ojB<
^`;oYhnl00CoZ8Veoj^>]on[S[OoZhjg0on/T[/00on/U/3o/9Bjok2D^P02ojjI`@Co/9o600?oY:?C
ok2Yd?n`ZM000onK[><2ofVTl`05o`1dgOl08ico03k2ocYGaOm:Ekd00ol00002oh=Z[P;oS6bY0onD
KjD2oiabX`03oj9fXOnRMJ3oXWFP00?oZW^O0_naP9l2okV7X0?o_hfP0ooCX:<2onJfX`03oo[CW_oe
i8;o]/M;00;oZlG/0_n[a>`4oj_0j@05oj^ojOnZ_^SoZ[kXojZnj?l000000_nZ_^P4ojZmj0CoZ[gW
3_nZ_NP00ol0003oooooooooo`0Looooo`002Oooool01000003ooooooooooooooolA000000H06ATI
00D0000003<c<`0c<c<0<c<c0000000304a<C004o`00001VIVH0IVIVo`000080Ogmo00Go000009VI
V@2IVIT0VIVIo`0000030;>c/`03o`00003<c<`0c<c<00/0c<c<00Go00000;>c/`2c/k<0/k>co`00
000209VIV@05o`00001oOgl0Ogmo07moOol000000P1VIVH01Ol00000C4a<04a<C01<C4`0000000D0
<c<c00<0000001TI6@0I6AT05@0I6AT3000000L0<c<c1000000904a<C0@000001P0c<c<00`000000
6ATI01TI6@0701TI6AL000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00[o
oooo1?nY_NP2ojVlj0?oZ;cX00?oZ;_XojNkionU^NL00_nU^NL2ojBgiP;oX[CU00?oW[3Toi^ZhOnK
Z^400onIY=d2oiNNf@;oUiWC0_nHULl00onJT/[oU8O3oiR6_`02oiR6_`;oW8Nl0onQRK/2ojB<^`03
ojN?_?nXRKGoZ8Ve00?oZhjg0_n/T[/01On_T;Go/9Bjok2D^_n`U;[o[YW100;o]9Zm0on`WlH4ok2Y
d003oi^/hon/]n7o[;OQ00;oP[Og00Go6HkYo`000?l0003o0000odYG_@02oeeJ]P;oL5n_0_n<K:T3
oiA_Y@03oiabXonIL:;oXWFP00;oXWFP1?nZNil00onaP9oo^HNPokV7X002okn=X0;ocY^R00Sodj2S
onJfXooV]Z?oi[JSoo[CW_oei8;oZ/G]oj_5k0KoZl3Y0onZ_^P2ojZmj004o`000?nZ_NSoZ[gXojZm
j0KoZ[gW4?nZ_NP00ol0003oooooooooo`0Kooooo`002Oooool01000003ooooooooooooooolA0000
00H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C004o`00001VIVH0IVIVo`0000<0Ogmo00Co
000009VIV@2IVIWo00000`2c/k<00ol00000c<c<0<c<c00:0<c<c005o`00002c/k<0/k>c0;>c/ol0
00000`2IVIT01?l00000Ogmo07moOol0000306IVIP05o`00001<C4`0C4a<04a<C0000000100c<c<0
0`0000006ATI01TI6@0I01TI6@8000002@0c<c<9000000T0<c<c00?o000001TI6@0I6AT01`0I6AT0
0ol0000000000000000E000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0;
ooooo`?oZKgX0onY_>P2ojRlj0?oYk_W00?oYKWWoj>gionS]nL00onQ]>H2oij`i0;oVj[Q00CoVJCM
ohnKf_n>TmCoSY?D0_n>SLh2oi69b0?oU8O30_nHQ[l3oib7_0;oXHVk00?oY8bkojB6]?nXRKD00onX
RKD2oj^>]`Co[i2e0_n`U;X4okBJ_@03ok2Oa_niXl?o^J?300;o/:W@00Co_;3>ojbghOn/]n7o[;OQ
0ol000001?nadO7o03Bjo`Hf^?m:Ekd2oeeJ]P;oL5n_0_n0IJT3ohiZY@;oVG2R1?nRMJ03ojYkW`03
ok60WoniQj3o^HNP00;o_hfP0_o>Vj800ooCX:?oi[JSonJfX`02oo[CWP03okK7BonZ`>[oZ/3Z00;o
Zl3Y1OnZ_^P5ojZmj003o`000?nZ_NOoZ[gW00KoZ[gW4?nZ_NP00ooooooo0000ooooo`0Kooooo`00
2Oooool01000003ooooooooooooooolA000000H06ATI00<0000003<c<`0c<c<00P0c<c<010000000
C4a<04a<C?l0000306IVIP04o`00001oOgl0Ogmoo`000080VIVI00Go00000;>c/`2c/k<0/k>co`00
000;0<c<c0;o00000`2c/k<01Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Go000006IVIP1VIVH0
IVIVo`00000304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT06`0I6AT00ol00000
000000000002000001@0<c<c0P00000801TI6AX000001?ooool00`00003oooooooooo`0Dooooo`03
o`000?oooooooooo00gooooo0_nY_NP00onY_>SoZ;cXojRlj002ojRlj004ojNkionU^^SoYK[XojFj
j0;oXkOW00CoXKCVoib`i_nGZ^CoUj[T0_nCXml3ohnKfP;oSY?D0_n>SLh2oi69b0;oU8O30onHQ[l2
oib7_003oj69^onOP[CoY8Jd00;oY8Jd0onXRKD00on[S[Oo[H^bojf;/P03ojn@]@03ok2D^_nfUKKo
]YFf00;o]9Zm00Co_9fiokVS`oniXl?o^J?30onl/<h3o`000007ok_1g_o7bM_oalWKok7AlOnoenco
03Bjo`Hf^003oeeJ]P03og1O[on0IJWoP6FY00?oSVZU0onIL:83oj9eX0?oZW^O1?niQj000onoSJ3o
cY^RoljKXP03onJfX`04oo[CW_oei8;o]/M;oj[0jPKoZ[kX1_nZ_NP2ojZmi`03o`000?nZ_NOoZ[gW
00GoZ[gW4OnZ_NP00ol0003oooooooooo`0Jooooo`002Oooool01000003ooooooooooooooolA0000
00H06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C?l0000306IVIP04o`00001oOgl0
Ogmoo`000080VIVI00?o00000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0070<c<c003o`00002c
/k<0/k>c00<0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`05o`00001VIVH0IVIV06IVI_l0
00000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00P06ATI1`00000A01TI6@@0
00002@0c<c<7000000P06ATI70000004ooooo`0300000?oooooooooo01Cooooo00?o0000oooooooo
ool03Oooool3ojVmj0?oZ;cX0onW^nP01?nU^^SoXkSXoj2eionP]NL3oib`iP;oUj[T0_nCXml2ohnK
fP;oSY?D0on>SLh2oi69b0;oU8O30_nHQ[l01?nLQkcoVGnfoin2]?nOP[@3ojB6]0?oZ8Ve0on]Rk83
ojn@]@?o]YFf00Co]9ZmokbM^OnlWKWo_9fi0_niXl<3o`000003okb`c_o7^<co^l7N00;oalWK0_oA
dMT00onoencob=_Wo`Hf^002obQ0]P03oeeJ]_m`GjooP6FY00;oP6FY0_n>JZD3oiU`XP?oXWFP0_nZ
Nil00on`P:3o^HNPokV7X002okV7X0?ocY^R00Gohk>TonJfXooV]Z?on]>NooGTPP08ojZnj003ojZm
j?nZ_NOoZ[gW00GoZ[gW00?o0000ojZmionZ_NL01_nZ_NL@ojZmj003ooooool0003ooooo01[ooooo
0009ooooo`0400000?oooooooooooooooa4000001`0I6AT01@000000<c<c03<c<`0c<c<0000000<0
C4a<00Co000006IVIP1VIVKo00000`1oOgl01?l00000VIVI09VIVOl000040;>c/`03o`00003<c<`0
c<c<00@0c<c<0_l000050;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01Ol00000IVIV06IV
IP1VIVKo000000<0C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0801TI6@/00000
4P0I6AT9000000h06ATI7@000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool0
3oooool00onY_NSoZ;cXojRlj003ojRlj003ojNkj?nU^^SoXkSX00;oXkSX0_nP]NL00onL/>KoUJcV
oiF/iP02ohjSh`;oQiWN00?oPhoGoh:7d?n2Qm000on3PLP2ohMm`@;oSGbl0_nCOKP2oiUo]P?oWh:d
0onTQ[@00onXRKGoZHJ`ojf;/P03ojf;/P03ojn@]OndT;7o]YFf00;o]YFf0onlWKT3o`0000;o`ZW1
00Go_;3>olNhc?o7^<codL7;olO9f`03om7Af@04omOGf?o8fnOoc=cUo`Hf^0;o:42f0_m`Gjl2oh1U
Z@;oSVZU0onIL:83oj9eX003ojYkWon`P:3o/82P00Co^HNP0oo>Vj82on>cY0;on]>N00?o]/M;ojZn
j?nZ_NP01OnZ_^P:ojZmi`03o`000?nZ_NOoZ[gW00CoZ[gW4_nZ_NP00ol0003oooooooooo`0Ioooo
o`002Oooool01000003ooooooooooooooolA000000L06ATI00D0000003<c<`0c<c<0<c<c00000003
04a<C004o`00001VIVH0IVIVo`0000<0Ogmo00Go000009VIV@2IVIT0VIVIo`0000040;>c/`Ko0000
1P2c/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<
C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01`0I6AT00ol0000000000000000=0000
02@06ATI00?o00000000000000006`000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool04Oooool2ojRlj0?oYk_X0_nU^^P00onS^>SoX;OXoj2gj003oi^bj0;oUJcV0_n>Xn<2ohNI
gP03oh>?eon2Qm3oPXO@00;oPh780_n7OL42ohel_0;oTgfh0onIOkH2oin2]0;oY8Jd00CoY8:_ojV6
/?nYQ[3oZHJ`0on]Rk83okB@/@;o]YFf00Co_9Rco`000?l0003o_9fi0oo2ZL401_o</KooakS<olNh
c?o7^<codL7;om[;b`?odM7I00CoemOHom[MfOo<g>Goc=cU0_lX@;H01?m<C[?oL5n_oh1UZOn0IJT3
ohiZY@;oVG2R0onRMJ04ok20X0?o^HNP0_o>Vj83on>cY003oocHW_oei8;oZ[gX00?oZ[gX00?oZ[kX
ojZmj?nZ_NP03?nZ_NL00ol0003oZ[gWojZmi`02ojZmiaCoZ[gX00?o0000ooooooooool06?ooool0
00Wooooo00@00000oooooooooooooooo4@00000701TI6@05o`00000c<c<0<c<c03<c<`0000000`1<
C4`01?l00000IVIV06IVI_l0000307moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<0
3@2c/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<
C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATD000001l06ATI80000004oooo
o`0300000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool3ojRlj003ojNkj?nV^nSoY[_X
00?oY;WX0_nP]nP01?nK/^SoUJoYoh^Vion;Y^L2oh6Kh`;oN8kL0_mbP]@2oh:7d0;oPh780_n7OL42
ohel_0;oTgfh0_nIOkH00onOP[CoWWf_ojB2[`02ojB2[`?oZHJ`0_n]Rk801?n`Rjko]92aokB@/Ond
T;43o`000005okbH/onlWKWoa:>holBS^?o2ZL400oo</Kl00oo7^<codL7;om71b`02om[;b`04om7A
fOoGemSoemOHom[Mf@;of^7K00Co0025obQ0]_m<C[?oC4jc0_n0IJT3ohiZY@?oVG2R0_nRMJ04ok20
X0;o^HNP0_o6UJ<01_o>Vj;ohk>Ton>cY?oS/jCoo=RNomoNK0KoZ[gX3_nZ_NL00ol0003oZ[gWojZm
i`0FojZmj003o`000?oooooooooo01Oooooo0009ooooo`0400000?oooooooooooooooa8000001P0I
6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00Go000006IVIP1VIVH0IVIVo`00000307moO`03
o`00002IVIT0VIVI0080VIVI0_l0000;0;>c/`;o00000`2IVIT01Ol00000Ogmo07moO`1oOgoo0000
00<0IVIV00Go000004a<C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00L06ATI6000000G
01TI6B@000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00CoZ;cX
ojNlj?nW_>SoYkcX0_nV^nP00onT^NSoXKSYoibdj@02oibdj@;oUJoY0_n;Y^L2oh6Kh`;oN8kL00?o
LX;Dog5ibomaNL/00_meLl<2ohMm`@;oSGbl0_nCOKP00onIOkKoUWVaoiim[`02oiim[`?oY8:_0_nY
Q[000on]Rk;o/8^^ok2;[P03o`0000Co_9Rc0oo4XkP4olba_`04omJk_ooA`L_of/_;om[;b`;oh=C;
00CoemOHom[MfOoJhM_of^7K0_oHhmh2obQ0]P04oda>/om/FjkoK5^^oh1UZ@;oSVZU0onIL:800onR
MJ3oYGVRojEiXP03ok20X005okV7X?o6UJ?oaYFSolJEXoo>Vj800_oS/j@2oocHWPGoZ[gX4?nZ_NL0
0ol0003oZ[gXojZmj00FojZmj003o`000?oooooooooo01Oooooo0009ooooo`0400000?oooooooooo
oooooa8000001`0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00Co000006IVIP1VIVKo0000
101oOgl00ol00000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00H0/k>c0_l0000409VIV@03o`00
001oOgl0Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C0030000000c<c<0<c<c0080
<c<c00?o000001TI6@0I6AT01P0I6ATJ000001@06ATI00?o00000000000000008`000004ooooo`03
00000?oooooooooo01?ooooo00?o0000ooooooooool04oooool3ojNlj0?oYK[Y0_nQ^>T01?nL]>Wo
Uk;Zohf[j_n=ZnX2ognOj0;oKi7S0_mQP=/2og:2e0;oLGW;00?oMG?3ogab_?mlL[`00_n5LkL2ohif
/`;oUWVa0onNOJl3ojB2[`;oZHJ`0ol000000on`Rjko]92aokB@/@04okbH/`?oa:>h00OocJ^golba
_oo</Kooc;6oomJk_ooOa/3of/_;00?oh=C;00?oi=g=onGUdOoJhM/00ooHhmh01?oChn;o:42foda>
/om<C[<2ofaK[P;oSVZU0_nIL:801?nGLJGoYGVRojEiX_nUNJ83ok20X004okV7X?o6UJ?oaYFSolJE
X`?ohk>T0_olf9h3ojZmj1?oZ[gW00?o0000ojZmj?nZ_NP05_nZ_NP00ol0003oooooooooo`0Foooo
o`002Oooool01000003ooooooooooooooolA00000003o`00000I6AT06ATI00D06ATI00D0000003<c
<`0c<c<0<c<c0000000304a<C004o`00001VIVH0IVIV06IVIP;o00000P1oOgl2o`0000D0VIVI2?l0
000509VIV@;o00000P1oOgl2o`0000<0IVIV00Go000004a<C01<C4`0C4a<0000000403<c<`030000
000I6AT06ATI00H06ATI6`0000000ol0000000000000000g000000Cooooo00<00000ooooooooool0
4oooool00ol0003oooooooooo`0Eooooo`;oYkcX00?oYK[Yoj>jjOnS^^T00_nN]nX2oiNbjP;oSJ_Z
0_moWnP2ofnAh`03of60fomJL]7oFW;A00;oLGW;0_meLl<00omlL[coQG>gohEc]`02ohif/`?oUWVa
0_nNOJl2ojB2[`?o00001?n`Rjh00ondT;7o^I>_okVC[`02okbH/`;o`ijb00Goa:>holf[]oo=ZkOo
cJ^golba_`02omJk_`04omo6`?oWd/;oim;2on3Db`;oi=g=00OoiNGAon?ZeOoSj]Gof>?Nom?Sh_o=
h>Ko00>F00;oC4jc0_m/Fjh2ohAWZ@?oUg6U0onUNJ83ok20X0CoaYFS0_oS/j@2oocHWP03omoNK?nZ
_NOoZ[gW01?oZ[gW0_nZ_NP00ol0003oZ[gXojZmj00FojZmj003o`000?oooooooooo01Gooooo0009
ooooo`0400000?oooooooooooooooa8000001`0I6AT01@000000<c<c03<c<`0c<c<0000000@0C4a<
00Go000006IVIP1VIVH0IVIVo`00000407moO`;o00003`2IVIT01Ol00000Ogmo07moO`1oOgoo0000
00@0IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI
00H06ATIE@000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool3ojJk
j@03oj>jjOnQ^N[oXKWZ00?oVkK[0_nA/>`2oh:Wk005ofjHjOmGQ>;o@VkGod9^eomJL]400_mJJ<L2
of9U_`;oO7:l0_n5LkL2ohif/`;oUWVa00GoWWf_o`000?l0003o0000ojF1[003ojb6[@;o/8^^00Go
]Hf/okVC[oniTjoo^I>_okbH/`03ol>N/P06olBS^?o=ZkOocJ^golf[]ooG][Soe[^o0_oOa/02onOB
`P05oncNa?oTgLgoiNGAonGUdOoSj]D00_oNk=/01OoHjn;ocN3VolKKjOl08jcoC4jc00;oK5^^0_n4
IjT3oiMaY@?oYGVR0on`P:001_nlSZKoaYFSolJEXoo6UJ?og[6Xon>cY0;oo=RN4OnZ_NL8ojZmj003
o`000?nZ_NSoZ[gX01GoZ[gX00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooo
oooo4`00000701TI6@050000000c<c<0<c<c03<c<`000000101<C4`01Ol00000IVIV06IVIP1VIVKo
000000D0Ogmo0_l0000;09VIV@;o00000`1oOgl00ol00000IVIV06IVIP0206IVIP03o`00001<C4`0
C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6EH000001?ooool0
0`00003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00CoY[_YojFkjOnU^nWoYK_Y0_nQ
^NX01?nK]^_oV;G/oh^^k_n;[^h2ogJRkP;oFHkY00GoEhCRod9^eolgG<coFW;AoeYXa`02of9U_`;o
KVJi0_n5LkL2ohif/`?o000000CoWWf_oiek[?nUPJcoYH6/0on/QZd00on`Rjko]Hf/okF=[003okVC
[`Co`ijb0oo=ZkL2omNf^0;oglK00ooWd/801?o/g/Cok^S6onGUdOoSj]D2omk/f`;of>_R00KocnKW
olKKjOnoeN_o02>/oda>/om/Fjh3ohAWZ@?oUg6U0onUNJ800on`P:3o_8jVokb>YP02olJEX`;og[6X
00?ohk>ToocHW_olf9h04OnZ_NL8ojZmj003o`000?nZ_NSoZ[gX01KoZ[gX00?o0000ooooooooool0
5?ooool000Wooooo00@00000oooooooooooooooo4`00000701TI6@030000000c<c<0<c<c0080<c<c
00<0000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVKo000000H0Ogmo1?l0000309VIV@Co
00000`1oOgl2o`0000@0IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00H06ATIE`000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooooooo
ool06Oooool00onU^nWoY;_Yoinij`02oinij`;oV;G/0_n;[^h2ogJRkP05oeV>jOlfLmko=W?Nod9^
eolgG<`00_mJJ<L01?mRIKooKVJiofiV^OmlJ[@3o`000003oiIi/OnDMJkoWG^/00;oWG^/0onUPJ`2
ojb6[@Co]Hf/0_niTjl01_o1V:ko`ijbol>N/_o3W[;oc:Jbolf[]`?oekJh00CohL:iomo6`?oWd/;o
im;20_o/g/@01oo^j<Kok?3;onOedOoWmM7oh?KJomS[h_o?i^L00_o6gn/00onoeN_o^Lo[o`0S[002
ofaK[P;oQ6NY0onGLJD3ojEiXP03ok20X?nlSZKo_8jV00;oaYFS0_oN/JP2oo_RY@03omoNK?nZ_NOo
Z[gW00koZ[gW2_nZ_NP00ol0003oZ[gXojZmj00<ojZmj0CoZ[kX00?oZ[gXojZnj?nZ_^P00onZ_^P0
0ol0003oooooooooo`0Cooooo`002Oooool01000003ooooooooooooooolC000000L06ATI00<00000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C004o`00001VIVH0IVIV06IVIP;o0000201o
Ogl3o`0000H0Ogmo00?o000006IVIP1VIVH0101VIVH01Ol00000C4a<04a<C01<C4`0000000D0<c<c
00<0000001TI6@0I6AT01P0I6AUG000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0Jooooo`;oY;_Y00?oWkW[oijik?nN^N`00onD]Nh2ohB]k`;o?h?X00?o=W?NoaIEcolFELl0
0_ljDl82of9U_`;o000000?oO6ZdohU`/?n9L;000onDMJh2oiek[0?oYH6/0_n/QZd01On_R:_o]Hf/
okF=[?neSJco^I>_00?o`IR^00?o`ijbolbV/_o<Y[800ooG][P2on72^@04on_A^_oWd/;ok=k4oncN
a0;ok^S600Ook?3;onOedOoPm][oh?KJomObhoo>jnWoa]o[00;o_]O/00Co^Lo[o`0S[?lgB;SoK5^^
0_n4IjT3oiMaY@;oYGVR00?o[HF[okb>Y_nlSZH00_nlSZH00oo6UJ?og[6XomjaZ002oo_RY@ooZ[gW
3OnZ_NP00ol0003oZ[gXojZmj009ojZmj0coZ[kX00?o0000ooooooooool04oooool000Wooooo00@0
0000oooooooooooooooo5000000701TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`0
0P1<C4`00ol00000IVIV06IVIP0206IVIP;o00003@1oOgl2o`0000D0IVIV0_l0000304a<C0030000
000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT01P0I6AUH000000Cooooo00<00000ooooooooool0
4_ooool00ol0003oooooooooo`0Kooooo`?oXk_Z0_nN^N`01OnD]NkoTKC_ogf/lOmm[?7oFiW`00;o
?h?X00?o35gEoaIEcol5?l000ol00002ofiV^@03ogaZ]?n9L;3oRG2`00?oU7F^0onMNj`2ojF1[003
ojb6[On_R:_o[hR[00?o]Hf/1?o1V:h3olbV/P03omNa/ooG][SohL:i00;ohL:i00Oojm6joo7O_?oa
gkcolnblonkXa_o/l<_oioGA00;oh?KJ00Goeo;Solk[jOo4h^goa>;]okkGk003okS@k0;o=dRh0on4
IjT2oiMaY@03ojEiX_n]QJ_o[HF[00Co_8jV0_oN/JP3oo_RY@coZ[gW4OnZ_NP00ol0003oZ[gXojZm
j002ojZnj0?oZ[gX4?nZ_^P00ol0003oooooooooo`0Booooo`002Oooool01000003ooooooooooooo
oolE000000H06ATI00<00000o`00000c<c<0100c<c<00`000000C4a<04a<C00204a<C003o`00001V
IVH0IVIV00<0IVIV0ol0000807moO`;o00001@1VIVH2o`0000@0C4a<00<0000003<c<`0c<c<00`0c
<c<00`0000006ATI01TI6@0601TI6ET000001?ooool00`00003oooooooooo`0Booooo`03o`000?oo
oooooooo01cooooo00?oXk_Zoj:kj_nR^nX00_nL^N`2oi6dk`;oOJca0_mKVO03o`000003o`Do`?m7
Dk_oAe>k00;oKVJi0_mlJ[@2ohU`/0;oU7F^0onMNj`2ojF1[0?o[hR[0oneSJ`4ol6H[P05olVQ[oo<
Y[;oek6comNa/ooR_kD00_oQ`[T2on_A^P;olMnl00Colnbloo3e__oYn/;oh_g<0_oJo=T00ooBmnGo
bNg]olCRk@02okcHkP;o^=3/00?o//W[o`0S[?lgB;P00om`I[L00onGLJGoUGRaojf5Z`02ojf5Z`Co
_8jV0_oN/JP2oo_RY@?oZ[gW1OnZ_NP00onZ_NOoZ[gXojZmj00AojZmj0;oZ[kX00?o0000ojZnj?nZ
_^P05OnZ_^P00ol0003oooooooooo`0Booooo`002Oooool01000003ooooooooooooooolE000000L0
6ATI00<0000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00D0
IVIV2?l0000506IVIP;o00001@1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H0
6ATIF@000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00onR^n[o
X[_[oi^ik@02oi^ik@;oSkC`0ol00002o`U/g@04o`0d^ol5?l3o>U?2odMC^`;oFeVf0_mlJ[@2ohU`
/0?oU7F^0_nMNj`00onUPJcoZ8:[ojn8Z`03ojn8Z`03okF=[?nlTjco_9>/00;o`IR^0_o9XJl00oo<
Y[;oek6comNa/`02on:o]@04on72^Oo[dK[olMnloo7O_0;olnbl00Kol?Fnon;mc?oJo=Wof_cIom;g
iOo9kNd2ol3Qk`06okcHk_nfcngo]/o]okK?kOnbbN_o[lGZ0_lgB;P2og1V]`?oUGRa0on]QJ/3okb>
YP05omB^/_oN/JSonn:UojZmj?nZ_NL06OnZ_NP5ojZnj003o`000?nZ_^SoZ[kX01GoZ[kX00?o0000
ooooooooool04Oooool000Wooooo00@00000oooooooooooooooo5@00000801TI6@030000000c<c<0
<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`2o`000140IVIV00?o000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATIFP000004ooooo`0300000?oooooo
oooo017ooooo00?o0000ooooooooool07oooool2oj:kj`04oi^ikOl0003o0000o`0000;oS[Ga0_mf
[?@2o`U/g@03o`0d^ol5?l3oAe>k00;oFeVf0_m`H[<2ohU`/0?oU7F^00?oWG^/oiik[?nXPZ/00_nX
PZ/3ojn8Z`?o_9>/00Co`IR^olVQ[oo9XJoobJ6_0_oG/K<3on:o]@03ong@]_o[dK[olMnl00;olnbl
00Gol?FnomOl]OoBolGocooJol[hj@02ol?[l@05ol3Qkonie^oo^MK_okWFkonfcnd00_nab>`00on_
aN[o[L;YocM8^002og1V]`?oUGRa0on]QJ/2okb>YP;oe:jb0_okhZDKojZmj0KoZ[kX00?o0000ojZn
j?nZ_^P05OnZ_^P00ol0003oooooooooo`0@ooooo`002Oooool01000003ooooooooooooooolE0000
00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0;o0000301VIVH3o`00
00H0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6EX000001?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo0ol000001OnR^n_oVkW]oi^ikOn>]O7o
SkKa00;oMZke0_m6V?<01Ol06YGo01NVoahk]Om7Dk_oFeVf00;oL6:c0_n3Jk03oi9c[@;oWW^/0onX
PZ/2ojn8Z`04okF=[?nlTjco_9>/okbC[0CobJ6_00?oe:faomNa/ooR_kD00_oR_kD02oo]d;KomN:f
ooK_]?ofkkCok_N_on;j[_oBolGo^o_3ol7nh?o0m?3o`n_a00;o^mga0_nie^l2ok?=k@05ok78k?n^
a>[o[/CZojg2jOl008400om`I[L2oiEh/@?o[HF[00Go_8jVomB^/_oD[[;oe:jboo?c]P0KojZmj0So
Z[kX00?o0000ojZnj?nZ_^P05?nZ_^P00ol0003oooooooooo`0@ooooo`002Oooool01000003ooooo
oooooooooolF000000P06ATI00<00000o`00000c<c<0100c<c<00`00003o00000000000504a<C0co
00001`1<C4`2000000D0<c<c0P00000901TI6E/000001?ooool00`00003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo0ol00002ooooo`?oX[_[0_nK^^h2ohnfl@;oMZke0_m6V?<00ol06YGo
00fNoahk]@02oe]I]P04og1R/on3Jk3oPf^`oh=[/0;oTW>]0onNNj`2ojR2Z`04ojn8ZoneSJco]Hf/
okF=[0;o_9>/0oo9XJl2omB]/@03omNa/ooR_kGoh[ne00;okM2f00SomN:fooK_]?ofkkCok_N_okKb
YOnknl?o`OkPol3dl0;o^nGd00Go^mgaokCBkondd^oo]=;_ok?=k@02ojo7j`05ojk4j_n/`NWoZl3Y
oj_0jOl008400_m`I[L3oiEh/@;o[HF[1?oD[[800ooclkKoZ[gXojZmj00GojZmj0[oZ[kX00?o0000
ojZnj?nZ_^P05OnZ_^P00ol0003oooooooooo`0?ooooo`002Oooool01000003ooooooooooooooolG
000000T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00B04a<C0<000001P0c<c<0
0`0000006ATI01TI6@0901TI6E/000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Wooooo0ol00006ooooo`03oj:kjonR_>_oW;[]00;oW;[]0_nA^?42ogZamP;oC9ke00Co06kH
o`0=W_lnBKCoFeVf0_m`H[<2oh=[/0?oTW>]0_nNNj`2ojR2Z`Co]Hf/00Co_9>/olBK[_o4VjkobJ6_
0ooD[K42on:o]@;okM2f00OomN:fooK_]?ofkkCok_N_ok_/U?nYmlco]_W[00;o^>ge00?o^nGdokGH
l_nef?800_ndd^l2ok3:k@03ojo7jon]`n[o[L?Z00;o[<7Y00CoZl3Yoj^nj?l@F=7o45SA0onEN;40
0on]QJ_o`:W3ol2Y``02omB^/P03oo?c]_nZ_NSoZ[gX01?oZ[gX4?nZ_^P00ol0003oZ[kXojZnj00E
ojZnj003o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooooaP000002@0I6AT0
0`000000<c<c03<c<`0503<c<`<00000401<C4`00`000000<c<c03<c<`0603<c<`03o`00000I6AT0
6ATI00T06ATIG0000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05_ooool3
o`0000[ooooo0_nR_>/01?nL^^goW[_]oijkkOnN^nd2oi>il@;oOkCf00CoEjKgo`0=W_lN>kGo?TVd
0_m`H[<2oh=[/0?oTW>]0_nNNj`00onXPZ_o[8J/okF=[003okF=[004okbC[?o4Vjkoa9^^olVQ[`?o
e:fa00WohKfcon:o]Oo]d;KokM2fooGR]_ofkkCoh_BMol__T_nQm^000_n`lOH01?nhkOGo]=gdok3A
lOn`dO43ok3=k`04ok3:kOn]a>_o[LC[ojg3jP;oZl3Y0_n[_nP00on[_^SoZ[kXoa1Hd@03ohfGf@Co
`:W300?oe:jboo?c]_nZ_NP04_nZ_NPCojZnj003o`000?nZ_^SoZ[kX01CoZ[kX00?o0000oooooooo
ool03_ooool000Wooooo00@00000oooooooooooooooo6@00000901TI6@030000000c<c<0<c<c00L0
<c<c00<0000004a<C01<C4`02@1<C4`4000000P0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o
00000000001K000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o
00003oooool2oj>lj`03oijkkOnO_>goWkc]00;oUk[`0_n6]oD00omV[_Wo00fNoci9]002oemI]0?o
Pf^`0_nBLjd00onNNjcoX7j]ojb6[002ojb6[0?o]Hf/0oo4Vjh00oo@Z;7oe:faomB]/@02on6m/`;o
k]6f00GomnFdooCc[?oRm9gobnnBoj;am002ojcTnP04ok7Qmon_do?o[m?cok3Al@?o[LS^0_n]a^`0
1On]a>_oZl7Zoj_1j_n[`>WoZ[oX00CoZ[kX00?oZ[gXoa1HdOn=UmT00_n=UmT2ol2Y``03ojcga_nZ
_NSoZ[gX013oZ[gX5onZ_^P00ol0003oZ[kXojZnj00CojZnj003o`000?oooooooooo00kooooo0009
ooooo`0400000?oooooooooooooooaP0000000?o000001TI6@0I6AT01`0I6AT00ol00000000003<c
<`0803<c<`03o`0000000000000000P000002`0c<c<00`0000006ATI01TI6@0801TI6El000001?oo
ool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol0000Aooooo`?oY;c[00?o
Wkc]oj6lk?nJ^nl00_nJ^nl2ohjjm004o`00K?l05ZCo?TVdoemI]0?oNfRb0_n@M:l2oj1n[@?o[8J/
0_neSJ`01?nmUZkoa9^^olBK[_o4Vjh2om2X/@03omB]/OoQ_K?ohKfc00;ok]6f00?omnFdooCc[?nN
dfd00_nTi?`01?n/i?[o[MKeojgFmOn_do<3ojg:k`03ojg8k_n/`n_o[<;Z00;o[<;Z00?oZl7ZojZo
jOnZ_nT00_nZ_nP3ojZnj0;oZ[gX0on=UmT00oo0ZL?o[?O6ojZmj00CojZmj1KoZ[kX00?o0000ojZn
j?nZ_^P03_nZ_^P5ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooo
oaX000002P0I6AT2000001/0<c<c0P00000:01TI6F0000001?ooool00`00003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo0ol0000Eooooo`03ojBljonU_>[oYKcZ00;oXKc/00OoV[__oijl
k_nN_>koW[c^oiBkl_l05ZCo32n_00;oGeVd0_mkJ;82oi1d[`?oX7j]0_n/QZ`01OneSJco_IJ^okfF
[_nmUZkoa9^^00?od:Ra0_oQ_K<2onkA]P05ooOU]?odljcoW]=]oikCKOnTi?`00_nYe_L00on]e_Go
[<_`ojc;l002ojg:k`;oZlC/0_n/`n/01?n/`^[oZl3Yoj_0jOnZ_nT5ojZnj0GoZKgX00?oZ[gXojVm
j?nY_NP04OnZ_NPJojZnj003o`000?nZ_^SoZ[kX00_oZ[kX2?ooool00ol0003oooooooooo`0=oooo
o`002Oooool01000003ooooooooooooooolK000000/06ATI0P00000G03<c<`8000002`0I6AT00ol0
000000000000001N000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0<oooo
o`?o00006Oooool01?nU_>[oY[gZojJmj_nV_NX2oj>lj`07oijlk_nQ_NgoXKg]oiZml?l05ZCo32n_
oemI]002og]X/P?oT7B_0_nPOZd2ojb6[0Co_IJ^00Ooa9^^om2X/Oo@Z;7od:Raomjk]OoQ_K?ok]6f
00;omnFd00?om?>/oikCKOnUeOT00_nXbo82oj[<l@05ojc;l?n[aNgoZlG]oj_5kOn[a>`00_nZ`NX2
oj[0jP03oj_0jOnZ_^SoZ[kX00?oZ[kX2_nY_NP?ojZmj1goZ[kX00?o0000ojZnj?nZ_^P01OnZ_^P=
ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooa`00000300I6AT0
0`000000<c<c03<c<`0A03<c<`80000000?o000001TI6@0I6AT02P0I6AUR000000Cooooo00<00000
ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool00onV_N[oY[gYojBmj`02
ojBmj`06oj6mkOnS_NcoW[g^o`00Mol<;joo@Dfg0omkJ;82oi1d[`;oX7j]00?o[8J/ok>>/?ncS[00
0onmUZh3om2X/@;og[^e00Gok]>honkA]_ogiKComnFdoikCK@02ojK:l`04ojS;l_nYaNkoZLG^ojW5
kP;oZ/G^00CoZlG]oj[1jonZ`N_oZ/7Z1?nZ_nT00onZ_^SoZKkXojVnj002ojVnj0_oZKgX2OnZ_NPR
ojZnj003o`000?nZ_^SoZ[kX00?oZ[kX3oooool00ol0003oooooooooo`0=ooooo`002Oooool01000
003ooooooooooooooolK00000003o`00000000006ATI00/06ATI00?o00000000000000003@0c<c<3
000000h06ATIH`000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3
o`0002;ooooo0_nV_NT00onT_N_oYKgZojFmjP02oj>mk004oijmk_l<;joo@Dfgod5=]`;oNfRb0_n@
M:l00onPOZgoY8Fbok>>/002ok>>/0?o_IJ^00?obJ>com2X/OoN^kD00_oN^kD01Oo^dkSom^beooK/
]OoYmZ?oYl?^00?oZ<C^0_nYaNh4ojW1j`03oj[1jonY_nWoZKoY00?oZ[oY0onY_^P?ojVmj0SoZ[gX
8onZ_^P00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oo
oooooooooooooal000003@0I6AT=000000l06ATII@000004ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool00oooool3o`0002Kooooo0_nW_NT02?nU_N[oY[gYojJmjOnV_NWoYKg[o`00
Mol<;joo@Dfg0_m^I[P01?n@M:ooSgRfojB5/_nTQK84ok>>/004okfF[_o9Xk?obJ>com2X/@;og[^e
0_o^dkP2ooK/]@04ojK2kOnW`nkoYl?^ojS4kP?oZ<7[00?oZL7[ojVoj_nY_nT00onY_nT2ojVnj@?o
ZKkX4_nY_NP6ojZmj2?oZ[kX0_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00go
oooo0009ooooo`0400000?ooooooooooooooob0000009P0I6AUW000000Cooooo00<00000oooooooo
ool03oooool01?l0003oooooooooooooool3o`0002[ooooo0onW_NT01_nV_NWoYkgYojJmj_nV_N[o
00:Eod5=]`;oKVJh0_n?N;H3ojB5/P?o/hj`0oo9Xk<01?oI^K[og[^eomjk]Oo^dkP2ooK/]@04onWf
XonW`>_oYl3[ojO0j`?oZ<7[1?nY_nX01OnY_nWoZKkYojVnjOnY_^WoZKkX01KoZKgX0onZ_NPPojZn
j0Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003o
oooooooooooooolO00000003o`00000000006ATI02806ATIJ@000004ooooo`0300000?oooooooooo
00oooooo1?l0000^ooooo`03ojNmjOnX_NSoZ;gX00;oYkgY00GoY[gZo`02UOl6=KKo@DfgofiV^003
ohmh]P;oY8Fb0_ncS[02okjM]`;obJ>c0_oI^KX01?oN^kGok]>hooK/]Oo<ki<2ojNoj`03ojO0jonX
_^WoZ;kY00;oZ;oZ00?oZKoZojVnjOnY_^T00onY_^T4ojVnj1KoZKgX8?nZ_^P:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo8P00
000Q01TI6FX000001?ooool00`00003oooooooooo`0?ooooo`;o0000<Oooool3ojRmj0;oZ;gY00?o
YkgYo`02UOl6=KH00_m^I[P2ohmh]P;oY8Fb00Go/hj`okjM]onnWKOo_YfgolVS/`03omVi^P04on_G
`?oamK[oc>nColc_T`GoZ;kY1?nY_^T4ojVmj003ojVnj?nY_NSoZKgX01KoZKgX1?nY_^PIojZnj0oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooo
oooooooooolT000001d06ATIK0000004ooooo`0300000?oooooooooo017ooooo00?o0000oooooooo
ool0;oooool5ojRmj004oj/g0?l6=KKoEVC5oeITa@;oSgRf00?oY8FbojbC_OnnWKL00onnWKL3omVi
^P;ojmO000?olOFjolc_TonX_^T00_nX_^T2ojRmj@;oZ;kY00?oZKkYojVmj?nY_NP06onY_NP7ojVn
j1KoZ[kX4_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo0009ooooo`04
00000?ooooooooooooooobH000006@0I6AU^000000Cooooo00<00000ooooooooool04_ooool00ol0
003oooooooooo`0_ooooo`GoZ;gX00?o002=o`He]_mFI<D00_n<P/<3ojbC_@?o_Yfg00Koc[K2omVi
^_o[el3ojmO0oo7e^_nX_NT2ojRmj0?oZ;gY7onY_NP:ojVnj13oZ[kX6?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?ooooooooooooooobT00000500I
6AU`000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`CoZ;gX00?o
002=oeITaOmFI<D00_n<P/<3ojbC_@03okjM]oo>]/;oc[K200;oh]kA00?ojmO0ojRmj?nX_NP01OnX
_NPNojVmj0coZKkX2onZ_^PLooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool000Wooooo00@00000oooooooooooooooo<000000901TI6G@000001?ooool00`00003ooooooooo
o`0Dooooo`;o0000<Oooool4ojRmj0;o5E_C0_n<P/<2ojbC_@04okR_d?o>]/;oc[K2oljf`P;oh]kA
00?of_k3ojRmj?nX_NP01?nX_NPMojVmj0ooZKkX2?nZ_^POooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo01Kooooo00?o0000ooooooooool0;_ooool5ojRmj003oaEKdon5V^3oQI[P00Co^:o@
00Coc[K2on;NdOoRg]7of_k31OnX_NPMojVmj17oZKkX1?nZ_^PTooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo01Oooooo00?o0000ooooooooool0;_ooool6ojRmj0;oQI[P0onh[m000oo5i>ko
h]kAojRmj005ojRmj1goZKgX4onY_^P00onZ_^Soooooooooo`0Uooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool6ojRmj0;oQI[P00?o^:o@olGTk_nX
_NP01onX_NPKojVmj1;oZKkX:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Iooooo`;o
0000<?oooolBojRmj1OoZKgX4?nY_^P`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01_o
oooo00?o0000ooooooooool0;_oooolBojRmj1GoZKgX3onY_^Pcooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo01cooooo00?o0000ooooooooool0;_oooolBojRmj1;oZKgX3OnY_^Phooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo01gooooo00?o0000ooooooooool0;_oooolBojRmj17o
ZKgX2OnY_^Plooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01kooooo0_l0000_oooooa3o
Z;gX3onY_NP:ojVnj3oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool08?ooool00ol0003o
ooooooooo`0]ooooo`ooZ;gX3onY_NP6ojVnj4Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool08Oooool00ol0003oooooooooo`0^ooooo`koZ;gX2onY_NP5ojVnj4Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool08_ooool00ol0003oooooooooo`0^ooooo`koZ;gX2_nY_NP3ojVnj4_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool08oooool00ol0003oooooooooo`0^ooooo`co
Z;gX2_nY_NQ@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02Cooooo0_l0000^ooooo`go
Z;gX1OnY_NQEooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02Kooooo00?o0000oooooooo
ool0;?ooool;ojRmj0?oZKgXF?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Wooooo`03
o`000?oooooooooo02cooooo2OnX_NQMooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02So
oooo00?o0000ooooooooool0;?ooool6ojRmj63ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0:Oooool2o`0002gooooo00?oZ;gXooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0IOooool01?l0003oooooooooool0000;ooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0;_ooool2o`0002Sooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooool000002oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
000000[ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0b
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0cooooo`;o00008oooool0
0ol0003oooooooooo`1Wooooo`?o00002_ooool000Wooooo00@00000oooooooooooooooo[@000004
ooooo`0300000?oooooooooo03Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1S
ooooo`Co00003Oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo03Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo03Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo03Sooooo0_l0000Nooooo`03o`000?oooooo
oooo05Sooooo1?l0000Hooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000L
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0>oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0??ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04gooooo1?l0000Sooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0?Oooool2o`0001Wooooo00?o0000ooooooooool0BOooool4
o`0002Oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0o
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`10ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`11ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0?oooool4o`0003;ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`12ooooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo04Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0gooooo`Co0000>_ooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo04Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00@00000oooooooooooooooo[@000004
ooooo`0300000?oooooooooo04Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`
ooooo`?o0000@_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo04Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo04Sooooo0_l0000=
ooooo`03o`000?oooooooooo02Sooooo1?l00019ooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Cooooo1?l0001=ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0Boooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001A
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0C?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0001Dooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0COooool2o`0000Sooooo00?o0000
ooooooooool06Oooool4o`0005Sooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4
o`0005cooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1@
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:
ooooo`Co0000Ioooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo05Cooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo0ol0
001_ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0E_oo
ool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo05Oooooo0_l0001fooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo
]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00017ooooo]_l0000:oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0J?ooool?000003_ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo06Gooooo0`00000?ooooo`H00000=Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Hoooool2000001Sooooo00<00000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0H?oo
ool00`00003o0000o`00000Kooooo`<0000000?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0G_ooool2000002;ooooo0`00000]ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Moooo
o`0300000?oooooooooo02Gooooo0`00000Zooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Looooo`03
00000?oooooooooo02Wooooo00<00000ooooooooool09oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Foooool00`00003oooooooooo`0Aooooo`P000004_ooool2000002Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05[ooooo00<00000ooooooooool03_ooool4000000Sooooo1`00000=ooooo`8000009Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0FOooool00`00003oooooooooo`0<ooooo`<000004oooool3
000000cooooo0`00000Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
04cooooo6@3o]/5=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C?ooool<0?nf
`@030000003o]/40okK100T0okK100@00000o`000?l0000000006Oooool00`00003o000000000002
000000[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`19oooooal0okK1B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04Wooooo3P3o]/400ol00000okK10?nf`@090?nf`@030000003o]/40okK10080okK17_ooool20000
00Sooooo0P00000Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Ko
oooo8`3o]/49o`00od3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`16oooooa40
okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@Cooooo3`00000:ooooo`03
00000?oooooooooo00Oooooo0P00000Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo04?ooooo8`3o]/43o`00o`D0okK11?ooool3o`00ocgooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`13oooooa<0okK100<000000?nf`@3o]/402@3o]/400`000000okK1
0?nf`@070?nf`@<000003oooool3000000Sooooo0P000009ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@?oooolU0?nf`@03o`00o`3o
]/40okK100T0okK11?ooool2o`00oc_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`10oooooaD0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@060?nf`@8000001@3o
]/4@ooooo`@000001_ooool2000000Sooooo00<00000ooooooooool06_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0mooooobL0okK100?o003o0?nf`@3o]/403@3o]/43
ooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0m
oooooaL0okK100?o00000?nf`@3o]/402@3o]/400`000000okK10?nf`@050?nf`@800000203o]/4<
000000Oooooo0`000005ooooo`8000001oooool00`00003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo03[ooooo:@3o]/400ol00?l0okK10?nf`@0?0?nf
`@?ooooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03[ooooo6@3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100D0okK100<000000?nf
`@3o]/401@3o]/43000000<0okK12Oooool3000000Oooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0>OoooolY0?nf`@03o`00o`3o]/40okK10140okK10oooool00ol00?oo
ooooooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_oooolA00000004
o`00000000000000000001<0okK100<000000?nf`@3o]/402@3o]/400ol00000okK10?nf`@040?nf
`@03o`0000000000okK100@0okK100<00000o`00000000001`3o]/4;ooooo`D000000oooool30000
00Cooooo00?o000000000?ooool01Oooool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03Oooooo:P3o]/400ol00?l0okK10?nf`@0E0?nf`@03
ooooool00?oooooo03Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`80
00003Oooool80?nf`@<000003`3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@oo00001Oooool2000000Co
oooo00<00000ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01Ko
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=Oooool[0?nf`@03o`00
o`3o]/40okK101P0okK100?o003oooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02Cooooo1000000=ooooo`d0okK10`00000:0?nf`@800000303o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/42o`0000T0okK1
1_ooool4o`0000?ooooo00<00000ooooooooool00_ooool2000000Cooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo03Cooooo;03o]/400ol00?l0okK10?nf`@0H0?nf`@03o`00oooooooooooo03Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`8000004?oooolA0?nf`@X000003@3o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@040?nf`@_o00001?ooool2o`0000;ooooo0P000004ooooo`0300000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo03?ooooo;03o]/400ol00?l0okK10?nf`@0J
0?nf`@03o`00oooooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00oooooo:03o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100<0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@?o00001`3o]/44
ooooo`?o00000oooool2o`0000;ooooo0P000003ooooo`05o`000?ooooooooooooooo`0000001_oo
ool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo03;ooooo;@3o]/400ol00?l0okK10?nf`@0J0?nf`@03o`00o`3o]/7ooooo03?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Pooooo`0300000?oooooooooo00oooooo:@3o]/40
0ol00000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100@000000?nf`@3o]/40okK10_l0
00030?nf`@;o00001P3o]/45o`0000Kooooo0_l00003ooooo`;o00000_ooool00`00003ooooooooo
o`02000000?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo033ooooo;`3o]/400ol00?l0okK10?nf`@0E
0?nf`@So003o00<0okK1ooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01kooooo0P00000@ooooob/0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@03
0?nf`@050000003o]/40okK10?nf`Ol000000`3o]/42o`0000D0okK10ol000050?nf`@Oo000000Co
ooooo`000?l0003o00000_ooool01?l0003oooooooooo`000003ooooo`0500000?oooooooooooooo
o`0000001Oooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo02oooooo;`3o]/400ol00?l0okK10?nf`@0D0?nf`@;o003o1P3o]/401?l00?l0
okK1o`00ool00?l2ooooo`[o003o9Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01cooooo0P00000=ooooo`0300000?l0003o000001000000703o]/400`000000okK10?nf`@040?nf
`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40
okK10080okK10ol0000;0?nf`@Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
oooooooo000000?ooooo00D00000ooooooooooooooooo`000005ooooo`0300000?oooooooooo01;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;_ooool`0?nf`@03o`00
o`3o]/40okK100/0okK10ol000040?nf`@;o003o203o]/401?l00?l0okK10?nf`@3o]/42o`00o`[o
oooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02_ooool3000000?ooooo403o]/43000001T0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/401Ol0
0000okK10?nf`@3o]/7o000000<0okK12ol000000`3o]/7oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooo`0000000oooool01@00003oooooooooooooool0000000Gooooo
00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0]oooooc40okK100?o003o0?nf`@3o]/402P3o]/45o`0000<0okK100?o003o0?nf`@3o]/401`3o
]/401_l00?l0okK10?nf`Ol00?l0okK1o`00o`_ooooo00?o003oooooooooool08Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`03oooooa@0okK100<000000?nf`@3o]/405P3o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK10080okK100@000000?nf`@3o]/7o00000`3o]/401Ol00000okK10?nf`@3o]/7o
000000<0okK100?o00000?nf`@3o]/402@3o]/44o`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooo`000003ooooo`0400000?oooooooooo000000Gooooo00<00000oooooooo
ool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0/oooooc80okK1
00?o003o0?nf`@3o]/402P3o]/45o`000080okK100?o003o0?nf`@3o]/40203o]/400ol00?l0okK1
o`00o`030?nf`@03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Wooooo00<00000ooooooooool02Oooool2000000Gooooo
5P3o]/43000001@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@050000
003o]/40okK10?nf`Ol000000`3o]/401?l00000okK10?nf`Ol000030?nf`@03o`00003o]/40okK1
00<0okK11ol000030?nf`@05ooooool0003o0000ooooool000000_ooool01?l0003oooooooooool0
0002ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02_ooooo<`3o
]/400ol00?l0okK10?nf`@0:0?nf`@Go000000<0okK1o`00o`3o]/402P3o]/42o`00o`D0okK100?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06?ooool00`00003oooooooooo`08ooooo`8000001_ooool40?nf`@`000002P3o
]/400ol0000000000000000A0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o
]/401@000000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04
o`00003o]/40okK10?nf`@?o00001`3o]/43o`0000030?nf`Ooooooo000000;ooooo00?o0000oooo
ooooool00_l000001Ooooooo0000ooooooooool0000000;ooooo00D00000oooooooooooooooo0000
0004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0:_oooold0?nf`@03o`00o`3o]/40okK100/0okK10ol000000`3o]/7o003o0?nf`@0;
0?nf`@03o`00o`3o]/40okK100D0okK100?o003oooooooooool02Oooool00ol00?ooooooooooo`0N
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07
ooooo`0300000?oooooooooo00Gooooo00<0okK10000000000000P00000<0?nf`@<000002P3o]/40
0`000000okK10?nf`@0>0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/40
1@000000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@05o`00
003o]/40okK10?nf`Ol000001@3o]/43o`0000@0okK10_l000001?oooooo0000ooooool00003oooo
o`03o`000?oooooo000000;ooooo00@00000ooooooooool000000oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0:_oooold0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/402P3o]/400ol0
0?l0okK10?nf`@050?nf`@03o`00oooooooooooo00Wooooo00?o003oooooooooool07_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`05ooooo`8000004`3o]/42000000T0okK100<000000?nf`@3o]/403@3o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1o`000002
0?nf`@04o`00003o]/40okK1o`000080okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@;o0000
0`3o]/42o`0000@0okK100Go0000ooooool0003oooooo`000002ooooo`06o`000?ooooooooooo`00
0?ooool000000_ooool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Yooooo`<0okK11Ol00?l]
0?nf`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o]/402P3o]/42o`00o`P0okK100?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Gooooo00<00000
0?nf`@3o]/405@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100/0okK100<00000
0?nf`@3o]/401@3o]/401@000000okK10?nf`@3o]/40000000<0okK100Co00000?nf`@3o]/7o0000
0`3o]/401?l00000okK10?nf`Ol000030?nf`@05o`00003o]/40okK10?nf`Ol000001`3o]/401Ol0
0000okK10?nf`@3o]/7o000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Sooooo1?l00?l5
0?nf`@Co003o:P3o]/400ol00?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK100X0okK100?o003o
0?nf`@3o]/401`3o]/400ol00?l0okK1ooooo`09ooooo`03o`00oooooooooooo01gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Fooooo`0300000?oooooooooo00Kooooo00<00000
ooooooooool00oooool00`00003o0000000000070?nf`@co00001P3o]/400ol00000000000000007
0?nf`@8000002`3o]/400`000000okK10?nf`@050?nf`@050000003o]/40okK10?nf`@0000000`3o
]/401?l00000okK10?nf`Ol000020?nf`@04o`00003o]/40okK1o`0000<0okK100Go00000?nf`@3o
]/40okK1o`0000080?nf`@08o`00003o]/40okK10?nf`Ol00000okK1ooooool00002ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooo`0000000_ooool01@00003oooooooooooooool0000000Co
oooo00<00000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Vooooo`;o003o3@3o]/42o`00obP0okK100?o003o0?nf`@3o]/40303o]/400ol00?l0okK1
0?nf`@080?nf`@?o000000?o003o0?nf`@3o]/40203o]/400ol00?l0okK1ooooo`09ooooo`03o`00
oooooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool00oooool00`00003oooooooooo`040?nf`@Co0000
303o]/43o`0000H0okK10P0000070?nf`@8000002@3o]/400`000000okK10?nf`@050?nf`@050000
003o]/40okK10?nf`@0000000`3o]/401?l00000okK10?nf`Ol000020?nf`@04o`00003o]/40okK1
o`0000<0okK100Go00000?nf`@3o]/40okK1o`0000090?nf`@04o`00003o]/40okK1o`000080okK1
00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?ooool0000000;ooooo00D00000oooo
oooooooooooo00000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool09Oooool00ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK1
02D0okK100?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@070?nf`@Go00002@3o]/43o`00
00[ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo
00<0okK10_l0000C0?nf`@;o00001P3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK1
00H0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK1
0?nf`Ol000000P3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100Go00000?nf`@3o]/40
okK1o`00000;0?nf`@07o`00003o]/40okK1o`00003o]/7oooooo`000002ooooo`05o`000?oooooo
0000ooooool000000_ooool00`00003ooooo00000003ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0T
ooooo`03o`00ooooool0okK10140okK100?o003o0?nf`@3o]/401?l00?lQ0?nf`@03o`00o`3o]/40
okK100/0okK100?o003o0?nf`@3o]/401`3o]/45o`0000P0okK11Ol00009ooooo`03o`00oooooooo
oooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo00<00000ooooooooool00oooool01000003oooooooooooooool20?nf`@03o`00003o
]/40okK100@0okK13?l000050?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/401P3o
]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400P3o
]/401@000000okK10?nf`@3o]/7o00000080okK100Ko00000?nf`@3o]/7o00000?nf`Ol000020?nf
`@05o`00003o]/40okK10?nf`Ol00000303o]/401_l00000okK10?nf`Ol00000okK1o`0000;ooooo
00Go0000ooooool0003oooooo`000002ooooo`0300000?ooool0000000?ooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02Cooooo00?o003o0?nf`@3o]/404@3o]/43o`00o`@0okK10ol00?lN0?nf`@03o`00
o`3o]/40okK100`0okK100?o003o0?nf`@3o]/401P3o]/45o`0000P0okK11Ol000000`3o]/7ooooo
ooooo`06ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Dooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`020?nf`@03o`00003o]/40okK10080okK10ol0000<0?nf`@;o0000103o]/400ol00000okK1
0?nf`@030?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@050?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1o`0000020?nf`@06
o`00003o]/40okK1o`00003o]/7o00000P3o]/401Ol00000okK10?nf`@3o]/7o000000`0okK100Ko
00000?nf`@3o]/7o00000?nf`Ol00002ooooo`05o`000?oooooo0000ooooool000000_ooool00`00
003ooooo00000003ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool03oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`03o`00o`3o]/40okK10100
okK10_l00?l20?nf`@03o`00o`3o]/40okK100D0okK10ol00?lL0?nf`@03o`00o`3o]/40okK100/0
okK100?o003o0?nf`@3o]/401`3o]/43o`0000T0okK11Ol000000`3o]/7oooooooooo`06ooooo`03
o`00oooooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool00oooool00`00003oooooooooo`020?nf`@04
o`00003o]/40okK10?nf`@;o00004@3o]/42o`0000<0okK10_l000040?nf`@030000003o]/40okK1
00H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK1
0080okK100@000000?nf`@3o]/7o00000`3o]/400ol00000okK1o`0000020?nf`@04o`00003o]/40
okK1o`0000<0okK100?o00000?nf`@3o]/40203o]/401ol00000okK10?nf`@3o]/7o00000?nf`Ol0
00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00<00000ooooo`0000000oooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool08_ooool00ol00?oooooo0?nf`@0?0?nf`@;o003o1@3o]/400ol00?l0
okK10?nf`@070?nf`@03o`00o`3o]/40okK101X0okK100?o003o0?nf`@3o]/402P3o]/400ol00?l0
okK10?nf`@050?nf`@?o003o00<0okK1o`00o`3o]/402@3o]/43o`0000<0okK11oooool00ol00?oo
ooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00?ooooo00H00000oooooooooooooooo0?nf`Ol00003
0?nf`@03o`00003o]/40okK100L0okK11?l000080?nf`@03o`00003o]/40okK10080okK100?o0000
0?nf`@3o]/400P3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/401@3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK1o`0000<0okK100Ko
00000?nf`@3o]/7o00000?nf`Ol000020?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o
]/401P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Go00000?nf`Ol0003oooooo`000002
ooooo`03o`000?ooool0000000;ooooo00D00000oooooooooooooooo00000004ooooo`0300000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08_ooool0
0ol00?l0okK10?nf`@0>0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/401`3o]/40
0ol00?l0okK10?nf`@0J0?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/40103o]/40
0ol00?l0okK10?nf`@020?nf`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/400`3o]/47
ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0B
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00_ooool01P00003ooooooooooooo
ool0okK1o`0000@0okK100?o00000?nf`@3o]/400`3o]/44o`0000@0okK11?l000040?nf`@;o0000
103o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100H0okK100?o00000000003o]/40
0`3o]/400`000000okK10?nf`@060?nf`@050000003o]/40okK10?nf`@0000000`3o]/401?l00000
okK10?nf`Ol000020?nf`@04o`00003o]/40okK1o`000080okK100?o00000?nf`@3o]/400P3o]/43
o`000080okK10ol000040?nf`@08o`00003o]/40okK1o`00003o]/7o0000ooooool00002ooooo`03
o`000?ooool0000000;ooooo00D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool00ol00?oo
oooo0?nf`@0>0?nf`@03o`00o`3o]/40okK100L0okK100?o003o0?nf`@3o]/40203o]/400ol00?l0
okK10?nf`@0J0?nf`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/400`3o]/400ol00?l0
okK10?nf`@030?nf`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/40103o]/45ooooo`03
o`00oooooooooooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool00_ooool01@00003ooooooooooooooooo0000
00@0okK100Co00000?nf`@3o]/40okK10ol0000<0?nf`@;o0000103o]/400ol00000okK10?nf`@02
0?nf`@05o`00003o]/40okK10?nf`@0000002@3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100D0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`Ol000030?nf`@04o`00
003o]/40okK1o`000080okK10_l000000`3o]/7o0000o`0000050?nf`@;o00001`3o]/400ol00000
okK1o`0000020?nf`@03o`000?oooooo000000;ooooo00?o0000ooooo`0000000_ooool01@00003o
ooooooooooooool0000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Qooooo`03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o
]/401`3o]/400ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK101X0okK11?l00?l60?nf`@03
o`00o`3o]/40okK10080okK100?o003o0?nf`@3o]/401@3o]/400ol00?l0okK10?nf`@070?nf`@03
o`00o`3o]/40okK100D0okK11?ooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00;o
oooo00D00000ooooooooooooooooo`0000040?nf`@05o`00003o]/40okK10?nf`Ol000004@3o]/40
0ol00000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`Ol00000103o]/400`000000okK10?nf
`@070?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@020?nf`@040000003o]/40okK1o`0000<0okK100Co00000?nf`@3o]/7o00000`3o]/400ol00000
okK10?nf`@02o`0000T0okK10ol000001`3o]/7o00000?nf`@3o]/7o00000?nf`Ol000000_ooool0
0ol0003ooooo00000002ooooo`0500000?ooooooooooooooo`0000001Oooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo00?o003o
0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK100T0okK100?o003o
0?nf`@3o]/407@3o]/42o`00o`D0okK11?l00?l80?nf`@03o`00o`3o]/40okK100H0okK100?o003o
0?nf`@3o]/401P3o]/44ooooo`03o`00oooooooooooo01gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Aooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00_ooool0
1P00003oooooooooooooool0okK1o`0000<0okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@_o
0000103o]/42o`0000<0okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@03o`00003o]/40okK1
00H0okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@050?nf`@030000003o]/40okK1
0080okK100@000000?nf`@3o]/7o00000`3o]/401?l00000okK10?nf`Ol000030?nf`@04o`00003o
]/40okK10?nf`@?o00000P3o]/44o`0000<0okK100Co00000?nf`@3o]/7o00000P3o]/400ol0003o
ooooo`000002ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool00oooool00`00
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023o
oooo00?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100X0
okK100?o003o0?nf`@3o]/407P3o]/47o`00o`X0okK10_l00?l60?nf`@;o003o2@3o]/42ooooo`03
o`00oooooooooooo01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Cooooo00<00000ooooooooool00_ooool01P00003oooooooooooooool0okK1
o`0000<0okK100Co00000?nf`@3o]/7o0000103o]/400ol00000okK10?nf`@090?nf`@03o`00003o
]/40okK10080okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK100<0okK1
00<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100D0okK1
00D000000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK100;o00000P3o]/42o`000004
0?nf`Ol0003o0000o`0000@0okK10_l000040?nf`@?o000000<0okK1o`000?l000000P3o]/401?l0
0000okK10?nf`Ol00002ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo023ooooo00?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40
okK100X0okK100?o003o0?nf`@3o]/409@3o]/400ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40
okK10080okK100?o003o0?nf`@3o]/402@3o]/400ooooooo003oooooo`0Pooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04Oooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo00;ooooo00D00000ooooooooool0okK1o`0000030?nf`@05o`00003o]/40okK10?nf`Ol00000
0`3o]/400ol00000okK10?nf`@0;0?nf`@03o`00003o]/40okK10080okK100Go00000?nf`@3o]/40
okK1o`0000030?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/401@3o]/400`000000
okK10?nf`@060?nf`@030000003o]/40okK100D0okK100D000000?nf`@3o]/40okK1000000030?nf
`@05o`00003o]/40okK10?nf`Ol000000`3o]/401?l00000okK10?nf`@3o]/44o`000080okK11?l0
00030?nf`@05o`00003o]/40okK10?nf`Ol000000P3o]/401?l0003oooooooooo`000003ooooo`05
00000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo023ooooo00?o003o0?nf`@3o]/402P3o]/43o`0000d0
okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@0U0?nf`@;o003o2P3o]/401?l00?l0
okK10?nf`Ol00?l;0?nf`@;o003o8_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00<00000ooooooooool01Oooool01@00003oooooooooooooool0000000?ooooo00<0okK1
o`00003o]/400P3o]/401?l00000okK10?nf`Ol000030?nf`@03o`00003o]/40okK100d0okK100Go
00000?nf`@3o]/40okK1o`0000030?nf`@05o`00003o]/40okK10?nf`Ol000001@3o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@020?nf`@050000003o]/40okK10?nf`Ol000000`3o]/401?l00000okK10?nf`@3o]/42
o`0000D0okK10_l000060?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/401?l00000okK1oooo
o`000002ooooo`0500000?ooooooooooooooo`0000001Oooool00`00003oooooooooo`0Aooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01oooooo00?o003o0?nf`@3o]/40
2P3o]/45o`0000Co003o2@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK102L0okK1
0ol00?l70?nf`@?o003o2`3o]/401?l00?l0okK10?nf`@3o]/4Qooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00;o
oooo00D00000ooooooooool0okK1o`0000030?nf`@04o`00003o]/40okK1o`0000<0okK100?o0000
0?nf`@3o]/400P3o]/49o`0000@0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@05o`00003o
]/40okK10?nf`Ol00000103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100P0okK1
00?o00000?nf`@3o]/40103o]/42000000<0okK100@00000o`00003o]/40okK10_l000020?nf`@?o
00000P3o]/45o`0000H0okK10_l000020?nf`@;o00000P3o]/42o`000080okK100D00000oooooooo
oooooooo00000002ooooo`0300000?l0003ooooo00Cooooo00<00000ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`030?nf`Ol00?l0okK100X0
okK100?o003oo`000?l000000ol000040?nf`@;o003o1`3o]/400ol00?l0okK10?nf`@0;0?nf`@03
o`00o`3o]/40okK102T0okK11ol00?l20?nf`@Co003o1`3o]/400ol00?l0okK10?nf`@020?nf`B7o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool00_ooool01@00003ooooo0?nf`@3o]/7o000000<0okK100Co00000?nf
`@3o]/7o00000`3o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK100H0okK100Go0000
0?nf`@3o]/40okK1o`0000030?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/400ol00000okK1
0?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/402@3o]/400`000000okK1
0?nf`@050?nf`@8000000`3o]/4010000000okK10?nf`@3o]/42o`0000<0okK10ol000040?nf`@Ko
00000`3o]/400ol00000okK10?nf`@02o`0000<0okK100D000000?nf`Ooooooooooo00000003oooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Nooooo`030?nf`Ol00?l0okK100T0okK100?o003o0?nf`Ol0
00001?l000060?nf`@;o003o1@3o]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK103H0
okK11ol00?l60?nf`B3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
00000?oooooooooo00Cooooo00D00000oooooooooooooooo00000002ooooo`030?nf`Ol00000okK1
0080okK100Co00000?nf`@3o]/7o00000`3o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40
okK100P0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@05o`00003o]/40okK10?nf`Ol00000
0P3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
2`3o]/42000000L0okK100D000000?nf`@3o]/40okK1000000040?nf`@?o00000`3o]/44o`0000H0
okK10ol000000`3o]/7o0000o`0000040?nf`@050000003o]/40okK10?nf`@0000000oooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool07Oooool30?nf`@03o`00o`3o]/40okK100D0okK10_l00?l30?nf`@?o
00002@3o]/42o`00o`040?nf`Ol0003o0000o`0000d0okK100?o003o0?nf`@3o]/40@`3o]/4Poooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`04oooo
o`0600000?ooooooooooooooo`00003ooooo0P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK1
00Co00000?nf`@3o]/7o0000103o]/400ol00000okK10?nf`@0:0?nf`@05o`00003o]/40okK10?nf
`Ol000000`3o]/401?l00000okK10?nf`Ol000030?nf`@05o`00003o]/40okK10?nf`@0000001@3o
]/400`000000okK10?nf`@0=0?nf`@8000001P3o]/401`000000okK10?nf`@3o]/400000o`000000
0000103o]/400ol00000okK10?nf`@040?nf`@Ko00000`3o]/401?l00000okK10?nf`@3o]/420000
0005o`00003o]/40okK10?nf`Ol000000oooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07Oooool30?nf
`@03o`00o`3o]/40okK100@0okK100?o003o0?nf`@3o]/40103o]/400ol00?l0okK10?nf`@0:0?nf
`@Go0000303o]/400ol00?l0okK10?nf`@050?nf`@L0oooo=`3o]/4Pooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`04ooooo`0600000?oooooooooo
ooooo`00003ooooo0P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Co00000?nf`@3o]/7o
0000103o]/400ol00000okK10?nf`@0:0?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/401?l0
0000okK10?nf`Ol000030?nf`@05o`00003o]/40okK10?nf`@0000001@3o]/400`000000oooo0?oo
o`040?ooo`/0okK100<000000?nf`@3o]/40103o]/400ol0000000000?nf`@030?nf`@040000003o
]/40okK10?nf`@Oo00001P3o]/43o`0000<0okK100<000000?nf`@3o]/400P3o]/42000000050?nf
`Oooooooooooooooo`0000001_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01gooooo0`3o]/400ol00?l0okK10?nf`@030?nf`@03o`00
o`3o]/40okK100D0okK100?o003o0?nf`@3o]/402P3o]/45o`0000`0okK100Co003o0?nf`@3o]/40
okK13`3ooold0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
00000?oooooooooo00Cooooo00H00000oooooooooooooooo00000?ooool20?nf`@04o`00003o]/40
okK1o`0000<0okK100Co00000?nf`@3o]/7o0000103o]/400ol00000okK10?nf`@0:0?nf`@05o`00
003o]/40okK10?nf`Ol000000`3o]/401?l00000okK10?nf`Ol000030?nf`@06o`00003o]/40okK1
0?nf`@000000okK1103oool00`000000oooo0?ooo`080?ooo`P0okK100<000000?nf`@3o]/401@3o
]/400`000000okK10?nf`@020?nf`@<000001`3o]/46o`0000@0okK10P0000040?nf`@030000003o
]/40okK10080okK100?ooooo00000?ooool01Oooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo103o]/400ol00?l0okK10?nf`@02
0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/402P3o]/45o`0000`0okK100?o003o
0?nf`@3oool04P3ooolb0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo00Gooooo00D00000oooooooooooooooo000000030?nf`@04o`00003o
]/40okK1o`000080okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK100/0
okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@04o`00003o]/40okK1o`0000<0okK100Go0000
0?nf`@3o]/40okK1000000050?ooo`030000003oool0oooo00X0oooo1`3o]/400`000000okK10?nf
`@050?nf`@8000001@3o]/43000000/0okK10`0000050?nf`@03o`00003o]/40okK100<0okK100<0
0000ooooooooool01Oooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01cooooo103o]/401Ol00?l0okK10?nf`@3o]/7o003o00T0okK100?o
003o0?nf`@3o]/402`3o]/43o`0000d0okK100?o003o0?ooo`3oool0503oool`0?nf`Aoooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Gooooo00D0
0000oooooooooooooooo000000030?nf`@04o`00003o]/40okK1o`000080okK100Go00000?nf`@3o
]/40okK1o`0000030?nf`@03o`00003o]/40okK100/0okK100Go00000?nf`@3o]/40okK1o`000003
0?nf`@04o`00003o]/40okK1o`0000<0okK100Go00000?nf`@3oool0oooo000000050?ooo`030000
003oool0oooo00`0oooo1P3o]/401000003o00000000000000050?nf`@8000001P3o]/4200000003
o`0000000000000000@0000000?o00000000003o]/401@3o]/42000000@0okK10P000006ooooo`80
00005oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`D0okK1
00Co003o0?nf`@3o]/7o003o2@3o]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/7o003o00`0
okK100<0ooooo`00o`3oool05`3oool_0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo00Gooooo00D00000oooooooooooooooo000000030?nf
`@04o`00003o]/40okK1o`000080okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o
]/40okK100/0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@04o`00003o]/40okK1o`0000<0
okK100Go00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00h0oooo203o]/420000
00D0okK10`00000A0?nf`@<00000103o]/42000000<0okK11?ooool00`00003oooooooooo`0Goooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo1`3o]/42o`00o`/0
okK100?o003o0?nf`@3o]/402P3o]/400ol00?l0okK1o`00o`0;0?nf`@030?ooool00?l0oooo01T0
oooo;P3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003o
ooooooooo`04ooooo`0500000?ooooooooooooooo`0000000`3o]/401?l00000okK10?nf`Ol00003
0?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/402P3o]/400ol00000okK10?nf
`@020?nf`@04o`00003o]/40okK1o`0000<0okK100Co00000?nf`@3o]/7o00000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0100oooo2@3o]/400`000000okK10?nf`@050?nf`@L0
00000P3o]/48000000H0okK100<000000?nf`@3o]/400`3o]/43ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool70?nf`@;o003o
2`3o]/400ol00?l0okK10?nf`@090?nf`@04o`00o`3o]/40okK1o`00o`X0okK10P3oool00ol00?l0
oooo0?ooo`0I0?ooobd0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00<00000ooooooooool01?ooool01@00003ooooooooooooooooo000000<0okK100Co00000?nf
`@3o]/7o00000`3o]/401?l00000okK10?nf`Ol000030?nf`@03o`00003o]/40okK100X0okK100?o
00000?nf`@3o]/400P3o]/401?l00000okK10?nf`Ol000030?nf`@04o`00003o]/40okK1o`0000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`T0okK100@00000o`000000
000000002P3o]/42000000/0okK10P0000000ol00000okK10?nf`@040?nf`@;ooooo00<00000oooo
ooooool06Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`L0
okK10_l00?l;0?nf`@03o`00o`3o]/40okK100L0okK10_l00?l40?nf`@03o`00o`3o]/40okK100H0
okK10`3oool00ol00?l0oooo0?ooo`0J0?ooob`0okK17_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo00<00000ooooooooool01?ooool01@00003oooooooooooooool00000
00<0okK100Co00000?nf`@3o]/7o00000`3o]/401?l00000okK10?nf`Ol000040?nf`@03o`00003o
]/40okK100T0okK100?o00000?nf`@3o]/400P3o]/401?l00000okK10?nf`Ol000030?nf`@04o`00
003o]/40ooooo`0000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo``0
okK10`00000A0?nf`@<000002@3o]/400oooool00000ooooo`0Kooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01_ooooo1`3o]/401?l00?l0okK1o`00ool00?l90?nf`@03
o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/400`3o]/4H0000oa80oooo;03o]/4Nooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`04ooooo`05
00000?ooooooooooooooo`0000000`3o]/401?l00000okK10?nf`Ol000030?nf`@05o`00003o]/40
okK10?nf`Ol00000103o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK10080okK100Go
00000?nf`@3o]/40okK1o`0000030?nf`@04o`00003o]/40ooooo`0000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`L000000`3oool?0?nf`@<000002P3o]/44000000/0
okK10P00000Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo
1`3o]/401?l00?l0okK10?nf`@3o]/42o`00o`P0okK100?o003o0?nf`@3o]/400`3o]/42o`00o`80
okK110000?l00`3o]/7o003o0?nf`@050?nf`@@0oooo00?o003o0?ooo`3oool02@3oool50000o`h0
oooo:`3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003o
ooooooooo`04ooooo`0600000?ooooooooooooooo`3o]/4000000`3o]/401?l00000okK10?nf`Ol0
00030?nf`@04o`00003o]/40okK1o`0000D0okK10ol000030?nf`@?o00001@3o]/401?l00000okK1
0?nf`Ol000030?nf`@04o`00003oool0ooooo`0000@0oooo00?o00000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo1000000A0?nf`@X000003P3o]/400`00
0000okK1ooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_o
oooo1`3o]/400ol00?l0okK10?nf`@030?nf`@03o`00o`3o]/40okK100D0okK10ol000000`3o]/7o
003oo`00o`040000o`H0okK100?o003o0?nf`@3o]/400P3o]/440?ooo`03o`00o`3oool0oooo00l0
oooo10000?l;0?ooob/0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00<00000ooooooooool01?ooool01P00003oooooooooooooool0okK1000000<0okK100Co0000
0?nf`@3o]/7o00000`3o]/401Ol00000okK10?nf`@3o]/7o000000L0okK10ol000060?nf`@;o0000
0`3o]/401Ol00000okK10?nf`@3o]/7o00000080oooo00Go00000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00L0oooo00?o00000?ooo`3oool02P3oool3000002<0okK10P0000001?l0
0000okK10?nf`@3o]/4Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01[ooooo203o]/400ol00?l0okK10?nf`@040?nf`@Co003o0P3o]/45o`0000030000o`3o]/40okK1
00T0okK100?o003o0?nf`@3o]/400P3o]/430?ooo`03o`00o`3oool0oooo01@0oooo0P000?l90?oo
ob/0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00<00000oooo
ooooool01Oooool01Ol0003ooooo0?nf`@3o]/40000000<0okK100Co00000?nf`@3o]/7o00000`3o
]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK100/0okK10_l000050?nf`@04o`00003o
]/40okK1o`0000<0oooo00Go00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0303oool20?nf`@@000007P3o]/400`000000okK10?nf`@040?nf`Ago
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool80?nf`@03o`00
o`3o]/40okK100P0okK10_l00?l5o`000003o`00o`3o]/40okK100T0okK100Co003o0?nf`@3o]/40
okK10`3oool00ol00?l0oooo0?ooo`0G0?ooo`80003o203ooolZ0?nf`Agooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Aooooo`0300000?oooooooooo00Cooooo00<00000ooooo`3o
]/400P3o]/401@000000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o]/40okK1o`000004
0?nf`@?o00002@3o]/400ol00000okK10?nf`@040?nf`@04o`00003o]/40okK1o`0000<0oooo00Go
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3P3oool50?nf`@<00000603o]/43000000L0okK17Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Jooooo`P0okK100?o003o0?nf`@3o]/40203o]/420000o`Go000000<0
okK1o`00o`3o]/402@3o]/401?l00?l0okK10?nf`@3o]/420?ooo`03o`00o`3oool0oooo01X0oooo
0P000?l60?ooobX0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo
00<00000ooooooooool01?ooool00`00003ooooo0?nf`@020?nf`@050000003o]/40okK10?nf`Ol0
00000`3o]/401?l00000okK10?nf`@3o]/42o`0000D0okK100?o00000?nf`@3o]/400`3o]/43o`00
00D0okK10_l000020?nf`@05o`00003o]/40oooo0?ooool00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool80?nf`@80000000?o0000
0000003o]/403`3o]/4200000003o`0000000000okK100T0okK17Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Jooooo`P0okK100?o003o0?nf`@3o]/401@3o]/430000
o`<0okK10ol000030?nf`@03o`00o`3o]/40okK100L0okK100Co003o0?nf`@3o]/40oooo0_l00?lO
0?ooo`80003o1@3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0A
ooooo`0300000?oooooooooo00Cooooo00<00000ooooo`3o]/400P3o]/401@000000okK10?nf`@3o
]/7o000000@0okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@Ko00001`3o
]/400ol00000okK10?nf`@020?nf`@05o`00003oool0oooo0?ooool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool;0?nf`A000000
3P3o]/4Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo203o
]/400ol00?l0okK10?nf`@040?nf`@03o`00o`3o]/40okK100/0okK11?l00?l50?nf`@Co003o8`3o
ool20000o`<0oooo:@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Ooo
ool00`00003oooooooooo`05ooooo`030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1
o`0000030?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/403@3o]/400ol00000okK1
0?nf`@020?nf`@03o`00003o]/40oooo0080oooo00Go00000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04@3ooolY0?nf`Agooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool06_ooool80?nf`@03o`00o`3o]/40okK10080okK1
0P000?lB0?nf`@Ko003o0P3o]/4V0?ooo`030000ool00?l0003o02T0okK17Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<00000ooooooooool01?ooool00`000000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100Go00000?nf`@3o]/40okK1o`0000050?nf`@;o
00002`3o]/42o`0000@0okK100?o00000?nf`@3o]/400P3oool01Ol00000oooo0?ooo`3ooooo0000
00D0oooo00<000000?ooo`3oool01@3oool00ol00000oooo0?ooo`0B0?ooobT0okK17Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`P0okK100?o003o0?nf`@3o
]/400P000?lI0?nf`@03o`00o`3o]/40okK102T0oooo0P000?lW0?nf`Agooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Booooo`0300000?oooooooooo00Gooooo00<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`Ol000001P3o]/44o`00
00<0okK11?l000040?nf`@;o00000`3o]/400`3ooooo00000?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooobT0okK17Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`T0okK10P000?lJ0?nf`@03
o`00o`3o]/40okK102/0oooo00<0okK10000o`3o]/409@3o]/4Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04_ooool00`00003oooooooooo`05ooooo`030000003o]/40okK10080
okK100<000000?nf`@3o]/400`3o]/401?l00000okK10?nf`@3o]/42o`0000P0okK10ol000060?nf
`@;o0000103o]/400`3ooooo00000?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooobP0okK17Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Jooooo`P0okK100<0003oo`00o`3o]/406@3o]/401?l00?l0
okK10?nf`@3o]/4[0?ooo`80okK100<0003o0?nf`@3o]/408`3o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04_ooool00`00003oooooooooo`05ooooo`030?nf`@000000okK1
00<0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@;o00003@3o]/42o`00
00H0okK100?o00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0503ooolX0?nf`Agooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06Oooool80?nf`@040000o`3o]/40okK1o`00oaT0okK100Co003o0?nf
`@3o]/40okK1:`3oool30?nf`@030000o`3o]/40okK10280okK17Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01?ooooo00<00000ooooooooool00oooool20?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@040?nf`@;o00002P3o]/40
0ol00000okK10?nf`@050?nf`@03o`00003oool0oooo0080oooo00?o00000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo:03o]/4Mooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo1P3o]/420000o`<0okK10_l00?lG0?nf
`@03o`00o`3o]/40okK10080okK1:`3oool40?nf`@80003o8P3o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04oooool00`00003oooooooooo`03ooooo`<0okK100?o00000?nf
`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@;o00001P3o]/4:o`0000D0okK10ol00000103o
]/40oooo0?ooo`3oool2000000@0oooo0P0000080?ooo`03o`00003oool0oooo01D0oooo:03o]/4M
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo1@3o]/400`00
0?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/400P3o]/4[0?oo
o`H0okK10P000?lP0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo0`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00<0okK10_l0000A0?nf`@;o0000103o]/400`3oool00000000000050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool05P3ooolX0?nf`Agooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06Oooool40?nf`@030000o`3o]/40okK100L0okK100?o003o0?nf`@3o
]/404@3o]/42o`00o`D0okK1:`3oool80?nf`@030000o`3o]/40okK101d0okK17Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool00_ooool40?nf`@03
0000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/42o`0000d0okK10_l000060?nf`@03
o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooobP0
okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`80okK1
00<0003o0?nf`@3o]/402@3o]/400ol00?l0okK10?nf`@0>0?nf`@;o003o1`3o]/4[0?ooo`T0okK1
00<0003o0?nf`@3o]/40703o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
5Oooool00`00003oooooooooo`02ooooo`@0okK100<000000?nf`@3o]/40103o]/400`00003o0000
000000050?nf`@Ko00000`3o]/44o`0000L0okK100<000000?ooo`3oool0103oool2000000T0oooo
00<000000?ooo`3oool05`3ooolX0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06_ooool00`000?oo003o0?nf`@0<0?nf`@?o003o303o]/400ol00?l0okK10?nf
`@070?nf`B/0oooo2P3o]/400`000?l0okK10?nf`@0K0?nf`Agooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Eooooo`0300000?oooooooooo00;ooooo1@3o]/400ol00000okK10?nf
`@060?nf`@030000003o]/40okK100P0okK10ol0000:0?nf`@030000003o]/40oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0H0?ooobP0okK17Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Iooooo`030000o`3o]/40okK10100okK10_l00?l7
0?nf`@?o003o2`3o]/4Y0?ooo``0okK100?o003o0?nf`@3o]/406P3o]/4Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05_ooool01000003oooooooooooooool60?nf`@030000003o
]/40okK100H0okK10P00000B0?nf`@<000000`3o]/430?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0603ooolY0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool06?ooool00`000?oooooo0?nf`@0C0?nf`@Oo003o3P3o]/4Y0?ooo`d0okK100<0003o
0?nf`@3o]/406@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool0
1000003oooooooooooooool70?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/403@3o
]/400ol0000000000?nf`@050?nf`@80oooo00<000000?ooo`3oool0203oool00ol00000oooo0?oo
o`0I0?ooobT0okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0G
ooooo`030000oooooooooooo02T0okK1:@3oool>0?nf`@030000o`3o]/40okK101P0okK17Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00<00000o`000?ooool0203o]/42
000000P0okK100<00000o`0000000000300000080?nf`@8000002P3oool2000001/0oooo:@3o]/4M
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Kooooo00Co003ooooo
oooooooooooo:@3o]/4Y0?ooo`l0okK100<0003o0?nf`@3o]/405`3o]/4Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06?ooool00`00003ooooo0?nf`@090?nf`@8000006`3o]/42
000000/0oooo00<000000?ooo`3oool06`3ooolY0?nf`Agooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool05Oooool00`000?ooooooooooo`02ooooobX0okK19`3ooolA0?nf
`@030000o`3o]/40okK101H0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Wooooo00<000000?nf`@3o]/402P3o]/42000001P0okK100@000000?nf`@3o]/40okK12@3oool0
0ol00000oooo0?ooo`0K0?ooobX0okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Eooooo`030000oooooooooooo00;ooooo:P3o]/4W0?oooa80okK100?o003o0?nf
`@3o]/405@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00`00
0000okK10?nf`@0;0?nf`@030000003o]/40okK10180okK10P0000000ol00000okK10?nf`@020?nf
`@L0oooo0P00000N0?ooobX0okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Dooooo`030000oooooooooooo00?ooooo:`3o]/4U0?oooa<0okK100<0003o0?nf`@3o
]/405@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00`3o]/7o
00000?nf`@0<0?nf`@03o`0000000000000000h0okK10`0000080?nf`@D0oooo00<000000?ooo`3o
ool07@3oool[0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
4oooool00`000?ooooooooooo`05ooooob`0okK18`3ooolD0?nf`@030000o`3o]/40okK101@0okK1
7Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00<0okK10000003o]/40
3P3o]/4>000000d0okK10P3oool00`000000oooo0?ooo`0N0?ooob/0okK17Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Kooooo;03o
]/4R0?oooaD0okK100<0003o0?nf`@3o]/404`3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06oooool20?nf`@030000003o]/40okK102L0okK100<0oooo0000003oool07`3o
ool[0?nf`Akooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool04Oooool0
0`000?ooooooooooo`07ooooobd0okK1803ooolG0?nf`@030000o`3o]/40okK10180okK17_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo0`3o]/400`00003o00000000000V
0?nf`@03o`00003oool0oooo01h0oooo;03o]/4Nooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo017ooooo00<0003oooooooooool01oooool^0?nf`Ah0oooo6@3o]/400`00
0?l0okK10?nf`@0A0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Koooo
o`H0okK100<000000?nf`@3o]/408@3o]/4200000080okK17P3oool]0?nf`Akooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool04?ooool00`000?ooooooooooo`08ooooobl0
okK1703ooolK0?nf`@030000o`3o]/40okK10100okK17_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo1`3o]/42000001l0okK10P0000050?nf`A`0oooo;P3o]/4Nooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00oooooo00<0003oooooooooool0
2_ooool_0?nf`AT0oooo7P3o]/400`000?l0okK10?nf`@0?0?nf`Akooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Looooo`P0okK10P00000J0?nf`@80000000?o00000?nf`@3o]/40
1P3o]/4I0?oooc00okK17_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0>ooooo`030000oooooooooooo00_ooooo<@3o]/4E0?ooob40okK100<0003o0?nf`@3o]/403@3o
]/4Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool:0?nf`@<00000503o
]/43000000d0okK15@3ooola0?nf`Aoooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool03_ooool00`000?ooooooooooo`0;oooooc<0okK14@3ooolS0?nf`@030000o`3o]/40
okK100d0okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo3@3o]/43
000000h0okK10`00000B0?nf`A40oooo<`3o]/4Oooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00gooooo00<0003oooooooooool03Ooooold0?nf`@d0oooo9P3o]/400`00
0?l0okK10?nf`@0<0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Moooo
o`l0okK13P00000G0?nf`@d0oooo=@3o]/4Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo00gooooo00<0003oooooooooool03Ooooolh0?nf`@D0oooo:`3o]/400`000?l0
okK10?nf`@0:0?nf`B3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0MooooocP0
okK11@3ooolh0?nf`B3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
3?ooool00`000?ooooooooooo`0>ooooofP0okK100<0003o0?nf`@3o]/402P3o]/4Pooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07Ooooome0?nf`B3ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`0@ooooofP0okK100<0
003o0?nf`@3o]/402@3o]/4Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_oo
oomd0?nf`B3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02oooool0
0`000?ooooooooooo`0@ooooofP0okK100?o003o0?nf`@3o]/40203o]/4Qooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07_oooomc0?nf`B7ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`0BooooofL0okK100<0003o0?nf
`@3o]/40203o]/4Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07ooooomb0?nf
`B7ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02_ooool00`000?oo
ooooooooo`0CooooofL0okK100<0003o0?nf`@3o]/401P3o]/4Rooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool08?oooom`0?nf`B;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool02Oooool00`000?ooooooooooo`0DooooofP0okK100<0003o0?nf`@3o]/40
103o]/4Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?oooom_0?nf`B?ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02Oooool00`000?oooooooooo
o`0EooooofL0okK100<0003o0?nf`@3o]/40103o]/4Sooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool08Ooooom^0?nf`B?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool02?ooool00`000?ooooooooooo`0FooooofP0okK100<0003o0?nf`@3o]/400P3o]/4T
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Ooooom]0?nf`BCooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00`000?ooooooooooo`0Foooo
ofP0okK100<0003o0?nf`@3o]/400P3o]/4Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool08Ooooom]0?nf`BCooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool01oooool00`000?ooooooooooo`0HooooofL0okK100<0003o0?nf`@3o]/400P3o]/4Tooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08_oooom/0?nf`BCooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool01oooool00`000?ooooooooooo`0IooooofL0okK1
00<0003o0?nf`@3o]/409Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo
JP3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00<0
003oooooooooool06OoooomW0?nf`@030000o`3o]/7ooooo02Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0SooooofT0okK19_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`07ooooo`030000oooooooooooo01[oooooI`3o]/400`000?ooooooooooo`0T
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oooomX0?nf`BKooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`0Koooo
ofL0okK100<0003oooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02CoooooI`3o]/4Wooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Ko
oooo00<0003oooooooooool07?oooomV0?nf`@030000oooooooooooo02Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0UooooofH0okK19oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo01goooooI03o]/400oooool0003o
ooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_oooomT0?nf`BSooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00`000?oooooooooo
o`0Nooooof80okK10_ooool00`000?ooooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09ooooomR0?nf`BWooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool01Oooool00`000?ooooooooooo`0Pooooof00okK11?ooool00`000?ooooooooooo`0S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?oooomP0?nf`B[ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0Poooo
oel0okK11Oooool00`000?ooooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:?oooomO0?nf`B_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool01?ooool00`000?ooooooooooo`0Roooooeh0okK11_ooool00`000?ooooooooooo`0Rooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:OoooomN0?nf`B_ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0Soooooe`0okK1
1oooool00`000?ooooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:_oooomL0?nf`Bcooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?oo
ool00`000?ooooooooooo`0ToooooeX0okK12?ooool00`000?ooooooooooo`0Rooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0:ooooomJ0?nf`Bgooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0UoooooeP0okK12Oooool0
0`000?ooooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?oooomH
0?nf`Bkooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`00
0?ooooooooooo`0VoooooeD0okK12oooool00`000?ooooooooooo`0Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0;OoooomE0?nf`C3ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0Woooooe<0okK13?ooool00`000?oo
ooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;_oooomC0?nf`C7o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?oooooo
ooooo`0Yoooooe00okK13Oooool00`000?ooooooooooo`0Rooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<?oooom@0?nf`C;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool01?ooool00`000?ooooooooooo`0Zooooodh0okK13_ooool00`000?oooooooooo
o`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Ooooom>0?nf`C?ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00`000?ooooooooooo`0/
oooood`0okK14?ooool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<_oooom<0?nf`CCooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool00oooool00`000?ooooooooooo`0]ooooodX0okK14Oooool00`000?ooooooooooo`0Qoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<ooooom:0?nf`CGooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00`000?ooooooooooo`0_ooooodH0
okK14oooool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=Ooooom60?nf`COooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
0oooool00`000?ooooooooooo`0`oooood@0okK15?ooool00`000?ooooooooooo`0Qooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0=_oooom40?nf`CSooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool00oooool00`000?ooooooooooo`0boooood00okK15_oo
ool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>?oo
oom00?nf`C[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool0
0`000?ooooooooooo`0dooooo`d0okK10ol0000/0?nf`ASooooo00<0003oooooooooool08Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo?03o]/4looooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo00<0003oooooooooool0=Oooool;0?nf
`@Go0000:P3o]/4Iooooo`030000oooooooooooo027ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0kooooocX0okK1?Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`03ooooo`030000oooooooooooo03Sooooo203o]/45o`0002P0okK16oooool00`000?oo
ooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_oooole0?nf`Coo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00`000?oooooo
ooooo`0kooooo`D0okK11Ol0000U0?nf`Akooooo00<0003oooooooooool08Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo047ooooo;`3o]/52ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00?ooooo00<0003oooooooooool0?_ooool30?nf`@?o00008`3o
]/4Qooooo`030000oooooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`14ooooobT0okK1AOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`03
ooooo`030000oooooooooooo047ooooo8`3o]/4Tooooo`030000oooooooooooo027ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`17ooooob<0okK1B?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`03ooooo`030000oooooooooooo04Cooooo7@3o]/4Woooo
o`030000oooooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:oooo
oad0okK1Boooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`03ooooo`03
0000oooooooooooo04Oooooo5`3o]/4Zooooo`030000oooooooooooo027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1=oooooaL0okK1C_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`03ooooo`030000oooooooooooo053ooooo103o]/4dooooo`030000
oooooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Fooooo`@0okK1
F?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`03ooooo`030000oooo
oooooooo08Sooooo00<0003oooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool0
0`000?ooooooooooo`28ooooo`030000oooooooooooo027ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00?ooooo00<0003oooooooooool0R?ooool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`03ooooo`030000oooooooooooo08Sooooo00<0003oooooooooool08Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01?ooool00`000?ooooooooooo`27ooooo`030000oooooooooooo027ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00Cooooo00<0003oooooooooool0Q_ooool00`000?oooooooooo
o`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000oooooooooooo08Kooooo00<0003o
ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`26oooo
o`030000oooooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0003ooooooooo
ool0Q_ooool00`000?ooooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000
oooooooooooo08Cooooo00<0003oooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Ooo
ool00`000?ooooooooooo`24ooooo`030000oooooooooooo02?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo00Gooooo00<0003oooooooooool0Q?ooool00`000?ooooooooooo`0Sooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`05ooooo`030000oooooooooooo08Cooooo00<0003oooooooooool08oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`23ooooo`030000oooooooooooo02?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00Kooooo00<0003oooooooooool0P_ooool00`000?oooooo
ooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo08;ooooo00<0
003oooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00`000?ooooooooooo`20
ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00<0003ooooo
ooooool0P?ooool00`000?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03
0000oooooooooooo083ooooo00<0003oooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
2?ooool00`000?ooooooooooo`1nooooo`030000oooooooooooo02Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00Sooooo00<0003oooooooooool0O_ooool00`000?ooooooooooo`0Vooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`08ooooo`030000oooooooooooo07kooooo00<0003oooooooooool09_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`1looooo`030000oooooooooooo
02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool0N_ooool00`000?oo
ooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0:ooooo`030000oooooooooooo07[ooooo
00<0003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02oooool00`000?oooooooooo
o`1hooooo`030000oooooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
okKo00004Ooooonfo`0000[ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.53846 .131 m
.55769 .12787 L
.57692 .12673 L
.59615 .12783 L
.61538 .1312 L
.62858 .13462 L
.63462 .13704 L
.65385 .14629 L
.66667 .15385 L
.67308 .15851 L
.6904 .17308 L
.69231 .17491 L
.70857 .19231 L
.71154 .19569 L
.72482 .21154 L
.73077 .21822 L
.74276 .23077 L
.75 .23743 L
.7659 .25 L
.76923 .25253 L
.78846 .26664 L
.79204 .26923 L
.80769 .28221 L
.81449 .28846 L
.82692 .3017 L
.83165 .30769 L
.84464 .32692 L
.84615 .32952 L
.85363 .34615 L
.86019 .36538 L
.86426 .38462 L
.86538 .39451 L
.86579 .40385 L
.86538 .42144 L
.86525 .42308 L
.86256 .44231 L
.8583 .46154 L
.85347 .48077 L
.84961 .5 L
.84821 .51923 L
.84976 .53846 L
.85338 .55769 L
.8575 .57692 L
.86079 .59615 L
.86248 .61538 L
.8622 .63462 L
.85979 .65385 L
.85518 .67308 L
.84843 .69231 L
.84615 .69777 L
.83869 .71154 L
.82692 .72934 L
.8258 .73077 L
.80824 .75 L
.80769 .75051 L
.78846 .76597 L
.7837 .76923 L
.76923 .77738 L
.75 .78614 L
.74386 .78846 L
.73077 .79203 L
.71154 .79596 L
.69231 .79853 L
.67308 .80048 L
.65385 .80339 L
.63875 .80769 L
.63462 .80973 L
.61538 .82212 L
.60943 .82692 L
.59615 .839 L
.58809 .84615 L
.57692 .85541 L
.56343 .86538 L
.55769 .86891 L
.53846 .87919 L
.52577 .88462 L
.51923 .88657 L
.5 .89108 L
.48077 .89341 L
.46154 .89343 L
.44231 .89112 L
.42308 .88662 L
.41639 .88462 L
.40385 .87922 L
.38462 .86878 L
.37922 .86538 L
.36538 .85468 L
.35589 .84615 L
.34615 .83617 L
.33818 .82692 L
.32692 .81334 L
.32255 .80769 L
.30769 .79104 L
.30512 .78846 L
.28846 .77502 L
.2785 .76923 L
.26923 .76413 L
.25 .75455 L
.24064 .75 L
.23077 .74431 L
.21154 .73166 L
.21033 .73077 L
.19231 .71476 L
.18925 .71154 L
.17387 .69231 L
.17308 .69116 L
.16294 .67308 L
.15467 .65385 L
.15385 .65161 L
.14962 .63462 L
.14653 .61538 L
.14515 .59615 L
.14502 .57692 L
.14537 .55769 L
.14525 .53846 L
.14393 .51923 L
.14137 .5 L
.13833 .48077 L
.13583 .46154 L
.13471 .44231 L
.13553 .42308 L
.1386 .40385 L
.14412 .38462 L
.15196 .36538 L
.15385 .36138 L
.1632 .34615 L
.17308 .33229 L
.17748 .32692 L
.19231 .30996 L
.19436 .30769 L
.21099 .28846 L
.21154 .28775 L
.225 .26923 L
.23077 .25921 L
.23629 .25 L
.24735 .23077 L
.25 .2261 L
.2601 .21154 L
.26923 .19982 L
.27618 .19231 L
.28846 .18103 L
.2987 .17308 L
.30769 .16756 L
.32692 .15771 L
.3364 .15385 L
.34615 .15131 L
.36538 .14765 L
.38462 .14609 L
.40385 .14641 L
.42308 .14797 L
.44231 .1496 L
.46154 .14975 L
.48077 .14713 L
.5 .14187 L
.51923 .13567 L
.52258 .13462 L
F
0 g
.53846 .131 m
.55769 .12787 L
.57692 .12673 L
.59615 .12783 L
.61538 .1312 L
.62858 .13462 L
.63462 .13704 L
.65385 .14629 L
.66667 .15385 L
.67308 .15851 L
.6904 .17308 L
.69231 .17491 L
.70857 .19231 L
.71154 .19569 L
.72482 .21154 L
.73077 .21822 L
.74276 .23077 L
.75 .23743 L
.7659 .25 L
.76923 .25253 L
.78846 .26664 L
.79204 .26923 L
.80769 .28221 L
.81449 .28846 L
.82692 .3017 L
.83165 .30769 L
.84464 .32692 L
.84615 .32952 L
.85363 .34615 L
.86019 .36538 L
.86426 .38462 L
.86538 .39451 L
.86579 .40385 L
.86538 .42144 L
.86525 .42308 L
.86256 .44231 L
.8583 .46154 L
.85347 .48077 L
.84961 .5 L
.84821 .51923 L
.84976 .53846 L
.85338 .55769 L
.8575 .57692 L
.86079 .59615 L
.86248 .61538 L
.8622 .63462 L
.85979 .65385 L
.85518 .67308 L
.84843 .69231 L
.84615 .69777 L
Mistroke
.83869 .71154 L
.82692 .72934 L
.8258 .73077 L
.80824 .75 L
.80769 .75051 L
.78846 .76597 L
.7837 .76923 L
.76923 .77738 L
.75 .78614 L
.74386 .78846 L
.73077 .79203 L
.71154 .79596 L
.69231 .79853 L
.67308 .80048 L
.65385 .80339 L
.63875 .80769 L
.63462 .80973 L
.61538 .82212 L
.60943 .82692 L
.59615 .839 L
.58809 .84615 L
.57692 .85541 L
.56343 .86538 L
.55769 .86891 L
.53846 .87919 L
.52577 .88462 L
.51923 .88657 L
.5 .89108 L
.48077 .89341 L
.46154 .89343 L
.44231 .89112 L
.42308 .88662 L
.41639 .88462 L
.40385 .87922 L
.38462 .86878 L
.37922 .86538 L
.36538 .85468 L
.35589 .84615 L
.34615 .83617 L
.33818 .82692 L
.32692 .81334 L
.32255 .80769 L
.30769 .79104 L
.30512 .78846 L
.28846 .77502 L
.2785 .76923 L
.26923 .76413 L
.25 .75455 L
.24064 .75 L
.23077 .74431 L
Mistroke
.21154 .73166 L
.21033 .73077 L
.19231 .71476 L
.18925 .71154 L
.17387 .69231 L
.17308 .69116 L
.16294 .67308 L
.15467 .65385 L
.15385 .65161 L
.14962 .63462 L
.14653 .61538 L
.14515 .59615 L
.14502 .57692 L
.14537 .55769 L
.14525 .53846 L
.14393 .51923 L
.14137 .5 L
.13833 .48077 L
.13583 .46154 L
.13471 .44231 L
.13553 .42308 L
.1386 .40385 L
.14412 .38462 L
.15196 .36538 L
.15385 .36138 L
.1632 .34615 L
.17308 .33229 L
.17748 .32692 L
.19231 .30996 L
.19436 .30769 L
.21099 .28846 L
.21154 .28775 L
.225 .26923 L
.23077 .25921 L
.23629 .25 L
.24735 .23077 L
.25 .2261 L
.2601 .21154 L
.26923 .19982 L
.27618 .19231 L
.28846 .18103 L
.2987 .17308 L
.30769 .16756 L
.32692 .15771 L
.3364 .15385 L
.34615 .15131 L
.36538 .14765 L
.38462 .14609 L
.40385 .14641 L
.42308 .14797 L
Mistroke
.44231 .1496 L
.46154 .14975 L
.48077 .14713 L
.5 .14187 L
.51923 .13567 L
.52258 .13462 L
.53846 .131 L
Mfstroke
.2 g
.38462 .1728 m
.39978 .17308 L
.40385 .17338 L
.42308 .17581 L
.44231 .17878 L
.46154 .18022 L
.48077 .17815 L
.49932 .17308 L
.5 .17255 L
.51923 .16585 L
.53846 .15982 L
.55769 .15581 L
.57692 .1544 L
.59615 .15582 L
.61538 .16025 L
.63462 .16785 L
.6446 .17308 L
.65385 .17923 L
.66988 .19231 L
.67308 .19538 L
.68783 .21154 L
.69231 .21692 L
.70323 .23077 L
.71154 .24069 L
.72001 .25 L
.73077 .26002 L
.74266 .26923 L
.75 .27453 L
.76923 .28775 L
.77025 .28846 L
.78846 .30291 L
.7937 .30769 L
.80769 .32291 L
.81073 .32692 L
.82268 .34615 L
.82692 .35485 L
.83061 .36538 L
.83527 .38462 L
.83714 .40385 L
.83637 .42308 L
.83323 .44231 L
.82826 .46154 L
.82692 .46589 L
.8221 .48077 L
.81679 .5 L
.81467 .51923 L
.81659 .53846 L
.82118 .55769 L
.82627 .57692 L
.82692 .57922 L
.83001 .59615 L
.8319 .61538 L
.83158 .63462 L
.82885 .65385 L
.82692 .66275 L
.82331 .67308 L
.81454 .69231 L
.80769 .70379 L
.80201 .71154 L
.78846 .72663 L
.78398 .73077 L
.76923 .7421 L
.75623 .75 L
.75 .753 L
.73077 .76039 L
.71154 .76514 L
.69231 .76765 L
.67308 .76855 L
.65385 .76896 L
.64847 .76923 L
.63462 .77094 L
.61538 .7783 L
.60168 .78846 L
.59615 .79453 L
.58374 .80769 L
.57692 .81514 L
.56474 .82692 L
.55769 .83292 L
.53871 .84615 L
.53846 .8463 L
.51923 .85543 L
.5 .8614 L
.48077 .86434 L
.46154 .86436 L
.44231 .86145 L
.42308 .85548 L
.40385 .84628 L
.40362 .84615 L
.38462 .83256 L
.37825 .82692 L
.36538 .81342 L
.36071 .80769 L
.34634 .78846 L
.34615 .78821 L
.33202 .76923 L
.32692 .76363 L
.31064 .75 L
.30769 .74812 L
.28846 .73829 L
.27048 .73077 L
.26923 .73022 L
.25 .72078 L
.23465 .71154 L
.23077 .70874 L
.21208 .69231 L
.21154 .69173 L
.197 .67308 L
.19231 .66542 L
.18676 .65385 L
.18 .63462 L
.17602 .61538 L
.17433 .59615 L
.17428 .57692 L
.1749 .55769 L
.17502 .53846 L
.17366 .51923 L
.17308 .51345 L
.17091 .5 L
.16756 .48077 L
.16475 .46154 L
.1635 .44231 L
.16445 .42308 L
.16799 .40385 L
.17308 .38758 L
.17444 .38462 L
.18466 .36538 L
.19231 .35407 L
.19861 .34615 L
.21154 .33157 L
.21588 .32692 L
.23077 .31052 L
.23312 .30769 L
.24685 .28846 L
.25 .28296 L
.25761 .26923 L
.26766 .25 L
.26923 .24708 L
.27958 .23077 L
.28846 .21903 L
.29528 .21154 L
.30769 .20036 L
.31886 .19231 L
.32692 .1878 L
.34615 .17957 L
.36538 .17468 L
.37868 .17308 L
F
0 g
.38462 .1728 m
.39978 .17308 L
.40385 .17338 L
.42308 .17581 L
.44231 .17878 L
.46154 .18022 L
.48077 .17815 L
.49932 .17308 L
.5 .17255 L
.51923 .16585 L
.53846 .15982 L
.55769 .15581 L
.57692 .1544 L
.59615 .15582 L
.61538 .16025 L
.63462 .16785 L
.6446 .17308 L
.65385 .17923 L
.66988 .19231 L
.67308 .19538 L
.68783 .21154 L
.69231 .21692 L
.70323 .23077 L
.71154 .24069 L
.72001 .25 L
.73077 .26002 L
.74266 .26923 L
.75 .27453 L
.76923 .28775 L
.77025 .28846 L
.78846 .30291 L
.7937 .30769 L
.80769 .32291 L
.81073 .32692 L
.82268 .34615 L
.82692 .35485 L
.83061 .36538 L
.83527 .38462 L
.83714 .40385 L
.83637 .42308 L
.83323 .44231 L
.82826 .46154 L
.82692 .46589 L
.8221 .48077 L
.81679 .5 L
.81467 .51923 L
.81659 .53846 L
.82118 .55769 L
.82627 .57692 L
.82692 .57922 L
Mistroke
.83001 .59615 L
.8319 .61538 L
.83158 .63462 L
.82885 .65385 L
.82692 .66275 L
.82331 .67308 L
.81454 .69231 L
.80769 .70379 L
.80201 .71154 L
.78846 .72663 L
.78398 .73077 L
.76923 .7421 L
.75623 .75 L
.75 .753 L
.73077 .76039 L
.71154 .76514 L
.69231 .76765 L
.67308 .76855 L
.65385 .76896 L
.64847 .76923 L
.63462 .77094 L
.61538 .7783 L
.60168 .78846 L
.59615 .79453 L
.58374 .80769 L
.57692 .81514 L
.56474 .82692 L
.55769 .83292 L
.53871 .84615 L
.53846 .8463 L
.51923 .85543 L
.5 .8614 L
.48077 .86434 L
.46154 .86436 L
.44231 .86145 L
.42308 .85548 L
.40385 .84628 L
.40362 .84615 L
.38462 .83256 L
.37825 .82692 L
.36538 .81342 L
.36071 .80769 L
.34634 .78846 L
.34615 .78821 L
.33202 .76923 L
.32692 .76363 L
.31064 .75 L
.30769 .74812 L
.28846 .73829 L
.27048 .73077 L
Mistroke
.26923 .73022 L
.25 .72078 L
.23465 .71154 L
.23077 .70874 L
.21208 .69231 L
.21154 .69173 L
.197 .67308 L
.19231 .66542 L
.18676 .65385 L
.18 .63462 L
.17602 .61538 L
.17433 .59615 L
.17428 .57692 L
.1749 .55769 L
.17502 .53846 L
.17366 .51923 L
.17308 .51345 L
.17091 .5 L
.16756 .48077 L
.16475 .46154 L
.1635 .44231 L
.16445 .42308 L
.16799 .40385 L
.17308 .38758 L
.17444 .38462 L
.18466 .36538 L
.19231 .35407 L
.19861 .34615 L
.21154 .33157 L
.21588 .32692 L
.23077 .31052 L
.23312 .30769 L
.24685 .28846 L
.25 .28296 L
.25761 .26923 L
.26766 .25 L
.26923 .24708 L
.27958 .23077 L
.28846 .21903 L
.29528 .21154 L
.30769 .20036 L
.31886 .19231 L
.32692 .1878 L
.34615 .17957 L
.36538 .17468 L
.37868 .17308 L
.38462 .1728 L
Mfstroke
.3 g
.57692 .17233 m
.59027 .17308 L
.59615 .17391 L
.61538 .17903 L
.63462 .18801 L
.64159 .19231 L
.65385 .20184 L
.66399 .21154 L
.67308 .22178 L
.68016 .23077 L
.69231 .24674 L
.69479 .25 L
.71154 .26861 L
.7122 .26923 L
.73077 .284 L
.73752 .28846 L
.75 .29666 L
.76601 .30769 L
.76923 .31017 L
.78753 .32692 L
.78846 .32793 L
.80208 .34615 L
.80769 .35605 L
.81156 .36538 L
.81706 .38462 L
.81922 .40385 L
.81831 .42308 L
.8146 .44231 L
.80861 .46154 L
.80769 .464 L
.80118 .48077 L
.79472 .5 L
.79215 .51923 L
.79456 .53846 L
.80009 .55769 L
.80606 .57692 L
.80769 .58215 L
.81052 .59615 L
.81273 .61538 L
.81235 .63462 L
.80914 .65385 L
.80769 .65983 L
.8026 .67308 L
.79215 .69231 L
.78846 .69761 L
.77634 .71154 L
.76923 .71804 L
.75119 .73077 L
.75 .73143 L
.73077 .74015 L
.71154 .74552 L
.69231 .7481 L
.67308 .74844 L
.65385 .74741 L
.63462 .74657 L
.61538 .74914 L
.61298 .75 L
.59615 .76124 L
.58852 .76923 L
.57692 .7847 L
.57395 .78846 L
.55769 .80744 L
.55745 .80769 L
.53846 .82401 L
.53428 .82692 L
.51923 .83517 L
.5 .84218 L
.48077 .84558 L
.46154 .8456 L
.44231 .84223 L
.42308 .83522 L
.40802 .82692 L
.40385 .82396 L
.3854 .80769 L
.38462 .80686 L
.36994 .78846 L
.36538 .78181 L
.35748 .76923 L
.34615 .75249 L
.34429 .75 L
.32692 .73357 L
.32236 .73077 L
.30769 .72366 L
.28846 .71651 L
.27532 .71154 L
.26923 .70891 L
.25 .69868 L
.24066 .69231 L
.23077 .68393 L
.22062 .67308 L
.21154 .66048 L
.20783 .65385 L
.19976 .63462 L
.19513 .61538 L
.19323 .59615 L
.19327 .57692 L
.19417 .55769 L
.19457 .53846 L
.19327 .51923 L
.19231 .51018 L
.19018 .5 L
.18632 .48077 L
.18308 .46154 L
.18165 .44231 L
.18277 .42308 L
.18695 .40385 L
.19231 .38913 L
.19467 .38462 L
.20673 .36538 L
.21154 .35919 L
.22317 .34615 L
.23077 .33832 L
.24166 .32692 L
.25 .31726 L
.25705 .30769 L
.26808 .28846 L
.26923 .28608 L
.27748 .26923 L
.28761 .25 L
.28846 .24855 L
.30115 .23077 L
.30769 .22351 L
.32139 .21154 L
.32692 .20779 L
.34615 .19792 L
.36499 .19231 L
.36538 .19225 L
.38462 .19023 L
.40385 .19101 L
.4189 .19231 L
.42308 .19402 L
.44231 .19801 L
.46154 .20058 L
.48077 .19912 L
.5 .19314 L
.50226 .19231 L
.51923 .18539 L
.53846 .17845 L
.55769 .17388 L
.56358 .17308 L
F
0 g
.57692 .17233 m
.59027 .17308 L
.59615 .17391 L
.61538 .17903 L
.63462 .18801 L
.64159 .19231 L
.65385 .20184 L
.66399 .21154 L
.67308 .22178 L
.68016 .23077 L
.69231 .24674 L
.69479 .25 L
.71154 .26861 L
.7122 .26923 L
.73077 .284 L
.73752 .28846 L
.75 .29666 L
.76601 .30769 L
.76923 .31017 L
.78753 .32692 L
.78846 .32793 L
.80208 .34615 L
.80769 .35605 L
.81156 .36538 L
.81706 .38462 L
.81922 .40385 L
.81831 .42308 L
.8146 .44231 L
.80861 .46154 L
.80769 .464 L
.80118 .48077 L
.79472 .5 L
.79215 .51923 L
.79456 .53846 L
.80009 .55769 L
.80606 .57692 L
.80769 .58215 L
.81052 .59615 L
.81273 .61538 L
.81235 .63462 L
.80914 .65385 L
.80769 .65983 L
.8026 .67308 L
.79215 .69231 L
.78846 .69761 L
.77634 .71154 L
.76923 .71804 L
.75119 .73077 L
.75 .73143 L
.73077 .74015 L
Mistroke
.71154 .74552 L
.69231 .7481 L
.67308 .74844 L
.65385 .74741 L
.63462 .74657 L
.61538 .74914 L
.61298 .75 L
.59615 .76124 L
.58852 .76923 L
.57692 .7847 L
.57395 .78846 L
.55769 .80744 L
.55745 .80769 L
.53846 .82401 L
.53428 .82692 L
.51923 .83517 L
.5 .84218 L
.48077 .84558 L
.46154 .8456 L
.44231 .84223 L
.42308 .83522 L
.40802 .82692 L
.40385 .82396 L
.3854 .80769 L
.38462 .80686 L
.36994 .78846 L
.36538 .78181 L
.35748 .76923 L
.34615 .75249 L
.34429 .75 L
.32692 .73357 L
.32236 .73077 L
.30769 .72366 L
.28846 .71651 L
.27532 .71154 L
.26923 .70891 L
.25 .69868 L
.24066 .69231 L
.23077 .68393 L
.22062 .67308 L
.21154 .66048 L
.20783 .65385 L
.19976 .63462 L
.19513 .61538 L
.19323 .59615 L
.19327 .57692 L
.19417 .55769 L
.19457 .53846 L
.19327 .51923 L
.19231 .51018 L
Mistroke
.19018 .5 L
.18632 .48077 L
.18308 .46154 L
.18165 .44231 L
.18277 .42308 L
.18695 .40385 L
.19231 .38913 L
.19467 .38462 L
.20673 .36538 L
.21154 .35919 L
.22317 .34615 L
.23077 .33832 L
.24166 .32692 L
.25 .31726 L
.25705 .30769 L
.26808 .28846 L
.26923 .28608 L
.27748 .26923 L
.28761 .25 L
.28846 .24855 L
.30115 .23077 L
.30769 .22351 L
.32139 .21154 L
.32692 .20779 L
.34615 .19792 L
.36499 .19231 L
.36538 .19225 L
.38462 .19023 L
.40385 .19101 L
.4189 .19231 L
.42308 .19402 L
.44231 .19801 L
.46154 .20058 L
.48077 .19912 L
.5 .19314 L
.50226 .19231 L
.51923 .18539 L
.53846 .17845 L
.55769 .17388 L
.56358 .17308 L
.57692 .17233 L
Mfstroke
.4 g
.55769 .18836 m
.57692 .18659 L
.59615 .18841 L
.61325 .19231 L
.61538 .19416 L
.63462 .20472 L
.64359 .21154 L
.65385 .22133 L
.66207 .23077 L
.67308 .24537 L
.67632 .25 L
.69066 .26923 L
.69231 .27116 L
.7107 .28846 L
.71154 .2891 L
.73077 .3018 L
.74048 .30769 L
.75 .31383 L
.76728 .32692 L
.76923 .32867 L
.78502 .34615 L
.78846 .35095 L
.79617 .36538 L
.80258 .38462 L
.80505 .40385 L
.80399 .42308 L
.79967 .44231 L
.79254 .46154 L
.78846 .47039 L
.7837 .48077 L
.77582 .5 L
.7728 .51923 L
.77603 .53846 L
.78284 .55769 L
.78846 .57279 L
.78986 .57692 L
.79504 .59615 L
.79761 .61538 L
.79718 .63462 L
.79343 .65385 L
.78846 .66825 L
.78588 .67308 L
.77335 .69231 L
.76923 .69709 L
.75301 .71154 L
.75 .71362 L
.73077 .72394 L
.71154 .73005 L
.70805 .73077 L
.69231 .73273 L
.67308 .73268 L
.65548 .73077 L
.65385 .73053 L
.63462 .72726 L
.61538 .72511 L
.59615 .72993 L
.5944 .73077 L
.57865 .75 L
.57692 .75348 L
.56733 .76923 L
.55769 .78391 L
.55411 .78846 L
.53846 .80501 L
.53533 .80769 L
.51923 .81854 L
.5 .82675 L
.49943 .82692 L
.48077 .83058 L
.46154 .8306 L
.44266 .82692 L
.44231 .82682 L
.42308 .81862 L
.40698 .80769 L
.40385 .80496 L
.38857 .78846 L
.38462 .78315 L
.37585 .76923 L
.36538 .75036 L
.36519 .75 L
.35315 .73077 L
.34615 .72335 L
.32692 .71175 L
.32637 .71154 L
.30769 .70545 L
.28846 .69959 L
.27012 .69231 L
.26923 .69186 L
.25 .68015 L
.24151 .67308 L
.23077 .6614 L
.22547 .65385 L
.2158 .63462 L
.21154 .62193 L
.21046 .61538 L
.20838 .59615 L
.20853 .57692 L
.20974 .55769 L
.21048 .53846 L
.20931 .51923 L
.20593 .5 L
.20151 .48077 L
.19781 .46154 L
.19618 .44231 L
.19749 .42308 L
.20236 .40385 L
.21141 .38462 L
.21154 .3844 L
.22555 .36538 L
.23077 .35964 L
.24422 .34615 L
.25 .34049 L
.2624 .32692 L
.26923 .3176 L
.27519 .30769 L
.28431 .28846 L
.28846 .27892 L
.29297 .26923 L
.30385 .25 L
.30769 .2445 L
.31983 .23077 L
.32692 .22466 L
.34615 .21284 L
.34792 .21154 L
.36538 .20642 L
.38462 .20406 L
.40385 .2051 L
.42308 .2088 L
.43307 .21154 L
.44231 .21389 L
.46154 .21777 L
.48077 .21698 L
.49756 .21154 L
.5 .21051 L
.51923 .20148 L
.53846 .19347 L
.54029 .19231 L
F
0 g
.55769 .18836 m
.57692 .18659 L
.59615 .18841 L
.61325 .19231 L
.61538 .19416 L
.63462 .20472 L
.64359 .21154 L
.65385 .22133 L
.66207 .23077 L
.67308 .24537 L
.67632 .25 L
.69066 .26923 L
.69231 .27116 L
.7107 .28846 L
.71154 .2891 L
.73077 .3018 L
.74048 .30769 L
.75 .31383 L
.76728 .32692 L
.76923 .32867 L
.78502 .34615 L
.78846 .35095 L
.79617 .36538 L
.80258 .38462 L
.80505 .40385 L
.80399 .42308 L
.79967 .44231 L
.79254 .46154 L
.78846 .47039 L
.7837 .48077 L
.77582 .5 L
.7728 .51923 L
.77603 .53846 L
.78284 .55769 L
.78846 .57279 L
.78986 .57692 L
.79504 .59615 L
.79761 .61538 L
.79718 .63462 L
.79343 .65385 L
.78846 .66825 L
.78588 .67308 L
.77335 .69231 L
.76923 .69709 L
.75301 .71154 L
.75 .71362 L
.73077 .72394 L
.71154 .73005 L
.70805 .73077 L
.69231 .73273 L
Mistroke
.67308 .73268 L
.65548 .73077 L
.65385 .73053 L
.63462 .72726 L
.61538 .72511 L
.59615 .72993 L
.5944 .73077 L
.57865 .75 L
.57692 .75348 L
.56733 .76923 L
.55769 .78391 L
.55411 .78846 L
.53846 .80501 L
.53533 .80769 L
.51923 .81854 L
.5 .82675 L
.49943 .82692 L
.48077 .83058 L
.46154 .8306 L
.44266 .82692 L
.44231 .82682 L
.42308 .81862 L
.40698 .80769 L
.40385 .80496 L
.38857 .78846 L
.38462 .78315 L
.37585 .76923 L
.36538 .75036 L
.36519 .75 L
.35315 .73077 L
.34615 .72335 L
.32692 .71175 L
.32637 .71154 L
.30769 .70545 L
.28846 .69959 L
.27012 .69231 L
.26923 .69186 L
.25 .68015 L
.24151 .67308 L
.23077 .6614 L
.22547 .65385 L
.2158 .63462 L
.21154 .62193 L
.21046 .61538 L
.20838 .59615 L
.20853 .57692 L
.20974 .55769 L
.21048 .53846 L
.20931 .51923 L
.20593 .5 L
Mistroke
.20151 .48077 L
.19781 .46154 L
.19618 .44231 L
.19749 .42308 L
.20236 .40385 L
.21141 .38462 L
.21154 .3844 L
.22555 .36538 L
.23077 .35964 L
.24422 .34615 L
.25 .34049 L
.2624 .32692 L
.26923 .3176 L
.27519 .30769 L
.28431 .28846 L
.28846 .27892 L
.29297 .26923 L
.30385 .25 L
.30769 .2445 L
.31983 .23077 L
.32692 .22466 L
.34615 .21284 L
.34792 .21154 L
.36538 .20642 L
.38462 .20406 L
.40385 .2051 L
.42308 .2088 L
.43307 .21154 L
.44231 .21389 L
.46154 .21777 L
.48077 .21698 L
.49756 .21154 L
.5 .21051 L
.51923 .20148 L
.53846 .19347 L
.54029 .19231 L
.55769 .18836 L
Mfstroke
.5 g
.53846 .207 m
.55769 .20104 L
.57692 .19899 L
.59615 .20108 L
.61538 .20777 L
.62272 .21154 L
.63462 .22014 L
.6458 .23077 L
.65385 .24036 L
.66079 .25 L
.67308 .26849 L
.67358 .26923 L
.68892 .28846 L
.69231 .29171 L
.71154 .30573 L
.71487 .30769 L
.73077 .31675 L
.74717 .32692 L
.75 .32894 L
.76917 .34615 L
.76923 .34623 L
.78245 .36538 L
.78846 .3785 L
.78982 .38462 L
.79259 .40385 L
.79137 .42308 L
.78846 .4359 L
.78641 .44231 L
.77796 .46154 L
.76923 .47694 L
.76715 .48077 L
.75727 .5 L
.75369 .51923 L
.7584 .53846 L
.76705 .55769 L
.76923 .56247 L
.77545 .57692 L
.78153 .59615 L
.7845 .61538 L
.78401 .63462 L
.77969 .65385 L
.77083 .67308 L
.76923 .6757 L
.75553 .69231 L
.75 .69722 L
.73077 .70955 L
.72748 .71154 L
.71154 .71648 L
.69231 .71941 L
.67308 .71901 L
.65385 .71574 L
.63891 .71154 L
.63462 .71011 L
.61538 .70281 L
.59615 .69528 L
.57692 .70126 L
.57238 .71154 L
.56697 .73077 L
.56036 .75 L
.55769 .7568 L
.55082 .76923 L
.53846 .78642 L
.53657 .78846 L
.51923 .8033 L
.51262 .80769 L
.5 .81295 L
.48077 .81745 L
.46154 .81748 L
.44231 .81304 L
.42944 .80769 L
.42308 .80341 L
.40565 .78846 L
.40385 .78647 L
.39147 .76923 L
.38462 .75663 L
.38163 .75 L
.37338 .73077 L
.36538 .7155 L
.36259 .71154 L
.34615 .69915 L
.32692 .69375 L
.31977 .69231 L
.30769 .68998 L
.28846 .68484 L
.26923 .67646 L
.26342 .67308 L
.25 .66248 L
.24207 .65385 L
.23077 .6356 L
.23035 .63462 L
.22412 .61538 L
.22173 .59615 L
.22203 .57692 L
.22369 .55769 L
.22491 .53846 L
.22391 .51923 L
.22018 .5 L
.21517 .48077 L
.21154 .46569 L
.21096 .46154 L
.20914 .44231 L
.21063 .42308 L
.21154 .41866 L
.21624 .40385 L
.22694 .38462 L
.23077 .37945 L
.24359 .36538 L
.25 .3593 L
.26411 .34615 L
.26923 .34098 L
.28043 .32692 L
.28846 .31216 L
.29046 .30769 L
.29811 .28846 L
.30657 .26923 L
.30769 .26703 L
.31862 .25 L
.32692 .24065 L
.33873 .23077 L
.34615 .22639 L
.36538 .21884 L
.38462 .21614 L
.40385 .21745 L
.42308 .22205 L
.44231 .22867 L
.44841 .23077 L
.46154 .23431 L
.48077 .23443 L
.49246 .23077 L
.5 .22712 L
.51923 .21631 L
.52827 .21154 L
F
0 g
.53846 .207 m
.55769 .20104 L
.57692 .19899 L
.59615 .20108 L
.61538 .20777 L
.62272 .21154 L
.63462 .22014 L
.6458 .23077 L
.65385 .24036 L
.66079 .25 L
.67308 .26849 L
.67358 .26923 L
.68892 .28846 L
.69231 .29171 L
.71154 .30573 L
.71487 .30769 L
.73077 .31675 L
.74717 .32692 L
.75 .32894 L
.76917 .34615 L
.76923 .34623 L
.78245 .36538 L
.78846 .3785 L
.78982 .38462 L
.79259 .40385 L
.79137 .42308 L
.78846 .4359 L
.78641 .44231 L
.77796 .46154 L
.76923 .47694 L
.76715 .48077 L
.75727 .5 L
.75369 .51923 L
.7584 .53846 L
.76705 .55769 L
.76923 .56247 L
.77545 .57692 L
.78153 .59615 L
.7845 .61538 L
.78401 .63462 L
.77969 .65385 L
.77083 .67308 L
.76923 .6757 L
.75553 .69231 L
.75 .69722 L
.73077 .70955 L
.72748 .71154 L
.71154 .71648 L
.69231 .71941 L
.67308 .71901 L
Mistroke
.65385 .71574 L
.63891 .71154 L
.63462 .71011 L
.61538 .70281 L
.59615 .69528 L
.57692 .70126 L
.57238 .71154 L
.56697 .73077 L
.56036 .75 L
.55769 .7568 L
.55082 .76923 L
.53846 .78642 L
.53657 .78846 L
.51923 .8033 L
.51262 .80769 L
.5 .81295 L
.48077 .81745 L
.46154 .81748 L
.44231 .81304 L
.42944 .80769 L
.42308 .80341 L
.40565 .78846 L
.40385 .78647 L
.39147 .76923 L
.38462 .75663 L
.38163 .75 L
.37338 .73077 L
.36538 .7155 L
.36259 .71154 L
.34615 .69915 L
.32692 .69375 L
.31977 .69231 L
.30769 .68998 L
.28846 .68484 L
.26923 .67646 L
.26342 .67308 L
.25 .66248 L
.24207 .65385 L
.23077 .6356 L
.23035 .63462 L
.22412 .61538 L
.22173 .59615 L
.22203 .57692 L
.22369 .55769 L
.22491 .53846 L
.22391 .51923 L
.22018 .5 L
.21517 .48077 L
.21154 .46569 L
.21096 .46154 L
Mistroke
.20914 .44231 L
.21063 .42308 L
.21154 .41866 L
.21624 .40385 L
.22694 .38462 L
.23077 .37945 L
.24359 .36538 L
.25 .3593 L
.26411 .34615 L
.26923 .34098 L
.28043 .32692 L
.28846 .31216 L
.29046 .30769 L
.29811 .28846 L
.30657 .26923 L
.30769 .26703 L
.31862 .25 L
.32692 .24065 L
.33873 .23077 L
.34615 .22639 L
.36538 .21884 L
.38462 .21614 L
.40385 .21745 L
.42308 .22205 L
.44231 .22867 L
.44841 .23077 L
.46154 .23431 L
.48077 .23443 L
.49246 .23077 L
.5 .22712 L
.51923 .21631 L
.52827 .21154 L
.53846 .207 L
Mfstroke
.6 g
.57692 .21061 m
.58891 .21154 L
.59615 .21298 L
.61538 .22077 L
.62957 .23077 L
.63462 .23568 L
.64651 .25 L
.65385 .26111 L
.65869 .26923 L
.67074 .28846 L
.67308 .2916 L
.6897 .30769 L
.69231 .3095 L
.71154 .32028 L
.72458 .32692 L
.73077 .33033 L
.75 .34349 L
.75308 .34615 L
.76921 .36538 L
.76923 .36541 L
.77785 .38462 L
.78105 .40385 L
.77961 .42308 L
.77374 .44231 L
.76923 .45199 L
.76359 .46154 L
.75 .47991 L
.7495 .48077 L
.73563 .5 L
.73077 .51099 L
.73066 .51923 L
.73077 .51977 L
.7395 .53846 L
.75 .55638 L
.75121 .55769 L
.76175 .57692 L
.76892 .59615 L
.76923 .59733 L
.77234 .61538 L
.77178 .63462 L
.76923 .6466 L
.76682 .65385 L
.75626 .67308 L
.75 .68067 L
.7365 .69231 L
.73077 .6958 L
.71154 .70392 L
.69231 .70718 L
.67308 .70643 L
.65385 .70196 L
.63462 .6935 L
.63273 .69231 L
.61538 .6791 L
.61136 .67308 L
.60237 .65385 L
.60086 .63462 L
.6036 .61538 L
.60968 .59615 L
.61538 .58346 L
.61928 .57692 L
.6329 .55769 L
.63462 .55573 L
.6497 .53846 L
.65385 .53402 L
.6639 .51923 L
.66753 .5 L
.65882 .48077 L
.65385 .47008 L
.64772 .46154 L
.63715 .44231 L
.63462 .43725 L
.62782 .42308 L
.61837 .40385 L
.61538 .39859 L
.60511 .38462 L
.59615 .37645 L
.5781 .36538 L
.57692 .36478 L
.55769 .35538 L
.53993 .34615 L
.53846 .34535 L
.51923 .33402 L
.50779 .32692 L
.5 .32371 L
.48077 .32015 L
.46154 .32669 L
.4598 .32692 L
.44231 .34102 L
.43519 .34615 L
.42308 .35524 L
.40835 .36538 L
.40385 .3684 L
.38462 .38289 L
.38278 .38462 L
.36852 .40385 L
.36538 .41126 L
.36175 .42308 L
.35745 .44231 L
.35371 .46154 L
.35051 .48077 L
.34916 .5 L
.35151 .51923 L
.35776 .53846 L
.36538 .55698 L
.36569 .55769 L
.37327 .57692 L
.37934 .59615 L
.38399 .61538 L
.38462 .61683 L
.38814 .63462 L
.40006 .65385 L
.40385 .65521 L
.42308 .65629 L
.44231 .65565 L
.46154 .65595 L
.48077 .65815 L
.5 .66291 L
.51923 .67117 L
.52231 .67308 L
.53846 .68543 L
.54275 .69231 L
.55017 .71154 L
.55011 .73077 L
.5453 .75 L
.53846 .76605 L
.53576 .76923 L
.51923 .78794 L
.51866 .78846 L
.5 .79983 L
.48077 .80512 L
.46154 .80516 L
.44231 .79995 L
.42339 .78846 L
.42308 .78817 L
.40615 .76923 L
.40385 .76602 L
.39607 .75 L
.38962 .73077 L
.38504 .71154 L
.38462 .7104 L
.38027 .69231 L
.36538 .67874 L
.34615 .6776 L
.32692 .67745 L
.30769 .67566 L
.29564 .67308 L
.28846 .6709 L
.26923 .6614 L
.25943 .65385 L
.25 .64338 L
.24458 .63462 L
.23707 .61538 L
.23434 .59615 L
.23485 .57692 L
.23709 .55769 L
.23901 .53846 L
.23832 .51923 L
.23424 .5 L
.23077 .48777 L
.2285 .48077 L
.22355 .46154 L
.22141 .44231 L
.22317 .42308 L
.22983 .40385 L
.23077 .40188 L
.24259 .38462 L
.25 .37675 L
.26269 .36538 L
.26923 .35998 L
.28412 .34615 L
.28846 .341 L
.29701 .32692 L
.30431 .30769 L
.30769 .2974 L
.31075 .28846 L
.31941 .26923 L
.32692 .25753 L
.33336 .25 L
.34615 .23954 L
.36476 .23077 L
.36538 .23063 L
.38462 .22756 L
.40385 .22922 L
.41398 .23077 L
.42308 .23486 L
.44231 .24369 L
.45455 .25 L
.46154 .25164 L
.48077 .2555 L
.49324 .25 L
.5 .24526 L
.51923 .23144 L
.5203 .23077 L
.53846 .21997 L
.55769 .21299 L
.56523 .21154 L
F
0 g
.57692 .21061 m
.58891 .21154 L
.59615 .21298 L
.61538 .22077 L
.62957 .23077 L
.63462 .23568 L
.64651 .25 L
.65385 .26111 L
.65869 .26923 L
.67074 .28846 L
.67308 .2916 L
.6897 .30769 L
.69231 .3095 L
.71154 .32028 L
.72458 .32692 L
.73077 .33033 L
.75 .34349 L
.75308 .34615 L
.76921 .36538 L
.76923 .36541 L
.77785 .38462 L
.78105 .40385 L
.77961 .42308 L
.77374 .44231 L
.76923 .45199 L
.76359 .46154 L
.75 .47991 L
.7495 .48077 L
.73563 .5 L
.73077 .51099 L
.73066 .51923 L
.73077 .51977 L
.7395 .53846 L
.75 .55638 L
.75121 .55769 L
.76175 .57692 L
.76892 .59615 L
.76923 .59733 L
.77234 .61538 L
.77178 .63462 L
.76923 .6466 L
.76682 .65385 L
.75626 .67308 L
.75 .68067 L
.7365 .69231 L
.73077 .6958 L
.71154 .70392 L
.69231 .70718 L
.67308 .70643 L
.65385 .70196 L
Mistroke
.63462 .6935 L
.63273 .69231 L
.61538 .6791 L
.61136 .67308 L
.60237 .65385 L
.60086 .63462 L
.6036 .61538 L
.60968 .59615 L
.61538 .58346 L
.61928 .57692 L
.6329 .55769 L
.63462 .55573 L
.6497 .53846 L
.65385 .53402 L
.6639 .51923 L
.66753 .5 L
.65882 .48077 L
.65385 .47008 L
.64772 .46154 L
.63715 .44231 L
.63462 .43725 L
.62782 .42308 L
.61837 .40385 L
.61538 .39859 L
.60511 .38462 L
.59615 .37645 L
.5781 .36538 L
.57692 .36478 L
.55769 .35538 L
.53993 .34615 L
.53846 .34535 L
.51923 .33402 L
.50779 .32692 L
.5 .32371 L
.48077 .32015 L
.46154 .32669 L
.4598 .32692 L
.44231 .34102 L
.43519 .34615 L
.42308 .35524 L
.40835 .36538 L
.40385 .3684 L
.38462 .38289 L
.38278 .38462 L
.36852 .40385 L
.36538 .41126 L
.36175 .42308 L
.35745 .44231 L
.35371 .46154 L
.35051 .48077 L
Mistroke
.34916 .5 L
.35151 .51923 L
.35776 .53846 L
.36538 .55698 L
.36569 .55769 L
.37327 .57692 L
.37934 .59615 L
.38399 .61538 L
.38462 .61683 L
.38814 .63462 L
.40006 .65385 L
.40385 .65521 L
.42308 .65629 L
.44231 .65565 L
.46154 .65595 L
.48077 .65815 L
.5 .66291 L
.51923 .67117 L
.52231 .67308 L
.53846 .68543 L
.54275 .69231 L
.55017 .71154 L
.55011 .73077 L
.5453 .75 L
.53846 .76605 L
.53576 .76923 L
.51923 .78794 L
.51866 .78846 L
.5 .79983 L
.48077 .80512 L
.46154 .80516 L
.44231 .79995 L
.42339 .78846 L
.42308 .78817 L
.40615 .76923 L
.40385 .76602 L
.39607 .75 L
.38962 .73077 L
.38504 .71154 L
.38462 .7104 L
.38027 .69231 L
.36538 .67874 L
.34615 .6776 L
.32692 .67745 L
.30769 .67566 L
.29564 .67308 L
.28846 .6709 L
.26923 .6614 L
.25943 .65385 L
.25 .64338 L
Mistroke
.24458 .63462 L
.23707 .61538 L
.23434 .59615 L
.23485 .57692 L
.23709 .55769 L
.23901 .53846 L
.23832 .51923 L
.23424 .5 L
.23077 .48777 L
.2285 .48077 L
.22355 .46154 L
.22141 .44231 L
.22317 .42308 L
.22983 .40385 L
.23077 .40188 L
.24259 .38462 L
.25 .37675 L
.26269 .36538 L
.26923 .35998 L
.28412 .34615 L
.28846 .341 L
.29701 .32692 L
.30431 .30769 L
.30769 .2974 L
.31075 .28846 L
.31941 .26923 L
.32692 .25753 L
.33336 .25 L
.34615 .23954 L
.36476 .23077 L
.36538 .23063 L
.38462 .22756 L
.40385 .22922 L
.41398 .23077 L
.42308 .23486 L
.44231 .24369 L
.45455 .25 L
.46154 .25164 L
.48077 .2555 L
.49324 .25 L
.5 .24526 L
.51923 .23144 L
.5203 .23077 L
.53846 .21997 L
.55769 .21299 L
.56523 .21154 L
.57692 .21061 L
Mfstroke
.7 g
.36538 .24243 m
.38462 .2388 L
.40385 .24094 L
.42308 .2486 L
.42548 .25 L
.44231 .26045 L
.4494 .26923 L
.45717 .28846 L
.45031 .30769 L
.44231 .3218 L
.43756 .32692 L
.42308 .34058 L
.41548 .34615 L
.40385 .35383 L
.38462 .36521 L
.38438 .36538 L
.36538 .3786 L
.3602 .38462 L
.3512 .40385 L
.34734 .42308 L
.34615 .43018 L
.34422 .44231 L
.34052 .46154 L
.33643 .48077 L
.33377 .5 L
.33559 .51923 L
.34246 .53846 L
.34615 .54771 L
.35119 .55769 L
.35935 .57692 L
.36472 .59615 L
.36538 .59986 L
.36692 .61538 L
.36538 .63133 L
.36454 .63462 L
.34983 .65385 L
.34615 .65585 L
.32692 .6614 L
.30769 .66152 L
.28846 .65669 L
.28091 .65385 L
.26923 .64526 L
.25959 .63462 L
.25039 .61538 L
.25 .61392 L
.24713 .59615 L
.24799 .57692 L
.25 .56045 L
.25113 .55769 L
.25394 .53846 L
.25369 .51923 L
.25 .50048 L
.24983 .5 L
.24232 .48077 L
.23629 .46154 L
.23379 .44231 L
.23585 .42308 L
.24402 .40385 L
.25 .3952 L
.26013 .38462 L
.26923 .37748 L
.28615 .36538 L
.28846 .36376 L
.30567 .34615 L
.30769 .34246 L
.31317 .32692 L
.31761 .30769 L
.32315 .28846 L
.32692 .27851 L
.3323 .26923 L
.34615 .25337 L
.34885 .25 L
F
0 g
.36538 .24243 m
.38462 .2388 L
.40385 .24094 L
.42308 .2486 L
.42548 .25 L
.44231 .26045 L
.4494 .26923 L
.45717 .28846 L
.45031 .30769 L
.44231 .3218 L
.43756 .32692 L
.42308 .34058 L
.41548 .34615 L
.40385 .35383 L
.38462 .36521 L
.38438 .36538 L
.36538 .3786 L
.3602 .38462 L
.3512 .40385 L
.34734 .42308 L
.34615 .43018 L
.34422 .44231 L
.34052 .46154 L
.33643 .48077 L
.33377 .5 L
.33559 .51923 L
.34246 .53846 L
.34615 .54771 L
.35119 .55769 L
.35935 .57692 L
.36472 .59615 L
.36538 .59986 L
.36692 .61538 L
.36538 .63133 L
.36454 .63462 L
.34983 .65385 L
.34615 .65585 L
.32692 .6614 L
.30769 .66152 L
.28846 .65669 L
.28091 .65385 L
.26923 .64526 L
.25959 .63462 L
.25039 .61538 L
.25 .61392 L
.24713 .59615 L
.24799 .57692 L
.25 .56045 L
.25113 .55769 L
.25394 .53846 L
Mistroke
.25369 .51923 L
.25 .50048 L
.24983 .5 L
.24232 .48077 L
.23629 .46154 L
.23379 .44231 L
.23585 .42308 L
.24402 .40385 L
.25 .3952 L
.26013 .38462 L
.26923 .37748 L
.28615 .36538 L
.28846 .36376 L
.30567 .34615 L
.30769 .34246 L
.31317 .32692 L
.31761 .30769 L
.32315 .28846 L
.32692 .27851 L
.3323 .26923 L
.34615 .25337 L
.34885 .25 L
.36538 .24243 L
Mfstroke
.8 g
.28846 .38458 m
.30769 .3782 L
.32692 .38417 L
.32759 .38462 L
.33165 .40385 L
.33191 .42308 L
.3298 .44231 L
.32692 .45829 L
.32619 .46154 L
.32237 .48077 L
.31187 .5 L
.3109 .51923 L
.32109 .53846 L
.32692 .54733 L
.33501 .55769 L
.34449 .57692 L
.34615 .58315 L
.34952 .59615 L
.34967 .61538 L
.34615 .62612 L
.34333 .63462 L
.32692 .64389 L
.30769 .64641 L
.28846 .64102 L
.27632 .63462 L
.26923 .62555 L
.26508 .61538 L
.26074 .59615 L
.26221 .57692 L
.26789 .55769 L
.26923 .55423 L
.27513 .53846 L
.27861 .51923 L
.27117 .5 L
.26923 .49616 L
.25685 .48077 L
.25039 .46154 L
.25 .45718 L
.24764 .44231 L
.25 .4246 L
.25023 .42308 L
.26025 .40385 L
.26923 .39589 L
.28838 .38462 L
F
0 g
.28846 .38458 m
.30769 .3782 L
.32692 .38417 L
.32759 .38462 L
.33165 .40385 L
.33191 .42308 L
.3298 .44231 L
.32692 .45829 L
.32619 .46154 L
.32237 .48077 L
.31187 .5 L
.3109 .51923 L
.32109 .53846 L
.32692 .54733 L
.33501 .55769 L
.34449 .57692 L
.34615 .58315 L
.34952 .59615 L
.34967 .61538 L
.34615 .62612 L
.34333 .63462 L
.32692 .64389 L
.30769 .64641 L
.28846 .64102 L
.27632 .63462 L
.26923 .62555 L
.26508 .61538 L
.26074 .59615 L
.26221 .57692 L
.26789 .55769 L
.26923 .55423 L
.27513 .53846 L
.27861 .51923 L
.27117 .5 L
.26923 .49616 L
.25685 .48077 L
.25039 .46154 L
.25 .45718 L
.24764 .44231 L
.25 .4246 L
.25023 .42308 L
.26025 .40385 L
.26923 .39589 L
.28838 .38462 L
.28846 .38458 L
s
.9 g
.28846 .40934 m
.30769 .41674 L
.31031 .42308 L
.312 .44231 L
.30769 .45212 L
.30254 .46154 L
.28846 .47112 L
.27364 .46154 L
.26923 .45403 L
.26478 .44231 L
.26923 .42603 L
.27076 .42308 L
F
0 g
.28846 .40934 m
.30769 .41674 L
.31031 .42308 L
.312 .44231 L
.30769 .45212 L
.30254 .46154 L
.28846 .47112 L
.27364 .46154 L
.26923 .45403 L
.26478 .44231 L
.26923 .42603 L
.27076 .42308 L
.28846 .40934 L
s
.9 g
.28846 .56635 m
.30769 .5622 L
.32284 .57692 L
.32692 .58438 L
.33128 .59615 L
.32692 .61507 L
.32673 .61538 L
.30769 .62574 L
.28846 .61883 L
.28642 .61538 L
.27939 .59615 L
.28319 .57692 L
F
0 g
.28846 .56635 m
.30769 .5622 L
.32284 .57692 L
.32692 .58438 L
.33128 .59615 L
.32692 .61507 L
.32673 .61538 L
.30769 .62574 L
.28846 .61883 L
.28642 .61538 L
.27939 .59615 L
.28319 .57692 L
.28846 .56635 L
s
.8 g
.36538 .25489 m
.38462 .25085 L
.40385 .25328 L
.42308 .26454 L
.42687 .26923 L
.4362 .28846 L
.43288 .30769 L
.42308 .32247 L
.41932 .32692 L
.40385 .33934 L
.39288 .34615 L
.38462 .34907 L
.36538 .35573 L
.34615 .35873 L
.33299 .34615 L
.33015 .32692 L
.33122 .30769 L
.33587 .28846 L
.34615 .27065 L
.34659 .26923 L
F
0 g
.36538 .25489 m
.38462 .25085 L
.40385 .25328 L
.42308 .26454 L
.42687 .26923 L
.4362 .28846 L
.43288 .30769 L
.42308 .32247 L
.41932 .32692 L
.40385 .33934 L
.39288 .34615 L
.38462 .34907 L
.36538 .35573 L
.34615 .35873 L
.33299 .34615 L
.33015 .32692 L
.33122 .30769 L
.33587 .28846 L
.34615 .27065 L
.34659 .26923 L
.36538 .25489 L
s
.9 g
.38462 .26487 m
.4011 .26923 L
.40385 .27076 L
.4188 .28846 L
.41558 .30769 L
.40385 .32071 L
.3952 .32692 L
.38462 .33225 L
.36538 .33425 L
.35418 .32692 L
.3478 .30769 L
.3481 .28846 L
.36538 .2717 L
.36959 .26923 L
F
0 g
.38462 .26487 m
.4011 .26923 L
.40385 .27076 L
.4188 .28846 L
.41558 .30769 L
.40385 .32071 L
.3952 .32692 L
.38462 .33225 L
.36538 .33425 L
.35418 .32692 L
.3478 .30769 L
.3481 .28846 L
.36538 .2717 L
.36959 .26923 L
.38462 .26487 L
s
.4 g
.46154 .34511 m
.48077 .33902 L
.5 .34133 L
.5124 .34615 L
.51923 .3494 L
.53846 .3592 L
.55063 .36538 L
.55769 .36901 L
.57692 .37988 L
.58371 .38462 L
.59615 .39596 L
.60247 .40385 L
.61392 .42308 L
.61538 .42592 L
.62343 .44231 L
.63267 .46154 L
.63462 .46368 L
.64105 .48077 L
.64555 .5 L
.6417 .51923 L
.63462 .53526 L
.63026 .53846 L
.61667 .55769 L
.61538 .55961 L
.60488 .57692 L
.59615 .59489 L
.59566 .59615 L
.58891 .61538 L
.58365 .63462 L
.57855 .65385 L
.57692 .65796 L
.55769 .66803 L
.53846 .66111 L
.51923 .65428 L
.51784 .65385 L
.5 .64877 L
.48077 .6448 L
.46154 .64205 L
.44231 .63949 L
.42377 .63462 L
.42308 .63432 L
.40385 .61609 L
.40344 .61538 L
.39478 .59615 L
.38751 .57692 L
.38462 .56938 L
.37991 .55769 L
.3723 .53846 L
.36633 .51923 L
.36538 .51471 L
.36361 .5 L
.36417 .48077 L
.36538 .47064 L
.36683 .46154 L
.37071 .44231 L
.37624 .42308 L
.38462 .40559 L
.38578 .40385 L
.40371 .38462 L
.40385 .3845 L
.42308 .37003 L
.42962 .36538 L
.44231 .35684 L
.45891 .34615 L
F
0 g
.46154 .34511 m
.48077 .33902 L
.5 .34133 L
.5124 .34615 L
.51923 .3494 L
.53846 .3592 L
.55063 .36538 L
.55769 .36901 L
.57692 .37988 L
.58371 .38462 L
.59615 .39596 L
.60247 .40385 L
.61392 .42308 L
.61538 .42592 L
.62343 .44231 L
.63267 .46154 L
.63462 .46368 L
.64105 .48077 L
.64555 .5 L
.6417 .51923 L
.63462 .53526 L
.63026 .53846 L
.61667 .55769 L
.61538 .55961 L
.60488 .57692 L
.59615 .59489 L
.59566 .59615 L
.58891 .61538 L
.58365 .63462 L
.57855 .65385 L
.57692 .65796 L
.55769 .66803 L
.53846 .66111 L
.51923 .65428 L
.51784 .65385 L
.5 .64877 L
.48077 .6448 L
.46154 .64205 L
.44231 .63949 L
.42377 .63462 L
.42308 .63432 L
.40385 .61609 L
.40344 .61538 L
.39478 .59615 L
.38751 .57692 L
.38462 .56938 L
.37991 .55769 L
.3723 .53846 L
.36633 .51923 L
.36538 .51471 L
Mistroke
.36361 .5 L
.36417 .48077 L
.36538 .47064 L
.36683 .46154 L
.37071 .44231 L
.37624 .42308 L
.38462 .40559 L
.38578 .40385 L
.40371 .38462 L
.40385 .3845 L
.42308 .37003 L
.42962 .36538 L
.44231 .35684 L
.45891 .34615 L
.46154 .34511 L
Mfstroke
.3 g
.46154 .36232 m
.48077 .35672 L
.5 .35815 L
.51923 .36487 L
.52052 .36538 L
.53846 .37385 L
.55769 .38424 L
.55833 .38462 L
.57692 .39753 L
.58365 .40385 L
.59615 .41976 L
.59825 .42308 L
.60862 .44231 L
.61538 .457 L
.61719 .46154 L
.62394 .48077 L
.62647 .5 L
.62218 .51923 L
.61538 .5346 L
.61211 .53846 L
.6002 .55769 L
.59615 .56446 L
.58931 .57692 L
.57961 .59615 L
.57692 .60153 L
.57059 .61538 L
.55769 .6314 L
.55287 .63462 L
.53846 .63825 L
.51923 .63683 L
.50591 .63462 L
.5 .63356 L
.48077 .63022 L
.46154 .62667 L
.44231 .6213 L
.43061 .61538 L
.42308 .60908 L
.41302 .59615 L
.40385 .57809 L
.40331 .57692 L
.39492 .55769 L
.38735 .53846 L
.38462 .53143 L
.3814 .51923 L
.37829 .5 L
.37831 .48077 L
.38073 .46154 L
.38462 .44359 L
.38504 .44231 L
.39196 .42308 L
.40385 .4045 L
.40442 .40385 L
.42308 .38645 L
.42544 .38462 L
.44231 .37293 L
.45409 .36538 L
F
0 g
.46154 .36232 m
.48077 .35672 L
.5 .35815 L
.51923 .36487 L
.52052 .36538 L
.53846 .37385 L
.55769 .38424 L
.55833 .38462 L
.57692 .39753 L
.58365 .40385 L
.59615 .41976 L
.59825 .42308 L
.60862 .44231 L
.61538 .457 L
.61719 .46154 L
.62394 .48077 L
.62647 .5 L
.62218 .51923 L
.61538 .5346 L
.61211 .53846 L
.6002 .55769 L
.59615 .56446 L
.58931 .57692 L
.57961 .59615 L
.57692 .60153 L
.57059 .61538 L
.55769 .6314 L
.55287 .63462 L
.53846 .63825 L
.51923 .63683 L
.50591 .63462 L
.5 .63356 L
.48077 .63022 L
.46154 .62667 L
.44231 .6213 L
.43061 .61538 L
.42308 .60908 L
.41302 .59615 L
.40385 .57809 L
.40331 .57692 L
.39492 .55769 L
.38735 .53846 L
.38462 .53143 L
.3814 .51923 L
.37829 .5 L
.37831 .48077 L
.38073 .46154 L
.38462 .44359 L
.38504 .44231 L
.39196 .42308 L
Mistroke
.40385 .4045 L
.40442 .40385 L
.42308 .38645 L
.42544 .38462 L
.44231 .37293 L
.45409 .36538 L
.46154 .36232 L
Mfstroke
.2 g
.46154 .38061 m
.48077 .37508 L
.5 .37593 L
.51923 .38192 L
.52607 .38462 L
.53846 .39081 L
.55769 .40274 L
.55919 .40385 L
.57692 .42058 L
.57892 .42308 L
.59122 .44231 L
.59615 .45204 L
.59984 .46154 L
.60558 .48077 L
.60682 .5 L
.60213 .51923 L
.59615 .53334 L
.59278 .53846 L
.58169 .55769 L
.57692 .56581 L
.57067 .57692 L
.55804 .59615 L
.55769 .59658 L
.53846 .61291 L
.53095 .61538 L
.51923 .61687 L
.5 .61591 L
.49559 .61538 L
.48077 .61301 L
.46154 .60816 L
.44231 .59864 L
.43895 .59615 L
.42308 .57738 L
.42278 .57692 L
.41238 .55769 L
.40435 .53846 L
.40385 .53728 L
.39806 .51923 L
.39455 .5 L
.39415 .48077 L
.39651 .46154 L
.40159 .44231 L
.40385 .43608 L
.41047 .42308 L
.42308 .40709 L
.42643 .40385 L
.44231 .39129 L
.45222 .38462 L
F
0 g
.46154 .38061 m
.48077 .37508 L
.5 .37593 L
.51923 .38192 L
.52607 .38462 L
.53846 .39081 L
.55769 .40274 L
.55919 .40385 L
.57692 .42058 L
.57892 .42308 L
.59122 .44231 L
.59615 .45204 L
.59984 .46154 L
.60558 .48077 L
.60682 .5 L
.60213 .51923 L
.59615 .53334 L
.59278 .53846 L
.58169 .55769 L
.57692 .56581 L
.57067 .57692 L
.55804 .59615 L
.55769 .59658 L
.53846 .61291 L
.53095 .61538 L
.51923 .61687 L
.5 .61591 L
.49559 .61538 L
.48077 .61301 L
.46154 .60816 L
.44231 .59864 L
.43895 .59615 L
.42308 .57738 L
.42278 .57692 L
.41238 .55769 L
.40435 .53846 L
.40385 .53728 L
.39806 .51923 L
.39455 .5 L
.39415 .48077 L
.39651 .46154 L
.40159 .44231 L
.40385 .43608 L
.41047 .42308 L
.42308 .40709 L
.42643 .40385 L
.44231 .39129 L
.45222 .38462 L
.46154 .38061 L
s
.7 g
.44231 .6713 m
.46154 .66943 L
.48077 .67127 L
.48826 .67308 L
.5 .67708 L
.51923 .68955 L
.52185 .69231 L
.53317 .71154 L
.53537 .73077 L
.53129 .75 L
.52036 .76923 L
.51923 .77066 L
.5 .78637 L
.49532 .78846 L
.48077 .79278 L
.46154 .79284 L
.44659 .78846 L
.44231 .78656 L
.42308 .7713 L
.42137 .76923 L
.40988 .75 L
.40438 .73077 L
.40385 .72704 L
.40331 .71154 L
.40385 .70664 L
.40836 .69231 L
.42308 .67771 L
.43355 .67308 L
F
0 g
.44231 .6713 m
.46154 .66943 L
.48077 .67127 L
.48826 .67308 L
.5 .67708 L
.51923 .68955 L
.52185 .69231 L
.53317 .71154 L
.53537 .73077 L
.53129 .75 L
.52036 .76923 L
.51923 .77066 L
.5 .78637 L
.49532 .78846 L
.48077 .79278 L
.46154 .79284 L
.44659 .78846 L
.44231 .78656 L
.42308 .7713 L
.42137 .76923 L
.40988 .75 L
.40438 .73077 L
.40385 .72704 L
.40331 .71154 L
.40385 .70664 L
.40836 .69231 L
.42308 .67771 L
.43355 .67308 L
.44231 .6713 L
s
.1 g
.46154 .40351 m
.48077 .39719 L
.5 .39753 L
.51923 .40343 L
.52033 .40385 L
.53846 .41328 L
.55142 .42308 L
.55769 .42906 L
.56799 .44231 L
.57692 .45934 L
.5777 .46154 L
.58313 .48077 L
.58344 .5 L
.57821 .51923 L
.57692 .52281 L
.5691 .53846 L
.55769 .55698 L
.55726 .55769 L
.54248 .57692 L
.53846 .58034 L
.51923 .59083 L
.5 .59284 L
.48077 .59017 L
.46154 .58258 L
.45264 .57692 L
.44231 .56598 L
.43617 .55769 L
.42596 .53846 L
.42308 .53173 L
.41895 .51923 L
.41481 .5 L
.41405 .48077 L
.41669 .46154 L
.42308 .4426 L
.42333 .44231 L
.43566 .42308 L
.44231 .4164 L
.46074 .40385 L
F
0 g
.46154 .40351 m
.48077 .39719 L
.5 .39753 L
.51923 .40343 L
.52033 .40385 L
.53846 .41328 L
.55142 .42308 L
.55769 .42906 L
.56799 .44231 L
.57692 .45934 L
.5777 .46154 L
.58313 .48077 L
.58344 .5 L
.57821 .51923 L
.57692 .52281 L
.5691 .53846 L
.55769 .55698 L
.55726 .55769 L
.54248 .57692 L
.53846 .58034 L
.51923 .59083 L
.5 .59284 L
.48077 .59017 L
.46154 .58258 L
.45264 .57692 L
.44231 .56598 L
.43617 .55769 L
.42596 .53846 L
.42308 .53173 L
.41895 .51923 L
.41481 .5 L
.41405 .48077 L
.41669 .46154 L
.42308 .4426 L
.42333 .44231 L
.43566 .42308 L
.44231 .4164 L
.46074 .40385 L
.46154 .40351 L
s
.8 g
.44231 .68793 m
.46154 .68328 L
.48077 .68486 L
.49856 .69231 L
.5 .69278 L
.5167 .71154 L
.51923 .71936 L
.52068 .73077 L
.51923 .74182 L
.51686 .75 L
.50236 .76923 L
.5 .77096 L
.48077 .7799 L
.46154 .77999 L
.44231 .77142 L
.4392 .76923 L
.42437 .75 L
.42308 .74643 L
.41914 .73077 L
.42091 .71154 L
.42308 .7062 L
.43386 .69231 L
F
0 g
.44231 .68793 m
.46154 .68328 L
.48077 .68486 L
.49856 .69231 L
.5 .69278 L
.5167 .71154 L
.51923 .71936 L
.52068 .73077 L
.51923 .74182 L
.51686 .75 L
.50236 .76923 L
.5 .77096 L
.48077 .7799 L
.46154 .77999 L
.44231 .77142 L
.4392 .76923 L
.42437 .75 L
.42308 .74643 L
.41914 .73077 L
.42091 .71154 L
.42308 .7062 L
.43386 .69231 L
.44231 .68793 L
s
.9 g
.44231 .71104 m
.46154 .69772 L
.48077 .69931 L
.49599 .71154 L
.5 .71716 L
.50434 .73077 L
.5 .74743 L
.49848 .75 L
.48077 .76342 L
.46154 .76366 L
.44264 .75 L
.44231 .74951 L
.43538 .73077 L
.44201 .71154 L
F
0 g
.44231 .71104 m
.46154 .69772 L
.48077 .69931 L
.49599 .71154 L
.5 .71716 L
.50434 .73077 L
.5 .74743 L
.49848 .75 L
.48077 .76342 L
.46154 .76366 L
.44264 .75 L
.44231 .74951 L
.43538 .73077 L
.44201 .71154 L
.44231 .71104 L
s
.48077 .43294 m
.5 .4321 L
.51923 .4401 L
.52303 .44231 L
.53846 .45836 L
.54016 .46154 L
.54753 .48077 L
.54724 .5 L
.54009 .51923 L
.53846 .52247 L
.52861 .53846 L
.51923 .54494 L
.5 .55245 L
.48077 .54901 L
.46679 .53846 L
.46154 .53297 L
.45319 .51923 L
.44707 .5 L
.44602 .48077 L
.45009 .46154 L
.46154 .44391 L
.46478 .44231 L
F
.48077 .43294 m
.5 .4321 L
.51923 .4401 L
.52303 .44231 L
.53846 .45836 L
.54016 .46154 L
.54753 .48077 L
.54724 .5 L
.54009 .51923 L
.53846 .52247 L
.52861 .53846 L
.51923 .54494 L
.5 .55245 L
.48077 .54901 L
.46679 .53846 L
.46154 .53297 L
.45319 .51923 L
.44707 .5 L
.44602 .48077 L
.45009 .46154 L
.46154 .44391 L
.46478 .44231 L
.48077 .43294 L
s
.7 g
.55769 .22493 m
.57692 .22203 L
.59615 .22483 L
.61299 .23077 L
.61538 .23411 L
.63224 .25 L
.63462 .25298 L
.64477 .26923 L
.65385 .28709 L
.65454 .28846 L
.66664 .30769 L
.67308 .31414 L
.69231 .32565 L
.69514 .32692 L
.71154 .33384 L
.73077 .3436 L
.7349 .34615 L
.75 .3586 L
.75568 .36538 L
.76603 .38462 L
.76923 .39873 L
.76969 .40385 L
.76923 .41551 L
.76799 .42308 L
.761 .44231 L
.75 .45869 L
.74812 .46154 L
.73077 .47648 L
.72458 .48077 L
.71154 .48659 L
.69231 .48524 L
.68444 .48077 L
.67308 .47035 L
.6637 .46154 L
.65385 .44709 L
.65085 .44231 L
.64093 .42308 L
.63462 .40822 L
.63283 .40385 L
.62386 .38462 L
.61538 .37285 L
.60677 .36538 L
.59615 .35921 L
.57692 .3508 L
.56597 .34615 L
.55769 .34225 L
.53846 .3312 L
.53269 .32692 L
.51923 .31715 L
.51466 .30769 L
.50043 .28846 L
.50515 .26923 L
.5186 .25 L
.51923 .24912 L
.53846 .2334 L
.54162 .23077 L
F
0 g
.55769 .22493 m
.57692 .22203 L
.59615 .22483 L
.61299 .23077 L
.61538 .23411 L
.63224 .25 L
.63462 .25298 L
.64477 .26923 L
.65385 .28709 L
.65454 .28846 L
.66664 .30769 L
.67308 .31414 L
.69231 .32565 L
.69514 .32692 L
.71154 .33384 L
.73077 .3436 L
.7349 .34615 L
.75 .3586 L
.75568 .36538 L
.76603 .38462 L
.76923 .39873 L
.76969 .40385 L
.76923 .41551 L
.76799 .42308 L
.761 .44231 L
.75 .45869 L
.74812 .46154 L
.73077 .47648 L
.72458 .48077 L
.71154 .48659 L
.69231 .48524 L
.68444 .48077 L
.67308 .47035 L
.6637 .46154 L
.65385 .44709 L
.65085 .44231 L
.64093 .42308 L
.63462 .40822 L
.63283 .40385 L
.62386 .38462 L
.61538 .37285 L
.60677 .36538 L
.59615 .35921 L
.57692 .3508 L
.56597 .34615 L
.55769 .34225 L
.53846 .3312 L
.53269 .32692 L
.51923 .31715 L
.51466 .30769 L
Mistroke
.50043 .28846 L
.50515 .26923 L
.5186 .25 L
.51923 .24912 L
.53846 .2334 L
.54162 .23077 L
.55769 .22493 L
Mfstroke
.8 g
.53846 .24982 m
.55769 .23737 L
.57692 .23389 L
.59615 .23715 L
.61538 .24943 L
.61601 .25 L
.63075 .26923 L
.63462 .27517 L
.63896 .28846 L
.6453 .30769 L
.65385 .32536 L
.65526 .32692 L
.67308 .33619 L
.69231 .34126 L
.7081 .34615 L
.71154 .34738 L
.73077 .35732 L
.74073 .36538 L
.75 .37598 L
.75353 .38462 L
.75811 .40385 L
.75588 .42308 L
.75 .43662 L
.74734 .44231 L
.73077 .45804 L
.72474 .46154 L
.71154 .46573 L
.69231 .46365 L
.6873 .46154 L
.67308 .45066 L
.66544 .44231 L
.65434 .42308 L
.65385 .42243 L
.64684 .40385 L
.64135 .38462 L
.63524 .36538 L
.63462 .36411 L
.61538 .34805 L
.60939 .34615 L
.59615 .34271 L
.57692 .33701 L
.55769 .32837 L
.55508 .32692 L
.53846 .31556 L
.53224 .30769 L
.52266 .28846 L
.52465 .26923 L
.53828 .25 L
F
0 g
.53846 .24982 m
.55769 .23737 L
.57692 .23389 L
.59615 .23715 L
.61538 .24943 L
.61601 .25 L
.63075 .26923 L
.63462 .27517 L
.63896 .28846 L
.6453 .30769 L
.65385 .32536 L
.65526 .32692 L
.67308 .33619 L
.69231 .34126 L
.7081 .34615 L
.71154 .34738 L
.73077 .35732 L
.74073 .36538 L
.75 .37598 L
.75353 .38462 L
.75811 .40385 L
.75588 .42308 L
.75 .43662 L
.74734 .44231 L
.73077 .45804 L
.72474 .46154 L
.71154 .46573 L
.69231 .46365 L
.6873 .46154 L
.67308 .45066 L
.66544 .44231 L
.65434 .42308 L
.65385 .42243 L
.64684 .40385 L
.64135 .38462 L
.63524 .36538 L
.63462 .36411 L
.61538 .34805 L
.60939 .34615 L
.59615 .34271 L
.57692 .33701 L
.55769 .32837 L
.55508 .32692 L
.53846 .31556 L
.53224 .30769 L
.52266 .28846 L
.52465 .26923 L
.53828 .25 L
.53846 .24982 L
s
.9 g
.57692 .24791 m
.59006 .25 L
.59615 .25248 L
.61424 .26923 L
.61538 .2711 L
.62253 .28846 L
.62307 .30769 L
.61538 .31931 L
.59615 .32559 L
.57692 .32268 L
.55769 .31251 L
.55231 .30769 L
.54058 .28846 L
.54202 .26923 L
.55769 .25379 L
.5661 .25 L
F
0 g
.57692 .24791 m
.59006 .25 L
.59615 .25248 L
.61424 .26923 L
.61538 .2711 L
.62253 .28846 L
.62307 .30769 L
.61538 .31931 L
.59615 .32559 L
.57692 .32268 L
.55769 .31251 L
.55231 .30769 L
.54058 .28846 L
.54202 .26923 L
.55769 .25379 L
.5661 .25 L
.57692 .24791 L
s
1 g
.57692 .26941 m
.59615 .2804 L
.59793 .28846 L
.59615 .29439 L
.57692 .29883 L
.56597 .28846 L
F
0 g
.57692 .26941 m
.59615 .2804 L
.59793 .28846 L
.59615 .29439 L
.57692 .29883 L
.56597 .28846 L
.57692 .26941 L
s
.7 g
.69231 .53492 m
.70964 .53846 L
.71154 .53962 L
.73077 .55553 L
.73358 .55769 L
.74774 .57692 L
.75 .58057 L
.75651 .59615 L
.76058 .61538 L
.75993 .63462 L
.75402 .65385 L
.75 .6619 L
.74107 .67308 L
.73077 .6819 L
.71154 .69157 L
.70912 .69231 L
.69231 .69528 L
.67308 .69414 L
.66527 .69231 L
.65385 .68826 L
.63462 .67584 L
.63185 .67308 L
.61934 .65385 L
.61539 .63462 L
.61688 .61538 L
.62288 .59615 L
.63383 .57692 L
.63462 .57583 L
.65081 .55769 L
.65385 .55532 L
.67308 .54194 L
.67964 .53846 L
F
0 g
.69231 .53492 m
.70964 .53846 L
.71154 .53962 L
.73077 .55553 L
.73358 .55769 L
.74774 .57692 L
.75 .58057 L
.75651 .59615 L
.76058 .61538 L
.75993 .63462 L
.75402 .65385 L
.75 .6619 L
.74107 .67308 L
.73077 .6819 L
.71154 .69157 L
.70912 .69231 L
.69231 .69528 L
.67308 .69414 L
.66527 .69231 L
.65385 .68826 L
.63462 .67584 L
.63185 .67308 L
.61934 .65385 L
.61539 .63462 L
.61688 .61538 L
.62288 .59615 L
.63383 .57692 L
.63462 .57583 L
.65081 .55769 L
.65385 .55532 L
.67308 .54194 L
.67964 .53846 L
.69231 .53492 L
s
.8 g
.69231 .55602 m
.70469 .55769 L
.71154 .56046 L
.73077 .57578 L
.73179 .57692 L
.74368 .59615 L
.74854 .61538 L
.74781 .63462 L
.74067 .65385 L
.73077 .6668 L
.7241 .67308 L
.71154 .67882 L
.69231 .68327 L
.67308 .68163 L
.65385 .67337 L
.65338 .67308 L
.63527 .65385 L
.63462 .65251 L
.62917 .63462 L
.62989 .61538 L
.63462 .60023 L
.63638 .59615 L
.6498 .57692 L
.65385 .57311 L
.67308 .5602 L
.67991 .55769 L
F
0 g
.69231 .55602 m
.70469 .55769 L
.71154 .56046 L
.73077 .57578 L
.73179 .57692 L
.74368 .59615 L
.74854 .61538 L
.74781 .63462 L
.74067 .65385 L
.73077 .6668 L
.7241 .67308 L
.71154 .67882 L
.69231 .68327 L
.67308 .68163 L
.65385 .67337 L
.65338 .67308 L
.63527 .65385 L
.63462 .65251 L
.62917 .63462 L
.62989 .61538 L
.63462 .60023 L
.63638 .59615 L
.6498 .57692 L
.65385 .57311 L
.67308 .5602 L
.67991 .55769 L
.69231 .55602 L
s
.9 g
.69231 .57285 m
.70825 .57692 L
.71154 .57843 L
.7295 .59615 L
.73077 .60054 L
.73547 .61538 L
.73447 .63462 L
.73077 .6441 L
.7262 .65385 L
.71154 .66493 L
.69231 .67031 L
.67308 .66813 L
.65385 .65509 L
.65283 .65385 L
.64326 .63462 L
.6434 .61538 L
.6517 .59615 L
.65385 .59293 L
.67308 .57716 L
.67368 .57692 L
F
0 g
.69231 .57285 m
.70825 .57692 L
.71154 .57843 L
.7295 .59615 L
.73077 .60054 L
.73547 .61538 L
.73447 .63462 L
.73077 .6441 L
.7262 .65385 L
.71154 .66493 L
.69231 .67031 L
.67308 .66813 L
.65385 .65509 L
.65283 .65385 L
.64326 .63462 L
.6434 .61538 L
.6517 .59615 L
.65385 .59293 L
.67308 .57716 L
.67368 .57692 L
.69231 .57285 L
s
.9 g
.67308 .36032 m
.69231 .35763 L
.71154 .36206 L
.71838 .36538 L
.73077 .3719 L
.73976 .38462 L
.74574 .40385 L
.74301 .42308 L
.73077 .44142 L
.72636 .44231 L
.71154 .44867 L
.69231 .44577 L
.68645 .44231 L
.67308 .42966 L
.66915 .42308 L
.66134 .40385 L
.65913 .38462 L
.66478 .36538 L
F
0 g
.67308 .36032 m
.69231 .35763 L
.71154 .36206 L
.71838 .36538 L
.73077 .3719 L
.73976 .38462 L
.74574 .40385 L
.74301 .42308 L
.73077 .44142 L
.72636 .44231 L
.71154 .44867 L
.69231 .44577 L
.68645 .44231 L
.67308 .42966 L
.66915 .42308 L
.66134 .40385 L
.65913 .38462 L
.66478 .36538 L
.67308 .36032 L
s
1 g
.69231 .59089 m
.70559 .59615 L
.71154 .60135 L
.72085 .61538 L
.71905 .63462 L
.71154 .64372 L
.69231 .65349 L
.67308 .64901 L
.6614 .63462 L
.66077 .61538 L
.67308 .59743 L
.67493 .59615 L
F
0 g
.69231 .59089 m
.70559 .59615 L
.71154 .60135 L
.72085 .61538 L
.71905 .63462 L
.71154 .64372 L
.69231 .65349 L
.67308 .64901 L
.6614 .63462 L
.66077 .61538 L
.67308 .59743 L
.67493 .59615 L
.69231 .59089 L
s
1 g
.69231 .38018 m
.71154 .38055 L
.71605 .38462 L
.72701 .40385 L
.71939 .42308 L
.71154 .42965 L
.69231 .42313 L
.69226 .42308 L
.6811 .40385 L
.68554 .38462 L
F
0 g
.69231 .38018 m
.71154 .38055 L
.71605 .38462 L
.72701 .40385 L
.71939 .42308 L
.71154 .42965 L
.69231 .42313 L
.69226 .42308 L
.6811 .40385 L
.68554 .38462 L
.69231 .38018 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57245 .5035 .56654 Mtetra
.663 .741 .908 r
.5035 .56654 .50935 .57245 .51999 .56925 .51417 .56333 Mtetra
.51417 .56333 .51999 .56925 .53068 .56605 .52489 .5601 Mtetra
.52489 .5601 .53068 .56605 .54141 .56283 .53564 .55687 Mtetra
.53564 .55687 .54141 .56283 .55218 .55961 .54644 .55363 Mtetra
.662 .742 .909 r
.54644 .55363 .55218 .55961 .56299 .55638 .55728 .5504 Mtetra
.662 .742 .91 r
.55728 .5504 .56299 .55638 .57385 .55315 .56817 .54718 Mtetra
.661 .743 .911 r
.56817 .54718 .57385 .55315 .58474 .54991 .57909 .54397 Mtetra
.659 .744 .913 r
.57909 .54397 .58474 .54991 .59569 .54668 .59006 .54078 Mtetra
.658 .746 .915 r
.59006 .54078 .59569 .54668 .60667 .54344 .60108 .53761 Mtetra
.657 .749 .918 r
.60108 .53761 .60667 .54344 .6177 .5402 .61214 .53444 Mtetra
.657 .752 .92 r
.61214 .53444 .6177 .5402 .62877 .53694 .62325 .53126 Mtetra
.658 .756 .922 r
.62325 .53126 .62877 .53694 .63989 .53366 .6344 .52802 Mtetra
.66 .759 .924 r
.6344 .52802 .63989 .53366 .65105 .53034 .6456 .52472 Mtetra
.662 .762 .924 r
.6456 .52472 .65105 .53034 .66226 .52698 .65683 .52134 Mtetra
.665 .762 .923 r
.65683 .52134 .66226 .52698 .6735 .52358 .66811 .51787 Mtetra
.667 .762 .921 r
.66811 .51787 .6735 .52358 .6848 .52014 .67943 .51433 Mtetra
.668 .759 .918 r
.67943 .51433 .6848 .52014 .69613 .51667 .6908 .51074 Mtetra
.668 .756 .916 r
.6908 .51074 .69613 .51667 .70751 .51319 .7022 .50714 Mtetra
.668 .752 .914 r
.7022 .50714 .70751 .51319 .71894 .5097 .71366 .50354 Mtetra
.667 .749 .912 r
.71366 .50354 .71894 .5097 .73041 .50621 .72516 .49995 Mtetra
.666 .746 .91 r
.72516 .49995 .73041 .50621 .74193 .50272 .73671 .49638 Mtetra
.665 .744 .909 r
.73671 .49638 .74193 .50272 .7535 .49923 .74831 .49283 Mtetra
.665 .743 .909 r
.74831 .49283 .7535 .49923 .76511 .49573 .75995 .48929 Mtetra
.664 .742 .908 r
.75995 .48929 .76511 .49573 .77677 .49223 .77165 .48575 Mtetra
.77165 .48575 .77677 .49223 .78848 .48871 .78339 .4822 Mtetra
.78339 .4822 .78848 .48871 .80024 .48518 .79518 .47864 Mtetra
.79518 .47864 .80024 .48518 .81205 .48164 .80702 .47507 Mtetra
.664 .741 .908 r
.80702 .47507 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .457 Mtetra
.86696 .457 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.663 .741 .908 r
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56333 .50831 .55736 Mtetra
.50831 .55736 .51417 .56333 .52489 .5601 .51905 .55412 Mtetra
.51905 .55412 .52489 .5601 .53564 .55687 .52983 .55087 Mtetra
.662 .742 .909 r
.52983 .55087 .53564 .55687 .54644 .55363 .54066 .54764 Mtetra
.661 .742 .91 r
.54066 .54764 .54644 .55363 .55728 .5504 .55153 .54443 Mtetra
.659 .743 .912 r
.55153 .54443 .55728 .5504 .56817 .54718 .56244 .54125 Mtetra
.656 .745 .915 r
.56244 .54125 .56817 .54718 .57909 .54397 .5734 .53813 Mtetra
.653 .748 .919 r
.5734 .53813 .57909 .54397 .59006 .54078 .58441 .53508 Mtetra
.65 .752 .924 r
.58441 .53508 .59006 .54078 .60108 .53761 .59546 .53207 Mtetra
.648 .758 .93 r
.59546 .53207 .60108 .53761 .61214 .53444 .60655 .5291 Mtetra
.647 .766 .936 r
.60655 .5291 .61214 .53444 .62325 .53126 .6177 .5261 Mtetra
.648 .774 .94 r
.6177 .5261 .62325 .53126 .6344 .52802 .62889 .52301 Mtetra
.653 .782 .943 r
.62889 .52301 .6344 .52802 .6456 .52472 .64012 .51978 Mtetra
.659 .787 .943 r
.64012 .51978 .6456 .52472 .65683 .52134 .65139 .51637 Mtetra
.665 .789 .941 r
.65139 .51637 .65683 .52134 .66811 .51787 .6627 .51278 Mtetra
.671 .787 .936 r
.6627 .51278 .66811 .51787 .67943 .51433 .67405 .50905 Mtetra
.674 .782 .931 r
.67405 .50905 .67943 .51433 .6908 .51074 .68544 .50523 Mtetra
.675 .774 .925 r
.68544 .50523 .6908 .51074 .7022 .50714 .69687 .50138 Mtetra
.674 .766 .92 r
.69687 .50138 .7022 .50714 .71366 .50354 .70835 .49756 Mtetra
.672 .759 .916 r
.70835 .49756 .71366 .50354 .72516 .49995 .71988 .4938 Mtetra
.67 .753 .913 r
.71988 .4938 .72516 .49995 .73671 .49638 .73145 .49009 Mtetra
.667 .748 .911 r
.73145 .49009 .73671 .49638 .74831 .49283 .74308 .48644 Mtetra
.666 .746 .91 r
.74308 .48644 .74831 .49283 .75995 .48929 .75476 .48283 Mtetra
.665 .744 .909 r
.75476 .48283 .75995 .48929 .77165 .48575 .76648 .47924 Mtetra
.664 .743 .909 r
.76648 .47924 .77165 .48575 .78339 .4822 .77826 .47565 Mtetra
.664 .742 .908 r
.77826 .47565 .78339 .4822 .79518 .47864 .79009 .47206 Mtetra
.79009 .47206 .79518 .47864 .80702 .47507 .80196 .46846 Mtetra
.80196 .46846 .80702 .47507 .81891 .47148 .81388 .46484 Mtetra
.81388 .46484 .81891 .47148 .83085 .46788 .82586 .46121 Mtetra
.82586 .46121 .83085 .46788 .84283 .46427 .83788 .45757 Mtetra
.83788 .45757 .84283 .46427 .85487 .46064 .84995 .45391 Mtetra
.664 .741 .908 r
.84995 .45391 .85487 .46064 .86696 .457 .86207 .45023 Mtetra
.86207 .45023 .86696 .457 .87909 .45334 .87424 .44655 Mtetra
.87424 .44655 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.663 .741 .908 r
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .55461 Mtetra
.49168 .55461 .49761 .56059 .50831 .55736 .5024 .55136 Mtetra
.5024 .55136 .50831 .55736 .51905 .55412 .51317 .5481 Mtetra
.662 .742 .909 r
.51317 .5481 .51905 .55412 .52983 .55087 .52398 .54486 Mtetra
.66 .742 .91 r
.52398 .54486 .52983 .55087 .54066 .54764 .53484 .54165 Mtetra
.658 .743 .913 r
.53484 .54165 .54066 .54764 .55153 .54443 .54574 .53851 Mtetra
.653 .745 .917 r
.54574 .53851 .55153 .54443 .56244 .54125 .55668 .53546 Mtetra
.647 .748 .923 r
.55668 .53546 .56244 .54125 .5734 .53813 .56767 .53254 Mtetra
.64 .754 .931 r
.56767 .53254 .5734 .53813 .58441 .53508 .57871 .52977 Mtetra
.631 .763 .942 r
.57871 .52977 .58441 .53508 .59546 .53207 .5898 .52714 Mtetra
.624 .775 .953 r
.5898 .52714 .59546 .53207 .60655 .5291 .60094 .52458 Mtetra
.619 .791 .965 r
.60094 .52458 .60655 .5291 .6177 .5261 .61213 .52199 Mtetra
.619 .809 .973 r
.61213 .52199 .6177 .5261 .62889 .52301 .62337 .51922 Mtetra
.627 .826 .977 r
.62337 .51922 .62889 .52301 .64012 .51978 .63465 .51616 Mtetra
.642 .838 .976 r
.63465 .51616 .64012 .51978 .65139 .51637 .64596 .51272 Mtetra
.659 .843 .971 r
.64596 .51272 .65139 .51637 .6627 .51278 .6573 .50892 Mtetra
.675 .839 .962 r
.6573 .50892 .6627 .51278 .67405 .50905 .66868 .50482 Mtetra
.684 .827 .952 r
.66868 .50482 .67405 .50905 .68544 .50523 .68008 .50054 Mtetra
.688 .811 .941 r
.68008 .50054 .68544 .50523 .69687 .50138 .69153 .49623 Mtetra
.686 .794 .931 r
.69153 .49623 .69687 .50138 .70835 .49756 .70303 .492 Mtetra
.682 .778 .924 r
.70303 .492 .70835 .49756 .71988 .4938 .71457 .48789 Mtetra
.677 .765 .918 r
.71457 .48789 .71988 .4938 .73145 .49009 .72617 .48394 Mtetra
.672 .756 .914 r
.72617 .48394 .73145 .49009 .74308 .48644 .73782 .48012 Mtetra
.669 .75 .912 r
.73782 .48012 .74308 .48644 .75476 .48283 .74953 .4764 Mtetra
.666 .747 .91 r
.74953 .4764 .75476 .48283 .76648 .47924 .76129 .47273 Mtetra
.665 .745 .91 r
.76129 .47273 .76648 .47924 .77826 .47565 .77309 .46909 Mtetra
.664 .744 .909 r
.77309 .46909 .77826 .47565 .79009 .47206 .78495 .46546 Mtetra
.664 .743 .909 r
.78495 .46546 .79009 .47206 .80196 .46846 .79686 .46182 Mtetra
.79686 .46182 .80196 .46846 .81388 .46484 .80882 .45817 Mtetra
.80882 .45817 .81388 .46484 .82586 .46121 .82083 .4545 Mtetra
.664 .742 .908 r
.82083 .4545 .82586 .46121 .83788 .45757 .83288 .45083 Mtetra
.83288 .45083 .83788 .45757 .84995 .45391 .84499 .44713 Mtetra
.84499 .44713 .84995 .45391 .86207 .45023 .85715 .44343 Mtetra
.85715 .44343 .86207 .45023 .87424 .44655 .86936 .43971 Mtetra
.86936 .43971 .87424 .44655 .88647 .44284 .88162 .43597 Mtetra
.664 .741 .908 r
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.663 .741 .908 r
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .55511 Mtetra
.46432 .55511 .47035 .56109 .48099 .55785 .47499 .55185 Mtetra
.47499 .55185 .48099 .55785 .49168 .55461 .4857 .54859 Mtetra
.663 .741 .909 r
.4857 .54859 .49168 .55461 .5024 .55136 .49646 .54532 Mtetra
.662 .742 .909 r
.49646 .54532 .5024 .55136 .51317 .5481 .50725 .54207 Mtetra
.66 .742 .91 r
.50725 .54207 .51317 .5481 .52398 .54486 .51809 .53885 Mtetra
.657 .743 .913 r
.51809 .53885 .52398 .54486 .53484 .54165 .52897 .53571 Mtetra
.651 .744 .918 r
.52897 .53571 .53484 .54165 .54574 .53851 .5399 .53271 Mtetra
.642 .747 .925 r
.5399 .53271 .54574 .53851 .55668 .53546 .55088 .52991 Mtetra
.629 .753 .936 r
.55088 .52991 .55668 .53546 .56767 .53254 .5619 .5274 Mtetra
.61 .762 .952 r
.5619 .5274 .56767 .53254 .57871 .52977 .57298 .52519 Mtetra
.584 .777 .971 r
.57298 .52519 .57871 .52977 .5898 .52714 .58412 .52327 Mtetra
.554 .797 .989 r
.58412 .52327 .5898 .52714 .60094 .52458 .59531 .52151 Mtetra
.524 .821 .999 r
.59531 .52151 .60094 .52458 .61213 .52199 .60656 .51968 Mtetra
.505 .845 .996 r
.60656 .51968 .61213 .52199 .62337 .51922 .61786 .51754 Mtetra
.51 .87 .985 r
.61786 .51754 .62337 .51922 .63465 .51616 .62919 .51481 Mtetra
.545 .896 .977 r
.62919 .51481 .63465 .51616 .64596 .51272 .64055 .51135 Mtetra
.601 .916 .976 r
.64055 .51135 .64596 .51272 .6573 .50892 .65193 .50716 Mtetra
.655 .921 .976 r
.65193 .50716 .6573 .50892 .66868 .50482 .66333 .5024 Mtetra
.692 .905 .971 r
.66333 .5024 .66868 .50482 .68008 .50054 .67475 .49731 Mtetra
.708 .876 .96 r
.67475 .49731 .68008 .50054 .69153 .49623 .6862 .49216 Mtetra
.708 .843 .947 r
.6862 .49216 .69153 .49623 .70303 .492 .6977 .48717 Mtetra
.7 .812 .935 r
.6977 .48717 .70303 .492 .71457 .48789 .70925 .48246 Mtetra
.69 .788 .925 r
.70925 .48246 .71457 .48789 .72617 .48394 .72087 .47808 Mtetra
.68 .77 .919 r
.72087 .47808 .72617 .48394 .73782 .48012 .73254 .47397 Mtetra
.673 .759 .915 r
.73254 .47397 .73782 .48012 .74953 .4764 .74427 .47006 Mtetra
.669 .752 .913 r
.74427 .47006 .74953 .4764 .76129 .47273 .75605 .46629 Mtetra
.666 .749 .912 r
.75605 .46629 .76129 .47273 .77309 .46909 .7679 .46258 Mtetra
.665 .747 .911 r
.7679 .46258 .77309 .46909 .78495 .46546 .77979 .45889 Mtetra
.665 .746 .911 r
.77979 .45889 .78495 .46546 .79686 .46182 .79173 .4552 Mtetra
.664 .745 .91 r
.79173 .4552 .79686 .46182 .80882 .45817 .80372 .4515 Mtetra
.664 .744 .91 r
.80372 .4515 .80882 .45817 .82083 .4545 .81576 .44779 Mtetra
.664 .744 .909 r
.81576 .44779 .82083 .4545 .83288 .45083 .82785 .44406 Mtetra
.664 .743 .909 r
.82785 .44406 .83288 .45083 .84499 .44713 .84 .44033 Mtetra
.84 .44033 .84499 .44713 .85715 .44343 .85219 .43658 Mtetra
.664 .742 .908 r
.85219 .43658 .85715 .44343 .86936 .43971 .86444 .43282 Mtetra
.86444 .43282 .86936 .43971 .88162 .43597 .87673 .42905 Mtetra
.87673 .42905 .88162 .43597 .89393 .43222 .88908 .42527 Mtetra
.664 .741 .908 r
.88908 .42527 .89393 .43222 .9063 .42846 .90149 .42148 Mtetra
.90149 .42148 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.663 .741 .908 r
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55835 .4476 .55235 Mtetra
.4476 .55235 .45369 .55835 .46432 .55511 .45825 .54908 Mtetra
.45825 .54908 .46432 .55511 .47499 .55185 .46895 .54581 Mtetra
.663 .742 .909 r
.46895 .54581 .47499 .55185 .4857 .54859 .47968 .54253 Mtetra
.662 .742 .909 r
.47968 .54253 .4857 .54859 .49646 .54532 .49046 .53927 Mtetra
.66 .742 .91 r
.49046 .53927 .49646 .54532 .50725 .54207 .50129 .53604 Mtetra
.657 .743 .913 r
.50129 .53604 .50725 .54207 .51809 .53885 .51215 .53288 Mtetra
.651 .744 .917 r
.51215 .53288 .51809 .53885 .52897 .53571 .52306 .52988 Mtetra
.64 .746 .926 r
.52306 .52988 .52897 .53571 .5399 .53271 .53402 .52714 Mtetra
.621 .75 .939 r
.53402 .52714 .5399 .53271 .55088 .52991 .54503 .5248 Mtetra
.589 .757 .958 r
.54503 .5248 .55088 .52991 .5619 .5274 .55609 .52298 Mtetra
.537 .768 .982 r
.55609 .52298 .5619 .5274 .57298 .52519 .56722 .52175 Mtetra
.452 .774 .998 r
.56722 .52175 .57298 .52519 .58412 .52327 .57841 .52106 Mtetra
.322 .758 .968 r
.57841 .52106 .58412 .52327 .59531 .52151 .58968 .52069 Mtetra
.17 .699 .855 r
.58968 .52069 .59531 .52151 .60656 .51968 .601 .52022 Mtetra
0 0 0 r
.601 .52022 .60656 .51968 .61786 .51754 .61238 .51915 Mtetra
.61238 .51915 .61786 .51754 .62919 .51481 .62379 .51702 Mtetra
.62379 .51702 .62919 .51481 .64055 .51135 .63521 .51354 Mtetra
.285 .764 .662 r
.63521 .51354 .64055 .51135 .65193 .50716 .64663 .50871 Mtetra
.474 .889 .784 r
.64663 .50871 .65193 .50716 .66333 .5024 .65804 .50283 Mtetra
.633 .963 .891 r
.65804 .50283 .66333 .5024 .67475 .49731 .66946 .49634 Mtetra
.717 .961 .944 r
.66946 .49634 .67475 .49731 .6862 .49216 .68091 .48977 Mtetra
.738 .918 .953 r
.68091 .48977 .6862 .49216 .6977 .48717 .69239 .48352 Mtetra
.729 .867 .946 r
.69239 .48352 .6977 .48717 .70925 .48246 .70394 .47781 Mtetra
.711 .825 .935 r
.70394 .47781 .70925 .48246 .72087 .47808 .71555 .47271 Mtetra
.694 .794 .927 r
.71555 .47271 .72087 .47808 .73254 .47397 .72723 .46814 Mtetra
.681 .775 .921 r
.72723 .46814 .73254 .47397 .74427 .47006 .73898 .46395 Mtetra
.673 .763 .918 r
.73898 .46395 .74427 .47006 .75605 .46629 .7508 .46002 Mtetra
.668 .757 .917 r
.7508 .46002 .75605 .46629 .7679 .46258 .76267 .4562 Mtetra
.666 .754 .916 r
.76267 .4562 .7679 .46258 .77979 .45889 .77459 .45244 Mtetra
.666 .752 .915 r
.77459 .45244 .77979 .45889 .79173 .4552 .78657 .44868 Mtetra
.666 .751 .914 r
.78657 .44868 .79173 .4552 .80372 .4515 .79859 .44491 Mtetra
.666 .749 .912 r
.79859 .44491 .80372 .4515 .81576 .44779 .81067 .44112 Mtetra
.666 .747 .911 r
.81067 .44112 .81576 .44779 .82785 .44406 .82279 .43732 Mtetra
.665 .746 .91 r
.82279 .43732 .82785 .44406 .84 .44033 .83497 .43352 Mtetra
.665 .745 .909 r
.83497 .43352 .84 .44033 .85219 .43658 .8472 .42971 Mtetra
.665 .743 .909 r
.8472 .42971 .85219 .43658 .86444 .43282 .85948 .4259 Mtetra
.664 .743 .908 r
.85948 .4259 .86444 .43282 .87673 .42905 .87181 .42209 Mtetra
.664 .742 .908 r
.87181 .42209 .87673 .42905 .88908 .42527 .8842 .41827 Mtetra
.8842 .41827 .88908 .42527 .90149 .42148 .89664 .41444 Mtetra
.89664 .41444 .90149 .42148 .91394 .41767 .90913 .4106 Mtetra
.664 .741 .908 r
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.663 .741 .908 r
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54958 Mtetra
.43081 .54958 .43698 .55561 .4476 .55235 .44145 .54631 Mtetra
.663 .742 .908 r
.44145 .54631 .4476 .55235 .45825 .54908 .45213 .54303 Mtetra
.663 .742 .909 r
.45213 .54303 .45825 .54908 .46895 .54581 .46285 .53975 Mtetra
.662 .742 .91 r
.46285 .53975 .46895 .54581 .47968 .54253 .47362 .53647 Mtetra
.66 .742 .911 r
.47362 .53647 .47968 .54253 .49046 .53927 .48443 .53323 Mtetra
.658 .743 .913 r
.48443 .53323 .49046 .53927 .50129 .53604 .49528 .53005 Mtetra
.652 .744 .917 r
.49528 .53005 .50129 .53604 .51215 .53288 .50617 .52701 Mtetra
.64 .745 .925 r
.50617 .52701 .51215 .53288 .52306 .52988 .51711 .52424 Mtetra
.619 .748 .938 r
.51711 .52424 .52306 .52988 .53402 .52714 .5281 .52193 Mtetra
.58 .751 .959 r
.5281 .52193 .53402 .52714 .54503 .5248 .53914 .52031 Mtetra
.503 .752 .985 r
.53914 .52031 .54503 .5248 .55609 .52298 .55024 .51959 Mtetra
.351 .728 .986 r
.55024 .51959 .55609 .52298 .56722 .52175 .56142 .51992 Mtetra
.074 .61 .859 r
.56142 .51992 .56722 .52175 .57841 .52106 .57268 .52118 Mtetra
.23 0 0 r
.57268 .52118 .57841 .52106 .58968 .52069 .58403 .523 Mtetra
.384 0 0 r
.58403 .523 .58968 .52069 .601 .52022 .59546 .52467 Mtetra
.41 0 0 r
.59546 .52467 .601 .52022 .61238 .51915 .60695 .52533 Mtetra
.367 0 .001 r
.60695 .52533 .61238 .51915 .62379 .51702 .61846 .52416 Mtetra
.274 0 0 r
.61846 .52416 .62379 .51702 .63521 .51354 .62995 .52066 Mtetra
.126 0 0 r
.62995 .52066 .63521 .51354 .64663 .50871 .64142 .51484 Mtetra
0 0 0 r
.64142 .51484 .64663 .50871 .65804 .50283 .65285 .50719 Mtetra
.65285 .50719 .65804 .50283 .66946 .49634 .66425 .49854 Mtetra
.632 .951 .761 r
.66425 .49854 .66946 .49634 .68091 .48977 .67567 .48975 Mtetra
.752 .987 .898 r
.67567 .48975 .68091 .48977 .69239 .48352 .68712 .48154 Mtetra
.767 .938 .939 r
.68712 .48154 .69239 .48352 .70394 .47781 .69863 .4743 Mtetra
.743 .878 .942 r
.69863 .4743 .70394 .47781 .71555 .47271 .71024 .46812 Mtetra
.715 .831 .937 r
.71024 .46812 .71555 .47271 .72723 .46814 .72192 .46287 Mtetra
.693 .8 .932 r
.72192 .46287 .72723 .46814 .73898 .46395 .73369 .45829 Mtetra
.679 .782 .928 r
.73369 .45829 .73898 .46395 .7508 .46002 .74553 .45413 Mtetra
.671 .773 .926 r
.74553 .45413 .7508 .46002 .76267 .4562 .75743 .45018 Mtetra
.668 .768 .925 r
.75743 .45018 .76267 .4562 .77459 .45244 .76939 .4463 Mtetra
.668 .765 .923 r
.76939 .4463 .77459 .45244 .78657 .44868 .78139 .44242 Mtetra
.669 .762 .92 r
.78139 .44242 .78657 .44868 .79859 .44491 .79345 .43852 Mtetra
.669 .759 .918 r
.79345 .43852 .79859 .44491 .81067 .44112 .80555 .4346 Mtetra
.669 .755 .915 r
.80555 .4346 .81067 .44112 .82279 .43732 .8177 .43068 Mtetra
.668 .752 .913 r
.8177 .43068 .82279 .43732 .83497 .43352 .82991 .42676 Mtetra
.667 .749 .911 r
.82991 .42676 .83497 .43352 .8472 .42971 .84217 .42286 Mtetra
.666 .746 .91 r
.84217 .42286 .8472 .42971 .85948 .4259 .85448 .41897 Mtetra
.665 .744 .909 r
.85448 .41897 .85948 .4259 .87181 .42209 .86685 .41509 Mtetra
.665 .743 .909 r
.86685 .41509 .87181 .42209 .8842 .41827 .87927 .41123 Mtetra
.664 .742 .908 r
.87927 .41123 .8842 .41827 .89664 .41444 .89175 .40735 Mtetra
.89175 .40735 .89664 .41444 .90913 .4106 .90428 .40348 Mtetra
.90428 .40348 .90913 .4106 .92168 .40674 .91687 .39959 Mtetra
.664 .741 .908 r
.91687 .39959 .92168 .40674 .93428 .40287 .92951 .39569 Mtetra
.92951 .39569 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.663 .741 .908 r
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55285 .41397 .54681 Mtetra
.41397 .54681 .42022 .55285 .43081 .54958 .4246 .54353 Mtetra
.663 .742 .909 r
.4246 .54353 .43081 .54958 .44145 .54631 .43526 .54025 Mtetra
.662 .742 .909 r
.43526 .54025 .44145 .54631 .45213 .54303 .44597 .53696 Mtetra
.661 .742 .91 r
.44597 .53696 .45213 .54303 .46285 .53975 .45672 .53369 Mtetra
.66 .743 .912 r
.45672 .53369 .46285 .53975 .47362 .53647 .46751 .53045 Mtetra
.657 .744 .914 r
.46751 .53045 .47362 .53647 .48443 .53323 .47834 .52726 Mtetra
.653 .746 .918 r
.47834 .52726 .48443 .53323 .49528 .53005 .48922 .52418 Mtetra
.643 .747 .925 r
.48922 .52418 .49528 .53005 .50617 .52701 .50014 .52134 Mtetra
.623 .749 .937 r
.50014 .52134 .50617 .52701 .51711 .52424 .51111 .51893 Mtetra
.584 .75 .956 r
.51111 .51893 .51711 .52424 .5281 .52193 .52212 .51724 Mtetra
.5 .744 .982 r
.52212 .51724 .5281 .52193 .53914 .52031 .5332 .51666 Mtetra
.313 .698 .979 r
.5332 .51666 .53914 .52031 .55024 .51959 .54435 .51753 Mtetra
0 .499 .787 r
.54435 .51753 .55024 .51959 .56142 .51992 .55558 .52007 Mtetra
.44 0 0 r
.55558 .52007 .56142 .51992 .57268 .52118 .56692 .52414 Mtetra
.583 .065 0 r
.56692 .52414 .57268 .52118 .58403 .523 .57838 .52912 Mtetra
.6 .149 .152 r
.57838 .52912 .58403 .523 .59546 .52467 .58993 .5339 Mtetra
.567 .16 .229 r
.58993 .5339 .59546 .52467 .60695 .52533 .60155 .53707 Mtetra
.506 .126 .254 r
.60155 .53707 .60695 .52533 .61846 .52416 .61319 .5373 Mtetra
.416 .055 .241 r
.61319 .5373 .61846 .52416 .62995 .52066 .62479 .53379 Mtetra
.291 0 .187 r
.62479 .53379 .62995 .52066 .64142 .51484 .63631 .52653 Mtetra
.115 0 .074 r
.63631 .52653 .64142 .51484 .65285 .50719 .64775 .51635 Mtetra
0 0 0 r
.64775 .51635 .65285 .50719 .66425 .49854 .65913 .50458 Mtetra
.65913 .50458 .66425 .49854 .67567 .48975 .67049 .49264 Mtetra
.698 .962 .714 r
.67049 .49264 .67567 .48975 .68712 .48154 .68189 .48167 Mtetra
.791 .993 .877 r
.68189 .48167 .68712 .48154 .69863 .4743 .69336 .4723 Mtetra
.779 .94 .932 r
.69336 .4723 .69863 .4743 .71024 .46812 .70494 .46465 Mtetra
.74 .881 .945 r
.70494 .46465 .71024 .46812 .72192 .46287 .71662 .45849 Mtetra
.706 .84 .946 r
.71662 .45849 .72192 .46287 .73369 .45829 .7284 .45341 Mtetra
.684 .815 .946 r
.7284 .45341 .73369 .45829 .74553 .45413 .74027 .44898 Mtetra
.673 .803 .944 r
.74027 .44898 .74553 .45413 .75743 .45018 .7522 .44486 Mtetra
.67 .796 .942 r
.7522 .44486 .75743 .45018 .76939 .4463 .76419 .44082 Mtetra
.672 .792 .938 r
.76419 .44082 .76939 .4463 .78139 .44242 .77622 .43674 Mtetra
.674 .786 .934 r
.77622 .43674 .78139 .44242 .79345 .43852 .7883 .43261 Mtetra
.675 .779 .928 r
.7883 .43261 .79345 .43852 .80555 .4346 .80043 .42845 Mtetra
.675 .772 .923 r
.80043 .42845 .80555 .4346 .8177 .43068 .8126 .42428 Mtetra
.673 .764 .919 r
.8126 .42428 .8177 .43068 .82991 .42676 .82483 .42016 Mtetra
.671 .757 .915 r
.82483 .42016 .82991 .42676 .84217 .42286 .83711 .41608 Mtetra
.669 .752 .912 r
.83711 .41608 .84217 .42286 .85448 .41897 .84946 .41206 Mtetra
.667 .748 .911 r
.84946 .41206 .85448 .41897 .86685 .41509 .86186 .40809 Mtetra
.666 .745 .909 r
.86186 .40809 .86685 .41509 .87927 .41123 .87431 .40415 Mtetra
.665 .743 .909 r
.87431 .40415 .87927 .41123 .89175 .40735 .88683 .40023 Mtetra
.664 .742 .908 r
.88683 .40023 .89175 .40735 .90428 .40348 .8994 .3963 Mtetra
.8994 .3963 .90428 .40348 .91687 .39959 .91202 .39238 Mtetra
.91202 .39238 .91687 .39959 .92951 .39569 .9247 .38844 Mtetra
.664 .741 .908 r
.9247 .38844 .92951 .39569 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.663 .741 .908 r
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .54731 Mtetra
.38651 .54731 .39285 .55335 .40339 .55008 .39708 .54403 Mtetra
.39708 .54403 .40339 .55008 .41397 .54681 .40769 .54074 Mtetra
.662 .742 .909 r
.40769 .54074 .41397 .54681 .4246 .54353 .41833 .53745 Mtetra
.662 .742 .91 r
.41833 .53745 .4246 .54353 .43526 .54025 .42903 .53418 Mtetra
.66 .743 .911 r
.42903 .53418 .43526 .54025 .44597 .53696 .43976 .53092 Mtetra
.658 .744 .913 r
.43976 .53092 .44597 .53696 .45672 .53369 .45053 .52771 Mtetra
.656 .746 .916 r
.45053 .52771 .45672 .53369 .46751 .53045 .46135 .52455 Mtetra
.651 .748 .921 r
.46135 .52455 .46751 .53045 .47834 .52726 .47221 .52149 Mtetra
.643 .751 .927 r
.47221 .52149 .47834 .52726 .48922 .52418 .48311 .5186 Mtetra
.627 .754 .938 r
.48311 .5186 .48922 .52418 .50014 .52134 .49406 .51606 Mtetra
.594 .755 .955 r
.49406 .51606 .50014 .52134 .51111 .51893 .50505 .51415 Mtetra
.52 .749 .979 r
.50505 .51415 .51111 .51893 .52212 .51724 .5161 .51329 Mtetra
.346 .703 .984 r
.5161 .51329 .52212 .51724 .5332 .51666 .52721 .51404 Mtetra
0 .498 .816 r
.52721 .51404 .5332 .51666 .54435 .51753 .5384 .51695 Mtetra
.495 0 0 r
.5384 .51695 .54435 .51753 .55558 .52007 .54969 .52234 Mtetra
.667 .162 .034 r
.54969 .52234 .55558 .52007 .56692 .52414 .56112 .53004 Mtetra
.695 .261 .216 r
.56112 .53004 .56692 .52414 .57838 .52912 .57269 .53914 Mtetra
.673 .285 .303 r
.57269 .53914 .57838 .52912 .58993 .5339 .58439 .54799 Mtetra
.626 .269 .344 r
.58439 .54799 .58993 .5339 .60155 .53707 .59617 .55446 Mtetra
.559 .223 .355 r
.59617 .55446 .60155 .53707 .61319 .5373 .60797 .55655 Mtetra
.467 .148 .34 r
.60797 .55655 .61319 .5373 .62479 .53379 .61969 .55303 Mtetra
.344 .039 .295 r
.61969 .55303 .62479 .53379 .63631 .52653 .63128 .54389 Mtetra
.177 0 .208 r
.63128 .54389 .63631 .52653 .64775 .51635 .64274 .53039 Mtetra
0 0 .055 r
.64274 .53039 .64775 .51635 .65913 .50458 .65408 .51455 Mtetra
0 0 0 r
.65408 .51455 .65913 .50458 .67049 .49264 .66537 .49855 Mtetra
.615 .855 .491 r
.66537 .49855 .67049 .49264 .68189 .48167 .6767 .48408 Mtetra
.779 .988 .748 r
.6767 .48408 .68189 .48167 .69336 .4723 .68812 .47205 Mtetra
.801 .988 .886 r
.68812 .47205 .69336 .4723 .70494 .46465 .69967 .46264 Mtetra
.759 .94 .942 r
.69967 .46264 .70494 .46465 .71662 .45849 .71135 .45545 Mtetra
.712 .896 .963 r
.71135 .45545 .71662 .45849 .7284 .45341 .72315 .44985 Mtetra
.68 .869 .97 r
.72315 .44985 .7284 .45341 .74027 .44898 .73505 .44516 Mtetra
.666 .855 .972 r
.73505 .44516 .74027 .44898 .7522 .44486 .74702 .44084 Mtetra
.666 .849 .97 r
.74702 .44084 .7522 .44486 .76419 .44082 .75904 .43656 Mtetra
.674 .842 .964 r
.75904 .43656 .76419 .44082 .77622 .43674 .77109 .43215 Mtetra
.682 .832 .956 r
.77109 .43215 .77622 .43674 .7883 .43261 .78319 .4276 Mtetra
.686 .818 .946 r
.78319 .4276 .7883 .43261 .80043 .42845 .79532 .42299 Mtetra
.687 .803 .937 r
.79532 .42299 .80043 .42845 .8126 .42428 .80751 .41839 Mtetra
.684 .787 .928 r
.80751 .41839 .8126 .42428 .82483 .42016 .81974 .41388 Mtetra
.68 .773 .921 r
.81974 .41388 .82483 .42016 .83711 .41608 .83204 .4095 Mtetra
.675 .762 .916 r
.83204 .4095 .83711 .41608 .84946 .41206 .84441 .40525 Mtetra
.671 .754 .913 r
.84441 .40525 .84946 .41206 .86186 .40809 .85683 .40112 Mtetra
.668 .749 .911 r
.85683 .40112 .86186 .40809 .87431 .40415 .86932 .39706 Mtetra
.666 .745 .909 r
.86932 .39706 .87431 .40415 .88683 .40023 .88187 .39306 Mtetra
.665 .743 .909 r
.88187 .39306 .88683 .40023 .8994 .3963 .89447 .38909 Mtetra
.664 .742 .908 r
.89447 .38909 .8994 .3963 .91202 .39238 .90714 .38512 Mtetra
.90714 .38512 .91202 .39238 .9247 .38844 .91985 .38114 Mtetra
.664 .741 .908 r
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37716 Mtetra
.663 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .54731 .38013 .54123 Mtetra
.38013 .54123 .38651 .54731 .39708 .54403 .39072 .53793 Mtetra
.662 .742 .909 r
.39072 .53793 .39708 .54403 .40769 .54074 .40135 .53464 Mtetra
.661 .742 .91 r
.40135 .53464 .40769 .54074 .41833 .53745 .41203 .53137 Mtetra
.659 .743 .912 r
.41203 .53137 .41833 .53745 .42903 .53418 .42274 .52814 Mtetra
.656 .744 .915 r
.42274 .52814 .42903 .53418 .43976 .53092 .4335 .52497 Mtetra
.652 .747 .919 r
.4335 .52497 .43976 .53092 .45053 .52771 .4443 .52189 Mtetra
.647 .751 .925 r
.4443 .52189 .45053 .52771 .46135 .52455 .45514 .51893 Mtetra
.639 .756 .933 r
.45514 .51893 .46135 .52455 .47221 .52149 .46602 .51613 Mtetra
.625 .762 .945 r
.46602 .51613 .47221 .52149 .48311 .5186 .47695 .51358 Mtetra
.598 .767 .96 r
.47695 .51358 .48311 .5186 .49406 .51606 .48792 .51149 Mtetra
.54 .766 .981 r
.48792 .51149 .49406 .51606 .50505 .51415 .49894 .51022 Mtetra
.4 .733 .991 r
.49894 .51022 .50505 .51415 .5161 .51329 .51002 .51034 Mtetra
.066 .573 .885 r
.51002 .51034 .5161 .51329 .52721 .51404 .52116 .51263 Mtetra
.429 0 0 r
.52116 .51263 .52721 .51404 .5384 .51695 .53239 .51784 Mtetra
.685 .163 0 r
.53239 .51784 .5384 .51695 .54969 .52234 .54374 .52648 Mtetra
.746 .305 .203 r
.54374 .52648 .54969 .52234 .56112 .53004 .55525 .53834 Mtetra
.743 .352 .311 r
.55525 .53834 .56112 .53004 .57269 .53914 .56694 .55222 Mtetra
.712 .353 .367 r
.56694 .55222 .57269 .53914 .58439 .54799 .57879 .56582 Mtetra
.661 .325 .393 r
.57879 .56582 .58439 .54799 .59617 .55446 .59075 .57619 Mtetra
.588 .269 .397 r
.59075 .57619 .59617 .55446 .60797 .55655 .60272 .58047 Mtetra
.486 .185 .379 r
.60272 .58047 .60797 .55655 .61969 .55303 .61458 .57693 Mtetra
.347 .064 .334 r
.61458 .57693 .61969 .55303 .63128 .54389 .62626 .56556 Mtetra
.161 0 .247 r
.62626 .56556 .63128 .54389 .64274 .53039 .63773 .54815 Mtetra
0 0 .103 r
.63773 .54815 .64274 .53039 .65408 .51455 .64904 .52759 Mtetra
0 0 0 r
.64904 .52759 .65408 .51455 .66537 .49855 .66027 .50693 Mtetra
.66027 .50693 .66537 .49855 .6767 .48408 .67153 .48853 Mtetra
.755 .944 .615 r
.67153 .48853 .6767 .48408 .68812 .47205 .6829 .47363 Mtetra
.789 .997 .797 r
.6829 .47363 .68812 .47205 .69967 .46264 .69443 .46243 Mtetra
.741 .985 .903 r
.69443 .46243 .69967 .46264 .71135 .45545 .70613 .45432 Mtetra
.671 .952 .952 r
.70613 .45432 .71135 .45545 .72315 .44985 .71797 .44834 Mtetra
.618 .927 .97 r
.71797 .44834 .72315 .44985 .73505 .44516 .72992 .4435 Mtetra
.601 .918 .975 r
.72992 .4435 .73505 .44516 .74702 .44084 .74194 .439 Mtetra
.617 .918 .977 r
.74194 .439 .74702 .44084 .75904 .43656 .75399 .43437 Mtetra
.649 .918 .978 r
.75399 .43437 .75904 .43656 .77109 .43215 .76606 .42941 Mtetra
.681 .908 .974 r
.76606 .42941 .77109 .43215 .78319 .4276 .77815 .42414 Mtetra
.7 .886 .966 r
.77815 .42414 .78319 .4276 .79532 .42299 .79028 .41874 Mtetra
.707 .857 .954 r
.79028 .41874 .79532 .42299 .80751 .41839 .80245 .41337 Mtetra
.703 .827 .941 r
.80245 .41337 .80751 .41839 .81974 .41388 .81467 .4082 Mtetra
.695 .801 .931 r
.81467 .4082 .81974 .41388 .83204 .4095 .82697 .40328 Mtetra
.687 .78 .922 r
.82697 .40328 .83204 .4095 .84441 .40525 .83934 .39864 Mtetra
.679 .765 .916 r
.83934 .39864 .84441 .40525 .85683 .40112 .85178 .39423 Mtetra
.673 .755 .912 r
.85178 .39423 .85683 .40112 .86932 .39706 .86429 .39 Mtetra
.669 .749 .91 r
.86429 .39 .86932 .39706 .88187 .39306 .87687 .38588 Mtetra
.666 .745 .909 r
.87687 .38588 .88187 .39306 .89447 .38909 .88951 .38183 Mtetra
.665 .743 .908 r
.88951 .38183 .89447 .38909 .90714 .38512 .90221 .3778 Mtetra
.664 .742 .908 r
.90221 .3778 .90714 .38512 .91985 .38114 .91497 .37379 Mtetra
.91497 .37379 .91985 .38114 .93263 .37716 .92779 .36977 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53842 Mtetra
.36312 .53842 .36958 .54452 .38013 .54123 .37369 .53511 Mtetra
.662 .741 .909 r
.37369 .53511 .38013 .54123 .39072 .53793 .38431 .53181 Mtetra
.661 .742 .91 r
.38431 .53181 .39072 .53793 .40135 .53464 .39497 .52854 Mtetra
.658 .742 .912 r
.39497 .52854 .40135 .53464 .41203 .53137 .40567 .52533 Mtetra
.654 .744 .916 r
.40567 .52533 .41203 .53137 .42274 .52814 .4164 .52221 Mtetra
.648 .747 .922 r
.4164 .52221 .42274 .52814 .4335 .52497 .42718 .51923 Mtetra
.639 .752 .93 r
.42718 .51923 .4335 .52497 .4443 .52189 .438 .51644 Mtetra
.627 .759 .942 r
.438 .51644 .4443 .52189 .45514 .51893 .44886 .51387 Mtetra
.61 .77 .957 r
.44886 .51387 .45514 .51893 .46602 .51613 .45977 .51156 Mtetra
.582 .781 .974 r
.45977 .51156 .46602 .51613 .47695 .51358 .47072 .50959 Mtetra
.53 .787 .991 r
.47072 .50959 .47695 .51358 .48792 .51149 .48172 .50816 Mtetra
.417 .767 .996 r
.48172 .50816 .48792 .51149 .49894 .51022 .49276 .50767 Mtetra
.158 .649 .918 r
.49276 .50767 .49894 .51022 .51002 .51034 .50387 .50884 Mtetra
.29 0 0 r
.50387 .50884 .51002 .51034 .52116 .51263 .51504 .51263 Mtetra
.63 .076 0 r
.51504 .51263 .52116 .51263 .53239 .51784 .5263 .52007 Mtetra
.754 .286 .135 r
.5263 .52007 .53239 .51784 .54374 .52648 .53771 .53186 Mtetra
.783 .374 .276 r
.53771 .53186 .54374 .52648 .55525 .53834 .54929 .5478 Mtetra
.775 .402 .35 r
.54929 .5478 .55525 .53834 .56694 .55222 .56109 .56643 Mtetra
.744 .394 .39 r
.56109 .56643 .56694 .55222 .57879 .56582 .57308 .58484 Mtetra
.691 .359 .408 r
.57308 .58484 .57879 .56582 .59075 .57619 .58521 .59917 Mtetra
.61 .293 .408 r
.58521 .59917 .59075 .57619 .60272 .58047 .59734 .6057 Mtetra
.488 .189 .384 r
.59734 .6057 .60272 .58047 .61458 .57693 .60935 .60211 Mtetra
.31 .035 .325 r
.60935 .60211 .61458 .57693 .62626 .56556 .62113 .58842 Mtetra
.066 0 .215 r
.62113 .58842 .62626 .56556 .63773 .54815 .63263 .56699 Mtetra
0 0 .048 r
.63263 .56699 .63773 .54815 .64904 .52759 .64393 .54166 Mtetra
0 0 0 r
.64393 .54166 .64904 .52759 .66027 .50693 .65512 .51641 Mtetra
.676 .81 .36 r
.65512 .51641 .66027 .50693 .67153 .48853 .66634 .49429 Mtetra
.759 .916 .543 r
.66634 .49429 .67153 .48853 .6829 .47363 .6777 .47687 Mtetra
.737 .965 .69 r
.6777 .47687 .6829 .47363 .69443 .46243 .68925 .46432 Mtetra
.618 .949 .773 r
.68925 .46432 .69443 .46243 .70613 .45432 .70099 .45575 Mtetra
.45 .876 .774 r
.70099 .45575 .70613 .45432 .71797 .44834 .71291 .44981 Mtetra
.322 .8 .729 r
.71291 .44981 .71797 .44834 .72992 .4435 .72493 .44509 Mtetra
.289 .776 .703 r
.72493 .44509 .72992 .4435 .74194 .439 .73701 .4405 Mtetra
.348 .814 .73 r
.73701 .4405 .74194 .439 .75399 .43437 .7491 .43538 Mtetra
.467 .888 .802 r
.7491 .43538 .75399 .43437 .76606 .42941 .76118 .42953 Mtetra
.597 .95 .884 r
.76118 .42953 .76606 .42941 .77815 .42414 .77325 .42308 Mtetra
.688 .964 .938 r
.77325 .42308 .77815 .42414 .79028 .41874 .78534 .41636 Mtetra
.728 .936 .955 r
.78534 .41636 .79028 .41874 .80245 .41337 .79746 .40972 Mtetra
.733 .89 .952 r
.79746 .40972 .80245 .41337 .81467 .4082 .80964 .40343 Mtetra
.721 .845 .94 r
.80964 .40343 .81467 .4082 .82697 .40328 .82191 .39764 Mtetra
.706 .809 .929 r
.82191 .39764 .82697 .40328 .83934 .39864 .83427 .39235 Mtetra
.691 .783 .921 r
.83427 .39235 .83934 .39864 .85178 .39423 .84671 .3875 Mtetra
.681 .765 .915 r
.84671 .3875 .85178 .39423 .86429 .39 .85924 .38299 Mtetra
.673 .754 .912 r
.85924 .38299 .86429 .39 .87687 .38588 .87184 .37869 Mtetra
.669 .748 .91 r
.87184 .37869 .87687 .38588 .88951 .38183 .88451 .37453 Mtetra
.666 .744 .909 r
.88451 .37453 .88951 .38183 .90221 .3778 .89725 .37044 Mtetra
.665 .743 .908 r
.89725 .37044 .90221 .3778 .91497 .37379 .91005 .36638 Mtetra
.664 .742 .908 r
.91005 .36638 .91497 .37379 .92779 .36977 .9229 .36232 Mtetra
.663 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54173 .34605 .5356 Mtetra
.34605 .5356 .35259 .54173 .36312 .53842 .35661 .53228 Mtetra
.662 .741 .909 r
.35661 .53228 .36312 .53842 .37369 .53511 .36721 .52897 Mtetra
.661 .742 .91 r
.36721 .52897 .37369 .53511 .38431 .53181 .37785 .52568 Mtetra
.658 .742 .912 r
.37785 .52568 .38431 .53181 .39497 .52854 .38854 .52246 Mtetra
.653 .743 .916 r
.38854 .52246 .39497 .52854 .40567 .52533 .39925 .51937 Mtetra
.644 .746 .923 r
.39925 .51937 .40567 .52533 .4164 .52221 .41001 .51648 Mtetra
.631 .75 .934 r
.41001 .51648 .4164 .52221 .42718 .51923 .42081 .51387 Mtetra
.61 .758 .95 r
.42081 .51387 .42718 .51923 .438 .51644 .43164 .51163 Mtetra
.58 .77 .97 r
.43164 .51163 .438 .51644 .44886 .51387 .44251 .50978 Mtetra
.534 .784 .99 r
.44251 .50978 .44886 .51387 .45977 .51156 .45343 .50834 Mtetra
.459 .79 .999 r
.45343 .50834 .45977 .51156 .47072 .50959 .4644 .50732 Mtetra
.329 .762 .969 r
.4644 .50732 .47072 .50959 .48172 .50816 .47542 .50685 Mtetra
.102 .643 .846 r
.47542 .50685 .48172 .50816 .49276 .50767 .4865 .5073 Mtetra
.225 0 0 r
.4865 .5073 .49276 .50767 .50387 .50884 .49763 .50945 Mtetra
.527 0 0 r
.49763 .50945 .50387 .50884 .51504 .51263 .50884 .51442 Mtetra
.701 .202 .05 r
.50884 .51442 .51504 .51263 .5263 .52007 .52014 .5235 Mtetra
.778 .341 .212 r
.52014 .5235 .5263 .52007 .53771 .53186 .53158 .5376 Mtetra
.804 .409 .303 r
.53158 .5376 .53771 .53186 .54929 .5478 .54322 .55667 Mtetra
.802 .432 .356 r
.54322 .55667 .54929 .5478 .56109 .56643 .5551 .57905 Mtetra
.777 .423 .386 r
.5551 .57905 .56109 .56643 .57308 .58484 .5672 .60134 Mtetra
.725 .382 .398 r
.5672 .60134 .57308 .58484 .58521 .59917 .57946 .61894 Mtetra
.633 .3 .39 r
.57946 .61894 .58521 .59917 .59734 .6057 .59174 .62731 Mtetra
.469 .154 .348 r
.59174 .62731 .59734 .6057 .60935 .60211 .60388 .62362 Mtetra
.192 0 .245 r
.60388 .62362 .60935 .60211 .62113 .58842 .61576 .6079 Mtetra
0 0 .061 r
.61576 .6079 .62113 .58842 .63263 .56699 .62732 .58307 Mtetra
0 0 0 r
.62732 .58307 .63263 .56699 .64393 .54166 .63864 .55382 Mtetra
.735 .801 .323 r
.63864 .55382 .64393 .54166 .65512 .51641 .64984 .52498 Mtetra
.814 .881 .45 r
.64984 .52498 .65512 .51641 .66634 .49429 .66107 .50022 Mtetra
.796 .924 .547 r
.66107 .50022 .66634 .49429 .6777 .47687 .67247 .48138 Mtetra
.644 .905 .59 r
.67247 .48138 .6777 .47687 .68925 .46432 .6841 .46852 Mtetra
0 0 0 r
.6841 .46852 .68925 .46432 .70099 .45575 .69596 .46043 Mtetra
.69596 .46043 .70099 .45575 .71291 .44981 .708 .45526 Mtetra
.141 0 0 r
.708 .45526 .71291 .44981 .72493 .44509 .72015 .45115 Mtetra
.154 0 0 r
.72015 .45115 .72493 .44509 .73701 .4405 .73232 .44662 Mtetra
.077 0 0 r
.73232 .44662 .73701 .4405 .7491 .43538 .74445 .44084 Mtetra
0 0 0 r
.74445 .44084 .7491 .43538 .76118 .42953 .75653 .43364 Mtetra
.75653 .43364 .76118 .42953 .77325 .42308 .76855 .42536 Mtetra
.542 .902 .699 r
.76855 .42536 .77325 .42308 .78534 .41636 .78055 .4166 Mtetra
.708 .986 .863 r
.78055 .4166 .78534 .41636 .79746 .40972 .79258 .40798 Mtetra
.764 .964 .93 r
.79258 .40798 .79746 .40972 .80964 .40343 .80468 .39997 Mtetra
.759 .905 .941 r
.80468 .39997 .80964 .40343 .82191 .39764 .81688 .39281 Mtetra
.735 .849 .934 r
.81688 .39281 .82191 .39764 .83427 .39235 .8292 .38653 Mtetra
.711 .807 .925 r
.8292 .38653 .83427 .39235 .84671 .3875 .84163 .38101 Mtetra
.693 .779 .918 r
.84163 .38101 .84671 .3875 .85924 .38299 .85416 .37608 Mtetra
.68 .762 .913 r
.85416 .37608 .85924 .38299 .87184 .37869 .86678 .37153 Mtetra
.672 .752 .91 r
.86678 .37153 .87184 .37869 .88451 .37453 .87948 .36722 Mtetra
.668 .746 .909 r
.87948 .36722 .88451 .37453 .89725 .37044 .89225 .36304 Mtetra
.665 .743 .908 r
.89225 .36304 .89725 .37044 .91005 .36638 .90509 .35892 Mtetra
.664 .742 .908 r
.90509 .35892 .91005 .36638 .9229 .36232 .91798 .35481 Mtetra
.663 .741 .908 r
.32893 .53278 .33554 .53892 .34605 .5356 .33948 .52944 Mtetra
.663 .741 .909 r
.33948 .52944 .34605 .5356 .35661 .53228 .35006 .5261 Mtetra
.661 .741 .909 r
.35006 .5261 .35661 .53228 .36721 .52897 .36068 .52279 Mtetra
.658 .742 .911 r
.36068 .52279 .36721 .52897 .37785 .52568 .37135 .51955 Mtetra
.653 .742 .915 r
.37135 .51955 .37785 .52568 .38854 .52246 .38205 .51644 Mtetra
.643 .744 .922 r
.38205 .51644 .38854 .52246 .39925 .51937 .39279 .51357 Mtetra
.626 .747 .934 r
.39279 .51357 .39925 .51937 .41001 .51648 .40356 .51107 Mtetra
.596 .753 .953 r
.40356 .51107 .41001 .51648 .42081 .51387 .41436 .50911 Mtetra
.546 .761 .977 r
.41436 .50911 .42081 .51387 .43164 .51163 .42519 .50779 Mtetra
.457 .765 .996 r
.42519 .50779 .43164 .51163 .44251 .50978 .43606 .50716 Mtetra
.305 .737 .969 r
.43606 .50716 .44251 .50978 .45343 .50834 .44699 .50715 Mtetra
.079 .629 .827 r
.44699 .50715 .45343 .50834 .4644 .50732 .45797 .50765 Mtetra
.156 0 0 r
.45797 .50765 .4644 .50732 .47542 .50685 .46901 .50857 Mtetra
.34 0 0 r
.46901 .50857 .47542 .50685 .4865 .5073 .48012 .51016 Mtetra
.483 0 0 r
.48012 .51016 .4865 .5073 .49763 .50945 .49129 .51309 Mtetra
.607 .11 .046 r
.49129 .51309 .49763 .50945 .50884 .51442 .50254 .51859 Mtetra
.708 .252 .166 r
.50254 .51859 .50884 .51442 .52014 .5235 .51389 .52815 Mtetra
.777 .356 .249 r
.51389 .52815 .52014 .5235 .53158 .5376 .52537 .54298 Mtetra
.814 .419 .303 r
.52537 .54298 .53158 .5376 .54322 .55667 .53704 .56323 Mtetra
.826 .446 .334 r
.53704 .56323 .54322 .55667 .5551 .57905 .54896 .58726 Mtetra
.815 .441 .348 r
.54896 .58726 .5551 .57905 .5672 .60134 .56112 .61143 Mtetra
.772 .397 .345 r
.56112 .61143 .5672 .60134 .57946 .61894 .57346 .63067 Mtetra
.665 .281 .309 r
.57346 .63067 .57946 .61894 .59174 .62731 .58583 .63994 Mtetra
.379 0 .186 r
.58583 .63994 .59174 .62731 .60388 .62362 .59808 .63606 Mtetra
0 0 0 r
.59808 .63606 .60388 .62362 .61576 .6079 .61004 .61905 Mtetra
.759 .837 .38 r
.61004 .61905 .61576 .6079 .62732 .58307 .62169 .59222 Mtetra
.914 .896 .485 r
.62169 .59222 .62732 .58307 .63864 .55382 .63308 .56087 Mtetra
.951 .911 .539 r
.63308 .56087 .63864 .55382 .64984 .52498 .64435 .53046 Mtetra
.939 .935 .585 r
.64435 .53046 .64984 .52498 .66107 .50022 .65568 .50505 Mtetra
.846 .956 .613 r
.65568 .50505 .66107 .50022 .67247 .48138 .6672 .48663 Mtetra
0 0 0 r
.6672 .48663 .67247 .48138 .6841 .46852 .67898 .4751 Mtetra
.058 0 0 r
.67898 .4751 .6841 .46852 .69596 .46043 .69103 .46887 Mtetra
.319 0 .05 r
.69103 .46887 .69596 .46043 .708 .45526 .70327 .46555 Mtetra
.384 0 .143 r
.70327 .46555 .708 .45526 .72015 .45115 .7156 .46271 Mtetra
.361 0 .168 r
.7156 .46271 .72015 .45115 .73232 .44662 .7279 .45847 Mtetra
.283 0 .145 r
.7279 .45847 .73232 .44662 .74445 .44084 .74009 .45184 Mtetra
.156 0 .071 r
.74009 .45184 .74445 .44084 .75653 .43364 .75215 .44273 Mtetra
0 0 0 r
.75215 .44273 .75653 .43364 .76855 .42536 .76408 .4318 Mtetra
.76408 .4318 .76855 .42536 .78055 .4166 .77596 .42008 Mtetra
.586 .889 .602 r
.77596 .42008 .78055 .4166 .79258 .40798 .78784 .4086 Mtetra
.764 .996 .823 r
.78784 .4086 .79258 .40798 .80468 .39997 .79981 .39811 Mtetra
.801 .966 .912 r
.79981 .39811 .80468 .39997 .81688 .39281 .81191 .38899 Mtetra
.775 .897 .929 r
.81191 .38899 .81688 .39281 .8292 .38653 .82415 .3813 Mtetra
.739 .838 .926 r
.82415 .3813 .8292 .38653 .84163 .38101 .83654 .37483 Mtetra
.71 .797 .919 r
.83654 .37483 .84163 .38101 .85416 .37608 .84905 .3693 Mtetra
.69 .772 .914 r
.84905 .3693 .85416 .37608 .86678 .37153 .86169 .3644 Mtetra
.677 .757 .911 r
.86169 .3644 .86678 .37153 .87948 .36722 .87441 .35989 Mtetra
.67 .749 .909 r
.87441 .35989 .87948 .36722 .89225 .36304 .88721 .35559 Mtetra
.667 .745 .908 r
.88721 .35559 .89225 .36304 .90509 .35892 .90008 .3514 Mtetra
.665 .743 .908 r
.90008 .3514 .90509 .35892 .91798 .35481 .91302 .34725 Mtetra
.663 .741 .908 r
.32228 .52659 .32893 .53278 .33948 .52944 .33285 .52323 Mtetra
.662 .741 .909 r
.33285 .52323 .33948 .52944 .35006 .5261 .34346 .51989 Mtetra
.66 .741 .91 r
.34346 .51989 .35006 .5261 .36068 .52279 .35411 .5166 Mtetra
.655 .741 .913 r
.35411 .5166 .36068 .52279 .37135 .51955 .36479 .51343 Mtetra
.645 .742 .92 r
.36479 .51343 .37135 .51955 .38205 .51644 .37551 .5105 Mtetra
.627 .744 .931 r
.37551 .5105 .38205 .51644 .39279 .51357 .38626 .50798 Mtetra
.592 .746 .95 r
.38626 .50798 .39279 .51357 .40356 .51107 .39703 .50611 Mtetra
.526 .748 .977 r
.39703 .50611 .40356 .51107 .41436 .50911 .40782 .50514 Mtetra
.393 .732 .991 r
.40782 .50514 .41436 .50911 .42519 .50779 .41864 .50527 Mtetra
.13 .634 .904 r
.41864 .50527 .42519 .50779 .43606 .50716 .4295 .50652 Mtetra
.213 0 0 r
.4295 .50652 .43606 .50716 .44699 .50715 .4404 .50871 Mtetra
.427 0 0 r
.4404 .50871 .44699 .50715 .45797 .50765 .45138 .51147 Mtetra
.507 0 0 r
.45138 .51147 .45797 .50765 .46901 .50857 .46244 .51439 Mtetra
.536 .067 .087 r
.46244 .51439 .46901 .50857 .48012 .51016 .47359 .51734 Mtetra
.562 .119 .156 r
.47359 .51734 .48012 .51016 .49129 .51309 .48482 .52079 Mtetra
.607 .179 .202 r
.48482 .52079 .49129 .51309 .50254 .51859 .49613 .5259 Mtetra
.675 .254 .238 r
.49613 .5259 .50254 .51859 .51389 .52815 .50754 .53435 Mtetra
.749 .335 .264 r
.50754 .53435 .51389 .52815 .52537 .54298 .51906 .54767 Mtetra
.808 .4 .277 r
.51906 .54767 .52537 .54298 .53704 .56323 .53076 .56636 Mtetra
.843 .437 .272 r
.53076 .56636 .53704 .56323 .54896 .58726 .54269 .58904 Mtetra
.853 .438 .243 r
.54269 .58904 .54896 .58726 .56112 .61143 .55485 .61221 Mtetra
.826 .375 .158 r
.55485 .61221 .56112 .61143 .57346 .63067 .5672 .63079 Mtetra
.646 .095 0 r
.5672 .63079 .57346 .63067 .58583 .63994 .5796 .63959 Mtetra
.493 .898 .927 r
.5796 .63959 .58583 .63994 .59808 .63606 .5919 .63536 Mtetra
.93 .925 .783 r
.5919 .63536 .59808 .63606 .61004 .61905 .60394 .61811 Mtetra
.965 .863 .687 r
.60394 .61811 .61004 .61905 .62169 .59222 .61569 .59128 Mtetra
.972 .846 .658 r
.61569 .59128 .62169 .59222 .63308 .56087 .62719 .56039 Mtetra
.975 .86 .663 r
.62719 .56039 .63308 .56087 .64435 .53046 .63861 .53111 Mtetra
.97 .911 .696 r
.63861 .53111 .64435 .53046 .65568 .50505 .65011 .50766 Mtetra
.874 .989 .729 r
.65011 .50766 .65568 .50505 .6672 .48663 .66184 .49201 Mtetra
0 0 0 r
.66184 .49201 .6672 .48663 .67898 .4751 .67388 .48385 Mtetra
.35 0 .071 r
.67388 .48385 .67898 .4751 .69103 .46887 .6862 .48116 Mtetra
.483 .096 .229 r
.6862 .48116 .69103 .46887 .70327 .46555 .69871 .48095 Mtetra
.491 .133 .286 r
.69871 .48095 .70327 .46555 .7156 .46271 .71128 .48019 Mtetra
.445 .107 .298 r
.71128 .48019 .7156 .46271 .7279 .45847 .72375 .47654 Mtetra
.361 .04 .278 r
.72375 .47654 .7279 .45847 .74009 .45184 .73601 .46883 Mtetra
.24 0 .224 r
.73601 .46883 .74009 .45184 .75215 .44273 .74804 .45718 Mtetra
.071 0 .121 r
.74804 .45718 .75215 .44273 .76408 .4318 .75986 .44271 Mtetra
0 0 0 r
.75986 .44271 .76408 .4318 .77596 .42008 .77155 .42703 Mtetra
.77155 .42703 .77596 .42008 .78784 .4086 .78324 .41173 Mtetra
.726 .947 .642 r
.78324 .41173 .78784 .4086 .79981 .39811 .79503 .39795 Mtetra
.834 .997 .836 r
.79503 .39795 .79981 .39811 .81191 .38899 .80697 .38625 Mtetra
.82 .941 .905 r
.80697 .38625 .81191 .38899 .82415 .3813 .81911 .37669 Mtetra
.774 .871 .919 r
.81911 .37669 .82415 .3813 .83654 .37483 .83144 .36898 Mtetra
.732 .817 .918 r
.83144 .36898 .83654 .37483 .84905 .3693 .84393 .36267 Mtetra
.702 .783 .914 r
.84393 .36267 .84905 .3693 .86169 .3644 .85656 .35732 Mtetra
.684 .762 .911 r
.85656 .35732 .86169 .3644 .87441 .35989 .8693 .35255 Mtetra
.674 .751 .909 r
.8693 .35255 .87441 .35989 .88721 .35559 .88214 .34811 Mtetra
.668 .746 .908 r
.88214 .34811 .88721 .35559 .90008 .3514 .89504 .34383 Mtetra
.665 .743 .908 r
.89504 .34383 .90008 .3514 .91302 .34725 .90802 .33962 Mtetra
.663 .741 .908 r
.31558 .52035 .32228 .52659 .33285 .52323 .32617 .51698 Mtetra
.661 .741 .909 r
.32617 .51698 .33285 .52323 .34346 .51989 .3368 .51364 Mtetra
.657 .741 .912 r
.3368 .51364 .34346 .51989 .35411 .5166 .34748 .51039 Mtetra
.65 .741 .916 r
.34748 .51039 .35411 .5166 .36479 .51343 .35818 .50734 Mtetra
.634 .741 .926 r
.35818 .50734 .36479 .51343 .37551 .5105 .36891 .50466 Mtetra
.602 .741 .943 r
.36891 .50466 .37551 .5105 .38626 .50798 .37966 .50265 Mtetra
.535 .738 .968 r
.37966 .50265 .38626 .50798 .39703 .50611 .39043 .50168 Mtetra
.388 .711 .986 r
.39043 .50168 .39703 .50611 .40782 .50514 .40119 .50212 Mtetra
.06 .571 .881 r
.40119 .50212 .40782 .50514 .41864 .50527 .41198 .50427 Mtetra
.372 0 0 r
.41198 .50427 .41864 .50527 .4295 .50652 .42278 .50818 Mtetra
.581 .041 0 r
.42278 .50818 .4295 .50652 .4404 .50871 .43365 .51347 Mtetra
.628 .16 .122 r
.43365 .51347 .4404 .50871 .45138 .51147 .4446 .51939 Mtetra
.62 .199 .221 r
.4446 .51939 .45138 .51147 .46244 .51439 .45567 .52502 Mtetra
.597 .203 .267 r
.45567 .52502 .46244 .51439 .47359 .51734 .46687 .52965 Mtetra
.577 .197 .286 r
.46687 .52965 .47359 .51734 .48482 .52079 .47818 .53331 Mtetra
.577 .199 .288 r
.47818 .53331 .48482 .52079 .49613 .5259 .48958 .53701 Mtetra
.612 .222 .28 r
.48958 .53701 .49613 .5259 .50754 .53435 .50108 .54255 Mtetra
.683 .272 .26 r
.50108 .54255 .50754 .53435 .51906 .54767 .51267 .55184 Mtetra
.768 .332 .216 r
.51267 .55184 .51906 .54767 .53076 .56636 .52439 .56591 Mtetra
.829 .369 .123 r
.52439 .56591 .53076 .56636 .54269 .58904 .53631 .58394 Mtetra
.803 .324 0 r
.53631 .58394 .54269 .58904 .55485 .61221 .54844 .60295 Mtetra
0 0 .521 r
.54844 .60295 .55485 .61221 .5672 .63079 .56073 .61828 Mtetra
.294 .429 .828 r
.56073 .61828 .5672 .63079 .5796 .63959 .5731 .62512 Mtetra
.658 .602 .78 r
.5731 .62512 .5796 .63959 .5919 .63536 .5854 .62035 Mtetra
.785 .655 .719 r
.5854 .62035 .5919 .63536 .60394 .61811 .59749 .60397 Mtetra
.841 .683 .686 r
.59749 .60397 .60394 .61811 .61569 .59128 .60934 .57926 Mtetra
.871 .709 .678 r
.60934 .57926 .61569 .59128 .62719 .56039 .621 .5515 Mtetra
.891 .747 .695 r
.621 .5515 .62719 .56039 .63861 .53111 .63262 .52617 Mtetra
.906 .825 .755 r
.63262 .52617 .63861 .53111 .65011 .50766 .64437 .50736 Mtetra
.825 .986 .877 r
.64437 .50736 .65011 .50766 .66184 .49201 .65638 .49686 Mtetra
.179 0 0 r
.65638 .49686 .66184 .49201 .67388 .48385 .66874 .4941 Mtetra
.535 .12 .201 r
.66874 .4941 .67388 .48385 .6862 .48116 .68141 .49658 Mtetra
.577 .212 .312 r
.68141 .49658 .6862 .48116 .69871 .48095 .69426 .50073 Mtetra
.55 .213 .35 r
.69426 .50073 .69871 .48095 .71128 .48019 .70712 .50284 Mtetra
.485 .169 .355 r
.70712 .50284 .71128 .48019 .72375 .47654 .7198 .50006 Mtetra
.388 .091 .335 r
.7198 .50006 .72375 .47654 .73601 .46883 .73215 .49109 Mtetra
.255 0 .285 r
.73215 .49109 .73601 .46883 .74804 .45718 .74413 .47632 Mtetra
.079 0 .193 r
.74413 .47632 .74804 .45718 .75986 .44271 .7558 .45749 Mtetra
0 0 .039 r
.7558 .45749 .75986 .44271 .77155 .42703 .76729 .43697 Mtetra
0 0 0 r
.76729 .43697 .77155 .42703 .78324 .41173 .77874 .41701 Mtetra
.714 .886 .498 r
.77874 .41701 .78324 .41173 .79503 .39795 .7903 .39922 Mtetra
.861 .992 .742 r
.7903 .39922 .79503 .39795 .80697 .38625 .80207 .3844 Mtetra
.865 .965 .863 r
.80207 .3844 .80697 .38625 .81911 .37669 .81407 .37259 Mtetra
.811 .896 .902 r
.81407 .37259 .81911 .37669 .83144 .36898 .82632 .36338 Mtetra
.757 .835 .911 r
.82632 .36338 .83144 .36898 .84393 .36267 .83877 .35615 Mtetra
.717 .793 .911 r
.83877 .35615 .84393 .36267 .85656 .35732 .8514 .35025 Mtetra
.692 .768 .91 r
.8514 .35025 .85656 .35732 .8693 .35255 .86416 .34518 Mtetra
.677 .754 .909 r
.86416 .34518 .8693 .35255 .88214 .34811 .87702 .34058 Mtetra
.67 .747 .908 r
.87702 .34058 .88214 .34811 .89504 .34383 .88996 .33621 Mtetra
.666 .744 .908 r
.88996 .33621 .89504 .34383 .90802 .33962 .90297 .33194 Mtetra
.662 .741 .909 r
.30883 .51407 .31558 .52035 .32617 .51698 .31944 .51069 Mtetra
.66 .741 .91 r
.31944 .51069 .32617 .51698 .3368 .51364 .3301 .50736 Mtetra
.654 .741 .913 r
.3301 .50736 .3368 .51364 .34748 .51039 .34079 .50416 Mtetra
.643 .74 .92 r
.34079 .50416 .34748 .51039 .35818 .50734 .35152 .50126 Mtetra
.618 .739 .933 r
.35152 .50126 .35818 .50734 .36891 .50466 .36226 .49893 Mtetra
.565 .734 .955 r
.36226 .49893 .36891 .50466 .37966 .50265 .373 .49757 Mtetra
.443 .711 .98 r
.373 .49757 .37966 .50265 .39043 .50168 .38374 .49773 Mtetra
.142 .595 .928 r
.38374 .49773 .39043 .50168 .40119 .50212 .39447 .49997 Mtetra
.366 0 0 r
.39447 .49997 .40119 .50212 .41198 .50427 .40518 .50473 Mtetra
.648 .11 0 r
.40518 .50473 .41198 .50427 .42278 .50818 .41592 .51203 Mtetra
.708 .252 .166 r
.41592 .51203 .42278 .50818 .43365 .51347 .42671 .52129 Mtetra
.7 .295 .277 r
.42671 .52129 .43365 .51347 .4446 .51939 .43762 .53127 Mtetra
.667 .294 .329 r
.43762 .53127 .4446 .51939 .45567 .52502 .44868 .54032 Mtetra
.623 .268 .349 r
.44868 .54032 .45567 .52502 .46687 .52965 .45992 .54697 Mtetra
.576 .231 .347 r
.45992 .54697 .46687 .52965 .47818 .53331 .47133 .5506 Mtetra
.536 .191 .329 r
.47133 .5506 .47818 .53331 .48958 .53701 .48287 .55193 Mtetra
.523 .16 .292 r
.48287 .55193 .48958 .53701 .50108 .54255 .49449 .55289 Mtetra
.554 .147 .225 r
.49449 .55289 .50108 .54255 .51267 .55184 .50618 .55586 Mtetra
.633 .143 .072 r
.50618 .55586 .51267 .55184 .52439 .56591 .51796 .56258 Mtetra
.62 .064 0 r
.51796 .56258 .52439 .56591 .53631 .58394 .52987 .57306 Mtetra
0 .181 .715 r
.52987 .57306 .53631 .58394 .54844 .60295 .54193 .58517 Mtetra
.292 .349 .75 r
.54193 .58517 .54844 .60295 .56073 .61828 .55415 .59509 Mtetra
.509 .443 .718 r
.55415 .59509 .56073 .61828 .5731 .62512 .56643 .59867 Mtetra
.632 .505 .69 r
.56643 .59867 .5731 .62512 .5854 .62035 .57868 .59317 Mtetra
.706 .548 .672 r
.57868 .59317 .5854 .62035 .59749 .60397 .5908 .57855 Mtetra
.752 .582 .665 r
.5908 .57855 .59749 .60397 .60934 .57926 .60274 .55763 Mtetra
.781 .612 .671 r
.60274 .55763 .60934 .57926 .621 .5515 .61457 .53514 Mtetra
.796 .648 .699 r
.61457 .53514 .621 .5515 .63262 .52617 .62642 .51601 Mtetra
.792 .716 .779 r
.62642 .51601 .63262 .52617 .64437 .50736 .63844 .50392 Mtetra
.604 .858 .992 r
.63844 .50392 .64437 .50736 .65638 .49686 .65079 .50038 Mtetra
.516 0 0 r
.65079 .50038 .65638 .49686 .66874 .4941 .66351 .50451 Mtetra
.656 .248 .259 r
.66351 .50451 .66874 .4941 .68141 .49658 .67656 .51337 Mtetra
.644 .284 .346 r
.67656 .51337 .68141 .49658 .69426 .50073 .68979 .52276 Mtetra
.591 .259 .375 r
.68979 .52276 .69426 .50073 .70712 .50284 .70297 .5283 Mtetra
.506 .197 .376 r
.70297 .5283 .70712 .50284 .7198 .50006 .71587 .52662 Mtetra
.385 .099 .351 r
.71587 .52662 .7198 .50006 .73215 .49109 .72832 .51629 Mtetra
.221 0 .294 r
.72832 .51629 .73215 .49109 .74413 .47632 .74027 .49805 Mtetra
.009 0 .192 r
.74027 .49805 .74413 .47632 .7558 .45749 .75179 .47437 Mtetra
0 0 .032 r
.75179 .47437 .7558 .45749 .76729 .43697 .76304 .44847 Mtetra
0 0 0 r
.76304 .44847 .76729 .43697 .77874 .41701 .77424 .42338 Mtetra
.774 .878 .454 r
.77424 .42338 .77874 .41701 .7903 .39922 .78557 .40121 Mtetra
.9 .975 .679 r
.78557 .40121 .7903 .39922 .80207 .3844 .79714 .38297 Mtetra
.903 .965 .816 r
.79714 .38297 .80207 .3844 .81407 .37259 .80901 .36871 Mtetra
.846 .906 .878 r
.80901 .36871 .81407 .37259 .82632 .36338 .82117 .35789 Mtetra
.782 .845 .9 r
.82117 .35789 .82632 .36338 .83877 .35615 .83358 .34965 Mtetra
.732 .801 .906 r
.83358 .34965 .83877 .35615 .8514 .35025 .8462 .34317 Mtetra
.7 .772 .908 r
.8462 .34317 .8514 .35025 .86416 .34518 .85897 .33778 Mtetra
.682 .756 .908 r
.85897 .33778 .86416 .34518 .87702 .34058 .87186 .33299 Mtetra
.672 .748 .908 r
.87186 .33299 .87702 .34058 .88996 .33621 .88484 .32852 Mtetra
.667 .744 .908 r
.88484 .32852 .88996 .33621 .90297 .33194 .89789 .32419 Mtetra
.662 .741 .909 r
.30202 .50775 .30883 .51407 .31944 .51069 .31267 .50436 Mtetra
.658 .741 .911 r
.31267 .50436 .31944 .51069 .3301 .50736 .32335 .50104 Mtetra
.651 .74 .915 r
.32335 .50104 .3301 .50736 .34079 .50416 .33406 .49791 Mtetra
.635 .738 .923 r
.33406 .49791 .34079 .50416 .35152 .50126 .3448 .49519 Mtetra
.599 .734 .939 r
.3448 .49519 .35152 .50126 .36226 .49893 .35554 .49324 Mtetra
.517 .72 .965 r
.35554 .49324 .36226 .49893 .373 .49757 .36628 .49262 Mtetra
.312 .655 .971 r
.36628 .49262 .373 .49757 .38374 .49773 .37698 .49408 Mtetra
0 .382 .756 r
.37698 .49408 .38374 .49773 .39447 .49997 .38765 .49839 Mtetra
.623 .058 0 r
.38765 .49839 .39447 .49997 .40518 .50473 .39828 .50613 Mtetra
.753 .279 .119 r
.39828 .50613 .40518 .50473 .41592 .51203 .40891 .51733 Mtetra
.764 .353 .272 r
.40891 .51733 .41592 .51203 .42671 .52129 .4196 .53117 Mtetra
.74 .366 .343 r
.4196 .53117 .42671 .52129 .43762 .53127 .43043 .54583 Mtetra
.699 .347 .376 r
.43043 .54583 .43762 .53127 .44868 .54032 .44147 .55883 Mtetra
.642 .304 .384 r
.44147 .55883 .44868 .54032 .45992 .54697 .45276 .56774 Mtetra
.571 .241 .372 r
.45276 .56774 .45992 .54697 .47133 .5506 .46428 .57118 Mtetra
.488 .16 .336 r
.46428 .57118 .47133 .5506 .48287 .55193 .47598 .56946 Mtetra
.4 .058 .266 r
.47598 .56946 .48287 .55193 .49449 .55289 .48777 .56467 Mtetra
.305 0 .117 r
.48777 .56467 .49449 .55289 .50618 .55586 .4996 .55976 Mtetra
.112 0 0 r
.4996 .55976 .50618 .55586 .51796 .56258 .51147 .55734 Mtetra
.361 .679 .978 r
.51147 .55734 .51796 .56258 .52987 .57306 .52339 .55843 Mtetra
.459 .49 .803 r
.52339 .55843 .52987 .57306 .54193 .58517 .53541 .56198 Mtetra
.514 .445 .717 r
.53541 .56198 .54193 .58517 .55415 .59509 .54753 .56519 Mtetra
.572 .453 .679 r
.54753 .56519 .55415 .59509 .56643 .59867 .55971 .56478 Mtetra
.625 .477 .661 r
.55971 .56478 .56643 .59867 .57868 .59317 .57189 .55842 Mtetra
.667 .503 .653 r
.57189 .55842 .57868 .59317 .5908 .57855 .584 .54598 Mtetra
.697 .527 .654 r
.584 .54598 .5908 .57855 .60274 .55763 .59601 .52975 Mtetra
.713 .55 .666 r
.59601 .52975 .60274 .55763 .61457 .53514 .60799 .51363 Mtetra
.709 .572 .699 r
.60799 .51363 .61457 .53514 .62642 .51601 .62006 .50181 Mtetra
.652 .602 .785 r
.62006 .50181 .62642 .51601 .63844 .50392 .63236 .4974 Mtetra
.202 .537 .926 r
.63236 .4974 .63844 .50392 .65079 .50038 .64502 .50155 Mtetra
.711 .191 0 r
.64502 .50155 .65079 .50038 .66351 .50451 .65809 .51309 Mtetra
.745 .331 .265 r
.65809 .51309 .66351 .50451 .67656 .51337 .67151 .52867 Mtetra
.703 .333 .345 r
.67151 .52867 .67656 .51337 .68979 .52276 .68511 .54351 Mtetra
.629 .287 .372 r
.68511 .54351 .68979 .52276 .70297 .5283 .69861 .55261 Mtetra
.517 .199 .367 r
.69861 .55261 .70297 .5283 .71587 .52662 .71173 .55211 Mtetra
.35 .063 .329 r
.71173 .55211 .71587 .52662 .72832 .51629 .72429 .54048 Mtetra
.117 0 .245 r
.72429 .54048 .72832 .51629 .74027 .49805 .73621 .51883 Mtetra
0 0 .106 r
.73621 .51883 .74027 .49805 .75179 .47437 .74759 .49038 Mtetra
0 0 0 r
.74759 .49038 .75179 .47437 .76304 .44847 .75864 .45924 Mtetra
.724 .782 .294 r
.75864 .45924 .76304 .44847 .77424 .42338 .76962 .42915 Mtetra
.884 .905 .495 r
.76962 .42915 .77424 .42338 .78557 .40121 .78073 .40274 Mtetra
.947 .955 .663 r
.78073 .40274 .78557 .40121 .79714 .38297 .79213 .38121 Mtetra
.93 .943 .782 r
.79213 .38121 .79714 .38297 .80901 .36871 .80387 .36461 Mtetra
.87 .898 .85 r
.80387 .36461 .80901 .36871 .82117 .35789 .81596 .35223 Mtetra
.801 .845 .884 r
.81596 .35223 .82117 .35789 .83358 .34965 .82834 .34303 Mtetra
.745 .803 .898 r
.82834 .34303 .83358 .34965 .8462 .34317 .84095 .336 Mtetra
.708 .774 .904 r
.84095 .336 .8462 .34317 .85897 .33778 .85374 .33029 Mtetra
.686 .757 .906 r
.85374 .33029 .85897 .33778 .87186 .33299 .86666 .32534 Mtetra
.674 .749 .907 r
.86666 .32534 .87186 .33299 .88484 .32852 .87967 .32077 Mtetra
.668 .744 .908 r
.87967 .32077 .88484 .32852 .89789 .32419 .89276 .31638 Mtetra
.661 .741 .909 r
.29517 .50138 .30202 .50775 .31267 .50436 .30584 .49797 Mtetra
.657 .74 .911 r
.30584 .49797 .31267 .50436 .32335 .50104 .31654 .49467 Mtetra
.648 .739 .916 r
.31654 .49467 .32335 .50104 .33406 .49791 .32728 .49161 Mtetra
.626 .736 .926 r
.32728 .49161 .33406 .49791 .3448 .49519 .33803 .48906 Mtetra
.578 .728 .945 r
.33803 .48906 .3448 .49519 .35554 .49324 .34878 .4875 Mtetra
.464 .698 .969 r
.34878 .4875 .35554 .49324 .36628 .49262 .3595 .48764 Mtetra
.165 .572 .934 r
.3595 .48764 .36628 .49262 .37698 .49408 .37016 .4904 Mtetra
.404 0 0 r
.37016 .4904 .37698 .49408 .38765 .49839 .38075 .49679 Mtetra
.737 .216 0 r
.38075 .49679 .38765 .49839 .39828 .50613 .39128 .50754 Mtetra
.806 .366 .199 r
.39128 .50754 .39828 .50613 .40891 .51733 .40179 .5227 Mtetra
.803 .412 .313 r
.40179 .5227 .40891 .51733 .4196 .53117 .41236 .5412 Mtetra
.776 .412 .367 r
.41236 .5412 .4196 .53117 .43043 .54583 .42309 .56063 Mtetra
.73 .383 .391 r
.42309 .56063 .43043 .54583 .44147 .55883 .4341 .57765 Mtetra
.663 .326 .392 r
.4341 .57765 .44147 .55883 .45276 .56774 .44543 .58882 Mtetra
.564 .234 .368 r
.44543 .58882 .45276 .56774 .46428 .57118 .45707 .59194 Mtetra
.42 .094 .305 r
.45707 .59194 .46428 .57118 .47598 .56946 .46894 .58692 Mtetra
.197 0 .166 r
.46894 .58692 .47598 .56946 .48777 .56467 .48093 .57599 Mtetra
0 0 0 r
.48093 .57599 .48777 .56467 .4996 .55976 .49294 .56276 Mtetra
.787 .995 .781 r
.49294 .56276 .4996 .55976 .51147 .55734 .50492 .55075 Mtetra
.78 .783 .855 r
.50492 .55075 .51147 .55734 .52339 .55843 .5169 .54208 Mtetra
.659 .58 .756 r
.5169 .54208 .52339 .55843 .53541 .56198 .52889 .53678 Mtetra
.613 .497 .697 r
.52889 .53678 .53541 .56198 .54753 .56519 .54093 .5331 Mtetra
.611 .471 .667 r
.54093 .5331 .54753 .56519 .55971 .56478 .55302 .52858 Mtetra
.627 .473 .653 r
.55302 .52858 .55971 .56478 .57189 .55842 .56512 .52133 Mtetra
.647 .484 .649 r
.56512 .52133 .57189 .55842 .584 .54598 .5772 .5111 Mtetra
.661 .498 .653 r
.5772 .5111 .584 .54598 .59601 .52975 .58927 .49955 Mtetra
.66 .509 .668 r
.58927 .49955 .59601 .52975 .60799 .51363 .60137 .48974 Mtetra
.627 .512 .703 r
.60137 .48974 .60799 .51363 .62006 .50181 .61361 .48503 Mtetra
.495 .486 .776 r
.61361 .48503 .62006 .50181 .63236 .4974 .62614 .48794 Mtetra
0 .221 .743 r
.62614 .48794 .63236 .4974 .64502 .50155 .63906 .49924 Mtetra
.792 .295 0 r
.63906 .49924 .64502 .50155 .65809 .51309 .65242 .51747 Mtetra
.818 .387 .218 r
.65242 .51747 .65809 .51309 .67151 .52867 .66614 .539 Mtetra
.767 .37 .302 r
.66614 .539 .67151 .52867 .68511 .54351 .68003 .55862 Mtetra
.676 .3 .327 r
.68003 .55862 .68511 .54351 .69861 .55261 .69379 .57082 Mtetra
.516 .164 .309 r
.69379 .57082 .69861 .55261 .71173 .55211 .70711 .57138 Mtetra
.237 0 .228 r
.70711 .57138 .71173 .55211 .72429 .54048 .71976 .55871 Mtetra
0 0 .063 r
.71976 .55871 .72429 .54048 .73621 .51883 .73168 .53427 Mtetra
0 0 0 r
.73168 .53427 .73621 .51883 .74759 .49038 .74298 .5019 Mtetra
.802 .807 .32 r
.74298 .5019 .74759 .49038 .75864 .45924 .7539 .46646 Mtetra
.923 .879 .456 r
.7539 .46646 .75864 .45924 .76962 .42915 .76472 .4323 Mtetra
.972 .91 .57 r
.76472 .4323 .76962 .42915 .78073 .40274 .77568 .40244 Mtetra
.975 .918 .673 r
.77568 .40244 .78073 .40274 .79213 .38121 .78696 .37825 Mtetra
.94 .905 .761 r
.78696 .37825 .79213 .38121 .80387 .36461 .79863 .35976 Mtetra
.879 .873 .826 r
.79863 .35976 .80387 .36461 .81596 .35223 .81067 .34613 Mtetra
.812 .834 .867 r
.81067 .34613 .81596 .35223 .82834 .34303 .82303 .33615 Mtetra
.754 .799 .889 r
.82303 .33615 .82834 .34303 .84095 .336 .83565 .32866 Mtetra
.713 .773 .899 r
.83565 .32866 .84095 .336 .85374 .33029 .84846 .3227 Mtetra
.688 .757 .904 r
.84846 .3227 .85374 .33029 .86666 .32534 .86141 .3176 Mtetra
.675 .749 .906 r
.86141 .3176 .86666 .32534 .87967 .32077 .87446 .31295 Mtetra
.668 .744 .907 r
.87446 .31295 .87967 .32077 .89276 .31638 .88759 .3085 Mtetra
.661 .741 .909 r
.28827 .49496 .29517 .50138 .30584 .49797 .29896 .49154 Mtetra
.656 .74 .912 r
.29896 .49154 .30584 .49797 .31654 .49467 .30969 .48824 Mtetra
.645 .738 .917 r
.30969 .48824 .31654 .49467 .32728 .49161 .32044 .48523 Mtetra
.619 .733 .928 r
.32044 .48523 .32728 .49161 .33803 .48906 .33121 .48284 Mtetra
.56 .72 .948 r
.33121 .48284 .33803 .48906 .34878 .4875 .34196 .48161 Mtetra
.417 .673 .967 r
.34196 .48161 .34878 .4875 .3595 .48764 .35267 .48239 Mtetra
.048 .488 .887 r
.35267 .48239 .3595 .48764 .37016 .4904 .36329 .48628 Mtetra
.527 0 0 r
.36329 .48628 .37016 .4904 .38075 .49679 .37382 .49445 Mtetra
.79 .294 .007 r
.37382 .49445 .38075 .49679 .39128 .50754 .38425 .5078 Mtetra
.842 .416 .218 r
.38425 .5078 .39128 .50754 .40179 .5227 .39464 .52637 Mtetra
.839 .452 .316 r
.39464 .52637 .40179 .5227 .41236 .5412 .40508 .54889 Mtetra
.815 .448 .362 r
.40508 .54889 .41236 .5412 .42309 .56063 .41571 .57244 Mtetra
.77 .413 .38 r
.41571 .57244 .42309 .56063 .4341 .57765 .42667 .5929 Mtetra
.693 .34 .372 r
.42667 .5929 .4341 .57765 .44543 .58882 .43803 .60595 Mtetra
.554 .2 .323 r
.43803 .60595 .44543 .58882 .45707 .59194 .44978 .60863 Mtetra
.276 0 .186 r
.44978 .60863 .45707 .59194 .46894 .58692 .46182 .6005 Mtetra
0 0 0 r
.46182 .6005 .46894 .58692 .48093 .57599 .47401 .58395 Mtetra
.837 .941 .575 r
.47401 .58395 .48093 .57599 .49294 .56276 .48621 .5632 Mtetra
.95 .91 .743 r
.48621 .5632 .49294 .56276 .50492 .55075 .49834 .54262 Mtetra
.854 .753 .751 r
.49834 .54262 .50492 .55075 .5169 .54208 .51039 .52527 Mtetra
.746 .621 .72 r
.51039 .52527 .5169 .54208 .52889 .53678 .52239 .51215 Mtetra
.677 .538 .689 r
.52239 .51215 .52889 .53678 .54093 .5331 .53438 .50243 Mtetra
.645 .497 .668 r
.53438 .50243 .54093 .5331 .55302 .52858 .5464 .49432 Mtetra
.636 .482 .657 r
.5464 .49432 .55302 .52858 .56512 .52133 .55843 .48628 Mtetra
.637 .481 .654 r
.55843 .48628 .56512 .52133 .5772 .5111 .57049 .47793 Mtetra
.634 .484 .66 r
.57049 .47793 .5772 .5111 .58927 .49955 .58257 .47037 Mtetra
.614 .482 .678 r
.58257 .47037 .58927 .49955 .60137 .48974 .59475 .46585 Mtetra
.548 .463 .711 r
.59475 .46585 .60137 .48974 .61361 .48503 .60712 .46698 Mtetra
.341 .378 .755 r
.60712 .46698 .61361 .48503 .62614 .48794 .6198 .47569 Mtetra
0 .059 .624 r
.6198 .47569 .62614 .48794 .63906 .49924 .63289 .4924 Mtetra
.774 .313 0 r
.63289 .4924 .63906 .49924 .65242 .51747 .64642 .51549 Mtetra
.859 .407 .083 r
.64642 .51549 .65242 .51747 .66614 .539 .66032 .54115 Mtetra
.835 .388 .164 r
.66032 .54115 .66614 .539 .68003 .55862 .67439 .56399 Mtetra
.741 .282 .162 r
.67439 .56399 .68003 .55862 .69379 .57082 .68831 .57827 Mtetra
.459 0 .045 r
.68831 .57827 .69379 .57082 .70711 .57138 .70177 .5796 Mtetra
0 0 0 r
.70177 .5796 .70711 .57138 .71976 .55871 .71451 .56638 Mtetra
.827 .889 .465 r
.71451 .56638 .71976 .55871 .73168 .53427 .72647 .54029 Mtetra
.959 .894 .511 r
.72647 .54029 .73168 .53427 .74298 .5019 .73776 .5056 Mtetra
.99 .877 .541 r
.73776 .5056 .74298 .5019 .7539 .46646 .74865 .46758 Mtetra
.995 .867 .577 r
.74865 .46758 .7539 .46646 .76472 .4323 .75942 .431 Mtetra
.988 .863 .625 r
.75942 .431 .76472 .4323 .77568 .40244 .77034 .39908 Mtetra
.966 .862 .684 r
.77034 .39908 .77568 .40244 .78696 .37825 .78158 .37331 Mtetra
.929 .855 .748 r
.78158 .37331 .78696 .37825 .79863 .35976 .79322 .35369 Mtetra
.874 .839 .807 r
.79322 .35369 .79863 .35976 .81067 .34613 .80526 .3393 Mtetra
.813 .815 .852 r
.80526 .3393 .81067 .34613 .82303 .33615 .81764 .32886 Mtetra
.757 .789 .879 r
.81764 .32886 .82303 .33615 .83565 .32866 .83029 .32108 Mtetra
.716 .769 .894 r
.83029 .32108 .83565 .32866 .84846 .3227 .84313 .31496 Mtetra
.69 .755 .902 r
.84313 .31496 .84846 .3227 .86141 .3176 .85612 .30977 Mtetra
.676 .748 .905 r
.85612 .30977 .86141 .3176 .87446 .31295 .86921 .30505 Mtetra
.669 .744 .907 r
.86921 .30505 .87446 .31295 .88759 .3085 .88238 .30055 Mtetra
.66 .741 .909 r
.28131 .48848 .28827 .49496 .29896 .49154 .29203 .48505 Mtetra
.655 .74 .912 r
.29203 .48505 .29896 .49154 .30969 .48824 .30278 .48175 Mtetra
.642 .737 .917 r
.30278 .48175 .30969 .48824 .32044 .48523 .31356 .47877 Mtetra
.614 .73 .929 r
.31356 .47877 .32044 .48523 .33121 .48284 .32434 .47647 Mtetra
.548 .712 .948 r
.32434 .47647 .33121 .48284 .34196 .48161 .3351 .47547 Mtetra
.388 .652 .962 r
.3351 .47547 .34196 .48161 .35267 .48239 .3458 .47669 Mtetra
0 .435 .859 r
.3458 .47669 .35267 .48239 .36329 .48628 .3564 .48135 Mtetra
.564 .019 0 r
.3564 .48135 .36329 .48628 .37382 .49445 .36688 .49075 Mtetra
.812 .326 0 r
.36688 .49075 .37382 .49445 .38425 .5078 .37723 .50588 Mtetra
.869 .443 .194 r
.37723 .50588 .38425 .5078 .39464 .52637 .38752 .52678 Mtetra
.874 .48 .285 r
.38752 .52678 .39464 .52637 .40508 .54889 .39786 .55201 Mtetra
.859 .478 .325 r
.39786 .55201 .40508 .54889 .41571 .57244 .4084 .5783 Mtetra
.822 .44 .331 r
.4084 .5783 .41571 .57244 .42667 .5929 .41931 .60098 Mtetra
.741 .343 .296 r
.41931 .60098 .42667 .5929 .43803 .60595 .43069 .61509 Mtetra
.514 .081 .155 r
.43069 .61509 .43803 .60595 .44978 .60863 .44253 .61715 Mtetra
0 0 0 r
.44253 .61715 .44978 .60863 .46182 .6005 .45472 .60649 Mtetra
.912 .968 .662 r
.45472 .60649 .46182 .6005 .47401 .58395 .46709 .58562 Mtetra
.97 .89 .691 r
.46709 .58562 .47401 .58395 .48621 .5632 .47946 .55919 Mtetra
.931 .803 .697 r
.47946 .55919 .48621 .5632 .49834 .54262 .49173 .53219 Mtetra
.865 .72 .701 r
.49173 .53219 .49834 .54262 .51039 .52527 .50387 .50837 Mtetra
.789 .64 .697 r
.50387 .50837 .51039 .52527 .52239 .51215 .5159 .48943 Mtetra
.722 .573 .687 r
.5159 .48943 .52239 .51215 .53438 .50243 .52788 .47521 Mtetra
.676 .528 .676 r
.52788 .47521 .53438 .50243 .5464 .49432 .53985 .46446 Mtetra
.65 .502 .669 r
.53985 .46446 .5464 .49432 .55843 .48628 .55184 .45586 Mtetra
.634 .491 .669 r
.55184 .45586 .55843 .48628 .57049 .47793 .56387 .44892 Mtetra
.615 .483 .677 r
.56387 .44892 .57049 .47793 .58257 .47037 .57596 .44427 Mtetra
.574 .468 .695 r
.57596 .44427 .58257 .47037 .59475 .46585 .58818 .4435 Mtetra
.472 .424 .723 r
.58818 .4435 .59475 .46585 .60712 .46698 .60061 .44855 Mtetra
.222 .298 .731 r
.60061 .44855 .60712 .46698 .6198 .47569 .61335 .46085 Mtetra
0 .02 .593 r
.61335 .46085 .6198 .47569 .63289 .4924 .62651 .48055 Mtetra
.627 .239 0 r
.62651 .48055 .63289 .4924 .64642 .51549 .64009 .50594 Mtetra
.754 .329 0 r
.64009 .50594 .64642 .51549 .66032 .54115 .65404 .53327 Mtetra
.739 .287 0 r
.65404 .53327 .66032 .54115 .67439 .56399 .66815 .55726 Mtetra
0 0 .484 r
.66815 .55726 .67439 .56399 .68831 .57827 .68211 .57226 Mtetra
.344 .655 .97 r
.68211 .57226 .68831 .57827 .70177 .5796 .69563 .57395 Mtetra
.854 .846 .835 r
.69563 .57395 .70177 .5796 .71451 .56638 .70844 .5608 Mtetra
.94 .82 .699 r
.70844 .5608 .71451 .56638 .72647 .54029 .72048 .53456 Mtetra
.959 .799 .641 r
.72048 .53456 .72647 .54029 .73776 .5056 .73186 .49957 Mtetra
.963 .79 .622 r
.73186 .49957 .73776 .5056 .74865 .46758 .74282 .46119 Mtetra
.96 .789 .626 r
.74282 .46119 .74865 .46758 .75942 .431 .75367 .42424 Mtetra
.951 .793 .65 r
.75367 .42424 .75942 .431 .77034 .39908 .76466 .392 Mtetra
.933 .799 .689 r
.76466 .392 .77034 .39908 .78158 .37331 .77596 .36597 Mtetra
.903 .804 .74 r
.77596 .36597 .78158 .37331 .79322 .35369 .78766 .34615 Mtetra
.858 .802 .794 r
.78766 .34615 .79322 .35369 .80526 .3393 .79974 .33162 Mtetra
.805 .791 .839 r
.79974 .33162 .80526 .3393 .81764 .32886 .81217 .32108 Mtetra
.754 .776 .871 r
.81217 .32108 .81764 .32886 .83029 .32108 .82486 .31323 Mtetra
.715 .762 .89 r
.82486 .31323 .83029 .32108 .84313 .31496 .83774 .30706 Mtetra
.69 .753 .899 r
.83774 .30706 .84313 .31496 .85612 .30977 .85077 .30182 Mtetra
.676 .747 .904 r
.85077 .30182 .85612 .30977 .86921 .30505 .86391 .29706 Mtetra
.669 .744 .906 r
.86391 .29706 .86921 .30505 .88238 .30055 .87712 .29253 Mtetra
.66 .741 .909 r
.2743 .48196 .28131 .48848 .29203 .48505 .28505 .4785 Mtetra
.655 .739 .912 r
.28505 .4785 .29203 .48505 .30278 .48175 .29582 .47519 Mtetra
.641 .736 .917 r
.29582 .47519 .30278 .48175 .31356 .47877 .30662 .47221 Mtetra
.612 .728 .928 r
.30662 .47221 .31356 .47877 .32434 .47647 .31743 .46995 Mtetra
.544 .707 .946 r
.31743 .46995 .32434 .47647 .3351 .47547 .3282 .46904 Mtetra
.38 .639 .957 r
.3282 .46904 .3351 .47547 .3458 .47669 .33891 .47046 Mtetra
0 .419 .856 r
.33891 .47046 .3458 .47669 .3564 .48135 .3495 .47547 Mtetra
.54 .014 0 r
.3495 .47547 .3564 .48135 .36688 .49075 .35995 .48542 Mtetra
.806 .321 0 r
.35995 .48542 .36688 .49075 .37723 .50588 .37026 .50133 Mtetra
.881 .448 .132 r
.37026 .50133 .37723 .50588 .38752 .52678 .38049 .52321 Mtetra
.899 .493 .217 r
.38049 .52321 .38752 .52678 .39786 .55201 .39076 .5495 Mtetra
.897 .495 .242 r
.39076 .5495 .39786 .55201 .4084 .5783 .40125 .57676 Mtetra
.874 .453 .209 r
.40125 .57676 .4084 .5783 .41931 .60098 .41214 .60003 Mtetra
.784 .294 .047 r
.41214 .60003 .41931 .60098 .43069 .61509 .42353 .6141 Mtetra
0 .541 .739 r
.42353 .6141 .43069 .61509 .44253 .61715 .43543 .61527 Mtetra
.871 .912 .855 r
.43543 .61527 .44253 .61715 .45472 .60649 .44773 .6028 Mtetra
.923 .818 .724 r
.44773 .6028 .45472 .60649 .46709 .58562 .46022 .57928 Mtetra
.915 .767 .682 r
.46022 .57928 .46709 .58562 .47946 .55919 .47273 .54954 Mtetra
.892 .729 .673 r
.47273 .54954 .47946 .55919 .49173 .53219 .48512 .51884 Mtetra
.856 .691 .677 r
.48512 .51884 .49173 .53219 .50387 .50837 .49734 .49126 Mtetra
.807 .647 .684 r
.49734 .49126 .50387 .50837 .5159 .48943 .50941 .46892 Mtetra
.753 .601 .688 r
.50941 .46892 .5159 .48943 .52788 .47521 .5214 .45204 Mtetra
.705 .561 .689 r
.5214 .45204 .52788 .47521 .53985 .46446 .53335 .43975 Mtetra
.668 .532 .689 r
.53335 .43975 .53985 .46446 .55184 .45586 .54532 .4309 Mtetra
.638 .512 .694 r
.54532 .4309 .55184 .45586 .56387 .44892 .55733 .4249 Mtetra
.602 .495 .704 r
.55733 .4249 .56387 .44892 .57596 .44427 .56943 .42204 Mtetra
.539 .466 .722 r
.56943 .42204 .57596 .44427 .58818 .4435 .58165 .42338 Mtetra
.41 .402 .739 r
.58165 .42338 .58818 .4435 .60061 .44855 .59409 .43032 Mtetra
.163 .261 .719 r
.59409 .43032 .60061 .44855 .61335 .46085 .60684 .44389 Mtetra
0 .054 .614 r
.60684 .44389 .61335 .46085 .62651 .48055 .61996 .46406 Mtetra
0 0 .495 r
.61996 .46406 .62651 .48055 .64009 .50594 .63349 .48916 Mtetra
0 0 .477 r
.63349 .48916 .64009 .50594 .65404 .53327 .64735 .51571 Mtetra
0 .01 .582 r
.64735 .51571 .65404 .53327 .66815 .55726 .66137 .5388 Mtetra
.16 .266 .726 r
.66137 .5388 .66815 .55726 .68211 .57226 .67528 .5532 Mtetra
.527 .493 .762 r
.67528 .5532 .68211 .57226 .69563 .57395 .68878 .5549 Mtetra
.728 .606 .721 r
.68878 .5549 .69563 .57395 .70844 .5608 .70164 .54246 Mtetra
.822 .656 .677 r
.70164 .54246 .70844 .5608 .72048 .53456 .7138 .51755 Mtetra
.868 .682 .649 r
.7138 .51755 .72048 .53456 .73186 .49957 .72533 .48424 Mtetra
.891 .7 .638 r
.72533 .48424 .73186 .49957 .74282 .46119 .73648 .44762 Mtetra
.902 .715 .641 r
.73648 .44762 .74282 .46119 .75367 .42424 .74751 .41228 Mtetra
.903 .731 .659 r
.74751 .41228 .75367 .42424 .76466 .392 .75867 .38136 Mtetra
.893 .746 .692 r
.75867 .38136 .76466 .392 .77596 .36597 .77012 .35633 Mtetra
.872 .76 .736 r
.77012 .35633 .77596 .36597 .78766 .34615 .78193 .33721 Mtetra
.837 .769 .787 r
.78193 .33721 .78766 .34615 .79974 .33162 .79411 .32312 Mtetra
.792 .769 .832 r
.79411 .32312 .79974 .33162 .81217 .32108 .80661 .31283 Mtetra
.748 .764 .866 r
.80661 .31283 .81217 .32108 .82486 .31323 .81936 .30512 Mtetra
.712 .756 .886 r
.81936 .30512 .82486 .31323 .83774 .30706 .8323 .29899 Mtetra
.688 .749 .898 r
.8323 .29899 .83774 .30706 .85077 .30182 .84538 .29377 Mtetra
.675 .745 .903 r
.84538 .29377 .85077 .30182 .86391 .29706 .85856 .28899 Mtetra
.669 .743 .906 r
.85856 .28899 .86391 .29706 .87712 .29253 .87182 .28443 Mtetra
.66 .74 .909 r
.26724 .47539 .2743 .48196 .28505 .4785 .27801 .4719 Mtetra
.655 .739 .912 r
.27801 .4719 .28505 .4785 .29582 .47519 .28881 .46856 Mtetra
.641 .736 .917 r
.28881 .46856 .29582 .47519 .30662 .47221 .29964 .46556 Mtetra
.612 .727 .927 r
.29964 .46556 .30662 .47221 .31743 .46995 .31047 .46328 Mtetra
.544 .704 .944 r
.31047 .46328 .31743 .46995 .3282 .46904 .32126 .46236 Mtetra
.387 .636 .954 r
.32126 .46236 .3282 .46904 .33891 .47046 .33198 .46378 Mtetra
.029 .428 .866 r
.33198 .46378 .33891 .47046 .3495 .47547 .34258 .4688 Mtetra
0 .024 .519 r
.34258 .4688 .3495 .47547 .35995 .48542 .35303 .47874 Mtetra
.772 .29 0 r
.35303 .47874 .35995 .48542 .37026 .50133 .36333 .49456 Mtetra
.87 .43 .046 r
.36333 .49456 .37026 .50133 .38049 .52321 .37354 .51623 Mtetra
.899 .482 .12 r
.37354 .51623 .38049 .52321 .39076 .5495 .38379 .54211 Mtetra
.898 .481 .109 r
.38379 .54211 .39076 .5495 .40125 .57676 .39427 .56868 Mtetra
.844 .402 0 r
.39427 .56868 .40125 .57676 .41214 .60003 .40516 .591 Mtetra
0 0 .537 r
.40516 .591 .41214 .60003 .42353 .6141 .41657 .60392 Mtetra
.535 .619 .883 r
.41657 .60392 .42353 .6141 .43543 .61527 .42852 .60385 Mtetra
.792 .696 .758 r
.42852 .60385 .43543 .61527 .44773 .6028 .44088 .59016 Mtetra
.848 .696 .693 r
.44088 .59016 .44773 .6028 .46022 .57928 .45346 .56548 Mtetra
.862 .69 .667 r
.45346 .56548 .46022 .57928 .47273 .54954 .46605 .5346 Mtetra
.858 .681 .661 r
.46605 .5346 .47273 .54954 .48512 .51884 .47851 .50272 Mtetra
.842 .668 .667 r
.47851 .50272 .48512 .51884 .49734 .49126 .49079 .47391 Mtetra
.812 .648 .679 r
.49079 .47391 .49734 .49126 .50941 .46892 .50291 .45038 Mtetra
.772 .622 .693 r
.50291 .45038 .50941 .46892 .5214 .45204 .51492 .43256 Mtetra
.728 .593 .705 r
.51492 .43256 .5214 .45204 .53335 .43975 .52688 .41976 Mtetra
.686 .567 .715 r
.52688 .41976 .53335 .43975 .54532 .4309 .53884 .41098 Mtetra
.645 .545 .726 r
.53884 .41098 .54532 .4309 .55733 .4249 .55085 .40555 Mtetra
.596 .52 .74 r
.55085 .40555 .55733 .4249 .56943 .42204 .56294 .40352 Mtetra
.516 .48 .756 r
.56294 .40352 .56943 .42204 .58165 .42338 .57516 .40558 Mtetra
.374 .402 .761 r
.57516 .40558 .58165 .42338 .59409 .43032 .58758 .41272 Mtetra
.163 .269 .727 r
.58758 .41272 .59409 .43032 .60684 .44389 .60028 .42567 Mtetra
0 .122 .652 r
.60028 .42567 .60684 .44389 .61996 .46406 .61331 .44431 Mtetra
0 .041 .597 r
.61331 .44431 .61996 .46406 .63349 .48916 .6267 .46715 Mtetra
0 .065 .604 r
.6267 .46715 .63349 .48916 .64735 .51571 .6404 .4911 Mtetra
.108 .176 .653 r
.6404 .4911 .64735 .51571 .66137 .5388 .65426 .51185 Mtetra
.344 .322 .691 r
.65426 .51185 .66137 .5388 .67528 .5532 .66804 .52479 Mtetra
.542 .444 .694 r
.66804 .52479 .67528 .5532 .68878 .5549 .68148 .52632 Mtetra
.674 .527 .677 r
.68148 .52632 .68878 .5549 .70164 .54246 .69438 .51514 Mtetra
.756 .581 .659 r
.69438 .51514 .70164 .54246 .7138 .51755 .70667 .49264 Mtetra
.807 .617 .645 r
.70667 .49264 .7138 .51755 .72533 .48424 .71841 .46242 Mtetra
.838 .644 .641 r
.71841 .46242 .72533 .48424 .73648 .44762 .7298 .42906 Mtetra
.856 .668 .647 r
.7298 .42906 .73648 .44762 .74751 .41228 .74109 .3967 Mtetra
.863 .69 .665 r
.74109 .3967 .74751 .41228 .75867 .38136 .75247 .36825 Mtetra
.86 .711 .696 r
.75247 .36825 .75867 .38136 .77012 .35633 .76412 .34508 Mtetra
.845 .731 .738 r
.76412 .34508 .77012 .35633 .78193 .33721 .77609 .32726 Mtetra
.816 .746 .786 r
.77609 .32726 .78193 .33721 .79411 .32312 .78839 .31402 Mtetra
.778 .753 .83 r
.78839 .31402 .79411 .32312 .80661 .31283 .80099 .30423 Mtetra
.739 .753 .864 r
.80099 .30423 .80661 .31283 .81936 .30512 .81381 .29679 Mtetra
.707 .75 .885 r
.81381 .29679 .81936 .30512 .8323 .29899 .82681 .2908 Mtetra
.686 .746 .897 r
.82681 .2908 .8323 .29899 .84538 .29377 .83994 .28561 Mtetra
.674 .744 .903 r
.83994 .28561 .84538 .29377 .85856 .28899 .85317 .28084 Mtetra
.668 .742 .906 r
.85317 .28084 .85856 .28899 .87182 .28443 .86647 .27626 Mtetra
.66 .74 .909 r
.26013 .46876 .26724 .47539 .27801 .4719 .27092 .46525 Mtetra
.655 .739 .912 r
.27092 .46525 .27801 .4719 .28881 .46856 .28175 .46188 Mtetra
.642 .735 .917 r
.28175 .46188 .28881 .46856 .29964 .46556 .2926 .45885 Mtetra
.612 .727 .927 r
.2926 .45885 .29964 .46556 .31047 .46328 .30345 .45653 Mtetra
.546 .703 .943 r
.30345 .45653 .31047 .46328 .32126 .46236 .31427 .45557 Mtetra
.394 .637 .952 r
.31427 .45557 .32126 .46236 .33198 .46378 .32501 .45691 Mtetra
.057 .441 .876 r
.32501 .45691 .33198 .46378 .34258 .4688 .33563 .46178 Mtetra
0 .06 .564 r
.33563 .46178 .34258 .4688 .35303 .47874 .34609 .47144 Mtetra
.738 .256 0 r
.34609 .47144 .35303 .47874 .36333 .49456 .35639 .48678 Mtetra
.847 .403 0 r
.35639 .48678 .36333 .49456 .37354 .51623 .36661 .50762 Mtetra
.877 .454 .039 r
.36661 .50762 .37354 .51623 .38379 .54211 .37688 .53226 Mtetra
.856 .437 0 r
.37688 .53226 .38379 .54211 .39427 .56868 .38738 .55718 Mtetra
.69 .276 0 r
.38738 .55718 .39427 .56868 .40516 .591 .3983 .57755 Mtetra
.012 .239 .746 r
.3983 .57755 .40516 .591 .41657 .60392 .40975 .5885 Mtetra
.594 .561 .787 r
.40975 .5885 .41657 .60392 .42852 .60385 .42174 .5868 Mtetra
.758 .628 .716 r
.42174 .5868 .42852 .60385 .44088 .59016 .43415 .57209 Mtetra
.812 .646 .676 r
.43415 .57209 .44088 .59016 .45346 .56548 .44677 .54709 Mtetra
.833 .653 .659 r
.44677 .54709 .45346 .56548 .46605 .5346 .45941 .51643 Mtetra
.837 .656 .657 r
.45941 .51643 .46605 .5346 .47851 .50272 .47191 .48505 Mtetra
.83 .655 .665 r
.47191 .48505 .47851 .50272 .49079 .47391 .48423 .45677 Mtetra
.812 .65 .681 r
.48423 .45677 .49079 .47391 .50291 .45038 .49639 .43365 Mtetra
.783 .639 .703 r
.49639 .43365 .50291 .45038 .51492 .43256 .50842 .41612 Mtetra
.745 .624 .725 r
.50842 .41612 .51492 .43256 .52688 .41976 .5204 .40358 Mtetra
.702 .605 .745 r
.5204 .40358 .52688 .41976 .53884 .41098 .53237 .39509 Mtetra
.656 .584 .763 r
.53237 .39509 .53884 .41098 .55085 .40555 .54439 .38998 Mtetra
.596 .557 .781 r
.54439 .38998 .55085 .40555 .56294 .40352 .55648 .38813 Mtetra
.506 .509 .794 r
.55648 .38813 .56294 .40352 .57516 .40558 .56869 .38997 Mtetra
.369 .426 .789 r
.56869 .38997 .57516 .40558 .58758 .41272 .58108 .3962 Mtetra
.197 .306 .75 r
.58108 .3962 .58758 .41272 .60028 .42567 .59371 .4074 Mtetra
.058 .193 .69 r
.59371 .4074 .60028 .42567 .61331 .44431 .60663 .42342 Mtetra
.019 .14 .65 r
.60663 .42342 .61331 .44431 .6267 .46715 .61986 .44304 Mtetra
.087 .163 .648 r
.61986 .44304 .6267 .46715 .6404 .4911 .63338 .46366 Mtetra
.231 .242 .665 r
.63338 .46366 .6404 .4911 .65426 .51185 .64705 .48162 Mtetra
.398 .342 .678 r
.64705 .48162 .65426 .51185 .66804 .52479 .66068 .49294 Mtetra
.542 .432 .677 r
.66068 .49294 .66804 .52479 .68148 .52632 .67405 .49445 Mtetra
.651 .501 .667 r
.67405 .49445 .68148 .52632 .69438 .51514 .68699 .48486 Mtetra
.726 .553 .656 r
.68699 .48486 .69438 .51514 .70667 .49264 .69941 .46525 Mtetra
.778 .592 .648 r
.69941 .46525 .70667 .49264 .71841 .46242 .71137 .43866 Mtetra
.812 .623 .647 r
.71137 .43866 .71841 .46242 .7298 .42906 .72302 .40902 Mtetra
.833 .65 .655 r
.72302 .40902 .7298 .42906 .74109 .3967 .73457 .38005 Mtetra
.843 .675 .674 r
.73457 .38005 .74109 .3967 .75247 .36825 .7462 .35439 Mtetra
.841 .698 .705 r
.7462 .35439 .75247 .36825 .76412 .34508 .75805 .33333 Mtetra
.828 .72 .746 r
.75805 .33333 .76412 .34508 .77609 .32726 .77019 .31698 Mtetra
.801 .737 .792 r
.77019 .31698 .77609 .32726 .78839 .31402 .78262 .30469 Mtetra
.766 .746 .834 r
.78262 .30469 .78839 .31402 .80099 .30423 .79531 .29548 Mtetra
.731 .748 .866 r
.79531 .29548 .80099 .30423 .81381 .29679 .80821 .28835 Mtetra
.702 .747 .886 r
.80821 .28835 .81381 .29679 .82681 .2908 .82127 .28251 Mtetra
.683 .745 .898 r
.82127 .28251 .82681 .2908 .83994 .28561 .83445 .27738 Mtetra
.673 .743 .903 r
.83445 .27738 .83994 .28561 .85317 .28084 .84773 .27262 Mtetra
.667 .742 .906 r
.84773 .27262 .85317 .28084 .86647 .27626 .86108 .26802 Mtetra
.66 .74 .909 r
.25296 .46209 .26013 .46876 .27092 .46525 .26378 .45855 Mtetra
.655 .739 .912 r
.26378 .45855 .27092 .46525 .28175 .46188 .27464 .45515 Mtetra
.641 .736 .917 r
.27464 .45515 .28175 .46188 .2926 .45885 .28551 .4521 Mtetra
.612 .727 .927 r
.28551 .4521 .2926 .45885 .30345 .45653 .29639 .44977 Mtetra
.545 .704 .944 r
.29639 .44977 .30345 .45653 .31427 .45557 .30722 .4488 Mtetra
.39 .637 .954 r
.30722 .4488 .31427 .45557 .32501 .45691 .31798 .45013 Mtetra
.046 .439 .873 r
.31798 .45013 .32501 .45691 .33563 .46178 .3286 .45497 Mtetra
0 .056 .552 r
.3286 .45497 .33563 .46178 .34609 .47144 .33907 .46452 Mtetra
.743 .254 0 r
.33907 .46452 .34609 .47144 .35639 .48678 .34937 .47953 Mtetra
.846 .396 0 r
.34937 .47953 .35639 .48678 .36661 .50762 .3596 .49972 Mtetra
.874 .443 .039 r
.3596 .49972 .36661 .50762 .37688 .53226 .36988 .5232 Mtetra
.848 .417 0 r
.36988 .5232 .37688 .53226 .38738 .55718 .38042 .5464 Mtetra
.647 .221 0 r
.38042 .5464 .38738 .55718 .3983 .57755 .39139 .5646 Mtetra
.133 .331 .795 r
.39139 .5646 .3983 .57755 .40975 .5885 .4029 .57325 Mtetra
.633 .584 .781 r
.4029 .57325 .40975 .5885 .42174 .5868 .41496 .56956 Mtetra
.766 .631 .71 r
.41496 .56956 .42174 .5868 .43415 .57209 .42742 .5536 Mtetra
.812 .644 .674 r
.42742 .5536 .43415 .57209 .44677 .54709 .44009 .52827 Mtetra
.829 .649 .659 r
.44009 .52827 .44677 .54709 .45941 .51643 .45276 .49813 Mtetra
.833 .653 .659 r
.45276 .49813 .45941 .51643 .47191 .48505 .4653 .46781 Mtetra
.828 .657 .669 r
.4653 .46781 .47191 .48505 .48423 .45677 .47765 .44076 Mtetra
.814 .658 .689 r
.47765 .44076 .48423 .45677 .49639 .43365 .48983 .41878 Mtetra
.791 .657 .716 r
.48983 .41878 .49639 .43365 .50842 .41612 .50189 .40215 Mtetra
.757 .652 .746 r
.50189 .40215 .50842 .41612 .5204 .40358 .51389 .39025 Mtetra
.715 .643 .775 r
.51389 .39025 .5204 .40358 .53237 .39509 .52589 .38217 Mtetra
.665 .626 .801 r
.52589 .38217 .53237 .39509 .54439 .38998 .53792 .37723 Mtetra
.601 .599 .821 r
.53792 .37723 .54439 .38998 .55648 .38813 .55002 .3752 Mtetra
.51 .549 .832 r
.55002 .3752 .55648 .38813 .56869 .38997 .56223 .37636 Mtetra
.381 .465 .822 r
.56223 .37636 .56869 .38997 .58108 .3962 .57459 .38127 Mtetra
.234 .353 .781 r
.57459 .38127 .58108 .3962 .59371 .4074 .58715 .39041 Mtetra
.119 .25 .725 r
.58715 .39041 .59371 .4074 .60663 .42342 .59997 .40374 Mtetra
.084 .197 .685 r
.59997 .40374 .60663 .42342 .61986 .44304 .61307 .42032 Mtetra
.135 .206 .673 r
.61307 .42032 .61986 .44304 .63338 .46366 .62643 .43804 Mtetra
.252 .266 .681 r
.62643 .43804 .63338 .46366 .64705 .48162 .63995 .4538 Mtetra
.396 .351 .69 r
.63995 .4538 .64705 .48162 .66068 .49294 .65347 .46411 Mtetra
.534 .437 .691 r
.65347 .46411 .66068 .49294 .67405 .49445 .66681 .46604 Mtetra
.644 .508 .683 r
.66681 .46604 .67405 .49445 .68699 .48486 .6798 .45823 Mtetra
.725 .564 .672 r
.6798 .45823 .68699 .48486 .69941 .46525 .69236 .44135 Mtetra
.78 .606 .664 r
.69236 .44135 .69941 .46525 .71137 .43866 .70451 .41793 Mtetra
.816 .639 .663 r
.70451 .41793 .71137 .43866 .72302 .40902 .71639 .39143 Mtetra
.838 .667 .67 r
.71639 .39143 .72302 .40902 .73457 .38005 .72815 .36521 Mtetra
.846 .691 .69 r
.72815 .36521 .73457 .38005 .7462 .35439 .73998 .34175 Mtetra
.843 .713 .721 r
.73998 .34175 .7462 .35439 .75805 .33333 .752 .32232 Mtetra
.826 .732 .761 r
.752 .32232 .75805 .33333 .77019 .31698 .76428 .30711 Mtetra
.796 .744 .805 r
.76428 .30711 .77019 .31698 .78262 .30469 .77682 .29555 Mtetra
.76 .75 .843 r
.77682 .29555 .78262 .30469 .79531 .29548 .7896 .28678 Mtetra
.725 .75 .872 r
.7896 .28678 .79531 .29548 .80821 .28835 .80257 .2799 Mtetra
.698 .747 .889 r
.80257 .2799 .80821 .28835 .82127 .28251 .81568 .27418 Mtetra
.681 .744 .899 r
.81568 .27418 .82127 .28251 .83445 .27738 .82892 .26909 Mtetra
.672 .743 .904 r
.82892 .26909 .83445 .27738 .84773 .27262 .84224 .26433 Mtetra
.667 .742 .906 r
.84224 .26433 .84773 .27262 .86108 .26802 .85564 .25971 Mtetra
.66 .74 .91 r
.24573 .45536 .25296 .46209 .26378 .45855 .25658 .4518 Mtetra
.654 .739 .912 r
.25658 .4518 .26378 .45855 .27464 .45515 .26746 .44839 Mtetra
.64 .736 .918 r
.26746 .44839 .27464 .45515 .28551 .4521 .27836 .44534 Mtetra
.609 .727 .929 r
.27836 .44534 .28551 .4521 .29639 .44977 .28926 .44305 Mtetra
.536 .704 .948 r
.28926 .44305 .29639 .44977 .30722 .4488 .30011 .44217 Mtetra
.365 .632 .956 r
.30011 .44217 .30722 .4488 .31798 .45013 .31087 .4437 Mtetra
0 .406 .847 r
.31087 .4437 .31798 .45013 .3286 .45497 .32148 .44883 Mtetra
.531 .007 0 r
.32148 .44883 .3286 .45497 .33907 .46452 .33192 .45874 Mtetra
.786 .296 0 r
.33192 .45874 .33907 .46452 .34937 .47953 .3422 .4741 Mtetra
.865 .417 .068 r
.3422 .4741 .34937 .47953 .3596 .49972 .3524 .49441 Mtetra
.885 .455 .125 r
.3524 .49441 .3596 .49972 .36988 .5232 .36267 .51759 Mtetra
.874 .433 .084 r
.36267 .51759 .36988 .5232 .38042 .5464 .37322 .53982 Mtetra
.767 .28 0 r
.37322 .53982 .38042 .5464 .39139 .5646 .38424 .55635 Mtetra
.02 .383 .845 r
.38424 .55635 .39139 .5646 .4029 .57325 .39584 .56282 Mtetra
.698 .684 .833 r
.39584 .56282 .4029 .57325 .41496 .56956 .408 .55689 Mtetra
.813 .688 .727 r
.408 .55689 .41496 .56956 .42742 .5536 .42055 .53914 Mtetra
.843 .681 .682 r
.42055 .53914 .42742 .5536 .44009 .52827 .4333 .51285 Mtetra
.851 .677 .666 r
.4333 .51285 .44009 .52827 .45276 .49813 .44603 .48263 Mtetra
.849 .675 .666 r
.44603 .48263 .45276 .49813 .4653 .46781 .45862 .45294 Mtetra
.841 .677 .679 r
.45862 .45294 .4653 .46781 .47765 .44076 .471 .42691 Mtetra
.825 .68 .702 r
.471 .42691 .47765 .44076 .48983 .41878 .48322 .406 Mtetra
.801 .683 .733 r
.48322 .406 .48983 .41878 .50189 .40215 .49531 .39029 Mtetra
.768 .683 .77 r
.49531 .39029 .50189 .40215 .51389 .39025 .50734 .37906 Mtetra
.725 .679 .805 r
.50734 .37906 .51389 .39025 .52589 .38217 .51937 .37137 Mtetra
.673 .666 .835 r
.51937 .37137 .52589 .38217 .53792 .37723 .53142 .36651 Mtetra
.608 .64 .857 r
.53142 .36651 .53792 .37723 .55002 .3752 .54354 .36422 Mtetra
.518 .592 .868 r
.54354 .36422 .55002 .3752 .56223 .37636 .55575 .36468 Mtetra
.392 .509 .858 r
.55575 .36468 .56223 .37636 .57459 .38127 .5681 .3684 Mtetra
.243 .396 .818 r
.5681 .3684 .57459 .38127 .58715 .39041 .58062 .3759 Mtetra
.11 .282 .758 r
.58062 .3759 .58715 .39041 .59997 .40374 .59338 .3873 Mtetra
.04 .206 .709 r
.59338 .3873 .59997 .40374 .61307 .42032 .6064 .40194 Mtetra
.054 .192 .691 r
.6064 .40194 .61307 .42032 .62643 .43804 .61966 .41812 Mtetra
.152 .244 .706 r
.61966 .41812 .62643 .43804 .63995 .4538 .63311 .43311 Mtetra
.314 .344 .733 r
.63311 .43311 .63995 .4538 .65347 .46411 .64661 .4436 Mtetra
.497 .462 .749 r
.64661 .4436 .65347 .46411 .66681 .46604 .65997 .44666 Mtetra
.652 .563 .741 r
.65997 .44666 .66681 .46604 .6798 .45823 .67305 .44065 Mtetra
.761 .634 .72 r
.67305 .44065 .6798 .45823 .69236 .44135 .68573 .42585 Mtetra
.827 .68 .7 r
.68573 .42585 .69236 .44135 .70451 .41793 .69804 .40441 Mtetra
.864 .71 .689 r
.69804 .40441 .70451 .41793 .71639 .39143 .71006 .37955 Mtetra
.881 .732 .692 r
.71006 .37955 .71639 .39143 .72815 .36521 .72197 .35457 Mtetra
.882 .749 .71 r
.72197 .35457 .72815 .36521 .73998 .34175 .73393 .33197 Mtetra
.869 .761 .741 r
.73393 .33197 .73998 .34175 .752 .32232 .74605 .31312 Mtetra
.842 .769 .781 r
.74605 .31312 .752 .32232 .76428 .30711 .75841 .29828 Mtetra
.804 .77 .821 r
.75841 .29828 .76428 .30711 .77682 .29555 .77102 .28696 Mtetra
.762 .765 .855 r
.77102 .28696 .77682 .29555 .7896 .28678 .78386 .27834 Mtetra
.724 .758 .879 r
.78386 .27834 .7896 .28678 .80257 .2799 .79689 .27153 Mtetra
.697 .751 .893 r
.79689 .27153 .80257 .2799 .81568 .27418 .81006 .26584 Mtetra
.68 .746 .901 r
.81006 .26584 .81568 .27418 .82892 .26909 .82334 .26076 Mtetra
.671 .743 .905 r
.82334 .26076 .82892 .26909 .84224 .26433 .83671 .25598 Mtetra
.667 .742 .907 r
.83671 .25598 .84224 .26433 .85564 .25971 .85016 .25133 Mtetra
.66 .74 .91 r
.23845 .44859 .24573 .45536 .25658 .4518 .24933 .44501 Mtetra
.653 .739 .913 r
.24933 .44501 .25658 .4518 .26746 .44839 .26023 .44159 Mtetra
.638 .736 .919 r
.26023 .44159 .26746 .44839 .27836 .44534 .27115 .43857 Mtetra
.603 .727 .932 r
.27115 .43857 .27836 .44534 .28926 .44305 .28206 .43637 Mtetra
.52 .701 .952 r
.28206 .43637 .28926 .44305 .30011 .44217 .29292 .43572 Mtetra
.316 .615 .955 r
.29292 .43572 .30011 .44217 .31087 .4437 .30366 .43765 Mtetra
0 .333 .783 r
.30366 .43765 .31087 .4437 .32148 .44883 .31425 .44345 Mtetra
.64 .106 0 r
.31425 .44345 .32148 .44883 .33192 .45874 .32463 .4543 Mtetra
.827 .351 .012 r
.32463 .4543 .33192 .45874 .3422 .4741 .33483 .47081 Mtetra
.875 .443 .164 r
.33483 .47081 .3422 .4741 .3524 .49441 .34495 .4923 Mtetra
.882 .468 .22 r
.34495 .4923 .3524 .49441 .36267 .51759 .35517 .51632 Mtetra
.868 .445 .21 r
.35517 .51632 .36267 .51759 .37322 .53982 .36571 .53872 Mtetra
.809 .335 .089 r
.36571 .53872 .37322 .53982 .38424 .55635 .37677 .55447 Mtetra
.358 0 0 r
.37677 .55447 .38424 .55635 .39584 .56282 .38846 .55924 Mtetra
.785 .88 .916 r
.38846 .55924 .39584 .56282 .408 .55689 .40075 .55102 Mtetra
.889 .792 .747 r
.40075 .55102 .408 .55689 .42055 .53914 .41345 .53097 Mtetra
.897 .749 .689 r
.41345 .53097 .42055 .53914 .4333 .51285 .42633 .50287 Mtetra
.892 .728 .672 r
.42633 .50287 .4333 .51285 .44603 .48263 .43917 .47163 Mtetra
.882 .718 .674 r
.43917 .47163 .44603 .48263 .45862 .45294 .45183 .44167 Mtetra
.868 .715 .69 r
.45183 .44167 .45862 .45294 .471 .42691 .46428 .41591 Mtetra
.847 .715 .717 r
.46428 .41591 .471 .42691 .48322 .406 .47654 .39554 Mtetra
.819 .718 .754 r
.47654 .39554 .48322 .406 .49531 .39029 .48867 .38039 Mtetra
.781 .719 .795 r
.48867 .38039 .49531 .39029 .50734 .37906 .50074 .36961 Mtetra
.734 .715 .833 r
.50074 .36961 .50734 .37906 .51937 .37137 .5128 .36219 Mtetra
.679 .703 .866 r
.5128 .36219 .51937 .37137 .53142 .36651 .52489 .35737 Mtetra
.611 .679 .89 r
.52489 .35737 .53142 .36651 .54354 .36422 .53703 .35489 Mtetra
.517 .632 .903 r
.53703 .35489 .54354 .36422 .55575 .36468 .54926 .35491 Mtetra
.378 .549 .897 r
.54926 .35491 .55575 .36468 .5681 .3684 .56161 .35797 Mtetra
.188 .419 .853 r
.56161 .35797 .5681 .3684 .58062 .3759 .57412 .36468 Mtetra
0 .261 .768 r
.57412 .36468 .58062 .3759 .59338 .3873 .58686 .37538 Mtetra
0 .125 .675 r
.58686 .37538 .59338 .3873 .6064 .40194 .59985 .3897 Mtetra
0 .054 .619 r
.59985 .3897 .6064 .40194 .61966 .41812 .61311 .40617 Mtetra
0 .073 .635 r
.61311 .40617 .61966 .41812 .63311 .43311 .62658 .42219 Mtetra
0 .217 .741 r
.62658 .42219 .63311 .43311 .64661 .4436 .64013 .43436 Mtetra
.255 .502 .898 r
.64013 .43436 .64661 .4436 .65997 .44666 .6536 .43935 Mtetra
.657 .765 .929 r
.6536 .43935 .65997 .44666 .67305 .44065 .6668 .43508 Mtetra
.864 .854 .831 r
.6668 .43508 .67305 .44065 .68573 .42585 .67961 .42142 Mtetra
.934 .861 .744 r
.67961 .42142 .68573 .42585 .69804 .40441 .69202 .40034 Mtetra
.955 .854 .702 r
.69202 .40034 .69804 .40441 .71006 .37955 .70413 .37516 Mtetra
.955 .848 .696 r
.70413 .37516 .71006 .37955 .72197 .35457 .71609 .34943 Mtetra
.943 .843 .715 r
.71609 .34943 .72197 .35457 .73393 .33197 .72807 .32595 Mtetra
.917 .838 .752 r
.72807 .32595 .73393 .33197 .74605 .31312 .74022 .30629 Mtetra
.876 .827 .795 r
.74022 .30629 .74605 .31312 .75841 .29828 .7526 .29084 Mtetra
.825 .81 .836 r
.7526 .29084 .75841 .29828 .77102 .28696 .76525 .27911 Mtetra
.773 .789 .866 r
.76525 .27911 .77102 .28696 .78386 .27834 .77812 .27024 Mtetra
.729 .77 .886 r
.77812 .27024 .78386 .27834 .79689 .27153 .79118 .2633 Mtetra
.699 .757 .897 r
.79118 .2633 .79689 .27153 .81006 .26584 .80439 .25753 Mtetra
.681 .749 .903 r
.80439 .25753 .81006 .26584 .82334 .26076 .81772 .25239 Mtetra
.671 .744 .905 r
.81772 .25239 .82334 .26076 .83671 .25598 .83113 .24757 Mtetra
.667 .742 .907 r
.83113 .24757 .83671 .25598 .85016 .25133 .84462 .24289 Mtetra
.659 .74 .91 r
.23112 .44176 .23845 .44859 .24933 .44501 .24202 .43817 Mtetra
.652 .739 .913 r
.24202 .43817 .24933 .44501 .26023 .44159 .25295 .43475 Mtetra
.635 .735 .92 r
.25295 .43475 .26023 .44159 .27115 .43857 .26389 .43178 Mtetra
.595 .725 .935 r
.26389 .43178 .27115 .43857 .28206 .43637 .27481 .42971 Mtetra
.5 .695 .956 r
.27481 .42971 .28206 .43637 .29292 .43572 .28566 .42934 Mtetra
.255 .587 .947 r
.28566 .42934 .29292 .43572 .30366 .43765 .29638 .43181 Mtetra
0 .239 .696 r
.29638 .43181 .30366 .43765 .31425 .44345 .30691 .4385 Mtetra
.717 .194 0 r
.30691 .4385 .31425 .44345 .32463 .4543 .31721 .45066 Mtetra
.851 .394 .094 r
.31721 .45066 .32463 .4543 .33483 .47081 .32731 .46886 Mtetra
.879 .464 .223 r
.32731 .46886 .33483 .47081 .34495 .4923 .33731 .49223 Mtetra
.876 .479 .274 r
.33731 .49223 .34495 .4923 .35517 .51632 .34743 .51798 Mtetra
.854 .452 .275 r
.34743 .51798 .35517 .51632 .36571 .53872 .35791 .54149 Mtetra
.791 .351 .204 r
.35791 .54149 .36571 .53872 .37677 .55447 .36899 .55734 Mtetra
.486 0 0 r
.36899 .55734 .37677 .55447 .38846 .55924 .38077 .56104 Mtetra
.77 .996 .86 r
.38077 .56104 .38846 .55924 .40075 .55102 .39321 .55083 Mtetra
.947 .885 .738 r
.39321 .55083 .40075 .55102 .41345 .53097 .40609 .52839 Mtetra
.946 .815 .683 r
.40609 .52839 .41345 .53097 .42633 .50287 .41915 .49806 Mtetra
.934 .782 .669 r
.41915 .49806 .42633 .50287 .43917 .47163 .43213 .46515 Mtetra
.92 .767 .676 r
.43213 .46515 .43917 .47163 .45183 .44167 .44492 .43419 Mtetra
.902 .762 .697 r
.44492 .43419 .45183 .44167 .46428 .41591 .45745 .40798 Mtetra
.877 .762 .731 r
.45745 .40798 .46428 .41591 .47654 .39554 .46978 .38751 Mtetra
.843 .763 .774 r
.46978 .38751 .47654 .39554 .48867 .38039 .48197 .37244 Mtetra
.799 .763 .82 r
.48197 .37244 .48867 .38039 .50074 .36961 .49408 .36177 Mtetra
.744 .756 .862 r
.49408 .36177 .50074 .36961 .5128 .36219 .50618 .35444 Mtetra
.682 .743 .897 r
.50618 .35444 .5128 .36219 .52489 .35737 .5183 .34967 Mtetra
.605 .718 .924 r
.5183 .34967 .52489 .35737 .53703 .35489 .53047 .34718 Mtetra
.492 .67 .942 r
.53047 .34718 .53703 .35489 .54926 .35491 .54273 .34716 Mtetra
.305 .57 .932 r
.54273 .34716 .54926 .35491 .56161 .35797 .5551 .35021 Mtetra
.012 .383 .845 r
.5551 .35021 .56161 .35797 .57412 .36468 .56763 .35709 Mtetra
0 .125 .644 r
.56763 .35709 .57412 .36468 .58686 .37538 .58039 .36838 Mtetra
.586 .099 0 r
.58039 .36838 .58686 .37538 .59985 .3897 .59341 .38394 Mtetra
.721 .227 0 r
.59341 .38394 .59985 .3897 .61311 .40617 .60673 .40245 Mtetra
.768 .266 0 r
.60673 .40245 .61311 .40617 .62658 .42219 .6203 .42118 Mtetra
.74 .216 0 r
.6203 .42118 .62658 .42219 .64013 .43436 .63399 .43632 Mtetra
.584 .027 0 r
.63399 .43632 .64013 .43436 .6536 .43935 .64762 .44393 Mtetra
.13 0 0 r
.64762 .44393 .6536 .43935 .6668 .43508 .66097 .44124 Mtetra
0 0 0 r
.66097 .44124 .6668 .43508 .67961 .42142 .67391 .42773 Mtetra
.82 .922 .534 r
.67391 .42773 .67961 .42142 .69202 .40034 .6864 .4054 Mtetra
.931 .929 .564 r
.6864 .4054 .69202 .40034 .70413 .37516 .69852 .37797 Mtetra
.97 .924 .606 r
.69852 .37797 .70413 .37516 .71609 .34943 .71045 .34957 Mtetra
.977 .917 .662 r
.71045 .34957 .71609 .34943 .72807 .32595 .72239 .32352 Mtetra
.958 .905 .726 r
.72239 .32352 .72807 .32595 .74022 .30629 .73449 .30174 Mtetra
.914 .882 .789 r
.73449 .30174 .74022 .30629 .7526 .29084 .74684 .28472 Mtetra
.854 .85 .838 r
.74684 .28472 .7526 .29084 .76525 .27911 .75947 .27197 Mtetra
.791 .815 .871 r
.75947 .27197 .76525 .27911 .77812 .27024 .77236 .26247 Mtetra
.739 .785 .89 r
.77236 .26247 .77812 .27024 .79118 .2633 .78544 .25518 Mtetra
.703 .764 .899 r
.78544 .25518 .79118 .2633 .80439 .25753 .79869 .24923 Mtetra
.683 .752 .904 r
.79869 .24923 .80439 .25753 .81772 .25239 .81205 .24399 Mtetra
.672 .746 .906 r
.81205 .24399 .81772 .25239 .83113 .24757 .82551 .23911 Mtetra
.667 .743 .907 r
.82551 .23911 .83113 .24757 .84462 .24289 .83905 .23437 Mtetra
.659 .74 .91 r
.22372 .43489 .23112 .44176 .24202 .43817 .23465 .43127 Mtetra
.651 .739 .913 r
.23465 .43127 .24202 .43817 .25295 .43475 .2456 .42785 Mtetra
.633 .734 .921 r
.2456 .42785 .25295 .43475 .26389 .43178 .25656 .42491 Mtetra
.589 .723 .936 r
.25656 .42491 .26389 .43178 .27481 .42971 .2675 .42296 Mtetra
.483 .687 .957 r
.2675 .42296 .27481 .42971 .28566 .42934 .27835 .42285 Mtetra
.208 .557 .934 r
.27835 .42285 .28566 .42934 .29638 .43181 .28905 .4258 Mtetra
0 .171 .636 r
.28905 .4258 .29638 .43181 .30691 .4385 .29953 .4333 Mtetra
.752 .242 0 r
.29953 .4333 .30691 .4385 .31721 .45066 .30975 .44667 Mtetra
.865 .42 .118 r
.30975 .44667 .31721 .45066 .32731 .46886 .31973 .46646 Mtetra
.889 .482 .235 r
.31973 .46646 .32731 .46886 .33731 .49223 .3296 .49168 Mtetra
.885 .492 .281 r
.3296 .49168 .33731 .49223 .34743 .51798 .3396 .51924 Mtetra
.862 .463 .279 r
.3396 .51924 .34743 .51798 .35791 .54149 .35001 .54413 Mtetra
.796 .358 .206 r
.35001 .54413 .35791 .54149 .36899 .55734 .36108 .56056 Mtetra
.471 0 0 r
.36108 .56056 .36899 .55734 .38077 .56104 .37294 .56388 Mtetra
.778 .998 .819 r
.37294 .56388 .38077 .56104 .39321 .55083 .38551 .55246 Mtetra
.961 .905 .719 r
.38551 .55246 .39321 .55083 .40609 .52839 .39856 .52834 Mtetra
.965 .841 .671 r
.39856 .52834 .40609 .52839 .41915 .49806 .41179 .49631 Mtetra
.957 .814 .661 r
.41179 .49631 .41915 .49806 .43213 .46515 .42493 .46197 Mtetra
.946 .805 .671 r
.42493 .46197 .43213 .46515 .44492 .43419 .43785 .42995 Mtetra
.932 .806 .698 r
.43785 .42995 .44492 .43419 .45745 .40798 .4505 .40302 Mtetra
.909 .812 .739 r
.4505 .40302 .45745 .40798 .46978 .38751 .46292 .38205 Mtetra
.874 .819 .791 r
.46292 .38205 .46978 .38751 .48197 .37244 .47518 .36663 Mtetra
.823 .819 .845 r
.47518 .36663 .48197 .37244 .49408 .36177 .48735 .35573 Mtetra
.758 .811 .894 r
.48735 .35573 .49408 .36177 .50618 .35444 .49949 .34832 Mtetra
.68 .793 .934 r
.49949 .34832 .50618 .35444 .5183 .34967 .51165 .34363 Mtetra
.578 .763 .966 r
.51165 .34363 .5183 .34967 .53047 .34718 .52387 .34136 Mtetra
.412 .698 .98 r
.52387 .34136 .53047 .34718 .54273 .34716 .53616 .34172 Mtetra
.114 .536 .915 r
.53616 .34172 .54273 .34716 .5551 .35021 .54856 .34536 Mtetra
0 .223 .664 r
.54856 .34536 .5551 .35021 .56763 .35709 .56113 .35318 Mtetra
.638 .096 0 r
.56113 .35318 .56763 .35709 .58039 .36838 .57393 .36596 Mtetra
.784 .282 0 r
.57393 .36596 .58039 .36838 .59341 .38394 .58702 .38376 Mtetra
.83 .362 .085 r
.58702 .38376 .59341 .38394 .60673 .40245 .60044 .40532 Mtetra
.825 .377 .167 r
.60044 .40532 .60673 .40245 .6203 .42118 .61414 .42769 Mtetra
.777 .338 .208 r
.61414 .42769 .6203 .42118 .63399 .43632 .62801 .44649 Mtetra
.662 .229 .211 r
.62801 .44649 .63399 .43632 .64762 .44393 .64183 .45694 Mtetra
.418 .009 .154 r
.64183 .45694 .64762 .44393 .66097 .44124 .65537 .45551 Mtetra
0 0 .005 r
.65537 .45551 .66097 .44124 .67391 .42773 .66843 .44132 Mtetra
0 0 0 r
.66843 .44132 .67391 .42773 .6864 .4054 .68097 .41652 Mtetra
.774 .827 .357 r
.68097 .41652 .6864 .4054 .69852 .37797 .69307 .38547 Mtetra
.911 .893 .477 r
.69307 .38547 .69852 .37797 .71045 .34957 .70493 .35309 Mtetra
.966 .919 .579 r
.70493 .35309 .71045 .34957 .72239 .32352 .71678 .32336 Mtetra
.973 .923 .675 r
.71678 .32336 .72239 .32352 .73449 .30174 .72879 .2986 Mtetra
.94 .907 .761 r
.72879 .2986 .73449 .30174 .74684 .28472 .74109 .27942 Mtetra
.88 .874 .826 r
.74109 .27942 .74684 .28472 .75947 .27197 .75368 .26524 Mtetra
.81 .832 .867 r
.75368 .26524 .75947 .27197 .77236 .26247 .76656 .25489 Mtetra
.751 .795 .889 r
.76656 .25489 .77236 .26247 .78544 .25518 .77966 .24712 Mtetra
.709 .77 .899 r
.77966 .24712 .78544 .25518 .79869 .24923 .79294 .24091 Mtetra
.685 .755 .904 r
.79294 .24091 .79869 .24923 .81205 .24399 .80634 .23554 Mtetra
.673 .747 .906 r
.80634 .23554 .81205 .24399 .82551 .23911 .81984 .23058 Mtetra
.667 .743 .907 r
.81984 .23058 .82551 .23911 .83905 .23437 .83342 .22579 Mtetra
.659 .74 .91 r
.21627 .42795 .22372 .43489 .23465 .43127 .22722 .42431 Mtetra
.651 .738 .914 r
.22722 .42431 .23465 .43127 .2456 .42785 .2382 .42088 Mtetra
.632 .733 .921 r
.2382 .42088 .2456 .42785 .25656 .42491 .24919 .41794 Mtetra
.586 .72 .936 r
.24919 .41794 .25656 .42491 .2675 .42296 .26014 .41603 Mtetra
.477 .68 .955 r
.26014 .41603 .2675 .42296 .27835 .42285 .271 .41602 Mtetra
.201 .543 .928 r
.271 .41602 .27835 .42285 .28905 .4258 .28169 .4192 Mtetra
0 .163 .644 r
.28169 .4192 .28905 .4258 .29953 .4333 .29215 .42707 Mtetra
.743 .242 0 r
.29215 .42707 .29953 .4333 .30975 .44667 .30232 .44101 Mtetra
.869 .424 .079 r
.30232 .44101 .30975 .44667 .31973 .46646 .31223 .46156 Mtetra
.901 .491 .193 r
.31223 .46156 .31973 .46646 .3296 .49168 .32201 .48767 Mtetra
.905 .505 .231 r
.32201 .48767 .3296 .49168 .3396 .51924 .33192 .51615 Mtetra
.889 .475 .208 r
.33192 .51615 .3396 .51924 .35001 .54413 .34227 .54184 Mtetra
.821 .347 .07 r
.34227 .54184 .35001 .54413 .36108 .56056 .35331 .55883 Mtetra
.257 0 0 r
.35331 .55883 .36108 .56056 .37294 .56388 .36519 .56245 Mtetra
.848 .935 .882 r
.36519 .56245 .37294 .56388 .38551 .55246 .37782 .55113 Mtetra
.943 .858 .727 r
.37782 .55113 .38551 .55246 .39856 .52834 .39097 .52704 Mtetra
.956 .827 .675 r
.39097 .52704 .39856 .52834 .41179 .49631 .40432 .49501 Mtetra
.96 .82 .661 r
.40432 .49501 .41179 .49631 .42493 .46197 .4176 .46062 Mtetra
.959 .827 .669 r
.4176 .46062 .42493 .46197 .43785 .42995 .43064 .42842 Mtetra
.954 .844 .696 r
.43064 .42842 .43785 .42995 .4505 .40302 .4434 .40109 Mtetra
.939 .867 .74 r
.4434 .40109 .4505 .40302 .46292 .38205 .45593 .37954 Mtetra
.907 .887 .8 r
.45593 .37954 .46292 .38205 .47518 .36663 .46827 .36347 Mtetra
.853 .897 .867 r
.46827 .36347 .47518 .36663 .48735 .35573 .48051 .35205 Mtetra
.771 .889 .929 r
.48051 .35205 .48735 .35573 .49949 .34832 .49272 .34439 Mtetra
.658 .864 .978 r
.49272 .34439 .49949 .34832 .51165 .34363 .50493 .33981 Mtetra
.485 .807 1 r
.50493 .33981 .51165 .34363 .52387 .34136 .51719 .33802 Mtetra
.188 .66 .935 r
.51719 .33802 .52387 .34136 .53616 .34172 .52952 .33915 Mtetra
0 .344 .671 r
.52952 .33915 .53616 .34172 .54856 .34536 .54198 .34381 Mtetra
.587 .012 0 r
.54198 .34381 .54856 .34536 .56113 .35318 .5546 .35293 Mtetra
.752 .239 0 r
.5546 .35293 .56113 .35318 .57393 .36596 .56745 .36741 Mtetra
.817 .354 .122 r
.56745 .36741 .57393 .36596 .58702 .38376 .58061 .38747 Mtetra
.835 .403 .207 r
.58061 .38747 .58702 .38376 .60044 .40532 .59412 .41192 Mtetra
.824 .408 .254 r
.59412 .41192 .60044 .40532 .61414 .42769 .60796 .43758 Mtetra
.78 .371 .275 r
.60796 .43758 .61414 .42769 .62801 .44649 .62199 .45955 Mtetra
.679 .272 .268 r
.62199 .45955 .62801 .44649 .64183 .45694 .636 .4723 Mtetra
.452 .061 .207 r
.636 .4723 .64183 .45694 .65537 .45551 .6497 .47157 Mtetra
.001 0 .042 r
.6497 .47157 .65537 .45551 .66843 .44132 .66287 .45615 Mtetra
0 0 0 r
.66287 .45615 .66843 .44132 .68097 .41652 .67545 .42844 Mtetra
.812 .83 .357 r
.67545 .42844 .68097 .41652 .69307 .38547 .68753 .39343 Mtetra
.932 .882 .467 r
.68753 .39343 .69307 .38547 .70493 .35309 .69933 .35683 Mtetra
.977 .901 .558 r
.69933 .35683 .70493 .35309 .71678 .32336 .71109 .32329 Mtetra
.982 .907 .648 r
.71109 .32329 .71678 .32336 .72879 .2986 .72303 .29548 Mtetra
.953 .898 .734 r
.72303 .29548 .72879 .2986 .74109 .27942 .73527 .27411 Mtetra
.895 .872 .807 r
.73527 .27411 .74109 .27942 .75368 .26524 .74784 .25849 Mtetra
.824 .835 .856 r
.74784 .25849 .75368 .26524 .76656 .25489 .76072 .24727 Mtetra
.761 .799 .884 r
.76072 .24727 .76656 .25489 .77966 .24712 .77383 .23901 Mtetra
.715 .772 .897 r
.77383 .23901 .77966 .24712 .79294 .24091 .78714 .23253 Mtetra
.688 .756 .903 r
.78714 .23253 .79294 .24091 .80634 .23554 .80058 .22702 Mtetra
.674 .748 .906 r
.80058 .22702 .80634 .23554 .81984 .23058 .81412 .22198 Mtetra
.668 .744 .907 r
.81412 .22198 .81984 .23058 .83342 .22579 .82774 .21714 Mtetra
.659 .74 .91 r
.20876 .42096 .21627 .42795 .22722 .42431 .21974 .41729 Mtetra
.651 .738 .913 r
.21974 .41729 .22722 .42431 .2382 .42088 .23075 .41382 Mtetra
.632 .733 .92 r
.23075 .41382 .2382 .42088 .24919 .41794 .24176 .41083 Mtetra
.589 .718 .933 r
.24176 .41083 .24919 .41794 .26014 .41603 .25274 .40884 Mtetra
.488 .678 .95 r
.25274 .40884 .26014 .41603 .271 .41602 .26363 .40872 Mtetra
.244 .553 .931 r
.26363 .40872 .271 .41602 .28169 .4192 .27434 .41169 Mtetra
0 .225 .719 r
.27434 .41169 .28169 .4192 .29215 .42707 .28482 .41926 Mtetra
.664 .174 0 r
.28482 .41926 .29215 .42707 .30232 .44101 .295 .43273 Mtetra
.836 .387 0 r
.295 .43273 .30232 .44101 .31223 .46156 .30492 .45266 Mtetra
.889 .472 .072 r
.30492 .45266 .31223 .46156 .32201 .48767 .3147 .47804 Mtetra
.898 .49 .087 r
.3147 .47804 .32201 .48767 .33192 .51615 .3246 .50581 Mtetra
.861 .441 0 r
.3246 .50581 .33192 .51615 .34227 .54184 .33491 .53107 Mtetra
.63 .194 0 r
.33491 .53107 .34227 .54184 .35331 .55883 .34592 .54822 Mtetra
.269 .482 .881 r
.34592 .54822 .35331 .55883 .36519 .56245 .35775 .55286 Mtetra
.761 .726 .82 r
.35775 .55286 .36519 .56245 .37782 .55113 .37034 .54346 Mtetra
.879 .766 .733 r
.37034 .54346 .37782 .55113 .39097 .52704 .38346 .52192 Mtetra
.925 .788 .69 r
.38346 .52192 .39097 .52704 .40432 .49501 .39681 .4926 Mtetra
.951 .815 .674 r
.39681 .4926 .40432 .49501 .4176 .46062 .41013 .4605 Mtetra
.966 .848 .675 r
.41013 .4605 .4176 .46062 .43064 .42842 .42325 .42973 Mtetra
.97 .888 .691 r
.42325 .42973 .43064 .42842 .4434 .40109 .43612 .40282 Mtetra
.958 .928 .725 r
.43612 .40282 .4434 .40109 .45593 .37954 .44876 .38084 Mtetra
.924 .963 .78 r
.44876 .38084 .45593 .37954 .46827 .36347 .46122 .3639 Mtetra
.858 .984 .851 r
.46122 .3639 .46827 .36347 .48051 .35205 .47356 .35162 Mtetra
.74 .976 .922 r
.47356 .35162 .48051 .35205 .49272 .34439 .48584 .34353 Mtetra
.53 .908 .949 r
.48584 .34353 .49272 .34439 .50493 .33981 .49811 .33914 Mtetra
.18 .711 .84 r
.49811 .33914 .50493 .33981 .51719 .33802 .51042 .33811 Mtetra
.233 0 0 r
.51042 .33811 .51719 .33802 .52952 .33915 .52281 .34037 Mtetra
.526 0 0 r
.52281 .34037 .52952 .33915 .54198 .34381 .53532 .34627 Mtetra
.683 .167 .001 r
.53532 .34627 .54198 .34381 .5546 .35293 .548 .35657 Mtetra
.765 .297 .132 r
.548 .35657 .5546 .35293 .56745 .36741 .56091 .37216 Mtetra
.809 .373 .207 r
.56091 .37216 .56745 .36741 .58061 .38747 .57413 .39335 Mtetra
.829 .411 .248 r
.57413 .39335 .58061 .38747 .59412 .41192 .58771 .41906 Mtetra
.827 .416 .265 r
.58771 .41906 .59412 .41192 .60796 .43758 .60162 .44614 Mtetra
.796 .38 .26 r
.60162 .44614 .60796 .43758 .62199 .45955 .61575 .46943 Mtetra
.7 .267 .218 r
.61575 .46943 .62199 .45955 .636 .4723 .62986 .48296 Mtetra
.397 0 .075 r
.62986 .48296 .636 .4723 .6497 .47157 .64367 .48203 Mtetra
0 0 0 r
.64367 .48203 .6497 .47157 .66287 .45615 .65694 .46522 Mtetra
.852 .886 .455 r
.65694 .46522 .66287 .45615 .67545 .42844 .66957 .43504 Mtetra
.965 .889 .508 r
.66957 .43504 .67545 .42844 .68753 .39343 .68167 .39696 Mtetra
.992 .875 .545 r
.68167 .39696 .68753 .39343 .69933 .35683 .69345 .3572 Mtetra
.994 .869 .592 r
.69345 .3572 .69933 .35683 .71109 .32329 .70519 .32086 Mtetra
.98 .867 .652 r
.70519 .32086 .71109 .32329 .72303 .29548 .71711 .29083 Mtetra
.948 .863 .721 r
.71711 .29083 .72303 .29548 .73527 .27411 .72934 .26786 Mtetra
.895 .848 .789 r
.72934 .26786 .73527 .27411 .74784 .25849 .74191 .25119 Mtetra
.829 .823 .843 r
.74191 .25119 .74784 .25849 .76072 .24727 .7548 .23933 Mtetra
.766 .794 .876 r
.7548 .23933 .76072 .24727 .77383 .23901 .76794 .23071 Mtetra
.719 .77 .893 r
.76794 .23071 .77383 .23901 .78714 .23253 .78128 .22404 Mtetra
.69 .755 .902 r
.78128 .22404 .78714 .23253 .80058 .22702 .79476 .21841 Mtetra
.675 .747 .905 r
.79476 .21841 .80058 .22702 .81412 .22198 .80835 .2133 Mtetra
.668 .744 .907 r
.80835 .2133 .81412 .22198 .82774 .21714 .82202 .2084 Mtetra
.659 .74 .91 r
.2012 .41391 .20876 .42096 .21974 .41729 .2122 .41019 Mtetra
.652 .738 .912 r
.2122 .41019 .21974 .41729 .23075 .41382 .22324 .40666 Mtetra
.636 .732 .918 r
.22324 .40666 .23075 .41382 .24176 .41083 .23428 .40356 Mtetra
.598 .718 .929 r
.23428 .40356 .24176 .41083 .25274 .40884 .2453 .40138 Mtetra
.512 .681 .942 r
.2453 .40138 .25274 .40884 .26363 .40872 .25623 .40089 Mtetra
.323 .581 .935 r
.25623 .40089 .26363 .40872 .27434 .41169 .26701 .40322 Mtetra
0 .335 .815 r
.26701 .40322 .27434 .41169 .28482 .41926 .27756 .40973 Mtetra
0 0 .525 r
.27756 .40973 .28482 .41926 .295 .43273 .28783 .42163 Mtetra
.692 .264 0 r
.28783 .42163 .295 .43273 .30492 .45266 .29785 .43943 Mtetra
.763 .367 0 r
.29785 .43943 .30492 .45266 .3147 .47804 .30774 .4623 Mtetra
.727 .365 0 r
.30774 .4623 .3147 .47804 .3246 .50581 .31772 .4876 Mtetra
0 0 .366 r
.31772 .4876 .3246 .50581 .33491 .53107 .32806 .51109 Mtetra
0 .075 .619 r
.32806 .51109 .33491 .53107 .34592 .54822 .33902 .52797 Mtetra
.378 .389 .746 r
.33902 .52797 .34592 .54822 .35775 .55286 .35072 .53441 Mtetra
.648 .567 .749 r
.35072 .53441 .35775 .55286 .37034 .54346 .36313 .52894 Mtetra
.789 .668 .73 r
.36313 .52894 .37034 .54346 .38346 .52192 .37605 .51284 Mtetra
.876 .746 .715 r
.37605 .51284 .38346 .52192 .39681 .4926 .38925 .48936 Mtetra
.937 .821 .704 r
.38925 .48936 .39681 .4926 .41013 .4605 .40249 .46229 Mtetra
.971 .891 .69 r
.40249 .46229 .41013 .4605 .42325 .42973 .41563 .43488 Mtetra
.963 .942 .666 r
.41563 .43488 .42325 .42973 .43612 .40282 .42859 .40936 Mtetra
.913 .963 .644 r
.42859 .40936 .43612 .40282 .44876 .38084 .44137 .38712 Mtetra
.836 .967 .647 r
.44137 .38712 .44876 .38084 .46122 .3639 .45397 .36899 Mtetra
.725 .958 .678 r
.45397 .36899 .46122 .3639 .47356 .35162 .46643 .35546 Mtetra
.516 .889 .69 r
.46643 .35546 .47356 .35162 .48584 .34353 .47881 .34672 Mtetra
0 0 0 r
.47881 .34672 .48584 .34353 .49811 .33914 .49116 .34261 Mtetra
.257 0 0 r
.49116 .34261 .49811 .33914 .51042 .33811 .50353 .34268 Mtetra
.497 0 0 r
.50353 .34268 .51042 .33811 .52281 .34037 .51599 .34645 Mtetra
.617 .135 .086 r
.51599 .34645 .52281 .34037 .53532 .34627 .52857 .3537 Mtetra
.686 .236 .176 r
.52857 .3537 .53532 .34627 .548 .35657 .54132 .36471 Mtetra
.738 .308 .227 r
.54132 .36471 .548 .35657 .56091 .37216 .5543 .38011 Mtetra
.781 .361 .251 r
.5543 .38011 .56091 .37216 .57413 .39335 .56755 .40028 Mtetra
.813 .394 .251 r
.56755 .40028 .57413 .39335 .58771 .41906 .58114 .42439 Mtetra
.827 .4 .226 r
.58114 .42439 .58771 .41906 .60162 .44614 .59505 .44964 Mtetra
.81 .355 .155 r
.59505 .44964 .60162 .44614 .61575 .46943 .60916 .47115 Mtetra
.685 .154 0 r
.60916 .47115 .61575 .46943 .62986 .48296 .62328 .4831 Mtetra
.202 .73 .796 r
.62328 .4831 .62986 .48296 .64367 .48203 .63712 .48078 Mtetra
.926 .949 .787 r
.63712 .48078 .64367 .48203 .65694 .46522 .65043 .46269 Mtetra
.976 .859 .659 r
.65043 .46269 .65694 .46522 .66957 .43504 .66314 .4313 Mtetra
.979 .821 .615 r
.66314 .4313 .66957 .43504 .68167 .39696 .67531 .39207 Mtetra
.976 .806 .608 r
.67531 .39207 .68167 .39696 .69345 .3572 .68717 .35128 Mtetra
.968 .804 .625 r
.68717 .35128 .69345 .3572 .70519 .32086 .69898 .31408 Mtetra
.952 .807 .663 r
.69898 .31408 .70519 .32086 .71711 .29083 .71096 .28338 Mtetra
.924 .812 .716 r
.71096 .28338 .71711 .29083 .72934 .26786 .72324 .25993 Mtetra
.88 .81 .776 r
.72324 .25993 .72934 .26786 .74191 .25119 .73586 .24294 Mtetra
.822 .799 .83 r
.73586 .24294 .74191 .25119 .7548 .23933 .74879 .23088 Mtetra
.764 .782 .868 r
.74879 .23088 .7548 .23933 .76794 .23071 .76199 .22213 Mtetra
.719 .765 .889 r
.76199 .22213 .76794 .23071 .78128 .22404 .77537 .21538 Mtetra
.69 .753 .9 r
.77537 .21538 .78128 .22404 .79476 .21841 .7889 .20969 Mtetra
.675 .746 .904 r
.7889 .20969 .79476 .21841 .80835 .2133 .80253 .20453 Mtetra
.668 .743 .907 r
.80253 .20453 .80835 .2133 .82202 .2084 .81624 .19959 Mtetra
.66 .74 .909 r
.19357 .4068 .2012 .41391 .2122 .41019 .20461 .40303 Mtetra
.654 .738 .911 r
.20461 .40303 .2122 .41019 .22324 .40666 .21567 .39942 Mtetra
.64 .733 .916 r
.21567 .39942 .22324 .40666 .23428 .40356 .22675 .39617 Mtetra
.61 .72 .923 r
.22675 .39617 .23428 .40356 .2453 .40138 .23782 .39369 Mtetra
.544 .689 .934 r
.23782 .39369 .2453 .40138 .25623 .40089 .24881 .39264 Mtetra
.41 .613 .933 r
.24881 .39264 .25623 .40089 .26701 .40322 .25968 .39397 Mtetra
.165 .448 .878 r
.25968 .39397 .26701 .40322 .27756 .40973 .27035 .39883 Mtetra
0 .191 .722 r
.27035 .39883 .27756 .40973 .28783 .42163 .28079 .40828 Mtetra
0 0 .545 r
.28079 .40828 .28783 .42163 .29785 .43943 .291 .42281 Mtetra
0 0 .458 r
.291 .42281 .29785 .43943 .30774 .4623 .30108 .44181 Mtetra
0 0 .477 r
.30108 .44181 .30774 .4623 .31772 .4876 .31122 .46332 Mtetra
0 .006 .558 r
.31122 .46332 .31772 .4876 .32806 .51109 .32163 .4841 Mtetra
.138 .174 .637 r
.32163 .4841 .32806 .51109 .33902 .52797 .33252 .50052 Mtetra
.369 .33 .684 r
.33252 .50052 .33902 .52797 .35072 .53441 .34402 .50958 Mtetra
.542 .459 .711 r
.34402 .50958 .35072 .53441 .36313 .52894 .3561 .50988 Mtetra
.681 .58 .735 r
.3561 .50988 .36313 .52894 .37605 .51284 .36867 .5018 Mtetra
.809 .715 .762 r
.36867 .5018 .37605 .51284 .38925 .48936 .38156 .48698 Mtetra
.922 .869 .768 r
.38156 .48698 .38925 .48936 .40249 .46229 .39461 .46742 Mtetra
.941 .963 .69 r
.39461 .46742 .40249 .46229 .41563 .43488 .40771 .44507 Mtetra
.824 .923 .536 r
.40771 .44507 .41563 .43488 .42859 .40936 .42075 .42171 Mtetra
.689 .843 .42 r
.42075 .42171 .42859 .40936 .44137 .38712 .43369 .39919 Mtetra
0 0 0 r
.43369 .39919 .44137 .38712 .45397 .36899 .44647 .37942 Mtetra
.44647 .37942 .45397 .36899 .46643 .35546 .45909 .36415 Mtetra
.45909 .36415 .46643 .35546 .47881 .34672 .47159 .35456 Mtetra
.192 0 0 r
.47159 .35456 .47881 .34672 .49116 .34261 .48403 .35089 Mtetra
.46 0 .051 r
.48403 .35089 .49116 .34261 .50353 .34268 .49648 .35252 Mtetra
.583 .143 .17 r
.49648 .35252 .50353 .34268 .51599 .34645 .50902 .35824 Mtetra
.634 .219 .238 r
.50902 .35824 .51599 .34645 .52857 .3537 .52169 .36692 Mtetra
.662 .26 .273 r
.52169 .36692 .52857 .3537 .54132 .36471 .53454 .37797 Mtetra
.691 .291 .285 r
.53454 .37797 .54132 .36471 .5543 .38011 .54758 .39154 Mtetra
.728 .319 .273 r
.54758 .39154 .5543 .38011 .56755 .40028 .56086 .40798 Mtetra
.77 .34 .229 r
.56086 .40798 .56755 .40028 .58114 .42439 .57442 .42696 Mtetra
.798 .329 .118 r
.57442 .42696 .58114 .42439 .59505 .44964 .58824 .44645 Mtetra
.714 .186 0 r
.58824 .44645 .59505 .44964 .60916 .47115 .60224 .46252 Mtetra
.017 .382 .844 r
.60224 .46252 .60916 .47115 .62328 .4831 .61625 .47015 Mtetra
.656 .652 .834 r
.61625 .47015 .62328 .4831 .63712 .48078 .63002 .46513 Mtetra
.813 .683 .721 r
.63002 .46513 .63712 .48078 .65043 .46269 .64334 .44605 Mtetra
.869 .693 .662 r
.64334 .44605 .65043 .46269 .66314 .4313 .65612 .41505 Mtetra
.895 .703 .635 r
.65612 .41505 .66314 .4313 .67531 .39207 .66843 .37705 Mtetra
.907 .714 .629 r
.66843 .37705 .67531 .39207 .68717 .35128 .68046 .33782 Mtetra
.911 .727 .641 r
.68046 .33782 .68717 .35128 .69898 .31408 .69243 .30209 Mtetra
.905 .742 .669 r
.69243 .30209 .69898 .31408 .71096 .28338 .70456 .2726 Mtetra
.887 .758 .714 r
.70456 .2726 .71096 .28338 .72324 .25993 .71696 .25001 Mtetra
.853 .769 .769 r
.71696 .25001 .72324 .25993 .73586 .24294 .72969 .23357 Mtetra
.806 .772 .821 r
.72969 .23357 .73586 .24294 .74879 .23088 .7427 .22182 Mtetra
.756 .766 .861 r
.7427 .22182 .74879 .23088 .76199 .22213 .75596 .21323 Mtetra
.715 .757 .885 r
.75596 .21323 .76199 .22213 .77537 .21538 .7694 .20653 Mtetra
.689 .749 .898 r
.7694 .20653 .77537 .21538 .7889 .20969 .78297 .20085 Mtetra
.674 .745 .904 r
.78297 .20085 .7889 .20969 .80253 .20453 .79665 .19567 Mtetra
.668 .743 .906 r
.79665 .19567 .80253 .20453 .81624 .19959 .81042 .19069 Mtetra
.661 .74 .909 r
.18589 .39963 .19357 .4068 .20461 .40303 .19695 .39581 Mtetra
.656 .738 .91 r
.19695 .39581 .20461 .40303 .21567 .39942 .20805 .3921 Mtetra
.646 .734 .913 r
.20805 .3921 .21567 .39942 .22675 .39617 .21917 .38868 Mtetra
.623 .723 .918 r
.21917 .38868 .22675 .39617 .23782 .39369 .23028 .38585 Mtetra
.576 .698 .925 r
.23028 .38585 .23782 .39369 .24881 .39264 .24136 .38414 Mtetra
.487 .643 .926 r
.24136 .38414 .24881 .39264 .25968 .39397 .25233 .38429 Mtetra
.336 .535 .901 r
.25233 .38429 .25968 .39397 .27035 .39883 .26316 .38723 Mtetra
.138 .368 .825 r
.26316 .38723 .27035 .39883 .28079 .40828 .2738 .3938 Mtetra
0 .198 .718 r
.2738 .3938 .28079 .40828 .291 .42281 .28425 .4045 Mtetra
0 .098 .639 r
.28425 .4045 .291 .42281 .30108 .44181 .29458 .41905 Mtetra
0 .084 .61 r
.29458 .41905 .30108 .44181 .31122 .46332 .30492 .43623 Mtetra
.078 .129 .614 r
.30492 .43623 .31122 .46332 .32163 .4841 .31542 .45403 Mtetra
.2 .198 .632 r
.31542 .45403 .32163 .4841 .33252 .50052 .32624 .47012 Mtetra
.31 .274 .655 r
.32624 .47012 .33252 .50052 .34402 .50958 .33746 .48246 Mtetra
.406 .357 .691 r
.33746 .48246 .34402 .50958 .3561 .50988 .34913 .48976 Mtetra
.507 .472 .753 r
.34913 .48976 .3561 .50988 .36867 .5018 .36122 .49138 Mtetra
.657 .683 .863 r
.36122 .49138 .36867 .5018 .38156 .48698 .37367 .48704 Mtetra
.811 .98 .893 r
.37367 .48704 .38156 .48698 .39461 .46742 .38644 .4766 Mtetra
.624 .866 .51 r
.38644 .4766 .39461 .46742 .40771 .44507 .39944 .46036 Mtetra
0 0 0 r
.39944 .46036 .40771 .44507 .42075 .42171 .41257 .43952 Mtetra
.41257 .43952 .42075 .42171 .43369 .39919 .42569 .41651 Mtetra
.42569 .41651 .43369 .39919 .44647 .37942 .43869 .39463 Mtetra
.43869 .39463 .44647 .37942 .45909 .36415 .45152 .37722 Mtetra
.003 0 0 r
.45152 .37722 .45909 .36415 .47159 .35456 .46417 .36665 Mtetra
.337 0 .084 r
.46417 .36665 .47159 .35456 .48403 .35089 .47671 .36369 Mtetra
.54 .126 .205 r
.47671 .36369 .48403 .35089 .49648 .35252 .48924 .36738 Mtetra
.618 .225 .275 r
.48924 .36738 .49648 .35252 .50902 .35824 .50187 .37558 Mtetra
.638 .26 .311 r
.50187 .37558 .50902 .35824 .52169 .36692 .51465 .38582 Mtetra
.635 .264 .323 r
.51465 .38582 .52169 .36692 .53454 .37797 .5276 .3963 Mtetra
.632 .256 .314 r
.5276 .3963 .53454 .37797 .54758 .39154 .54074 .40643 Mtetra
.64 .243 .275 r
.54074 .40643 .54758 .39154 .56086 .40798 .55405 .41655 Mtetra
.664 .212 .169 r
.55405 .41655 .56086 .40798 .57442 .42696 .56756 .42705 Mtetra
.628 .067 0 r
.56756 .42705 .57442 .42696 .58824 .44645 .58124 .43719 Mtetra
.064 .397 .854 r
.58124 .43719 .58824 .44645 .60224 .46252 .59505 .44451 Mtetra
.52 .511 .787 r
.59505 .44451 .60224 .46252 .61625 .47015 .60887 .44542 Mtetra
.662 .541 .706 r
.60887 .44542 .61625 .47015 .63002 .46513 .6225 .4366 Mtetra
.737 .568 .664 r
.6225 .4366 .63002 .46513 .64334 .44605 .63579 .4168 Mtetra
.785 .594 .641 r
.63579 .4168 .64334 .44605 .65612 .41505 .64865 .38762 Mtetra
.818 .617 .631 r
.64865 .38762 .65612 .41505 .66843 .37705 .66114 .35298 Mtetra
.839 .64 .633 r
.66114 .35298 .66843 .37705 .68046 .33782 .67339 .3176 Mtetra
.852 .663 .646 r
.67339 .3176 .68046 .33782 .69243 .30209 .6856 .28544 Mtetra
.854 .687 .674 r
.6856 .28544 .69243 .30209 .70456 .2726 .69795 .25881 Mtetra
.845 .711 .715 r
.69795 .25881 .70456 .2726 .71696 .25001 .71054 .23828 Mtetra
.821 .732 .767 r
.71054 .23828 .71696 .25001 .72969 .23357 .7234 .22318 Mtetra
.784 .746 .818 r
.7234 .22318 .72969 .23357 .7427 .22182 .73652 .21221 Mtetra
.743 .75 .858 r
.73652 .21221 .7427 .22182 .75596 .21323 .74986 .20402 Mtetra
.708 .749 .883 r
.74986 .20402 .75596 .21323 .7694 .20653 .76336 .19751 Mtetra
.685 .746 .897 r
.76336 .19751 .7694 .20653 .78297 .20085 .77699 .19189 Mtetra
.673 .743 .903 r
.77699 .19189 .78297 .20085 .79665 .19567 .79072 .18671 Mtetra
.667 .742 .906 r
.79072 .18671 .79665 .19567 .81042 .19069 .80454 .18171 Mtetra
.662 .74 .909 r
.17814 .3924 .18589 .39963 .19695 .39581 .18923 .38853 Mtetra
.658 .739 .909 r
.18923 .38853 .19695 .39581 .20805 .3921 .20036 .38473 Mtetra
.651 .735 .911 r
.20036 .38473 .20805 .3921 .21917 .38868 .21152 .38114 Mtetra
.635 .727 .914 r
.21152 .38114 .21917 .38868 .23028 .38585 .22269 .37796 Mtetra
.603 .708 .918 r
.22269 .37796 .23028 .38585 .24136 .38414 .23384 .3756 Mtetra
.546 .669 .918 r
.23384 .3756 .24136 .38414 .25233 .38429 .24493 .37458 Mtetra
.455 .597 .904 r
.24493 .37458 .25233 .38429 .26316 .38723 .25592 .37561 Mtetra
.334 .487 .862 r
.25592 .37561 .26316 .38723 .2738 .3938 .26677 .37936 Mtetra
.219 .36 .794 r
.26677 .37936 .2738 .3938 .28425 .4045 .27748 .38632 Mtetra
.152 .26 .722 r
.27748 .38632 .28425 .4045 .29458 .41905 .28807 .39657 Mtetra
.14 .206 .671 r
.28807 .39657 .29458 .41905 .30492 .43623 .29862 .40965 Mtetra
.16 .188 .642 r
.29862 .40965 .30492 .43623 .31542 .45403 .30921 .42473 Mtetra
.183 .19 .631 r
.30921 .42473 .31542 .45403 .32624 .47012 .31993 .44075 Mtetra
.192 .197 .635 r
.31993 .44075 .32624 .47012 .33746 .48246 .33086 .45663 Mtetra
.175 .209 .657 r
.33086 .45663 .33746 .48246 .34913 .48976 .34206 .47119 Mtetra
.118 .243 .718 r
.34206 .47119 .34913 .48976 .36122 .49138 .35361 .48281 Mtetra
0 .376 .839 r
.35361 .48281 .36122 .49138 .37367 .48704 .36557 .48931 Mtetra
.079 0 0 r
.36557 .48931 .37367 .48704 .38644 .4766 .37801 .48835 Mtetra
0 0 0 r
.37801 .48835 .38644 .4766 .39944 .46036 .39089 .47843 Mtetra
.39089 .47843 .39944 .46036 .41257 .43952 .40409 .46009 Mtetra
.40409 .46009 .41257 .43952 .42569 .41651 .41743 .43639 Mtetra
.41743 .43639 .42569 .41651 .43869 .39463 .43068 .41217 Mtetra
.43068 .41217 .43869 .39463 .45152 .37722 .44373 .39251 Mtetra
.043 0 0 r
.44373 .39251 .45152 .37722 .46417 .36665 .45654 .3811 Mtetra
.4 0 .159 r
.45654 .3811 .46417 .36665 .47671 .36369 .46918 .3792 Mtetra
.586 .194 .266 r
.46918 .3792 .47671 .36369 .48924 .36738 .48179 .38547 Mtetra
.645 .27 .32 r
.48179 .38547 .48924 .36738 .50187 .37558 .4945 .39659 Mtetra
.644 .282 .342 r
.4945 .39659 .50187 .37558 .51465 .38582 .5074 .40854 Mtetra
.613 .256 .341 r
.5074 .40854 .51465 .38582 .5276 .3963 .52049 .41802 Mtetra
.566 .205 .315 r
.52049 .41802 .5276 .3963 .54074 .40643 .53374 .42354 Mtetra
.506 .119 .241 r
.53374 .42354 .54074 .40643 .55405 .41655 .54711 .42551 Mtetra
.384 0 .005 r
.54711 .42551 .55405 .41655 .56756 .42705 .56058 .42527 Mtetra
.299 .776 .926 r
.56058 .42527 .56756 .42705 .58124 .43719 .57413 .4237 Mtetra
.619 .625 .835 r
.57413 .4237 .58124 .43719 .59505 .44451 .58773 .42026 Mtetra
.646 .534 .712 r
.58773 .42026 .59505 .44451 .60887 .44542 .60132 .41303 Mtetra
.675 .517 .663 r
.60132 .41303 .60887 .44542 .6225 .4366 .61478 .39982 Mtetra
.707 .525 .64 r
.61478 .39982 .6225 .4366 .63579 .4168 .62801 .37953 Mtetra
.738 .544 .63 r
.62801 .37953 .63579 .4168 .64865 .38762 .64094 .35306 Mtetra
.766 .566 .628 r
.64094 .35306 .64865 .38762 .66114 .35298 .65361 .32308 Mtetra
.787 .591 .635 r
.65361 .32308 .66114 .35298 .67339 .3176 .66611 .29299 Mtetra
.802 .618 .652 r
.66611 .29299 .67339 .3176 .6856 .28544 .6786 .26572 Mtetra
.809 .647 .68 r
.6786 .26572 .6856 .28544 .69795 .25881 .6912 .24303 Mtetra
.806 .677 .722 r
.6912 .24303 .69795 .25881 .71054 .23828 .704 .22534 Mtetra
.789 .705 .771 r
.704 .22534 .71054 .23828 .7234 .22318 .71702 .21208 Mtetra
.761 .726 .821 r
.71702 .21208 .7234 .22318 .73652 .21221 .73027 .2022 Mtetra
.728 .738 .859 r
.73027 .2022 .73652 .21221 .74986 .20402 .7437 .19459 Mtetra
.7 .742 .884 r
.7437 .19459 .74986 .20402 .76336 .19751 .75727 .18835 Mtetra
.681 .742 .897 r
.75727 .18835 .76336 .19751 .77699 .19189 .77096 .18283 Mtetra
.671 .742 .903 r
.77096 .18283 .77699 .19189 .79072 .18671 .78474 .17767 Mtetra
.667 .742 .906 r
.78474 .17767 .79072 .18671 .80454 .18171 .7986 .17265 Mtetra
.662 .741 .908 r
.17033 .38512 .17814 .3924 .18923 .38853 .18145 .38119 Mtetra
.66 .74 .909 r
.18145 .38119 .18923 .38853 .20036 .38473 .19262 .37732 Mtetra
.655 .737 .91 r
.19262 .37732 .20036 .38473 .21152 .38114 .20382 .37356 Mtetra
.645 .731 .911 r
.20382 .37356 .21152 .38114 .22269 .37796 .21504 .37009 Mtetra
.625 .717 .913 r
.21504 .37009 .22269 .37796 .23384 .3756 .22626 .36715 Mtetra
.589 .69 .912 r
.22626 .36715 .23384 .3756 .24493 .37458 .23746 .36513 Mtetra
.533 .641 .903 r
.23746 .36513 .24493 .37458 .25592 .37561 .24859 .36451 Mtetra
.456 .566 .877 r
.24859 .36451 .25592 .37561 .26677 .37936 .25964 .36584 Mtetra
.371 .47 .831 r
.25964 .36584 .26677 .37936 .27748 .38632 .27058 .36962 Mtetra
.295 .373 .773 r
.27058 .36962 .27748 .38632 .28807 .39657 .28141 .37621 Mtetra
.234 .29 .716 r
.28141 .37621 .28807 .39657 .29862 .40965 .29215 .38585 Mtetra
.179 .222 .67 r
.29215 .38585 .29862 .40965 .30921 .42473 .30281 .39868 Mtetra
.109 .158 .633 r
.30281 .39868 .30921 .42473 .31993 .44075 .31345 .41472 Mtetra
0 .082 .597 r
.31345 .41472 .31993 .44075 .33086 .45663 .3241 .43371 Mtetra
0 0 .546 r
.3241 .43371 .33086 .45663 .34206 .47119 .33486 .45457 Mtetra
0 0 .446 r
.33486 .45457 .34206 .47119 .35361 .48281 .3459 .47494 Mtetra
.7 .211 0 r
.3459 .47494 .35361 .48281 .36557 .48931 .35739 .49102 Mtetra
.607 .063 0 r
.35739 .49102 .36557 .48931 .37801 .48835 .36949 .49849 Mtetra
.212 0 0 r
.36949 .49849 .37801 .48835 .39089 .47843 .38224 .49422 Mtetra
0 0 0 r
.38224 .49422 .39089 .47843 .40409 .46009 .39552 .47813 Mtetra
.39552 .47813 .40409 .46009 .41743 .43639 .40905 .45384 Mtetra
.40905 .45384 .41743 .43639 .43068 .41217 .42255 .42762 Mtetra
.42255 .42762 .43068 .41217 .44373 .39251 .43581 .40619 Mtetra
.43581 .40619 .44373 .39251 .45654 .3811 .44877 .39441 Mtetra
.43 .014 .147 r
.44877 .39441 .45654 .3811 .46918 .3792 .4615 .39398 Mtetra
.629 .232 .273 r
.4615 .39398 .46918 .3792 .48179 .38547 .47417 .40311 Mtetra
.677 .3 .325 r
.47417 .40311 .48179 .38547 .4945 .39659 .48695 .41733 Mtetra
.66 .294 .342 r
.48695 .41733 .4945 .39659 .5074 .40854 .49995 .43098 Mtetra
.598 .238 .329 r
.49995 .43098 .5074 .40854 .52049 .41802 .51318 .43925 Mtetra
.487 .124 .275 r
.51318 .43925 .52049 .41802 .53374 .42354 .52657 .43975 Mtetra
.269 0 .118 r
.52657 .43975 .53374 .42354 .54711 .42551 .54003 .43299 Mtetra
0 0 0 r
.54003 .43299 .54711 .42551 .56058 .42527 .5535 .42143 Mtetra
.871 .905 .852 r
.5535 .42143 .56058 .42527 .57413 .4237 .56694 .40771 Mtetra
.771 .662 .742 r
.56694 .40771 .57413 .4237 .58773 .42026 .58036 .39326 Mtetra
.713 .559 .679 r
.58036 .39326 .58773 .42026 .60132 .41303 .59374 .37787 Mtetra
.696 .521 .648 r
.59374 .37787 .60132 .41303 .61478 .39982 .60705 .36036 Mtetra
.7 .514 .633 r
.60705 .36036 .61478 .39982 .62801 .37953 .62021 .3398 Mtetra
.715 .523 .629 r
.62021 .3398 .62801 .37953 .64094 .35306 .6332 .31635 Mtetra
.733 .54 .631 r
.6332 .31635 .64094 .35306 .65361 .32308 .64604 .29139 Mtetra
.751 .563 .642 r
.64604 .29139 .65361 .32308 .66611 .29299 .65878 .26697 Mtetra
.765 .591 .662 r
.65878 .26697 .66611 .29299 .6786 .26572 .67154 .24498 Mtetra
.773 .622 .693 r
.67154 .24498 .6786 .26572 .6912 .24303 .68439 .22656 Mtetra
.772 .656 .734 r
.68439 .22656 .6912 .24303 .704 .22534 .6974 .21195 Mtetra
.76 .688 .783 r
.6974 .21195 .704 .22534 .71702 .21208 .71059 .2007 Mtetra
.738 .714 .829 r
.71059 .2007 .71702 .21208 .73027 .2022 .72396 .19201 Mtetra
.712 .729 .864 r
.72396 .19201 .73027 .2022 .7437 .19459 .73748 .18503 Mtetra
.691 .737 .886 r
.73748 .18503 .7437 .19459 .75727 .18835 .75113 .17908 Mtetra
.677 .74 .898 r
.75113 .17908 .75727 .18835 .77096 .18283 .76487 .17368 Mtetra
.669 .741 .904 r
.76487 .17368 .77096 .18283 .78474 .17767 .77871 .16854 Mtetra
.666 .741 .906 r
.77871 .16854 .78474 .17767 .7986 .17265 .79262 .1635 Mtetra
.663 .741 .908 r
.16246 .37778 .17033 .38512 .18145 .38119 .17361 .37381 Mtetra
.661 .74 .908 r
.17361 .37381 .18145 .38119 .19262 .37732 .18481 .36986 Mtetra
.658 .738 .909 r
.18481 .36986 .19262 .37732 .20382 .37356 .19604 .36598 Mtetra
.652 .734 .909 r
.19604 .36598 .20382 .37356 .21504 .37009 .20731 .36227 Mtetra
.64 .725 .91 r
.20731 .36227 .21504 .37009 .22626 .36715 .2186 .35889 Mtetra
.618 .707 .908 r
.2186 .35889 .22626 .36715 .23746 .36513 .22988 .35608 Mtetra
.584 .674 .902 r
.22988 .35608 .23746 .36513 .24859 .36451 .24115 .35419 Mtetra
.533 .623 .887 r
.24115 .35419 .24859 .36451 .25964 .36584 .25236 .35366 Mtetra
.467 .55 .857 r
.25236 .35366 .25964 .36584 .27058 .36962 .26349 .35498 Mtetra
.387 .461 .815 r
.26349 .35498 .27058 .36962 .28141 .37621 .27452 .35875 Mtetra
.291 .361 .763 r
.27452 .35875 .28141 .37621 .29215 .38585 .28542 .36568 Mtetra
.168 .249 .705 r
.28542 .36568 .29215 .38585 .30281 .39868 .29616 .37662 Mtetra
0 .115 .632 r
.29616 .37662 .30281 .39868 .31345 .41472 .30674 .39238 Mtetra
0 0 .526 r
.30674 .39238 .31345 .41472 .3241 .43371 .31718 .41326 Mtetra
0 0 .375 r
.31718 .41326 .3241 .43371 .33486 .45457 .32762 .43832 Mtetra
.714 .353 0 r
.32762 .43832 .33486 .45457 .3459 .47494 .33825 .46471 Mtetra
.805 .367 0 r
.33825 .46471 .3459 .47494 .35739 .49102 .34936 .48756 Mtetra
.731 .203 0 r
.34936 .48756 .35739 .49102 .36949 .49849 .36118 .50116 Mtetra
.191 0 0 r
.36118 .50116 .36949 .49849 .38224 .49422 .37381 .50119 Mtetra
.653 .918 .619 r
.37381 .50119 .38224 .49422 .39552 .47813 .38713 .48707 Mtetra
.88 .95 .597 r
.38713 .48707 .39552 .47813 .40905 .45384 .40081 .46281 Mtetra
.916 .944 .592 r
.40081 .46281 .40905 .45384 .42255 .42762 .4145 .43571 Mtetra
.857 .954 .605 r
.4145 .43571 .42255 .42762 .43581 .40619 .42791 .41361 Mtetra
0 0 0 r
.42791 .41361 .43581 .40619 .44877 .39441 .44097 .40224 Mtetra
.427 0 0 r
.44097 .40224 .44877 .39441 .4615 .39398 .45376 .40355 Mtetra
.684 .251 .215 r
.45376 .40355 .4615 .39398 .47417 .40311 .46646 .41541 Mtetra
.726 .323 .285 r
.46646 .41541 .47417 .40311 .48695 .41733 .47928 .43234 Mtetra
.694 .3 .298 r
.47928 .43234 .48695 .41733 .49995 .43098 .49236 .44735 Mtetra
.589 .193 .261 r
.49236 .44735 .49995 .43098 .51318 .43925 .5057 .45435 Mtetra
.331 0 .12 r
.5057 .45435 .51318 .43925 .52657 .43975 .51923 .45021 Mtetra
0 0 0 r
.51923 .45021 .52657 .43975 .54003 .43299 .5328 .43562 Mtetra
.935 .968 .712 r
.5328 .43562 .54003 .43299 .5535 .42143 .54631 .41407 Mtetra
.915 .804 .722 r
.54631 .41407 .5535 .42143 .56694 .40771 .5597 .3898 Mtetra
.825 .668 .687 r
.5597 .3898 .56694 .40771 .58036 .39326 .57301 .36595 Mtetra
.759 .584 .661 r
.57301 .36595 .58036 .39326 .59374 .37787 .58625 .34371 Mtetra
.721 .539 .644 r
.58625 .34371 .59374 .37787 .60705 .36036 .59943 .32276 Mtetra
.706 .521 .636 r
.59943 .32276 .60705 .36036 .62021 .3398 .61255 .30224 Mtetra
.61255 .30224 .62021 .3398 .6332 .31635 .62559 .28166 Mtetra
.715 .533 .642 r
.62559 .28166 .6332 .31635 .64604 .29139 .63857 .26134 Mtetra
.727 .554 .656 r
.63857 .26134 .64604 .29139 .65878 .26697 .65152 .24214 Mtetra
.738 .581 .679 r
.65152 .24214 .65878 .26697 .67154 .24498 .6645 .22501 Mtetra
.745 .614 .713 r
.6645 .22501 .67154 .24498 .68439 .22656 .67758 .21053 Mtetra
.745 .649 .755 r
.67758 .21053 .68439 .22656 .6974 .21195 .69078 .19878 Mtetra
.735 .683 .8 r
.69078 .19878 .6974 .21195 .71059 .2007 .70412 .1894 Mtetra
.718 .709 .841 r
.70412 .1894 .71059 .2007 .72396 .19201 .7176 .18182 Mtetra
.698 .726 .871 r
.7176 .18182 .72396 .19201 .73748 .18503 .73121 .17543 Mtetra
.683 .735 .89 r
.73121 .17543 .73748 .18503 .75113 .17908 .74493 .16975 Mtetra
.673 .739 .9 r
.74493 .16975 .75113 .17908 .76487 .17368 .75873 .16445 Mtetra
.668 .74 .905 r
.75873 .16445 .76487 .17368 .77871 .16854 .77262 .15933 Mtetra
.665 .741 .907 r
.77262 .15933 .77871 .16854 .79262 .1635 .78658 .15427 Mtetra
.663 .741 .908 r
.15452 .37039 .16246 .37778 .17361 .37381 .1657 .36637 Mtetra
.662 .741 .908 r
.1657 .36637 .17361 .37381 .18481 .36986 .17693 .36236 Mtetra
.661 .739 .908 r
.17693 .36236 .18481 .36986 .19604 .36598 .1882 .35839 Mtetra
.657 .737 .908 r
.1882 .35839 .19604 .36598 .20731 .36227 .19951 .3545 Mtetra
.65 .731 .908 r
.19951 .3545 .20731 .36227 .2186 .35889 .21085 .3508 Mtetra
.637 .719 .907 r
.21085 .3508 .2186 .35889 .22988 .35608 .22221 .34744 Mtetra
.616 .698 .903 r
.22221 .34744 .22988 .35608 .24115 .35419 .23357 .34466 Mtetra
.582 .664 .895 r
.23357 .34466 .24115 .35419 .25236 .35366 .24491 .34281 Mtetra
.53 .611 .878 r
.24491 .34281 .25236 .35366 .26349 .35498 .25619 .34237 Mtetra
.453 .536 .852 r
.25619 .34237 .26349 .35498 .27452 .35875 .26738 .34406 Mtetra
.335 .432 .812 r
.26738 .34406 .27452 .35875 .28542 .36568 .27842 .34885 Mtetra
.157 .287 .747 r
.27842 .34885 .28542 .36568 .29616 .37662 .28925 .358 Mtetra
0 .092 .635 r
.28925 .358 .29616 .37662 .30674 .39238 .29984 .37273 Mtetra
0 0 .47 r
.29984 .37273 .30674 .39238 .31718 .41326 .31021 .39369 Mtetra
0 0 .3 r
.31021 .39369 .31718 .41326 .32762 .43832 .32047 .42007 Mtetra
.711 .373 0 r
.32047 .42007 .32762 .43832 .33825 .46471 .33088 .44883 Mtetra
.708 .34 0 r
.33088 .44883 .33825 .46471 .34936 .48756 .34176 .47468 Mtetra
0 0 .486 r
.34176 .47468 .34936 .48756 .36118 .50116 .35339 .49131 Mtetra
.352 .567 .919 r
.35339 .49131 .36118 .50116 .37381 .50119 .36592 .49389 Mtetra
.821 .799 .831 r
.36592 .49389 .37381 .50119 .38713 .48707 .37922 .48155 Mtetra
.912 .813 .736 r
.37922 .48155 .38713 .48707 .40081 .46281 .39296 .45841 Mtetra
.932 .821 .713 r
.39296 .45841 .40081 .46281 .4145 .43571 .40672 .43209 Mtetra
.924 .854 .755 r
.40672 .43209 .4145 .43571 .42791 .41361 .4202 .41086 Mtetra
.815 .928 .909 r
.4202 .41086 .42791 .41361 .44097 .40224 .4333 .40076 Mtetra
.19 0 0 r
.4333 .40076 .44097 .40224 .45376 .40355 .4461 .40382 Mtetra
.739 .225 0 r
.4461 .40382 .45376 .40355 .46646 .41541 .45879 .41764 Mtetra
.795 .329 .127 r
.45879 .41764 .46646 .41541 .47928 .43234 .47162 .43621 Mtetra
.753 .279 .119 r
.47162 .43621 .47928 .43234 .49236 .44735 .48473 .45178 Mtetra
.538 .006 0 r
.48473 .45178 .49236 .44735 .5057 .45435 .49816 .45747 Mtetra
.44 .86 .715 r
.49816 .45747 .5057 .45435 .51923 .45021 .51179 .44978 Mtetra
.94 .939 .764 r
.51179 .44978 .51923 .45021 .5328 .43562 .52546 .42953 Mtetra
.938 .813 .694 r
.52546 .42953 .5328 .43562 .54631 .41407 .53902 .40097 Mtetra
.893 .727 .668 r
.53902 .40097 .54631 .41407 .5597 .3898 .55242 .36943 Mtetra
.839 .658 .657 r
.55242 .36943 .5597 .3898 .57301 .36595 .56568 .3392 Mtetra
.786 .602 .651 r
.56568 .3392 .57301 .36595 .58625 .34371 .57885 .31248 Mtetra
.745 .562 .647 r
.57885 .31248 .58625 .34371 .59943 .32276 .59197 .28951 Mtetra
.719 .539 .646 r
.59197 .28951 .59943 .32276 .61255 .30224 .60507 .26949 Mtetra
.707 .533 .651 r
.60507 .26949 .61255 .30224 .62559 .28166 .61816 .2515 Mtetra
.707 .541 .661 r
.61816 .2515 .62559 .28166 .63857 .26134 .63126 .23504 Mtetra
.713 .559 .679 r
.63126 .23504 .63857 .26134 .65152 .24214 .64438 .22013 Mtetra
.72 .586 .706 r
.64438 .22013 .65152 .24214 .6645 .22501 .65755 .20696 Mtetra
.724 .619 .741 r
.65755 .20696 .6645 .22501 .67758 .21053 .6708 .19571 Mtetra
.723 .654 .781 r
.6708 .19571 .67758 .21053 .69078 .19878 .68415 .1863 Mtetra
.714 .686 .822 r
.68415 .1863 .69078 .19878 .70412 .1894 .69763 .17844 Mtetra
.701 .711 .856 r
.69763 .17844 .70412 .1894 .7176 .18182 .71121 .17176 Mtetra
.687 .726 .88 r
.71121 .17176 .7176 .18182 .73121 .17543 .7249 .16584 Mtetra
.676 .735 .894 r
.7249 .16584 .73121 .17543 .74493 .16975 .73868 .16039 Mtetra
.67 .739 .902 r
.73868 .16039 .74493 .16975 .75873 .16445 .75254 .15516 Mtetra
.666 .74 .905 r
.75254 .15516 .75873 .16445 .77262 .15933 .76648 .15005 Mtetra
.665 .741 .907 r
.76648 .15005 .77262 .15933 .78658 .15427 .78049 .14496 Mtetra
.663 .741 .908 r
.14652 .36293 .15452 .37039 .1657 .36637 .15773 .35888 Mtetra
.15773 .35888 .1657 .36637 .17693 .36236 .16899 .35482 Mtetra
.662 .74 .908 r
.16899 .35482 .17693 .36236 .1882 .35839 .18029 .35077 Mtetra
.66 .739 .908 r
.18029 .35077 .1882 .35839 .19951 .3545 .19164 .34676 Mtetra
.656 .735 .908 r
.19164 .34676 .19951 .3545 .21085 .3508 .20303 .34285 Mtetra
.649 .728 .907 r
.20303 .34285 .21085 .3508 .22221 .34744 .21445 .33913 Mtetra
.636 .715 .905 r
.21445 .33913 .22221 .34744 .23357 .34466 .22588 .33577 Mtetra
.613 .693 .901 r
.22588 .33577 .23357 .34466 .24491 .34281 .23732 .33304 Mtetra
.573 .657 .894 r
.23732 .33304 .24491 .34281 .25619 .34237 .24872 .33139 Mtetra
.503 .598 .881 r
.24872 .33139 .25619 .34237 .26738 .34406 .26003 .33154 Mtetra
.383 .503 .855 r
.26003 .33154 .26738 .34406 .27842 .34885 .2712 .33453 Mtetra
.184 .348 .795 r
.2712 .33453 .27842 .34885 .28925 .358 .28216 .34173 Mtetra
0 .128 .669 r
.28216 .34173 .28925 .358 .29984 .37273 .29284 .35449 Mtetra
0 0 .496 r
.29284 .35449 .29984 .37273 .31021 .39369 .30326 .37357 Mtetra
0 0 .363 r
.30326 .37357 .31021 .39369 .32047 .42007 .31354 .39826 Mtetra
0 0 .337 r
.31354 .39826 .32047 .42007 .33088 .44883 .32393 .42565 Mtetra
0 0 .446 r
.32393 .42565 .33088 .44883 .34176 .47468 .33476 .45064 Mtetra
.039 .137 .639 r
.33476 .45064 .34176 .47468 .35339 .49131 .34632 .46716 Mtetra
.468 .423 .724 r
.34632 .46716 .35339 .49131 .36592 .49389 .35876 .47054 Mtetra
.688 .562 .707 r
.35876 .47054 .36592 .49389 .37922 .48155 .37198 .4599 Mtetra
.777 .62 .684 r
.37198 .4599 .37922 .48155 .39296 .45841 .38565 .43907 Mtetra
.808 .647 .682 r
.38565 .43907 .39296 .45841 .40672 .43209 .39936 .41529 Mtetra
.798 .66 .711 r
.39936 .41529 .40672 .43209 .4202 .41086 .41281 .39642 Mtetra
.707 .647 .788 r
.41281 .39642 .4202 .41086 .4333 .40076 .42587 .38822 Mtetra
.323 .483 .864 r
.42587 .38822 .4333 .40076 .4461 .40382 .43863 .39258 Mtetra
0 .023 .58 r
.43863 .39258 .4461 .40382 .45879 .41764 .4513 .40708 Mtetra
.598 .157 0 r
.4513 .40708 .45879 .41764 .47162 .43621 .4641 .42568 Mtetra
0 .004 .554 r
.4641 .42568 .47162 .43621 .48473 .45178 .47721 .4406 Mtetra
.292 .504 .891 r
.47721 .4406 .48473 .45178 .49816 .45747 .49065 .44493 Mtetra
.743 .698 .808 r
.49065 .44493 .49816 .45747 .51179 .44978 .50433 .43514 Mtetra
.844 .703 .707 r
.50433 .43514 .51179 .44978 .52546 .42953 .51806 .41214 Mtetra
.863 .686 .661 r
.51806 .41214 .52546 .42953 .53902 .40097 .53168 .38043 Mtetra
.854 .664 .644 r
.53168 .38043 .53902 .40097 .55242 .36943 .54511 .34573 Mtetra
.83 .638 .643 r
.54511 .34573 .55242 .36943 .56568 .3392 .55838 .31286 Mtetra
.797 .609 .647 r
.55838 .31286 .56568 .3392 .57885 .31248 .57153 .28448 Mtetra
.762 .583 .654 r
.57153 .28448 .57885 .31248 .59197 .28951 .58465 .26119 Mtetra
.733 .564 .663 r
.58465 .26119 .59197 .28951 .60507 .26949 .59777 .24227 Mtetra
.714 .557 .674 r
.59777 .24227 .60507 .26949 .61816 .2515 .61092 .22658 Mtetra
.706 .563 .689 r
.61092 .22658 .61816 .2515 .63126 .23504 .62411 .21315 Mtetra
.705 .58 .712 r
.62411 .21315 .63126 .23504 .64438 .22013 .63735 .20145 Mtetra
.707 .606 .741 r
.63735 .20145 .64438 .22013 .65755 .20696 .65067 .19122 Mtetra
.708 .637 .775 r
.65067 .19122 .65755 .20696 .6708 .19571 .66406 .18234 Mtetra
.705 .669 .812 r
.66406 .18234 .6708 .19571 .68415 .1863 .67754 .17464 Mtetra
.697 .696 .845 r
.67754 .17464 .68415 .1863 .69763 .17844 .69111 .16791 Mtetra
.687 .716 .871 r
.69111 .16791 .69763 .17844 .71121 .17176 .70478 .16187 Mtetra
.678 .729 .888 r
.70478 .16187 .71121 .17176 .7249 .16584 .71854 .1563 Mtetra
.671 .736 .899 r
.71854 .1563 .7249 .16584 .73868 .16039 .73238 .15099 Mtetra
.667 .739 .904 r
.73238 .15099 .73868 .16039 .75254 .15516 .74629 .14581 Mtetra
.665 .74 .906 r
.74629 .14581 .75254 .15516 .76648 .15005 .76028 .14069 Mtetra
.664 .741 .907 r
.76028 .14069 .76648 .15005 .78049 .14496 .77434 .13557 Mtetra
.663 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35888 .1497 .35133 Mtetra
.1497 .35133 .15773 .35888 .16899 .35482 .16098 .34723 Mtetra
.16098 .34723 .16899 .35482 .18029 .35077 .17232 .34313 Mtetra
.662 .74 .908 r
.17232 .34313 .18029 .35077 .19164 .34676 .1837 .33903 Mtetra
.66 .738 .908 r
.1837 .33903 .19164 .34676 .20303 .34285 .19512 .33498 Mtetra
.655 .734 .907 r
.19512 .33498 .20303 .34285 .21445 .33913 .20659 .33103 Mtetra
.647 .726 .906 r
.20659 .33103 .21445 .33913 .22588 .33577 .21808 .3273 Mtetra
.632 .713 .905 r
.21808 .3273 .22588 .33577 .23732 .33304 .22959 .32401 Mtetra
.602 .688 .903 r
.22959 .32401 .23732 .33304 .24872 .33139 .24108 .32152 Mtetra
.545 .645 .899 r
.24108 .32152 .24872 .33139 .26003 .33154 .25251 .32048 Mtetra
.441 .568 .886 r
.25251 .32048 .26003 .33154 .2712 .33453 .26381 .32186 Mtetra
.263 .432 .842 r
.26381 .32186 .2712 .33453 .28216 .34173 .27492 .32691 Mtetra
.016 .231 .738 r
.27492 .32691 .28216 .34173 .29284 .35449 .28577 .33687 Mtetra
0 .03 .598 r
.28577 .33687 .29284 .35449 .30326 .37357 .29638 .35246 Mtetra
0 0 .505 r
.29638 .35246 .30326 .37357 .31354 .39826 .30685 .37305 Mtetra
0 0 .507 r
.30685 .37305 .31354 .39826 .32393 .42565 .3174 .39613 Mtetra
0 .062 .575 r
.3174 .39613 .32393 .42565 .33476 .45064 .32833 .41726 Mtetra
.279 .242 .637 r
.32833 .41726 .33476 .45064 .34632 .46716 .33992 .43123 Mtetra
.499 .385 .656 r
.33992 .43123 .34632 .46716 .35876 .47054 .35231 .43406 Mtetra
.629 .473 .652 r
.35231 .43406 .35876 .47054 .37198 .4599 .36539 .42501 Mtetra
.698 .523 .648 r
.36539 .42501 .37198 .4599 .38565 .43907 .37888 .40738 Mtetra
.724 .549 .653 r
.37888 .40738 .38565 .43907 .39936 .41529 .39243 .38737 Mtetra
.71 .552 .672 r
.39243 .38737 .39936 .41529 .41281 .39642 .40575 .3718 Mtetra
.63 .519 .709 r
.40575 .3718 .41281 .39642 .42587 .38822 .41873 .36566 Mtetra
.425 .407 .736 r
.41873 .36566 .42587 .38822 .43863 .39258 .43143 .37054 Mtetra
.135 .223 .692 r
.43143 .37054 .43863 .39258 .4513 .40708 .44406 .38418 Mtetra
.037 .15 .654 r
.44406 .38418 .4513 .40708 .4641 .42568 .45682 .40104 Mtetra
.217 .259 .692 r
.45682 .40104 .4641 .42568 .47721 .4406 .46989 .41404 Mtetra
.486 .423 .711 r
.46989 .41404 .47721 .4406 .49065 .44493 .4833 .41691 Mtetra
.666 .528 .687 r
.4833 .41691 .49065 .44493 .50433 .43514 .49695 .40644 Mtetra
.756 .579 .658 r
.49695 .40644 .50433 .43514 .51806 .41214 .51068 .38354 Mtetra
.797 .603 .64 r
.51068 .38354 .51806 .41214 .53168 .38043 .52432 .35243 Mtetra
.811 .613 .634 r
.52432 .35243 .53168 .38043 .54511 .34573 .53779 .31855 Mtetra
.808 .613 .638 r
.53779 .31855 .54511 .34573 .55838 .31286 .55109 .28656 Mtetra
.793 .607 .65 r
.55109 .28656 .55838 .31286 .57153 .28448 .56428 .2592 Mtetra
.769 .597 .665 r
.56428 .2592 .57153 .28448 .58465 .26119 .57743 .23722 Mtetra
.744 .589 .683 r
.57743 .23722 .58465 .26119 .59777 .24227 .59059 .22001 Mtetra
.723 .587 .703 r
.59059 .22001 .59777 .24227 .61092 .22658 .6038 .2064 Mtetra
.709 .594 .725 r
.6038 .2064 .61092 .22658 .62411 .21315 .61708 .19528 Mtetra
.702 .611 .751 r
.61708 .19528 .62411 .21315 .63735 .20145 .63043 .18584 Mtetra
.699 .635 .781 r
.63043 .18584 .63735 .20145 .65067 .19122 .64384 .17762 Mtetra
.696 .662 .812 r
.64384 .17762 .65067 .19122 .66406 .18234 .65734 .17032 Mtetra
.691 .688 .842 r
.65734 .17032 .66406 .18234 .67754 .17464 .67091 .16376 Mtetra
.684 .709 .866 r
.67091 .16376 .67754 .17464 .69111 .16791 .68457 .15776 Mtetra
.677 .723 .884 r
.68457 .15776 .69111 .16791 .70478 .16187 .69831 .15215 Mtetra
.672 .732 .895 r
.69831 .15215 .70478 .16187 .71854 .1563 .71213 .14679 Mtetra
.668 .737 .902 r
.71213 .14679 .71854 .1563 .73238 .15099 .72602 .14156 Mtetra
.666 .74 .905 r
.72602 .14156 .73238 .15099 .74629 .14581 .73999 .1364 Mtetra
.664 .741 .907 r
.73999 .1364 .74629 .14581 .76028 .14069 .75403 .13125 Mtetra
.75403 .13125 .76028 .14069 .77434 .13557 .76814 .1261 Mtetra
.663 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34723 .15291 .33959 Mtetra
.15291 .33959 .16098 .34723 .17232 .34313 .16427 .33544 Mtetra
.16427 .33544 .17232 .34313 .1837 .33903 .17569 .33128 Mtetra
.662 .74 .908 r
.17569 .33128 .1837 .33903 .19512 .33498 .18715 .32714 Mtetra
.659 .737 .908 r
.18715 .32714 .19512 .33498 .20659 .33103 .19865 .32305 Mtetra
.654 .733 .907 r
.19865 .32305 .20659 .33103 .21808 .3273 .21019 .31909 Mtetra
.643 .725 .907 r
.21019 .31909 .21808 .3273 .22959 .32401 .22176 .31542 Mtetra
.622 .709 .908 r
.22176 .31542 .22959 .32401 .24108 .32152 .23333 .31233 Mtetra
.58 .679 .908 r
.23333 .31233 .24108 .32152 .25251 .32048 .24486 .31034 Mtetra
.502 .622 .902 r
.24486 .31034 .25251 .32048 .26381 .32186 .25629 .31024 Mtetra
.369 .519 .876 r
.25629 .31024 .26381 .32186 .27492 .32691 .26757 .31305 Mtetra
.188 .364 .808 r
.26757 .31305 .27492 .32691 .28577 .33687 .27864 .31978 Mtetra
.031 .204 .709 r
.27864 .31978 .28577 .33687 .29638 .35246 .28952 .331 Mtetra
0 .114 .636 r
.28952 .331 .29638 .35246 .30685 .37305 .30029 .34619 Mtetra
.061 .123 .615 r
.30029 .34619 .30685 .37305 .3174 .39613 .31112 .36336 Mtetra
.22 .202 .624 r
.31112 .36336 .3174 .39613 .32833 .41726 .32228 .37901 Mtetra
.387 .299 .633 r
.32228 .37901 .32833 .41726 .33992 .43123 .33397 .38911 Mtetra
.517 .38 .634 r
.33397 .38911 .33992 .43123 .35231 .43406 .34631 .3906 Mtetra
.603 .439 .632 r
.34631 .3906 .35231 .43406 .36539 .42501 .35923 .38296 Mtetra
.654 .477 .632 r
.35923 .38296 .36539 .42501 .37888 .40738 .3725 .36878 Mtetra
.674 .498 .639 r
.3725 .36878 .37888 .40738 .39243 .38737 .38582 .35297 Mtetra
.659 .498 .654 r
.38582 .35297 .39243 .38737 .40575 .3718 .39896 .34088 Mtetra
.593 .465 .676 r
.39896 .34088 .40575 .3718 .41873 .36566 .41183 .33647 Mtetra
.459 .386 .687 r
.41183 .33647 .41873 .36566 .43143 .37054 .42447 .34095 Mtetra
.315 .288 .669 r
.42447 .34095 .43143 .37054 .44406 .38418 .43706 .35235 Mtetra
.284 .257 .652 r
.43706 .35235 .44406 .38418 .45682 .40104 .44979 .36606 Mtetra
.382 .312 .653 r
.44979 .36606 .45682 .40104 .46989 .41404 .46281 .37616 Mtetra
.519 .396 .653 r
.46281 .37616 .46989 .41404 .4833 .41691 .47614 .37749 Mtetra
.629 .467 .644 r
.47614 .37749 .4833 .41691 .49695 .40644 .48972 .36742 Mtetra
.702 .517 .635 r
.48972 .36742 .49695 .40644 .51068 .38354 .50339 .34675 Mtetra
.747 .55 .629 r
.50339 .34675 .51068 .38354 .52432 .35243 .517 .31903 Mtetra
.771 .573 .631 r
.517 .31903 .52432 .35243 .53779 .31855 .53049 .28891 Mtetra
.781 .589 .64 r
.53049 .28891 .53779 .31855 .55109 .28656 .54382 .26046 Mtetra
.778 .599 .657 r
.54382 .26046 .55109 .28656 .56428 .2592 .55706 .23612 Mtetra
.766 .606 .681 r
.55706 .23612 .56428 .2592 .57743 .23722 .57027 .21665 Mtetra
.747 .611 .708 r
.57027 .21665 .57743 .23722 .59059 .22001 .58349 .20159 Mtetra
.727 .618 .737 r
.58349 .20159 .59059 .22001 .6038 .2064 .59677 .1899 Mtetra
.71 .63 .765 r
.59677 .1899 .6038 .2064 .61708 .19528 .61012 .18051 Mtetra
.699 .646 .793 r
.61012 .18051 .61708 .19528 .63043 .18584 .62355 .17262 Mtetra
.692 .666 .821 r
.62355 .17262 .63043 .18584 .64384 .17762 .63704 .16567 Mtetra
.686 .687 .846 r
.63704 .16567 .64384 .17762 .65734 .17032 .65062 .15935 Mtetra
.681 .706 .867 r
.65062 .15935 .65734 .17032 .67091 .16376 .66427 .15348 Mtetra
.675 .72 .883 r
.66427 .15348 .67091 .16376 .68457 .15776 .67799 .1479 Mtetra
.671 .73 .894 r
.67799 .1479 .68457 .15776 .69831 .15215 .69179 .14253 Mtetra
.668 .735 .901 r
.69179 .14253 .69831 .15215 .71213 .14679 .70567 .13728 Mtetra
.666 .739 .904 r
.70567 .13728 .71213 .14679 .72602 .14156 .71961 .13209 Mtetra
.665 .74 .906 r
.71961 .13209 .72602 .14156 .73999 .1364 .73363 .12691 Mtetra
.664 .741 .907 r
.73363 .12691 .73999 .1364 .75403 .13125 .74772 .12174 Mtetra
.664 .741 .908 r
.74772 .12174 .75403 .13125 .76814 .1261 .76188 .11654 Mtetra
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.663 .741 .908 r
.13343 .33606 .1416 .34373 .15291 .33959 .14477 .33189 Mtetra
.14477 .33189 .15291 .33959 .16427 .33544 .15616 .32769 Mtetra
.15616 .32769 .16427 .33544 .17569 .33128 .16761 .32349 Mtetra
.663 .74 .908 r
.16761 .32349 .17569 .33128 .18715 .32714 .1791 .31928 Mtetra
.661 .739 .908 r
.1791 .31928 .18715 .32714 .19865 .32305 .19064 .3151 Mtetra
.658 .737 .908 r
.19064 .3151 .19865 .32305 .21019 .31909 .20222 .31099 Mtetra
.651 .732 .908 r
.20222 .31099 .21019 .31909 .22176 .31542 .21384 .30706 Mtetra
.637 .722 .909 r
.21384 .30706 .22176 .31542 .23333 .31233 .22547 .30353 Mtetra
.608 .701 .91 r
.22547 .30353 .23333 .31233 .24486 .31034 .23709 .30077 Mtetra
.555 .662 .908 r
.23709 .30077 .24486 .31034 .25629 .31024 .24865 .29937 Mtetra
.467 .59 .892 r
.24865 .29937 .25629 .31024 .26757 .31305 .2601 .30007 Mtetra
.352 .481 .851 r
.2601 .30007 .26757 .31305 .27864 .31978 .27142 .30362 Mtetra
.249 .362 .783 r
.27142 .30362 .27864 .31978 .28952 .331 .2826 .3104 Mtetra
.214 .281 .717 r
.2826 .3104 .28952 .331 .30029 .34619 .2937 .32005 Mtetra
.259 .264 .674 r
.2937 .32005 .30029 .34619 .31112 .36336 .30487 .33109 Mtetra
.352 .294 .652 r
.30487 .33109 .31112 .36336 .32228 .37901 .31629 .34103 Mtetra
.451 .343 .64 r
.31629 .34103 .32228 .37901 .33397 .38911 .32812 .347 Mtetra
.533 .39 .633 r
.32812 .347 .33397 .38911 .34631 .3906 .34044 .3469 Mtetra
.593 .43 .63 r
.34044 .3469 .34631 .3906 .35923 .38296 .3532 .34039 Mtetra
.63 .458 .632 r
.3532 .34039 .35923 .38296 .3725 .36878 .36623 .32938 Mtetra
.644 .475 .639 r
.36623 .32938 .3725 .36878 .38582 .35297 .37932 .31738 Mtetra
.63 .474 .652 r
.37932 .31738 .38582 .35297 .39896 .34088 .39228 .30829 Mtetra
.576 .447 .668 r
.39228 .30829 .39896 .34088 .41183 .33647 .40504 .30498 Mtetra
.483 .39 .674 r
.40504 .30498 .41183 .33647 .42447 .34095 .41765 .30827 Mtetra
.398 .329 .662 r
.41765 .30827 .42447 .34095 .43706 .35235 .43023 .31659 Mtetra
.387 .31 .647 r
.43023 .31659 .43706 .35235 .44979 .36606 .44295 .32637 Mtetra
.448 .341 .64 r
.44295 .32637 .44979 .36606 .46281 .37616 .45591 .33313 Mtetra
.534 .392 .635 r
.45591 .33313 .46281 .37616 .47614 .37749 .46915 .33294 Mtetra
.61 .442 .63 r
.46915 .33294 .47614 .37749 .48972 .36742 .48262 .32386 Mtetra
.669 .484 .627 r
.48262 .32386 .48972 .36742 .50339 .34675 .49619 .30651 Mtetra
.71 .518 .628 r
.49619 .30651 .50339 .34675 .517 .31903 .50975 .28362 Mtetra
.738 .546 .634 r
.50975 .28362 .517 .31903 .53049 .28891 .52321 .25881 Mtetra
.754 .571 .648 r
.52321 .25881 .53049 .28891 .54382 .26046 .53657 .23527 Mtetra
.759 .592 .671 r
.53657 .23527 .54382 .26046 .55706 .23612 .54986 .215 Mtetra
.754 .612 .7 r
.54986 .215 .55706 .23612 .57027 .21665 .56313 .19866 Mtetra
.741 .63 .735 r
.56313 .19866 .57027 .21665 .58349 .20159 .57642 .18592 Mtetra
.724 .646 .771 r
.57642 .18592 .58349 .20159 .59677 .1899 .58977 .17596 Mtetra
.707 .662 .803 r
.58977 .17596 .59677 .1899 .61012 .18051 .60318 .16789 Mtetra
.694 .678 .831 r
.60318 .16789 .61012 .18051 .62355 .17262 .61668 .16101 Mtetra
.684 .694 .853 r
.61668 .16101 .62355 .17262 .63704 .16567 .63024 .15483 Mtetra
.678 .709 .871 r
.63024 .15483 .63704 .16567 .65062 .15935 .64388 .14907 Mtetra
.673 .72 .885 r
.64388 .14907 .65062 .15935 .66427 .15348 .65759 .14357 Mtetra
.67 .729 .894 r
.65759 .14357 .66427 .15348 .67799 .1479 .67137 .13822 Mtetra
.667 .735 .9 r
.67137 .13822 .67799 .1479 .69179 .14253 .68523 .13296 Mtetra
.666 .738 .904 r
.68523 .13296 .69179 .14253 .70567 .13728 .69915 .12775 Mtetra
.665 .74 .906 r
.69915 .12775 .70567 .13728 .71961 .13209 .71315 .12255 Mtetra
.664 .741 .907 r
.71315 .12255 .71961 .13209 .73363 .12691 .72722 .11735 Mtetra
.664 .741 .908 r
.72722 .11735 .73363 .12691 .74772 .12174 .74135 .11214 Mtetra
.74135 .11214 .74772 .12174 .76188 .11654 .75556 .1069 Mtetra
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33189 .13656 .32412 Mtetra
.663 .741 .908 r
.13656 .32412 .14477 .33189 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32349 .15946 .31565 Mtetra
.15946 .31565 .16761 .32349 .1791 .31928 .17098 .31139 Mtetra
.662 .74 .908 r
.17098 .31139 .1791 .31928 .19064 .3151 .18256 .30714 Mtetra
.66 .739 .908 r
.18256 .30714 .19064 .3151 .20222 .31099 .19418 .30293 Mtetra
.656 .736 .908 r
.19418 .30293 .20222 .31099 .21384 .30706 .20584 .29882 Mtetra
.647 .729 .909 r
.20584 .29882 .21384 .30706 .22547 .30353 .21752 .29496 Mtetra
.629 .716 .91 r
.21752 .29496 .22547 .30353 .23709 .30077 .22922 .2916 Mtetra
.595 .689 .908 r
.22922 .2916 .23709 .30077 .24865 .29937 .24089 .28913 Mtetra
.542 .642 .898 r
.24089 .28913 .24865 .29937 .2601 .30007 .25251 .28805 Mtetra
.473 .569 .872 r
.25251 .28805 .2601 .30007 .27142 .30362 .26405 .28885 Mtetra
.407 .481 .824 r
.26405 .28885 .27142 .30362 .2826 .3104 .27551 .29178 Mtetra
.376 .408 .767 r
.27551 .29178 .2826 .3104 .2937 .32005 .28694 .29659 Mtetra
.391 .371 .717 r
.28694 .29659 .2937 .32005 .30487 .33109 .29842 .30229 Mtetra
.439 .369 .682 r
.29842 .30229 .30487 .33109 .31629 .34103 .3101 .30725 Mtetra
.497 .387 .66 r
.3101 .30725 .31629 .34103 .32812 .347 .32207 .30961 Mtetra
.55 .413 .647 r
.32207 .30961 .32812 .347 .34044 .3469 .33439 .30803 Mtetra
.591 .438 .643 r
.33439 .30803 .34044 .3469 .3532 .34039 .34702 .30234 Mtetra
.619 .459 .644 r
.34702 .30234 .3532 .34039 .36623 .32938 .35986 .29381 Mtetra
.629 .473 .652 r
.35986 .29381 .36623 .32938 .37932 .31738 .37274 .2848 Mtetra
.615 .473 .665 r
.37274 .2848 .37932 .31738 .39228 .30829 .38555 .2779 Mtetra
.572 .453 .678 r
.38555 .2779 .39228 .30829 .40504 .30498 .39825 .27501 Mtetra
.506 .411 .682 r
.39825 .27501 .40504 .30498 .41765 .30827 .41085 .27664 Mtetra
.452 .369 .672 r
.41085 .27664 .41765 .30827 .43023 .31659 .42345 .28163 Mtetra
.447 .353 .656 r
.42345 .28163 .43023 .31659 .44295 .32637 .43617 .28744 Mtetra
.488 .369 .644 r
.43617 .28744 .44295 .32637 .45591 .33313 .44909 .29094 Mtetra
.546 .401 .636 r
.44909 .29094 .45591 .33313 .46915 .33294 .46225 .28938 Mtetra
.602 .438 .631 r
.46225 .28938 .46915 .33294 .48262 .32386 .4756 .28145 Mtetra
.649 .472 .631 r
.4756 .28145 .48262 .32386 .49619 .30651 .48906 .26758 Mtetra
.685 .503 .635 r
.48906 .26758 .49619 .30651 .50975 .28362 .50254 .24971 Mtetra
.712 .533 .646 r
.50254 .24971 .50975 .28362 .52321 .25881 .51597 .2304 Mtetra
.73 .562 .664 r
.51597 .2304 .52321 .25881 .53657 .23527 .52934 .21198 Mtetra
.739 .591 .691 r
.52934 .21198 .53657 .23527 .54986 .215 .54267 .19591 Mtetra
.739 .619 .726 r
.54267 .19591 .54986 .215 .56313 .19866 .55599 .18271 Mtetra
.73 .646 .765 r
.55599 .18271 .56313 .19866 .57642 .18592 .56935 .17216 Mtetra
.716 .669 .803 r
.56935 .17216 .57642 .18592 .58977 .17596 .58276 .16368 Mtetra
.7 .688 .835 r
.58276 .16368 .58977 .17596 .60318 .16789 .59623 .1566 Mtetra
.687 .703 .859 r
.59623 .1566 .60318 .16789 .61668 .16101 .60979 .15038 Mtetra
.678 .714 .876 r
.60979 .15038 .61668 .16101 .63024 .15483 .62341 .14465 Mtetra
.672 .723 .888 r
.62341 .14465 .63024 .15483 .64388 .14907 .6371 .13919 Mtetra
.669 .73 .896 r
.6371 .13919 .64388 .14907 .65759 .14357 .65087 .13386 Mtetra
.667 .735 .901 r
.65087 .13386 .65759 .14357 .67137 .13822 .6647 .12861 Mtetra
.665 .738 .904 r
.6647 .12861 .67137 .13822 .68523 .13296 .67861 .12339 Mtetra
.664 .74 .906 r
.67861 .12339 .68523 .13296 .69915 .12775 .69258 .11817 Mtetra
.664 .74 .907 r
.69258 .11817 .69915 .12775 .71315 .12255 .70663 .11295 Mtetra
.664 .741 .907 r
.70663 .11295 .71315 .12255 .72722 .11735 .72074 .10771 Mtetra
.664 .741 .908 r
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74918 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.663 .741 .908 r
.13974 .31203 .14799 .31989 .15946 .31565 .15124 .30774 Mtetra
.15124 .30774 .15946 .31565 .17098 .31139 .1628 .30345 Mtetra
.1628 .30345 .17098 .31139 .18256 .30714 .1744 .29914 Mtetra
.662 .74 .908 r
.1744 .29914 .18256 .30714 .19418 .30293 .18605 .29485 Mtetra
.659 .738 .908 r
.18605 .29485 .19418 .30293 .20584 .29882 .19775 .29061 Mtetra
.654 .734 .909 r
.19775 .29061 .20584 .29882 .21752 .29496 .20949 .28651 Mtetra
.643 .726 .908 r
.20949 .28651 .21752 .29496 .22922 .2916 .22125 .28271 Mtetra
.624 .709 .907 r
.22125 .28271 .22922 .2916 .24089 .28913 .23302 .27944 Mtetra
.593 .678 .9 r
.23302 .27944 .24089 .28913 .25251 .28805 .24478 .277 Mtetra
.553 .63 .882 r
.24478 .277 .25251 .28805 .26405 .28885 .2565 .2757 Mtetra
.512 .569 .85 r
.2565 .2757 .26405 .28885 .27551 .29178 .2682 .27568 Mtetra
.486 .507 .805 r
.2682 .27568 .27551 .29178 .28694 .29659 .27989 .27679 Mtetra
.485 .463 .758 r
.27989 .27679 .28694 .29659 .29842 .30229 .29164 .27841 Mtetra
.505 .442 .719 r
.29164 .27841 .29842 .30229 .3101 .30725 .30353 .27958 Mtetra
.536 .44 .692 r
.30353 .27958 .3101 .30725 .32207 .30961 .31563 .27918 Mtetra
.569 .449 .676 r
.31563 .27918 .32207 .30961 .33439 .30803 .32796 .27643 Mtetra
.598 .464 .669 r
.32796 .27643 .33439 .30803 .34702 .30234 .34051 .27126 Mtetra
.617 .479 .67 r
.34051 .27126 .34702 .30234 .35986 .29381 .3532 .26445 Mtetra
.624 .49 .678 r
.3532 .26445 .35986 .29381 .37274 .2848 .36595 .25747 Mtetra
.612 .491 .691 r
.36595 .25747 .37274 .2848 .38555 .2779 .37866 .25191 Mtetra
.579 .478 .703 r
.37866 .25191 .38555 .2779 .39825 .27501 .39132 .24892 Mtetra
.532 .448 .706 r
.39132 .24892 .39825 .27501 .41085 .27664 .40394 .24878 Mtetra
.496 .416 .695 r
.40394 .24878 .41085 .27664 .42345 .28163 .41658 .25072 Mtetra
.493 .399 .678 r
.41658 .25072 .42345 .28163 .43617 .28744 .42933 .25306 Mtetra
.52 .404 .662 r
.42933 .25306 .43617 .28744 .44909 .29094 .44224 .25376 Mtetra
.56 .423 .651 r
.44224 .25376 .44909 .29094 .46225 .28938 .45534 .25108 Mtetra
.601 .448 .646 r
.45534 .25108 .46225 .28938 .4756 .28145 .46859 .24417 Mtetra
.638 .475 .646 r
.46859 .24417 .4756 .28145 .48906 .26758 .48195 .23332 Mtetra
.669 .504 .653 r
.48195 .23332 .48906 .26758 .50254 .24971 .49534 .2198 Mtetra
.693 .533 .666 r
.49534 .2198 .50254 .24971 .51597 .2304 .50873 .20529 Mtetra
.71 .565 .688 r
.50873 .20529 .51597 .2304 .52934 .21198 .5221 .19134 Mtetra
.72 .598 .719 r
.5221 .19134 .52934 .21198 .54267 .19591 .53546 .17895 Mtetra
.722 .632 .757 r
.53546 .17895 .54267 .19591 .55599 .18271 .54884 .16846 Mtetra
.715 .663 .797 r
.54884 .16846 .55599 .18271 .56935 .17216 .56225 .15976 Mtetra
.703 .688 .832 r
.56225 .15976 .56935 .17216 .58276 .16368 .57572 .15245 Mtetra
.69 .706 .86 r
.57572 .15245 .58276 .16368 .59623 .1566 .58925 .14609 Mtetra
.68 .718 .878 r
.58925 .14609 .59623 .1566 .60979 .15038 .60286 .14029 Mtetra
.672 .727 .89 r
.60286 .14029 .60979 .15038 .62341 .14465 .61653 .13481 Mtetra
.668 .732 .897 r
.61653 .13481 .62341 .14465 .6371 .13919 .63028 .12949 Mtetra
.666 .736 .902 r
.63028 .12949 .6371 .13919 .65087 .13386 .64409 .12423 Mtetra
.665 .738 .905 r
.64409 .12423 .65087 .13386 .6647 .12861 .65797 .119 Mtetra
.664 .74 .906 r
.65797 .119 .6647 .12861 .67861 .12339 .67193 .11377 Mtetra
.664 .74 .907 r
.67193 .11377 .67861 .12339 .69258 .11817 .68595 .10853 Mtetra
.664 .741 .907 r
.68595 .10853 .69258 .11817 .70663 .11295 .70004 .10327 Mtetra
.664 .741 .908 r
.70004 .10327 .70663 .11295 .72074 .10771 .71421 .09799 Mtetra
.71421 .09799 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.663 .741 .908 r
.14296 .29978 .15124 .30774 .1628 .30345 .15454 .29544 Mtetra
.15454 .29544 .1628 .30345 .1744 .29914 .16618 .29109 Mtetra
.16618 .29109 .1744 .29914 .18605 .29485 .17786 .28674 Mtetra
.661 .74 .908 r
.17786 .28674 .18605 .29485 .19775 .29061 .1896 .2824 Mtetra
.658 .737 .908 r
.1896 .2824 .19775 .29061 .20949 .28651 .20138 .27814 Mtetra
.652 .732 .908 r
.20138 .27814 .20949 .28651 .22125 .28271 .2132 .27403 Mtetra
.642 .722 .906 r
.2132 .27403 .22125 .28271 .23302 .27944 .22504 .27021 Mtetra
.625 .703 .901 r
.22504 .27021 .23302 .27944 .24478 .277 .2369 .26684 Mtetra
.603 .673 .89 r
.2369 .26684 .24478 .277 .2565 .2757 .24877 .26409 Mtetra
.579 .632 .869 r
.24877 .26409 .2565 .2757 .2682 .27568 .26064 .26205 Mtetra
.56 .586 .837 r
.26064 .26205 .2682 .27568 .27989 .27679 .27254 .26062 Mtetra
.553 .545 .799 r
.27254 .26062 .27989 .27679 .29164 .27841 .28449 .25947 Mtetra
.559 .516 .764 r
.28449 .25947 .29164 .27841 .30353 .27958 .29655 .25805 Mtetra
.574 .502 .737 r
.29655 .25805 .30353 .27958 .31563 .27918 .30875 .25576 Mtetra
.593 .5 .719 r
.30875 .25576 .31563 .27918 .32796 .27643 .3211 .25218 Mtetra
.611 .507 .711 r
.3211 .25218 .32796 .27643 .34051 .27126 .33361 .24729 Mtetra
.624 .516 .711 r
.33361 .24729 .34051 .27126 .3532 .26445 .34622 .24154 Mtetra
.628 .526 .719 r
.34622 .24154 .3532 .26445 .36595 .25747 .35888 .23576 Mtetra
.618 .529 .731 r
.35888 .23576 .36595 .25747 .37866 .25191 .37155 .23086 Mtetra
.594 .521 .742 r
.37155 .23086 .37866 .25191 .39132 .24892 .3842 .22749 Mtetra
.562 .499 .742 r
.3842 .22749 .39132 .24892 .40394 .24878 .39686 .22578 Mtetra
.538 .472 .73 r
.39686 .22578 .40394 .24878 .41658 .25072 .40955 .22525 Mtetra
.534 .454 .711 r
.40955 .22525 .41658 .25072 .42933 .25306 .42234 .22487 Mtetra
.551 .45 .693 r
.42234 .22487 .42933 .25306 .44224 .25376 .43526 .22344 Mtetra
.578 .458 .68 r
.43526 .22344 .44224 .25376 .45534 .25108 .44832 .2199 Mtetra
.607 .474 .673 r
.44832 .2199 .45534 .25108 .46859 .24417 .46151 .21375 Mtetra
.636 .495 .674 r
.46151 .21375 .46859 .24417 .48195 .23332 .47479 .20519 Mtetra
.661 .52 .682 r
.47479 .20519 .48195 .23332 .49534 .2198 .48812 .19498 Mtetra
.681 .549 .698 r
.48812 .19498 .49534 .2198 .50873 .20529 .50148 .18415 Mtetra
.696 .582 .723 r
.50148 .18415 .50873 .20529 .5221 .19134 .51485 .17363 Mtetra
.705 .616 .755 r
.51485 .17363 .5221 .19134 .53546 .17895 .52824 .16406 Mtetra
.706 .65 .792 r
.52824 .16406 .53546 .17895 .54884 .16846 .54165 .15565 Mtetra
.701 .68 .827 r
.54165 .15565 .54884 .16846 .56225 .15976 .55511 .14834 Mtetra
.691 .703 .857 r
.55511 .14834 .56225 .15976 .57572 .15245 .56863 .14188 Mtetra
.681 .719 .878 r
.56863 .14188 .57572 .15245 .58925 .14609 .58222 .136 Mtetra
.673 .728 .891 r
.58222 .136 .58925 .14609 .60286 .14029 .59587 .13047 Mtetra
.669 .733 .898 r
.59587 .13047 .60286 .14029 .61653 .13481 .6096 .12511 Mtetra
.666 .737 .903 r
.6096 .12511 .61653 .13481 .63028 .12949 .62339 .11984 Mtetra
.665 .739 .905 r
.62339 .11984 .63028 .12949 .64409 .12423 .63725 .11459 Mtetra
.664 .74 .906 r
.63725 .11459 .64409 .12423 .65797 .119 .65119 .10934 Mtetra
.664 .741 .907 r
.65119 .10934 .65797 .119 .67193 .11377 .66519 .10408 Mtetra
.664 .741 .908 r
.66519 .10408 .67193 .11377 .68595 .10853 .67926 .0988 Mtetra
.67926 .0988 .68595 .10853 .70004 .10327 .6934 .0935 Mtetra
.6934 .0935 .70004 .10327 .71421 .09799 .70762 .08817 Mtetra
.70762 .08817 .71421 .09799 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.663 .741 .908 r
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29109 .15788 .28298 Mtetra
.15788 .28298 .16618 .29109 .17786 .28674 .1696 .27858 Mtetra
.662 .74 .908 r
.1696 .27858 .17786 .28674 .1896 .2824 .18137 .27417 Mtetra
.661 .739 .908 r
.18137 .27417 .1896 .2824 .20138 .27814 .19319 .26979 Mtetra
.658 .736 .908 r
.19319 .26979 .20138 .27814 .2132 .27403 .20505 .26548 Mtetra
.652 .73 .906 r
.20505 .26548 .2132 .27403 .22504 .27021 .21696 .26131 Mtetra
.644 .72 .903 r
.21696 .26131 .22504 .27021 .2369 .26684 .2289 .25735 Mtetra
.633 .702 .896 r
.2289 .25735 .2369 .26684 .24877 .26409 .24087 .25371 Mtetra
.62 .677 .883 r
.24087 .25371 .24877 .26409 .26064 .26205 .25287 .25041 Mtetra
.608 .647 .863 r
.25287 .25041 .26064 .26205 .27254 .26062 .26491 .24741 Mtetra
.602 .615 .838 r
.26491 .24741 .27254 .26062 .28449 .25947 .277 .24455 Mtetra
.602 .589 .811 r
.277 .24455 .28449 .25947 .29655 .25805 .28918 .24154 Mtetra
.608 .572 .788 r
.28918 .24154 .29655 .25805 .30875 .25576 .30145 .23808 Mtetra
.618 .564 .771 r
.30145 .23808 .30875 .25576 .3211 .25218 .31384 .23396 Mtetra
.628 .564 .763 r
.31384 .23396 .3211 .25218 .33361 .24729 .32633 .22919 Mtetra
.636 .57 .764 r
.32633 .22919 .33361 .24729 .34622 .24154 .33891 .224 Mtetra
.638 .577 .77 r
.33891 .224 .34622 .24154 .35888 .23576 .35154 .21883 Mtetra
.63 .581 .78 r
.35154 .21883 .35888 .23576 .37155 .23086 .36419 .21417 Mtetra
.614 .576 .788 r
.36419 .21417 .37155 .23086 .3842 .22749 .37687 .21034 Mtetra
.593 .56 .786 r
.37687 .21034 .3842 .22749 .39686 .22578 .38957 .2074 Mtetra
.577 .538 .774 r
.38957 .2074 .39686 .22578 .40955 .22525 .40233 .20506 Mtetra
.573 .518 .755 r
.40233 .20506 .40955 .22525 .42234 .22487 .41516 .20277 Mtetra
.582 .507 .736 r
.41516 .20277 .42234 .22487 .43526 .22344 .4281 .19984 Mtetra
.599 .507 .722 r
.4281 .19984 .43526 .22344 .44832 .2199 .44115 .1957 Mtetra
.619 .516 .715 r
.44115 .1957 .44832 .2199 .46151 .21375 .45431 .19007 Mtetra
.64 .532 .715 r
.45431 .19007 .46151 .21375 .47479 .20519 .46754 .18306 Mtetra
.659 .553 .724 r
.46754 .18306 .47479 .20519 .48812 .19498 .48084 .1751 Mtetra
.675 .58 .741 r
.48084 .1751 .48812 .19498 .50148 .18415 .49418 .16677 Mtetra
.686 .611 .766 r
.49418 .16677 .50148 .18415 .51485 .17363 .50756 .15861 Mtetra
.692 .643 .796 r
.50756 .15861 .51485 .17363 .52824 .16406 .52097 .15097 Mtetra
.692 .673 .827 r
.52097 .15097 .52824 .16406 .54165 .15565 .53442 .14398 Mtetra
.687 .698 .854 r
.53442 .14398 .54165 .15565 .55511 .14834 .54793 .13761 Mtetra
.68 .716 .876 r
.54793 .13761 .55511 .14834 .56863 .14188 .5615 .13171 Mtetra
.674 .727 .89 r
.5615 .13171 .56863 .14188 .58222 .136 .57513 .12613 Mtetra
.669 .734 .898 r
.57513 .12613 .58222 .136 .59587 .13047 .58884 .12074 Mtetra
.666 .737 .903 r
.58884 .12074 .59587 .13047 .6096 .12511 .60261 .11544 Mtetra
.665 .739 .905 r
.60261 .11544 .6096 .12511 .62339 .11984 .61645 .11017 Mtetra
.664 .74 .907 r
.61645 .11017 .62339 .11984 .63725 .11459 .63036 .1049 Mtetra
.664 .741 .907 r
.63036 .1049 .63725 .11459 .65119 .10934 .64434 .09962 Mtetra
.664 .741 .908 r
.64434 .09962 .65119 .10934 .66519 .10408 .65839 .09432 Mtetra
.65839 .09432 .66519 .10408 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28805 Mtetra
.11459 .28805 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.663 .741 .908 r
.13782 .27924 .14622 .28737 .15788 .28298 .14952 .2748 Mtetra
.14952 .2748 .15788 .28298 .1696 .27858 .16127 .27036 Mtetra
.16127 .27036 .1696 .27858 .18137 .27417 .17307 .2659 Mtetra
.662 .74 .908 r
.17307 .2659 .18137 .27417 .19319 .26979 .18492 .26144 Mtetra
.661 .739 .908 r
.18492 .26144 .19319 .26979 .20505 .26548 .19683 .257 Mtetra
.658 .736 .907 r
.19683 .257 .20505 .26548 .21696 .26131 .20878 .25261 Mtetra
.654 .73 .905 r
.20878 .25261 .21696 .26131 .2289 .25735 .22078 .24832 Mtetra
.649 .721 .901 r
.22078 .24832 .2289 .25735 .24087 .25371 .23282 .24416 Mtetra
.643 .707 .894 r
.23282 .24416 .24087 .25371 .25287 .25041 .24491 .24015 Mtetra
.637 .689 .882 r
.24491 .24015 .25287 .25041 .26491 .24741 .25704 .23626 Mtetra
.633 .669 .867 r
.25704 .23626 .26491 .24741 .277 .24455 .26924 .23243 Mtetra
.632 .651 .851 r
.26924 .23243 .277 .24455 .28918 .24154 .2815 .22852 Mtetra
.634 .636 .835 r
.2815 .22852 .28918 .24154 .30145 .23808 .29383 .22439 Mtetra
.639 .628 .823 r
.29383 .22439 .30145 .23808 .31384 .23396 .30626 .21995 Mtetra
.644 .626 .817 r
.30626 .21995 .31384 .23396 .32633 .22919 .31876 .2152 Mtetra
.648 .629 .817 r
.31876 .2152 .32633 .22919 .33891 .224 .33133 .21027 Mtetra
.648 .634 .822 r
.33133 .21027 .33891 .224 .35154 .21883 .34396 .20536 Mtetra
.643 .636 .828 r
.34396 .20536 .35154 .21883 .36419 .21417 .35663 .2007 Mtetra
.633 .633 .832 r
.35663 .2007 .36419 .21417 .37687 .21034 .36934 .19646 Mtetra
.621 .621 .829 r
.36934 .19646 .37687 .21034 .38957 .2074 .38209 .19266 Mtetra
.611 .603 .819 r
.38209 .19266 .38957 .2074 .40233 .20506 .39491 .18914 Mtetra
.607 .585 .803 r
.39491 .18914 .40233 .20506 .41516 .20277 .40779 .18561 Mtetra
.612 .572 .786 r
.40779 .18561 .41516 .20277 .4281 .19984 .42076 .18173 Mtetra
.621 .567 .773 r
.42076 .18173 .4281 .19984 .44115 .1957 .43382 .17719 Mtetra
.634 .571 .766 r
.43382 .17719 .44115 .1957 .45431 .19007 .44697 .17185 Mtetra
.648 .582 .766 r
.44697 .17185 .45431 .19007 .46754 .18306 .46019 .16579 Mtetra
.661 .599 .775 r
.46019 .16579 .46754 .18306 .48084 .1751 .47348 .15921 Mtetra
.672 .622 .79 r
.47348 .15921 .48084 .1751 .49418 .16677 .48682 .15243 Mtetra
.679 .647 .811 r
.48682 .15243 .49418 .16677 .50756 .15861 .50021 .14572 Mtetra
.682 .673 .834 r
.50021 .14572 .50756 .15861 .52097 .15097 .51365 .13927 Mtetra
.681 .695 .857 r
.51365 .13927 .52097 .15097 .53442 .14398 .52714 .13315 Mtetra
.677 .713 .875 r
.52714 .13315 .53442 .14398 .54793 .13761 .54069 .12734 Mtetra
.673 .725 .889 r
.54069 .12734 .54793 .13761 .5615 .13171 .55431 .12177 Mtetra
.669 .733 .898 r
.55431 .12177 .5615 .13171 .57513 .12613 .56799 .11636 Mtetra
.666 .737 .903 r
.56799 .11636 .57513 .12613 .58884 .12074 .58174 .11103 Mtetra
.665 .739 .905 r
.58174 .11103 .58884 .12074 .60261 .11544 .59555 .10573 Mtetra
.664 .74 .907 r
.59555 .10573 .60261 .11544 .61645 .11017 .60944 .10044 Mtetra
.664 .741 .907 r
.60944 .10044 .61645 .11017 .63036 .1049 .6234 .09514 Mtetra
.664 .741 .908 r
.6234 .09514 .63036 .1049 .64434 .09962 .63743 .08982 Mtetra
.63743 .08982 .64434 .09962 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28805 .10606 .27992 Mtetra
.10606 .27992 .11459 .28805 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.663 .741 .908 r
.14108 .26656 .14952 .2748 .16127 .27036 .15286 .26207 Mtetra
.15286 .26207 .16127 .27036 .17307 .2659 .1647 .25756 Mtetra
.1647 .25756 .17307 .2659 .18492 .26144 .17658 .25305 Mtetra
.662 .74 .908 r
.17658 .25305 .18492 .26144 .19683 .257 .18853 .24852 Mtetra
.661 .739 .907 r
.18853 .24852 .19683 .257 .20878 .25261 .20052 .24401 Mtetra
.66 .736 .906 r
.20052 .24401 .20878 .25261 .22078 .24832 .21257 .23953 Mtetra
.657 .731 .904 r
.21257 .23953 .22078 .24832 .23282 .24416 .22466 .23509 Mtetra
.654 .724 .9 r
.22466 .23509 .23282 .24416 .24491 .24015 .23681 .2307 Mtetra
.652 .715 .895 r
.23681 .2307 .24491 .24015 .25704 .23626 .24901 .22635 Mtetra
.65 .705 .887 r
.24901 .22635 .25704 .23626 .26924 .23243 .26127 .22202 Mtetra
.649 .694 .878 r
.26127 .22202 .26924 .23243 .2815 .22852 .27359 .21764 Mtetra
.65 .685 .87 r
.27359 .21764 .2815 .22852 .29383 .22439 .28598 .21315 Mtetra
.652 .679 .863 r
.28598 .21315 .29383 .22439 .30626 .21995 .29843 .20852 Mtetra
.655 .677 .859 r
.29843 .20852 .30626 .21995 .31876 .2152 .31096 .20375 Mtetra
.656 .678 .859 r
.31096 .20375 .31876 .2152 .33133 .21027 .32355 .19889 Mtetra
.656 .681 .861 r
.32355 .19889 .33133 .21027 .34396 .20536 .3362 .19405 Mtetra
.653 .682 .865 r
.3362 .19405 .34396 .20536 .35663 .2007 .3489 .18932 Mtetra
.647 .679 .866 r
.3489 .18932 .35663 .2007 .36934 .19646 .36165 .18478 Mtetra
.641 .671 .863 r
.36165 .18478 .36934 .19646 .38209 .19266 .37445 .18042 Mtetra
.635 .659 .856 r
.37445 .18042 .38209 .19266 .39491 .18914 .38731 .17619 Mtetra
.633 .645 .844 r
.38731 .17619 .39491 .18914 .40779 .18561 .40025 .17192 Mtetra
.635 .634 .832 r
.40025 .17192 .40779 .18561 .42076 .18173 .41325 .16747 Mtetra
.64 .628 .822 r
.41325 .16747 .42076 .18173 .43382 .17719 .42634 .16268 Mtetra
.648 .629 .817 r
.42634 .16268 .43382 .17719 .44697 .17185 .4395 .15749 Mtetra
.656 .636 .818 r
.4395 .15749 .44697 .17185 .46019 .16579 .45273 .15194 Mtetra
.664 .648 .824 r
.45273 .15194 .46019 .16579 .47348 .15921 .46602 .14612 Mtetra
.67 .664 .836 r
.46602 .14612 .47348 .15921 .48682 .15243 .47938 .1402 Mtetra
.673 .682 .85 r
.47938 .1402 .48682 .15243 .50021 .14572 .49279 .13429 Mtetra
.674 .699 .865 r
.49279 .13429 .50021 .14572 .51365 .13927 .50627 .1285 Mtetra
.673 .714 .879 r
.50627 .1285 .51365 .13927 .52714 .13315 .5198 .12286 Mtetra
.671 .725 .89 r
.5198 .12286 .52714 .13315 .54069 .12734 .53339 .11735 Mtetra
.668 .732 .898 r
.53339 .11735 .54069 .12734 .55431 .12177 .54705 .11194 Mtetra
.666 .737 .902 r
.54705 .11194 .55431 .12177 .56799 .11636 .56078 .1066 Mtetra
.665 .739 .905 r
.56078 .1066 .56799 .11636 .58174 .11103 .57457 .10128 Mtetra
.664 .74 .907 r
.57457 .10128 .58174 .11103 .59555 .10573 .58844 .09597 Mtetra
.664 .741 .907 r
.58844 .09597 .59555 .10573 .60944 .10044 .60237 .09064 Mtetra
.664 .741 .908 r
.60237 .09064 .60944 .10044 .6234 .09514 .61637 .0853 Mtetra
.61637 .0853 .6234 .09514 .63743 .08982 .63045 .07993 Mtetra
.63045 .07993 .63743 .08982 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.663 .741 .908 r
.14438 .25372 .15286 .26207 .1647 .25756 .15625 .24917 Mtetra
.15625 .24917 .1647 .25756 .17658 .25305 .16817 .2446 Mtetra
.16817 .2446 .17658 .25305 .18853 .24852 .18015 .24002 Mtetra
.663 .74 .908 r
.18015 .24002 .18853 .24852 .20052 .24401 .19218 .23543 Mtetra
.662 .739 .907 r
.19218 .23543 .20052 .24401 .21257 .23953 .20426 .23084 Mtetra
.661 .737 .906 r
.20426 .23084 .21257 .23953 .22466 .23509 .2164 .22625 Mtetra
.66 .734 .904 r
.2164 .22625 .22466 .23509 .23681 .2307 .22859 .22167 Mtetra
.659 .73 .902 r
.22859 .22167 .23681 .2307 .24901 .22635 .24084 .21709 Mtetra
.658 .725 .898 r
.24084 .21709 .24901 .22635 .26127 .22202 .25315 .2125 Mtetra
.658 .719 .894 r
.25315 .2125 .26127 .22202 .27359 .21764 .26552 .20788 Mtetra
.658 .715 .89 r
.26552 .20788 .27359 .21764 .28598 .21315 .27795 .2032 Mtetra
.659 .712 .887 r
.27795 .2032 .28598 .21315 .29843 .20852 .29044 .19846 Mtetra
.66 .71 .885 r
.29044 .19846 .29843 .20852 .31096 .20375 .303 .19365 Mtetra
.661 .711 .885 r
.303 .19365 .31096 .20375 .32355 .19889 .31562 .1888 Mtetra
.66 .712 .886 r
.31562 .1888 .32355 .19889 .3362 .19405 .3283 .18394 Mtetra
.658 .712 .887 r
.3283 .18394 .3362 .19405 .3489 .18932 .34103 .17913 Mtetra
.656 .71 .887 r
.34103 .17913 .3489 .18932 .36165 .18478 .35382 .17438 Mtetra
.653 .705 .885 r
.35382 .17438 .36165 .18478 .37445 .18042 .36667 .1697 Mtetra
.65 .698 .881 r
.36667 .1697 .37445 .18042 .38731 .17619 .37958 .16505 Mtetra
.649 .689 .874 r
.37958 .16505 .38731 .17619 .40025 .17192 .39256 .16037 Mtetra
.65 .682 .867 r
.39256 .16037 .40025 .17192 .41325 .16747 .4056 .1556 Mtetra
.653 .678 .861 r
.4056 .1556 .41325 .16747 .42634 .16268 .41872 .15066 Mtetra
.657 .677 .858 r
.41872 .15066 .42634 .16268 .4395 .15749 .43191 .14552 Mtetra
.661 .681 .858 r
.43191 .14552 .4395 .15749 .45273 .15194 .44516 .14021 Mtetra
.665 .688 .862 r
.44516 .14021 .45273 .15194 .46602 .14612 .45848 .13477 Mtetra
.667 .698 .869 r
.45848 .13477 .46602 .14612 .47938 .1402 .47186 .12927 Mtetra
.669 .709 .877 r
.47186 .12927 .47938 .1402 .49279 .13429 .48531 .12376 Mtetra
.669 .718 .886 r
.48531 .12376 .49279 .13429 .50627 .1285 .49882 .11828 Mtetra
.668 .727 .893 r
.49882 .11828 .50627 .1285 .5198 .12286 .51239 .11286 Mtetra
.667 .733 .899 r
.51239 .11286 .5198 .12286 .53339 .11735 .52603 .10748 Mtetra
.666 .736 .903 r
.52603 .10748 .53339 .11735 .54705 .11194 .53973 .10214 Mtetra
.665 .739 .905 r
.53973 .10214 .54705 .11194 .56078 .1066 .5535 .09681 Mtetra
.664 .74 .907 r
.5535 .09681 .56078 .1066 .57457 .10128 .56734 .09147 Mtetra
.664 .741 .907 r
.56734 .09147 .57457 .10128 .58844 .09597 .58125 .08612 Mtetra
.664 .741 .908 r
.58125 .08612 .58844 .09597 .60237 .09064 .59523 .08076 Mtetra
.59523 .08076 .60237 .09064 .61637 .0853 .60929 .07536 Mtetra
.60929 .07536 .61637 .0853 .63045 .07993 .62341 .06994 Mtetra
.62341 .06994 .63045 .07993 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.663 .741 .908 r
.14773 .24071 .15625 .24917 .16817 .2446 .15968 .2361 Mtetra
.15968 .2361 .16817 .2446 .18015 .24002 .17169 .23147 Mtetra
.17169 .23147 .18015 .24002 .19218 .23543 .18376 .22682 Mtetra
.663 .74 .908 r
.18376 .22682 .19218 .23543 .20426 .23084 .19588 .22216 Mtetra
.663 .739 .907 r
.19588 .22216 .20426 .23084 .2164 .22625 .20805 .21748 Mtetra
.662 .738 .906 r
.20805 .21748 .2164 .22625 .22859 .22167 .22029 .2128 Mtetra
.662 .736 .905 r
.22029 .2128 .22859 .22167 .24084 .21709 .23258 .2081 Mtetra
.661 .734 .904 r
.23258 .2081 .24084 .21709 .25315 .2125 .24492 .20338 Mtetra
.661 .732 .902 r
.24492 .20338 .25315 .2125 .26552 .20788 .25733 .19863 Mtetra
.661 .73 .9 r
.25733 .19863 .26552 .20788 .27795 .2032 .2698 .19386 Mtetra
.662 .729 .899 r
.2698 .19386 .27795 .2032 .29044 .19846 .28233 .18904 Mtetra
.662 .728 .898 r
.28233 .18904 .29044 .19846 .303 .19365 .29492 .18419 Mtetra
.29492 .18419 .303 .19365 .31562 .1888 .30757 .1793 Mtetra
.662 .728 .899 r
.30757 .1793 .31562 .1888 .3283 .18394 .32029 .17441 Mtetra
.661 .728 .899 r
.32029 .17441 .3283 .18394 .34103 .17913 .33306 .16951 Mtetra
.66 .727 .899 r
.33306 .16951 .34103 .17913 .35382 .17438 .34589 .16463 Mtetra
.659 .724 .898 r
.34589 .16463 .35382 .17438 .36667 .1697 .35878 .15976 Mtetra
.658 .721 .895 r
.35878 .15976 .36667 .1697 .37958 .16505 .37174 .15489 Mtetra
.657 .716 .892 r
.37174 .15489 .37958 .16505 .39256 .16037 .38476 .15 Mtetra
.658 .712 .888 r
.38476 .15 .39256 .16037 .4056 .1556 .39784 .14504 Mtetra
.659 .71 .885 r
.39784 .14504 .4056 .1556 .41872 .15066 .41099 .14 Mtetra
.661 .709 .884 r
.41099 .14 .41872 .15066 .43191 .14552 .42421 .13487 Mtetra
.663 .711 .884 r
.42421 .13487 .43191 .14552 .44516 .14021 .4375 .12965 Mtetra
.664 .715 .886 r
.4375 .12965 .44516 .14021 .45848 .13477 .45085 .12436 Mtetra
.665 .72 .889 r
.45085 .12436 .45848 .13477 .47186 .12927 .46427 .11903 Mtetra
.666 .725 .893 r
.46427 .11903 .47186 .12927 .48531 .12376 .47775 .11368 Mtetra
.666 .73 .898 r
.47775 .11368 .48531 .12376 .49882 .11828 .4913 .10833 Mtetra
.665 .734 .901 r
.4913 .10833 .49882 .11828 .51239 .11286 .50491 .10299 Mtetra
.665 .737 .904 r
.50491 .10299 .51239 .11286 .52603 .10748 .51859 .09765 Mtetra
.664 .739 .906 r
.51859 .09765 .52603 .10748 .53973 .10214 .53234 .09231 Mtetra
.664 .74 .907 r
.53234 .09231 .53973 .10214 .5535 .09681 .54616 .08696 Mtetra
.664 .741 .907 r
.54616 .08696 .5535 .09681 .56734 .09147 .56005 .08159 Mtetra
.664 .741 .908 r
.56005 .08159 .56734 .09147 .58125 .08612 .574 .0762 Mtetra
.574 .0762 .58125 .08612 .59523 .08076 .58803 .07078 Mtetra
.58803 .07078 .59523 .08076 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .2361 .15112 .22752 Mtetra
.663 .741 .908 r
.15112 .22752 .15968 .2361 .17169 .23147 .16316 .22285 Mtetra
.16316 .22285 .17169 .23147 .18376 .22682 .17526 .21815 Mtetra
.17526 .21815 .18376 .22682 .19588 .22216 .18741 .21344 Mtetra
.18741 .21344 .19588 .22216 .20805 .21748 .19963 .20871 Mtetra
.663 .74 .907 r
.19963 .20871 .20805 .21748 .22029 .2128 .21189 .20395 Mtetra
.21189 .20395 .22029 .2128 .23258 .2081 .22422 .19918 Mtetra
.663 .739 .906 r
.22422 .19918 .23258 .2081 .24492 .20338 .23661 .19439 Mtetra
.663 .738 .906 r
.23661 .19439 .24492 .20338 .25733 .19863 .24905 .18957 Mtetra
.663 .737 .905 r
.24905 .18957 .25733 .19863 .2698 .19386 .26156 .18473 Mtetra
.26156 .18473 .2698 .19386 .28233 .18904 .27412 .17986 Mtetra
.663 .736 .904 r
.27412 .17986 .28233 .18904 .29492 .18419 .28675 .17496 Mtetra
.28675 .17496 .29492 .18419 .30757 .1793 .29944 .17003 Mtetra
.29944 .17003 .30757 .1793 .32029 .17441 .31219 .16509 Mtetra
.31219 .16509 .32029 .17441 .33306 .16951 .32499 .16013 Mtetra
.662 .735 .904 r
.32499 .16013 .33306 .16951 .34589 .16463 .33787 .15516 Mtetra
.662 .734 .904 r
.33787 .15516 .34589 .16463 .35878 .15976 .3508 .15019 Mtetra
.661 .732 .902 r
.3508 .15019 .35878 .15976 .37174 .15489 .3638 .14519 Mtetra
.661 .73 .901 r
.3638 .14519 .37174 .15489 .38476 .15 .37686 .14017 Mtetra
.661 .729 .899 r
.37686 .14017 .38476 .15 .39784 .14504 .38998 .13511 Mtetra
.662 .727 .898 r
.38998 .13511 .39784 .14504 .41099 .14 .40317 .13 Mtetra
.662 .727 .897 r
.40317 .13 .41099 .14 .42421 .13487 .41643 .12484 Mtetra
.663 .728 .897 r
.41643 .12484 .42421 .13487 .4375 .12965 .42975 .11964 Mtetra
.664 .73 .898 r
.42975 .11964 .4375 .12965 .45085 .12436 .44314 .11438 Mtetra
.664 .732 .9 r
.44314 .11438 .45085 .12436 .46427 .11903 .4566 .1091 Mtetra
.664 .734 .902 r
.4566 .1091 .46427 .11903 .47775 .11368 .47012 .1038 Mtetra
.664 .736 .903 r
.47012 .1038 .47775 .11368 .4913 .10833 .48371 .09848 Mtetra
.664 .738 .905 r
.48371 .09848 .4913 .10833 .50491 .10299 .49737 .09314 Mtetra
.664 .739 .906 r
.49737 .09314 .50491 .10299 .51859 .09765 .51109 .08779 Mtetra
.664 .74 .907 r
.51109 .08779 .51859 .09765 .53234 .09231 .52489 .08242 Mtetra
.664 .741 .907 r
.52489 .08242 .53234 .09231 .54616 .08696 .53875 .07703 Mtetra
.664 .741 .908 r
.53875 .07703 .54616 .08696 .56005 .08159 .55268 .07162 Mtetra
.55268 .07162 .56005 .08159 .574 .0762 .56669 .06618 Mtetra
.56669 .06618 .574 .0762 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22357 Mtetra
.13047 .22357 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22285 .15456 .21416 Mtetra
.15456 .21416 .16316 .22285 .17526 .21815 .16669 .20942 Mtetra
.663 .741 .908 r
.16669 .20942 .17526 .21815 .18741 .21344 .17888 .20466 Mtetra
.17888 .20466 .18741 .21344 .19963 .20871 .19112 .19988 Mtetra
.19112 .19988 .19963 .20871 .21189 .20395 .20343 .19508 Mtetra
.20343 .19508 .21189 .20395 .22422 .19918 .21579 .19025 Mtetra
.663 .74 .907 r
.21579 .19025 .22422 .19918 .23661 .19439 .22821 .18541 Mtetra
.22821 .18541 .23661 .19439 .24905 .18957 .24069 .18054 Mtetra
.24069 .18054 .24905 .18957 .26156 .18473 .25323 .17564 Mtetra
.25323 .17564 .26156 .18473 .27412 .17986 .26583 .17072 Mtetra
.26583 .17072 .27412 .17986 .28675 .17496 .27849 .16578 Mtetra
.27849 .16578 .28675 .17496 .29944 .17003 .29122 .16081 Mtetra
.663 .739 .907 r
.29122 .16081 .29944 .17003 .31219 .16509 .304 .15582 Mtetra
.304 .15582 .31219 .16509 .32499 .16013 .31685 .15081 Mtetra
.31685 .15081 .32499 .16013 .33787 .15516 .32976 .14577 Mtetra
.663 .739 .906 r
.32976 .14577 .33787 .15516 .3508 .15019 .34273 .14072 Mtetra
.663 .738 .906 r
.34273 .14072 .3508 .15019 .3638 .14519 .35577 .13565 Mtetra
.663 .737 .905 r
.35577 .13565 .3638 .14519 .37686 .14017 .36887 .13055 Mtetra
.663 .736 .905 r
.36887 .13055 .37686 .14017 .38998 .13511 .38204 .12542 Mtetra
.663 .736 .904 r
.38204 .12542 .38998 .13511 .40317 .13 .39527 .12026 Mtetra
.39527 .12026 .40317 .13 .41643 .12484 .40857 .11506 Mtetra
.40857 .11506 .41643 .12484 .42975 .11964 .42193 .10983 Mtetra
.664 .737 .904 r
.42193 .10983 .42975 .11964 .44314 .11438 .43536 .10456 Mtetra
.664 .737 .905 r
.43536 .10456 .44314 .11438 .4566 .1091 .44886 .09927 Mtetra
.664 .738 .905 r
.44886 .09927 .4566 .1091 .47012 .1038 .46242 .09395 Mtetra
.664 .739 .906 r
.46242 .09395 .47012 .1038 .48371 .09848 .47605 .08861 Mtetra
.664 .74 .907 r
.47605 .08861 .48371 .09848 .49737 .09314 .48975 .08325 Mtetra
.664 .741 .907 r
.48975 .08325 .49737 .09314 .51109 .08779 .50352 .07786 Mtetra
.664 .741 .908 r
.50352 .07786 .51109 .08779 .52489 .08242 .51736 .07245 Mtetra
.51736 .07245 .52489 .08242 .53875 .07703 .53127 .06702 Mtetra
.53127 .06702 .53875 .07703 .55268 .07162 .54525 .06156 Mtetra
.54525 .06156 .55268 .07162 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.6806 .34074 m
.7064 .33294 L
.7322 .33541 L
.75222 .3452 L
.758 .34801 L
.77615 .371 L
.78297 .3968 L
.78094 .4226 L
.76772 .4484 L
.758 .45816 L
.7322 .47145 L
.7064 .47352 L
.6806 .46678 L
.65738 .4484 L
.6548 .44301 L
.64479 .4226 L
.64239 .3968 L
.65026 .371 L
.6548 .36195 L
.67161 .3452 L
.6806 .34074 L
s
.5516 .21214 m
.5774 .20592 L
.6032 .21006 L
.61551 .2162 L
.629 .22445 L
.64118 .242 L
.64923 .2678 L
.64736 .2936 L
.63372 .3194 L
.629 .32478 L
.6032 .34129 L
.5774 .34473 L
.5516 .33951 L
.52602 .3194 L
.5258 .31867 L
.51247 .2936 L
.51049 .2678 L
.5189 .242 L
.5258 .23023 L
.54137 .2162 L
.5516 .21214 L
s
.3452 .23198 m
.371 .22233 L
.3968 .22342 L
.4226 .23649 L
.42891 .242 L
.44474 .2678 L
.44743 .2936 L
.44103 .3194 L
.4226 .34241 L
.4159 .3452 L
.3968 .35366 L
.371 .35486 L
.34604 .3452 L
.3452 .34493 L
.32131 .3194 L
.3194 .31359 L
.31452 .2936 L
.31788 .2678 L
.3194 .26387 L
.33191 .242 L
.3452 .23198 L
s
.7064 .55159 m
.70647 .5516 L
.7322 .56012 L
.7532 .5774 L
.758 .58548 L
.76677 .6032 L
.77057 .629 L
.76521 .6548 L
.758 .67236 L
.74968 .6806 L
.7322 .69354 L
.7064 .70255 L
.6806 .70243 L
.6548 .6931 L
.63811 .6806 L
.629 .67112 L
.62256 .6548 L
.61719 .629 L
.621 .6032 L
.629 .58665 L
.63452 .5774 L
.6548 .56055 L
.6806 .5517 L
.68127 .5516 L
.7064 .55159 L
s
.2678 .54116 m
.2936 .53376 L
.3194 .53602 L
.3452 .5497 L
.34758 .5516 L
.36688 .5774 L
.371 .59315 L
.37214 .6032 L
.371 .6188 L
.36876 .629 L
.35387 .6548 L
.3452 .66274 L
.3194 .67588 L
.2936 .67798 L
.2678 .67104 L
.24552 .6548 L
.242 .64831 L
.23155 .629 L
.22778 .6032 L
.23374 .5774 L
.242 .55986 L
.25046 .5516 L
.2678 .54116 L
s
.4484 .67005 m
.4742 .66665 L
.5 .67303 L
.51582 .6806 L
.5258 .69049 L
.53509 .7064 L
.54265 .7322 L
.54047 .758 L
.52691 .7838 L
.5258 .78523 L
.5 .80537 L
.48482 .8096 L
.4742 .811 L
.45604 .8096 L
.4484 .8079 L
.4226 .79377 L
.4133 .7838 L
.40048 .758 L
.39851 .7322 L
.40544 .7064 L
.4226 .68365 L
.4284 .6806 L
.4484 .67005 L
s
.2678 .36406 m
.2936 .36423 L
.31197 .371 L
.3194 .37423 L
.34037 .3968 L
.3452 .4097 L
.34838 .4226 L
.34692 .4484 L
.3452 .45399 L
.33575 .4742 L
.3194 .48942 L
.2936 .49931 L
.2678 .49945 L
.242 .49002 L
.22469 .4742 L
.2162 .45644 L
.21355 .4484 L
.21209 .4226 L
.2162 .40725 L
.2202 .3968 L
.242 .37377 L
.24854 .371 L
.2678 .36406 L
s
0 g
.03 w
.71286 .40342 Mdot
.57986 .2755 Mdot
.38097 .28873 Mdot
.69387 .62689 Mdot
.30019 .60597 Mdot
.47043 .73905 Mdot
.28026 .43185 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.69608 .59267 m
.70962 .59804 L
.71569 .60334 L
.72518 .61765 L
.72335 .63725 L
.71569 .64654 L
.69608 .6565 L
.67647 .65194 L
.66456 .63725 L
.66393 .61765 L
.67647 .59934 L
.67836 .59804 L
.69608 .59267 L
s
.69608 .37783 m
.71569 .37821 L
.72028 .38235 L
.73146 .40196 L
.72369 .42157 L
.71569 .42827 L
.69608 .42163 L
.69603 .42157 L
.68465 .40196 L
.68918 .38235 L
.69608 .37783 L
s
.57843 .26489 m
.59804 .27609 L
.59985 .28431 L
.59804 .29036 L
.57843 .29489 L
.56726 .28431 L
.57843 .26489 L
s
.44118 .71518 m
.46078 .7016 L
.48039 .70321 L
.49591 .71569 L
.5 .72142 L
.50443 .73529 L
.5 .75228 L
.49845 .7549 L
.48039 .76859 L
.46078 .76883 L
.44152 .7549 L
.44118 .7544 L
.43412 .73529 L
.44087 .71569 L
.44118 .71518 L
s
.69608 .57428 m
.71233 .57843 L
.71569 .57997 L
.734 .59804 L
.73529 .60251 L
.74008 .61765 L
.73907 .63725 L
.73529 .64693 L
.73064 .65686 L
.71569 .66817 L
.69608 .67365 L
.67647 .67143 L
.65686 .65813 L
.65583 .65686 L
.64607 .63725 L
.64621 .61765 L
.65468 .59804 L
.65686 .59475 L
.67647 .57868 L
.67709 .57843 L
.69608 .57428 L
s
.28431 .56765 m
.30392 .56342 L
.31937 .57843 L
.32353 .58604 L
.32797 .59804 L
.32353 .61733 L
.32334 .61765 L
.30392 .62821 L
.28431 .62116 L
.28223 .61765 L
.27507 .59804 L
.27894 .57843 L
.28431 .56765 L
s
.28431 .40756 m
.30392 .41511 L
.30659 .42157 L
.30831 .44118 L
.30392 .45118 L
.29867 .46078 L
.28431 .47055 L
.26921 .46078 L
.26471 .45313 L
.26017 .44118 L
.26471 .42458 L
.26626 .42157 L
.28431 .40756 L
s
.67647 .35758 m
.69608 .35484 L
.71569 .35936 L
.72267 .36275 L
.73529 .36939 L
.74446 .38235 L
.75055 .40196 L
.74778 .42157 L
.73529 .44027 L
.73079 .44118 L
.71569 .44766 L
.69608 .44471 L
.69011 .44118 L
.67647 .42829 L
.67246 .42157 L
.66451 .40196 L
.66225 .38235 L
.66801 .36275 L
.67647 .35758 L
s
.38235 .26026 m
.39917 .26471 L
.40196 .26627 L
.4172 .28431 L
.41393 .30392 L
.40196 .31719 L
.39314 .32353 L
.38235 .32896 L
.36275 .331 L
.35132 .32353 L
.34482 .30392 L
.34512 .28431 L
.36275 .26723 L
.36704 .26471 L
.38235 .26026 L
s
.57843 .24297 m
.59182 .2451 L
.59804 .24763 L
.61648 .26471 L
.61765 .26662 L
.62493 .28431 L
.62548 .30392 L
.61765 .31577 L
.59804 .32217 L
.57843 .3192 L
.55882 .30884 L
.55333 .30392 L
.54137 .28431 L
.54284 .26471 L
.55882 .24896 L
.56739 .2451 L
.57843 .24297 L
s
.44118 .69161 m
.46078 .68687 L
.48039 .68849 L
.49853 .69608 L
.5 .69656 L
.51703 .71569 L
.51961 .72366 L
.52108 .73529 L
.51961 .74656 L
.5172 .7549 L
.5024 .77451 L
.5 .77628 L
.48039 .78539 L
.46078 .78548 L
.44118 .77674 L
.43801 .77451 L
.42289 .7549 L
.42157 .75127 L
.41755 .73529 L
.41936 .71569 L
.42157 .71025 L
.43257 .69608 L
.44118 .69161 L
s
.69608 .55712 m
.7087 .55882 L
.71569 .56165 L
.73529 .57727 L
.73634 .57843 L
.74846 .59804 L
.75341 .61765 L
.75267 .63725 L
.74539 .65686 L
.73529 .67007 L
.7285 .67647 L
.71569 .68233 L
.69608 .68686 L
.67647 .68519 L
.65686 .67677 L
.65638 .67647 L
.63792 .65686 L
.63725 .6555 L
.6317 .63725 L
.63244 .61765 L
.63725 .6022 L
.63905 .59804 L
.65273 .57843 L
.65686 .57454 L
.67647 .56138 L
.68343 .55882 L
.69608 .55712 L
s
.28431 .38232 m
.30392 .37581 L
.32353 .38189 L
.32421 .38235 L
.32835 .40196 L
.32862 .42157 L
.32646 .44118 L
.32353 .45748 L
.32278 .46078 L
.31889 .48039 L
.30818 .5 L
.3072 .51961 L
.31758 .53922 L
.32353 .54825 L
.33177 .55882 L
.34144 .57843 L
.34314 .58478 L
.34657 .59804 L
.34673 .61765 L
.34314 .6286 L
.34026 .63725 L
.32353 .64671 L
.30392 .64929 L
.28431 .64378 L
.27194 .63725 L
.26471 .62801 L
.26047 .61765 L
.25605 .59804 L
.25755 .57843 L
.26334 .55882 L
.26471 .5553 L
.27072 .53922 L
.27427 .51961 L
.26668 .5 L
.26471 .49609 L
.25208 .48039 L
.24549 .46078 L
.2451 .45634 L
.2427 .44118 L
.2451 .42313 L
.24534 .42157 L
.25555 .40196 L
.26471 .39385 L
.28424 .38235 L
.28431 .38232 L
s
.36275 .25008 m
.38235 .24597 L
.40196 .24844 L
.42157 .25992 L
.42543 .26471 L
.43495 .28431 L
.43157 .30392 L
.42157 .31899 L
.41773 .32353 L
.40196 .33619 L
.39078 .34314 L
.38235 .34611 L
.36275 .3529 L
.34314 .35596 L
.32972 .34314 L
.32682 .32353 L
.32791 .30392 L
.33265 .28431 L
.34314 .26616 L
.34358 .26471 L
.36275 .25008 L
s
.53922 .24491 m
.55882 .23222 L
.57843 .22867 L
.59804 .232 L
.61765 .24451 L
.61828 .2451 L
.63331 .26471 L
.63725 .27076 L
.64169 .28431 L
.64815 .30392 L
.65686 .32194 L
.65831 .32353 L
.67647 .33297 L
.69608 .33815 L
.71218 .34314 L
.71569 .34439 L
.73529 .35452 L
.74545 .36275 L
.7549 .37355 L
.7585 .38235 L
.76317 .40196 L
.76089 .42157 L
.7549 .43537 L
.75219 .44118 L
.73529 .45722 L
.72915 .46078 L
.71569 .46505 L
.69608 .46294 L
.69098 .46078 L
.67647 .44969 L
.66869 .44118 L
.65736 .42157 L
.65686 .42091 L
.64972 .40196 L
.64413 .38235 L
.63789 .36275 L
.63725 .36145 L
.61765 .34507 L
.61154 .34314 L
.59804 .33963 L
.57843 .33381 L
.55882 .32501 L
.55616 .32353 L
.53922 .31194 L
.53288 .30392 L
.52311 .28431 L
.52513 .26471 L
.53903 .2451 L
.53922 .24491 L
s
.44118 .67466 m
.46078 .67275 L
.48039 .67462 L
.48803 .67647 L
.5 .68055 L
.51961 .69327 L
.52228 .69608 L
.53382 .71569 L
.53607 .73529 L
.53191 .7549 L
.52076 .77451 L
.51961 .77597 L
.5 .79198 L
.49523 .79412 L
.48039 .79852 L
.46078 .79859 L
.44554 .79412 L
.44118 .79218 L
.42157 .77662 L
.41982 .77451 L
.40811 .7549 L
.40251 .73529 L
.40196 .73149 L
.40142 .71569 L
.40196 .71069 L
.40656 .69608 L
.42157 .68119 L
.43225 .67647 L
.44118 .67466 L
s
.69608 .53561 m
.71375 .53922 L
.71569 .5404 L
.73529 .55662 L
.73816 .55882 L
.7526 .57843 L
.7549 .58215 L
.76154 .59804 L
.76569 .61765 L
.76503 .63725 L
.759 .65686 L
.7549 .66508 L
.7458 .67647 L
.73529 .68547 L
.71569 .69533 L
.71322 .69608 L
.69608 .69911 L
.67647 .69795 L
.66851 .69608 L
.65686 .69195 L
.63725 .67929 L
.63444 .67647 L
.62168 .65686 L
.61765 .63725 L
.61917 .61765 L
.62529 .59804 L
.63645 .57843 L
.63725 .57732 L
.65377 .55882 L
.65686 .55641 L
.67647 .54276 L
.68316 .53922 L
.69608 .53561 L
s
.36275 .23738 m
.38235 .23368 L
.40196 .23586 L
.42157 .24367 L
.42402 .2451 L
.44118 .25576 L
.44841 .26471 L
.45633 .28431 L
.44934 .30392 L
.44118 .3183 L
.43633 .32353 L
.42157 .33745 L
.41382 .34314 L
.40196 .35096 L
.38235 .36257 L
.38211 .36275 L
.36275 .37622 L
.35745 .38235 L
.34828 .40196 L
.34435 .42157 L
.34314 .42881 L
.34117 .44118 L
.33739 .46078 L
.33323 .48039 L
.33051 .5 L
.33237 .51961 L
.33938 .53922 L
.34314 .54864 L
.34827 .55882 L
.35659 .57843 L
.36207 .59804 L
.36275 .60182 L
.36431 .61765 L
.36275 .63391 L
.36188 .63725 L
.34688 .65686 L
.34314 .6589 L
.32353 .66456 L
.30392 .66468 L
.28431 .65976 L
.27661 .65686 L
.26471 .64811 L
.25487 .63725 L
.2455 .61765 L
.2451 .61616 L
.24217 .59804 L
.24305 .57843 L
.2451 .56163 L
.24625 .55882 L
.24912 .53922 L
Mistroke
.24886 .51961 L
.2451 .50049 L
.24493 .5 L
.23727 .48039 L
.23112 .46078 L
.22857 .44118 L
.23068 .42157 L
.239 .40196 L
.2451 .39314 L
.25543 .38235 L
.26471 .37507 L
.28195 .36275 L
.28431 .36109 L
.30186 .34314 L
.30392 .33938 L
.3095 .32353 L
.31403 .30392 L
.31968 .28431 L
.32353 .27416 L
.32902 .26471 L
.34314 .24853 L
.34588 .2451 L
.36275 .23738 L
Mfstroke
.55882 .21953 m
.57843 .21658 L
.59804 .21943 L
.6152 .22549 L
.61765 .22889 L
.63483 .2451 L
.63725 .24813 L
.64761 .26471 L
.65686 .28292 L
.65757 .28431 L
.66991 .30392 L
.67647 .31049 L
.69608 .32224 L
.69897 .32353 L
.71569 .33058 L
.73529 .34053 L
.7395 .34314 L
.7549 .35583 L
.76069 .36275 L
.77125 .38235 L
.77451 .39675 L
.77498 .40196 L
.77451 .41385 L
.77324 .42157 L
.76612 .44118 L
.7549 .45788 L
.75299 .46078 L
.73529 .47602 L
.72898 .48039 L
.71569 .48633 L
.69608 .48495 L
.68806 .48039 L
.67647 .46977 L
.66691 .46078 L
.65686 .44605 L
.65381 .44118 L
.64369 .42157 L
.63725 .40642 L
.63543 .40196 L
.62629 .38235 L
.61765 .37035 L
.60886 .36275 L
.59804 .35645 L
.57843 .34787 L
.56726 .34314 L
.55882 .33916 L
.53922 .32789 L
.53333 .32353 L
.51961 .31356 L
.51495 .30392 L
Mistroke
.50044 .28431 L
.50525 .26471 L
.51897 .2451 L
.51961 .2442 L
.53922 .22818 L
.54243 .22549 L
.55882 .21953 L
Mfstroke
.57843 .20494 m
.59066 .20588 L
.59804 .20736 L
.61765 .21529 L
.63211 .22549 L
.63725 .23049 L
.64939 .2451 L
.65686 .25643 L
.6618 .26471 L
.67408 .28431 L
.67647 .28751 L
.69342 .30392 L
.69608 .30577 L
.71569 .31676 L
.72898 .32353 L
.73529 .327 L
.7549 .34042 L
.75804 .34314 L
.77449 .36275 L
.77451 .36277 L
.78329 .38235 L
.78656 .40196 L
.78509 .42157 L
.7791 .44118 L
.77451 .45105 L
.76876 .46078 L
.7549 .47951 L
.75439 .48039 L
.74025 .5 L
.73529 .5112 L
.73518 .51961 L
.73529 .52016 L
.7442 .53922 L
.7549 .55749 L
.75614 .55882 L
.76688 .57843 L
.77419 .59804 L
.77451 .59924 L
.77768 .61765 L
.77711 .63725 L
.77451 .64948 L
.77205 .65686 L
.76128 .67647 L
.7549 .68421 L
.74114 .69608 L
.73529 .69964 L
.71569 .70792 L
.69608 .71125 L
.67647 .71048 L
.65686 .70592 L
Mistroke
.63725 .69729 L
.63534 .69608 L
.61765 .68261 L
.61354 .67647 L
.60437 .65686 L
.60284 .63725 L
.60563 .61765 L
.61183 .59804 L
.61765 .5851 L
.62162 .57843 L
.63551 .55882 L
.63725 .55682 L
.65263 .53922 L
.65686 .53469 L
.66712 .51961 L
.67081 .5 L
.66194 .48039 L
.65686 .46949 L
.65062 .46078 L
.63984 .44118 L
.63725 .43602 L
.63032 .42157 L
.62069 .40196 L
.61765 .3966 L
.60717 .38235 L
.59804 .37402 L
.57963 .36275 L
.57843 .36213 L
.55882 .35255 L
.54072 .34314 L
.53922 .34232 L
.51961 .33076 L
.50794 .32353 L
.5 .32026 L
.48039 .31663 L
.46078 .32329 L
.45902 .32353 L
.44118 .33791 L
.43392 .34314 L
.42157 .3524 L
.40655 .36275 L
.40196 .36582 L
.38235 .3806 L
.38049 .38235 L
.36594 .40196 L
.36275 .40952 L
.35904 .42157 L
.35465 .44118 L
.35084 .46078 L
.34757 .48039 L
Mistroke
.34621 .5 L
.3486 .51961 L
.35497 .53922 L
.36275 .5581 L
.36306 .55882 L
.37079 .57843 L
.37697 .59804 L
.38171 .61765 L
.38235 .61913 L
.38595 .63725 L
.3981 .65686 L
.40196 .65826 L
.42157 .65935 L
.44118 .6587 L
.46078 .65901 L
.48039 .66125 L
.5 .6661 L
.51961 .67453 L
.52275 .67647 L
.53922 .68907 L
.54359 .69608 L
.55116 .71569 L
.5511 .73529 L
.54619 .7549 L
.53922 .77127 L
.53646 .77451 L
.51961 .79359 L
.51903 .79412 L
.5 .80571 L
.48039 .8111 L
.46078 .81114 L
.44118 .80583 L
.42189 .79412 L
.42157 .79382 L
.40431 .77451 L
.40196 .77123 L
.39403 .7549 L
.38745 .73529 L
.38278 .71569 L
.38235 .71452 L
.37792 .69608 L
.36275 .68225 L
.34314 .68108 L
.32353 .68093 L
.30392 .67911 L
.29164 .67647 L
.28431 .67425 L
.26471 .66457 L
.25471 .65686 L
.2451 .64619 L
Mistroke
.23957 .63725 L
.23192 .61765 L
.22913 .59804 L
.22965 .57843 L
.23194 .55882 L
.23389 .53922 L
.23319 .51961 L
.22903 .5 L
.22549 .48753 L
.22318 .48039 L
.21813 .46078 L
.21594 .44118 L
.21775 .42157 L
.22454 .40196 L
.22549 .39995 L
.23754 .38235 L
.2451 .37434 L
.25803 .36275 L
.26471 .35724 L
.27989 .34314 L
.28431 .33788 L
.29302 .32353 L
.30048 .30392 L
.30392 .29343 L
.30704 .28431 L
.31587 .26471 L
.32353 .25277 L
.3301 .2451 L
.34314 .23443 L
.36211 .22549 L
.36275 .22535 L
.38235 .22222 L
.40196 .22391 L
.41229 .22549 L
.42157 .22967 L
.44118 .23866 L
.45366 .2451 L
.46078 .24677 L
.48039 .2507 L
.4931 .2451 L
.5 .24026 L
.51961 .22617 L
.52069 .22549 L
.53922 .21448 L
.55882 .20736 L
.56651 .20588 L
.57843 .20494 L
Mfstroke
.46078 .34207 m
.48039 .33586 L
.5 .33822 L
.51264 .34314 L
.51961 .34645 L
.53922 .35644 L
.55162 .36275 L
.55882 .36644 L
.57843 .37753 L
.58535 .38235 L
.59804 .39392 L
.60448 .40196 L
.61616 .42157 L
.61765 .42446 L
.62585 .44118 L
.63528 .46078 L
.63725 .46296 L
.64382 .48039 L
.6484 .5 L
.64448 .51961 L
.63725 .53595 L
.63281 .53922 L
.61895 .55882 L
.61765 .56077 L
.60693 .57843 L
.59804 .59675 L
.59753 .59804 L
.59066 .61765 L
.58529 .63725 L
.58009 .65686 L
.57843 .66106 L
.55882 .67132 L
.53922 .66427 L
.51961 .6573 L
.51819 .65686 L
.5 .65168 L
.48039 .64764 L
.46078 .64483 L
.44118 .64223 L
.42227 .63725 L
.42157 .63695 L
.40196 .61836 L
.40155 .61765 L
.39272 .59804 L
.3853 .57843 L
.38235 .57074 L
.37756 .55882 L
.3698 .53922 L
.36371 .51961 L
.36275 .515 L
Mistroke
.36094 .5 L
.36151 .48039 L
.36275 .47006 L
.36422 .46078 L
.36818 .44118 L
.37381 .42157 L
.38235 .40374 L
.38354 .40196 L
.40183 .38235 L
.40196 .38224 L
.42157 .36748 L
.42824 .36275 L
.44118 .35403 L
.45811 .34314 L
.46078 .34207 L
Mfstroke
.53922 .20126 m
.55882 .19518 L
.57843 .19309 L
.59804 .19522 L
.61765 .20204 L
.62512 .20588 L
.63725 .21465 L
.64866 .22549 L
.65686 .23527 L
.66394 .2451 L
.67647 .26395 L
.67698 .26471 L
.69262 .28431 L
.69608 .28763 L
.71569 .30192 L
.71908 .30392 L
.73529 .31315 L
.75201 .32353 L
.7549 .32559 L
.77444 .34314 L
.77451 .34321 L
.78798 .36275 L
.79412 .37612 L
.7955 .38235 L
.79832 .40196 L
.79708 .42157 L
.79412 .43465 L
.79203 .44118 L
.78341 .46078 L
.77451 .47649 L
.77239 .48039 L
.76232 .5 L
.75866 .51961 L
.76347 .53922 L
.77229 .55882 L
.77451 .56369 L
.78085 .57843 L
.78705 .59804 L
.79008 .61765 L
.78958 .63725 L
.78518 .65686 L
.77614 .67647 L
.77451 .67914 L
.76054 .69608 L
.7549 .70108 L
.73529 .71366 L
.73194 .71569 L
.71569 .72073 L
.69608 .72372 L
.67647 .72331 L
Mistroke
.65686 .71997 L
.64163 .71569 L
.63725 .71423 L
.61765 .70678 L
.59804 .69911 L
.57843 .70521 L
.5738 .71569 L
.56828 .73529 L
.56154 .7549 L
.55882 .76183 L
.55181 .77451 L
.53922 .79204 L
.53729 .79412 L
.51961 .80924 L
.51287 .81373 L
.5 .81908 L
.48039 .82367 L
.46078 .8237 L
.44118 .81917 L
.42806 .81373 L
.42157 .80936 L
.4038 .79412 L
.40196 .79209 L
.38934 .77451 L
.38235 .76166 L
.37931 .7549 L
.3709 .73529 L
.36275 .71973 L
.3599 .71569 L
.34314 .70306 L
.32353 .69755 L
.31624 .69608 L
.30392 .69371 L
.28431 .68846 L
.26471 .67992 L
.25879 .67647 L
.2451 .66567 L
.23701 .65686 L
.22549 .63826 L
.22506 .63725 L
.21871 .61765 L
.21627 .59804 L
.21658 .57843 L
.21827 .55882 L
.21951 .53922 L
.21849 .51961 L
.2147 .5 L
.20958 .48039 L
.20588 .46502 L
.2053 .46078 L
Mistroke
.20343 .44118 L
.20496 .42157 L
.20588 .41707 L
.21068 .40196 L
.22158 .38235 L
.22549 .37708 L
.23856 .36275 L
.2451 .35655 L
.25949 .34314 L
.26471 .33787 L
.27612 .32353 L
.28431 .30848 L
.28635 .30392 L
.29415 .28431 L
.30278 .26471 L
.30392 .26246 L
.31506 .2451 L
.32353 .23556 L
.33557 .22549 L
.34314 .22103 L
.36275 .21332 L
.38235 .21058 L
.40196 .21191 L
.42157 .2166 L
.44118 .22335 L
.44739 .22549 L
.46078 .2291 L
.48039 .22922 L
.49231 .22549 L
.5 .22177 L
.51961 .21075 L
.52883 .20588 L
.53922 .20126 L
Mfstroke
.46078 .35962 m
.48039 .35392 L
.5 .35537 L
.51961 .36222 L
.52092 .36275 L
.53922 .37137 L
.55882 .38197 L
.55948 .38235 L
.57843 .39552 L
.58529 .40196 L
.59804 .41818 L
.60017 .42157 L
.61075 .44118 L
.61765 .45615 L
.61949 .46078 L
.62637 .48039 L
.62895 .5 L
.62458 .51961 L
.61765 .53528 L
.61431 .53922 L
.60217 .55882 L
.59804 .56573 L
.59106 .57843 L
.58117 .59804 L
.57843 .60352 L
.57197 .61765 L
.55882 .63397 L
.55391 .63725 L
.53922 .64096 L
.51961 .63951 L
.50602 .63725 L
.5 .63618 L
.48039 .63277 L
.46078 .62915 L
.44118 .62367 L
.42925 .61765 L
.42157 .61122 L
.41131 .59804 L
.40196 .57962 L
.40141 .57843 L
.39286 .55882 L
.38514 .53922 L
.38235 .53205 L
.37907 .51961 L
.3759 .5 L
.37592 .48039 L
.37839 .46078 L
.38235 .44248 L
.38278 .44118 L
.38984 .42157 L
Mistroke
.40196 .40263 L
.40254 .40196 L
.42157 .38422 L
.42398 .38235 L
.44118 .37044 L
.45319 .36275 L
.46078 .35962 L
Mfstroke
.55882 .18225 m
.57843 .18045 L
.59804 .1823 L
.61547 .18627 L
.61765 .18817 L
.63725 .19893 L
.6464 .20588 L
.65686 .21586 L
.66525 .22549 L
.67647 .24037 L
.67978 .2451 L
.6944 .26471 L
.69608 .26668 L
.71483 .28431 L
.71569 .28496 L
.73529 .29792 L
.7452 .30392 L
.7549 .31017 L
.77252 .32353 L
.77451 .32531 L
.79061 .34314 L
.79412 .34803 L
.80198 .36275 L
.80851 .38235 L
.81103 .40196 L
.80995 .42157 L
.80555 .44118 L
.79827 .46078 L
.79412 .46981 L
.78926 .48039 L
.78123 .5 L
.77815 .51961 L
.78145 .53922 L
.78839 .55882 L
.79412 .57422 L
.79554 .57843 L
.80082 .59804 L
.80345 .61765 L
.803 .63725 L
.79919 .65686 L
.79412 .67155 L
.79149 .67647 L
.77871 .69608 L
.77451 .70095 L
.75798 .71569 L
.7549 .71781 L
.73529 .72833 L
.71569 .73456 L
.71213 .73529 L
.69608 .73729 L
Mistroke
.67647 .73724 L
.65853 .73529 L
.65686 .73505 L
.63725 .73171 L
.61765 .72953 L
.59804 .73444 L
.59625 .73529 L
.58019 .7549 L
.57843 .75845 L
.56865 .77451 L
.55882 .78947 L
.55517 .79412 L
.53922 .81099 L
.53602 .81373 L
.51961 .82479 L
.5 .83316 L
.49942 .83333 L
.48039 .83706 L
.46078 .83709 L
.44153 .83333 L
.44118 .83323 L
.42157 .82486 L
.40515 .81373 L
.40196 .81094 L
.38639 .79412 L
.38235 .78871 L
.37341 .77451 L
.36275 .75526 L
.36255 .7549 L
.35027 .73529 L
.34314 .72773 L
.32353 .7159 L
.32297 .71569 L
.30392 .70947 L
.28431 .7035 L
.26562 .69608 L
.26471 .69562 L
.2451 .68368 L
.23644 .67647 L
.22549 .66456 L
.22009 .65686 L
.21023 .63725 L
.20588 .62432 L
.20479 .61765 L
.20266 .59804 L
.20282 .57843 L
.20405 .55882 L
.2048 .53922 L
.20361 .51961 L
.20016 .5 L
Mistroke
.19566 .48039 L
.19188 .46078 L
.19022 .44118 L
.19156 .42157 L
.19652 .40196 L
.20575 .38235 L
.20588 .38213 L
.22017 .36275 L
.22549 .35689 L
.23921 .34314 L
.2451 .33736 L
.25774 .32353 L
.26471 .31402 L
.27078 .30392 L
.28008 .28431 L
.28431 .27459 L
.28891 .26471 L
.3 .2451 L
.30392 .23949 L
.31629 .22549 L
.32353 .21926 L
.34314 .20721 L
.34494 .20588 L
.36275 .20067 L
.38235 .19826 L
.40196 .19931 L
.42157 .20309 L
.43176 .20588 L
.44118 .20828 L
.46078 .21224 L
.48039 .21143 L
.49751 .20588 L
.5 .20483 L
.51961 .19562 L
.53922 .18746 L
.54108 .18627 L
.55882 .18225 L
Mfstroke
.46078 .37827 m
.48039 .37263 L
.5 .37349 L
.51961 .3796 L
.52658 .38235 L
.53922 .38867 L
.55882 .40083 L
.56035 .40196 L
.57843 .41902 L
.58047 .42157 L
.59301 .44118 L
.59804 .4511 L
.6018 .46078 L
.60765 .48039 L
.60892 .5 L
.60413 .51961 L
.59804 .534 L
.5946 .53922 L
.5833 .55882 L
.57843 .5671 L
.57206 .57843 L
.55917 .59804 L
.55882 .59847 L
.53922 .61513 L
.53156 .61765 L
.51961 .61916 L
.5 .61819 L
.4955 .61765 L
.48039 .61523 L
.46078 .61028 L
.44118 .60058 L
.43775 .59804 L
.42157 .5789 L
.42127 .57843 L
.41066 .55882 L
.40247 .53922 L
.40196 .53801 L
.39606 .51961 L
.39249 .5 L
.39208 .48039 L
.39448 .46078 L
.39966 .44118 L
.40196 .43483 L
.40871 .42157 L
.42157 .40527 L
.42499 .40196 L
.44118 .38916 L
.45128 .38235 L
.46078 .37827 L
s
.57843 .1659 m
.59204 .16667 L
.59804 .16752 L
.61765 .17273 L
.63725 .18189 L
.64437 .18627 L
.65686 .19599 L
.6672 .20588 L
.67647 .21632 L
.68369 .22549 L
.69608 .24178 L
.69861 .2451 L
.71569 .26407 L
.71636 .26471 L
.73529 .27976 L
.74218 .28431 L
.7549 .29267 L
.77123 .30392 L
.77451 .30645 L
.79317 .32353 L
.79412 .32456 L
.808 .34314 L
.81373 .35322 L
.81767 .36275 L
.82327 .38235 L
.82548 .40196 L
.82455 .42157 L
.82077 .44118 L
.81466 .46078 L
.81373 .46329 L
.80709 .48039 L
.80049 .5 L
.79788 .51961 L
.80033 .53922 L
.80597 .55882 L
.81206 .57843 L
.81373 .58376 L
.81661 .59804 L
.81886 .61765 L
.81848 .63725 L
.81521 .65686 L
.81373 .66296 L
.80853 .67647 L
.79787 .69608 L
.79412 .70149 L
.78176 .71569 L
.77451 .72231 L
.75612 .73529 L
.7549 .73597 L
.73529 .74486 L
Mistroke
.71569 .75034 L
.69608 .75296 L
.67647 .75331 L
.65686 .75226 L
.63725 .7514 L
.61765 .75403 L
.6152 .7549 L
.59804 .76636 L
.59025 .77451 L
.57843 .79028 L
.5754 .79412 L
.55882 .81347 L
.55857 .81373 L
.53922 .83036 L
.53495 .83333 L
.51961 .84174 L
.5 .84888 L
.48039 .85235 L
.46078 .85237 L
.44118 .84894 L
.42157 .8418 L
.40622 .83333 L
.40196 .83032 L
.38315 .81373 L
.38235 .81288 L
.36739 .79412 L
.36275 .78733 L
.35469 .77451 L
.34314 .75744 L
.34124 .7549 L
.32353 .73815 L
.31888 .73529 L
.30392 .72804 L
.28431 .72075 L
.27092 .71569 L
.26471 .713 L
.2451 .70257 L
.23558 .69608 L
.22549 .68754 L
.21514 .67647 L
.20588 .66363 L
.2021 .65686 L
.19387 .63725 L
.18915 .61765 L
.18722 .59804 L
.18726 .57843 L
.18818 .55882 L
.18858 .53922 L
.18725 .51961 L
.18627 .51038 L
Mistroke
.18411 .5 L
.18017 .48039 L
.17687 .46078 L
.1754 .44118 L
.17655 .42157 L
.18081 .40196 L
.18627 .38696 L
.18869 .38235 L
.20098 .36275 L
.20588 .35643 L
.21774 .34314 L
.22549 .33515 L
.2366 .32353 L
.2451 .31368 L
.25229 .30392 L
.26353 .28431 L
.26471 .28189 L
.27311 .26471 L
.28345 .2451 L
.28431 .24362 L
.29725 .22549 L
.30392 .21809 L
.31789 .20588 L
.32353 .20206 L
.34314 .192 L
.36234 .18627 L
.36275 .18622 L
.38235 .18416 L
.40196 .18495 L
.41731 .18627 L
.42157 .18802 L
.44118 .19209 L
.46078 .19471 L
.48039 .19322 L
.5 .18712 L
.50231 .18627 L
.51961 .17922 L
.53922 .17214 L
.55882 .16748 L
.56483 .16667 L
.57843 .1659 L
Mfstroke
.46078 .40161 m
.48039 .39518 L
.5 .39552 L
.51961 .40154 L
.52073 .40196 L
.53922 .41158 L
.55243 .42157 L
.55882 .42767 L
.56932 .44118 L
.57843 .45855 L
.57923 .46078 L
.58476 .48039 L
.58508 .5 L
.57974 .51961 L
.57843 .52326 L
.57045 .53922 L
.55882 .55809 L
.55839 .55882 L
.54331 .57843 L
.53922 .58191 L
.51961 .59261 L
.5 .59466 L
.48039 .59194 L
.46078 .5842 L
.45171 .57843 L
.44118 .56727 L
.43492 .55882 L
.42451 .53922 L
.42157 .53236 L
.41736 .51961 L
.41314 .5 L
.41236 .48039 L
.41506 .46078 L
.42157 .44148 L
.42183 .44118 L
.43439 .42157 L
.44118 .41476 L
.45997 .40196 L
.46078 .40161 L
s
.38235 .16638 m
.39781 .16667 L
.40196 .16697 L
.42157 .16946 L
.44118 .17248 L
.46078 .17395 L
.48039 .17184 L
.4993 .16667 L
.5 .16613 L
.51961 .1593 L
.53922 .15315 L
.55882 .14906 L
.57843 .14763 L
.59804 .14907 L
.61765 .15358 L
.63725 .16134 L
.64744 .16667 L
.65686 .17294 L
.67321 .18627 L
.67647 .18941 L
.69152 .20588 L
.69608 .21137 L
.70722 .22549 L
.71569 .23561 L
.72433 .2451 L
.73529 .25532 L
.74741 .26471 L
.7549 .27011 L
.77451 .28359 L
.77555 .28431 L
.79412 .29905 L
.79946 .30392 L
.81373 .31943 L
.81682 .32353 L
.829 .34314 L
.83333 .35201 L
.83709 .36275 L
.84184 .38235 L
.84375 .40196 L
.84297 .42157 L
.83976 .44118 L
.83469 .46078 L
.83333 .46523 L
.82842 .48039 L
.823 .5 L
.82084 .51961 L
.82279 .53922 L
.82748 .55882 L
.83267 .57843 L
.83333 .58078 L
Mistroke
.83648 .59804 L
.83841 .61765 L
.83808 .63725 L
.8353 .65686 L
.83333 .66594 L
.82965 .67647 L
.82071 .69608 L
.81373 .70779 L
.80793 .71569 L
.79412 .73107 L
.78955 .73529 L
.77451 .74685 L
.76126 .7549 L
.7549 .75796 L
.73529 .7655 L
.71569 .77034 L
.69608 .7729 L
.67647 .77381 L
.65686 .77423 L
.65138 .77451 L
.63725 .77625 L
.61765 .78376 L
.60367 .79412 L
.59804 .8003 L
.58538 .81373 L
.57843 .82132 L
.56601 .83333 L
.55882 .83944 L
.53947 .85294 L
.53922 .85309 L
.51961 .86239 L
.5 .86849 L
.48039 .87149 L
.46078 .8715 L
.44118 .86853 L
.42157 .86245 L
.40196 .85307 L
.40173 .85294 L
.38235 .83908 L
.37586 .83333 L
.36275 .81956 L
.35798 .81373 L
.34332 .79412 L
.34314 .79386 L
.32872 .77451 L
.32353 .76879 L
.30693 .7549 L
.30392 .75298 L
.28431 .74296 L
.26598 .73529 L
Mistroke
.26471 .73473 L
.2451 .72511 L
.22944 .71569 L
.22549 .71284 L
.20644 .69608 L
.20588 .69549 L
.19106 .67647 L
.18627 .66867 L
.18062 .65686 L
.17373 .63725 L
.16967 .61765 L
.16795 .59804 L
.16789 .57843 L
.16853 .55882 L
.16865 .53922 L
.16726 .51961 L
.16667 .51372 L
.16446 .5 L
.16104 .48039 L
.15818 .46078 L
.1569 .44118 L
.15787 .42157 L
.16148 .40196 L
.16667 .38538 L
.16805 .38235 L
.17848 .36275 L
.18627 .35121 L
.1927 .34314 L
.20588 .32826 L
.21031 .32353 L
.22549 .3068 L
.22788 .30392 L
.24189 .28431 L
.2451 .2787 L
.25286 .26471 L
.26311 .2451 L
.26471 .24212 L
.27526 .22549 L
.28431 .21352 L
.29126 .20588 L
.30392 .19448 L
.31531 .18627 L
.32353 .18168 L
.34314 .17329 L
.36275 .1683 L
.3763 .16667 L
.38235 .16638 L
Mfstroke
.48039 .43162 m
.5 .43077 L
.51961 .43892 L
.52348 .44118 L
.53922 .45754 L
.54095 .46078 L
.54847 .48039 L
.54817 .5 L
.54088 .51961 L
.53922 .52291 L
.52918 .53922 L
.51961 .54582 L
.5 .55348 L
.48039 .54997 L
.46614 .53922 L
.46078 .53362 L
.45227 .51961 L
.44604 .5 L
.44496 .48039 L
.44911 .46078 L
.46078 .44281 L
.46409 .44118 L
.48039 .43162 L
s
.53922 .12376 m
.55882 .12057 L
.57843 .11941 L
.59804 .12054 L
.61765 .12397 L
.6311 .12745 L
.63725 .12992 L
.65686 .13935 L
.66994 .14706 L
.67647 .15182 L
.69414 .16667 L
.69608 .16854 L
.71266 .18627 L
.71569 .18973 L
.72922 .20588 L
.73529 .2127 L
.74752 .22549 L
.7549 .23228 L
.77112 .2451 L
.77451 .24768 L
.79412 .26207 L
.79777 .26471 L
.81373 .27794 L
.82066 .28431 L
.83333 .29781 L
.83816 .30392 L
.8514 .32353 L
.85294 .32618 L
.86056 .34314 L
.86725 .36275 L
.87141 .38235 L
.87255 .39245 L
.87297 .40196 L
.87255 .41989 L
.87241 .42157 L
.86967 .44118 L
.86533 .46078 L
.8604 .48039 L
.85647 .5 L
.85504 .51961 L
.85662 .53922 L
.86031 .55882 L
.86451 .57843 L
.86787 .59804 L
.86958 .61765 L
.8693 .63725 L
.86685 .65686 L
.86214 .67647 L
.85526 .69608 L
.85294 .70165 L
Mistroke
.84533 .71569 L
.83333 .73383 L
.83218 .73529 L
.81428 .7549 L
.81373 .75542 L
.79412 .77118 L
.78927 .77451 L
.77451 .78282 L
.7549 .79175 L
.74864 .79412 L
.73529 .79775 L
.71569 .80176 L
.69608 .80438 L
.67647 .80637 L
.65686 .80934 L
.64148 .81373 L
.63725 .8158 L
.61765 .82843 L
.61158 .83333 L
.59804 .84565 L
.58982 .85294 L
.57843 .86237 L
.56467 .87255 L
.55882 .87614 L
.53922 .88663 L
.52627 .89216 L
.51961 .89415 L
.5 .89875 L
.48039 .90112 L
.46078 .90114 L
.44118 .89879 L
.42157 .8942 L
.41475 .89216 L
.40196 .88665 L
.38235 .87601 L
.37685 .87255 L
.36275 .86163 L
.35306 .85294 L
.34314 .84277 L
.33501 .83333 L
.32353 .81949 L
.31907 .81373 L
.30392 .79674 L
.3013 .79412 L
.28431 .78042 L
.27415 .77451 L
.26471 .76931 L
.2451 .75954 L
.23555 .7549 L
.22549 .7491 L
Mistroke
.20588 .7362 L
.20465 .73529 L
.18627 .71897 L
.18316 .71569 L
.16747 .69608 L
.16667 .69491 L
.15633 .67647 L
.1479 .65686 L
.14706 .65458 L
.14275 .63725 L
.1396 .61765 L
.13819 .59804 L
.13806 .57843 L
.13841 .55882 L
.13829 .53922 L
.13695 .51961 L
.13434 .5 L
.13124 .48039 L
.12869 .46078 L
.12755 .44118 L
.12838 .42157 L
.13151 .40196 L
.13714 .38235 L
.14514 .36275 L
.14706 .35867 L
.15659 .34314 L
.16667 .329 L
.17116 .32353 L
.18627 .30623 L
.18837 .30392 L
.20532 .28431 L
.20588 .28358 L
.2196 .26471 L
.22549 .25449 L
.23111 .2451 L
.24239 .22549 L
.2451 .22073 L
.2554 .20588 L
.26471 .19393 L
.27179 .18627 L
.28431 .17478 L
.29476 .16667 L
.30392 .16104 L
.32353 .151 L
.33319 .14706 L
.34314 .14447 L
.36275 .14074 L
.38235 .13915 L
.40196 .13948 L
.42157 .14106 L
Mistroke
.44118 .14272 L
.46078 .14288 L
.48039 .14021 L
.5 .13484 L
.51961 .12852 L
.52302 .12745 L
.53922 .12376 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0P000012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool300000003ooooo`00003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`8000000oooool00onY_NP000000000
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3000000;ooooo1?nY_NP00`00003ooooo00000010ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0P?ooool3000000;ooooo1onY_NP00`00003ooooo0000
0010ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0O_oo
ool2000000?ooooo2OnY_NP01000003oZKgXooooo`00000oooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0Noooool3000000;ooooo3?nY_NP01@00003oZKgX
ooooooooool0000003kooooo0009ooooo`0400000?oooooooooooooooel00000300I6AT300000003
o`0000000000000003`000001?ooool00`00003oooooooooo`1iooooo`8000000oooool>ojVmj005
00000?nY_NSoZKgXooooo`000000?_ooool000Wooooo00@00000ooooooooooooooooFP0000000ol0
00006ATI01TI6@0B01TI6Ch000001?ooool00`00003oooooooooo`1fooooo`<000000_oooolAojVm
j00600000?nY_NSoZKgXojVmj?ooool00000?Oooool000Wooooo00@00000ooooooooooooooooF000
000I01TI6C`000001?ooool00`00003oooooooooo`1dooooo`8000000_oooolDojVmj00300000?nY
_NSoZKgX00;oZKgX00<00000ooooooooool0>oooool000Wooooo00@00000ooooooooooooooooE@00
000M01TI6C/000001?ooool00`00003oooooooooo`1aooooo`<000000_oooolFojVmj00300000?nY
_NSoZKgX00?oZKgX00<00000ooooooooool0>_ooool000Wooooo00@00000oooooooooooooooo>P00
000U01TI6@`000002P0I6AT00ol0000000000000000e000000Cooooo00<00000ooooooooool0K_oo
ool3000000;ooooo6OnY_NP00`00003oZKgXojVmj003ojVmj003ooooo`00003ooooo03[ooooo0009
ooooo`0400000?ooooooooooooooocP00000900I6AT3000000`0<c<c0`00000801TI6CL000001?oo
ool00`00003oooooooooo`1/ooooo`8000000ooooolLojVmj00300000?nY_NSoZKgX00?oZKgX00<0
0000ooooooooool0>Oooool000Wooooo00@00000oooooooooooooooo=P00000R01TI6@@000004P0c
<c<3000000L06ATI=@000004ooooo`0300000?oooooooooo06Wooooo0`000002oooooaooZKgX00<0
0000ojVmj?nY_NP00onY_NP00oooool00000ooooo`0iooooo`002Oooool01000003ooooooooooooo
oolc000000d06ATI00D00000o`000?l000000000o`000003000000d06ATI0`00000:03<c<`D00000
00?o000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0501TI6@03o`0000000000000003400000
1?ooool00`00003oooooooooo`1Wooooo`8000000ooooolQojVmj00300000?nY_NSoZKgX00CoZKgX
00?ooooo00000?ooool0>?ooool000Wooooo00@00000oooooooooooooooo<P00000;01TI6@<00000
200c<c<7000000<06ATI0`00000703<c<`D0000000?o000004a<C01<C4`0101<C4`3000000H0<c<c
00<0000001TI6@0I6AT01@0I6ATd000000Cooooo00<00000ooooooooool0I?ooool3000000;ooooo
9?nY_NP00`00003oZKgXojVmj004ojVmj003ooooo`00003ooooo03Sooooo0009ooooo`0400000?oo
oooooooooooooc400000200I6AT400000180<c<c0`00000903<c<`030000001<C4`0C4a<00d0C4a<
0`00000403<c<`8000001P0I6ATc000000Cooooo00<00000ooooooooool0H_ooool2000000?ooooo
9_nY_NP00`00003oZKgXojVmj005ojVmj003ooooo`00003ooooo03Oooooo0009ooooo`0400000?oo
oooooooooooooc0000001`0I6AT200000200<c<c0P00000504a<C0/000000`1<C4`00`00003o0000
03<c<`0303<c<`030000000I6AT06ATI00@06ATI<P000004ooooo`0300000?oooooooooo05oooooo
0`000002ooooo`;oZKgW1?nY_NP2ojVmib7oZKgX00<00000ojVmj?nY_NP01_nY_NP00oooool00000
ooooo`0fooooo`002Oooool01000003oooooooooooooool_000000H06ATI00<00000o`00000c<c<0
1@0c<c<;00000004o`00000000000000000000T0<c<c00@00000o`000000000000000`1<C4`01000
003o000000000000000;06IVIP8000000`1<C4`00`000000<c<c03<c<`0203<c<`03o`0000000000
6ATI00@06ATI00?o0000000000000000;P000004ooooo`0300000?oooooooooo05gooooo0P000003
ooooo`03ojVlionY_NOoZKgW00;oZKgW00?oZKgXojVlionY_NL00onY_NL00onY_NSoZKgWojVmi`0M
ojVmj00300000?nY_NSoZKgX00OoZKgX00<00000ooooooooool0=Oooool000Wooooo00@00000oooo
oooooooooooo;@0000000ol000006ATI01TI6@0301TI6@8000001@0c<c<3000000l0C4a<2@000006
04a<C0030000001VIVH0IVIV0080IVIV2P00000306IVIP8000000P1<C4`00`000000<c<c03<c<`02
03<c<`030000000I6AT06ATI00@06ATI<0000004ooooo`0300000?oooooooooo05[ooooo0`000002
ooooo`GoZKcW0_nY_NL4ojVli`;oZKgW00?oZ[cWojVmionY_NL00_nY_NL00onY_NSoZ[gWojZmi`02
ojVmj003ojZmionY_NSoZKgX01CoZKgX00<00000ojVmj?nY_NP02?nY_NP00`00003oooooooooo`0d
ooooo`002Oooool01000003oooooooooooooool]000000D06ATI00<0000003<c<`0c<c<00`0c<c<2
000000<0C4a<2`00000@04a<C0<000000`1VIVH2000000X0Ogmo00<0000006IVIP1VIVH00P1VIVH0
0ol00000C4a<04a<C002000000<0<c<c00<0000001TI6@0I6AT0100I6AT_000000Cooooo00<00000
ooooooooool0Eoooool3000000?ooooo1_nY_>L00onY^nKoZKcWojVli`03ojVli`;oZ[_V0onZ_>L2
ojVmi`;oZ[cW00?oZ[gWojZli_nZ_>H00onZ_NL2ojVmj003ojZmionY_NSoZKgX013oZKgX00<00000
ojVmj?nY_NP02?nY_NP00oooool00000ooooo`0dooooo`002Oooool01000003oooooooooooooool/
000000D06ATI00<0000003<c<`0c<c<00P0c<c<00ol00000000004a<C00204a<C08000002`1VIVH0
1000003o000000000000000904a<C0<000000`1VIVH00`00003o0000o`00000407moO`D0000000Co
000007moO`1oOgl0Ogmo0`00000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00ol00000
6ATI01TI6@0401TI6Bh000001?ooool00`00003oooooooooo`1Eooooo`8000000oooool7ojVli`Co
ZK_V0_nY_>L00onZ^^GoZ[_VojZkiP02ojZkiP06ojZlionZ^nKoZ[_VojZki_nZ_>OoZk_U1?nZ_>H0
0onZ_NOoZ[cWojZli`03ojZmi`;oZKgX00?oZ[gWojVmj?nY_NP00onY_NP00onY_NOoZKgXojVmj006
ojVmj00300000?nY_NSoZKgX00WoZKgX00<00000ooooooooool0<oooool000Wooooo00@00000oooo
oooooooooooo;000000501TI6@030000000c<c<0<c<c0080<c<c00H0000004a<C01<C4`0C4a<0000
0?l0000406IVIPP00000101VIVH3000000<0C4a<0`00000406IVIP800000101oOgl200000003o`00
002IVIT0VIVI00@0VIVI0`00000307moO`040000001VIVH0IVIV000000<0C4a<00D0000003<c<`0c
<c<0<c<c0000000501TI6Bh000001?ooool00`00003oooooooooo`1Booooo`<000000oooool6ojVl
i`;oZK[U1?nY^nH2ojZii0?oZ[[U0_nZ^nH2oj^ji0;oZ[_V00CoZkWSoj^kiOn[^nGoZk_U0_nZ_>H0
0on[^nGoZ[cWojZli`02ojZli`03ojZmionZ_>OoZ[gW00?oZ[gW00?oZKgXojZmionZ_NL00onY_NL2
ojVmj0;oZKgW00CoZKgXojVmionY_NL000002onY_NP00oooool00000ooooo`0cooooo`002Oooool0
1000003oooooooooooooool[000000D06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<
C002000000<0IVIV0`00000807moO`@000000`1VIVH3000000D0IVIV0P00000307moO`<00000102I
VIT4000000@0VIVI0P00000207moO`040000001VIVH0IVIV000000<0C4a<00@0000003<c<`0c<c<0
00001P0I6AT]000000Cooooo00<00000ooooooooool0D?ooool2000000Cooooo1_nY_>L5ojVji@03
ojVki_nZ^>?oZ[WT00?oZ[WT00KoZ[[Uoj^gh_n[]n;oZkORoj^ji?n/]^44oj^ih`03oj^kiOn/^N?o
[;WS00?oZk_U0_nZ_>L01?n[^nGoZ[cWojZlionZ_>L2ojZmi`03ojZlionZ_NOoZ[gW00;oZ[gW00?o
ZKgWojZlionZ_>L00_nY_NL01onZ_>OoZKgWojVmionY_NL00000ojVmj?nZ_NL02_nY_NP00`00003o
ooooooooo`0booooo`002Oooool01000003ooooooooooooooolZ000000H06ATI00D0000003<c<`0c
<c<0<c<c0000000204a<C0030000001VIVH0IVIV00<000000`1oOgl5000000L0Ogmo00?o000006IV
IP1VIVH01`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI0`0000040;>c
/`@000000P2IVIT010000000Ogmo07moO`00000206IVIP040000001<C4`0C4a<000000<0<c<c00<0
000001TI6@0I6AT0100I6AT/000000Cooooo00<00000ooooooooool0COooool3000000?ooooo1_nY
_>L7ojVji@04ojVgh_nZ^>?oZ[SSojZhh`;oZ[WT0_n[]N02oj^ghP04ojbbgOn/]^7o[;KQojbfh@;o
ZkWS00?o[KKOojbihon/^N<00_n/^N<00on[^nGo[;[Soj^ki@03oj^ki@03ojZlion[^nGoZk_U00?o
Z[cW0_nZ_NL2ojZliP03ojZlionZ_>KoZ[cW00?oZ[cW0_nY_NL01000003oZ[gWojZmionZ_NL2ojVm
j003ojZmionY_NSoZKgX00CoZKgX00?ooooo00000?ooool0<_ooool000Wooooo00@00000oooooooo
oooooooo:@0000000ol000006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<ol000000P1<C4`0
1?l00000IVIV06IVIP00000307moO`<000001@2IVIT4000000@0Ogmo1P0000000`1VIVH00000o`00
000307moO`8000000P2IVIT00ol000000000000000030;>c/`Co0000102c/k<010000000VIVI09VI
VOl0000207moO`040000001VIVH0IVIV00000080C4a<00D0000003<c<`0c<c<0<c<c0000000601TI
6B/000001?ooool00`00003oooooooooo`1;ooooo`8000001?ooool6ojVli`KoZK[U0onY]^82ojVg
hP05ojZhhonZ/]koZ[;NojZbg_n[]N000_n/[]T3ojbbg@03ojbfhOn^/M_o[[7K00?o[KKO0_n/^N<0
1?n^]n3o[;[Sojbjhon/^^<2oj^ki@;o[;[T0on[^nD00onZ_>OoZk_Uoj^ki@02ojZliP04oj^jiOnZ
_>KoZ[cVojZliP;oZ[cW00GoZ[cVojZlionZ_>L00000ojZli`06ojZmi`KoZKgX00?ooooo00000?oo
ool0<Oooool000Wooooo00@00000oooooooooooooooo:P00000501TI6@040000000c<c<0<c<c0000
0080C4a<00D0000006IVIP1VIVH0000007moO`03000000<0VIVI1@00000409VIV@<000001`1oOgl0
10000000Ogmo07moO`1oOgl2000000<0VIVI00@000000;>c/`2c/k<0/k>c0ol000040<c<c0?o0000
0P2c/k<01P000000VIVI09VIV@000000Ogmo000000<0IVIV00<0000004a<C0000000100c<c<00`00
00006ATI01TI6@0501TI6BT000001?ooool00`00003oooooooooo`18ooooo`<000000oooool4ojVl
i`GoZK[V00?oZK[UojReh_nX]N800onY]N82ojVfhP03ojV^fonZ/=coZ[3L00?oZ[;N00?oZjWFojb^
fOn/[]T00_n/[]T00on//]go[ZcEojjaf`03ojjaf`03ojffgon_/][o[[OP00?o[[OP00?o[;[Sojjh
h?n^^>000on/^^@4ojbjh`03oj^kiOn/^N?o[;WS00?oZk[U00?oZ[cVoj^ji?n[^^@00onZ_>H00onZ
_>L00000oj^liP07ojZmi`KoZKgX00<00000ooooooooool0<?ooool000Wooooo00@00000oooooooo
oooooooo:@00000501TI6@040000000c<c<0<c<c00000080C4a<00H0000006IVIP1VIVH0000007mo
O`00000309VIV@<000001@2c/k<3000000@0VIVI0P00000807moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00_l0000:0<c<c004o`00002c/k<0/k>c00000080VIVI00@0000007moO`00
000000000P1VIVH00ol00000C4a<0000000403<c<`03o`00000I6AT06ATI00H06ATI9`000004oooo
o`0300000?oooooooooo04Gooooo0`000002ooooo`04ojVmj?nY_NOoZKgWojVmi`;oZKcW00?oZK_V
ojVji_nY^^H00onY^^H00onX]^?oZ;GRojRehP02ojRehP03ojVeh_nX[M_oZJkK00?oZJkK0_nZ/=`0
1?nZ/]koZjWFoj^Ye_n[ZMH2ojb^f@04ojfUcon^[=Go[ZcEojj/e@;o[[7K00Co/JcCojnbf_n_/][o
[k;J0_n^]n000on`/m_o[[SPojjhh002ojjhh003ojbji?n^]n3o[[OP00;o[;[S00?o[KKPojbihon/
^N<00_n/^N<00on[^^Go[;SRoj^ji003oj^ji004ojZli_n[^^CoZkcV000000;oZkcV00CoZ[gWoj^l
i_n[_>KoZkcV1_nZ_NL01?nY_NSoZ[gXooooo`00000aooooo`002Oooool01000003ooooooooooooo
oolX000000@06ATI00Go00000000000c<c<0<c<c0000000204a<C006o`00001VIVH0IVIVo`00001o
Ogl000000P2IVIT2000000<0/k>c1Ol000030;>c/`<000000`2IVIT2000000@0Ogmo00<00000o`00
002IVIT00`2IVIT010000000/k>c0;>c/ol000040<c<c0Ko00000`3<c<`01?l00000/k>c0;>c/ol0
000209VIV@060000001oOgl0Ogmo0000001VIVH000000P1<C4`00ol00000000003<c<`0203<c<`03
0000000I6AT06ATI00H06ATI00?o00000000000000008`000004ooooo`0300000?oooooooooo04?o
oooo0P000002ooooo`GoZKgX00?oZKgWojVkionY^nL00onY^nH2ojVjiP04ojRgi?nX]^?oZ;KSojRf
h`;oZ;GR00CoYjgLojR]fonX[M_oZ:gK0onY[]/00onZ/=coZJGBojVUdP03oj^YeP04ojb^fOn]YLoo
[JG?ojfUc`;o[ZcE1?na[=<00on_/][o/jkCok>^d`03ok2cf`;o[[SP0_n`]=`00on^]n3o[k?Kojnc
f`03ojffh0;o[;WS00Co[KGNojbhh_n/^>;o[;SR0_n[^^@01_n/^>;oZk[Toj^ji?n[^^@00000oj^l
iP;o[;_U0on[_>H6ojZmi`?oZ[gX00?ooooo00000?ooool0;oooool000Wooooo00@00000oooooooo
oooooooo:000000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01P000000IVIV06IVIP00
0000Ogmo00000080VIVI00?o00000;>c/`2c/k<00_l000050<c<c0;o0000102c/k<00`000000VIVI
09VIV@0209VIV@@000001P2IVIT010000000/k>c0;>c/ol000030<c<c003o`00003Vi^H0i^KV00@0
i^KV00Co00000<c<c03<c<co00000`2c/k<00`000000VIVI0000000207moO`030000001VIVH00000
00<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6BH000001?ooool00`00
003oooooooooo`10ooooo`<000000_ooool6ojVmj0;oZKcW0onY^nL00onY^nKoZ;SUojRhi@03ojRg
i003ojRfhonV[]goYZkM00?oYjgL0onX[M/00onY[]_oYj;AojVUdP03ojVUdP03oj^Ye_n/Wl[o[JG?
00?o[JG?00?o[ZcEok6TbonaY</00ona[=<4ok>^d`03ok2cfonc/=Co/;CL00;o/;CL00?o/k3Eojnc
fon_/m/00_n_/m/00on]]^3o[k7JojfegP03ojfegP03ojbhh_n^]=go[;SR00?o[;SR00KoZk[Tojfi
hP00003o[KWRojbkiOn]^^<4oj^liP03ojZmion[_NKoZ[gW00?oZ[gW0_nZ_NP00oooool00000oooo
o`0_ooooo`002Oooool01000003ooooooooooooooolW000000D06ATI00@0000003<c<`0c<c<00000
0P1<C4`01P000000IVIV06IVIP000000Ogmo00000080VIVI00@000000;>c/`2c/k?o00002@3<c<`2
o`0000<0/k>c00<0000009VIV@2IVIT02P2IVIT010000000/k>c0;>c/ol000030<c<c003o`00003V
i^H0i^KV00H0i^KV00Co00000<c<c03<c<co00000P2c/k<010000000VIVI09VIV@00000207moO`03
0000001VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6B@0
00001?ooool00`00003oooooooooo`0nooooo`8000000oooool6ojVmj0GoZKcW00?oZK_WojRiiOnX
^>D00onX^>D00onX]nCoY[3OojJ^g@03ojJ^g@;oYjgL0_nX[M/01?nUXM7oYj;AojNRdOnWX]42ojVU
dP04ojVIa_n/Wl[o[9o:ojbObP;o[JG?00?o[ic4ok6TbonaY</00_naY</00ona[=?o]:K:okBVbP02
ok>^d`05okNYc?nc/=Co/k3Dok>`e?n`]=`00onc/=D2ojncf`04ok6]e?n_/M[o[k7JojnafP;o[KGN
00Co[joHojjdgOn^]=go[[CM0_n/^>82ojneg@03ojfihP00003o[kON00?o[K[S0_n[_>H01?n]_>Co
ZkgVoj^mi_n[_NH2ojZmi`06oj^mionZ_NSoZ[gXojZmj?ooool00000;oooool000Wooooo00@00000
oooooooooooooooo9`00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV
0000000207moO`030000002IVIT000000080/k>c00?o00000<c<c03<c<`00P3<c<`4o`0000@0c<c<
00Co00000;>c/`2c/k<000002`2IVIT01@000000/k>c0;>c/`2c/k?o00000080c<c<00?o00000>KV
iP3Vi^H0203Vi^H01?l00000c<c<0<c<c?l000020;>c/`030000002IVIT000000080Ogmo00@00000
06IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00L06ATI00?o
00000000000000007`000004ooooo`0300000?oooooooooo03_ooooo0`000002ooooo`KoZKgX1onY
_>L01?nX^^KoZ;WUojRiiOnX^ND2ojRhi@04ojJbhOnV/=ooY[3OojJ`g`;oYZkM00?oXZ;Doj>Pd_nS
X=801?nUXM400onWX]7oYIC4ojVIaP03ojVIaP;o[9o:1?n_W<@2ok6Tb`05okBM`OndY/[o]:K:okBV
b_nc[]<00ongZL`00onc/=Co]j_=okN[c@03ok>`e@Co/JgD00?o[k7Jok6Zd_n_[mP00on_[mP00on^
]=go/;3Gok2`e`03ojneg@06ojnggP00003o[kONojngg_n]^^?o[kWQ1?n]_>@00on[_NKo[;gVoj^m
i`03oj^mi`05ojZmj?nZ_NOoZ[gWooooo`000000;_ooool000Wooooo00@00000oooooooooooooooo
9P00000501TI6@040000000c<c<0<c<c00000080C4a<00P0000006IVIP1VIVKo000007moO`000000
VIVI00000080/k>c00?o00000<c<c03<c<`00ol000040>KViP05o`00003<c<`0c<c<0<c<c?l00000
0`2c/k<00`000000VIVI09VIV@0709VIV@050000002c/k<0/k>c0;>c/ol000000P3<c<`00ol00000
i^KV0>KViP030>KViP;o00001@3Vi^H01?l00000c<c<0<c<c?l000020;>c/`030000002IVIT00000
0080Ogmo00<0000006IVIP1VIVH00P00000204a<C08000000`0c<c<2000000L06ATI8P000004oooo
o`0300000?oooooooooo03Wooooo0P000003ooooo`KoZKgX1_nY_>L2ojVjiP?oZ;[V00?oZ;WUojNd
h_nW]>800onV/^400onV/=ooXZGHoj:Re003oj:Re0;oXj3B0_nUXM401?nRT/CoYIC4ojFDa?nUU<@3
ojVIaP03ojbOb_n/U;go[9Bm00?o[ic400Go/JC;okBM`OndWL7o]9g1okBVbP02okRQ`@?o]jW<1?ng
Zld00onc/=Go]:W=okBYc@02ok6]e004ok:UbonaZ];o/J[Bok6ZdP;o[joH00?o/ZW?ok2`eon`/=L0
0_n`/=L01_n_]Mgo/[;Hok:bf000003o[kONok>ff`?o[kWQ0_n]_>@01?n^_>?o[;gVojbmi_n/_NH4
oj^mi`?oZ[gW00<00000ooooooooool0;?ooool000Wooooo00@00000oooooooooooooooo9@000005
01TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01`000000IVIV06IVIP000000Ogmo00000?l0
00000`2c/k<00ol00000c<c<o`0000080>KViP04o`00003<c<`0c<c<o`0000<0/k>c00<0000009VI
V@2IVIT01`2IVIT01@000000/k>c0;>c/`2c/k?o00000080c<c<00?o00000>KViP3Vi^H00`3Vi^H0
1?l00000ooooo`000?l000030>KViP09o`00003<c<`0c<c<0<c<c?l00000/k>c0000002IVIT00000
00<0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c0080<c<c0P000007
01TI6B0000001?ooool00`00003oooooooooo`0fooooo`<000000oooool6ojVmj0KoZKcW1OnY^^H0
0onX^^KoYkGSojNdhP03ojNdhP03ojJbhOnRZ=_oXZGH00;oXZGH0onRX]@00onSX=;oWY75oj:Ba002
oj:Ba0CoYIC400?oZIW6ojR=^On/U;d00on/U;d00on_W<Co/YBiokBM`@03okBM`@Co^:7100?o]jW<
okZU`onjYL<00_ngZld01OniYLGo]:W=okBYcOndZLgo/JgD00?o/ZG;0_naZ]84ok:Yc`;o/;3G00Go
]:_?ok:bf?nb/]So/[;H00000003ok>ff`03ojnihOnb^Mko[[cS00?o[[cS00?o[;gVojfmiOn]_ND0
0on[_NL4ojZmi`0300000?oooooooooo02_ooooo0009ooooo`0400000?ooooooooooooooob@00000
1@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00P0000006IVIP1VIVH0000007moO`000000
VIVI00000080/k>c00?o00000<c<c?l000002P3Vi^H01?l00000c<c<0<c<c?l000030;>c/`030000
002IVIT0VIVI00H0VIVI00D000000;>c/`2c/k<0/k>co`0000020<c<c003o`00003Vi^H0i^KV0080
i^KV00?o00000?ooo`3oool00P3oool01Ol00000i^KV0>KViP3Vi^Ko00000080c<c<00Ko00000;>c
/`2c/k<0000009VIV@00000307moO`050000001VIVH0IVIV06IVIP0000000`1<C4`00ol00000<c<c
03<c<`0303<c<`030000000I6AT06ATI00D06ATI00?o000000000000000070000004ooooo`030000
0?oooooooooo03?ooooo0`000004ooooo`KoZKgX0onY_>L5ojVji@03ojVji_nX]^;oZ;KR00?oZ;KS
0_nW]N<2ojNdhP04ojB[g?nRZ=_oXZSKoj:Xf`?oXZGH00?oXZ;DoibBbOnNTLD00_nNTLD3oj:Ba0;o
YIC400CoXhRgojR=^OnXSKWoZ8fi0_n/U;d01?n^S;;o/YBiok:D^OnbU;T2okBM`@03okRI^?nhXL7o
^:7100;o^:710onjYL<01OngZlgo^JG5okVUaOniYLGo]:W=00;o]J730onbYL/00onaZ];o/Z;7ok:R
a`03ok:Yc`Co]:_?00?o/[;HokJ_dP0000000_nc]]/01?ng]MOo/[WNok:ig_nb^Mh2ojjlh`;o/;cR
00?o[KgUojjmiOn^_ND00on[_NL3ojZmi`0300000?oooooooooo02_ooooo0009ooooo`0400000?oo
ooooooooooooob<000001P0I6AT01ol00000<c<c03<c<`0c<c<0000004a<C?l000000P1VIVH00`00
0000Ogmo0000000209VIV@050000002c/k?o00000<c<c?l00000303Vi^H01?l00000c<c<0<c<c?l0
00030;>c/`030000002IVIT0VIVI00D0VIVI00D000000;>c/`2c/k<0/k>co`0000020<c<c005o`00
003Vi^H0i^KV0>KVi_l000001@3oool00ol00000i^KV0>KViP020>KViP06o`00003<c<`0c<c<o`00
002c/k<000000P2IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00@0000004a<C01<C4`0C4a<
0P00000403<c<`8000001P0I6ATN000000Cooooo00<00000ooooooooool0<Oooool2000000Cooooo
1?nY_NP6ojVli`;oZK[V1?nY^^D2ojVfhP?oZ;KR00?oZ;KSojN^gOnW[]d00_nU[Md3ojB[g003oj:X
fonLV]7oViG=00;oViG=0onLT/T2oijAa@?oXY;400?oYIC4oj>8]onSR;L00onXSKT00on/U;go[Xbb
ojj</P03ok:D^@04okBM`OnhVKSo^9VhokRI^0;o^:710_nmW[T2okZU``Co^JG51?neXL<00onbYL_o
/ic0ok:Ra`03ok:Ra`03ok:YconeXlKo]J?600;o]:_?00Go^JO7okJ_d_nf[m;o]ZoB00000003okNe
e`06ok:ig_nf^]go][[MokJjgOn`_>;o/kgR1?n^_ND00on[_NOo[;kWojZmi`03ojZmi`0300000?oo
oooooooo02[ooooo0009ooooo`0400000?ooooooooooooooob<000001P0I6AT01`000000<c<c03<c
<`0c<c<0000004a<C00000000P1VIVH00`000000Ogmo0000000209VIV@050000002c/k?o00000<c<
c?l00000303Vi^H01?l00000c<c<0<c<c?l000030;>c/`030000002IVIT0VIVI00D0VIVI00D00000
0;>c/`2c/k<0/k>co`0000020<c<c003o`00003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool00ol0
00040>KViP06o`00003<c<`0c<c<o`00002c/k<000000`2IVIT00`000000Ogmo07moO`02000000<0
IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00@0
6ATI7@000004ooooo`0300000?oooooooooo02kooooo0`000002ooooo`KoZKgX00?oZKgWojVlionY
_>L00onY_>L5ojVjiP03ojVjiOnX]N;oZKKR00?oZKKR00?oZ;KRojN^g?nW[]d00onW[]d2ojF]g@03
ojB[g?nNW]CoW9[A00;oW9[A0onKULd2oibBb@?oWY7500?oXY;4oij4]onSR;L00onSR;L2ojR=^@Co
[Xbb0_nbU;T4okRI^005okRQ`OnmW[Wo_IjiokfN^OnjYL<00_nmXK`3okVUa@04okZN_?neXL?o]J73
okFH^@?o/ic00_nbX/L01OndVkgo]J?6okFSa_neXlKo]:_?00?o^JO700Ko]ZoBokb^c000003o_:k<
okNeeonl]]@3okJjg@04okZlfonc_N;o/kgRok>mhP;o[[gU0_n__^D2ojbni`;oZ[gW0_n[_^L00`00
003oooooooooo`0Yooooo`002Oooool01000003ooooooooooooooolR000000H06ATI00D0000003<c
<`0c<c<0<c<c0000000204a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT01@000000/k>c
o`00003<c<co000000`0i^KV00Co00000<c<c03<c<co00000P2c/k<00`000000VIVI09VIV@0709VI
V@040000002c/k<0/k>co`0000<0c<c<00?o00000>KViP3Vi^H00P3Vi^H2o`0000L0i^KV00Co0000
0<c<c03<c<co00000P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo0P00000206IVIP030000
001<C4`0C4a<0080C4a<0P00000403<c<`030000000I6AT06ATI00@06ATI70000004ooooo`030000
0?oooooooooo02cooooo0P000003ooooo`OoZKgX0onY_NL2ojVli`03ojVki_nY^^KoZK[V00?oZK[V
00CoZ;KSojReh_nX]N;oZ;GR0_nY]^801?nW[M_oYjkLojN^g?nW[]`2ojN^g@03ojBRdonRX]CoXZ;D
00?oWYkD0onLV]42oi^Ec@03oibBbOnDPKcoVH6h00;oVH6h0onNQ;L3oj>8]`03ojR=^OnYQJkoZHF^
00?o[Xbb00?o/YBiokF@/?neT;000onhVKP4okfN^@Co_J6l00Co^JG5okZN_?njW[co]J730_neV;T3
ok>L`004ok:RaondVkgo]9^mokBK_@;o]J?600Co^IjmokVWaoniYlOo^JO70_nl[/`00`00003o`[38
okbfe002okbfe005okJjgOnj_=_o^[cKokZlfonc_N800_ne_n82ojnni@04ok2oiOn/_^Oo[;kWojbn
i`;oZkkW00?oZkkX00000?ooool0:_ooool000Wooooo00@00000oooooooooooooooo8@00000601TI
6@030000000c<c<0<c<c0080<c<c00<0000004a<C00000000P1VIVH020000000Ogmo07moO`000000
VIVI0000002c/k?o00000P3<c<`00ol00000i^KV0>KViP090>KViP04o`00003<c<`0c<c<o`0000<0
/k>c00<0000009VIV@2IVIT01`2IVIT01@000000/k>c0;>c/`2c/k?o00000080c<c<00?o00000>KV
iP3Vi^H02`3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c00D0000009VIV@2IVIT0VIVI0000
000407moO`03o`00001VIVH0IVIV00800000101<C4`00`000000<c<c03<c<`0203<c<`03o`00000I
6AT06ATI00@06ATI00?o000000000000000060000004ooooo`0300000?oooooooooo02Wooooo0`00
0002ooooo`_oZKgX00?oZKgWojVkionY^nL00onY^nH00onY^^KoZ;OSojRgh`03ojRfh`03ojReh_nW
[M_oYjgK00?oYjgK00?oYjkLojFRd_nTX]<00onTX]<2oj:Re0;oWYkD0_nLV]400onCRLKoTXC1oi:4
`@03oiB1_0;oVH6h0onNQ;L3oj>8]`?oZHF^0on^S;84okF@/003okRI^?nmUk3o_IN`00;o_Iji0_o1
W;<2okfQ_004oknL]OnjW[co^YjlokZN_0Co]IRi0_ncW<04okBK_@05okFSa_niW[go^IjmokVN_Oni
YlL00_nnY/401_nl[/`00000ol:`b?o2/<So_;KDol:idP?o^[cK00Co_[oKokFoh_ne_n;o]KoR1?n`
_nD2ojbni`CoZkkX00<00000ooooooooool0:?ooool000Wooooo00@00000oooooooooooooooo8000
000601TI6@040000000c<c<0<c<c03<c<`8000000P1<C4`01P000000IVIV06IVIP000000Ogmo0000
0080VIVI00<000000;>c/ol000000P3<c<`00ol00000i^KV0>KViP090>KViP04o`00003<c<`0c<c<
o`000080/k>c00<0000009VIV@2IVIT02@2IVIT010000000/k>c0;>c/ol000030<c<c003o`00003V
i^H0i^KV00X0i^KV00Go00000<c<c03<c<`0c<c<o`0000030;>c/`04o`00002IVIT0VIVI09VIV@80
00000P1oOgl300000080IVIV0P00000304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I
6AT00`0I6ATK000000Cooooo00<00000ooooooooool09oooool2000000?ooooo3?nY_NP3ojVli`;o
ZK_W00CoZK_VojRhi?nX^>CoZ;ST0_nX]n<00onX]^?oYZgLojN]f`04ojN]f`04ojFQdOnUX];oYJ;B
ojFRdP?oY:;C00CoXZ;DoifCbOnGSlWoUho90onCRLH2oi:4`@?oU86l0onIPKP3oij4]`03oj>8]onR
OZcoZHF^00;oZHF^0on^S;84okF@/0?o_IN`00Go_Ijiol6L/oo1W;?o`IbcokfQ_003oknL]@;o^Yjl
00Go^IJcokFH^OneV;Wo]IRiok>L`002okBD]P?o]9^m1?niW[d3okjV`@04ol:`b000003o`[38ol:`
b0?o`[WB00Go^[cKokjofonn_m_o_[oKokFohP02okO1hP;o/;oU00Co/<3Vojbnion/_^Oo[;kW1?n[
_^P00`00003oooooooooo`0Wooooo`002Oooool01000003ooooooooooooooolO000000H06ATI00D0
000003<c<`0c<c<0<c<c0000000404a<C0030000001VIVKo00000080Ogmo00H0000009VIV@2IVIT0
00000;>c/ol000020<c<c003o`00003Vi^H0i^KV00P0i^KV00Go00000<c<c03<c<`0c<c<o`000002
0;>c/`030000002IVIT0VIVI00X0VIVI00?o00000;>c/`2c/k<00_l000020<c<c0?o0000203Vi^H0
0ol00000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c0080/k>c0P00000309VIV@8000000`1oOgl2
00000080IVIV0P00000204a<C0050000000c<c<0<c<c03<c<`0000001P0I6ATJ000000Cooooo00<0
0000ooooooooool09?ooool3000000?ooooo2onY_NP5ojVli`04ojRji_nX^NGoZ;WUojRii@;oZ;ST
00?oY[7PojJ_g_nV[mh00onV[M`2ojN]f`04ojBPdOnUXM7oYJ7AojFQd@?oYJ;B00?oY:;Coj6DaonM
TlT00_nMTlT2oiN?b@?oThW60_nBQ<42oiB1_0?oVH6h0_nNQ;L01?nKNJcoXWj/oj9n[?nROZ`3ojV5
[P03ojj</_naR:[o/HRZ00?o]I2`0onmUk04ol6L/`Co_ibe00?o^YjlokVF/oniU[<00oneV;T4okBD
]P03okBK_OnhU[Co^9Jd00;o^Ijm0_nnWKH2okjV`@03olFW^`00003o`[3800;obKC500?o`[WBolRn
dOo8_]400_nn_m/2ol74g003okO1h_nh`n?o/<3V00?o/<3V00?o[;kWojboion/_nL00on[_^P00`00
003oooooooooo`0Wooooo`002Oooool01000003ooooooooooooooolN000000H06ATI00<0000003<c
<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00<0000007moO`0000000P2IVIT0
10000000/k>c0;>c/ol000030<c<c003o`00003Vi^H0i^KV00H0i^KV00Go00000<c<c03<c<`0c<c<
o`0000020;>c/`03o`00002IVIT0VIVI00<0VIVI1000000509VIV@050000002c/k<0/k>c0;>c/ol0
0000103<c<`3o`0000<0i^KV0_l000060<c<c003o`00002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00P2IVIT2000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0050000000c<c<0<c<c
03<c<`0000001P0I6ATI000000Cooooo00<00000ooooooooool08_ooool2000000Cooooo3_nY_NP0
0onY_>OoZ;_WojRki`03ojRjiP03ojRiiOnV]>?oY[CS00?oY[7P0_nV[mh00onV[McoXj3Boj>PdP03
ojBPd@;oYJ7A0_nUX]801?nSTlGoXIC7oj6DaonQU<L3oifCb@;oUho90_nCRLH2oi:4`@?oU86l00?o
VH6hoi=e[_nKNJ`00_nKNJ`3oj9n[0;oZHF^00CoZh6Wok68Z_naR:[o/HRZ0_neT;02okZ?Z@;o_IN`
00Co`YN[ol6L/oo1W;?o`Ibc1?noW;D4okVF/`03okFH^OndT;3o]9Bf00?o]9Bf0onhU[@01OniW[go
_YffokjM]_nnWKKo_ZK100;oaJNk00@00000olVdaOo9]<GobKC50oo8_]43ol74g004ol?8g_nh`n?o
^<?SokS3h`;o/<3V0_n``NH2ojboi`CoZkkX00<00000ooooooooool09_ooool000Wooooo00@00000
oooooooooooooooo7@00000601TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<
o`00000206IVIP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k?o00000`3<c<`00ol0
0000i^KV0>KViP040>KViP;o00000P3<c<`2o`000080/k>c00L0000009VIV@2IVIT0VIVI00000?l0
0000000000@0Ogmo0`00000309VIV@040000002c/k<0/k>c0;>c/`?o0000103<c<`3o`0000P0c<c<
0ol000040;>c/`04o`0000000000000000000080VIVI00Go000007moO`1oOgl0Ogmoo`00000306IV
IP05o`00001<C4`0C4a<o`00000000000P0c<c<00ol00000000001TI6@0401TI6@03o`0000000000
000001D000001?ooool00`00003oooooooooo`0Oooooo`<0000000?oooooojVmj?nY_NP04?nY_NP2
ojVli`?oZ;_W00?oZ;[VojJgiOnV]nD00onV]><00onV/N3oXJKIoj:Re@02oj:Re@?oXj3B0_nTX=40
0onUXM7oXY73oj>Ca@03oj>Ca@;oXIC70_nMTlT00onHQKgoSgnmohmo_@02ohUh^P;oR7Bf0on=Lk42
oi=e[PCoVgV/0_nROZ`00onYQJkoZh6Woj^1Y`03ok68ZP05okF@/?njSjWo^XnYokZ?ZOnmUk000_o2
Uj/2ol6L/`;oa9^^0_noW;D00onnUZko^IJcokVF/`02okVF/`?o]92`0_ndU;H01?nfSjgo^9JdokRF
]?nhU[@4okjM]P?oaJNk00H00000olVdaOo9]<GobKC5om:ka?o8_]42olk5dP05ol74g?o3b=ko`lSN
ol?8g_nh`n<00_nhaN@2ok31iP04ok31ion/_nOo[;oWojboi`;oZkkX00?oZ[kXooooo`0000009ooo
ool000Wooooo00@00000oooooooooooooooo6`0000000ol000006ATI01TI6@0401TI6@03o`00000c
<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP040000001oOgl0Ogmo00000080
VIVI00@000000;>c/`2c/k?o0000103<c<`00ol00000i^KV0>KViP03o`0000<0c<c<00?o00000;>c
/`2c/k<00P2c/k<010000000VIVI09VIV@00000:07moO`060000002IVIT0VIVI09VIVOl000000000
102c/k<00ol00000c<c<0<c<c00?0<c<c003o`00002c/k<0/k>c00D0/k>c0P0000000`2IVIT00000
0000000207moO`040000001VIVH0IVIV000000<0C4a<00D0000003<c<`0c<c<0<c<c0000000501TI
6AP000001?ooool00`00003oooooooooo`0Looooo`<000000_oooolDojVmj0?oZKcW00?oZ;_WojNi
i_nV]nD00onV]nD00onV]>?oXZ_Moj6Vf@02oj6Vf@?oXZ;E00CoXj3Boij@aOnPT<?oX9330onRTL<3
oj>Ca@03oj6DaonNQk_oV8Fm00;oV8Fm0_n?Okd2ohUh^P?oR7Bf0_n=Lk42oi=e[PCoVgV/0_nROZ`4
oj^1Y`;o/HRZ1?njSjT01OnmUk3o`YN[ol:GZoo2Uj_o`Ibc00;oa9^^00Co_ibeokjF[_nnUZko_YJ^
0_niU[<01OnfSZco]92`okB@/?ndT;3o]9Bf00?o]Xn]0_nhU[@01OnlU:go_YffokjM]_nnWKKoaIna
00;oaJNk00<00000olj]^?o9]<D00_oB^l@3olk5dP;od/cD00Go`lSNolC;h?o4bn3o^<GTokO5i@04
ok31i`?o[;oW0onZ_^P00`00003oooooooooo`0Uooooo`002Oooool01000003ooooooooooooooolL
000000H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0050000001VIVH0IVIV06IVIP000000
0P1oOgl010000000VIVI09VIV@0000030;>c/`03o`00003<c<`0c<c<00<0c<c<0_l000050<c<c003
o`00002c/k<0/k>c0080/k>c00@0000009VIV@2IVIT00000101oOgl4000000@0Ogmo0P00000309VI
V@8000000`2c/k<3o`0000l0c<c<0ol000060;>c/`030000002IVIT0VIVI0080000000D0Ogmo0000
001VIVH0IVIV0000000304a<C0050000000c<c<0<c<c03<c<`000000100I6ATH000000Cooooo00<0
0000ooooooooool06_ooool2000000?ooooo5OnY_NP2ojRli`?oZ;_W0_nW^NH2ojJgi@04oj>`hOnR
ZmgoXZ_Moj:[g@;oXJKI0_nRX]D00onKT/WoWY35oij@a@03oj2@``?oXY7300?oXi?5oj26^?nNQk/0
0_nNQk/3oiR5_@;oSgnm0_n9N;X2ohQd]P?oSG>a0_nCMJh3oi]i[003oj9n[?nSNJGoZh6W00?oZh6W
0_naR:X01?nfR:Go^XnYokZ?ZOnjSjT4ol:GZ`?oa9^^1?nnUZh01?niU[?o]Xj/okJ>[?nfSZ`2okB@
/0Co]Xn]00Go^9JdokbD[OnlU:go_9B]okjM]P02olFO/@04olFW^oo>[KP00000olj]^0?od[_400?o
f/C4olk5d_oBc=@00_oBc=@3olC;h0?o]lGU0_n``NL2ojo1i`03ojboion/_^OoZ[kX00?oZ[kX00<0
0000ooooooooool09?ooool000Wooooo00@00000oooooooooooooooo6`00000601TI6@050000000c
<c<0<c<c03<c<`0000000`1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2I
VIT0VIVI000000030;>c/`03o`00003<c<`0c<c<00T0c<c<00Co00000;>c/`2c/k<0/k>c0P000002
09VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH3000000<0Ogmo00<00000
09VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`?o00003`3<c<`3o`0000@0/k>c00[o0000
09VIV@2IVIT0VIVIo`00001oOgl00000o`00001VIVH000000P1<C4`01@000000<c<c03<c<`0c<c<0
000000D06ATI5`000004ooooo`0300000?oooooooooo01Oooooo0`000003oooooaOoZKgX0onX_>L0
0onX^nOoY[SVojJhiP03ojBdi0;oXk3Q00CoXZ_MoiZMe_nJU/ooVYK?1?nKT/T2oij@a@;oX9330_nR
TL<00onOQ;KoX8Jhoj26^003oij7^`?oV8Fm0_n?Okd2ohUh^P;oR7Bf0on=Lk42oi=e[P;oVgV/00?o
VG:Uoj=iYOnSNJD01?n[PJL00onaR:[o]XRUokJ8Y@03okZ?Z@Co`YN[0oo4Vjh01?o4V:[o_YJ^okjF
[_nnUZh4okJ>[0;o]92`00Co]8ZYokJ?[OnfSjgo]Xn]1?nlU:d3olFO/@06olj]^00000000000olj]
^?oH][Ood[_40_oJa<@3om;<e0;oe=;G00Coa<_Pol;<h_o2c>;o]lGU0oneaNH00on_`NOo[/3Wojbn
i`02ojbni`;oZ[kX00?oZ[gXooooo`0000009Oooool000Wooooo00@00000oooooooooooooooo6`00
000501TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`01Ol00000IVIV06IVIP00003o00000080
Ogmo00Go000009VIV@2IVIT0VIVIo`0000040;>c/`;o00001P3<c<`4o`000080/k>c0P00000209VI
V@8000000P1oOgl00`00003o0000o`00000806IVIP06o`0000000000000007moO`00003o00000P00
00000`2IVIWo0000000000060;>c/`?o00003`3<c<`3o`000080/k>c0P0000001@2IVIT0000007mo
O`1oOgl000000080IVIV00Co000004a<C01<C4co00000`0c<c<00ol000006ATI01TI6@0201TI6AL0
00001?ooool00`00003oooooooooo`0Fooooo`8000000ooooolJojVmj003ojRlionW^^OoY[SV00?o
Y[SV00CoY;CToij]h_nKYMcoVjGL0onJWMH2oiZFc`?oVi;90_nNT<D00onPT<?oW86foin4]P02oin4
]P?oX8Jh0onNQk/01?nHQKgoU7ZcohQb]?n8L[@2ogiZ/@?oOVJ]0_n=Lk42oi=e[P03oi]i[?nILZGo
VG:U00?oXgVU0on[PJL3okJ8Y@;o^XnY0_o1TZD2ol:GZ`;oaiVX00?oa9^^olBHZ_o4V:X00onnUZh4
okJ>[003okB@/?ndRZWo]8ZY00?o]Xn]1?nlU:d01_o5Wk40000000000000003ocZfh000000;of;Jg
0ooJa<@01?oQclKod/cDomCBeooDd]L2om;Ef`03ol;<h_o0bn?o`<_S00;o]LGV00Go/l?Vojk0ion^
`>Oo[/3Wojbni`02oj^ni`?oZ[gX00<00000ooooooooool08oooool000Wooooo00@00000oooooooo
oooooooo6P00000501TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`010000000IVIV06IVIP00
000307moO`050000002IVIT0VIVI09VIV@0000001`2c/k<00ol00000c<c<0<c<c003o`0000@0/k>c
0P00000209VIV@8000000`1oOgl00`000000IVIV06IVIP0<06IVIP030000001oOgl0Ogmo0080Ogmo
0P000000102IVIT000000000000000060;>c/`03o`00003<c<`0c<c<00l0c<c<00Oo00000;>c/`2c
/k<0/k>c0000002IVIT000000080Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000<c<c03<c
<`0c<c<0000000<06ATI5`000004ooooo`0300000?oooooooooo01Kooooo00<00000ojVmj?nY_NP0
6onY_NP2ojRlj0;oYk[W0_nV^>H01?nR/nGoWZgRoij]h_nN[N82oi^Ug0;oVYgF0onJU/l01?nKT/Wo
TX2loiMo^?nGOkP3oib1]P?oWhBf0_nPQ[P2oij7^`03oiam/?nDN[?oU7Zc00;oR7:d0omnJ[42ogiV
[@;oQFNY0_n?K:H3oiUbY@?oXgVU0on[PJL4okJ8Y@04okZ?ZOo1TZGo`I:Uol:GZ`?oaiVX00Goa9^^
olBHZ_o4V:[oa9RZokjF[P02ok^@Z@?o]Xj/1?ndRZT01?nfSjgo^XfWokZ=YonlU:d300000009olFO
/Oo?YJkocjF^olj]^?oH][L00000omRf]ooS`[Kof/C400;ohLo600GoiMW9omCBeooBeM_od]GKoloD
g@03ol3;h`Co/l?V00?o[/3Wojjoion^_nL00_n[_^L4ojZmj00300000?oooooooooo02;ooooo0009
ooooo`0400000?oooooooooooooooaT000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<
00@0000006IVIP1VIVH000000`1oOgl01@000000VIVI09VIV@2IVIT0000000T0/k>c0_l000060;>c
/`050000002IVIT0VIVI09VIV@0000000`1oOgl2000000D0IVIV1`00000406IVIP<000000`1oOgl0
10000000VIVI09VIV@2IVIT3000000@0/k>c00?o00000<c<c03<c<`0103<c<`7o`0000@0c<c<0_l0
00020;>c/`03o`00002IVIT000000080Ogmo00<0000006IVIP0000000P1<C4`01@000000<c<c03<c
<`0c<c<0000000@06ATI5P000004ooooo`0300000?oooooooooo01Kooooo00<00000ojVmj?nY_NP0
6onY_NP00onX_>SoY[[WojJji`03ojBhi`;oX[?U0_nN[N801?nKYMcoSiKFohf;c?n=Rl`3ohn4``;o
TX2l0_nGOkP3oib1]P?oWhBf00?oX8Jhoimm[OnLOK000_nLOK03oiAj/`;oR7:d0_mnJ[42ogiV[@;o
QFNY0on?K:H3oiUbY@;oXgVU0_n[PJL00on_P:;o]XRUokJ8Y@02okJ8Y@?o`I:U1?o7VJP4olBHZP?o
^i2Y0_nfSZ`00ondR:Ko]8ZYokB:Z@02okB:Z@04okZ=Y`0000000000000000?o`iNY00?oaInaolnU
[_o?YJh00ooH][L00`00003ohl:fon7?aP02on7?aP03onGIbOoUglkod]GK00?ocmCM00?o`<_Sokg8
honmb><00_nc`nH2ok;1i@03ojjoion^_^KoZkkW00;oZkkW0_nZ_NP00onZ_NL00000ooooo`0Soooo
o`002Oooool01000003ooooooooooooooolH00000003o`00000I6AT06ATI00806ATI00D0000003<c
<`0c<c<0<c<co`00000304a<C004o`00001VIVH0IVIVo`000080Ogmo00@00000o`00002IVIT0VIVI
0P00000@0;>c/`8000000`2IVIT01Ol00000Ogmo07moO`1oOgl0000000<0IVIV1000000704a<C0<0
0000101VIVH01ol00000Ogmo07moO`1oOgl00000o`00000000000`2IVIT00`000000/k>c0;>c/`02
0;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H01@3Vi^H4o`000080c<c<00Ko0000
0;>c/`2c/k<0000009VIV@00000207moO`030000001VIVH000000080C4a<00@0000003<c<`0c<c<0
00001@0I6ATE000000Cooooo00<00000ooooooooool05_ooool00`00003oZKgXojVmj00JojVmj0;o
Z;cX0onV^^L01?nT^>OoWk?VoiZ/honJ[><3oiBQgP;oSiKF0_n=Rl`2ohn4``?oTX2l0_nGOkP3oib1
]P04oin4]_nMNZ_oWgf]oimm[@CoW7f`0_nDN[<2ohQb]0;oOVZa0_mnIZd2ohEWZ@?oSfbV0onILZD2
oj=iY@04oj^1Yon_P:;o[h2Rojn0XP?o]XRU0oo1TZD01?o7UZ?oaiVXolNIZ?o7VJP4olBHZP?o^i2Y
00Go]Xj/okB8Y_ndR:Ko]8RVokB:Z@03000000;o^XfW1?o3UjT3olnU[P07omZ_[?oH][Oohl:fon?2
]P00003ok<ngon7?aP02onGIb@04onGOc_oQgm?ocmCMoloDg@;ob]3N00?o_LSSok[5h_njaN800_nb
`ND01Onb`>Co[[kVojjni_n^_^KoZkkW00;o[;kW0onZ_NL00`00003oooooooooo`0Qooooo`002Ooo
ool01000003ooooooooooooooolI000000@06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C006
0000001VIVH0IVIV0000001oOgl000000`2IVIT00`000000/k>c0;>c/`0?0;>c/`040000002IVIT0
VIVI09VIV@8000000P1oOgl00`00003o000006IVIP0206IVIP030000001<C4`0C4a<00`0C4a<00<0
000006IVIP1VIVH00P1VIVH2000000@0Ogmo00@0000009VIV@2IVIT00000102c/k<00ol00000c<c<
0<c<c0020<c<c003o`00003Vi^H0i^KV00T0i^KV00So00000<c<c03<c<co00000;>c/`000000VIVI
00000080Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000501TI6AD000001?oo
ool00`00003oooooooooo`0Eooooo`0400000?oooooooooooooooa[oZKgX0onX_>P00onV^^OoY;SW
oinciP02oinciP;oVZcS0onDXMh2ohnFeP;oSH_<0_n?Q<<2oi:0_0;oUgnh0_nLPKH00onIMZ_oWGZ[
oiejZ`03oimm[@?oW7f`0_nDN[<2ohQb]0?oOVZa0_mnIZd2ohEWZ@;oSfbV0onILZD2oj=iY@Co[h2R
0_nfR:D2okb;XP03ol6BYOo7UZ?oaiJS00;oaiVX0_o;VjH2olBHZP;o`iFW0_nkT:T2okB8YP<00000
00?o]8ZYokN8Y?njSJL00_njSJL01?o0T:Co`iNYol>GZOo3UjT2olnU[P;ofZn/00Ooikf[on?2]_oS
`[H00000onc?]oobg;SoiMW900;oiMo>00CohMoCol[@g_o:d=kob]3N0_o5bMd00onjaN;o^L;Qok;0
i003ok;0i0?o[[kV0_n/_^L4ojZmi`0300000?oooooooooo023ooooo0009ooooo`0400000?oooooo
oooooooooaP000001@0I6AT010000000<c<c03<c<`00000304a<C0060000001VIVH0IVIV0000001o
Ogl000000`2IVIT00`000000/k>c0;>c/`030;>c/`<000002@2c/k<01@000000VIVI09VIV@2IVIT0
000000<0Ogmo00@0000006IVIP1VIVH0IVIV0P00000504a<C0Oo0000101<C4`2000000@0IVIV00<0
000007moO`1oOgl00P1oOgl010000000VIVI09VIV@0000030;>c/`03o`00003<c<`0c<c<0080c<c<
00?o00000>KViP3Vi^H02@3Vi^H02Ol00000c<c<0<c<c03<c<co00000;>c/`000000VIVI00000002
07moO`8000000P1<C4`010000000<c<c03<c<`00000501TI6AD000001?ooool00`00003ooooooooo
o`0Eooooo`0400000?oooooooooooooooaWoZKgX0_nX_>P3ojJkj0;oY;SW00?oWk?VoiN]i_nG[NH0
0_n=XN42oh>Af@;oO87>0_mlM/82oh5a^0;oTX2l00?oUgnhoi5b[OnIMZ/00_nIMZ/3oiejZ`;oWgf]
0_nLOK000onMNJ[oTW>]oi9c[@02oh5Y[P?oLej/0_mnIZd2ohEWZ@?oSfbV0_nILZD00onSNJGoYWRQ
ojn0XP03ojn0XP05okJ8YOnlRj;o_8^Rokb;X_o1TZD00_o7UZ<2olNIZ0;obi^V00Goa9RZol>EYoo3
UJOo`iFWok^@Z@03000000;o]8RV00Go]8ZYokN8Y?ngR:Co]hRTokZ=Y`02ol2@Y0;o`iNY0_o=WZH0
0oo?YJkofZn/omZ_[002onNmZ`06on?2]_o/ckL00000oo;L^?ociK_oiMo>0_oQgm<00ooJfMKob]3N
olG9g@02olG9g@?o^L;Q0_nb`>@2ok:oh`03ojjni_n^_^Go[;kW00;o[;kW0_nZ_NL00on[_NL00000
ooooo`0Qooooo`002Oooool01000003ooooooooooooooolH000000@06ATI00D0000003<c<`0c<c<0
<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIT000000`2c/k<0
0ol000000000000000030<c<c0030000002c/k<0/k>c00D0/k>c00Go000009VIV@2IVIT0VIVIo`00
000207moO`03o`0000000000IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`3o`0000L0<c<c0_l0
000404a<C08000000`1VIVH200000080Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`04o`00
003<c<`0c<c<o`0000D0i^KV00Go00000000000000000000o`0000030>KViP08o`00003<c<`0c<c<
o`00002c/k<0000009VIV@00000207moO`03o`00001VIVH000000080C4a<00@0000003<c<`0c<c<0
0000100I6ATE000000Cooooo00<00000ooooooooool05Oooool00`00003oooooooooo`02oooooaSo
ZKgX0onX_>P00onV^nSoY;WXoinej003oinej0;oUjgV0_n=XN42oh>Af@03ogb1c_mlM/;oO7K200;o
PG6h0_n9L;43oi5b[@;oVGJ[0onMNZ/2oimm[@03oiam/?nMNJ[oWGVZ00;oTW>]0on1JJh2og=N[0;o
LUZW0_n5IjT3ohm/YP03oiUbYOnJL:7oYWRQ00;oYWRQ0on_P:84okb;XP05ol6BYOo7UZ?oaiJSolNF
Xoo7VJP00_o;VjH00oo4V:[o`iFW00000002000000;o^8VU0ondR:H4okN8Y003okZ=Yoo0T:Co`92T
00;o`iNY0_o=WZH00oo?YJkofZn/onNmZ`02onNmZ`;ok<ng00Gol]bh00000?ociK_ol>S2on7Od`02
om[IeP;odloF00CoaLWMol?3f_o3`m[o^L;Q0_ni_ml2ok:oh`04ok>oh_n^_^Go[[kUojjni@?o[;kW
0on[_NL00`00003oooooooooo`0Oooooo`002Oooool01000003ooooooooooooooolG000000@06ATI
00Go00000000000c<c<0<c<c0000000204a<C0040000001VIVH0IVIVo`000080Ogmo00@0000009VI
V@2IVIT000000`2c/k<00`00003o00000<c<c0050<c<c0030000002c/k<0/k>c00<0/k>c00D00000
09VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV008000000`1<C4`2o`0000`0<c<c0_l0
000404a<C08000000`1VIVH010000000Ogmo07moO`00000309VIV@040000002c/k<0/k>co`000080
c<c<00?o00000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`030?ooo`070000003Vi^H0i^KV0>KV
i_l00000c<c<o`0000020;>c/`070000002IVIT0000007moO`000000IVIV0000000204a<C0040000
000c<c<0<c<c000000@06ATI00?o00000000000000004P000004ooooo`0300000?oooooooooo01Go
oooo00<00000ooooooooool01?oooolGojVmj003ojRlj?nW^nSoYk_X00;oY;WX0_nO]NP00onH/>So
RZCUohZTi@02ogVAg`;oJ7_B0_mlPLh2ogaf`P03oh5a^?n9L;7oRG2a00?oTG:]0onIMZ/2oiejZ`03
oimm[OnQNJKoWGVZ00;oWGVZ0onBLjd2oh5Y[P;oLej/0_mbFZL2ogaNY0;oSfbV00?oRfJRoiY`XOnJ
L:400onVN:43ojn0XPCo_8^R1?o7UZ<2ol^KYP<000000_o3UJL3okR9Y@?o]8RV00Go]8FRokN8Y?ng
R:Co]hRTokZ=Y`03ol2@Y003ol>GZOo=WZKocIjV00;ofZn/0ooW_J/02?occZWok<ngoo;L^?ociK/0
0000oo3X`_oYhLWof]WF0_oCcmH01?o=aM;o`l?Jol?3f_o3`mX3okVog`Co/koR00?o[[kUojnniOn_
_^D00_n/_^L4oj^ni`0300000?oooooooooo01kooooo0009ooooo`0400000?oooooooooooooooaL0
0000100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl0
0`000000VIVI000000030;>c/`030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<00`2c/k<0
1@000000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1VIVH000000`1<C4`2o`000100<c<c
0_l0000404a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl010000000VIVI09VIV@0000020;>c
/`04o`00003<c<`0c<c<o`0000@0i^KV00<000000?ooo`3oool00`3oool01`000000i^KV0>KViP3V
i^Ko00000<c<c?l000000P2c/k<01`000000VIVI0000001oOgl0000006IVIP0000000P1<C4`01000
0000<c<c03<c<`00000401TI6AD000001?ooool00`00003oooooooooo`0Eooooo`0300000?oooooo
oooo00Gooooo5?nY_NP3ojRlj003ojNkj?nU^^SoYK[X00;oXKOX0onH/>P2ohZTi@;oNI7O00?oJ7_B
of1Xa?mPJ<@00_mlM/82oh5a^0;oRG2a0_nALZd3oiUfZ`;oWGZ[0onQNJH3oieiZP;oTW>]0_n1JJh2
og=N[0;oLUZW0_mlGZ@3oh]VXP;oVW2Q0onVN:42ojn0XP;o]HBP0onlRj84olNFX`80000000?obi^V
olbKYOo3UJL00_o3UJL4okR9Y@03okB8Y_ndQJ;o]8FR00?o]hRT1?o0T:@3olfNYP04omZYYOoJ[jco
ikf[onNmZ`;olljY00Son]fVoo;L^?ociK/00000oo3X`_oYhLWoh=?;om??eP?ocLGB00Co`l?Jol:o
eoo2_mOo^KoO0_nk_md2ok>ohP;o];oR00?o[kkUok2oiOn/_^L00_n/_^L3oj^ni`0300000?oooooo
oooo01kooooo0009ooooo`0400000?oooooooooooooooaH00000100I6AT01@000000<c<c03<c<`0c
<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl00`000000VIVI000000020;>c/`800000
2P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00@0000007moO`1oOgl000000P1VIVH01@00
0000C4a<04a<C01<C4co000000L0<c<c1ol0000603<c<`;o00000`1<C4`200000080IVIV00Co0000
07moO`1oOgl000000P2IVIT010000000/k>c0;>c/ol000020<c<c004o`00003Vi^H0i^KV000000L0
oooo00d000000>KViP3Vi^H0i^KVo`00003<c<co00000;>c/ol00000VIVI0000001oOgl000000080
IVIV00<0000004a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6AD000001?ooool00`00003o
ooooooooo`0Eooooo`0300000?oooooooooo00Kooooo5?nY_NP00onX_>SoYkcXojNlj003ojFjj0;o
XKOX00CoV;3XohjYj?mgUnCoMiOT0_mJNmT2ofQkdP03of1Xa?mTG[OoI5jg00;oPG6h0_n9L;43oi5b
[@;oVGJ[00?oWGZ[oiieY?nQNJH00_nQNJH3oieiZP;oTW>]0on1JJh2og=N[003og9JYomlGZCoO5jT
00?oRfJR0_nJL:44ojIhX@03ojn0X_neQ:3o]HBP00;o_8^R00?oaI:QolNFX`0000000P0000001?o>
W:?obi^VolbKYOo<VjD2ol>EY`03okj?YOnhRJGo^8VU00;o^8VU00?o]8RVokB5X_ndQJ800ongR:@4
ol2@Y0;ocIjV0_oJZJD3onNmZ`;olljY00Oon]fVoo_XYOoik:col>S200000?oYhLWoh=?;00?ocLGB
0_o;_/h01?o2_mOoa;kEolBneOnk_md2okg0g@;o];oR00Go]/7Rok2oiOn`_nGo/;oUojbni`02ojfo
i`;oZkkW00?oZkkX00000?ooool07_ooool000Wooooo00@00000oooooooooooooooo5P00000401TI
6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV0000000207moO`030000002IVIWo
00000080/k>c00<000000<c<c03<c<`02P3<c<`01@000000/k>c0;>c/`2c/k<000000080VIVI00Co
000007moO`1oOgl000000P1VIVH01@000000C4a<04a<C01<C4co000000@0<c<c1?l0000701TI6@?o
00001@0c<c<00ol00000C4a<04a<C00204a<C0040000001VIVH0IVIV00000080Ogmo00?o000009VI
V@0000000P2c/k<01?l00000c<c<0<c<c?l000020>KViP030000003oool0oooo00D0oooo00d00000
0>KViP3Vi^H0i^KVo`00003<c<co00000;>c/`000000VIVI0000001oOgl000000080IVIV00<00000
04a<C00000000P0c<c<00`0000006ATI01TI6@0301TI6A@000001?ooool00`00003oooooooooo`0D
ooooo`0300000?oooooooooo00Sooooo4_nY_NP3ojRmj0;oYkcX00?oYK[Xoj>hj?nK/nP00_nK/nP2
ohjYj0;oMiOT00CoFW_IocmLb?loG<SoH6S40_mTG[L2og1N[P;oRG2a0onALZd01?nIMZ_oUg2Toiie
Y?nNMJ@3oj5iYP?oWGVZ00?oTW>]oi=bZomkHj`00_mkHj`2og=N[0;oLUZW00CoO5jToh]VX_n;IZ;o
RfJR0onJL:43ojIhX@04ojn0X_neQ:3o]HBPokb;XP<000000_o7UZ<2oljLX`03ol^KY_o<VjGoc9^U
00;o`iFW0_nnSjD3okR9Y@Co]8FR00?o]hRTok^:XOo0T:@00_o0T:@2olVGXP03olfNY_oJZJGofZVU
00;oikf[0_occZT2oo[MYP08oo_XYOoik:comNNionWQb@00003oh=?;omO4aoo=aM82ol^ncP04olfl
b_o4_]Goa;kEolBne@?o_L3M1?nf`N800on`_nGo/<3Vok30iP02ojfoi`CoZkkX00<00000oooooooo
ool07?ooool000Wooooo00@00000oooooooooooooooo5P00000401TI6@050000000c<c<0<c<c03<c
<`0000000P1<C4`00`000000IVIV0000000207moO`030000002IVIT000000080/k>c00<000000<c<
c03<c<`00P3<c<`3o`0000D0c<c<00L000000;>c/`2c/k<0/k>c0000002IVIT0000000<0Ogmo00@0
000006IVIP1VIVH000000`1<C4`01Ol00000<c<c03<c<`0c<c?o000000h06ATI00?o000003<c<`0c
<c<00`0c<c<01Ol00000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000P2IVIT0
0ol00000/k>co`0000020<c<c004o`00003Vi^H0i^KV000000L0oooo00d000000>KViP3Vi^H0i^KV
o`00003<c<co00000;>c/`000000VIVI0000001oOgl000000080IVIV00<0000004a<C00000000P0c
<c<00`0000006ATI01TI6@0301TI6A@000001?ooool00`00003oooooooooo`0Dooooo`0300000?oo
oooooooo00[ooooo4?nY_NP2ojRmj004ojRlj?nV^nSoY[_XojJkj0;oXkSX00?oVk?XoiB]j?nD[NP0
0_n0WnH01omNQ>3oFW_IoeYkfOloG<So=TNgof1Xa?mTG[L00_m`GZh2ogmSZ0?oS6VU0_nGL:@3oiie
Y0?oXGVV0_nMNJX3oi=bZ`;oNf>/0_mUE:T2og9JY`;oO5jT0on;IZ82oiY`X@?oYWRQ00Go]HBP0000
000000000000okb;XP02olFBX@05olNFXoo>W:?ocYbSoljLXoo;VjH00oo<VjD00oo3UJOo_XnUokj?
Y@03okR9Y@Co]8FR00?o]hRTok^:XOnkRZ400_o0T:@2olVGXP05olfNY_oJZJGofZVUonVjY?oW_J/0
0_occZT02oojgJKonnRUooW/[?oik:comNNion[F`?oPdl/00000omO4aooC^l;obkk>00?ocKc:00Co
a;kEolO0e?o7`=Co_L3M0_no`md2okK1hP;o]l?S00?o/<3Vok31i_n]_nL00_n]_nL3oj^nj0030000
0?oooooooooo01cooooo0009ooooo`0400000?oooooooooooooooaH00000100I6AT01@000000<c<c
03<c<`0c<c<000000080C4a<0P00000207moO`060000002IVIT0VIVI0000002c/k<00000103<c<`0
1?l00000i^KV0>KViP3Vi^H2o`0000<0c<c<00L000000;>c/`2c/k<0/k>c0000002IVIT000000080
Ogmo00@0000006IVIP1VIVH000000`1<C4`01Ol00000<c<c03<c<`0c<c?o000001006ATI0_l00004
03<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH01P000000Ogmo07moO`000000VIVI00000080
/k>c00?o00000<c<c?l000000`3Vi^H00`000000oooo0?ooo`040?ooo`0=0000003Vi^H0i^KV0>KV
i_l00000c<c<o`00002c/k<0000009VIV@000000Ogmo0000000206IVIP030000001<C4`000000080
<c<c00<0000001TI6@0I6AT00P0I6ATE000000Cooooo00<00000ooooooooool05?ooool00`00003o
ooooooooo`0:oooooa7oZKgX0onX_>P00onV^nSoY;WXojBij003oinej0;oU:gX0_n0WnH00omNQ>3o
<5g>ocmLb002ocI7]`;oI5jg00?oL5j^ogmSZ?moHjP00on<JJD2oiM`Y0?oWWFT0onQNJH00onMNJ[o
XGVVoi=bZ`02oi=bZ`;oNf>/0_mUE:T01?mSCjGoLUZWogaNY?mlGZ@3oh]VXP;oVW2Q00CoYWRQ0000
0000000000000oneQ:03olFBX@04olNFXoo>W:?ocYbSoljLX`Coc9^U0onnSjD2okR9Y@Go]8FR0onk
RZ401?o0T:CobINRolVGX_o9Uj82omZYY@;ojKZT0_ogcIl01?occZWon]fVoo_XYOoik:`2ooGW^@03
on[F`?oN`[d0000000;odk_20oo=_<X01_o@_/Woal3DolO0e?o7`=Cob/CDoko3g@;o`LKN0_ng`n<0
1Onga>Co/<7Vok31i_n``NKo[KoW00;o[;oW0on[_^P00`00003oooooooooo`0Kooooo`002Oooool0
1000003ooooooooooooooolF000000@06ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV
0000000207moO`030000002IVIT000000080/k>c00D000000<c<c03<c<`0c<c<o`0000050>KViP05
o`00003<c<`0c<c<0<c<c00000000P2c/k<00`000000VIVI0000000307moO`040000001VIVH0IVIV
00000080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0@01TI6@03o`00000c<c<0
<c<c0080<c<c00Oo000004a<C01<C4`0C4a<o`00001VIVH000000080Ogmo00H0000009VIV@2IVIT0
00000;>c/ol000020<c<c003o`00003Vi^H0i^KV00800000103oool01@000000i^KV0>KViP3Vi^Ko
00000080c<c<00Wo00000;>c/`000000VIVI0000001oOgl0000006IVIP0000000P1<C4`010000000
<c<c03<c<`00000401TI6@03o`00000000000000018000001?ooool00`00003oooooooooo`0Doooo
o`0300000?oooooooooo00_ooooo4OnY_NP00onX_>SoYk_XojNkj003ojBij004oinej?nJ/>OoRjGV
oh^UiP;oL97R0_m3K]L01_l7=;Go?ec8ocI7]om2@jcoI5jgog1N[P;oOf>X0on<JJD3oiM`Y0;oWWFT
0_nQNJH00onTNJ?oXGVVoj5iYP03oi=bZ`;oNf>/0_mUE:T2of=?Y@;oO5jT0on;IZ83000000;oZg^P
1?neQ:03olFBX@CocYbS1?o<VjD3okj?Y@03okR9YOndQJ;o]8FR00Co]8FR0onkRZ401?o0T:CobINR
olVGX_o9Uj82omZYY@;ojKZT0_ogcIl01OongYOon]fVoo_XYOoik:comNNi00;oj]K000Kog/:mom>k
`P00003odk_2om>h__o=_<X3om2nb@03olO0e?o:a=Cob/CD00?o`LKN1?nga>@01On``NKo/<7Wok31
ion/_nOo[;oX00?oZkkX00?ooooo00000?ooool06oooool000Wooooo00@00000oooooooooooooooo
5P00000401TI6@040000000c<c<0<c<c00000080C4a<00D0000006IVI_l00000Ogmo0000000209VI
V@030000002c/k<0000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H01Ol00000c<c<0<c<c03<c<`0
00000080/k>c00?o000009VIV@0000000P1oOgl010000000IVIV06IVIP00000204a<C003o`00000c
<c<0<c<c0080<c<c00?o000001TI6@0I6AT04P0I6AT00ol00000<c<c03<c<`0203<c<`04o`00001<
C4`0C4a<00000080IVIV00P0000007moO`1oOgl0000009VIV@000000/k>co`000080c<c<00Co0000
0>KViP3Vi^H0i^KV0`0000020?ooo`05o`00003Vi^H0i^KV0>KVi_l000000P3<c<`02Ol00000/k>c
0000002IVIT0000007moO`000000IVIV0000000204a<C0040000000c<c<0<c<c000000@06ATI5@00
0004ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool03Oooool=ojVmj0?oZ;cX00?o
Yk_XojFiionU^NL00onQ]^L2oiZ`i`;oRjGV0_m`TN801?m3K]Oo13^lo`Ld]OlfAkL2od93[0;oL5j^
0_moHjP3ohaYY@;oUg2T0_nNMJ@00onQNJKoY7VSojAiX`03oj5iYP?oTg:[0_mkHj`00omUE:WoHdnU
of=?Y@02og9GX`<0000000?oVW2QoiaaXOn[Nj000on[Nj03okF4X0?oaI:Q00?ocibRoljLXoo>W:<0
0_oDXj@2olbKY@;obIZV0_nnSjD6okB5XP04okN5XOnkRZ7o^hZQok^:X@CobINR00CoeZ>RomZYYOoY
^ZCojKZT0_ogcIl01_ongYOon^J>ooO[U?ojjZWolMNgon[F`0;og/:m00CoekJhom>k`P00003odkRn
0oo@_/T2omK4b@04ol[4e?o>b]Koc/[Fol76gP;o`LWQ0_nga>@00onfaNKo/<7Wok31i`02ojo1i`;o
[;oX00CoZkkXojZnj?nZ_^P000007?ooool000Wooooo00@00000oooooooooooooooo5P00000401TI
6@040000000c<c<0<c<c00000080C4a<00D0000006IVIP000000Ogmo0000000209VIV@030000002c
/k<0000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H01Ol00000c<c<0<c<c03<c<`000000080/k>c
00<0000009VIV@0000000P1oOgl010000000IVIV06IVIP00000204a<C003o`00000c<c<0<c<c0080
<c<c00?o000001TI6@0I6AT0100I6AT6o`0000T06ATI00Go000003<c<`0c<c<0<c<co`00000204a<
C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@000000/k>co`0000030<c<c003o`00003V
i^H0i^KV00<0i^KV0P0000040>KViP0<o`00003<c<`0c<c<o`00002c/k<0000009VIV@000000Ogmo
0000001VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6AD000001?ooool00`00003ooooo
ooooo`0Dooooo`0300000?oooooooooo00gooooo3_nY_NP01?nX_>SoYk_XojNkj?nW^nP2ojFii`04
oj6fionL/NKoTZSToi:Xi0;oP9WQ0_mRP=X2od=^e`06o`@k_?lfAkOo=TNgod93[?mJBjKoL5j^0_mo
HjP3ohaYY@;oUg2T0_nNMJ@3ojAiX`?oXGVV0onCLZ/2og]S[0;oIEBY0`000003ohQTXP;oW76Q1?n[
Nj02okF4X003okn<XOo5TZ7oaI:Q00;ocibR0_o>W:<2omBSY004olbKYOo9VZKobIZVolVJYP;o_XnU
00?o^8VTokB5X_ndQJ800_ndQJ83okN5X@;o^hZQ00?oa92PolVGX_o9Uj800_oFXj82onVjY0;omlfO
0_ongYL01?ojiXkomn^Doo[ZZOoaekL2omk2_@;oekJh00GodkRn00000?oC^;kof;^lom2nb@03omK4
b@?oc/[F00God=3Jol79hOo1c>?o`LcSokK5iP02okG6i`;o[l7W00Co[/7Xojboj?n/_nSo[;oX0_nZ
_^P00oooool00000ooooo`0Jooooo`002Oooool01000003ooooooooooooooolE000000D06ATI00@0
000003<c<`0c<c<000000P1<C4`01`000000IVIV0000001oOgl0000009VIV@0000000P2c/k<01000
0000c<c<0<c<c?l000080>KViP04o`00003<c<`0c<c<00000080/k>c00D0000009VIV@000000Ogmo
0000000206IVIP040000001<C4`0C4a<o`0000@0<c<c00?o000001TI6@0I6AT0100I6AT00ol00000
000000000004000000;o0000200I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00@0000006IV
IP1VIVH000000P1oOgl01@000000VIVI0000002c/k?o000000<0c<c<00?o00000>KViP3Vi^H01`3V
i^H02?l00000c<c<0<c<c?l00000/k>c0000002IVIT000000P1oOgl01Ol00000IVIV0000001<C4`0
000000<0<c<c00<0000001TI6@0I6AT00P0I6ATE000000Cooooo00<00000ooooooooool04oooool0
0`00003oooooooooo`0?ooooo`coZKgX0onX_>P00onW^nSoY[[Xoj:gi`02oj:gi`;oW;7V0_nBZ>@2
oh2Ih@07of:0f_l_FL_o;eW;o`@k_?l7=;Go=TNgod93[002oeY;YP;oOf>X0on<JJD2oiM`Y003oiie
Y?nQMJ7oY7VS00?oY7VS0_nQNJH2oi=bZ`03oiMg[OmeHZl000000080000000?oHdnUog9GXombEj<0
0on8I:83oiaaX@?oZg^P00Go]HBPokn<XOnoS:7o_hbQolFBX@02olnLXP;ocYbS0_oDXj@4olVJYP03
okj?YOnhRJCo^8VT00Co]8FR0ongQJ400onkRZ7oa92PolB@X002olVGXP;oeZ>R0_oY^Z@2ooO=W`04
ookNUoojiXkomn^Doo[ZZ@;olMNg00WohKneomk2_OoG][SoekJhomNb]?oC^;h00000omRk_?oO`[`0
0ooFa<T01_oKcL_oc/[Fom3@f_o@d=[ocmGMol7<h`;o_/gU00?o]LKWok?5j?n^`NP00on^`NP00on/
_nSoZkoXoj^oj002ojZnj00300000?oooooooooo01Wooooo0009ooooo`0400000?oooooooooooooo
oaD000001@0I6AT010000000<c<c03<c<`00000204a<C0070000001VIVH0000007moO`000000VIVI
000000020;>c/`040000003<c<`0c<c<o`0000P0i^KV00Ko00000<c<c03<c<`000000;>c/`000002
09VIV@030000001oOgl000000080IVIV00@0000004a<C01<C4co00000`0c<c<00ol000006ATI01TI
6@0401TI6@03o`0000000000000000L000000_l0000701TI6@05o`00000c<c<0<c<c03<c<ol00000
0P1<C4`01P000000IVIV06IVIP000000Ogmoo`000080VIVI00<000000;>c/ol000000`3<c<`00ol0
0000i^KV0>KViP030>KViP?o00000P3<c<`02?l00000/k>c0;>c/`000000VIVI0000001oOgl00000
0P1VIVH00`000000C4a<0000000303<c<`030000000I6AT06ATI00806ATI5@000004ooooo`030000
0?oooooooooo01?ooooo00<00000ooooooooool04Oooool;ojVmj003ojRlj?nW_>SoY[[X00;oY[[X
00?oX[OWoifbionM/^L00_nDZND2ohNLh008og>9f_mEK/ooEFk?obmIbol08:_o13^lo`0MX_m2@j`2
oeY;YP;oLeNS0on<JJD01?nGL:CoUfjQoj5eXOnQMJ44ojAiX`;oXGVV0_nGMjd200000003ogER[om@
BJ_oIEBY00;oHdnU0_mbEj<2ohQTXP?oW76Q0on[Nj001OneQ:3o_hbQokn<XOnoS:7oaI:Q00?ocibR
0ooDXj@01?oFZ:SobIZVolVJY_o9VZH3okR9Y0?o]8FR1?ngQJ400onkRZ7oa92PolB@X002olVGXP;o
eZ>R00?oj;JQonVjY?ogcIl00_ongYL01?ojiXkomn^Doo[ZZOoaekL2on6o]@;oekJh0_oG/[@00ooC
^;kof;^l00000002omo2_005omK4bOoKcL_oflg;omoFc_o@d=X00_o?eMd01?o=f>;o_/gUok_=ionk
cNL2ok?5j0;o[/7X0_n]`NP00on[_nSoZkkXojZnj002ojZnj00300000?oooooooooo01Sooooo0009
ooooo`0400000?oooooooooooooooaD000001@0I6AT010000000<c<c03<c<`00000204a<C0070000
001VIVH0000007moO`000000VIVI000000020;>c/`040000003<c<`0c<c<o`0000P0i^KV00Ko0000
0<c<c03<c<`000000;>c/`00000209VIV@030000001oOgl000000080IVIV00@0000004a<C01<C4co
00000`0c<c<00ol000006ATI01TI6@0401TI6@03o`0000000000000000P0000000?o000001TI6@0I
6AT01@0I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00H0000006IVIP1VIVH0000007moO`00
000209VIV@04o`00002c/k<0/k>co`0000<0c<c<1Ol000040<c<c009o`00002c/k<0/k>c0;>c/`00
0000VIVI0000001oOgl000000080IVIV00<0000004a<C00000000`0c<c<00`0000006ATI01TI6@02
01TI6AD000001?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01;ooooo2OnY_NP2
ojRmj0;oYkcX00?oY[[Xoj>hj?nS^>P00onM/^L2oiBYi@;oQicP00KoLhWJoeE^colXBKoo;eW;o`0P
Zol01iT2od93[003oeY;Y_mcEj?oLeNS00?oR6>R0_nGKZ43oj5eX@?oY7VS00CoXGVV000000000000
00000_nGMjd00omeHZooD4V[oe19Z`02of=?Y@;oLUNS0_n8I:83oiaaX@?oZg^P1?noS:44olnLXP;o
e:>T0_oFZ:P3olVJYPCo^8VT0_ndQJ84okN5X@04ok^:XOo4T:3oa92PolB@X0?oeZ>R00?oj;JQooO=
WoogcIl00_ongYL01?ojiXkon>bKooCI/_oaekL2on6o]@04omR`/?oG][Soek:domNb]0;of;^l00Go
gl:l00000?oO`[coilfmom_=b`02omoFcP04on7Odoo?eMgocMSRolgHhP?o^lgW0onaa>P2ojg1j0;o
[<3X0_n[_^P3ojZnj00300000?oooooooooo01Oooooo0009ooooo`0400000?oooooooooooooooaD0
00001@0I6AT010000000<c<c03<c<`00000204a<C0070000001VIVH0000007moO`000000VIVI0000
00020;>c/`050000003<c<`0c<c<0<c<c?l000001P3Vi^H01?l00000c<c<0<c<c00000020;>c/`06
0000002IVIT0VIVI0000001oOgl000000P1VIVH010000000C4a<04a<C?l0000203<c<`03o`00000I
6AT06ATI00@06ATI00?o00000000000000002P0000000ol000006ATI01TI6@0501TI6@05o`00000c
<c<0<c<c03<c<ol000000P1<C4`00`000000IVIV0000000207moO`030000002IVIT0000000<0/k>c
00?o00000<c<c03<c<`0203<c<`01ol00000/k>c0;>c/`2c/k<0000009VIV@0000000P1oOgl00`00
0000IVIV0000000204a<C0050000000c<c<0<c<c03<c<`000000100I6ATE000000Cooooo00<00000
ooooooooool04oooool00`00003oooooooooo`0Cooooo`SoZKgX00?oZ;gXojRlj?nX_>P00onV^nP2
oj>hj004oifbionE[>KoR9oSohROh`;oMhcK0_mSM]001omEK/oo:4Voo`0PZol01iWo01fRod93[?mJ
BjH00_mcEj<3ohQSXP;oUfjQ0onQMJ401?nTNJ<00000000000000002ojQoY`?oUgN]0_meHZl00om@
BJ_oB46Vof=?Y@02og9GX`?oR6BR0_nLLJ43oj]kX0Co_hbQ1?o?W:82omBSY0;oeZRX0_o9VZH00oo2
UJWo^8VTokR9Y002okR9Y003okB5X_ncPj;o/h>R00?o]hFQ1?o4T:02omJSXP;oj;JQ00OonLjKooO=
WoongYOon^J>onWTN_ohk9_om=Vb00;ohKne0_oH/;03omNb]004ombf/_oH^kcogl:l000000;oilfm
00?okMZoomoFc_oQgm<00_oNiMT01?o=f>;ob=SVolSHi_nkcNL2okO;j@03ok74j?n_`nWo[l?Y00;o
[<3X00?oZkoXojZnj?nZ_^P00_nZ_^P00onY_NP00000ooooo`0Hooooo`002Oooool01000003ooooo
oooooooooolF000000@06ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207mo
O`050000002IVIT000000;>c/`0000000`3<c<`00ol00000i^KV0>KViP040>KViP04o`00003<c<`0
c<c<o`000080/k>c00D0000009VIV@000000Ogmo0000000206IVIP040000001<C4`0C4a<o`0000<0
<c<c00?o000001TI6@0I6AT00`0I6AT00ol0000000000000000<00000003o`00000I6AT06ATI00@0
6ATI00Go000003<c<`0c<c<0<c<co`00000204a<C006o`00001VIVH0IVIV0000001oOgl000000P2I
VIT01@000000/k>c0;>c/`2c/k?o000000P0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@03
0000001oOgl000000080IVIV00<0000004a<C00000000`0c<c<00`0000006ATI01TI6@0201TI6AH0
00001?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01Cooooo2?nY_NP3ojRlj003
ojJkj?nS^NSoW[CX00;oW[CX0_nE[>H2ohROh`;oMhcK00OoHgK@odYL`om:G<?o022[o`00O_l0087o
3anM00;oFT^V00CoLeNSohQSX_n8Hj;oR6>R0onGKZ4300000003ojAiXon/Oj?oZ7nW00;oZ7nW0onG
Mjd2ogER[`03oe19Zom8@JKoB46V00;oLUNS0on8I:83oiaaX@03oj]kX?ncQ:;o_hbQ00?o_hbQ0oo?
W:82omZYY005omBSY?oFZ:SoeZRXomJXZ?o9VZH00_o2UJT3okR9Y0?o/h>R0ongQJ44olB@X0;oeZ>R
0_oX]Z401OoicY_ooMn;oogORoo^hGOon>bK00;om=Vb00KohK^aon6o]OoH/;3of;2`omN/[?oG/[@2
ombf/P07onBn/OoO`[coilfm00000?oWcKgokMZoon7Od`02omkUf@;of>OP00Cob=SVol7EjOo1eNWo
]l_Y0_ncb>T00on_`nWo[L7Yoj^oj002oj^oj0CoZ[kX0_nY_NP00`00003oooooooooo`0Fooooo`00
2Oooool01000003ooooooooooooooolF000000@06ATI00@0000003<c<`0c<c<000000P1<C4`00`00
0000IVIV0000000207moO`050000002IVIT000000;>c/ol00000103<c<`2o`000080i^KV0_l00003
0<c<c0080000002c/k<0/k>c0000002IVIT0000007moO`00000206IVIP040000001<C4`0C4a<o`00
0080<c<c00?o000001TI6@0I6AT00`0I6AT00ol0000000000000000>00000003o`00000I6AT06ATI
00@06ATI00Go000003<c<`0c<c<0<c<co`00000204a<C0060000001VIVKo00000000001oOgl00000
0P2IVIT200000080/k>c2?l000020;>c/`8000000P2IVIT01P000000Ogmo07moO`000000IVIVo`00
0080C4a<00D0000003<c<`0c<c<0<c<c0000000401TI6AH000001?ooool00`00003oooooooooo`0C
ooooo`0300000?oooooooooo01Gooooo1_nY_NP2ojRlj0?oY[_X0_nS^NP01?nN]>SoU[3YohRTion8
Y>L2ogB@h0;oGWSD0_mSM]001Om:G<?o:cndo`0PZol01iWo3anM00;oFT^V00CoLeNSohQSX_n8Hj;o
R6>R0`000002oj5eX@03ojAiXon/Oj?o[7nS00?oZ7nW0_nGMjd01?nQQ;GoK6RlofaX_?m@BJ/2odQ1
YP;oHDnW00?oLUNSohQTX_n8I:800onLLJ400on[Nj3o/hBRok>4XP02okn<X@;oc9ZS0_o?W:82omZY
Y0CoeZRX0oo2UJT2okR9Y004ok:5YOncPj;o/h>Rok>3XP;o]hFQ00Co_8^QolB@X?o4T:3oa92P0_oA
WJ401?oFXj;oj;JQonRfXOoicY/2oogOR`03onWTN_odfK;om=Vb00;ohK^a0_oH/;02omN/[004omNb
]?oL][;og;JbonBn/@?oilfm00@00000ongJ_oo^lLSog^GI0_oHin000oo?iNKo`MGYol7Ej@02ok_A
j`03ok?8jOn`aNWo/<GY00;o[L7Y00?oZkoXoj^nj?n[_^P00onZ_^P3ojVmj00300000?oooooooooo
01Gooooo0009ooooo`0400000?oooooooooooooooaH00000100I6AT010000000<c<c03<c<`000002
04a<C0030000001VIVH000000080Ogmo00D0000009VIV@000000/k>c000000060<c<c0;o00001@3<
c<`020000000/k>c0;>c/`000000VIVI0000001oOgoo00000P1VIVH010000000C4a<04a<C?l00002
03<c<`03o`00000I6AT06ATI00<06ATI00?o00000000000000003P0000000ol000006ATI01TI6@04
01TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`010000000IVIV06IVIP00000207moO`05o`00
002IVIT0VIVI09VIV@0000002P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl000000080
IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6AH000001?ooool00`00
003oooooooooo`0Booooo`0300000?oooooooooo01Oooooo1_nY_NP2ojRlj003ojJkj?nU^nWoWkOY
00;oWkOY0_nF/>T2ohRTi`;oM93P00CoGWSDod]OaOm;GlGoBUc30_l[?k@01Ol007ko0021ocPcWomJ
BjKoLeNS00<0000000?oR6>RoiM^XOnGKZ400_nQMJ44ojaoX`;oZ7nW0onQQ;D2ofaX_0;oD4V[00Co
B46Vof5?YomQCjOoHDnW0_n8I:82oiaaX@04oj5gY?ncQ:;o/hBRok>4XP;o_hbQ0_o<VZ<01?o?W:;o
fZVTomZYY?oJZJ@4omJXZ0?o`YFY00?o^8VTok:5YOnbQJD01?ncPj800ongQJ7o_8^Qokb;X@02olB@
X0;odIfQ0_oX]Z42ooW>V`04oogORoo^hGOon>bKooCI/P?ohK^a00CoeZZ[omR`/?oG[:coejb/0_oL
][82onBn/@09onk</?oWcKgokMZoongJ_`00003ok_78onOgd?oHin3ocnGV00;oa]k[0_nkdN/2okG<
j`03ok35jOn^`nWo[<3X00;o[<3X00?oZkkXojZnj?nZ_^P00onZ_^P2ojVmj00300000?oooooooooo
01Gooooo0009ooooo`0400000?oooooooooooooooaH00000100I6AT01@000000<c<c03<c<`0c<c<0
00000080C4a<00D0000006IVIP000000Ogmo0000000209VIV@030000002c/k<0000000/0c<c<00H0
00000;>c/`2c/k<0000009VIV@00000207moO`030000001VIVH000000080C4a<00Go000003<c<`0c
<c<0<c<co`00000501TI6@03o`0000000000000000l0000000?o000001TI6@0I6AT00`0I6AT00ol0
0000<c<c03<c<`0203<c<`04o`00001<C4`0C4a<00000080IVIV00<0000007moO`000000102IVIT0
0`000000/k>c0;>c/`060;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moOol000000`1VIVH0
0`000000C4a<0000000303<c<`030000000I6AT06ATI00806ATI5`000004ooooo`0300000?oooooo
oooo01;ooooo00<00000ooooooooool06?ooool4ojVmj004ojRmj?nW_>SoYkcXojNlj0;oYK_Y00?o
WkOYoiZejonJ]N/00_n;Zn/2ogBHi`09oeElg?mNN=CoGWSDod]OaOlkB[OoBUc3ob/o]?l007ko0021
00<0000000CoLeNSohQSX_n8Hj;oR6>R0_nGKZ400onQMJ7oYgZQojaoX`03ojaoX`;oZ7nW00Oo]Hf/
oj64]OnQQ;GoXHBeofaX_?lR>K7oD4V[00;oB46V0_mQCjL2ohAUY`?oXGNT0oncQ:801OnoS:7oc9ZS
olbJXoo<VZ?ocibR00?ofZVT0ooFZ:P2om>[[`;o`YFY1?nbQJD3ok>3XP04okN5XOnlRj7o_8^QolB@
X0?odIfQ0_oX]Z401_oicY_ooMn;oogORooYi7[om=ZcooCI/P;ohK^a0_oFZZ/01_oH/;3oejb/omN/
[?oL/:[og;JbonBn/@;ok/b`00Commb_ongJ_oo`il8000000_oWmm000ooMmmcodO3WolKNj`02okgF
k@;o]Lc[00Go/LO[ojk3jOn^`nWo[/?Yojc0j002oj^oj0;oZ[kX1_nY_NP00`00003oooooooooo`0D
ooooo`002Oooool01000003ooooooooooooooolF000000@06ATI00D0000003<c<`0c<c<0<c<c0000
000204a<C0050000001VIVH0000007moO`0000000P2IVIT010000000/k>c0;>c/`00000:0<c<c006
0000002c/k<0/k>c0000002IVIT000000P1oOgl00`000000IVIV0000000204a<C005o`00000c<c<0
<c<c03<c<ol000001@0I6AT00ol0000000000000000?00000003o`00000I6AT06ATI00<06ATI00?o
000003<c<`0c<c<00P0c<c<01?l00000C4a<04a<C000000206IVIP040000001oOgl0Ogmo000000@0
VIVI00<000000;>c/`2c/k<00`2c/k<2000000@0VIVI00@0000007moO`1oOgl000000P1VIVH01000
0000C4a<04a<C000000303<c<`030000000I6AT06ATI00806ATI5`000004ooooo`0300000?oooooo
oooo01;ooooo00<00000ooooooooool06Oooool3ojVmj0;oZ;gX00CoYkcXojJljOnV_>WoY[cY0_nR
^^T2oiZej`;oRj_[0_mdV>L00omEO=co>5c;od]Oa@02oc]:]`<0000000Co3anMocPcWomSC:;oLeNS
0on8Hj82oiM^X@?oYgZQ0on/Oj<00onXOjOo]Hf/okF=[003oj64]@;oK6Rl00?o8SVaodQ1Y_m8@JH0
0_mQCjL2ohAUY`?oXGNT0oncQ:801?noS:7oc9ZSolbJXoo<VZ<3omZYY0;oi;Z[00CoeZRXom>[[ooC
Zjoodj^_0_o2UJT4ok:5Y@?o/h>R0onlRj403?o4T:3odIfQom6MXOoAWJ7oiK>RonRfXOoicY_ooMn;
onkQMoo^kI3om=Zcomfe/0;ohK^a0_oFZZ/2omN/[0;og;2Z0_oT_[42onk</007ooOL[ooijjcol_BY
onKi[@00003ogOOLom7`i`02olKUk@05okgFkOnfc^co]/k/ok77jon^`nX01?n/`NT00on[_nSoZ[kX
ojZnj002ojZnj0KoZKgX00<00000ooooooooool04oooool000Wooooo00@00000oooooooooooooooo
5P00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV0000000207moO`03
o`00002IVIT000000080/k>c00<000000<c<c03<c<`0203<c<`01P000000/k>c0;>c/`000000VIVI
00000080Ogmo00<0000006IVIP0000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000D06ATI00?o
00000000000000003`0000000ol000006ATI01TI6@0301TI6@03o`00000c<c<0<c<c0080<c<c00Co
000004a<C01<C4`000000P1VIVH010000000Ogmo07moO`00000509VIV@03o`000000000000000080
00001@2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00@0000004a<C01<C4`000000`0c<c<0
0`0000006ATI01TI6@0201TI6AL000001?ooool00`00003oooooooooo`0Booooo`0300000?oooooo
oooo01[ooooo0onY_NP3ojRmj003ojJljOnU^nWoWkW[00;oWkW[0_nC/^`2ogbTk@04oeJ8i_lSG]?o
8ekCobI2^080000000Go;CR[ob/o]?l07J7o0021ocPcW`02of=<XP?oR6>R00?oUfjQoiY`XOnWNZ40
0_nWNZ43ojaoX`?o]Hf/0onQQ;D2oe9kg@03ob8i/Ol99ZOoB46V00;oHDnW0_n4IJL4oj5gY0;o/hBR
1?o<VZ<00ooL[jWofZVTomZYY002onBjZ`05omJXZ?oCZjoodj^_om>[[oo2UJT00_nfSjd3ok:5Y@;o
/h>R00Co]8JSokb;XOnlRj7o_8^Q1?oAWJ401OoU/j;onLjKooW>Voomgh_oa]=K00;om=Zc0_oM]K00
1OoQ^k7oeZZ[omJZZooEYZOoejb/00;og;2Z00?oik^XonBn/Oo^c;000_ogg:l01ooijjcol_BYonKi
[OoLoKd00000olggjOo6iNd00_nlfNl00onfc^co/<S[ok38j`02ojk3jP;o[<7Y0_n[_nP3ojZnj0Oo
ZKgX00<00000ooooooooool04oooool000Wooooo00@00000oooooooooooooooo5`00000401TI6@04
0000000c<c<0<c<c00000080C4a<00H0000006IVIP1VIVH0000007moO`00000209VIV@040000002c
/k<0/k>c000000P0c<c<00@000000;>c/`2c/k<000000P2IVIT01P000000Ogmo07moO`000000IVIV
00000080C4a<00Go000003<c<`0c<c<0<c<co`00000501TI6@03o`0000000000000000l0000000?o
000001TI6@0I6AT0100I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00D0000006IVIP1VIVH0
IVIV0000000207moO`030000002IVIT0VIVI00/0VIVI00D0000007moO`1oOgl0Ogmo0000000206IV
IP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6ATG000000Cooooo00<00000
ooooooooool04_ooool00`00003oooooooooo`0Looooo`;oZKgX00?oZ;gXojNlj?nW_>P00_nU^nT0
1?nO^N_oW;S/oh^`kon;/>l2ofRLkP06obYbh0000000000000000?lV@[So>dZg0_l]>:/00ol07J7o
001LocPcW`02of=<XP?oQ66R0_nJL:43ojMjX@?o[7nS1?neSJ`00onQQ;Go]:G9okBUb@02oe9kg@03
ob8i/Ol99ZOoB46V00;oHDnW00?oQ6FWoj5gY?nQMj@00_nQMj@2ok>4XP03ol6DZ?o<VZ?oc9ZS00;o
g:nY0_oJZJ@2onBjZ`Codj^_0onfSjd3ok:5Y@03ok>3X_ndQZ?o]8JS00?o_8^Q00?ob9RTom6MXOoA
WJ400_oU/j801OojdYgooMn;oloDFoo^kI3om=Zc00?ogKF`0_oFZZ/2omFVY`0@omN/[?oL/:[oik^X
onNkZ?ocbjKok/b`ooOL[ooijjcol_BYonKi[OoLoKgoeOoFolggj@00003o`^O`okcIk`;o]<o]00?o
/<S[ojg3j_n/`NT00_n/`NT2oj^oj0CoZ[kX2?nY_NP00`00003oooooooooo`0Booooo`002Oooool0
1000003ooooooooooooooolG000000@06ATI00@0000003<c<`0c<c<000000P1<C4`01P000000IVIV
06IVIP000000Ogmo00000080VIVI00D000000;>c/`2c/k<0/k>c000000060<c<c0050000002c/k<0
/k>c0;>c/`0000000P2IVIT01P000000Ogmo07moO`000000IVIV00000080C4a<00Go000003<c<`0c
<c<0<c<co`00000501TI6@03o`0000000000000000l0000000?o000001TI6@0I6AT0100I6AT01Ol0
0000<c<c03<c<`0c<c?o00000080C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002I
VIT0VIVI00T0VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP050000001<C4`0C4a<04a<C000
00000`0c<c<00`0000006ATI01TI6@0301TI6AL000001?ooool00`00003oooooooooo`0Booooo`03
00000?oooooooooo01cooooo0onY_NP00onW_>SoYkcYoj>kjP02oj>kjP;oW;S/00goRk3_00000000
00000000obYbh?l0<;So8ekCobI2^?lS=:_o>dZgobdhZol07J7o001<00;o>3>O00CoHdbRohAQX_n4
HJ;oQ66R0_nJL:44ojMjX@03ojaoXoniS:Oo^HbW00?o]Hf/0ondYLT3oe9kg@;o2BJW0_mQCjL2ohAU
Y`?oXGNT00?o/hBRol6DZ?o1U:P00_o<VZ<3omb_Z@?oi;Z[00Coj/fhom>[[ooCZjoodj^_0onfSjd3
ok:5Y@Co]8JS00?o_8^QolRHY?o8V:@00_oAWJ42onFcXP05oo[BWOoghh;oa]=Konk]T?odf[<00ooM
]K001?o@XjWoeZZ[omFVYooEYZL2omb`ZP;oik^X00[oll^VoocLWoogg:oonN^/oo;dZOnfhWoo^O:T
ol?fk_o2io0000000_nhf?000ondcngo[lO/ojo7k002ojg3jP03ojc1jOn[_nWoZkoY00CoZ[kX2OnY
_NP00`00003oooooooooo`0Booooo`002Oooool01000003ooooooooooooooolG000000@06ATI00@0
000003<c<`0c<c<000000P1<C4`01P000000IVIV06IVIP000000Ogmo00000080VIVI00Go00000;>c
/`2c/k<0/k>c000000060<c<c0050000002c/k<0/k>c0;>c/`0000000P2IVIT01P000000Ogmo07mo
O`000000IVIV00000080C4a<00Go000003<c<`0c<c<0<c<co`00000501TI6@03o`00000000000000
00l0000000?o000001TI6@0I6AT0100I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00D00000
06IVIP1VIVH0IVIV0000000307moO`030000002IVIT0VIVI00T0VIVI00D0000007moO`1oOgl0Ogmo
0000000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0301TI6AL0
00001?ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01gooooo00?oZKgXojRmj?nX
_NP00_nW_>T00onS^n[oX[_[0000000200000007oiVgkOn3[_7oPjkaoe:Dkol0EM3o032hobI2^002
ob<dZ`05obdhZolK::;o01fQo`00E_lh<il00_mSC:82ohAQXP?oVW2Q0onWNZ400on/Oj?o^HbWokV<
Y`02okF=[0;oc:Rf00Wo]:G9om3]j?o@kNSo0000ooCH/_l01ICo2BJWocM2/OmQCjL00_n4IJL3oj5g
Y003ok>4X_o1U:So`IBX00;oc9ZS0ooL[jT2onBjZ`?oj/fh00?odj^_olFY_Oo5ZKd00onfSjd2ok:5
Y@Co]8JS00?o_8^QolRHY?o8V:@00_oAWJ42onFcXP04oo[BWOoghh;odNb8onoL_P?ogKF`0_o@XjT0
1_oFZZ_oeJJWomFVYooKZjGog;2ZonNkZ0;oll^V00Koo=bOooSXTOoRigkoa^1dokKROoo3m^h2ok_S
l`06okSHl000003o/Lg^ok7=k_n_anco[<?Z0on[`NT00on[_nWoZ[kXojZnj002ojZnj0_oZKgX00<0
0000ooooooooool04Oooool000Wooooo00@00000oooooooooooooooo5`00000401TI6@070000000c
<c<0<c<c03<c<`000000C4a<0000000206IVIP030000001oOgl000000080VIVI00D000000;>c/`2c
/k<0/k>c000000060<c<c0050000002c/k<0/k>c0;>c/`0000000P2IVIT01P000000Ogmo07moO`00
0000IVIV00000080C4a<00Go000003<c<`0c<c<0<c<co`00000501TI6@03o`0000000000000000l0
000000?o000001TI6@0I6AT0100I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00D0000006IV
IP1VIVH0IVIV0000000307moO`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl00P1oOgl0
10000000IVIV06IVIP00000304a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATG000000Cooooo
00<00000ooooooooool04Oooool00`00003oooooooooo`0Oooooo`?oZ;gX0`0000000onR^n_oXK_[
oiJgkP02oiJgkP;oO:gc00Go?Xg^o`1Ed?l0<[Oo9T:hob<dZ`02obdhZ`03oa/XX_l005co>3>O00;o
HdbR0_n4HJ83oiY`X@?oYgZQ0oniS:L02?neSJcoc:RfolbX]_o<Z;Kok=[1om3]j?oKm9[on>>`0_od
f;800ol99ZOo=d:aocM2/@02ohAUY`;oXGNT00?oZXN_ol6DZ?o1U:P00_o1U:P4omb_Z@05oo3@/OoT
^Z_oj/fhon[=^?oNimX00oo5ZKd3okJ?[@03ok:5YOn/Q:Wo[8BY00?o]8JS00Co_8^QolRHY?o8V:Co
b9RT0_oU/j82oo[BW@05oloDFooAk8Sokmbnom>^/ooM]K000oo@XjT2omFVY`;ofj^U0_oW^jP01_oc
bjKoo=bOoocLWoohj97oh^MnokKRO`;o^^od00Ko^n?cok?Cl?ncdo3o/Lg^00000?n^aN/3ojc3jP03
oj_1jOnZ_nWoZ[oY00?oZ[kX3OnY_NP00`00003oooooooooo`0@ooooo`002Oooool01000003ooooo
oooooooooolG000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0060000001VIVH0IVIV
0000001oOgl000000P2IVIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<00<000000;>c/`2c/k<0
0P2c/k<01P000000VIVI09VIV@000000Ogmo00000080IVIV00@0000004a<C01<C4co00000`0c<c<0
0ol000006ATI01TI6@0301TI6@03o`0000000000000000d0000000?o000001TI6@0I6AT0100I6AT0
1Ol00000<c<c03<c<`0c<c?o000000<0C4a<00@0000006IVIP1VIVH000000`1oOgl00`000000VIVI
09VIV@0909VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH010000000C4a<04a<C000000303<c
<`030000000I6AT06ATI00<06ATI60000004ooooo`0300000?oooooooooo017ooooo00<00000oooo
ooooool07oooool300000004ojRmj?nV_>WoY[cYojJlj@;oXK_[00CoU[O^oiJhkomj[_CoNZkd0_lc
Rnd02?l0>KSo01VSob<dZolX<:Co;CR[oa/XX_l004co00nC0_mSC:83ohAQXP;oVW2Q0_nWNZ401?nb
QJGo^HbWokV<YoniS:L4olbX]P03oncJ`OoKm9[on>>`00;om=Rb0_o^c[801Ol99ZOo=d:aoga/]_ml
K;KoXGNT00;oZXN_1?o1U:P3omb_Z@;ol=2a00?okoNfon[=^?oNimX00_oNimX2olFY_@;o]Xn]00Co
YHRfojb4ZOn/Q:Wo[8BY0ondQZ<4olRHY0;oiK>R00Con]:MooOSP_oAk8Sokmbn0_oC[[<01?oM]K3o
d:>Yom2SZOo@XjT2omFVY`;ofj^U0_oW^jP01oocbjKoo=bOooSXTOoRigkoa^1dok3fl?njko@00_nd
fo@01Oncdo3o[lW]ojo9kOn^aN/0000000CoZl3Y00?oZ[oYojZnj?nZ_^P00_nZ_^P=ojVmj0030000
0?oooooooooo013ooooo0009ooooo`0400000?oooooooooooooooaL000001@0I6AT01?l00000<c<c
03<c<`00000204a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT01@000000/k>c0;>c/`2c
/k<0000000D0c<c<00<000000;>c/`2c/k<00P2c/k<01P000000VIVI09VIV@000000Ogmoo`000080
IVIV00@0000004a<C01<C4co00000`0c<c<00ol000006ATI01TI6@0301TI6@03o`00000000000000
00d0000000?o000001TI6@0I6AT0100I6AT01Ol00000<c<c03<c<`0c<c?o000000<0C4a<00@00000
06IVIP1VIVH000000`1oOgl00`000000VIVI09VIV@0909VIV@050000001oOgl0Ogmo07moO`000000
0`1VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00<06ATI60000004ooooo`03
00000?oooooooooo017ooooo00<00000ooooooooool07?ooool3000000;ooooo0onX_NP2ojJlj@?o
XK_[0_nF^>l2ogZ^m0;o<h_]00Oo002;ob<dZolS=:_o:32Toa/XX_l059So001F00;oAcfS00?oHdbR
ohAQX_n4HJ800_nJL:400onWNZ7o/XFUok:5Y@03okV<Y`03oljU[_o<Z;Koc:Rf00;ok=[100?o0000
ooSS/?odf;800_o^c[800ooV`k;oVBP0ocM2/@02oga/]PCoZXN_0oo1U:P00ooH/kCog:nYoo3@/@02
oo3@/@03onog]_l0003og^OJ00;og^OJ00?oaJVmoijOeOnUR;H00_nUR;H3ojb4Z@?o]8JS1?o8V:@0
1_oN/JWoiK>Roo[BWOoghh;ogM[DonoL_P;odjjc0oo@XjT2olnOY@04omFVYooKZjGofj^UonJgY0;o
ll^V00Coo=bOooSXTOoRigko/?K`0_nch_L01?ndfoCo[lg_ojo=kon_bNd2ojc3j`0400000?n[`N[o
Zl3Yoj_0j@?oZ[kX00?oZKkXojVmj?nY_NP03_nY_NP00`00003oooooooooo`0?ooooo`002Oooool0
1000003ooooooooooooooolG000000D06ATI00@0000003<c<`0c<c<000000P1<C4`01P000000IVIV
06IVIP000000Ogmo00000080VIVI00D000000;>c/`2c/k<0/k>c000000050<c<c0030000002c/k<0
/k>c0080/k>c00H0000009VIV@2IVIT0000007moO`00000206IVIP040000001<C4`0C4a<o`0000<0
<c<c00?o000001TI6@0I6AT0100I6AT00ol0000000000000000;00000003o`00000I6AT06ATI00@0
6ATI00?o000003<c<`0c<c<00P0c<c<01Ol00000C4a<04a<C01<C4`000000080IVIV00D0000007mo
O`1oOgl0Ogmo0000000;09VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH010000000C4a<04a<
C000000303<c<`030000000I6AT06ATI00<06ATI60000004ooooo`0300000?oooooooooo017ooooo
00<00000ooooooooool06Oooool3000000Kooooo0onX_NP2ojJlj@04oj6kjonR^n_oX[_[oj:kj`;o
U[W_0_mk[o@01?leS^oo01FLob<dZolX<:@2oa/XXP04o`00C?l03i?oAcfSodLmX`;oQ66R0_nJL:44
ok:5Y@0:okV<Yoo>YJkocZF^oljU[_o<Z;Kok=[1o`000?oflJ[on>>`ooCH/P;ok/jb00Coi/>bomjg
/?lg@[7o=d:a0_mlK;H3ojZ7[`;o`IBX0_oH/k@01_oL[jWol=2aoo3@/Oo_mkKoYH^ioj>3/@;oVWjd
00CoRGNhoijOeOnNWmGoWYoE0_nUR;H4ojb4Z@;o]8JS0oo8V:@2omjaZ@;on]:M00?o0000omgJe?oC
[[<00_oC[[<00oo7VjWod:>Yom2SZ@02olnOY@;ofj^U0_oV]j@01OoebJ3oo=bOoocLWoohj97o0000
00;o[]Cd0_n_dO802?n_cNoo[<G/ojc5k?n/`n_oZl3YojZoj@00003oZ[oY0onZ_^P3ojVnj13oZKgX
00<00000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo5`00000501TI6@040000
000c<c<0<c<c00000080C4a<00H0000006IVIP1VIVH0000007moO`00000209VIV@050000002c/k<0
/k>c0;>c/`0000001P3<c<`00`000000/k>c0;>c/`020;>c/`060000002IVIT0VIVI0000001oOgl0
00000P1VIVH010000000C4a<04a<C?l0000303<c<`03o`00000I6AT06ATI00@06ATI00?o00000000
000000002P0000000ol000006ATI01TI6@0401TI6@05o`00000c<c<0<c<c03<c<ol000000`1<C4`0
10000000IVIV06IVIP00000307moO`030000002IVIT0VIVI00/0VIVI00D0000007moO`1oOgl0Ogmo
0000000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0301TI6AL0
00001?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Kooooo0`00000:ooooo`Co
Z;gX0_nV_NT00onR^n_oX[c[oj:lj`02oiRik`;oOk7d00Oo002;o`0EW?lX<:Co;S2Qoa/XX_l059So
001b00;oAcfS0_moHZL00onJL:7oXGVVok:5Y@03ok:5Y@09okV<Yoo>YJkocZF^oljU[_o^d[Kok=[1
o`000?ogfJcomM>[00;ol/j[00Gok/jbonK3/_oN]k3og[N`ocM2/@02oga/]P?oZXN_00Ko`IBXomRc
]?oH/kCof;>doo3``oo`d;42ojnA]`;oXh>a0onJO[@00on9MkSoWYoEoijOe@03ojF8]P?o[8BY00?o
]8JSokbAZOnlTJT00_o8V:@2omjaZ@06ooWKZ?oghh;ogM[DomgJe?o2X[Sodjjc0oo7VjT00oo@XjWo
cinUolnOY@02om^[Y@;oi[NT00ComLVPookMToo/hGCo^LQ;0_n^e?@2ojc9k`;o[<O]00?o[<G/oj_1
j_n[`NX00_n[`>T01?nZ_nT00000ojZnj?nZ_^PDojVmj00300000?oooooooooo00kooooo0009oooo
o`0400000?oooooooooooooooaL000001@0I6AT010000000<c<c03<c<`00000204a<C0060000001V
IVH0IVIV0000001oOgl000000P2IVIT01@000000/k>c0;>c/`2c/k<0000000L0c<c<00D000000;>c
/`2c/k<0/k>c0000000209VIV@030000001oOgl000000080IVIV00Co000004a<C01<C4co00000`0c
<c<00ol000006ATI01TI6@0401TI6@;o00002P0000000ol000006ATI01TI6@0401TI6@04o`00000c
<c<0<c<c03<c<`;o00000P1<C4`01@000000IVIV06IVIP00003o00000080Ogmo00<0000009VIV@2I
VIT00P2IVIT6o`0000D0VIVI00@0000007moO`1oOgl000000P1VIVH01@000000C4a<04a<C01<C4`0
000000<0<c<c00<0000001TI6@0I6AT00`0I6ATG000000Cooooo00<00000ooooooooool04Oooool0
0`00003oooooooooo`0Dooooo`8000003oooool2ojRmj0?oY[gY00?oX[c[oj>ljonJ^^h00_nJ^^h2
ohFcl`06o`0EW?lX<:Co:32Tobh`XOl059So001F0_m7?J<2ogmRY`;oXGVV1?nbQJD02OniS:OocZF^
oljU[_o>YJkok]:fo`000?ohi;3ommV/ooGCZ`02oo;>Z`03on_4[OoV`k;og[N`00;oejf]0_mlK;H3
ojZ7[`08okjbc_oH/kCof;>domRc]?o`l<?o^YNdojnA]on[R;03oj>3/@;oVWjd00?oRGNhoa1Uf_l@
IMX00onUR;H2ojb4Z@05ojV:]?nlTJWo_96YokbAZOo8V:@00ooN/JT00ooifjSof^9domgJe002ol:R
^004om>^/oo7VjWoai^YolNKZ@?ocinU00OoeZBTom^[YOoV]jCoi[NTooG9X?ongI?ok>5d00;o[<[`
0_n/bNl01On[`n_oZl;[oj_2jon[`^_oZl7Z00;oZ[oY0onZ_^P00`00003oZKkXojVmj00@ojVmj0?o
oooo00<00000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo5`00000501TI6@04
0000000c<c<0<c<c00000080C4a<00H0000006IVIP1VIVH0000007moO`00000209VIV@050000002c
/k<0/k>c0;>c/`0000001`3<c<`01@000000/k>c0;>c/`2c/k<000000080VIVI00<0000007moO`00
00000P1VIVH010000000C4a<04a<C?l0000303<c<`03o`00000I6AT06ATI00H06ATI00?o00000000
000000001P0000000ol000006ATI01TI6@0501TI6@05o`00000c<c<0<c<c03<c<ol000000`1<C4`0
10000000IVIV06IVIP00000307moO`030000002IVIT0VIVI00;o00001P2c/k<00ol00000VIVI09VI
V@0209VIV@040000001oOgl0Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`03
0000000I6AT06ATI00<06ATI5`000004ooooo`0300000?oooooooooo013ooooo00<00000oooooooo
ool04_ooool3000001;ooooo0_nX_NP00onV_NWoYkgYojNmj@02oj>lj`0<oiZjk_nK^^goVk[]oi^j
kOl05Ico4b6MobP`Y?l^<:7o01BHo`00Rol03i?oAcfS0_moHZL3oj5iYP?o/XFU0oo>YJh2onkB]P03
o`000?ogfJcomM>[00?ol/j[00?ojlB]omjg/?oN]k000_oG[Jd01?o@Z;3oBX7TodZ1i?nZQjl3okjb
cP04omRc]?o`l<?ol?33okB?/0?oZhR`0_nSPk42oiYn]004ohUg^?nBMk7o46GJoa1UfP;oYHRf00?o
[8BYojV:]?nYR[@00onlTJT00oo8V:Cog[6YomjaZ@02ooWKZ004ojJ@_Oo2X[So`Z:hol:R^0Coai^Y
0_o?WjD2omJTY0;oi[NT0_oebJ000oongI?o^LQ;ojc:l002oj_3k0;oZl?[0_n[`^/3ojZoj@CoZKkX
00<00000ojVmj?nY_NP03_nY_NP5ooooo`0300000?oooooooooo00kooooo0009ooooo`0400000?oo
oooooooooooooaL000001@0I6AT010000000<c<c03<c<`00000204a<C0060000001VIVH0IVIV0000
001oOgl000000P2IVIT010000000/k>c0;>c/`0000090<c<c0070000002c/k<0/k>c0;>c/`000000
VIVI0000000207moO`030000001VIVH0000000<0C4a<00Go000003<c<`0c<c<0<c<co`00000801TI
6@?o00000P000003o`0000L06ATI00Go000003<c<`0c<c<0<c<co`00000304a<C0040000001VIVH0
IVIV000000<0Ogmo00@0000009VIVOl0003o00002@2c/k<00ol00000VIVI09VIV@0209VIV@040000
001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0301TI
6AL000001?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00oooooo0`00000Eoooo
o`?oZ;gX1?nW_NT2oj>lj`09oi^jkOnL^^goRkCao`0EW?lC8Igo;S2Qoc4bX_l059So001b00;oAcfS
00CoOf:Woj5iY_nQNJKoXGVV0_nbQJD2olJN[`04oljU[_o^d[Kok]:fon[aU`;ommV/00?omM>[oo;>
ZoobcZ/00_o[a:d01ooQ]jcog[N`omN][OoG[JgodjR[om2X/?m:PN@00onn//h2og3L]`03oo3``ond
Sk3o]8n`00?oZhR`0_nSPk42oiek[@?oTWNa00?o46GJohF2bOn5P/T01?nYR[@2okbAZ@?og[6Y00Co
nM^Xom[RM?nVT;goYY2m0_o2X[P00oniT:coai^YolNKZ@02olNGY@03olnOYOoFY:CoeZBT00;oi[NT
00?omLVPookMToo/hG@00_n[a>`00on[`ncoZ/3Zoj[0jP02oj[0j@;oZ[oY1OnY_^P2ojVmj0030000
0?nY_NSoZKgX00WoZKgX2_ooool00`00003oooooooooo`0=ooooo`002Oooool01000003ooooooooo
oooooolG000000D06ATI00@0000003<c<`0c<c<000000P1<C4`01P000000IVIV06IVIP000000Ogmo
00000080VIVI00@000000;>c/`2c/k<000002P3<c<`010000000/k>c0;>c/`00000209VIV@030000
001oOgl000000080IVIV00@0000004a<C01<C4co00000`0c<c<00ol000006ATI01TI6@0901TI6@;o
00002P0I6AT01Ol00000<c<c03<c<`0c<c?o000000<0C4a<00@0000006IVIP1VIVH000000P1oOgl0
0`000000VIVIo`00000<0;>c/`05o`00002IVIT0VIVI09VIV@0000000P1oOgl010000000IVIV06IV
IP00000304a<C0050000000c<c<0<c<c03<c<`000000100I6ATG000000Cooooo00<00000oooooooo
ool04?ooool00`00003oooooooooo`0<ooooo`<000006Oooool4ojRmj0;oYkgY0onT_>X2oibjk@06
o`0EW?lC8Igo;S2Qobh`XOla<Z;o]Ul00_m7?J<2ogmRY`;oXGVV00Go/XFUolJN[oo6WZooaYj_oljU
[P02onkB]P05ooST/?ogfJcommV/ooGCZoobcZ/00_o[a:d2on6g[0;oejf]0ooCZ:/00oo@Z;3ocjJ^
okjbcP03olFO/@Co]8n`0_n[R;001?nSPk7oXWf[oiek[OnMNjd3oi9g/@04ogQ/^Ol@IM[oQH;9ohF2
b@?oZHZd0_nlTJT01Oo@[[Sog[6YomjaZOoifjSof^9d00;oYY2m00?o`Z:hokV@[?niT:`00_o7VjT2
olNGY@09olnOYOoFY:CoeZBTonBcXooV]jComLVPookMToo/hGCoZlC/00;oZ/7Z00?oZ/3ZojZnjOnY
_^P01OnY_^P6ojVmj00300000?nY_NSoZKgX00GoZKgX3Oooool00`00003oooooooooo`0=ooooo`00
2Oooool01000003ooooooooooooooolG000000D06ATI00@0000003<c<`0c<c<000000P1<C4`02@00
0000IVIV06IVIP000000Ogmo0000002IVIWo0000000000020;>c/`03o`00003<c<`0c<c<00T0c<c<
00H000000;>c/`2c/k<0000009VIV@00000207moO`030000001VIVH0000000<0C4a<00Go000003<c
<`0c<c<0<c<co`00000E01TI6@05o`00000c<c<0<c<c03<c<ol000000`1<C4`01ol00000IVIV0000
0?l00000Ogmoo`00000000000P2IVIT00ol00000/k>c0;>c/`09o`000080/k>c0_l0000209VIV@04
0000001oOgl0Ogmoo`000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@02
01TI6AL000001?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo0`00000N
ooooo`?oZ;gX0_nW_NT3ojBljP;oW;[]00Oo4b6Moc<bXOl^<:7o<C:Rob`eZ?l98j?oAcfS00;oOf:W
0_nQNJH4olJN[`;ojM2l00Cok]:foo?@[?ocd:comM6Y0_obcZ/01_o[a:gohKN/on6g[?oQ]jcofJbZ
omN][@?odjR[0oo?YZh01?o?YJgoaInaolFO/Oo0VK03okB?/004oj^8/?nVP:_oXWf[oj9mZ`?oWG^]
0onBMk400omhK;WoQH;9ohF2b@03ojV:]004okbAZOo@[[Sod:jhom2^^0;onM^X00?oOgJoojJ@_OnT
PZh01?niT:`00oo7VjWoaiNUolNGY@03omJTY004onBcXooebJ3omLVPookMT`;oZl7Z00?oZ/7ZojZo
jOnZ_nT00_nZ_^T5ojVnj0KoZKgX00@00000ojVmj?nY_NSoZKgX4Oooool00`00003oooooooooo`0=
ooooo`002Oooool01000003ooooooooooooooolG000000D06ATI00@0000003<c<`0c<c<000000P1<
C4`020000000IVIV06IVIP000000Ogmo0000002IVIT000000`2c/k<00`000000c<c<0<c<c005o`00
00@0c<c<00H000000;>c/`2c/k<0000009VIV@00000207moO`030000001VIVH0000000<0C4a<00?o
000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0A01TI6@05o`00000c<c<0<c<c03<c<ol00000
0`1<C4`010000000IVIV06IVIP00000207moO`040000002IVIT0VIVIo`000080/k>c00?o00000<c<
c03<c<`01`3<c<`01?l00000/k>c0;>c/ol0000209VIV@040000001oOgl0Ogmo00000080IVIV00@0
000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6AL000001?ooool00`00003ooooo
ooooo`0@ooooo`0300000?oooooooooo00Kooooo0`00000Rooooo`?oZ;gX0_nW_NT2ojBljP;oW;[]
00Oo4b6Moc<bXOlc<Z7o<C:Rob`eZ?l007;o2B>S00;oOf:W00?oXGVVok2?]?n`Sk@00oo6WZl2onW@
_007onoB]?ocd:colm2/ooGAZOodd:WoklR[on_4[@02on6g[0;ofJbZ00Koejf]om>XZooCZ:_odjR[
omBWZ_o?YZh2olnU[@03olFO/Oo0VK3o`9V`00?o]8n`0_nVP:/3oj9mZ`;oWG^]0_nBMk400onMNjgo
S7Jfohaf]P02o`AQf003ojV:]?nWY]God:jh00?od:jh00?okO;9ohQ_/?n8Kk000_nTPZh4okV@[0?o
aiNU0_oFY:@2onBcX`03ooK:WoongI?ok>5d00CoZ[oY1OnY_^P:ojVmj00300000?oooooooooo017o
oooo00<00000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5`00000501TI6@04
0000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl00`000000VIVI000000020;>c
/`050000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000c<c<0<c<c0020<c<c0060000002c/k<0
/k>c0000002IVIT000000P1oOgl00`000000IVIV0000000304a<C003o`00000c<c<0<c<c0080<c<c
00?o000001TI6@0I6AT03`0I6AT00ol00000<c<c03<c<`0203<c<`07o`00001<C4`0C4a<04a<C000
0000IVIV0000000207moO`040000002IVIT0VIVIo`000080/k>c00?o00000<c<c03<c<`02@3<c<`0
1?l00000/k>c0;>c/ol0000209VIV@030000001oOgl0000000<0IVIV00@0000004a<C01<C4`00000
0P0c<c<00`0000006ATI01TI6@0301TI6AH000001?ooool00`00003oooooooooo`0@ooooo`030000
0?oooooooooo00?ooooo0`00000Vooooo`?oZ;gX0onW_NT02OnT_>[oW;[]o`01S_lC8Igo<c:Qodm6
Yola<Z;o;3FXo`TSX`02ogM/^@?o/8nd0_o6WZl3onW@_0;olm2/0_oedJT00oodd:WoklR[onBj[002
on6g[0;ofJbZ0ooCZ:/2omBWZP03olnV[_o?YJgocjF]00Co`9V`00?o]8n`ojf7[OnVP:/00_nVP:/2
oj9mZ`GoWG^]0_n<M[H00omGH<7o167HojNVe@02ojNVe@;od:jh00CokO;9ofEI/?n8Kk3oR6n`0onT
PZh3okV@[0?oaiNU0_oFY:@2onBcX`05ooK:Woomh8[o0000oj_0jOnZ_nT00_nZ_^P3ojVnj0SoZKgX
1Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00gooooo0009ooooo`0400000?oo
oooooooooooooaL000001@0I6AT010000000<c<c03<c<`00000204a<C0030000001VIVH000000080
Ogmo00<0000009VIV@0000000P2c/k<010000000c<c<0<c<c?l000060>KViP05o`00003<c<`0c<c<
0<c<c00000000P2c/k<01P000000VIVI09VIV@000000Ogmoo`000080IVIV00D0000004a<C01<C4`0
C4a<o`00000403<c<`;o00003P0I6AT00ol00000<c<c03<c<`0203<c<`07o`00001<C4`0C4a<04a<
C0000000IVIV0000000207moO`040000002IVIT0VIVIo`000080/k>c00?o00000<c<c03<c<`02?l0
00030<c<c004o`00002c/k<0/k>co`000080VIVI00<0000007moO`0000000P1VIVH010000000C4a<
04a<C?l0000203<c<`03o`00000I6AT06ATI00<06ATI5P000004ooooo`0300000?oooooooooo00oo
oooo00@00000oooooooooooooooo0`00000[ooooo`;oZ;gX0onW_NT2ojBljP06oa<QWOlc<Z7oCdJW
odm6Yol/=JSo2B>S0_mgK;T4ok2?]004olJN[ooYd;cojM2lon7cV0;olm2/00ComM6YooC@ZOo_b:_o
klR[0_oT^Z`01OoQ]jcofJbZomV/Z_oEYjSodjR[00?oe:NZ0oo?YJd4ol2I/0;o[HN]0onVP:/2oj9m
Z`03oiek[OnRNjSoXW^X00?oWG^]0_n<M[H01_mGH<7o167HojNVeOnWY]God:jhongbb@;oIEV`0_n8
Kk03ojB2[P;o^I2/0_niSJL01?o7UjGocYfUoljMYOoFY:@2onBcX`03ooK:Woomh8[oZkoY00;oZ[oX
00?oZ[kXojVnj?nY_^P02?nY_NP8ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
3Oooool000Wooooo00@00000oooooooooooooooo5`00000501TI6@040000000c<c<0<c<c00000080
C4a<00<0000006IVIP0000000P1oOgl00`000000VIVI000000020;>c/`040000003<c<`0c<c<o`00
00H0i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`060000002IVIT0VIVI0000001oOgl00000
0P1VIVH01Ol00000C4a<04a<C01<C4co000000H0<c<c0_l0000:01TI6@;o00001@0c<c<01ol00000
C4a<04a<C01<C4`0000006IVIP0000000P1oOgl010000000VIVI09VIVOl000020;>c/`03o`00003<
c<co000000P0i^KV00Co00000<c<c03<c<co00000`2c/k<01Ol00000VIVI0000001oOgl000000080
IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6AH000001?ooool00`00
003oooooooooo`0?ooooo`@00000;oooool2ojRmj0?oYkgY00?oY;cZo`01S_lc<Z400_m?AZL00omW
Fk3o;3FXo`TSX`02ogM/^@;o/8nd0_oBc=@01?oYd;coYn^NonoB]?ocd:`2ooGAZ@03ooC@ZOo_b:_o
i;Z/00;oi;Z/0_oI[:X2omFWZ006om>XZooDYj[oe:NZomBWZ_oGZj[ocjF]0_o>YJl2ol2I/004okRB
[on]Qjgo[HN]ojf7[@;oYX2[00?oXWf[oj=kYonRNjP00_nRNjP3oiek[@;oS7Jf0_mGH<401?nWY]Go
<k[;oaHYYOlk?JX2ofEG[@?oR6n`0_nTPZh01OniT:co^HfWokV=YoniSJOoaiNU00;ocYfU0_oT/j<2
ooK:W`03olg>DOnZ_^SoZ[kX00;oZ[kX00?oZKkXojVmj?nY_NP00onY_NP<ooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5`000005
01TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl00`000000VIVI0000
00020;>c/`040000003<c<`0c<c<o`0000L0i^KV00Oo00000<c<c03<c<`0c<c<0000002c/k<00000
0080VIVI00<0000007moO`0000000P1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0<c<c
00D0<c<c00?o000001TI6@0I6AT01P0I6AT00ol00000<c<c03<c<`0403<c<`05o`00001<C4`0C4a<
04a<C00000000P1VIVH00`000000Ogmo0000000209VIV@06o`00002c/k<0/k>co`00003<c<co0000
2P3Vi^H01?l00000c<c<0<c<c?l000020;>c/`05o`00002IVIT0000007moO`0000000P1VIVH01000
0000C4a<04a<C000000303<c<`030000000I6AT06ATI00806ATI5P000004ooooo`0300000?oooooo
oooo00oooooo0P00000aooooo`?oZ;gX0_nW_NT01OnU_>[o006>oc<bXOlc<Z7oCdJW00;oIe^`00Co
001logM/^OmgK;Wo/8nd0ooBc=@01?nWjikokm:doo?@[?ocd:`2ooGAZ@03ooC@ZOo_b:_oi;Z/00;o
i;Z/00CofJfZomV/Z_oEYjSoeJNX0ooDYjX2omN[ZP04olnU[Oo>YJoocZF_ol2I/0?o^9:_0_n]Qjd2
ojJ0Z`;oXg^W0onRNjP3oiek[@08ohaf]_nPPk?oOWc6ogila_l0>;ko001no`0@V_lk?JX3ofEG[@;o
R6n`0_nTPZh4okV=Y`03olNGYOo>WJGocYfU00;oi;>S00?om/ZOoogPR_nZ_^P00onZ_^P5ojVmj0oo
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0<ooooo`002Oooool01000003ooooo
oooooooooolG000000D06ATI00@0000003<c<`0c<c<000000P1<C4`01@000000IVIV0000001oOgl0
00000080VIVI00<000000;>c/`0000000`3<c<`00ol00000i^KV0>KViP050>KViP05o`00003<c<`0
c<c<0<c<c00000000P2c/k<01P000000VIVI09VIV@000000Ogmo00000080IVIV00D0000004a<C01<
C4`0C4a<o`00000803<c<`So00001`0c<c<01ol00000C4a<04a<C01<C4`0000006IVIP0000000P1o
Ogl020000000VIVI09VIVOl00000/k>co`00003<c<co00001@3Vi^H4o`0000<0i^KV00Co00000<c<
c03<c<co00000P2c/k<01Ol00000VIVI0000001oOgl000000080IVIV00@0000004a<C01<C4`00000
0P0c<c<00`0000006ATI01TI6@0301TI6AD000001?ooool00`00003oooooooooo`0Aooooo`030000
0?oooooooooo02oooooo00?oZ;gXojVmj?nY_NP00_nW_NT00onU_>[o8bbSoc<bX@02odm6Y`03ofMK
/?n1N<3oFY7[00;oFY7[0ooBc=@2on2n]`04onc9/?ocd:comM6YooC@Z@;oklR[0_oT^Z`2omV]ZP04
omV/Z_oEYjSoeJNXomJWZ0;oe:NZ0_oGZjX3oljU[`Co^9:_0_n]Qjd01?nVP:_oXW^Xoj=kYonSNjL4
oj9kZ0;oWG^]0onPPk<2ogilaP03o`0h__l049[o>cfZ00?oIEN]0_n:KZd00onTPZkoYX2ZojJ0ZP03
okV=Y`?ocYfU00CogZjVonBcXoofbYoooN2:0onZ_^P2ojVmj1Cooooo00<00000ooooooooool03_oo
ool00`00003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolG000000D06ATI00@0
000003<c<`0c<c<000000P1<C4`01@000000IVIV0000001oOgl000000080VIVI00<000000;>c/`00
00000`3<c<`00ol00000i^KV0>KViP060>KViP04o`00003<c<`0c<c<00000080/k>c00Ko000009VI
V@2IVIT0000007moO`00000306IVIP040000001<C4`0C4a<04a<C0?o00004P0c<c<2o`0000<0C4a<
00Ko000006IVIP1VIVH0000007moO`00000209VIV@03o`00002c/k?o00000080c<c<00Co00000>KV
iP3Vi^H0i^KV0_l000040?ooo`05o`00003Vi^H0i^KV0>KVi_l000000P3<c<`01ol00000/k>co`00
002IVIT0000007moO`0000000P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI
00<06ATI5@000004ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0;oooool4ojVm
j003ojRmjOl00Hko8bbS00;oCdJW0_mWFk001_n1N<3oFY7[oeZAjomJTN_od/cDolng``;oh;jg00Go
k<V`ooCC[?oddjcommN[oo;@[P03onBj[0;ofJfZ0_oEYjP3omJWZ004omBWZ_oGZj[oej^Zom^`[@;o
cZF_00KobJ>bokRB[onhTZoo^9:_ojf7[OnUOj/2oj9kZ0?oXg^W0onRNjP00onMNjgoZ8:[oj23/`02
oj23/`06ogila_nVV/SoYY[8o`00O_lK;JOo>cfZ0_mUEjd2ohY^[@?oYX2Z0oniSJL2oljMY@;ogZjV
0_ofbYl00oo=cU7oooooooooo`0Hooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0
3?ooool000Wooooo00@00000oooooooooooooooo5`00000501TI6@040000000c<c<0<c<c00000080
C4a<00D0000006IVIP000000Ogmo0000000209VIV@030000002c/k<0000000<0c<c<00?o00000>KV
iP3Vi^H01P3Vi^H01?l00000c<c<0<c<c00000020;>c/`060000002IVIT0VIVI0000001oOgl00000
101VIVH00`000000C4a<04a<C00304a<C0;o00003`0c<c<00ol00000C4a<04a<C00204a<C0070000
001VIVH0IVIV06IVIP000000Ogmo0000000209VIV@03o`00002c/k?o00000080c<c<00Go00000>KV
iP3Vi^H0i^KVo`0000060?ooo`04o`00003Vi^H0i^KVo`000080c<c<00Oo00000;>c/ol00000VIVI
0000001oOgl000000080IVIV00@0000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0301TI
6AD000001?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo033ooooo0_nY_NP00onX
_NWo006>ob</X`02oeiD[`;oIe^`0_n1N<000on^U;cockO3olng``02on2n]`;ok<V`0_oddj`01?og
ej_ol]2^onBj[?oT^Z`3omV]ZP;oeJNX0ooFYjP2omN[ZP;ofk2]00?ocZF_olVS/_o9Xk800onhTZl2
ojEoZ`?oXW^X0_nSNjL2oj9kZ004ojUoYonXPZ_oZ8:[ojR2Z`;oX8>c0onVV/P00oo:]lOo012Joc/m
ZP02ofEG[@;oRVj]0onVP:X2okV=Y`;o`IBX00GocYfUomj^Y_oN[ZKomLbToogPRP0Kooooo`030000
0?oooooooooo00gooooo00<00000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo
6000000401TI6@040000000c<c<0<c<c00000080C4a<00P0000006IVIP1VIVH0000007moO`000000
VIVI00000080/k>c00D000000<c<c03<c<`0c<c<o`0000060>KViP05o`00003<c<`0c<c<0<c<c000
00000P2c/k<01`000000VIVI09VIV@2IVIT0000007moO`000000101VIVH00`000000C4a<04a<C004
04a<C0?o00002`0c<c<00ol00000C4a<04a<C00304a<C0060000001VIVH0IVIV0000001oOgl00000
0P2IVIT01_l00000/k>c0;>c/ol00000c<c<o`0000<0i^KV00?o00000?ooo`3oool01@3oool01?l0
0000i^KV0>KVi_l000020<c<c00:o`00002c/k<0/k>co`00002IVIT0000007moO`000000IVIV0000
0080C4a<00@0000003<c<`0c<c<000001@0I6ATE000000Cooooo00<00000ooooooooool05?ooool2
0000037ooooo0_nY_NP01?nX_NWo8bbSoeiD[omNE:l2ohYe]PCo[YBl00CockO3on2n]ooP_[Ook<V`
0_oddj`01Oogej_ol]2^oo;@[_oU_k3oi;Z/00;ofJfZ0_oDYZP01_oEYjSoeZNXomJWZ?oFYjSofjjY
omN[ZP;ofk2]1?o9Xk801?nhTZoo[HV`ojEoZonUOj/3oj9kZ0;oXg^W00?oXW^XojUoYonYOjL00onX
PZ/01?nPPk?o]I:bokFB/_nVV/P2olZga`03o`00N_lK;JOoIEN]00;oIEN]0_n:KZd3ojJ0ZP04okV=
Yoo1U:So`IBXoljMY@;ogZjV00?omLbTooGTP_ooool06oooool00`00003oooooooooo`0<ooooo`03
00000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooaP00000100I6AT010000000
<c<c03<c<`00000204a<C0080000001VIVH0IVIV0000001oOgl0000009VIV@0000020;>c/`050000
003<c<`0c<c<0<c<c?l000001@3Vi^H2o`0000<0c<c<00@000000;>c/`2c/k<000000`2IVIT01?l0
0000Ogmo07moO`00000406IVIP03o`0000000000C4a<00H0C4a<1_l0000203<c<`?o00001@1<C4`0
1`000000IVIV06IVIP1VIVH0000007moO`0000000P2IVIT01Ol00000/k>co`00003<c<co000000<0
i^KV00?o00000?ooo`3oool01`3oool01_l00000i^KV0>KVi_l00000c<c<o`000080/k>c00Oo0000
09VIV@000000Ogmo0000001VIVH000000080C4a<00@0000003<c<`0c<c<000001@0I6ATE000000Co
oooo00<00000ooooooooool05_ooool00`00003oooooooooo`0_ooooo`;oZKgX0_lS;:<01?mNE:oo
RWFfohYe]_n:MKH3ojjD_0;oh;jg0_o/bK02ooCC[004ooOGZoobd:koiKn`onFo/0?ofJfZ0_oDYZP3
omJWZ0;ofjjY00Coej^Zom^`[OoK/:gogKRc0_o9Xk800onnW[So[HV`ojf9/003ojEoZ`;oXW^X00?o
Xg^WojEkY_nYOjL00onYOjL2ojR2Z`?o]I:b0oo:]lL01OoWdl7o6bfWoeQB/?mHD[3oIEN]00;oRVj]
0_nVP:X01?n/QZgo`IBXol6DZ?o1U:P2omj^YP;omLbT00?o0000ooooooooool06oooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooaP0
0000100I6AT010000000<c<c03<c<`00000204a<C0080000001VIVH0IVIV0000001oOgl0000009VI
V@0000020;>c/`040000003<c<`0c<c<0<c<c0?o00000P3Vi^H00ol00000c<c<0<c<c0030<c<c004
0000002c/k<0/k>c000000<0VIVI00D0000007moO`1oOgl0Ogmo0000000506IVIP<000002P1<C4`2
o`0000P0C4a<00L0000006IVIP1VIVH0IVIV0000001oOgl000000080VIVI00Go00000;>c/ol00000
c<c<o`0000030>KViP03o`00003oool0oooo00L0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l00002
0;>c/`07o`00002IVIT0000007moO`000000IVIV0000000204a<C0040000000c<c<0<c<c000000D0
6ATI5@000004ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool0;oooool2ojVmj003
ob</XomNE:ooGUB_00;oRWFf0on^U;`01_o9Zk[oh;jgonc9/?o/bK3om=>/ooOGZ`;ol]2^0_oU_k00
0ooG[ZkofJfZomV]ZP02omBVZ0?oeZNX0_oK[ZT2om^`[@;ogKRc00?obJ>bokjN^?nnW[P00on]RK02
ojEoZ`;oXW^X0onUNjH3ojUoY`;oZ8:[0oneT[801_o;YK;ob[O7onOC`OoWdl7o00:Doa/]Y`;oF5:`
0_n:KZd00onVP:[o[8J]ojb6[@03ol6DZ0;ogZjV00?omLbTooGTP_ooool07_ooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooaP00000
100I6AT010000000<c<c03<c<`00000204a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT0
10000000/k>c0;>c/`0000050<c<c0;o00001P3<c<`010000000/k>c0;>c/`00000309VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH01@1VIVH4000000l0C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo0000000209VIV@05o`00002c/k?o00000<c<c?l000000`3Vi^H00ol00000
oooo0?ooo`070?ooo`06o`00003Vi^H0i^KVo`00003<c<co00000P2c/k<01ol00000VIVI0000001o
Ogl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000501TI6AD000001?ooool00`00003o
ooooooooo`0Hooooo`0300000?oooooooooo02oooooo0_nY_NP2oeiD[`?oRWFf00?o[YBlolV[^_o9
ZkX00_oQa;/00ooafk[om=>/ooOGZ`02oo;@[P04onFo/?oG[Zkoejj^omN^[P?oe:JX00?oeJNXomJW
Z?oK[ZT00_oK[ZT01?oT^Zcofk2]omfh/ooM^;<4okjN^0;o[HV`0_nUOj/00onRNjSoX7VWojEkYP02
ojEkYP?oZGnW00CoZ8:[okJ<Z_nfS:[o]I:b0_o;YK82onBo/@03onOC`Ol007[o00:D00;oF5:`0_n:
LK44ojb6[@;o`IBX00CodZN]omj^Y_oec:ComNB27oooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooaP000001@0I6AT01P000000<c<c
03<c<`000000C4a<000000<0IVIV00D0000007moO`000000VIVI000000020;>c/`030000003<c<`0
c<c<00/0c<c<00@000000;>c/`2c/k?o00000`2IVIT00`000000Ogmo07moO`0307moO`030000001V
IVH0IVIV00P0IVIV0`00000;04a<C003o`00001VIVH0IVIV0080IVIV00H0000007moO`1oOgl00000
09VIVOl000020;>c/`03o`00003<c<co000000<0i^KV00?o00000?ooo`3oool01`3oool02?l00000
i^KV0>KVi_l00000c<c<o`00002c/k?o00000P2IVIT01@000000Ogmo0000001VIVH000000080C4a<
00@0000003<c<`0c<c<000001@0I6ATE000000Cooooo00<00000ooooooooool06Oooool20000033o
oooo00?oZKgXof1S__mPHkh00_n:MKH01?nUTKoobJ^jolV[^_o9ZkX2on74^`04oo7K^_ofikSol^:l
oo;R_0;oiKn`0ooG[Zh2omBVZ0;oeJNX00?oeZNXom^^ZOoK[ZT00_oT^Z`3omfh/`04om[0`?nnW[So
_YjhokjN^0;o[HV`00CoYGn[oiahZ_nPNJOoX7VW0onUNjH3ojUoY`?o]XbZ00?o]I:bol^U/_o;YK80
0_oT_k400ooig:WolnV9o`02U002oeQB/0?oRW6a0on/QZd00oo1U:SodZN]om:W[@02ooG<Y27ooooo
00<00000ooooooooool02_ooool00`00003oooooooooo`0;ooooo`002Oooool01000003ooooooooo
oooooolH000000D06ATI00@0000003<c<`0c<c<000000P1<C4`01P000000IVIV06IVIP000000Ogmo
00000080VIVI00<000000;>c/`2c/k<00P0000090<c<c08000000`2c/k<01@000000VIVI09VIV@2I
VIT0000000H0Ogmo0`00000:06IVIP/000001@1VIVH01P000000Ogmo07moO`000000VIVIo`000080
/k>c00?o00000<c<c?l000000`3Vi^H00ol00000oooo0?ooo`070?ooo`08o`00003Vi^H0i^KVo`00
003<c<co00000;>c/ol0000209VIV@050000001oOgl0000006IVIP0000000P1<C4`010000000<c<c
03<c<`00000501TI6AD000001?ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo02ko
oooo00?oZKgXof1S__nUTKl00onUTKl00oo9Zk[ohLBkon74^`02oo7K^P05ooKW^?obh[col^:lon?:
_ooU_k000ooG[Zh01?o?Y:coe:JXomFWZ?oEYjP3om^^Z@;oi;Z/00?ok/fbomfh/ooJ`<000_oJ`<00
1?nnW[SoZ9C1oiao/_nLOk82oiahZP?oX7VW0onUNjH2ojUoY`?o]XbZ0_o;YK83onBo/@04ooWLZOnl
cE;o00:Do`02U0;oF5:`0_n:LK43ojb6[@05ol6DZ?oBYjgodZN]oo3A/_oei8808_ooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooaP0
00001@0I6AT010000000<c<c03<c<`00000204a<C0040000001VIVH0IVIV00000080Ogmo00Co0000
09VIV@2IVIT000000`2c/k<3000000<0c<c<0`0000040;>c/`030000002IVIT0VIVI0080VIVI00<0
000007moO`1oOgl01`1oOgl7000001<0IVIV00H0000007moO`1oOgl0000009VIVOl000020;>c/`03
o`00003<c<co000000@0i^KV00?o00000?ooo`3oool0103oool2o`0000<0i^KV00Go00000<c<c?l0
0000/k>co`00000209VIV@050000001oOgl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00
000501TI6AD000001?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo02kooooo00?o
XC40of1S__nUTKl00_nUTKl2on74^`;olM^j00?om^Nhoo;R_?obh[`00_oSb[l3omN^[P;ocjB/00Co
e:JXomFWZ?oEYjSog;2Z0_oK[ZT00ooT^Zcok/fbonk=/P03om[0`003olO8f_nXU<7oZ9C100;oW7nb
0_nLN:X3oj1iY`?oYG^V00?oZGnWok:6YonbQZL00_nfS:X01_o7W:_objFbonBo/OoT_k7onMbYoo?Y
R@;ooooo00?o00:DobQ4^OmHD[000_n:LK43ojb6[@?odZN]00?ol=6bom?SMoooool08_ooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooo
oaT000001@0I6AT010000000<c<c03<c<`00000204a<C0040000001VIVH0IVIV00000080Ogmo00<0
000009VIV@2IVIT00P0000040;>c/`<000001P2c/k<00`000000VIVI09VIV@0409VIV@030000001o
Ogl0Ogmo00d0Ogmo1P00000<06IVIP050000001oOgl0Ogmo07moO`0000000P2IVIT01_l00000/k>c
0;>c/ol00000c<c<o`0000@0i^KV0ol000000`3ooooo0000o`0000040>KViP05o`00003<c<co0000
0;>c/ol000000P2IVIT01Ol00000Ogmo0000001VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c
0000000401TI6AH000001?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo02kooooo
0_m4Nn401?nUTKoo`[WAol:idOoQa;/2oo7K^P03ooKW^?obh[col^:l00;ohlZo00?od;2jomN^[_o?
Y:`00_o?Y:`2omFWZ0?og;2Z0_oT^Z`2onk=/P03oo?X__oJ`<3oalSJ00;oalSJ0_nXU<42oiao/P;o
W7RZ0_nPNJL2ojEkYP05ojZ0YonbQZOo/XJWok:6YonfS:X00_o7W:/01Oo;YK;oi;naonBo/Ooig:Wo
lnV900?ooooo00?o00:DobQ4^On:LK400_n:LK42ojb6[@;odZN]0_o`dK8Tooooo`0300000?oooooo
oooo00Sooooo00<00000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo6@000005
01TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`050000
002IVIT0VIVI09VIV@0000002`2c/k<00ol00000VIVI09VIV@0609VIV@03o`00001oOgl0Ogmo0180
Ogmo0`00000906IVIP05o`00001oOgl0Ogmo07moO`0000000P2IVIT01?l00000/k>c0;>c/ol00002
0<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000>KViP3Vi^H00`3Vi^H01_l00000c<c<0<c<c?l0
0000/k>co`000080VIVI00D0000007moO`000000IVIV0000000204a<C005o`00000c<c<0<c<c03<c
<`000000100I6ATF000000Cooooo00<00000ooooooooool07_ooool2000002oooooo00GoA7_Qol:i
dOo2^M7o`[WAomW_h@02olOod@04olGng?o8hN[ob>7Zon?:_`;od;2j1?o?Y:`00oo?YJgoeJNXomb`
ZP02omb`ZP03on[4[_oT^Zcok/fb00;olnRn0_o9o/L2olO8fP;oZ9C10_nLOk82oiahZP;oX7VW00?o
YG^VojZ0YonZP:L00onbQZL00onfS:[oaib[olNLZ`02onBo/@;onMbY1Oooool01OlXA;WoQWk3ohIn
`on6O/?o[8J]00;o^Y^h00?odZN]oo3A/_oChgL09Oooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooaT000001@0I6AT01@000000<c<c
03<c<`0c<c?o00000080C4a<00@0000006IVIP1VIVH000000`1oOgl01@000000VIVI09VIV@2IVIWo
0000008000001P2c/k<3000000T0VIVI4@00000607moO`030000001VIVH0IVIV00@0IVIV0P000004
07moO`040000002IVIT0VIVIo`000080/k>c00?o00000<c<c03<c<`00_l0000:0>KViP07o`00003<
c<`0c<c<0<c<c?l00000/k>co`00000209VIV@050000001oOgl0000006IVIP0000000P1<C4`01@00
0000<c<c03<c<`0c<c<0000000@06ATI5P000004ooooo`0300000?oooooooooo023ooooo00<00000
ooooooooool0;Oooool00om1003o`[WAomW_h@02olOod@04ojDh0?l5H]Sob>7Zok:_e@?od;2j00?o
a:6eolnT[?o?Y:`00_o?YJd02?oEYjSog;2Zomb`Z_oL/:[oj/B^ooSS/?o^cK;olnRn1?nY_NP00omL
[O[oMGg=ogEmc@02oiao/P;oW7RZ00?oX7VWoimjZOnZP:L00_nZP:L3ok:6Y`?oaib[00Cog[F]onBo
/Ooig:WolnV91Oooool01?lXA;WoQWk3ohIn`on6O/<3okZK^003om:W[Oo`dK;ooooo02Kooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooo
oolJ000000D06ATI00@0000003<c<`0c<c<000000`1<C4`00`000000IVIV06IVIP0200000080Ogmo
0`00000309VIV@H000007@2IVIT3000000@0Ogmo0`00000206IVIP030000001oOgl0Ogmo00D0Ogmo
00@0000009VIV@2IVIWo00000P2c/k<01?l00000c<c<0<c<c03<c<`2o`0000D0i^KV0ol000030<c<
c008o`00002c/k<0/k>co`00002IVIT0000007moO`00000206IVIP040000001<C4`0C4a<000000<0
<c<c00<0000001TI6@0I6AT00P0I6ATF000000Cooooo00<00000ooooooooool08Oooool00`00003o
ooooooooo`0^ooooo`CoZKgX00Go8UC;ok:_eOnb[mGo/ZoEom2`^P02olBQ]@;ocjB/0_o?YJd3omb`
ZP;oj/B^00?on>>`omK`TonY_NP01OnY_NP01?mL[O[oMGg=oh=a]on3LKL2oi9c[@?oWgZY0onZP:L2
ok:6Y`;oaib[0_oN]Jd2ooSHZ0Oooooo00Co:4BiohIn`on6O/?oQWk30_njVkP00ooJf=Gol=6boooo
o`0Wooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02_ooool000Wooooo00@00000
oooooooooooooooo6P00000501TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`01@000000IVIV
06IVIP1VIVH0000000@0Ogmo0P00000I09VIV@Wo00001@2IVIT00`00003o000007moO`0407moO`80
0000201oOgl010000000VIVI09VIVOl000030;>c/`03o`00003<c<`0c<c<0080c<c<1Ol000050<c<
c004o`00002c/k<0/k>co`000080VIVI00<0000007moO`0000000P1VIVH00ol00000C4a<00000004
03<c<`030000000I6AT06ATI00806ATI5P000004ooooo`0300000?oooooooooo02;ooooo00<00000
ooooooooool0;_ooool3ojVmj004ojDh0?lRE<_o/ZoEoj:Ea`Coa:6e00GocjB/olnU[Oo?YJgofK:a
omb`ZP02on[4[P;on>>`1OnY_NP2ooooo`04oih@0?meOLgoPg6goh=a]`;oTW>]0onONZT3ojZ0Y`04
ok:6Yoo0U:[o`9BZolNLZ`;og[F]0_ohf:P8ooooo`?oQWk300?o^Y^hom[HeOoJf=D0:Oooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooo
oa/000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00L0000006IVIP1VIVH0IVIV0000
0?l00000000000<0Ogmo1@00000C09VIV@03o`00002c/k<0/k>c00L0/k>c1?l0000309VIV@030000
001oOgl0Ogmo00d0Ogmo00<0000009VIV@2IVIT00_l000020;>c/`?o00002@3<c<`2o`0000030;>c
/ol0003o00000080VIVI00?o000007moO`0000000P1VIVH010000000C4a<04a<C000000303<c<`03
0000000I6AT06ATI00<06ATI5P000004ooooo`0300000?oooooooooo02?ooooo00<00000oooooooo
ool0;_ooool3ojVmj004ob9DbonRULOoXYG7oj:Ea`;oa:6e00?o`Z2golnU[Oo?YJd00_oI/[401?oL
/:[oj/B^on[4[_ohhk02ojVmj0Oooooo00?o02jgogEmcOn3LKL00_nBLjd3oimjZ@?oZX2W00Go/XJW
ol2DZ_o0U:[oaib[omje[@02ooSHZ003onWUO?oooooooooo00Sooooo0_mHYoP00ooJf=Gooooooooo
o`0Yooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02_ooool000Wooooo00@00000
oooooooooooooooo6`00000501TI6@030000000c<c<0<c<c0080<c<c00H0000004a<C01<C4`0C4a<
o`000000000406IVIP030000001oOgl0Ogmo00D0Ogmo2@00000809VIV@;o00003P2c/k<01Ol00000
VIVI09VIV@2IVIT0000000h0Ogmo00?o00000000002IVIT00P2IVIT00ol00000/k>c0;>c/`020;>c
/`Co00000P3<c<`3o`0000030;>c/ol0003o00000080VIVI0P00000207moO`040000001VIVH0IVIV
00000080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6AH000001?ooool00`00003ooooooooo
o`0Tooooo`800000;oooool2ojVmj005o`<m__lRE<_oXYG7oj:Eaoo4XKD00oo2X;L00oo?YJgofK:a
omVb/@02oncA^@03on[4[_ohhk3ooooo00Wooooo00?o02jgoh=a]on3LKL00_nBLjd3oimjZ@;oZX2W
0oo0U:X2omje[@03ooSHZ?oYiGcooooo03Wooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`0:ooooo`002Oooool01000003ooooooooooooooolL000000D06ATI00<0000003<c<`0c<c<0
0P0c<c<2000000<0C4a<0P00000306IVIP<000003@1oOgl00`000000VIVI09VIV@0409VIV@03o`00
002c/k<0/k>c0080/k>c2_l000030;>c/`05o`00002IVIT0VIVI09VIVOl000003`1oOgl01@000000
VIVI09VIV@2IVIWo000000L0/k>c0_l000030;>c/`05o`00002IVIT0VIVI09VIV@0000000`1oOgl0
10000000IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATG000000Cooooo
00<00000ooooooooool09_ooool00`00003oooooooooo`0]ooooo`;oZKgX00?o0cfnoj:EaonHSlT0
1?o2X;L00oo?YJgofK:aomVb/@02oncA^@03onWgZOoooooooooo00Wooooo00?o02jgodYI_on3LKL0
0_nBLjd3oimjZ@03ojZ0YondS:co`9BZ00;o`9BZ00Coejj_omje[Oohf:So`]IQ>_ooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooa`0
000000?o000001TI6@0I6AT00`0I6AT2000000@0<c<c00<0000004a<C01<C4`00P1<C4`2000000@0
IVIV1000000:07moO`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00P2c/k<00ol00000
c<c<0<c<c0080<c<c005o`00002c/k<0/k>c0;>c/ol000000`2IVIT00`000000Ogmo07moO`0=07mo
O`0400000?l00000000009VIV@Co00001@2c/k<3o`0000<0VIVI00Go000007moO`1oOgl0Ogmoo`00
000206IVIP04o`00001<C4`0C4a<o`0000<0<c<c00<0000001TI6@0I6AT00`0I6AT00ol000000000
0000000E000000Cooooo00<00000ooooooooool09oooool00`00003oooooooooo`0]ooooo`;oZKgX
0onHSlT3ol:P]`;ofK:a0oo/dKT00ooYmjWoooooooooo`0:ooooo`04o`0^]om:FKooTW>]oi9c[@;o
WgZY00GoXH6`okB<[?ndS:co]8b/ol2DZP02omN^[`03ooOL[oo2eV7o`]IQ03_ooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolM0000
00L06ATI00<0000003<c<`0c<c<00P0c<c<00ol00000000004a<C00304a<C0030000001VIVH0IVIV
00D0IVIV00?o00000000000000000P00000507moO`030000002IVIT0VIVI0080VIVI00?o00000;>c
/`2c/k<00P2c/k<01?l00000c<c<0<c<c03<c<`4o`0000<0c<c<00Go00000;>c/`2c/k<0/k>co`00
000309VIV@030000001oOgl0Ogmo00D0Ogmo1@00000607moO`030000002IVIT0VIVI0080VIVI1Ol0
000409VIV@8000000P1oOgl200000080IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`030000
000I6AT06ATI00<06ATI60000004ooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool0
;Oooool2ojVmj0?oV8o900Co`Z2golZb`_o://;ofK:a0_o/dKT00ooYmjWoooooooooo`0<ooooo`03
odYI_on2LKOoPW6g00?oXH6`0ondS:`01Oo0U:[oejj_omN^[oogg:oo`]IQ03gooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`09ooooo`002Oooool01000003ooooooooooooooolN0000
00L06ATI00<0000003<c<`0c<c<00`0c<c<2000000<0C4a<0`00000906IVIP030000001oOgl0Ogmo
0080Ogmo00D0000009VIV@2IVIT0VIVIo`0000040;>c/`05o`00003<c<`0c<c<0<c<c?l00000103V
i^H2o`000080c<c<00Go00000;>c/`2c/k<0/k>co`00000309VIV@030000001oOgl0Ogmo0080Ogmo
0P00000506IVIP<00000101oOgl3000000H0VIVI1000000207moO`8000000`1VIVH01@000000C4a<
04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT0100I6ATH000000Cooooo00<00000oooooooo
ool0:Oooool2000002gooooo00<00000ooooooooool00_n8W^83olZb`P03omkYf_o/dKWooooo00oo
oooo00CoBUVooh9a]on2LKOoPW6g0onQPK02okB<[0;oejj_00?ommb_ol;FHOooool0?_ooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00Wooooo0009ooooo`0400000?oooooooooooooo
oah00000200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<1000000606IV
IP030000001oOgl0Ogmo0080Ogmo00@0000009VIV@2IVIWo00000`2c/k<01Ol00000c<c<0<c<c03<
c<co000000L0i^KV00Co00000<c<c03<c<co00000P2c/k<01Ol00000VIVI09VIV@2IVIT0000000@0
Ogmo00<0000006IVIP1VIVH01`1VIVH2000000D0Ogmo1P00000507moO`03o`00001VIVH0IVIV0080
IVIV00D0000004a<C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00<06ATI6@000004oooo
o`0300000?oooooooooo02_ooooo00<00000ooooooooool0:_ooool01000003oooooooooooooool2
ohRNhP03olZb`_oNjM[og^WJ01;ooooo00?oBUVooh9a]on2LKL00onQPK02okB<[003olRW^?oG[Zoo
mmb_043ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`09ooooo`002Oooool01000
003ooooooooooooooolO00000003o`00000I6AT06ATI00D06ATI00?o00000000000c<c<0100c<c<0
0ol00000000004a<C00604a<C08000001@1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00Co
00000;>c/`2c/k?o00000`3<c<`00ol00000i^KV0>KViP070>KViP04o`00003<c<`0c<c<o`000080
/k>c00Go000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV00T0IVIV00?o00000000
000000000P00000:07moO`8000000P1VIVH2000000<0C4a<00?o000003<c<`0c<c<00P0c<c<00`00
00006ATI01TI6@0401TI6AT000001?ooool00`00003oooooooooo`0/ooooo`0300000?oooooooooo
02Wooooo00<00000ooooooooool01?ooool00ooNjM[oooooooooo`0Booooo`;oPW6g0onQPK001Ond
S:cob:NholRW^?oG[Zoommb_047ooooo00D00000oooooooooooooooo0000000;ooooo`002Oooool0
1000003ooooooooooooooolQ000000P06ATI0P00000503<c<`<000001P1<C4`2000000<0IVIV00D0
000007moO`1oOgl0Ogmo0000000209VIV@04o`00002c/k<0/k>co`0000<0c<c<00?o00000>KViP3V
i^H01`3Vi^H01ol00000c<c<0<c<c03<c<co00000;>c/ol000000`2IVIT01@000000Ogmo07moO`1o
Ogl000000100IVIV2P00000206IVIP8000000`1<C4`2000000@0<c<c00<0000001TI6@0I6AT01@0I
6ATI000000Cooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0Xooooo`0300000?oo
oooooooo01[ooooo0_m;KM<00onQPK3oZ9[7olRW^002olRW^003onk/b?oooooooooo047ooooo00@0
0000ooooooooool000002oooool000Wooooo00@00000oooooooooooooooo8P00000901TI6@800000
1P0c<c<3000000D0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002IVIWo00000080
/k>c00Co00000<c<c03<c<co00002P3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c00Co0000
09VIV@2IVIT000000P1oOgl00`000000IVIV06IVIP0406IVIP@000004@1VIVH2000000@0C4a<00<0
000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0501TI6AX000001?ooool00`00003ooooooooo
o`0^ooooo`800000:?ooool00`00003oooooooooo`0Kooooo`04od]]donXV/OoZ9[7ojRJa`;ob:Nh
00?ok^c8ooooooooool0@_ooool00`00003ooooo0000000;ooooo`002Oooool01000003ooooooooo
oooooolT000000T06ATI0P00000703<c<`030000001<C4`0C4a<00<0C4a<00Go000006IVIP1VIVH0
IVIV0000000207moO`030000002IVIWo00000080/k>c00Co00000<c<c03<c<co00002`3Vi^H01?l0
0000c<c<0<c<c?l000020;>c/`04o`00002IVIT0VIVI00000080Ogmo00<0000006IVIP1VIVH00P1V
IVH2000000@0C4a<1@0000000ol0000000000000000506IVIP80000000?o00000000001<C4`00`1<
C4`2000000@0<c<c0P00000601TI6@0300000?l00000000001T000001?ooool00`00003ooooooooo
o`0`ooooo`0300000?oooooooooo02Gooooo00<00000ooooooooool07?ooool01Om;KM?oZ9[7ojRJ
aoo8YkSok^c804Gooooo00<00000ooooo`0000002oooool000Wooooo00@00000oooooooooooooooo
9@00000:01TI6@030000000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV
06IVIP1VIVH000000080Ogmo00<0000009VIVOl000000P2c/k<01?l00000c<c<0<c<c?l0000;0>KV
iP04o`00003<c<`0c<c<o`000080/k>c00Co000009VIV@2IVIT000000P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00/0C4a<1@00000604a<C08000001@0c<c<00`0000006ATI01TI
6@0601TI6A`000001?ooool00`00003oooooooooo`0aooooo`0300000?oooooooooo02Cooooo00<0
0000ooooooooool07Oooool00onXV/OoO^G]ooooo`17ooooo`0300000?ooool0000000[ooooo0009
ooooo`0400000?ooooooooooooooobH000002P0I6AT3000000D0<c<c00<0000004a<C01<C4`00P1<
C4`010000000IVIV06IVIP00000207moO`030000002IVIWo000000<0/k>c00?o00000<c<c?l00000
2P3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c00Ko000009VIV@2IVIT0000007moO`000004
06IVIP030000001<C4`0C4a<01D0C4a<0P00000603<c<`030000000I6AT06ATI00H06ATI7@000004
ooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool08oooool00`00003oooooooooo`1X
ooooo`8000002_ooool000Wooooo00@00000oooooooooooooooo:000000;01TI6@800000100c<c<0
1@000000C4a<04a<C01<C4`0000000<0IVIV00H0000007moO`1oOgl0000009VIVOl000020;>c/`04
o`00003<c<`0c<c<o`0000T0i^KV00Oo00000<c<c03<c<`0c<c<o`00002c/k?o00000080VIVI00@0
000007moO`1oOgl000000`1VIVH00`000000C4a<04a<C00404a<C18000001`0c<c<00`0000006ATI
01TI6@0601TI6Ah000001?ooool00`00003oooooooooo`0cooooo`8000008oooool00`00003ooooo
ooooo`1Wooooo`<000002_ooool000Wooooo00@00000oooooooooooooooo:@0000000ol000000000
01TI6@0801TI6@03o`0000000000<c<c00<0<c<c00D00000o`00001<C4`0C4a<0000000206IVIP06
0000001oOgl0Ogmo0000002IVIWo00000P2c/k<00ol00000c<c<0<c<c002o`0000L0i^KV0_l00003
0<c<c003o`00002c/k?o00000080VIVI00<0000007moOol000000P1VIVH00`00003o000004a<C003
04a<C0<000005P0c<c<200000003o`00000I6AT06ATI00H06ATI7`000004ooooo`0300000?oooooo
oooo03Gooooo00<00000ooooooooool08?ooool00`00003oooooooooo`1Sooooo`@000003Oooool0
00Wooooo00@00000oooooooooooooooo;@00000901TI6@030000000c<c<0<c<c0080<c<c00@00000
04a<C01<C4`000000`1VIVH01Ol00000Ogmo0000002IVIWo00000080/k>c00?o00000<c<c03<c<`0
0P3<c<`2o`0000@0i^KV00?o00000<c<c03<c<`00P3<c<`01?l00000/k>c0;>c/ol0000209VIV@03
0000001oOgl000000080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0E03<c<`80
00002P0I6ATP000000Cooooo00<00000ooooooooool0=_ooool00`00003oooooooooo`0Oooooo`03
00000?oooooooooo063ooooo0`00000Aooooo`002Oooool01000003oooooooooooooool^000000T0
6ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP060000001oOgl0Ogmo
0000002IVIWo00000P2c/k<00ol00000c<c<0<c<c0030<c<c0Co0000103<c<`01?l00000/k>c0;>c
/ol0000209VIV@060000001oOgl0Ogmo0000001VIVH000000`1<C4`200000180<c<c1P00000;01TI
6B4000001?ooool00`00003oooooooooo`0gooooo`0300000?oooooooooo01kooooo00<00000oooo
ooooool0G?ooool4000001Cooooo0009ooooo`0400000?ooooooooooooooobh0000000?o00000000
000I6AT01`0I6AT00ol00000<c<c03<c<`0203<c<`040000001<C4`0C4a<00000080IVIV00H00000
07moO`00003o000009VIVOl000020;>c/`03o`00003<c<`0c<c<00L0c<c<0ol000000`2c/k?o0000
o`00000209VIV@040000001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`000001`0c<c<40000
0003o`0000000000000000H000003P0I6AT200000003o`0000000000000001l000001?ooool00`00
003oooooooooo`0hooooo`8000007_ooool00`00003oooooooooo`1Hooooo`@000006?ooool000Wo
oooo00@00000oooooooooooooooo<@00000701TI6@030000000c<c<0<c<c0080<c<c00@0000004a<
C01<C4`000000P1VIVH010000000Ogmo07moO`00000209VIV@;o000000@0/k>co`000?l0003o0000
1@3<c<`01Ol00000/k>c0;>c/`2c/k?o000000@0VIVI00<0000007moO`0000000`1VIVH010000000
C4a<04a<C000000503<c<`8000006P0I6ATU000000Cooooo00<00000ooooooooool0>_ooool00`00
003oooooooooo`0Kooooo`0300000?oooooooooo05Cooooo1000000Looooo`002Oooool01000003o
oooooooooooooolb000000L06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C0000002
06IVIP040000001oOgl0Ogmo000000<0VIVI00Co00000;>c/`2c/k<0/k>c1Ol000030;>c/`03o`00
002IVIT0VIVI0080VIVI00<0000007moO`0000000`1VIVH010000000C4a<04a<C000000503<c<`03
0000000I6AT06ATI01P06ATI9`000004ooooo`0300000?oooooooooo03_ooooo00<00000oooooooo
ool06_ooool00`00003oooooooooo`1Aooooo`<000008?ooool000Wooooo00@00000oooooooooooo
oooo<`00000701TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`010000000IVIV06IVIP000002
07moO`050000002IVIT0VIVI09VIVOl000002@2c/k<00ol00000VIVI09VIV@0209VIV@030000001o
Ogoo000000<0IVIV00Co000004a<C01<C4co00001@0c<c<00`0000006ATI01TI6@0G01TI6@03o`00
00000000000002H000001?ooool00`00003oooooooooo`0looooo`0300000?oooooooooo01Wooooo
00<00000ooooooooool0COooool4000002?ooooo0009ooooo`0400000?oooooooooooooooc@00000
00?o000001TI6@0I6AT0100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00Go000006IVIP1V
IVKo00000000000207moO`8000000P2IVIT:o`000080VIVI0P0000000`1oOgl000000000000206IV
IP050000001<C4`0C4a<04a<C0000000100c<c<00ol000006ATI01TI6@0C01TI6Bh000001?ooool0
0`00003oooooooooo`0mooooo`8000006Oooool00`00003oooooooooo`19ooooo`@000009oooool0
00Wooooo00@00000oooooooooooooooo=@00000601TI6@030000000c<c<0<c<c0080<c<c00@00000
04a<C01<C4`000000`1VIVH200000080Ogmo00<0000009VIV@2IVIT02@2IVIT200000080Ogmo00D0
000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0
3@0I6ATe000000Cooooo00<00000ooooooooool0?oooool00`00003oooooooooo`0Fooooo`030000
0?oooooooooo04Gooooo1000000[ooooo`002Oooool01000003ooooooooooooooolf000000H06ATI
00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000406IVIP030000001oOgl0Ogmo00<0
00001P2IVIT2000000<0Ogmo00Go000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c
0080<c<c00<0000001TI6@0I6AT01`0I6ATl000000Cooooo00<00000ooooooooool0@?ooool00`00
003oooooooooo`0Dooooo`0300000?oooooooooo04?ooooo0`00000_ooooo`002Oooool01000003o
oooooooooooooolg000000H06ATI00<0000003<c<`0c<c<00P0c<c<01P000000C4a<04a<C000003o
000000000080IVIV00?o00000000001oOgl00P1oOgl6000000<0Ogmo0P00000206IVIP8000000P1<
C4`2000000<0<c<c0P00000701TI6@80000000?o0000000000000000>P000004ooooo`0300000?oo
oooooooo047ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0oooooo`@00000<_oo
ool000Wooooo00@00000oooooooooooooooo=`0000000ol000006ATI01TI6@0401TI6@03o`00000c
<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`010000000IVIV06IVIP1VIVH3000000H0Ogmo
0`00000306IVIP050000001<C4`0C4a<04a<C0000000100c<c<00`0000006ATI01TI6@0601TI6D00
00001?ooool00`00003oooooooooo`12ooooo`8000004oooool00`00003oooooooooo`0kooooo`@0
0000=_ooool000Wooooo00@00000oooooooooooooooo>000000601TI6@030000000c<c<0<c<c00<0
<c<c00<0000004a<C01<C4`00P1<C4`2000000@0IVIV1P00000406IVIP8000000`1<C4`00`000000
<c<c03<c<`0303<c<`030000000I6AT06ATI00D06ATI@@000004ooooo`0300000?oooooooooo04Co
oooo00<00000ooooooooool04?ooool00`00003oooooooooo`0gooooo`@00000>_ooool000Wooooo
00@00000oooooooooooooooo>@00000601TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0906IVIP800000101<C4`00ol00000<c<c03<c<`0303<c<`03
0000000I6AT06ATI00D06ATI00?o0000000000000000?`000004ooooo`0300000?oooooooooo04Go
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0cooooo`@00000?_ooool000Wooooo
00@00000oooooooooooooooo>`00000501TI6@800000100c<c<00ol0000000000000000304a<C0/0
00001@1<C4`2000000@0<c<c00?o000001TI6@0I6AT01@0I6AU3000000Cooooo00<00000oooooooo
ool0A_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo033ooooo0`000012ooooo`00
2Oooool01000003oooooooooooooooll000000H06ATI0P00000503<c<`<00000301<C4`4000000@0
<c<c0P00000701TI6D@000001?ooool00`00003oooooooooo`17ooooo`0300000?oooooooooo00go
oooo00<00000ooooooooool0;?ooool4000004Gooooo0009ooooo`0400000?oooooooooooooooc`0
0000200I6AT00`000000<c<c03<c<`0503<c<`<000001P1<C4`3000000H0<c<c0P00000701TI6DH0
00001?ooool00`00003oooooooooo`18ooooo`8000003Oooool00`00003oooooooooo`0Xooooo`@0
0000BOooool000Wooooo00@00000oooooooooooooooo?@00000801TI6@800000200c<c<6000000L0
<c<c0P00000801TI6DL000001?ooool00`00003oooooooooo`1:ooooo`0300000?oooooooooo00[o
oooo00<00000ooooooooool09?ooool4000004gooooo0009ooooo`0400000?oooooooooooooooch0
00002@0I6AT200000180<c<c00<0000001TI6@0I6AT01`0I6AU8000000Cooooo00<00000oooooooo
ool0Boooool00`00003oooooooooo`09ooooo`0300000?oooooooooo027ooooo0`00001Aooooo`00
2Oooool01000003ooooooooooooooom0000000T06ATI0`00000<03<c<`<000002@0I6AU9000000Co
oooo00<00000ooooooooool0C?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01go
oooo1000001Dooooo`002Oooool01000003ooooooooooooooom1000000/06ATI3000000;01TI6DX0
00001?ooool00`00003oooooooooo`1=ooooo`8000002?ooool00`00003oooooooooo`0Iooooo`@0
0000F?ooool000Wooooo00@00000oooooooooooooooo@P0000000ol00000000001TI6@0K01TI6@80
000000?o0000000000000000B0000004ooooo`0300000?oooooooooo04oooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0Eooooo`@00000G?ooool000Wooooo00@00000oooooooooooo
ooooA@00000I01TI6Dl000001?ooool00`00003oooooooooo`1@ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool04_ooool30000063ooooo0009ooooo`0400000?ooooooooooooooodL0
00005@0I6AUA000000Cooooo00<00000ooooooooool0DOooool00`00003oooooooooo`03ooooo`03
00000?oooooooooo00kooooo1000001Sooooo`002Oooool01000003ooooooooooooooom<000000`0
6ATI0`0000000ol0000000000000001?000000Cooooo00<00000ooooooooool0D_ooool2000000?o
oooo00<00000ooooooooool02_ooool4000006Oooooo0009ooooo`0400000?ooooooooooooooodl0
00001P0I6AUH000000Cooooo00<00000ooooooooool0E?ooool01000003oooooooooo`000008oooo
o`@00000Joooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
05Gooooo00<00000ooooo`0000001Oooool3000006oooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`1Fooooo`80000000?ooooo0000000000000P00001boooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Eoooool20000
07Kooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?oooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`04
00000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooo
ooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?oooo
o`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo0009oooookH000004Ooooonf000000[ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Q
ooooo`/00000A_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0F_ooool00`00003o0000000000040000
00_ooooo0`0000000ol0003oooooooooo`10ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Hooooo`80
00005_ooool3000003oooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo047ooooo2000000=ooooo`800000
6oooool2000003gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo03[ooooo1`000008ooooo`d000007ooo
ool00`00003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0gooooo`0300000?l00000
000002Oooooo2`00000:ooooo`03o`000?oooooooooo03Wooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
03Gooooo0P00000Vooooo`@000002oooool4000000Oooooo0P00000iooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0cooooo`8000009?ooool4000001?ooooo0P000007ooooo`800000=oooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`1<oooooaT0okK1COooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool02oooool00`00003o0000
o`00000200000004o`00000000000000000000?ooooo2P3o]/43000000P0okK100<00000o`000000
0000100000001?l000000000000000000006ooooo`8000001oooool00ol0003oooooooooo`0doooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04Wooooo7`3o]/5:ooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`06ooooo`H0
00002Oooool700000080okK1100000080?nf`@<000001`3o]/44ooooo`<000001Oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo03Cooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0A_oooolU0?nf`DOooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0`ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02_ooool:0?nf`@800000
2P3o]/42000000d0okK11?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool0<oooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`13ooooob/0okK1A?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02oooooo00<0
0000ooooooooool01Oooool2000000Sooooo1000000E0?nf`@8000001@3o]/4;00000080okK10_oo
ool2000000Cooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo043ooooo<@3o]/51ooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`04ooooo`8000001_ooool4
000000@0okK11`00000:0?nf`@0400000?l000000000000000@0okK10`00000;0?nf`@03o`000000
000000000080okK100?ooooo00000?ooool00oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo037ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0?Ooooolg
0?nf`Ckooooo00<00000ooooooooool03oooool00`00003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Cooooo00<00000ooooooooool00oooool3000000l0okK12P0000060?nf`@8000000`3o]/4:
000000@0okK100D000000?nf`@3o]/40okK100000004ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool0<?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0j
oooooc/0okK1?Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02cooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`03ooooo`040000003o]/40okK10?nf`@`00000403o
]/43000000@0okK100<000000?nf`@3o]/40203o]/42000000<0okK10P0000020?nf`@8000000ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool0>Oooool[0?nf`@Go003o3@3o]/4looooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0:oooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo00;ooooo00Co00000000003o]/40okK10P00000<0?nf`@@000002@3o]/43000000<0okK11000
00030?nf`@D0000000?o00000?nf`@3o]/400P3o]/400ol0000000000?nf`@020?nf`@050000003o
]/40okK10?nf`@0000000oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo02kooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0=oooool[0?nf`@;o003o1@3o
]/43o`00o`d0okK1>Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02_ooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`02ooooo`060000003o]/40okK10?nf`@00003o
00001@3o]/48000000@0okK10`0000020?nf`@@00000103o]/42000000D0okK100<00000o`00003o
]/401@3o]/43000000<0okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK1
00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo03Gooooo:P3o]/43o`00o`X0okK10_l00?l=0?nf`COo
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool00_ooool01@000000okK10?nf`@3o]/40000000<0okK1100000080?nf
`@8000001@3o]/42000000H0okK10P0000040?nf`@<000000`3o]/45000000<0okK10P0000020?nf
`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000Kooooo00<0
0000ooooooooool0;Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0d
ooooo`/0okK11Ol00?lJ0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/402`3o]/4f
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`04
ooooo`0500000?ooooooooooooooo`0000000P3o]/4200000080okK10P0000040?nf`@@000001P3o
]/42000000X0okK100<000000?nf`@3o]/400P3o]/42000000<0okK10`0000050?nf`@<000000P3o
]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`00003o
ooooooooo`04ooooo`0300000?oooooooooo02cooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0<oooool:0?nf`@;o003o1@3o]/43o`00oaH0okK100?o003o0?nf`@3o]/40
3`3o]/400ol00?l0okK10?nf`@0;0?nf`CGooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00?ooooo00D00000ooooooooooooooooo`0000020?nf`@05
0000003o]/40okK10?nf`Ol000000`3o]/43000000@0okK10`0000000ol00000okK10?nf`@020?nf
`@03o`0000000000000000D0okK100<00000o`00003o]/400P3o]/4200000080okK10`00000;0?nf
`@04o`00003o]/40okK1o`000080okK100@000000?nf`@3o]/4000000`3o]/401@000000okK10?nf
`@3o]/40000000Kooooo0P00000/ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo03;ooooo2@3o]/42o`00o`X0okK10_l00?lC0?nf`@03o`00o`3o]/40okK10100okK100?o
003o0?nf`@3o]/40303o]/4dooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0:Ooo
ool00`00003oooooooooo`03ooooo`0400000?oooooooooo00000080okK100D000000?nf`@3o]/40
okK1000000020?nf`@8000000`3o]/44000000@0okK10`0000040?nf`@D00000103o]/401@000000
okK10?nf`@3o]/40000000<0okK12P0000020?nf`@80000000L0okK10000003o]/40okK10000003o
]/40000000<0okK100D000000?nf`@3o]/40okK100000008ooooo`0300000?oooooooooo02Wooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0<?ooool:0?nf`@03o`00o`3o
]/40okK100`0okK10_l00?lA0?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/403@3o
]/4booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0:?ooool00`00003ooooooooo
o`03ooooo`0400000?ooool0okK100000080okK100<000000?nf`@3o]/400P0000000`3o]/400000
000000020?nf`@<00000103o]/44000000<0okK10`0000090?nf`@050000003o]/40okK10?nf`@00
00000`3o]/400`000000okK10?nf`@080?nf`@8000000P3o]/400`000000okK1000000020?nf`@03
o`00003o]/40000000<0okK100@000000?nf`@3o]/40okK10P000007ooooo`0300000?oooooooooo
02Sooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;oooool:0?nf`@03
o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0C0?nf`@03
o`00o`3o]/40okK100d0okK1<Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02Oo
oooo00<00000ooooooooool00oooool01000003ooooo0?nf`@0000020?nf`@04o`00003o]/40okK1
00000080okK100<000000?nf`@3o]/400P00000;0?nf`@03o`0000000000000000<0okK100?o0000
0?nf`@3o]/400`3o]/400`00003o0000000000030?nf`@050000003o]/40okK10?nf`Ol000000`3o
]/4500000003o`00003o]/40okK10080okK100H000000?nf`@3o]/7o00000?nf`@0000020?nf`@04
0000003o]/7o000000000080okK100<000000?nf`@3o]/400P3o]/400`00003oooooooooo`05oooo
o`03o`000?oooooooooo02Oooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0;_ooool;0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0
okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100h0okK1<?ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo02Oooooo00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf
`@040000003o]/40okK100000080okK100<000000?nf`Ol000000P3o]/4:000000@0okK100@00000
0?nf`@3o]/40okK11@0000060?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK1
0?nf`@040?nf`@8000000P3o]/401P000000okK10?nf`@000000okK100000080okK100@000000?nf
`@3o]/4000000P3o]/400`000000okK10?nf`@030?nf`@0300000?oooooooooo00Gooooo0P00000W
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02gooooo2`3o]/400ol0
0?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/40503o]/400ol0
0?l0okK10?nf`@0?0?nf`Boooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Voooo
o`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@00
00020?nf`@060000003o]/40okK10000003o]/4000002P3o]/400`000000okK10?nf`@020?nf`@03
0000003o]/40okK100X0okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK1
00L0okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@040000003o]/40okK100000080okK1
00@000000?nf`@3o]/4000001@3o]/400`00003oooooooooo`06ooooo`0300000?oooooooooo02Co
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;?ooool<0?nf`@03o`00
o`3o]/40okK10140okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00
o`3o]/40okK100l0okK1;_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02Kooooo
00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf`@060000003o]/40okK10000
003o]/4000000P3o]/400`000000okK1000000040?nf`@@00000103o]/401Ol00000okK10?nf`@3o
]/40000000/0okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100T0okK1
00H000000?nf`@3o]/4000000?nf`@0000020?nf`@03o`00003o]/40000000<0okK100@000000?nf
`@3o]/4000001@3o]/400`00003oooooooooo`06ooooo`0300000?oooooooooo02?ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0:oooool<0?nf`@03o`00o`3o]/40okK1
0180okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@080?nf`@?o00002P3o]/400ol0
0?l0okK10?nf`@0@0?nf`Bgooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Uoooo
o`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/401P000000okK10?nf`@00
0000okK100000080okK100<000000?nf`@0000000`3o]/42000000@0okK100?o00000000003o]/40
0P3o]/401@000000okK10?nf`@3o]/40000000T0okK100D000000?nf`@3o]/40okK1000000020?nf
`@030000003o]/40okK100@0okK10P0000050?nf`@060000003o]/40okK1o`00003o]/4000000P3o
]/400`000000okK1000000030?nf`@050000003o]/40okK1o`0000000000103o]/42000000Oooooo
0P00000Sooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02[ooooo3@3o
]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/40203o
]/45o`0000T0okK100?o003o0?nf`@3o]/40403o]/4]ooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool09?ooool00`00003oooooooooo`03ooooo`050?nf`@000000okK10?nf`@000000
0P3o]/401P000000okK10?nf`@000000okK100000080okK100<000000?nf`@0000000P3o]/400`00
0000okK10?nf`@050?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@07
0?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@040?nf`@030000003o
]/40000000@0okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o]/40000000<0
okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@03ooooo`000000000000Oo
oooo00<00000ooooooooool08?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Zooooo`d0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@090?nf`@03o`00
o`3o]/40okK100P0okK11Ol000090?nf`@03o`00o`3o]/40okK10140okK1;?ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01?ooool010000000okK1
0?nf`@0000020?nf`@040000003o]/40okK100000080okK100D000000?nf`@000000okK100000002
0?nf`@030000003o]/40okK100L0okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o
]/40okK100H0okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100<0okK1
00D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK100000080okK100H000000?nf
`@3o]/4000000?nf`@0000030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o
]/42ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Yooooo`h0okK100?o003o0?nf`@3o]/401`3o]/43
o`0000T0okK100?o003o0?nf`@3o]/402@3o]/400ol00?l0okK10?nf`@080?nf`@Go00002@3o]/40
0ol00?l0okK10?nf`@0B0?nf`B_ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0R
ooooo`0300000?oooooooooo00Cooooo00D000000?nf`@3o]/40okK1000000020?nf`@060000003o
]/40okK10000003o]/4000000P3o]/401@000000okK10000003o]/40000000/0okK100@000000?nf
`@3o]/4000000`3o]/400`000000okK10?nf`@060?nf`@050000003o]/40okK10?nf`@0000000P3o
]/400`000000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@000000103o]/4010000000okK1
0?nf`@0000020?nf`@03o`00003o]/4000000080okK100D000000?nf`@3o]/40okK1000000040?nf
`@03o`00003o]/40okK10080okK10_ooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo
01oooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0:?ooool>0?nf`@03
o`00o`3o]/40okK100L0okK11Ol000090?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o
]/40203o]/43o`0000X0okK100?o003o0?nf`@3o]/404`3o]/4Zooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`030?nf`Ol00000okK10080
okK100Ko00000?nf`@3o]/4000000?nf`@0000020?nf`@070000003o]/4000000?nf`@000000okK1
0000000=0?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/401@3o]/401@000000
okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/400P3o]/42000000@0okK100Go00000?nf
`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/7o0000
000000020?nf`@8000000`3o]/4300000080okK100?ooooo0000000000001_ooool2000001oooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool09oooool?0?nf`@03o`00o`3o
]/40okK100L0okK11Ol000090?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/405@3o
]/400ol00?l0okK10?nf`@0D0?nf`BWooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0Qooooo`0300000?oooooooooo00?ooooo00<0okK10000003o]/400`3o]/4020000000okK10?nf
`@000000okK10000003o]/7o00000P3o]/401@000000okK10000003o]/40000000d0okK100@00000
0?nf`@3o]/4000000`3o]/400`000000okK10?nf`@050?nf`@050000003o]/40okK10?nf`@000000
0P3o]/400`000000okK10?nf`@040?nf`@@00000103o]/4010000000okK10?nf`@0000020?nf`@05
0000003o]/40okK10?nf`@0000000`3o]/4010000000okK10?nf`@3o]/42000000@0okK100<00000
0?nf`@3o]/400_ooool2000000Kooooo00<00000ooooooooool07?ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Voooooa00okK100?o003o0?nf`@3o]/401`3o]/45o`00
00T0okK100?o003o0?nf`@3o]/402@3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK1
01@0okK1:Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo023ooooo00<00000oooo
ooooool00oooool00`3o]/4000000?nf`@030?nf`@060000003o]/40okK10000003o]/4000000P3o
]/401@000000okK10000003o]/4000000080okK100<000000?nf`@3o]/402P3o]/4010000000okK1
0?nf`@0000030?nf`@030000003o]/40okK100L0okK100D000000?nf`@3o]/40okK1000000020?nf
`@030000003o]/40okK100/0okK100D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40
okK10?nf`@0000000`3o]/400`000000okK10?nf`@020?nf`@8000000`3o]/400`000000okK1oooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Voooooa00okK100?o003o0?nf`@3o]/40203o]/43
o`0000X0okK100?o003o0?nf`@3o]/402P3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40
okK101H0okK1:?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01oooooo00<00000
ooooooooool01?ooool00`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100<0
00000?nf`@0000000P3o]/400`000000okK1000000020?nf`@030000003o]/40okK100X0okK100@0
00000?nf`@3o]/4000000P3o]/400`000000okK10?nf`@090?nf`@040000003o]/40okK1000000<0
okK100<000000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/40000000<0okK100Go00000?nf
`@3o]/40okK1o`000002000000040?nf`Ol000000000000000<0okK10P0000020?nf`@03o`00003o
]/7ooooo00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Jooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo02Gooooo4P3o]/400ol00?l0okK10?nf`@0C
0?nf`@03o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0G
0?nf`BOooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Oooooo`03o`000?oooooo
oooo00?ooooo00<0okK1o`00003o]/400P3o]/401`000000okK10?nf`@3o]/4000000?nf`Ol00000
0P3o]/401P000000okK10?nf`@000000okK100000080okK100<000000?nf`@3o]/402@3o]/401@00
0000okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/402@3o]/401@000000okK10?nf`@3o
]/40000000<0okK100?o00000000003o]/402@3o]/401@000000okK10?nf`@3o]/40000000@0okK1
0P0000040?nf`@050000003o]/40okK10?nf`@000000103o]/401@000000okK10?nf`@000000okK1
00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo02Cooooo4`3o]/400ol00?l0okK10?nf`@0C0?nf`@03
o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0G0?nf`BOo
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00?o
oooo00<0okK10000003o]/400P3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf
`@3o]/4000000P3o]/400`000000okK1000000030?nf`@030000003o]/40okK100L0okK100D00000
0?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100<0okK1100000040?nf`@040000003o
]/40okK10?nf`@8000000`3o]/42000000D0okK10`0000050?nf`@030000003o]/40okK100<0okK1
0P0000030?nf`@8000000P3o]/42000000<0okK100@000000?nf`@3o]/4000001?ooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool09?oooolC0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40
303o]/42o`00oa80okK100?o003o0?nf`@3o]/406@3o]/4Vooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool07Oooool00`00003oooooooooo`04ooooo`030000003o]/40okK10080okK1
00L000000?nf`@3o]/40okK10000003o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/40
1@000000okK10?nf`@3o]/40000000P0okK100D000000?nf`@3o]/40okK1o`0000030?nf`@04o`00
003o]/40okK10?nf`@800000103o]/42000000<0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@020?nf`@D000002@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK10080
okK100D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1000000Cooooo00?o0000
ooooooooool00oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo02?ooooo5@3o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK1
00l0okK100?o003o0?nf`@3o]/403@3o]/42o`00oa`0okK19_ooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo01cooooo00<00000ooooooooool00oooool00ol0000000000?nf`@030?nf
`@030000003o]/40okK1008000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40
okK1000000@0okK10P0000040?nf`@8000000`3o]/42000000030?nf`@00000000000080okK10P00
00080?nf`@8000000P3o]/44000000030?nf`@00000000000100okK10`0000040?nf`@<000000`3o
]/401_l0000000000000003o]/7o000000000080okK100D000000?nf`@3o]/7o000000000003oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool06?ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`0SoooooaH0okK100?o003o0?nf`@3o]/403`3o]/400ol00?l0
okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100X0okK10_l00?l>0?nf`@Co003o3@3o]/4Uooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03
0000003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@000003
0?nf`@040000003o]/40okK1000000H0okK1100000040?nf`@040000003o]/40okK1000000<0okK1
00<000000?nf`@3o]/402P3o]/42000000@0okK100<000000?nf`@3o]/400P00000A0?nf`@<00000
103o]/42000000@0okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@000003oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool06?ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`0RoooooaP0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0
okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/402`3o]/43o`00o`@0
okK10ol00?l;0?nf`BCooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Jooooo`03
00000?oooooooooo00Cooooo00@000000?nf`@3o]/40okK10P0000020?nf`@050000003o]/40okK1
0?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/402@3o
]/4200000080okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@P000000`3o]/42000000<0okK1
0P0000020?nf`@<000004@3o]/4400000080okK10P0000030?nf`@040000003o]/40okK100000080
okK100@000000?nf`@3o]/4000000oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo
01Oooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool08OoooolJ0?nf`@03
o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/405@3o]/4:o`00o``0okK10_l00?l:0?nf`@;o
003o2@3o]/4Tooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06Oooool00`00003o
ooooooooo`04ooooo`050000003o]/40okK10?nf`@0000000`3o]/401Ol00000okK10?nf`@3o]/7o
000000<0okK100?o00000?nf`@3o]/400P0000040?nf`@030000003o]/40okK100L0okK10P000003
0?nf`@030000003o]/40okK1008000000P3o]/400`00003o0000000000080?nf`@03o`00003o]/40
okK10080okK10P0000030?nf`@8000000`3o]/4400000140okK10P0000020?nf`@05o`0000000000
00000?nf`@0000000P3o]/401`000000okK10?nf`Ol00000okK1ooooo`0000000oooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool08OoooolK0?nf`@?o003o203o]/42o`00obd0okK100?o003o0?nf`@3o]/40
303o]/42o`00o`P0okK18oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Wooooo
00<00000ooooooooool01?ooool01@000000okK10?nf`@3o]/40000000<0okK100@000000?nf`@3o
]/4000000`3o]/4010000000okK10?nf`@0000060?nf`@030000003o]/40okK100D0okK10P000004
0?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/402P3o]/42000000@0okK100<0
00000?nf`@3o]/400P3o]/42000000D0okK100?o00000000003o]/40403o]/42000000<0okK10P00
00020?nf`@070000003o]/40okK10?nf`@000000okK100000003ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool05_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Poooooal0okK12?l00?l^0?nf`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o]/40
1P3o]/4Sooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06?ooool00`00003ooooo
ooooo`04ooooo`050000003o]/40okK10?nf`@0000000`3o]/4010000000okK10?nf`@0000030?nf
`@040000003o]/40okK1000000P0okK100<000000?nf`@3o]/40100000040?nf`@8000000P3o]/40
1@000000okK10?nf`@3o]/40000000@0okK11`0000040?nf`@8000000`3o]/42000000@0okK100<0
00000?nf`@3o]/40103o]/400`000000okK10?nf`@070?nf`@D00000103o]/4010000000okK10?nf
`@3o]/4200000080okK100L000000?nf`@3o]/4000000?nf`Oooool0000000?ooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo023oooooE03o]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100H0
okK18_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo00<00000oooooooo
ool00oooool01@00003ooooo0?nf`@3o]/40000000<0okK100@000000?nf`@3o]/4000000`3o]/40
10000000okK10?nf`@00000:0?nf`@8000001P3o]/42000000<0okK100D000000?nf`@3o]/40okK1
000000030?nf`@03o`0000000000okK100H0okK10P0000040?nf`@8000000`3o]/42000000<0okK1
0P0000050?nf`@030000003o]/40okK100@0okK100?o00000000003o]/40103o]/42000000<0okK1
00T000000?nf`@3o]/4000000?nf`@00003o00000?nf`@0000000P3o]/400`000000okK100000003
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool05Oooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Oooooo`d0okK12@000?ln0?nf`@03o`00o`3o]/40okK1
0180okK100?o003o0?nf`@3o]/401P3o]/4Qooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool05oooool00ol0003oooooooooo`03ooooo`0500000?ooool0okK10?nf`Ol000000`3o]/40
1?l00000okK10?nf`Ol000020?nf`@0600000?l00000okK10?nf`@00003o0000403o]/4200000080
okK10P0000000ol00000okK10?nf`@0200000080okK100<00000o`00003o]/402P3o]/43000000<0
okK100?o00000000000000000P3o]/42000000<0okK10P0000030?nf`@03o`00003o]/40okK100<0
okK100?o00000?nf`@3o]/401`3o]/4200000080okK100H000000?nf`@3o]/4000000?nf`@000002
0?nf`@030000003o]/4000000080okK100@00000ooooooooool000001Oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01kooooo303o]/42
0000o`T0okK10P000?ll0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/401@3o]/4Q
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05oooool00`00003oooooooooo`03
ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@050000
003o]/40okK10?nf`@0000004@3o]/401@000000okK10?nf`@3o]/40000000<0okK10P0000020?nf
`@800000403o]/43000000<0okK10P0000020?nf`@030000003o]/40okK10080okK100@000000?nf
`@3o]/4000001@3o]/400`000000okK10?nf`@090?nf`@080000003o]/40okK10000003o]/400000
0?nf`@0000020?nf`@030000003o]/4000000080okK100@00000ooooooooool000001Oooool00`00
003oooooooooo`0Eooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01ko
oooo2`3o]/400ol00?l0okK10?nf`@0;0?nf`@030000o`3o]/40okK103T0okK100?o003o0?nf`@3o
]/404`3o]/400ol00?l0okK10?nf`@060?nf`B3ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0Fooooo`0300000?oooooooooo00?ooooo00D00000ooooo`3o]/40okK1000000020?nf
`@040000003o]/40okK100000080okK100<000000?nf`@3o]/400P0000040?nf`@D00000203o]/40
1Ol00000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK1000000060?nf`@P00000
1`3o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK1008000000P3o]/401@000000okK1
0?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400`3o]/400ol000000000000000050?nf`@08
0000003o]/40okK1o`00003o]/4000000?nf`@0000020?nf`@03o`00003o]/4000000080okK100@0
0000ooooooooool000001Oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo01gooooo2`3o]/400`000?l0okK10?nf`@0=0?nf`@030000o`3o
]/40okK103L0okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@050?nf`B3ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00;ooooo00D0
0000ooooo`3o]/40okK1000000020?nf`@040000003o]/40okK1o`000080okK100Co00000?nf`@3o
]/4000000`3o]/400`00003o0000000000050?nf`@8000001@3o]/401@000000okK10?nf`@3o]/40
000000<0okK100D000000?nf`@3o]/40okK1000000040?nf`@;o000000<000000?nf`@3o]/401P3o
]/400`00003o000000000002000000<0okK10P0000030?nf`@050000003o]/40okK10?nf`@000000
0P3o]/401@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/400P3o]/401_l00000
okK10?nf`@3o]/7o0000000000@0okK100D000000?nf`@000000okK1000000020?nf`@050000003o
]/4000000?nf`@0000000P3o]/401000003oooooooooo`000005ooooo`0300000?oooooooooo01Co
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07Oooool:0?nf`@030000
o`3o]/40okK100l0okK100<0003o0?nf`@3o]/40603o]/470?oooaL0okK100?o003o0?nf`@3o]/40
5@3o]/400ol00?l0okK10?nf`@050?nf`B3ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0Fooooo`0300000?oooooooooo00;ooooo00Go0000ooooo`3o]/40okK1o`0000020?nf`@04
0000003o]/40okK100000080okK100<000000?nf`@0000000`3o]/400`000000okK10?nf`@070?nf
`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40
okK10?nf`Ol00000103o]/400`000000okK10?nf`@030?nf`@L0oooo103o]/400`000000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@04
0000003o]/40okK1000000@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf
`@050000003o]/4000000?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK100@0
0000ooooooooool000001Oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo01gooooo2@3o]/400`000?l0okK10?nf`@0A0?nf`@030000o`3o
]/40okK101<0okK13`3ooolC0?nf`@03o`00o`3o]/40okK100P0okK10ol0000:0?nf`@03o`00o`3o
]/40okK100H0okK17oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo00<0
0000ooooooooool00_ooool01@00003ooooo0?nf`@3o]/4000000080okK100<000000?nf`@000000
0P3o]/400`000000okK1000000030?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
0P3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1000000030?nf
`@8000000P3o]/4?0?ooo`030?nf`@000000okK100<0okK100D000000?nf`@3o]/40okK100000002
0?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/400000103o]/400`000000okK1
0?nf`@030?nf`@070000003o]/40okK10?nf`@000000okK1000000020?nf`@070000003o]/400000
0?nf`@000000okK1000000020?nf`@0400000?oooooooooo000000Gooooo00<00000ooooooooool0
5?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Looooo`T0okK100<0
003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0@0?nf`A<0oooo403o]/400ol00?l0okK10?nf
`@080?nf`@Go00002P3o]/400ol00?l0okK10?nf`@050?nf`Aoooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00;ooooo00D00000ooooo`3o]/40okK1
000000020?nf`@060000003o]/40okK10000003o]/4000000P3o]/4010000000okK10?nf`@00000;
0?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf
`@3o]/40000000<0okK100<000000?nf`@3o]/40103oool8000000L0oooo00<000000?nf`@3o]/40
0P3o]/401?l00000okK10?nf`@0000030?nf`@030000003o]/40000000<0okK100<000000?nf`@00
00000`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK100T000000?nf`@00
0000okK1o`00003o]/4000000?nf`@0000000P3o]/400`000000okK100000003ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool05?ooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0Looooo`T0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0>
0?nf`AL0oooo3P3o]/400ol00?l0okK10?nf`@080?nf`@Go00002P3o]/400ol00?l0okK10?nf`@05
0?nf`Aoooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Eooooo`0300000?oooooo
oooo00;ooooo00D00000ooooo`3o]/40okK1000000020?nf`@030000003o]/4000000080okK100?o
00000?nf`@0000000P3o]/400`000000okK10?nf`@0:0?nf`@050000003o]/40okK10?nf`@000000
0P3o]/401?l00000okK10?nf`@0000030?nf`@060000003o]/40okK1o`0000000000okK10`3oool0
0`00003o0000000000080?ooo`<000001@3oool2000000<0okK100@000000?nf`@3o]/4000000P3o
]/401?l00000okK10?nf`@0000020?nf`@030000003o]/40000000<0okK100<000000?nf`@3o]/40
1@3o]/403@000000okK10?nf`@3o]/4000000?nf`@000000okK10000003o]/4000000?nf`@000000
0P3o]/400`000000okK100000003ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool0
5?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Looooo`P0okK100<0
003o0?nf`@3o]/405@3o]/400`000?l0okK10?nf`@0<0?nf`AX0oooo303o]/400ol00?l0okK10?nf
`@080?nf`@Go00002P3o]/400ol00?l0okK10?nf`@060?nf`Akooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00;ooooo00D00000ooooo`3o]/40okK1
000000020?nf`@030000003o]/4000000080okK100<000000?nf`@0000000P3o]/4010000000okK1
0?nf`@3o]/44000000D0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1
000000<0okK100D000000?nf`@3o]/4000000?nf`@030?ooo`030000003oool0oooo00`0oooo0P00
00050?ooo`040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/401_l00000
okK10?nf`@000000okK1000000<0okK100<000000?nf`@3o]/401@3o]/403@000000okK10?nf`@3o
]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o]/4010000000okK10000003o
]/42ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool05?ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Kooooo`T0okK100<0003o0?nf`@3o]/405@3o]/40
0`000?l0okK10?nf`@0;0?nf`A`0oooo303o]/400ol00?l0okK10?nf`@080?nf`@?o00002P3o]/40
0ol00?l0okK10?nf`@070?nf`Akooooo00<00000ooooooooool03oooool00`00003oooooooooo`0D
ooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/400`000000okK10000
00020?nf`@030000003o]/4000000080okK100D000000?nf`@3o]/40okK1000000040?nf`@030000
0?l00000okK100<0okK100<000000?nf`@0000000`3o]/400`000000okK1000000030?nf`@050000
003o]/40okK10000003o]/400`3oool00`000000oooo0?ooo`0?0?ooo`800000103oool010000000
okK10?nf`@0000020?nf`@060000003o]/40okK10000003o]/4000000`3o]/400`000000okK10000
00030?nf`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000020?nf`@090000
003o]/7o00000?nf`@000000okK10000003o]/4000000080okK100@000000?nf`Oooool000001Ooo
ool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo01_ooooo203o]/400`000?l0okK10?nf`@090?nf`@?o00002P3o]/400`000?l0okK10?nf`@0:
0?nf`Ah0oooo2`3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK100L0okK17_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool00oooool0
10000000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/400`000000okK1
000000030?nf`@030000003o]/40okK100D0okK100L000000?nf`@3o]/40okK10000003o]/400000
0080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@000000okK100<0oooo00?o
00000?ooo`3oool04P3oool00ol00000oooo0?ooo`020?ooo`070000003o]/40okK1o`0000000000
okK1o`0000020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/420000
00<0okK100D000000?nf`@3o]/40okK1000000020?nf`@090000003o]/4000000?nf`@000000okK1
0000003o]/4000000080okK100@000000?nf`Oooool000001Oooool00`00003oooooooooo`0Doooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01_ooooo203o]/400`000?l0
okK10?nf`@080?nf`@Go00002@3o]/400`000?l0okK10?nf`@090?nf`B00oooo2P3o]/400ol00?l0
okK10?nf`@0E0?nf`@03o`00o`3o]/40okK100L0okK17_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo01Cooooo00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf
`@050000003o]/4000000?nf`@0000000P3o]/400`000000okK1o`0000030?nf`@03o`00003o]/40
okK100D0okK100L000000?nf`@3o]/40okK10000003o]/4000000080okK100@000000?nf`@3o]/40
00000P3o]/4010000000okK10?nf`@0000040?ooo`030000003oool0oooo01<0oooo00H000000?oo
o`3oool0oooo0000003oool20?nf`@080000003o]/40okK10000003o]/4000000?nf`@0000020?nf
`@040000003o]/40okK1000000D0okK100<000000?nf`@000000103o]/4030000000okK10?nf`@00
0000okK10000003o]/4000000?nf`@000000okK100000080okK100@000000?nf`Oooool000001Ooo
ool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo01_ooooo203o]/400`000?l0okK10?nf`@080?nf`@Go00002@3o]/400`000?l0okK10?nf`@09
0?nf`B00oooo2P3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK100L0okK17_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool00oooool0
10000000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/400`000000okK1
000000030?nf`@030000003o]/40okK100D0okK100L000000?nf`@3o]/40okK10000003o]/400000
0080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o]/40oooo0080oooo00<0
00000?ooo`3oool01@3oool7000000P0oooo00<000000?ooo`3oool00P3oool010000000okK10?nf
`@0000020?nf`@060000003o]/40okK10000003o]/4000000P3o]/4010000000okK1000000000005
0?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/4000000P3o]/401`000000okK10000
003o]/4000000?nf`@0000000P3o]/4010000000okK1ooooo`000005ooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool06oooool80?nf`@03
0000o`3o]/40okK100P0okK11Ol000090?nf`@030000o`3o]/40okK100L0okK18`3oool:0?nf`@03
o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40203o]/4Nooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool05?ooool00`00003oooooooooo`02ooooo`0700000?ooool0okK10?nf
`@000000okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/4010000000okK10?nf
`@0000080?nf`@040000003o]/40okK100000080okK100<000000?nf`@0000000P3o]/4010000000
okK10?nf`@0000020?nf`@050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`05
0?ooo`0300000?l00000oooo00H0oooo00H000000?ooo`3oool0oooo0000003oool20?nf`@080000
003o]/40okK10000003o]/4000000?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000002@3o
]/4020000000okK10?nf`Ol00000okK10000003o]/4000000P3o]/401Ol00000okK10000003o]/40
00000080okK100?ooooo00000?ooool00oooool00`00003oooooooooo`0Eooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo01_ooooo2@3o]/400`000?l0okK10?nf`@080?nf
`@?o00002P3o]/400`000?l0okK10?nf`@060?nf`BD0oooo2@3o]/400ol00?l0okK10?nf`@0C0?nf
`@03o`00o`3o]/40okK100T0okK17Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool00_ooool01`00003ooooo0?nf`@3o]/4000000?nf`@0000000P3o
]/401@000000okK10000003o]/4000000080okK100@000000?nf`@3o]/400000203o]/4010000000
okK10?nf`@0000020?nf`@030000003o]/4000000080okK100<000000?nf`@0000000P3o]/401Ol0
0000oooo0?ooo`3oool0000000H0oooo00?o00000000003oool02@3oool00`000000oooo0?ooo`05
0?ooo`080000003oool0oooo0?ooo`000000oooo0?nf`@0000020?nf`@060000003o]/40okK1o`00
003o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000D0okK10P0000001?l00000okK10?nf
`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/400`000000okK1000000030?nf`@03
00000?oooooooooo00;ooooo00<00000ooooooooool05Oooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Jooooo`X0okK100<0003o0?nf`@3o]/405@3o]/400ol00?l0okK1
0?nf`@060?nf`BD0oooo2P3o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100X0okK1
7Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool0
0_ooool01`000000okK10?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10000003o]/40
00000080okK100@000000?nf`@3o]/400000203o]/4010000000okK10?nf`@0000020?nf`@030000
003o]/4000000080okK100<000000?nf`@0000000P3o]/401@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`080000003oool0oooo0?oo
o`000000oooo0?nf`@0000020?nf`@040000003o]/40okK100000080okK100Go00000?nf`@3o]/7o
0000000000020?nf`@03o`0000000000000000800000103o]/402@000000okK10?nf`@3o]/400000
0?nf`@000000okK1000000020?nf`@030000003o]/40000000<0okK100<00000ooooooooool00_oo
ool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo01[ooooo2P3o]/400`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK100D0okK19`3oool:
0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/402`3o]/4Mooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool05?ooool00`00003oooooooooo`03ooooo`040000003o]/40
okK100000080okK100<000000?nf`@0000000P3o]/401@000000okK10000003o]/40000000<0okK1
00<000000?nf`@3o]/40103o]/401ol00000okK10?nf`@3o]/4000000?nf`@0000000P3o]/401@00
0000okK10000003o]/4000000080okK100D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0103oool020000000oooo0?ooo`3ooooo00000?ooo`3o
]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000002@3o
]/402@000000okK10?nf`@3o]/4000000?nf`Ol00000okK1000000020?nf`@030000003o]/400000
00<0okK100<00000ooooooooool00_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01[ooooo2P3o]/400`000?l0okK10?nf`@0E0?nf`@03
0000o`3o]/40okK100D0okK19`3oool;0?nf`@03o`00o`3o]/40okK100`0okK10_l00?l>0?nf`Ago
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00?o
oooo00@000000?nf`@3o]/4000000P3o]/400`000000okK1000000020?nf`@050000003o]/400000
0?nf`@000000103o]/401?l00000okK10?nf`@3o]/42000000<0okK100@00000o`00003o]/400000
0P3o]/401@000000okK10000003o]/4000000080okK100D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
00000080okK100@000000?nf`@3o]/7o00000P3o]/4010000000okK10?nf`@0000030?nf`@030000
003o]/40okK100<0okK10P0000001ol00000okK10?nf`@00003o00000?nf`@0000000P3o]/400`00
0000okK1000000020?nf`@05o`00003o]/40okK10?nf`Ol000001?ooool00`00003oooooooooo`0F
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01[ooooo2P3o]/400`00
0?l0okK10?nf`@0D0?nf`@030000o`3o]/40okK100D0okK1:@3oool;0?nf`@03o`00o`3o]/40okK1
00P0okK10ol00?l@0?nf`Agooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Doooo
o`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/400`000000okK1o`000002
0?nf`@050000003o]/4000000?nf`@0000001@3o]/400`000000okK1000000050?nf`@040000003o
]/40okK100000080okK100P000000?nf`@000000okK10000003o]/40oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00P00000
0?ooo`3oool0oooo0000003oool0okK100000080okK100@000000?nf`@3o]/4000000P3o]/400`00
0000okK10?nf`@020?nf`@03o`0000000000000000800000103o]/401@000000okK10?nf`@3o]/40
00000080okK100<000000?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000Cooooo00<0
0000ooooooooool05_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0J
ooooo`/0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@050?nf`BT0oooo303o]/44
o`00o`<0okK10ol00?lC0?nf`Agooooo00<00000ooooooooool03oooool00`00003oooooooooo`0D
ooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/400`000000okK10000
00020?nf`@030000003o]/4000000080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@040?nf`@040000003o]/40okK100000080okK100P000000?nf`@000000okK10000003o]/40oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00P000000?ooo`3oool0oooo0000003oool0okK100000080okK100D000000?nf`@3o
]/40okK1000000020?nf`@030000003o]/40okK100T0okK100D000000?nf`@3o]/40okK100000002
0?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK100000004ooooo`030000
0?oooooooooo01Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool06_oo
ool<0?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/401P3o]/4Y0?oooa00okK10ol0
0?lF0?nf`Agooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Eooooo`0300000?oo
oooooooo00;ooooo00L000000?nf`@3o]/40okK10000003o]/4000000080okK100<000000?nf`@00
00000P3o]/400`000000okK10000000<0?nf`@030000003o]/4000000080okK100T000000?nf`@3o
]/4000000?nf`@000000okK10?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080okK1
00@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000T0okK100?o00000?nf
`@3o]/400P3o]/400`000000okK1o`0000030?nf`@030000003o]/40000000<0okK100<000000?nf
`Oooool00oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo01[ooooo3@3o]/400`000?l0okK10?nf`@0?0?nf`@030000o`3o]/40okK100L0
okK1:@3ooolY0?nf`Agooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Eooooo`03
00000?oooooooooo00;ooooo00L000000?nf`@3o]/40okK10000003o]/4000000080okK100<00000
0?nf`@0000000P3o]/4010000000okK10?nf`@00000;0?nf`@030000003o]/4000000080okK100<0
00000?nf`@0000000P3o]/4010000000okK10?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3o]/4010000000okK10?nf`@0000030?nf`@040000003o]/40okK10?nf`@8000001@3o]/42
000000<0okK100D00000o`00003o]/40okK1000000020?nf`@040000003o]/40okK1000000<0okK1
00<000000?nf`Oooool00oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo01[ooooo3P3o]/400`000?l0okK10?nf`@0=0?nf`@030000o`3o
]/40okK100L0okK1:`3ooolX0?nf`Agooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo00;ooooo00L000000?nf`@3o]/40okK10000003o]/4000000080
okK100H000000?nf`@3o]/7o00000?nf`@0000020?nf`@030000003o]/40okK100T0okK100<00000
0?nf`@0000000P3o]/400`000000okK1000000020?nf`@040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00P0
00000?ooo`3oool0oooo0000003oool0okK100000080okK100D000000?nf`@3o]/40okK100000005
0?nf`@D000001@3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/400000
0`3o]/400`000000okK1ooooo`03ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool06_ooool?0?nf`@@0003o203o]/430000o`X0okK1:`3o
oolX0?nf`Agooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Eooooo`0300000?oo
oooooooo00;ooooo00L000000?nf`@3o]/40okK10000003o]/4000000080okK100H000000?nf`@3o
]/4000000?nf`@0000030?nf`@030000003o]/40okK100L0okK100@000000?nf`@3o]/4000000P3o
]/400`000000okK1000000020?nf`@040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00P000000?ooo`3oool0
oooo0000003oool0okK100000080okK100D000000?nf`@3o]/40okK10000000>0?nf`@050000003o
]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000<0okK100<000000?nf`Ooo
ool00oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo01Wooooo503o]/480000o`d0okK1:`3ooolX0?nf`Agooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`0Eooooo`0400000?ooooooooooooooo`80okK100@000000?nf`@3o
]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40000000<0okK100<00000
0?nf`@3o]/401P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/4000000080okK100@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool01P000000oooo0?ooo`3oool000000?ooo`80okK100@000000?nf
`@3o]/4000000`3o]/400`000000okK10?nf`@0;0?nf`@050000003o]/40okK10?nf`@0000000P3o
]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK100?ooooo00<00000ooooooooool0
5oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0IooooobT0okK1:`3o
oolX0?nf`Agooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Eooooo`0400000?oo
ooooooooooooo`80okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf
`@030000003o]/40000000<0okK100?o00000?nf`@3o]/401@3o]/401@000000okK10?nf`@3o]/40
00000080okK100<000000?nf`@0000000P3o]/4010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`060000003o
ool0oooo0?ooo`000000oooo0P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK1
00X0okK100D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000000`3o
]/400`000000okK10?nf`@03ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool06OoooolY0?nf`B/0oooo:03o]/4Mooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool05Oooool01000003oooooooooooooool20?nf`@070000003o
]/40okK10?nf`Ol00000okK1000000020?nf`@060000003o]/40okK10000003o]/4000000`3o]/40
0`000000okK10?nf`@050?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10000
00020?nf`@040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool0oooo0000003oool20?nf
`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o
]/4000000080okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK100?ooooo
00<00000ooooooooool05oooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`0IooooobT0okK1:`3ooolX0?nf`Agooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0Fooooo`0300000?oooooooooo0080okK100D000000?nf`@3o]/40okK1000000020?nf`@060000
003o]/40okK10000003o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000H0okK100D00000
0?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool000000080oooo00<0okK10000003o]/400P3o]/401@00
0000okK10?nf`@3o]/40000000/0okK100Go00000?nf`@3o]/40okK1000000030?nf`@040000003o
]/40okK1000000<0okK100@000000?nf`@3o]/40okK10oooool00`00003oooooooooo`0Gooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01[ooooo:03o]/4[0?ooobP0okK1
7Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo00H00000oooooooooooo
oooo0?nf`Ol000030?nf`@040000003o]/40okK100000080okK100<000000?nf`@0000000P3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK10000
00020?nf`@040000003o]/40okK1o`000080okK100@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00?o00000?ooo`3oool0103oool01Ol00000
oooo0?ooo`3oool000000080oooo00<0okK10000003o]/400P3o]/401@000000okK10?nf`@3o]/40
000000/0okK100D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1000000<0okK1
00@000000?nf`@3o]/40okK10oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo01[ooooo:03o]/4[0?ooobP0okK17Oooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo01Kooooo00H00000oooooooooooooooo0?nf`@0000030?nf
`@040000003o]/40okK100000080okK100<000000?nf`@0000000P3o]/400`000000okK10?nf`@02
0?nf`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o
]/40okK100000080okK100@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0080oooo00<0okK10000003o]/400P3o]/401@000000okK10?nf`@3o]/40000000/0okK100D00000
0?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1000000<0okK100@000000?nf`@3o]/40
okK10oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo01[ooooo:@3o]/4Y0?ooobT0okK17Oooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo01Kooooo00H00000oooooooooooooooo0?nf`@0000030?nf`@040000003o]/40okK1
00000080okK100<000000?nf`@0000000P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100@0okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030?nf`@000000okK1
0080okK100D000000?nf`@3o]/40okK10000000=0?nf`@040000003o]/40okK1000000<0okK100@0
00000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@3o]/43ooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool06_oooolF0?nf`@T0003o
2P3o]/4Y0?ooobT0okK17Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo
00@00000oooooooooooooooo0P3o]/4010000000okK10?nf`@0000020?nf`@060000003o]/40okK1
0000003o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000L0okK100D000000?nf`@3o]/40
okK1000000020?nf`@060000003o]/40okK10000003o]/4000000`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3ooooo00000080oooo00D0okK1o`00003o]/40okK1o`0000030?nf`@030000003o]/40okK100<0
okK1100000050?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40
000000<0okK100<000000?nf`@3o]/400oooool00`00003oooooooooo`0Gooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo01[ooooo4`3o]/430000o`T0okK10P000?l80?nf
`BT0oooo:@3o]/4Mooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05_ooool01000
003oooooooooooooool20?nf`@040000003o]/40okK100000080okK100H000000?nf`@3o]/400000
0?nf`@0000020?nf`@050000003o]/40okK10?nf`@000000203o]/401?l00000okK10?nf`Ol00002
0?nf`@040000003o]/40okK100000080okK100@000000?ooo`3ooooo00000`3oool00`000000oooo
0?ooo`040?ooo`03o`0000000000oooo00P0oooo0P0000060?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3o]/401@000000okK10?nf`@3o]/7o000000<0okK10`0000040?nf
`@800000103o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000000`3o
]/400`000000okK10?nf`@03ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool06_oooolA0?nf`@80003o3P3o]/400`000?l0okK10?nf`@05
0?nf`BT0oooo:@3o]/4Mooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05_ooool0
1000003oooooooooooooool20?nf`@040000003o]/40okK100000080okK100H000000?nf`@3o]/40
00000?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000002@3o]/401P000000okK10?nf`@00
0000okK100000080okK100@000000?nf`@3o]/4000000P3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool00`3oool3000000P0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/401`3o
]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/401@000000
okK10?nf`@3o]/4000000080okK10oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01[ooooo403o]/400`000?l0okK10?nf`@0?0?nf`@03
0000o`3o]/40okK100D0okK19`3oool;0?nf`@X0003o5@3o]/4Mooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool05_ooool01000003oooooooooooooool20?nf`@040000003o]/40okK1
00000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@040000003o]/40okK1000000X0
okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01P3oool5000000X0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o
]/402@3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/40
1P000000okK10?nf`@3o]/4000000?nf`@Cooooo00<00000ooooooooool05_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Jooooo`l0okK100?o003o0?nf`@3o]/40403o
]/400`000?l0okK10?nf`@050?nf`BL0oooo203o]/430000o`X0okK10P000?lC0?nf`Agooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0Fooooo`0400000?ooooooooooooooo`80okK1
00@000000?nf`@3o]/4000000P3o]/401P000000okK10?nf`@000000okK100000080okK100@00000
0?nf`@3o]/4000002`3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/4000000080okK1
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3ooooo00000P3o]/401?l00000okK10?nf`@0000020?nf`@03o`0000000000
okK10080okK11@0000000ol00000okK10?nf`@020?nf`@05o`0000000000okK10?nf`@0000000P3o
]/401?l00000okK10?nf`@0000020?nf`@060000003o]/40okK10?nf`@000000okK11?ooool00`00
003oooooooooo`0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01[o
oooo3`3o]/400`000?l0okK10?nf`@0A0?nf`@030000o`3o]/40okK100D0okK19@3oool90?nf`@03
0000o`3o]/40okK100`0okK100<0003o0?nf`@3o]/40403o]/4Mooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool05_ooool01000003oooooooooooooool20?nf`@040000003o]/40okK1
00000080okK100P000000?nf`@3o]/4000000?nf`@000000okK1o`0000<0okK100<000000?nf`@3o
]/400P3o]/43000000@0okK100@000000?nf`@3o]/4000000P3o]/400`000000okK1000000020?nf
`@040000003oool0oooo000000@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0okK100H000000?nf`@3o]/4000000?nf`@0000030?nf`@800000
1P3o]/42000000<0okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf
`@060000003o]/40okK10?nf`@000000okK11?ooool00`00003oooooooooo`0Fooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo01_ooooo3@3o]/400`000?l0okK10?nf`@0C
0?nf`@030000o`3o]/40okK100H0okK18`3oool80?nf`@030000o`3o]/40okK100h0okK100<0003o
0?nf`@3o]/403`3o]/4Mooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05_ooool0
0`00003oooooooooo`02ooooo`050?nf`@000000okK10?nf`@0000000P3o]/4020000000okK10?nf
`@000000okK10000003o]/4000000`3o]/400`000000okK10?nf`@02000000<0okK100<000000?nf
`@3o]/400P3o]/401P000000okK10?nf`@000000okK100000080okK100L000000?nf`@3o]/400000
0?nf`@3oool0000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0okK100D000000?nf`@000000okK1000000030?nf`@030000003o]/40
okK100P0okK10P0000020?nf`@060000003o]/40okK10000003o]/4000000`3o]/400`000000okK1
000000030?nf`@030000003o]/7ooooo00?ooooo00<00000ooooooooool05_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Kooooo`d0okK100<0003o0?nf`@3o]/404`3o
]/400`000?l0okK10?nf`@060?nf`B80oooo203o]/400`000?l0okK10?nf`@0@0?nf`@030000o`3o
]/40okK100d0okK17_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo00<0
0000ooooooooool00_ooool01@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@000000
0P3o]/400`000000okK1000000020?nf`@050000003o]/40okK10?nf`@0000001@3o]/401@000000
okK10?nf`@3o]/4000000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@040000003o
]/40oooo000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0okK100D000000?nf`@000000okK1000000030?nf`@030000003o]/40okK1
0080okK11@0000040?nf`@03o`00003o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/40
1?l00000okK10?nf`@0000030?nf`@0300000?oooooooooo00;ooooo00<00000ooooooooool05_oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Kooooo``0okK100<0003o
0?nf`@3o]/405@3o]/400`000?l0okK10?nf`@060?nf`B00oooo203o]/400`000?l0okK10?nf`@0B
0?nf`@03o`00o`3o]/40okK100`0okK17_ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01Kooooo00<00000ooooooooool00_ooool01@000000okK10?nf`@3o]/4000000080okK100<0
00000?nf`@0000000P3o]/400`000000okK1000000020?nf`@050000003o]/40okK10?nf`@000000
1P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100<000000?nf`@0000000P3o]/401`000000
okK10?nf`@000000okK10?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`800000103oool0
1@000000oooo0?ooo`3oool000000080okK100<000000?nf`@0000000P3o]/401?l00000okK10?nf
`Ol000030?nf`@8000001@3o]/4200000080okK100T000000?nf`@3o]/7o00000000003o]/400000
0?nf`@0000000P3o]/4010000000okK10?nf`Ol000030?nf`@0300000?oooooooooo00;ooooo00<0
0000ooooooooool05_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0K
ooooo``0okK100<0003o0?nf`@3o]/405@3o]/400`000?l0okK10?nf`@070?nf`Ah0oooo203o]/40
0ol00?l0okK10?nf`@0D0?nf`@030000o`3o]/40okK100/0okK17_ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool00_ooool01@000000okK10?nf`@3o
]/4000000080okK100<000000?nf`@0000000P3o]/400`000000okK1000000020?nf`@050000003o
]/40okK10?nf`@0000001`3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/4000000080
okK100@000000?nf`@3o]/4000000P3o]/400`3oool000000?ooo`040?ooo`03o`00000000000000
00T0oooo0P0000060?ooo`050000003oool0oooo0?nf`@0000000P3o]/400`000000okK1o`000002
0?nf`@040000003o]/40okK100000080okK100<000000?nf`@3o]/401`3o]/400`000000okK10000
00030?nf`@050000003o]/4000000?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@03
00000?oooooooooo00;ooooo00<00000ooooooooool05_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Kooooo``0okK100<0003o0?nf`@3o]/405P3o]/400`000?l0okK1
0?nf`@070?nf`A`0oooo2@3o]/400`000?l0okK10?nf`@0D0?nf`@030000o`3o]/40okK100/0okK1
7_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool0
0_ooool01@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@0000000P3o]/401@000000
okK10000003o]/40000000<0okK100<000000?nf`@3o]/401P3o]/4010000000okK10?nf`@000003
0?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/400`3oool000000?oo
o`060?ooo`@000000P3oool3000000L0oooo00D000000?ooo`3oool0okK1000000020?nf`@060000
003o]/40okK10000003o]/4000000P3o]/4010000000okK10?nf`@0000040?nf`@?o0000103o]/40
0`000000okK1000000030?nf`@050000003o]/4000000?nf`@0000000P3o]/400`000000okK10000
00030?nf`@0300000?oooooooooo00?ooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Looooo`X0okK100<0003o0?nf`@3o]/402@3o]/43
o`0000/0okK100<0003o0?nf`@3o]/40203o]/4I0?ooo`X0okK100<0003o0?nf`@3o]/405P3o]/40
0`000?l0okK10?nf`@0:0?nf`Akooooo00<00000ooooooooool03oooool00`00003oooooooooo`0F
ooooo`0300000?oooooooooo00;ooooo00D000000?nf`@3o]/40okK1000000020?nf`@030000003o
]/4000000080okK100D000000?nf`@000000okK1000000030?nf`@030000003o]/40okK100H0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@03o`00003o]/4000000080okK100@000000?nf`@3o
]/4000000`3o]/400`3oool000000?ooo`090?ooo`8000002@3oool01@000000oooo0?nf`@3o]/7o
00000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@040000003o]/7o000000000080
okK10ol000030?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@0000000P3o]/401@000000
okK10000003o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/400`00003oooooooooo`03
ooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool07?ooool:0?nf`@030000o`3o]/40okK100P0okK11Ol0000:0?nf`@030000o`3o]/40okK1
00X0okK15@3oool;0?nf`@030000o`3o]/40okK101P0okK100<0003o0?nf`@3o]/40203o]/4Ooooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool05_ooool00`00003oooooooooo`02oooo
o`050000003o]/40okK10?nf`@0000000P3o]/400`000000okK1000000020?nf`@050000003o]/40
00000?nf`@0000000`3o]/400`000000okK10?nf`@060?nf`@050000003o]/40okK10?nf`@000000
0P3o]/400`000000okK1000000020?nf`@040000003o]/40okK1000000D0okK100?o000000000000
00004@3oool00`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100D000000?nf
`@000000okK1o`0000020?nf`@050000003o]/40okK10?nf`Ol000001P3o]/401ol00000okK10?nf
`@3o]/4000000?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK100L000000?nf
`@3o]/4000000?nf`Oooool0000000Gooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Looooo`X0okK100<0003o0?nf`@3o]/40203o]/45
o`0000X0okK100<0003o0?nf`@3o]/40303o]/4A0?ooo`d0okK100<0003o0?nf`@3o]/40603o]/40
0`000?l0okK10?nf`@080?nf`Aoooooo00<00000ooooooooool03oooool00`00003oooooooooo`0F
ooooo`0300000?oooooooooo00;ooooo00D000000?nf`@3o]/40okK1000000020?nf`@030000003o
]/4000000080okK100D000000?nf`@000000okK1000000030?nf`@030000003o]/40okK100H0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40000000<0okK100@000000?nf`@3o
]/4000001P3o]/40103oool0000000000000000=0?ooo`030000003o]/40okK100<0okK100@00000
0?nf`@3o]/4000000P3o]/401@000000okK10000003o]/4000000080okK100@000000?nf`@3o]/7o
00001`3o]/401ol00000okK10?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10000003o
]/4000000080okK100L000000?nf`@3o]/4000000?nf`Oooool0000000Gooooo00<00000oooooooo
ool05Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Mooooo`T0okK1
00<0003o0?nf`@3o]/40203o]/45o`0000X0okK100<0003o0?nf`@3o]/403P3o]/4=0?ooo`l0okK1
00<0003o0?nf`@3o]/40603o]/400`000?l0okK10?nf`@080?nf`Aoooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/40
00000P3o]/4020000000okK10?nf`@000000okK10000003o]/4000000P3o]/401@000000okK10?nf
`@3o]/40000000L0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK10000
0080okK100@000000?nf`@3o]/40okK10P0000060?nf`@80oooo100000070?ooo`8000001@3o]/40
10000000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/401@000000okK1
0?nf`@3o]/7o000000P0okK100Wo00000?nf`@3o]/40okK10000003o]/4000000?nf`@0000000P3o
]/401@000000okK10000003o]/4000000080okK100D000000?nf`Ooooooooooo00000004ooooo`03
00000?oooooooooo01Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
7Oooool:0?nf`@030000o`3o]/40okK100P0okK10ol0000;0?nf`@030000o`3o]/40okK10180okK1
1@3ooolC0?nf`@030000o`3o]/40okK100T0okK10ol0000<0?nf`@030000o`3o]/40okK100L0okK1
8?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool0
0oooool010000000okK10?nf`@0000020?nf`@080000003o]/40okK10000003o]/4000000?nf`@00
00020?nf`@040000003o]/40okK10?nf`@8000001@3o]/42000000<0okK100@000000?nf`@3o]/40
00000P3o]/401@000000okK10?nf`@3o]/40000000@0okK10P0000080?nf`@80oooo1`0000060?nf
`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK100@0
00000?nf`@3o]/7o00002P3o]/402?l00000okK10?nf`@000000okK10000003o]/4000000P3o]/40
1@000000okK10000003o]/4000000080okK100D00000oooooooooooooooo00000004ooooo`030000
0?oooooooooo01Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07Ooo
ool:0?nf`@030000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/40:P3o]/400`000?l0okK10?nf
`@080?nf`@Go00002`3o]/400`000?l0okK10?nf`@070?nf`B3ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/400000
0P3o]/402?l00000okK10?nf`@000000okK10000003o]/4000000P3o]/400`000000okK10?nf`@03
0?nf`@80000000<0okK10000000000001@3o]/4010000000okK10?nf`@0000020?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400`3o]/43000001@0okK100D000000?nf`@3o]/40okK1
000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/4010000000okK10?nf`Ol0000:0?nf
`@08o`00003o]/40okK10000003o]/4000000?nf`@0000020?nf`@050000003o]/4000000?nf`@00
00000P3o]/401@00003oooooooooooooool0000000Cooooo00<00000ooooooooool05Oooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Nooooo`T0okK100<0003o0?nf`@3o
]/405P3o]/400`000?l0okK10?nf`@0Z0?nf`@030000o`3o]/40okK100P0okK11Ol0000;0?nf`@03
0000o`3o]/40okK100L0okK18?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool00oooool01P000000okK10?nf`@000000okK1000000<0okK100D00000
0?nf`@000000okK1000000020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o
]/401Ol00000okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@050?nf`@<00000403o]/401@000000okK10?nf`@3o]/4000000080okK100H000000?nf`@3o
]/4000000?nf`@0000020?nf`@040000003o]/40okK1o`0000X0okK100So00000?nf`@3o]/400000
0?nf`@000000okK100000080okK100D000000?nf`@000000okK1000000020?nf`@0500000?oooooo
ooooooooo`0000001?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo01kooooo2@3o]/400`000?l0okK10?nf`@0F0?nf`@030000o`3o]/40
okK102X0okK100<0003o0?nf`@3o]/40203o]/45o`0000/0okK100<0003o0?nf`@3o]/401P3o]/4Q
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05oooool00`00003oooooooooo`03
ooooo`040000003o]/40okK100000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@04
0000003o]/40okK1o`0000/0okK10P0000030?nf`@050000003o]/40okK10?nf`@0000001@3o]/43
000000L0okK1200000050?nf`@80000000?o00000?nf`@3o]/400P3o]/4010000000okK10?nf`@00
00020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/7o00002P3o]/402?l00000okK1
0?nf`@000000okK10000003o]/4000000P3o]/401@000000okK10000003o]/4000000080okK100D0
0000oooooooooooooooo00000004ooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool07oooool90?nf`@030000o`3o]/40okK101@0okK100<0
003o0?nf`@3o]/40:`3o]/400`000?l0okK10?nf`@090?nf`@?o0000303o]/400`000?l0okK10?nf
`@060?nf`B7ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Gooooo`0300000?oo
oooooooo00?ooooo00@00000ooooo`3o]/4000000P3o]/401P000000okK10?nf`Ol00000okK10000
00<0okK100@000000?nf`@3o]/4000002@3o]/400`000000okK10?nf`@030?nf`@050000003o]/40
okK10?nf`@000000203o]/44000000/0okK11@0000070?nf`@040000003o]/40okK100000080okK1
00<000000?nf`@0000000P3o]/4010000000okK10?nf`Ol000090?nf`@09o`00003o]/40okK10?nf
`@000000okK10000003o]/4000000080okK100D000000?nf`@000000okK1000000020?nf`@050000
0?ooooooooooooooo`0000001?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo023ooooo2@3o]/400`000?l0okK10?nf`@0B0?nf`@030000
o`3o]/40okK102d0okK100<0003o0?nf`@3o]/405P3o]/400`000?l0okK10?nf`@060?nf`B;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00;ooooo
00D00000ooooooooool0okK1000000020?nf`@030000003o]/4000000080okK100D000000?nf`@3o
]/40okK1000000020?nf`@<000000`3o]/43000000D0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@090?nf`@L00000403o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40
000000<0okK100@000000?nf`@3o]/7o00001P3o]/42o`0000<0okK100P000000?nf`@3o]/400000
0?nf`@000000okK100000080okK100H000000?nf`@000000okK1ooooo`000003ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool05Oooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0Pooooo`T0okK100?o003o0000o`3o]/404@3o]/400`000?l0okK10?nf`@0^
0?nf`@030000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/401@3o]/4Sooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool06?ooool00`00003oooooooooo`03ooooo`0400000?ooool0
okK100000080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000@0
okK10`0000070?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40403o]/43000000`0
okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100@00000
0?nf`@3o]/40okK10ol000020?nf`@03o`00003o]/40okK100<0okK100D000000?nf`@000000okK1
000000020?nf`@03o`00003o]/4000000080okK100<00000ooooo`0000000oooool00`00003ooooo
ooooo`03ooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool08Oooool:0?nf`@80003o403o]/400`000?l0okK10?nf`@0^0?nf`@030000o`3o
]/40okK101H0okK100<0003o0?nf`@3o]/401@3o]/4Sooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`0500000?oooooooooo0?nf`@000000
0P3o]/4010000000okK10?nf`@0000020?nf`@8000000P3o]/401000003o00000000000000070?nf
`@80000000?o00000?nf`@3o]/401P3o]/400ol0000000000000000;000000L0okK1100000080?nf
`@05o`00003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@0200000080okK100<00000
0?nf`@3o]/400`3o]/42o`0000@0okK10P0000020?nf`@030000003o]/7o00000080okK100<00000
0?nf`@0000000P3o]/400`00003oooooo`000003ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Qoooo
o``0okK100<0003o0?nf`@3o]/402`3o]/420000oc80okK100<0003o0?nf`@3o]/405@3o]/400`00
0?l0okK10?nf`@040?nf`BCooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Hoooo
o`0300000?oooooooooo00?ooooo00D00000ooooooooool0okK1o`0000030?nf`@05o`00003o]/40
okK1o`00000000000P3o]/42000000@0okK11`00000I0?nf`@@000001`3o]/4400000080okK10`00
00030?nf`@050000003o]/40okK10?nf`@0000000`3o]/4010000000okK10?nf`@0000090?nf`@05
0000003o]/40okK10?nf`@0000000P3o]/401P000000okK10?nf`@000000okK100000080okK100<0
0000ooooo`0000000oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo01Gooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool08Oooool=0?nf`@80003o203o]/43
0000oa80okK12@000?lI0?nf`@030000o`3o]/40okK101@0okK100<0003o0?nf`@3o]/401@3o]/4T
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06Oooool00`00003oooooooooo`03
ooooo`0500000?ooool0okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40000000<0okK1
00<000000?nf`@3o]/409@3o]/43000000P0okK10P0000070?nf`@050000003o]/40okK10?nf`@00
00000`3o]/4010000000okK10?nf`@0000060?nf`@8000000`3o]/401?l00000okK10?nf`@000002
0?nf`@030000003o]/4000000080okK100@00000ooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool08_ooool>0?nf`@80003o0`3o]/430000oa@0okK100<0003o0?nf`@3o]/401`3o]/44
0000oaD0okK100<0003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@050?nf`BCooooo00<00000
ooooooooool03oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00Cooooo00Go0000
ooooo`3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000000`3o]/44000001H0okK1
2P0000000ol000000000000000030?nf`@0300000?l00000000000l0okK100D000000?nf`@3o]/40
okK1000000030?nf`@80000000<0okK1000000000000100000030?nf`@8000000P3o]/401P000000
okK10?nf`@000000okK1o`000080okK100@00000o`000?ooool000000oooool00`00003ooooooooo
o`03ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool08oooool?0?nf`@<0003o5@3o]/420000o`h0okK100<0003o0?nf`@3o]/404`3o]/42
0000oa80okK10P000?l70?nf`BGooooo00<00000ooooooooool03oooool00`00003oooooooooo`0I
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00P3o]/4010000000okK10?nf`@00
00040?nf`@03o`0000000000okK100@0okK1300000090?nf`@030000003o]/40okK100/0okK10P00
00040?nf`@030000003o]/40okK100`0okK100H000000?nf`@3o]/40okK1o`00000000040?nf`@03
0000003o]/40okK100@0okK10`0000030?nf`@070000003o]/40okK10?nf`@000000okK100000002
0?nf`@0400000?oooooooooo000000?ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02?ooooo9P3o]/40
0`000?l0okK10?nf`@0?0?nf`@030000o`3o]/40okK101@0okK100<0003o0?nf`@3o]/403@3o]/42
0000o`P0okK19_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01[ooooo00<00000
ooooooooool01?ooool00`00003ooooo0?nf`@020?nf`@030000003o]/40okK100800000103o]/40
0`000000okK10?nf`@0=0?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/400`3o]/44
000000H0okK10P0000030?nf`@030000003o]/40okK100`0okK10P0000030?nf`@8000000`3o]/46
000000@0okK10P0000020?nf`@8000000P3o]/400`000000okK100000002ooooo`0500000?oooooo
ooooooooo`0000001_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo02Cooooo9@3o]/400`000?l0okK10?nf`@0@0?nf`@030000o`3o]/40
okK101@0okK10P000?l;0?nf`@80003o2P3o]/4Vooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool06_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00<0okK100@00000
0?nf`@3o]/40okK10P0000030?nf`@<000003@3o]/400`000000okK10?nf`@050?nf`@040000003o
]/40okK10?nf`@<00000103o]/44000000@0okK100Go00000?nf`@3o]/40okK1o`00000?0?nf`@03
0000003o]/40okK10080okK10P0000090?nf`@8000000`3o]/401@000000okK10?nf`@3o]/400000
0080okK100@00000ooooooooool000000oooool00`00003oooooooooo`03ooooo`0300000?oooooo
oooo01Oooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool09?oooolT0?nf
`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/405P3o]/430000o`H0okK10P000?l;0?nf
`BOooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo
00Cooooo0P0000040?nf`@030000003o]/40okK10080okK10`0000030?nf`@P000001P3o]/400`00
0000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@0000002`3o]/401@000000okK10?nf`@3o
]/40000000<0okK100<000000?nf`@3o]/403P3o]/42000000@0okK100@00000o`00000000000000
0`3o]/42000000@0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04o`000?ooooooooooo`00
00?ooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo02Gooooo8P3o]/400`000?l0okK10?nf`@0C0?nf`@03
0000o`3o]/40okK101P0okK11P000?l=0?nf`BOooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0Kooooo`0300000?oooooooooo00Kooooo00<000000?nf`@3o]/400P3o]/400ol00000
00000?nf`@040?nf`@<00000203o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0
okK100D000000?nf`@3o]/40okK1000000030?nf`@H000000`3o]/4010000000okK10?nf`@000003
0?nf`@030000003o]/40okK100H0okK1100000060?nf`@8000001P3o]/43000000<0okK10`000002
0?nf`@8000000P3o]/401@000000okK1ooooooooool0000000?ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo02Kooooo803o]/400`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK102T0okK1:?ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool01_ooool0
0`000000okK10?nf`@030?nf`@8000001P3o]/43000000H0okK100<000000?nf`@3o]/400`3o]/40
1@000000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK1000000060?nf`@050000
003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000D0okK10P0000040?nf
`@@00000103o]/43000000H0okK10`0000030?nf`@8000000`3o]/401@000000okK1ooooooooool0
000000?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Hooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo02Oooooo7`3o]/400`000?l0okK10?nf`@0E0?nf
`@030000o`3o]/40okK102P0okK1:Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01gooooo00<00000ooooooooool01_ooool00`000000okK10?nf`@040?nf`@030000003o]/40okK1
00H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK1
0?nf`@0000000P3o]/401@000000okK10?nf`@3o]/7o000000P0okK100D000000?nf`@3o]/40okK1
000000020?nf`@040000003o]/40okK1000000D0okK100<000000?nf`@3o]/401`3o]/400`000000
okK10?nf`@040?nf`@H000001@3o]/400ol00000okK10?nf`@020?nf`@050000003o]/7ooooooooo
o`0000001?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo01Wooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0:?oooolN0?nf`@030000o`3o]/40okK101D0
okK100<0003o0?nf`@3o]/409`3o]/4Zooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool07_ooool00`00003o0000ooooo`06ooooo`03o`0000000000okK100@0okK100Co000000000000
000000001@3o]/400`00003o0000000000040?nf`@0500000?l00000okK10?nf`Ol000000`3o]/40
1?l00000okK10?nf`Ol000030?nf`@03o`00003o]/40okK100L0okK100Go00000?nf`@3o]/40okK1
o`0000020?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/402@3o]/400ol00000
000000000003000000H0okK11@0000030?nf`@80000000@0okK1oooooooooooo00001?ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0:?oooolM0?nf`@030000o`3o]/40okK101L0okK100<0003o0?nf`@3o
]/409@3o]/4[ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool08?ooool00`00003o
ooooooooo`05ooooo`030?nf`@000000000000L0okK10P0000060?nf`@030000003o]/40okK10080
okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40
okK100L0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000<0okK1
00<000000?nf`@3o]/403`3o]/46000000H0okK10P0000020?nf`@03ooooo`000000000000Cooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo02Wooooo703o]/400`000?l0okK10?nf`@090?nf`@?o00002`3o
]/400`000?l0okK10?nf`@0U0?nf`B_ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0Qooooo`0300000?oooooooooo00Gooooo0P3o]/42000000L0okK10`0000040?nf`@030000003o
]/40okK10080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@03
0000003o]/40okK100P0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1
00000080okK100<000000?nf`@3o]/40103o]/48000000d0okK10`0000040?nf`@0300000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0Jooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo02[ooooo6`3o]/400`000?l0okK10?nf`@080?nf
`@Go00002P3o]/400`000?l0okK10?nf`@0T0?nf`Bcooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Rooooo`8000001_ooool30?nf`@<000001`3o]/400`000000okK10?nf`@020?nf
`@05o`00003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`Ol000020?nf`@040000003o
]/40okK1000000/0okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf
`@030000003o]/40okK10080okK10P0000080?nf`@d000001@3o]/42000000Cooooo0P000006oooo
o`0300000?l0003ooooo01cooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0:ooooolJ0?nf`@030000o`3o]/40okK100P0okK11Ol0000:0?nf`@030000o`3o]/40okK102<0
okK1;Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02Cooooo00<00000oooooooo
ool01?ooool50?nf`@8000001P3o]/401Ol00000okK10?nf`@3o]/40000000<0okK100@000000?nf
`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK100T0okK100@0
00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/405`3o]/42000000Gooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0Looooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02cooooo
6@3o]/400`000?l0okK10?nf`@080?nf`@Go00002P3o]/400`000?l0okK10?nf`@0R0?nf`Bkooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo00Cooooo
1P3o]/42000000D0okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o]/4000000080
okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@070?nf`@050000003o]/40okK1
0?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@000000
5`3o]/43000000030?nf`Ooooooooooo00?ooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02gooooo603o
]/400`000?l0okK10?nf`@090?nf`@?o00002`3o]/400`000?l0okK10?nf`@0P0?nf`C3ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0Vooooo`8000001Oooool70?nf`@030000003o
]/40okK100<0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080
okK100<000000?nf`@0000000`3o]/400`000000okK10?nf`@070?nf`@07o`00003o]/40okK10?nf
`@000000okK1000000020?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/400`3o
]/400ol0000000000000000@00000080okK11_ooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo01kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;_oooolG
0?nf`@030000o`3o]/40okK101L0okK100<0003o0?nf`@3o]/407`3o]/4aooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0:?ooool00`00003o000000000003ooooo`L0okK100?o0000
0000003o]/400`3o]/401@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@0000000P3o
]/4010000000okK10?nf`Ol000020?nf`@03o`0000000000okK100H0okK10P0000030?nf`@030000
003o]/4000000080okK100@000000?nf`@3o]/7o00000P3o]/400`000000okK10?nf`@020?nf`@80
0000503o]/44ooooo`80000000?o0000ooooooooool01_ooool00`00003oooooooooo`0Oooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo033ooooo5@3o]/400`000?l0okK1
0?nf`@0G0?nf`@030000o`3o]/40okK101h0okK1<_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo02_ooooo0P000003ooooo`L0okK100D000000?nf`@3o]/40okK1000000030?nf`@06
0000003o]/40okK1o`00003o]/4000000P3o]/4010000000okK10?nf`@0000040?nf`@030000003o
]/40okK100<0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@0000020?nf`@030000
003o]/40000000<0okK100D000000?nf`@3o]/40okK10000000E0?nf`@?ooooo0P00000:ooooo`03
00000?oooooooooo023ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
<OoooolE0?nf`@030000o`3o]/40okK101D0okK100<0003o0?nf`@3o]/407P3o]/4cooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0;Oooool2000000;ooooo1`3o]/401@000000okK1
0?nf`@3o]/40000000<0okK100<000000?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf
`@030000003o]/40okK10080okK11@0000040?nf`@040000003o]/40okK100000080okK100@00000
0?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/7o000001<0okK11P00000;ooooo`030000
0?oooooooooo027ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0<_oo
oolE0?nf`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/407P3o]/4dooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0;oooool00`00003oooooooooo`070?nf`@05o`00003o
]/40okK10?nf`@0000000`3o]/400`000000okK1000000020?nf`@040000003o]/40okK100000080
okK100<000000?nf`@3o]/401`3o]/4200000004o`00003o]/40000000000080okK100@00000o`00
003o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000H0okK11@0000000ol0000000000000
0006000000030?nf`Ooooooooooo00_ooooo0P0000000ol0003oooooooooo`0Rooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo03?ooooo503o]/400`000?l0okK10?nf`@0C
0?nf`@030000o`3o]/40okK101d0okK1=Oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo033ooooo00?o000000000?ooool01P3o]/400`000000okK10?nf`@020?nf`@040000003o]/40
okK100000080okK100<000000?nf`@0000000P3o]/401Ol0000000000?nf`@3o]/7o000000800000
1@3o]/401@000000okK10?nf`@3o]/40000000@0okK100@000000?nf`@3o]/4000000P3o]/401@00
0000okK10?nf`@3o]/40000000D0okK100<000000?nf`@3o]/40303o]/4=ooooo`0300000?oooooo
oooo02Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0=OoooolC0?nf
`@030000o`3o]/40okK10100okK10P000?lN0?nf`COooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0booooo`0300000?oooooooooo00D0okK100<000000?nf`@3o]/400P3o]/401000
0000okK10?nf`@0000020?nf`@030000003o]/40000000<0okK10P0000030?nf`@D000000`3o]/40
0`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1
000000040?nf`@8000003@3o]/4=ooooo`800000:?ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`0foooooa80okK100<0003o0?nf`@3o]/403`3o]/400`000?l0okK10?nf
`@0M0?nf`CSooooo00<00000ooooooooool03oooool00`00003oooooooooo`0cooooo`0300000?oo
oooooooo00@0okK10P0000030?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@000000
103o]/400`000000okK10?nf`@070?nf`@03o`00003o]/40okK10080okK100@000000?nf`@3o]/7o
00000P3o]/401Ol00000okK10?nf`@3o]/7o000000@0okK100<000000?nf`@3o]/40303o]/4;oooo
o`<00000:_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0hoooooa40
okK10P000?l>0?nf`@030000o`3o]/40okK101`0okK1>_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo03Cooooo00@00000oooooooooooooooo0`3o]/400`000000okK10?nf`@020?nf
`@040000003o]/40okK1o`000080okK100?o00000000003o]/400P0000030?nf`@03o`0000000000
000000L000000P3o]/42000000030?nf`@00000000000080okK100D000000?nf`@3o]/40okK10000
00040?nf`@03o`00003o]/40okK100/0okK12?ooool5000002gooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool0>_oooolA0?nf`@<0003o2P3o]/400`000?l0okK10?nf`@0K
0?nf`Ccooooo00<00000ooooooooool03oooool00`00003oooooooooo`0eooooo`0300000?oooooo
oooo00;ooooo0P3o]/401@000000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK1
000000020?nf`@8000002`3o]/4200000080okK100<000000?nf`@3o]/400P3o]/4010000000okK1
0?nf`@0000040?nf`@030000003o]/40okK100X0okK11oooool3000003;ooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0>ooooolC0?nf`@D0003o00<0okK10000o`000?l0
0P000?lM0?nf`Cgooooo00<00000ooooooooool03oooool00`00003oooooooooo`0fooooo`030000
0?oooooooooo00;ooooo0P3o]/401@000000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o
]/40okK1000000030?nf`@<000001P3o]/42000000<0okK100?o00000?nf`@3o]/400P3o]/401000
0000okK10?nf`@0000040?nf`@030000003o]/40okK100P0okK12P00000eooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo03kooooo5@3o]/400`000?l0okK10?nf`@0M0?nf
`Coooooo00<00000ooooooooool03oooool00`00003oooooooooo`0gooooo`0300000?oooooooooo
00Cooooo00@000000?nf`@3o]/40okK10P0000020?nf`@8000000P3o]/400ol00000000000000003
0?nf`@H000000`3o]/4200000080okK10P0000001?l00000okK10?nf`@0000040?nf`@030000003o
]/40okK100L0okK100?o000000000?ooool0?_ooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`11ooooobl0okK1@_ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo03Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo0?nf`@020?nf`@050000003o]/40
okK10?nf`@000000103o]/43000000H0okK10`0000030?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@800000@Oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`14ooooobT0okK1AOooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool01?ooool00`00003oooooooooo`02
ooooo`030?nf`@000000okK10080okK10P0000050?nf`@H00000103o]/42000000@0okK100<00000
0?nf`@3o]/400P3o]/42000000H0okK100?ooooo00000?ooool0@_ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`17ooooob<0okK1B?ooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo03Wooooo00<00000ooooooooool01?ooool00`00003oooooooooo`03oooo
o`030000003o]/40okK10080okK10P00000;0?nf`@8000001@3o]/400ol00000okK10?nf`@020?nf
`@030000003o]/40okK100<0okK10oooool00ol0003oooooooooo`12ooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo04[ooooo7@3o]/5;ooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool0>_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00?o
oooo00?o000000000?ooool00`3o]/4;000000D0okK10P0000040?nf`@04o`00003o]/40okK10?nf
`@Cooooo0P000015ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04go
oooo5`3o]/5>ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0>oooool00ol0003o
ooooooooo`04ooooo`03o`000000003ooooo00Cooooo0P000002ooooo`d0okK10`0000040?nf`@80
000000<0okK1ooooooooool01?ooool00`00003oooooooooo`15ooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo05Kooooo103o]/5Hooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool0??ooool00`00003oooooooooo`05ooooo`8000001Oooool2000000Wooooo
0P3o]/42000000Kooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`16ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0mooooo`0300000?oooooooooo00Kooooo0P000005ooooo`/000001_oo
ool2000000Sooooo00<00000ooooooooool0Aoooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0?_ooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo017ooooo0P000009ooooo`0300000?oooooo
oooo04Sooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo03oooooo00<00000ooooooooool01oooool30000
00gooooo0`000009ooooo`800000Boooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0@?ooool00`00003o
ooooooooo`09ooooo`@000001_ooool3000000_ooooo00<00000ooooooooool0Boooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo
00<00000ooooooooool0@Oooool00`00003o00000000000<ooooo`H000002oooool200000003o`00
0?oooooooooo04cooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo04Cooooo0P00000Jooooo`0300000?oo
oooooooo04oooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo04Kooooo0P00000Fooooo`800000D_ooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00oooooo00<00000ooooooooool0B?ooool00`00003oooooooooo`0Aooooo`03o`000000003ooooo
05?ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo04Wooooo00?o00000000000000003Oooool3000005Ko
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo04cooooo3@00001Iooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooookH000004Ooooonf0000
00[ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.02886 0.144395 0.000526922 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16811 -0.0125 -3 -9 ]
[.16811 -0.0125 3 0 ]
[.31241 -0.0125 -6 -9 ]
[.31241 -0.0125 6 0 ]
[.45671 -0.0125 -6 -9 ]
[.45671 -0.0125 6 0 ]
[.60101 -0.0125 -6 -9 ]
[.60101 -0.0125 6 0 ]
[.74531 -0.0125 -6 -9 ]
[.74531 -0.0125 6 0 ]
[.88961 -0.0125 -6 -9 ]
[.88961 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03901 -24 -4.5 ]
[-0.0125 .03901 0 4.5 ]
[-0.0125 .1444 -6 -4.5 ]
[-0.0125 .1444 0 4.5 ]
[-0.0125 .24978 -18 -4.5 ]
[-0.0125 .24978 0 4.5 ]
[-0.0125 .35516 -18 -4.5 ]
[-0.0125 .35516 0 4.5 ]
[-0.0125 .46055 -18 -4.5 ]
[-0.0125 .46055 0 4.5 ]
[-0.0125 .56593 -18 -4.5 ]
[-0.0125 .56593 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.16811 0 m
.16811 .61803 L
s
.31241 0 m
.31241 .61803 L
s
.45671 0 m
.45671 .61803 L
s
.60101 0 m
.60101 .61803 L
s
.74531 0 m
.74531 .61803 L
s
.88961 0 m
.88961 .61803 L
s
0 .03901 m
1 .03901 L
s
0 .1444 m
1 .1444 L
s
0 .24978 m
1 .24978 L
s
0 .35516 m
1 .35516 L
s
0 .46055 m
1 .46055 L
s
0 .56593 m
1 .56593 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16811 0 m
.16811 .00625 L
s
[(5)] .16811 -0.0125 0 1 Mshowa
.31241 0 m
.31241 .00625 L
s
[(10)] .31241 -0.0125 0 1 Mshowa
.45671 0 m
.45671 .00625 L
s
[(15)] .45671 -0.0125 0 1 Mshowa
.60101 0 m
.60101 .00625 L
s
[(20)] .60101 -0.0125 0 1 Mshowa
.74531 0 m
.74531 .00625 L
s
[(25)] .74531 -0.0125 0 1 Mshowa
.88961 0 m
.88961 .00625 L
s
[(30)] .88961 -0.0125 0 1 Mshowa
.125 Mabswid
.05267 0 m
.05267 .00375 L
s
.08153 0 m
.08153 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.13925 0 m
.13925 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.22583 0 m
.22583 .00375 L
s
.25469 0 m
.25469 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.39899 0 m
.39899 .00375 L
s
.42785 0 m
.42785 .00375 L
s
.48557 0 m
.48557 .00375 L
s
.51443 0 m
.51443 .00375 L
s
.54329 0 m
.54329 .00375 L
s
.57215 0 m
.57215 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.68759 0 m
.68759 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.77417 0 m
.77417 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.83189 0 m
.83189 .00375 L
s
.86075 0 m
.86075 .00375 L
s
.91847 0 m
.91847 .00375 L
s
.94733 0 m
.94733 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03901 m
.00625 .03901 L
s
[(-200)] -0.0125 .03901 1 0 Mshowa
0 .1444 m
.00625 .1444 L
s
[(0)] -0.0125 .1444 1 0 Mshowa
0 .24978 m
.00625 .24978 L
s
[(200)] -0.0125 .24978 1 0 Mshowa
0 .35516 m
.00625 .35516 L
s
[(400)] -0.0125 .35516 1 0 Mshowa
0 .46055 m
.00625 .46055 L
s
[(600)] -0.0125 .46055 1 0 Mshowa
0 .56593 m
.00625 .56593 L
s
[(800)] -0.0125 .56593 1 0 Mshowa
.125 Mabswid
0 .06536 m
.00375 .06536 L
s
0 .0917 m
.00375 .0917 L
s
0 .11805 m
.00375 .11805 L
s
0 .17074 m
.00375 .17074 L
s
0 .19709 m
.00375 .19709 L
s
0 .22343 m
.00375 .22343 L
s
0 .27613 m
.00375 .27613 L
s
0 .30247 m
.00375 .30247 L
s
0 .32882 m
.00375 .32882 L
s
0 .38151 m
.00375 .38151 L
s
0 .40786 m
.00375 .40786 L
s
0 .4342 m
.00375 .4342 L
s
0 .48689 m
.00375 .48689 L
s
0 .51324 m
.00375 .51324 L
s
0 .53959 m
.00375 .53959 L
s
0 .01266 m
.00375 .01266 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.16811 .61178 m
.16811 .61803 L
s
.31241 .61178 m
.31241 .61803 L
s
.45671 .61178 m
.45671 .61803 L
s
.60101 .61178 m
.60101 .61803 L
s
.74531 .61178 m
.74531 .61803 L
s
.88961 .61178 m
.88961 .61803 L
s
.125 Mabswid
.05267 .61428 m
.05267 .61803 L
s
.08153 .61428 m
.08153 .61803 L
s
.11039 .61428 m
.11039 .61803 L
s
.13925 .61428 m
.13925 .61803 L
s
.19697 .61428 m
.19697 .61803 L
s
.22583 .61428 m
.22583 .61803 L
s
.25469 .61428 m
.25469 .61803 L
s
.28355 .61428 m
.28355 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.37013 .61428 m
.37013 .61803 L
s
.39899 .61428 m
.39899 .61803 L
s
.42785 .61428 m
.42785 .61803 L
s
.48557 .61428 m
.48557 .61803 L
s
.51443 .61428 m
.51443 .61803 L
s
.54329 .61428 m
.54329 .61803 L
s
.57215 .61428 m
.57215 .61803 L
s
.62987 .61428 m
.62987 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.68759 .61428 m
.68759 .61803 L
s
.71645 .61428 m
.71645 .61803 L
s
.77417 .61428 m
.77417 .61803 L
s
.80303 .61428 m
.80303 .61803 L
s
.83189 .61428 m
.83189 .61803 L
s
.86075 .61428 m
.86075 .61803 L
s
.91847 .61428 m
.91847 .61803 L
s
.94733 .61428 m
.94733 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03901 m
1 .03901 L
s
.99375 .1444 m
1 .1444 L
s
.99375 .24978 m
1 .24978 L
s
.99375 .35516 m
1 .35516 L
s
.99375 .46055 m
1 .46055 L
s
.99375 .56593 m
1 .56593 L
s
.125 Mabswid
.99625 .06536 m
1 .06536 L
s
.99625 .0917 m
1 .0917 L
s
.99625 .11805 m
1 .11805 L
s
.99625 .17074 m
1 .17074 L
s
.99625 .19709 m
1 .19709 L
s
.99625 .22343 m
1 .22343 L
s
.99625 .27613 m
1 .27613 L
s
.99625 .30247 m
1 .30247 L
s
.99625 .32882 m
1 .32882 L
s
.99625 .38151 m
1 .38151 L
s
.99625 .40786 m
1 .40786 L
s
.99625 .4342 m
1 .4342 L
s
.99625 .48689 m
1 .48689 L
s
.99625 .51324 m
1 .51324 L
s
.99625 .53959 m
1 .53959 L
s
.99625 .01266 m
1 .01266 L
s
.99625 .59228 m
1 .59228 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.05267 .50601 L
.08153 .52901 L
.11039 .54149 L
.13925 .54847 L
.16811 .55361 L
.19697 .55814 L
.22583 .56215 L
.25469 .56569 L
.28355 .56886 L
.31241 .57173 L
.34127 .57432 L
.37013 .57665 L
.39899 .5788 L
.42785 .58084 L
.45671 .58283 L
.48557 .5848 L
.51443 .58675 L
.54329 .58866 L
.57215 .59051 L
.60101 .59225 L
.62987 .59387 L
.65873 .59534 L
.68759 .59666 L
.71645 .59783 L
.74531 .59886 L
.77417 .59975 L
.80303 .60052 L
.83189 .60118 L
.86075 .60174 L
.88961 .60223 L
.91847 .60264 L
.94733 .603 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.05267 .50601 Mdot
.08153 .52901 Mdot
.11039 .54149 Mdot
.13925 .54847 Mdot
.16811 .55361 Mdot
.19697 .55814 Mdot
.22583 .56215 Mdot
.25469 .56569 Mdot
.28355 .56886 Mdot
.31241 .57173 Mdot
.34127 .57432 Mdot
.37013 .57665 Mdot
.39899 .5788 Mdot
.42785 .58084 Mdot
.45671 .58283 Mdot
.48557 .5848 Mdot
.51443 .58675 Mdot
.54329 .58866 Mdot
.57215 .59051 Mdot
.60101 .59225 Mdot
.62987 .59387 Mdot
.65873 .59534 Mdot
.68759 .59666 Mdot
.71645 .59783 Mdot
.74531 .59886 Mdot
.77417 .59975 Mdot
.80303 .60052 Mdot
.83189 .60118 Mdot
.86075 .60174 Mdot
.88961 .60223 Mdot
.91847 .60264 Mdot
.94733 .603 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002;ooooo0ol0000Pooooo`?o0000
1?ooool2o`0001cooooo0ol00003ooooo`?o00007?ooool5o`0000?ooooo0_l0000Kooooo`Go0000
0_ooool3o`0001gooooo0ol00004ooooo`;o00006_ooool001oooooo00Co0000oooooooooooo0000
8?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Looooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0J
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00006Oooool001oooooo00Co0000oooooooooooo00009?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Oooooo000Oooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0L
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06oooool2o`0000?ooooo00Co0000oooooooooooo0000
6Oooool001oooooo00Co0000oooooooooooo00008?ooool4o`00027ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Looooo`04o`000?ooooooooooooooo`Co00007?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006_ooool01_l0003ooooooooo
oooooooo0000ooooo`Co00008?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
01Oooooo000Oooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool08Oooool2o`00
00Cooooo00Co0000oooooooooooo00006oooool2o`0000?ooooo00?o0000ooooooooool07Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006_ooool01ol0003ooooo
oooooooooooo0000ooooool000007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00006Oooool0023ooooo0_l0000Qooooo`Go00008?ooool00ol0003oooooooooo`03
ooooo`;o00007Oooool01?l0003oooooooooooooool5o`0001cooooo0ol00004ooooo`;o00007?oo
ool3o`0000;ooooo1Ol0000Looooo`?o00001?ooool2o`0001[ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000Kooooo`0300000?l0003o00000?oo00000Ol0
00010000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool1
0000007ooooo000Kooooo`0300000?oooooooooo00;ooooo0`3o000Sooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`4000000Oooool001_o
oooo00@00000o`000?oooooooooo1@3o000Rooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Hooooo`7o00000@000001ooooo`006oooool01000003o
ooooooooooooool50?l002;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool01000003oooooooooooooool50?l0
02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`02ooooo`<0o`008oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007o
oooo000Kooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool08_ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo
0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool06Oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool06Oooool10000007ooooo0005o`0000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00
000007l00`0007l00`000000001o0000O`3i0000O`7o00000@000001ooooo`002Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo0006oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`400000
0Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo
02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Wooooo0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003o0000ooooo`04
ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Sooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo
00Cooooo00<00000ooooooooool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000
ooooooooool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool06Oooool10000007ooooo000Kooooo`0300000?l0003ooooo00Cooooo00<00000oooooooo
ool08Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool06?ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`0Qooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Qooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Q
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0I
ooooo`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Qoooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Ioooo
o`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Qooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`40
00000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Qooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`400000
0Oooool001_ooooo00<00000o`000?ooool01?ooool00`00003oooooooooo`0Qooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Hooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo023ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001
ooooo`006oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo023ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001oooo
o`006oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo023ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`00
5?ooool2o`0000Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Pooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`400000
0Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`030000
0?oooooooooo023ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Wooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`030000
0?l00000001o00D0001o00<000000000O`0007l0m`0007l1o`00004000000Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo023ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo
0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool08?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool06Oooool10000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001Cooooo0_l0
0005ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08?ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000K
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Koooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`03
00000?l0003ooooo00Gooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool06?ooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<0
0000ooooooooool01Oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000
ooooooooool01Oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000o`000?ooool01_oo
ool00`00003oooooooooo`0Oooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Hooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Wooooo0@000001ooooo`006oooool00`00003o0000ooooo`06ooooo`0300000?oooooooooo
01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Sooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool07oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
7oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
6Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool07ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Ooo
ool10000007ooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooo
oooo00Kooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo0007ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo0008ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo00Kooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo0009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000o`00000007l01P0007l00`000000001o0000O`3f0000O`7o00000@000001oooo
o`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool07ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Ooo
ool10000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0Oooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Iooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo
00<00000ooooooooool01oooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000
ooooooooool01oooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool01oooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Hooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003ooooooooo
o`07ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`07
ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo01kooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo01kooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003o0000ooooo`07ooooo`030000
0?oooooooooo01kooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Sooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool07_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool07_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool07_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool07_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
7_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
6Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool07_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Ooo
ool10000007ooooo000Kooooo`0300000?l0003ooooo00Oooooo00<00000ooooooooool07_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06?ooool1
o`00004000000Oooool001_ooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Noooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Ioooo
o`4000000Oooool001_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Mooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`40
00000Oooool001_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Mooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`400000
0Oooool001_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Mooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Ooo
ool000Sooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`0Mooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Iooooo`4000000Oooool000Wooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`001_ooool5o`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o00P0001o
00<000000000O`0007l0m00007l1o`00004000000Oooool000Kooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool000Oooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool000Sooooo0_l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`002Oooool00ol0003oooooooooo`02
ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0M
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0I
ooooo`4000000Oooool001_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Moooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Ioooo
o`4000000Oooool001_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Mooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`40
00000Oooool001_ooooo00<00000o`000?ooool02?ooool00`00003oooooooooo`0Mooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Hooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01gooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@00
0001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01gooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001
ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01gooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001oooo
o`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01gooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`00
6oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo01cooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool0
0`00003o0000ooooo`09ooooo`0300000?oooooooooo01cooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Sooooo0Ol000010000007ooooo000Koooo
o`0300000?oooooooooo00Wooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`03
00000?oooooooooo00Wooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oo
oooooooo00Wooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo
00Wooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?l0003ooooo00Wo
oooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool06?ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0
2Oooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool02Ooo
ool00`00003oooooooooo`0Looooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`0Looooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Iooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`00
00Gooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Looooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool000Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01cooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@00
0001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o00T0001o00<000000000O`00
07l0l`0007l1o`00004000000Oooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo
01cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Wooooo0@000001ooooo`001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo01cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Wooooo0@000001ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo01cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Wooooo0@000001ooooo`002?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool0
0`00003oooooooooo`0:ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00
003oooooooooo`0:ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0:ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003o0000
ooooo`0:ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Sooooo0Ol000010000007ooooo000Kooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooo
oooo00[ooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo
00Wooooo0`3o000Looooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool02?ooool50?l001_o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Wo
oooo0@000001ooooo`006oooool00`00003oooooooooo`08ooooo`D0o`006oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo
000Kooooo`0300000?oooooooooo00Sooooo1@3o000Kooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000
o`000?ooool02Oooool30?l00003ooooo`00003ooooo01Wooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Sooooo0Ol000010000007ooooo000Koooo
o`0300000?oooooooooo00kooooo0P00000Hooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000oooooooo
ool04?ooool010000000o`000?l0003o000Dooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000oooooooo
ool04?ooool50?l001?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003oooooooooo`0@ooooo`D0o`00
4oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
6Oooool10000007ooooo000Kooooo`0300000?oooooooooo013ooooo1@3o00000`00003ooooooooo
o`0@ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool04Oooool30?l000;ooooo00<00000
ooooo`3o00000P3o000=ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Iooooo`4000000Oooool001_ooooo00<00000o`000?ooool05oooool50?l0
00Cooooo0`3o0005ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Hooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Gooooo`D0
o`000P0000000oooool0o`000?l000030?l000Cooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Gooooo`D0o`000_ooool00`000000o`000?l000030?l000?ooooo0`3o000Tooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oo
oooooooo01Sooooo0`3o0004ooooo`D0o`000P0000050?l000Cooooo0`3o000Looooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool06Oooool10000007ooooo0007ooooo`?o00001?ooool2
o`0000Cooooo0_l00005ooooo`0300000?oooooooooo023ooooo0`3o0003ooooo`D0o`000P000000
0oooool0o`000?l000030?l000?ooooo0`3o000Eooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool06Oooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
9_ooool50?l000;ooooo00<000000?l0003o00000`3o0002000000D0o`001?ooool30?l000gooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool000Kooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0Wooooo`<0o`001?ooool50?l000;ooooo1@3o00020000
0003ooooo`3o0000o`0000<0o`000oooool30?l000Gooooo0`3o000Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Wooooo0@000001ooooo`001oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?l00000001o02l0001o0`3o00030000O`D0o`000P0007l0
0`000000o`000?l000030?l0008000001@3o00030000O`D0o`000`0007l30?l00:P0001o0Ol00001
0000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0:?ooool00`0007oooooo
ooooo`0;ooooo`<0o`001?ooool50?l000;ooooo1@3o0003000000D0o`000P0000050?l000Cooooo
0`3o0004ooooo`<0o`003Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Iooooo`4000000Oooool000Kooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0Xooooo`030000Oooooooooooo01?ooooo0`3o0003oooo
o`D0o`000oooool50?l000;ooooo1@3o000200000003ooooo`3o0000o`0000<0o`000_ooool50?l0
00Cooooo0`3o0004ooooo`<0o`009?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool06Oooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Co
oooo0_l00005ooooo`0300000?oooooooooo02Sooooo00<0001oooooooooool06_ooool30?l000Go
oooo0`3o0003ooooo`D0o`000_ooool00`000000o`000?l000030?l0008000001@3o000200000003
ooooo`3o0000o`0000<0o`000_ooool50?l000Cooooo0`3o0004ooooo`<0o`005Oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool06Oooool10000007o
oooo000Kooooo`0300000?oooooooooo02Sooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`03ooooo`<0o`001?ooool50?l000;ooooo1@3o0002ooooo`030000003o0000o`0000<0o`00
0P0000050?l00080000000?ooooo0?l0003o00000`3o0002ooooo`D0o`001?ooool30?l000Cooooo
0`3o0006ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Iooooo`4000000Oooool001_ooooo00<00000ooooooooool0:?ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo00_ooooo0`3o0004ooooo`<0o`001?ooool50?l000;ooooo1@3o
0002ooooo`030000003o0000o`0000<0o`000P0000050?l00080000000?ooooo0?l0003o00000`3o
0002ooooo`D0o`001?ooool30?l000Cooooo0`3o000Looooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool06Oooool10000007ooooo000Kooooo`0300000?oooooooooo02Sooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Jooooo`<0o`001?ooool30?l000Cooooo1@3o0002
ooooo`D0o`000_ooool00`000000o`000?l000030?l0008000001@3o000200000003ooooo`3o0000
o`0000<0o`000_ooool50?l000Cooooo0`3o0004ooooo`<0o`001Oooool30?l000Cooooo0`3o000T
ooooo`030000Oooooooooooo01Wooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Xoooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`04oooo
o`<0o`001?ooool30?l000Cooooo1@3o0002ooooo`D0o`000_ooool00`000000o`000?l000030?l0
008000001@3o0003000000D0o`000P0000050?l000?ooooo1@3o0002ooooo`D0o`001?ooool30?l0
00Cooooo0`3o0005ooooo`<0o`001?ooool30?l000Gooooo0`3o0004ooooo`<0o`004_ooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool0:?ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool04oooool30?l000Cooooo0`3o0004ooooo`D0
o`000_ooool50?l000?ooooo1@3o0002ooooo`D0o`000`0000050?l0008000001@3o000200000003
ooooo`3o0000o`0000<0o`000_ooool50?l000?ooooo1@3o0002ooooo`D0o`000oooool50?l000;o
oooo1@3o0004ooooo`<0o`001?ooool30?l000Cooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Xooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Rooooo`<0o`001?ooool30?l000Cooooo1@3o0002ooooo`D0o`000oooool50?l000;ooooo
1@3o0002ooooo`030000003o0000o`0000<0o`000P0000050?l000<000001@3o0002000000D0o`00
0`0000050?l0008000001@3o0003000000D0o`000P0000050?l000?ooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Xooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo00_ooooo0`3o0004ooooo`<0o`001Ooo
ool30?l000Cooooo0`3o0004ooooo`D0o`000_ooool50?l000?ooooo1@3o0002ooooo`D0o`000ooo
ool50?l000;ooooo1@3o0003ooooo`D0o`000_ooool50?l000?ooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0Xooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool01?ooool3
0?l000Cooooo0`3o0005ooooo`<0o`001?ooool30?l000Gooooo0`3o0004ooooo`<0o`001?ooool5
0?l000;ooooo1@3o0003ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0`3o0004ooooo`<0o`001?ooool10000
007ooooo000Kooooool000001@000001ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.46136, -379.023, \
0.133461, 7.30977}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(scalar1\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #2: red class, full covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes full covariance matrices", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 5;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[data1, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.11000000000001364`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.81625 .98077 m
.82692 .972 L
.83856 .96154 L
.84615 .95424 L
.85768 .94231 L
.86538 .93372 L
.87429 .92308 L
.88462 .90972 L
.88885 .90385 L
.90169 .88462 L
.90385 .88116 L
.91301 .86538 L
.92308 .84618 L
.92309 .84615 L
.93192 .82692 L
.93977 .80769 L
.94231 .80093 L
.94661 .78846 L
.95256 .76923 L
.95772 .75 L
.96154 .7334 L
.96209 .73077 L
.9657 .71154 L
.96857 .69231 L
.97073 .67308 L
.97219 .65385 L
.97298 .63462 L
.97312 .61538 L
.97261 .59615 L
.97147 .57692 L
.96972 .55769 L
.96738 .53846 L
.96448 .51923 L
.96154 .5026 L
.96105 .5 L
.95712 .48077 L
.95276 .46154 L
.94798 .44231 L
.94285 .42308 L
.94231 .42111 L
.93739 .40385 L
.93163 .38462 L
.92557 .36538 L
.92308 .35775 L
.91917 .34615 L
.91237 .32692 L
.90505 .30769 L
.90385 .30468 L
.89705 .28846 L
.88818 .26923 L
.88462 .26208 L
.87822 .25 L
.8669 .23077 L
.86538 .22839 L
.85391 .21154 L
.84615 .20126 L
.83887 .19231 L
.82692 .17892 L
.82127 .17308 L
.80769 .16019 L
.80037 .15385 L
.78846 .14432 L
.77499 .13462 L
.76923 .13078 L
.75 .11922 L
.74288 .11538 L
.73077 .10937 L
.71154 .10104 L
.69845 .09615 L
.69231 .09408 L
.67308 .08837 L
.65385 .08383 L
.63462 .08039 L
.61538 .078 L
.60197 .07692 L
.59615 .07661 L
.57692 .07619 L
.55769 .07673 L
.55282 .07692 L
.53846 .07821 L
.51923 .08064 L
.5 .08402 L
.48077 .08836 L
.46154 .09369 L
.4537 .09615 L
.44231 .10006 L
.42308 .10751 L
.40536 .11538 L
.40385 .11611 L
.38462 .12596 L
.36957 .13462 L
.36538 .13718 L
.34615 .14995 L
.34074 .15385 L
.32692 .16449 L
.31667 .17308 L
.30769 .18113 L
.29618 .19231 L
.28846 .20039 L
.27858 .21154 L
.26923 .22306 L
.26343 .23077 L
.25039 .25 L
.25 .25062 L
.23924 .26923 L
.23077 .28635 L
.22981 .28846 L
.22196 .30769 L
.21558 .32692 L
.21154 .34199 L
.21058 .34615 L
.20686 .36538 L
.20433 .38462 L
.20289 .40385 L
.20241 .42308 L
.20271 .44231 L
.2036 .46154 L
.20485 .48077 L
.2062 .5 L
.20745 .51923 L
.20843 .53846 L
.20908 .55769 L
.20942 .57692 L
.2095 .59615 L
.20946 .61538 L
.20943 .63462 L
.20954 .65385 L
.20992 .67308 L
.21068 .69231 L
.21154 .70706 L
.21194 .71154 L
.21381 .73077 L
.21636 .75 L
.21968 .76923 L
.22384 .78846 L
.22891 .80769 L
.23077 .81397 L
.23505 .82692 L
.24232 .84615 L
.25 .86372 L
.2508 .86538 L
.26074 .88462 L
.26923 .89915 L
.27221 .90385 L
.28552 .92308 L
.28846 .92699 L
.30096 .94231 L
.30769 .94987 L
.31897 .96154 L
.32692 .96916 L
.34022 .98077 L
F
0 g
.81625 .98077 m
.82692 .972 L
.83856 .96154 L
.84615 .95424 L
.85768 .94231 L
.86538 .93372 L
.87429 .92308 L
.88462 .90972 L
.88885 .90385 L
.90169 .88462 L
.90385 .88116 L
.91301 .86538 L
.92308 .84618 L
.92309 .84615 L
.93192 .82692 L
.93977 .80769 L
.94231 .80093 L
.94661 .78846 L
.95256 .76923 L
.95772 .75 L
.96154 .7334 L
.96209 .73077 L
.9657 .71154 L
.96857 .69231 L
.97073 .67308 L
.97219 .65385 L
.97298 .63462 L
.97312 .61538 L
.97261 .59615 L
.97147 .57692 L
.96972 .55769 L
.96738 .53846 L
.96448 .51923 L
.96154 .5026 L
.96105 .5 L
.95712 .48077 L
.95276 .46154 L
.94798 .44231 L
.94285 .42308 L
.94231 .42111 L
.93739 .40385 L
.93163 .38462 L
.92557 .36538 L
.92308 .35775 L
.91917 .34615 L
.91237 .32692 L
.90505 .30769 L
.90385 .30468 L
.89705 .28846 L
.88818 .26923 L
Mistroke
.88462 .26208 L
.87822 .25 L
.8669 .23077 L
.86538 .22839 L
.85391 .21154 L
.84615 .20126 L
.83887 .19231 L
.82692 .17892 L
.82127 .17308 L
.80769 .16019 L
.80037 .15385 L
.78846 .14432 L
.77499 .13462 L
.76923 .13078 L
.75 .11922 L
.74288 .11538 L
.73077 .10937 L
.71154 .10104 L
.69845 .09615 L
.69231 .09408 L
.67308 .08837 L
.65385 .08383 L
.63462 .08039 L
.61538 .078 L
.60197 .07692 L
.59615 .07661 L
.57692 .07619 L
.55769 .07673 L
.55282 .07692 L
.53846 .07821 L
.51923 .08064 L
.5 .08402 L
.48077 .08836 L
.46154 .09369 L
.4537 .09615 L
.44231 .10006 L
.42308 .10751 L
.40536 .11538 L
.40385 .11611 L
.38462 .12596 L
.36957 .13462 L
.36538 .13718 L
.34615 .14995 L
.34074 .15385 L
.32692 .16449 L
.31667 .17308 L
.30769 .18113 L
.29618 .19231 L
.28846 .20039 L
.27858 .21154 L
Mistroke
.26923 .22306 L
.26343 .23077 L
.25039 .25 L
.25 .25062 L
.23924 .26923 L
.23077 .28635 L
.22981 .28846 L
.22196 .30769 L
.21558 .32692 L
.21154 .34199 L
.21058 .34615 L
.20686 .36538 L
.20433 .38462 L
.20289 .40385 L
.20241 .42308 L
.20271 .44231 L
.2036 .46154 L
.20485 .48077 L
.2062 .5 L
.20745 .51923 L
.20843 .53846 L
.20908 .55769 L
.20942 .57692 L
.2095 .59615 L
.20946 .61538 L
.20943 .63462 L
.20954 .65385 L
.20992 .67308 L
.21068 .69231 L
.21154 .70706 L
.21194 .71154 L
.21381 .73077 L
.21636 .75 L
.21968 .76923 L
.22384 .78846 L
.22891 .80769 L
.23077 .81397 L
.23505 .82692 L
.24232 .84615 L
.25 .86372 L
.2508 .86538 L
.26074 .88462 L
.26923 .89915 L
.27221 .90385 L
.28552 .92308 L
.28846 .92699 L
.30096 .94231 L
.30769 .94987 L
.31897 .96154 L
.32692 .96916 L
Mistroke
.34022 .98077 L
Mfstroke
.2 g
.7077 .98077 m
.71154 .97912 L
.73077 .9699 L
.7457 .96154 L
.75 .95892 L
.76923 .94599 L
.77419 .94231 L
.78846 .93075 L
.79705 .92308 L
.80769 .91271 L
.81602 .90385 L
.82692 .89112 L
.83205 .88462 L
.84574 .86538 L
.84615 .86476 L
.85745 .84615 L
.86538 .83126 L
.8675 .82692 L
.87605 .80769 L
.8833 .78846 L
.88462 .78461 L
.8893 .76923 L
.89416 .75 L
.89794 .73077 L
.90069 .71154 L
.9024 .69231 L
.90309 .67308 L
.90275 .65385 L
.90136 .63462 L
.89888 .61538 L
.89529 .59615 L
.89053 .57692 L
.88462 .55801 L
.88451 .55769 L
.87709 .53846 L
.86818 .51923 L
.86538 .51382 L
.85758 .5 L
.84615 .48233 L
.84505 .48077 L
.83022 .46154 L
.82692 .45769 L
.81254 .44231 L
.80769 .43762 L
.79109 .42308 L
.78846 .42099 L
.76923 .40715 L
.76411 .40385 L
.75 .39567 L
.73077 .38624 L
.72704 .38462 L
.71154 .37875 L
.69231 .373 L
.67308 .36892 L
.65385 .36647 L
.63462 .36563 L
.61538 .36639 L
.59615 .36879 L
.57692 .37283 L
.55769 .37855 L
.5417 .38462 L
.53846 .38602 L
.51923 .39534 L
.50426 .40385 L
.5 .40651 L
.48077 .41965 L
.47616 .42308 L
.46154 .4348 L
.45283 .44231 L
.44231 .452 L
.43251 .46154 L
.42308 .4713 L
.41434 .48077 L
.40385 .49281 L
.39784 .5 L
.38462 .51677 L
.38275 .51923 L
.36896 .53846 L
.36538 .54374 L
.35638 .55769 L
.34615 .57488 L
.345 .57692 L
.33484 .59615 L
.32692 .613 L
.32588 .61538 L
.31817 .63462 L
.31166 .65385 L
.30769 .66784 L
.3064 .67308 L
.30241 .69231 L
.29967 .71154 L
.29821 .73077 L
.29806 .75 L
.29925 .76923 L
.30185 .78846 L
.30592 .80769 L
.30769 .8145 L
.31157 .82692 L
.31895 .84615 L
.32692 .86296 L
.32821 .86538 L
.33966 .88462 L
.34615 .89405 L
.35364 .90385 L
.36538 .91748 L
.37073 .92308 L
.38462 .93619 L
.39186 .94231 L
.40385 .9515 L
.41875 .96154 L
.42308 .9642 L
.44231 .97474 L
.45526 .98077 L
F
0 g
.7077 .98077 m
.71154 .97912 L
.73077 .9699 L
.7457 .96154 L
.75 .95892 L
.76923 .94599 L
.77419 .94231 L
.78846 .93075 L
.79705 .92308 L
.80769 .91271 L
.81602 .90385 L
.82692 .89112 L
.83205 .88462 L
.84574 .86538 L
.84615 .86476 L
.85745 .84615 L
.86538 .83126 L
.8675 .82692 L
.87605 .80769 L
.8833 .78846 L
.88462 .78461 L
.8893 .76923 L
.89416 .75 L
.89794 .73077 L
.90069 .71154 L
.9024 .69231 L
.90309 .67308 L
.90275 .65385 L
.90136 .63462 L
.89888 .61538 L
.89529 .59615 L
.89053 .57692 L
.88462 .55801 L
.88451 .55769 L
.87709 .53846 L
.86818 .51923 L
.86538 .51382 L
.85758 .5 L
.84615 .48233 L
.84505 .48077 L
.83022 .46154 L
.82692 .45769 L
.81254 .44231 L
.80769 .43762 L
.79109 .42308 L
.78846 .42099 L
.76923 .40715 L
.76411 .40385 L
.75 .39567 L
.73077 .38624 L
Mistroke
.72704 .38462 L
.71154 .37875 L
.69231 .373 L
.67308 .36892 L
.65385 .36647 L
.63462 .36563 L
.61538 .36639 L
.59615 .36879 L
.57692 .37283 L
.55769 .37855 L
.5417 .38462 L
.53846 .38602 L
.51923 .39534 L
.50426 .40385 L
.5 .40651 L
.48077 .41965 L
.47616 .42308 L
.46154 .4348 L
.45283 .44231 L
.44231 .452 L
.43251 .46154 L
.42308 .4713 L
.41434 .48077 L
.40385 .49281 L
.39784 .5 L
.38462 .51677 L
.38275 .51923 L
.36896 .53846 L
.36538 .54374 L
.35638 .55769 L
.34615 .57488 L
.345 .57692 L
.33484 .59615 L
.32692 .613 L
.32588 .61538 L
.31817 .63462 L
.31166 .65385 L
.30769 .66784 L
.3064 .67308 L
.30241 .69231 L
.29967 .71154 L
.29821 .73077 L
.29806 .75 L
.29925 .76923 L
.30185 .78846 L
.30592 .80769 L
.30769 .8145 L
.31157 .82692 L
.31895 .84615 L
.32692 .86296 L
Mistroke
.32821 .86538 L
.33966 .88462 L
.34615 .89405 L
.35364 .90385 L
.36538 .91748 L
.37073 .92308 L
.38462 .93619 L
.39186 .94231 L
.40385 .9515 L
.41875 .96154 L
.42308 .9642 L
.44231 .97474 L
.45526 .98077 L
Mfstroke
.3 g
.61538 .44198 m
.63462 .44012 L
.65385 .43999 L
.67308 .44165 L
.67848 .44231 L
.69231 .44518 L
.71154 .45069 L
.73077 .45833 L
.73753 .46154 L
.75 .46838 L
.76862 .48077 L
.76923 .48123 L
.78846 .49753 L
.79102 .5 L
.80769 .51835 L
.8084 .51923 L
.82229 .53846 L
.82692 .54591 L
.83349 .55769 L
.84251 .57692 L
.84615 .58613 L
.84964 .59615 L
.8551 .61538 L
.85908 .63462 L
.86166 .65385 L
.86293 .67308 L
.86292 .69231 L
.86168 .71154 L
.85919 .73077 L
.85544 .75 L
.85039 .76923 L
.84615 .78242 L
.84396 .78846 L
.836 .80769 L
.82692 .82598 L
.82641 .82692 L
.81489 .84615 L
.80769 .85665 L
.80113 .86538 L
.78846 .88045 L
.78461 .88462 L
.76923 .89968 L
.76451 .90385 L
.75 .9155 L
.73935 .92308 L
.73077 .92862 L
.71154 .93949 L
.7059 .94231 L
.69231 .94841 L
.67308 .95562 L
.65385 .96129 L
.6529 .96154 L
.63462 .9655 L
.61538 .96835 L
.59615 .96986 L
.57692 .97007 L
.55769 .96898 L
.53846 .96653 L
.51923 .96267 L
.51461 .96154 L
.5 .9573 L
.48077 .95027 L
.46338 .94231 L
.46154 .94136 L
.44231 .93023 L
.43182 .92308 L
.42308 .9164 L
.40874 .90385 L
.40385 .89902 L
.39092 .88462 L
.38462 .87653 L
.37692 .86538 L
.36592 .84615 L
.36538 .84509 L
.35745 .82692 L
.35116 .80769 L
.34683 .78846 L
.34615 .78436 L
.34434 .76923 L
.34357 .75 L
.34445 .73077 L
.34615 .71406 L
.34694 .71154 L
.35103 .69231 L
.3567 .67308 L
.36395 .65385 L
.36538 .65048 L
.37283 .63462 L
.38333 .61538 L
.38462 .61322 L
.39552 .59615 L
.40385 .58435 L
.40943 .57692 L
.42308 .56012 L
.42517 .55769 L
.44231 .53908 L
.44292 .53846 L
.46154 .52057 L
.46302 .51923 L
.48077 .50423 L
.48616 .5 L
.5 .48988 L
.51374 .48077 L
.51923 .47741 L
.53846 .4668 L
.54938 .46154 L
.55769 .45797 L
.57692 .45091 L
.59615 .44558 L
.61282 .44231 L
F
0 g
.61538 .44198 m
.63462 .44012 L
.65385 .43999 L
.67308 .44165 L
.67848 .44231 L
.69231 .44518 L
.71154 .45069 L
.73077 .45833 L
.73753 .46154 L
.75 .46838 L
.76862 .48077 L
.76923 .48123 L
.78846 .49753 L
.79102 .5 L
.80769 .51835 L
.8084 .51923 L
.82229 .53846 L
.82692 .54591 L
.83349 .55769 L
.84251 .57692 L
.84615 .58613 L
.84964 .59615 L
.8551 .61538 L
.85908 .63462 L
.86166 .65385 L
.86293 .67308 L
.86292 .69231 L
.86168 .71154 L
.85919 .73077 L
.85544 .75 L
.85039 .76923 L
.84615 .78242 L
.84396 .78846 L
.836 .80769 L
.82692 .82598 L
.82641 .82692 L
.81489 .84615 L
.80769 .85665 L
.80113 .86538 L
.78846 .88045 L
.78461 .88462 L
.76923 .89968 L
.76451 .90385 L
.75 .9155 L
.73935 .92308 L
.73077 .92862 L
.71154 .93949 L
.7059 .94231 L
.69231 .94841 L
.67308 .95562 L
Mistroke
.65385 .96129 L
.6529 .96154 L
.63462 .9655 L
.61538 .96835 L
.59615 .96986 L
.57692 .97007 L
.55769 .96898 L
.53846 .96653 L
.51923 .96267 L
.51461 .96154 L
.5 .9573 L
.48077 .95027 L
.46338 .94231 L
.46154 .94136 L
.44231 .93023 L
.43182 .92308 L
.42308 .9164 L
.40874 .90385 L
.40385 .89902 L
.39092 .88462 L
.38462 .87653 L
.37692 .86538 L
.36592 .84615 L
.36538 .84509 L
.35745 .82692 L
.35116 .80769 L
.34683 .78846 L
.34615 .78436 L
.34434 .76923 L
.34357 .75 L
.34445 .73077 L
.34615 .71406 L
.34694 .71154 L
.35103 .69231 L
.3567 .67308 L
.36395 .65385 L
.36538 .65048 L
.37283 .63462 L
.38333 .61538 L
.38462 .61322 L
.39552 .59615 L
.40385 .58435 L
.40943 .57692 L
.42308 .56012 L
.42517 .55769 L
.44231 .53908 L
.44292 .53846 L
.46154 .52057 L
.46302 .51923 L
.48077 .50423 L
Mistroke
.48616 .5 L
.5 .48988 L
.51374 .48077 L
.51923 .47741 L
.53846 .4668 L
.54938 .46154 L
.55769 .45797 L
.57692 .45091 L
.59615 .44558 L
.61282 .44231 L
.61538 .44198 L
Mfstroke
.4 g
.57692 .49571 m
.59615 .48981 L
.61538 .48578 L
.63462 .48366 L
.65385 .48347 L
.67308 .48531 L
.69231 .48929 L
.71154 .49559 L
.72187 .5 L
.73077 .50454 L
.75 .5166 L
.75357 .51923 L
.76923 .53258 L
.77513 .53846 L
.78846 .55399 L
.79124 .55769 L
.80368 .57692 L
.80769 .58431 L
.81332 .59615 L
.82068 .61538 L
.82608 .63462 L
.82692 .63803 L
.82973 .65385 L
.83179 .67308 L
.83233 .69231 L
.83142 .71154 L
.82906 .73077 L
.82692 .74287 L
.82523 .75 L
.81986 .76923 L
.81286 .78846 L
.80769 .80028 L
.80405 .80769 L
.79318 .82692 L
.78846 .83421 L
.77988 .84615 L
.76923 .85914 L
.76354 .86538 L
.75 .87866 L
.74317 .88462 L
.73077 .89434 L
.71679 .90385 L
.71154 .90705 L
.69231 .91733 L
.67935 .92308 L
.67308 .92552 L
.65385 .93185 L
.63462 .9365 L
.61538 .93958 L
.59615 .94113 L
.57692 .94119 L
.55769 .93973 L
.53846 .9367 L
.51923 .932 L
.5 .92545 L
.49416 .92308 L
.48077 .91679 L
.46154 .90561 L
.4589 .90385 L
.44231 .89122 L
.43494 .88462 L
.42308 .87236 L
.41724 .86538 L
.40385 .84615 L
.40385 .84615 L
.3938 .82692 L
.3865 .80769 L
.38462 .80185 L
.38161 .78846 L
.37888 .76923 L
.37817 .75 L
.37939 .73077 L
.38247 .71154 L
.38462 .70192 L
.3874 .69231 L
.39418 .67308 L
.40283 .65385 L
.40385 .65181 L
.41339 .63462 L
.42308 .61949 L
.42593 .61538 L
.44057 .59615 L
.44231 .59405 L
.4575 .57692 L
.46154 .57272 L
.4771 .55769 L
.48077 .5544 L
.5 .53852 L
.50008 .53846 L
.51923 .52484 L
.52806 .51923 L
.53846 .51319 L
.55769 .50349 L
.56566 .5 L
F
0 g
.57692 .49571 m
.59615 .48981 L
.61538 .48578 L
.63462 .48366 L
.65385 .48347 L
.67308 .48531 L
.69231 .48929 L
.71154 .49559 L
.72187 .5 L
.73077 .50454 L
.75 .5166 L
.75357 .51923 L
.76923 .53258 L
.77513 .53846 L
.78846 .55399 L
.79124 .55769 L
.80368 .57692 L
.80769 .58431 L
.81332 .59615 L
.82068 .61538 L
.82608 .63462 L
.82692 .63803 L
.82973 .65385 L
.83179 .67308 L
.83233 .69231 L
.83142 .71154 L
.82906 .73077 L
.82692 .74287 L
.82523 .75 L
.81986 .76923 L
.81286 .78846 L
.80769 .80028 L
.80405 .80769 L
.79318 .82692 L
.78846 .83421 L
.77988 .84615 L
.76923 .85914 L
.76354 .86538 L
.75 .87866 L
.74317 .88462 L
.73077 .89434 L
.71679 .90385 L
.71154 .90705 L
.69231 .91733 L
.67935 .92308 L
.67308 .92552 L
.65385 .93185 L
.63462 .9365 L
.61538 .93958 L
.59615 .94113 L
Mistroke
.57692 .94119 L
.55769 .93973 L
.53846 .9367 L
.51923 .932 L
.5 .92545 L
.49416 .92308 L
.48077 .91679 L
.46154 .90561 L
.4589 .90385 L
.44231 .89122 L
.43494 .88462 L
.42308 .87236 L
.41724 .86538 L
.40385 .84615 L
.40385 .84615 L
.3938 .82692 L
.3865 .80769 L
.38462 .80185 L
.38161 .78846 L
.37888 .76923 L
.37817 .75 L
.37939 .73077 L
.38247 .71154 L
.38462 .70192 L
.3874 .69231 L
.39418 .67308 L
.40283 .65385 L
.40385 .65181 L
.41339 .63462 L
.42308 .61949 L
.42593 .61538 L
.44057 .59615 L
.44231 .59405 L
.4575 .57692 L
.46154 .57272 L
.4771 .55769 L
.48077 .5544 L
.5 .53852 L
.50008 .53846 L
.51923 .52484 L
.52806 .51923 L
.53846 .51319 L
.55769 .50349 L
.56566 .5 L
.57692 .49571 L
Mfstroke
.5 g
.63462 .51737 m
.65385 .51736 L
.67069 .51923 L
.67308 .51964 L
.69231 .52442 L
.71154 .53202 L
.72372 .53846 L
.73077 .54295 L
.7495 .55769 L
.75 .55815 L
.76726 .57692 L
.76923 .57949 L
.78029 .59615 L
.78846 .61194 L
.78998 .61538 L
.79704 .63462 L
.80189 .65385 L
.80479 .67308 L
.8059 .69231 L
.8053 .71154 L
.80301 .73077 L
.79903 .75 L
.79326 .76923 L
.78846 .78187 L
.78556 .78846 L
.77567 .80769 L
.76923 .8182 L
.76322 .82692 L
.75 .84343 L
.74755 .84615 L
.73077 .8626 L
.72754 .86538 L
.71154 .87764 L
.70083 .88462 L
.69231 .88952 L
.67308 .89884 L
.66024 .90385 L
.65385 .90595 L
.63462 .91109 L
.61538 .9144 L
.59615 .91598 L
.57692 .91584 L
.55769 .91395 L
.53846 .91022 L
.51923 .90447 L
.51748 .90385 L
.5 .89641 L
.48077 .88555 L
.47935 .88462 L
.46154 .87104 L
.4554 .86538 L
.44231 .85111 L
.43847 .84615 L
.42621 .82692 L
.42308 .82091 L
.41751 .80769 L
.41176 .78846 L
.40858 .76923 L
.40774 .75 L
.40912 .73077 L
.41262 .71154 L
.41823 .69231 L
.42308 .67954 L
.42595 .67308 L
.43583 .65385 L
.44231 .6431 L
.44796 .63462 L
.46154 .61656 L
.4625 .61538 L
.47976 .59615 L
.48077 .59512 L
.5 .57717 L
.50028 .57692 L
.51923 .56198 L
.52529 .55769 L
.53846 .5492 L
.55769 .53863 L
.55804 .53846 L
.57692 .5302 L
.59615 .52384 L
.61538 .51955 L
.61736 .51923 L
F
0 g
.63462 .51737 m
.65385 .51736 L
.67069 .51923 L
.67308 .51964 L
.69231 .52442 L
.71154 .53202 L
.72372 .53846 L
.73077 .54295 L
.7495 .55769 L
.75 .55815 L
.76726 .57692 L
.76923 .57949 L
.78029 .59615 L
.78846 .61194 L
.78998 .61538 L
.79704 .63462 L
.80189 .65385 L
.80479 .67308 L
.8059 .69231 L
.8053 .71154 L
.80301 .73077 L
.79903 .75 L
.79326 .76923 L
.78846 .78187 L
.78556 .78846 L
.77567 .80769 L
.76923 .8182 L
.76322 .82692 L
.75 .84343 L
.74755 .84615 L
.73077 .8626 L
.72754 .86538 L
.71154 .87764 L
.70083 .88462 L
.69231 .88952 L
.67308 .89884 L
.66024 .90385 L
.65385 .90595 L
.63462 .91109 L
.61538 .9144 L
.59615 .91598 L
.57692 .91584 L
.55769 .91395 L
.53846 .91022 L
.51923 .90447 L
.51748 .90385 L
.5 .89641 L
.48077 .88555 L
.47935 .88462 L
.46154 .87104 L
Mistroke
.4554 .86538 L
.44231 .85111 L
.43847 .84615 L
.42621 .82692 L
.42308 .82091 L
.41751 .80769 L
.41176 .78846 L
.40858 .76923 L
.40774 .75 L
.40912 .73077 L
.41262 .71154 L
.41823 .69231 L
.42308 .67954 L
.42595 .67308 L
.43583 .65385 L
.44231 .6431 L
.44796 .63462 L
.46154 .61656 L
.4625 .61538 L
.47976 .59615 L
.48077 .59512 L
.5 .57717 L
.50028 .57692 L
.51923 .56198 L
.52529 .55769 L
.53846 .5492 L
.55769 .53863 L
.55804 .53846 L
.57692 .5302 L
.59615 .52384 L
.61538 .51955 L
.61736 .51923 L
.63462 .51737 L
Mfstroke
.6 g
.59615 .55331 m
.61538 .54883 L
.63462 .54669 L
.65385 .54702 L
.67308 .55 L
.69231 .55595 L
.69665 .55769 L
.71154 .56542 L
.72784 .57692 L
.73077 .57944 L
.74687 .59615 L
.75 .60015 L
.76005 .61538 L
.76923 .63428 L
.76937 .63462 L
.77574 .65385 L
.77967 .67308 L
.78143 .69231 L
.78117 .71154 L
.77896 .73077 L
.77477 .75 L
.76923 .76734 L
.76848 .76923 L
.75988 .78846 L
.75 .80556 L
.74859 .80769 L
.73395 .82692 L
.73077 .83051 L
.71476 .84615 L
.71154 .84888 L
.69231 .8629 L
.68833 .86538 L
.67308 .87363 L
.65385 .88167 L
.64521 .88462 L
.63462 .88738 L
.61538 .89098 L
.59615 .89256 L
.57692 .89216 L
.55769 .8897 L
.53846 .88505 L
.53703 .88462 L
.51923 .87788 L
.5 .86765 L
.49649 .86538 L
.48077 .85334 L
.47322 .84615 L
.46154 .83256 L
.45756 .82692 L
.44683 .80769 L
.44231 .79686 L
.43984 .78846 L
.43596 .76923 L
.43483 .75 L
.43624 .73077 L
.44008 .71154 L
.44231 .70339 L
.44632 .69231 L
.45497 .67308 L
.46154 .66121 L
.46615 .65385 L
.48005 .63462 L
.48077 .63372 L
.49705 .61538 L
.5 .61241 L
.51793 .59615 L
.51923 .59509 L
.53846 .58085 L
.54449 .57692 L
.55769 .56927 L
.57692 .56012 L
.58281 .55769 L
F
0 g
.59615 .55331 m
.61538 .54883 L
.63462 .54669 L
.65385 .54702 L
.67308 .55 L
.69231 .55595 L
.69665 .55769 L
.71154 .56542 L
.72784 .57692 L
.73077 .57944 L
.74687 .59615 L
.75 .60015 L
.76005 .61538 L
.76923 .63428 L
.76937 .63462 L
.77574 .65385 L
.77967 .67308 L
.78143 .69231 L
.78117 .71154 L
.77896 .73077 L
.77477 .75 L
.76923 .76734 L
.76848 .76923 L
.75988 .78846 L
.75 .80556 L
.74859 .80769 L
.73395 .82692 L
.73077 .83051 L
.71476 .84615 L
.71154 .84888 L
.69231 .8629 L
.68833 .86538 L
.67308 .87363 L
.65385 .88167 L
.64521 .88462 L
.63462 .88738 L
.61538 .89098 L
.59615 .89256 L
.57692 .89216 L
.55769 .8897 L
.53846 .88505 L
.53703 .88462 L
.51923 .87788 L
.5 .86765 L
.49649 .86538 L
.48077 .85334 L
.47322 .84615 L
.46154 .83256 L
.45756 .82692 L
.44683 .80769 L
Mistroke
.44231 .79686 L
.43984 .78846 L
.43596 .76923 L
.43483 .75 L
.43624 .73077 L
.44008 .71154 L
.44231 .70339 L
.44632 .69231 L
.45497 .67308 L
.46154 .66121 L
.46615 .65385 L
.48005 .63462 L
.48077 .63372 L
.49705 .61538 L
.5 .61241 L
.51793 .59615 L
.51923 .59509 L
.53846 .58085 L
.54449 .57692 L
.55769 .56927 L
.57692 .56012 L
.58281 .55769 L
.59615 .55331 L
Mfstroke
.7 g
.61538 .57611 m
.63462 .57412 L
.65385 .57499 L
.66507 .57692 L
.67308 .579 L
.69231 .58673 L
.70761 .59615 L
.71154 .59925 L
.72787 .61538 L
.73077 .61902 L
.74092 .63462 L
.74953 .65385 L
.75 .65497 L
.75488 .67308 L
.75751 .69231 L
.75769 .71154 L
.75556 .73077 L
.75108 .75 L
.75 .75367 L
.7441 .76923 L
.73427 .78846 L
.73077 .79413 L
.72095 .80769 L
.71154 .81847 L
.70288 .82692 L
.69231 .83573 L
.67701 .84615 L
.67308 .84843 L
.65385 .85771 L
.63462 .86414 L
.63166 .86538 L
.61538 .86806 L
.59615 .86962 L
.57692 .86884 L
.55769 .86559 L
.55674 .86538 L
.53846 .85961 L
.51923 .85025 L
.51271 .84615 L
.5 .83634 L
.4905 .82692 L
.48077 .81464 L
.47646 .80769 L
.46758 .78846 L
.46264 .76923 L
.46154 .76076 L
.461 .75 L
.46154 .73752 L
.46233 .73077 L
.46646 .71154 L
.47336 .69231 L
.48077 .67709 L
.4831 .67308 L
.49589 .65385 L
.5 .64853 L
.51219 .63462 L
.51923 .62756 L
.53303 .61538 L
.53846 .61114 L
.55769 .59815 L
.56105 .59615 L
.57692 .5881 L
.59615 .58078 L
.60979 .57692 L
F
0 g
.61538 .57611 m
.63462 .57412 L
.65385 .57499 L
.66507 .57692 L
.67308 .579 L
.69231 .58673 L
.70761 .59615 L
.71154 .59925 L
.72787 .61538 L
.73077 .61902 L
.74092 .63462 L
.74953 .65385 L
.75 .65497 L
.75488 .67308 L
.75751 .69231 L
.75769 .71154 L
.75556 .73077 L
.75108 .75 L
.75 .75367 L
.7441 .76923 L
.73427 .78846 L
.73077 .79413 L
.72095 .80769 L
.71154 .81847 L
.70288 .82692 L
.69231 .83573 L
.67701 .84615 L
.67308 .84843 L
.65385 .85771 L
.63462 .86414 L
.63166 .86538 L
.61538 .86806 L
.59615 .86962 L
.57692 .86884 L
.55769 .86559 L
.55674 .86538 L
.53846 .85961 L
.51923 .85025 L
.51271 .84615 L
.5 .83634 L
.4905 .82692 L
.48077 .81464 L
.47646 .80769 L
.46758 .78846 L
.46264 .76923 L
.46154 .76076 L
.461 .75 L
.46154 .73752 L
.46233 .73077 L
.46646 .71154 L
Mistroke
.47336 .69231 L
.48077 .67709 L
.4831 .67308 L
.49589 .65385 L
.5 .64853 L
.51219 .63462 L
.51923 .62756 L
.53303 .61538 L
.53846 .61114 L
.55769 .59815 L
.56105 .59615 L
.57692 .5881 L
.59615 .58078 L
.60979 .57692 L
.61538 .57611 L
Mfstroke
.8 g
.59615 .60804 m
.61538 .60316 L
.63462 .60146 L
.65385 .60319 L
.67308 .60889 L
.68617 .61538 L
.69231 .61973 L
.70832 .63462 L
.71154 .6386 L
.72115 .65385 L
.7288 .67308 L
.73077 .6808 L
.73274 .69231 L
.73358 .71154 L
.73156 .73077 L
.73077 .73612 L
.72668 .75 L
.71867 .76923 L
.71154 .78181 L
.70693 .78846 L
.69231 .80555 L
.69011 .80769 L
.67308 .82155 L
.6648 .82692 L
.65385 .83268 L
.63462 .84014 L
.61538 .84448 L
.59615 .84596 L
.57692 .84458 L
.55769 .84009 L
.53846 .83182 L
.53033 .82692 L
.51923 .81831 L
.50909 .80769 L
.5 .79472 L
.49687 .78846 L
.49014 .76923 L
.48764 .75 L
.48873 .73077 L
.49316 .71154 L
.5 .69394 L
.5009 .69231 L
.51211 .67308 L
.51923 .66335 L
.52736 .65385 L
.53846 .64274 L
.54797 .63462 L
.55769 .62746 L
.57692 .61608 L
.5782 .61538 L
F
0 g
.59615 .60804 m
.61538 .60316 L
.63462 .60146 L
.65385 .60319 L
.67308 .60889 L
.68617 .61538 L
.69231 .61973 L
.70832 .63462 L
.71154 .6386 L
.72115 .65385 L
.7288 .67308 L
.73077 .6808 L
.73274 .69231 L
.73358 .71154 L
.73156 .73077 L
.73077 .73612 L
.72668 .75 L
.71867 .76923 L
.71154 .78181 L
.70693 .78846 L
.69231 .80555 L
.69011 .80769 L
.67308 .82155 L
.6648 .82692 L
.65385 .83268 L
.63462 .84014 L
.61538 .84448 L
.59615 .84596 L
.57692 .84458 L
.55769 .84009 L
.53846 .83182 L
.53033 .82692 L
.51923 .81831 L
.50909 .80769 L
.5 .79472 L
.49687 .78846 L
.49014 .76923 L
.48764 .75 L
.48873 .73077 L
.49316 .71154 L
.5 .69394 L
.5009 .69231 L
.51211 .67308 L
.51923 .66335 L
.52736 .65385 L
.53846 .64274 L
.54797 .63462 L
.55769 .62746 L
.57692 .61608 L
.5782 .61538 L
Mistroke
.59615 .60804 L
Mfstroke
.9 g
.61538 .63204 m
.63462 .63088 L
.65385 .63426 L
.6553 .63462 L
.67308 .64336 L
.68554 .65385 L
.69231 .6622 L
.69848 .67308 L
.705 .69231 L
.70701 .71154 L
.70522 .73077 L
.69964 .75 L
.69231 .76547 L
.68979 .76923 L
.67413 .78846 L
.67308 .78948 L
.65385 .80428 L
.64833 .80769 L
.63462 .81349 L
.61538 .81853 L
.59615 .81981 L
.57692 .81729 L
.55769 .81019 L
.553 .80769 L
.53846 .79661 L
.5314 .78846 L
.52097 .76923 L
.51923 .76365 L
.51677 .75 L
.51733 .73077 L
.51923 .72111 L
.52211 .71154 L
.53116 .69231 L
.53846 .68113 L
.54506 .67308 L
.55769 .66044 L
.56575 .65385 L
.57692 .64648 L
.59615 .63722 L
.60412 .63462 L
F
0 g
.61538 .63204 m
.63462 .63088 L
.65385 .63426 L
.6553 .63462 L
.67308 .64336 L
.68554 .65385 L
.69231 .6622 L
.69848 .67308 L
.705 .69231 L
.70701 .71154 L
.70522 .73077 L
.69964 .75 L
.69231 .76547 L
.68979 .76923 L
.67413 .78846 L
.67308 .78948 L
.65385 .80428 L
.64833 .80769 L
.63462 .81349 L
.61538 .81853 L
.59615 .81981 L
.57692 .81729 L
.55769 .81019 L
.553 .80769 L
.53846 .79661 L
.5314 .78846 L
.52097 .76923 L
.51923 .76365 L
.51677 .75 L
.51733 .73077 L
.51923 .72111 L
.52211 .71154 L
.53116 .69231 L
.53846 .68113 L
.54506 .67308 L
.55769 .66044 L
.56575 .65385 L
.57692 .64648 L
.59615 .63722 L
.60412 .63462 L
.61538 .63204 L
s
1 g
.61538 .66725 m
.63462 .66755 L
.64913 .67308 L
.65385 .67556 L
.66802 .69231 L
.67302 .71154 L
.67198 .73077 L
.66492 .75 L
.65385 .7654 L
.64995 .76923 L
.63462 .77933 L
.61538 .78582 L
.59615 .7864 L
.57692 .78064 L
.56272 .76923 L
.55769 .76052 L
.55361 .75 L
.55257 .73077 L
.55769 .71283 L
.55822 .71154 L
.57075 .69231 L
.57692 .68607 L
.59615 .67336 L
.5968 .67308 L
F
0 g
.61538 .66725 m
.63462 .66755 L
.64913 .67308 L
.65385 .67556 L
.66802 .69231 L
.67302 .71154 L
.67198 .73077 L
.66492 .75 L
.65385 .7654 L
.64995 .76923 L
.63462 .77933 L
.61538 .78582 L
.59615 .7864 L
.57692 .78064 L
.56272 .76923 L
.55769 .76052 L
.55361 .75 L
.55257 .73077 L
.55769 .71283 L
.55822 .71154 L
.57075 .69231 L
.57692 .68607 L
.59615 .67336 L
.5968 .67308 L
.61538 .66725 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .746 .916 r
.39901 .59822 .40512 .60371 .41536 .60078 .40928 .59528 Mtetra
.657 .747 .916 r
.40928 .59528 .41536 .60078 .42564 .59784 .41958 .59235 Mtetra
.656 .747 .917 r
.41958 .59235 .42564 .59784 .43596 .59492 .42992 .58943 Mtetra
.655 .748 .918 r
.42992 .58943 .43596 .59492 .44632 .592 .44031 .58652 Mtetra
.653 .749 .92 r
.44031 .58652 .44632 .592 .45672 .58911 .45073 .58364 Mtetra
.651 .749 .922 r
.45073 .58364 .45672 .58911 .46716 .58625 .4612 .58081 Mtetra
.647 .75 .924 r
.4612 .58081 .46716 .58625 .47764 .58344 .4717 .57805 Mtetra
.643 .751 .928 r
.4717 .57805 .47764 .58344 .48816 .58071 .48225 .57538 Mtetra
.636 .753 .932 r
.48225 .57538 .48816 .58071 .49873 .57808 .49284 .57284 Mtetra
.628 .754 .938 r
.49284 .57284 .49873 .57808 .50933 .57558 .50348 .57047 Mtetra
.617 .756 .945 r
.50348 .57047 .50933 .57558 .51999 .57324 .51416 .5683 Mtetra
.601 .759 .954 r
.51416 .5683 .51999 .57324 .53069 .57109 .52489 .56637 Mtetra
.581 .762 .965 r
.52489 .56637 .53069 .57109 .54144 .56919 .53567 .56475 Mtetra
.554 .765 .976 r
.53567 .56475 .54144 .56919 .55224 .56754 .5465 .56345 Mtetra
.516 .767 .987 r
.5465 .56345 .55224 .56754 .5631 .56618 .5574 .56252 Mtetra
.466 .765 .995 r
.5574 .56252 .5631 .56618 .57402 .56512 .56836 .56196 Mtetra
.398 .756 .993 r
.56836 .56196 .57402 .56512 .585 .56436 .57938 .56179 Mtetra
.307 .733 .972 r
.57938 .56179 .585 .56436 .59605 .56388 .59048 .56198 Mtetra
.193 .688 .918 r
.59048 .56198 .59605 .56388 .60716 .56365 .60165 .56248 Mtetra
.064 .617 .824 r
.60165 .56248 .60716 .56365 .61835 .5636 .61289 .56322 Mtetra
.063 0 0 r
.61289 .56322 .61835 .5636 .6296 .56365 .62421 .56411 Mtetra
.169 0 0 r
.62421 .56411 .6296 .56365 .64092 .56373 .63561 .56503 Mtetra
.246 0 0 r
.63561 .56503 .64092 .56373 .65231 .5637 .64708 .56585 Mtetra
.294 0 0 r
.64708 .56585 .65231 .5637 .66375 .56347 .65861 .56643 Mtetra
.317 0 0 r
.65861 .56643 .66375 .56347 .67525 .56292 .6702 .56661 Mtetra
.322 0 0 r
.6702 .56661 .67525 .56292 .68679 .56192 .68184 .56626 Mtetra
.312 0 0 r
.68184 .56626 .68679 .56192 .69837 .56039 .69351 .56524 Mtetra
.29 0 0 r
.69351 .56524 .69837 .56039 .70998 .55823 .7052 .56345 Mtetra
.255 0 0 r
.7052 .56345 .70998 .55823 .7216 .5554 .71691 .56082 Mtetra
.208 0 0 r
.71691 .56082 .7216 .5554 .73323 .55186 .72862 .5573 Mtetra
.149 0 0 r
.72862 .5573 .73323 .55186 .74486 .54761 .74031 .55288 Mtetra
.074 0 0 r
.74031 .55288 .74486 .54761 .75649 .54267 .752 .5476 Mtetra
0 0 0 r
.752 .5476 .75649 .54267 .76811 .53711 .76366 .54154 Mtetra
.76366 .54154 .76811 .53711 .77972 .53101 .77531 .53478 Mtetra
.77531 .53478 .77972 .53101 .79133 .52448 .78693 .52748 Mtetra
.78693 .52748 .79133 .52448 .80294 .51762 .79855 .51976 Mtetra
.508 .886 .694 r
.79855 .51976 .80294 .51762 .81456 .51057 .81016 .51179 Mtetra
.615 .951 .793 r
.81016 .51179 .81456 .51057 .8262 .50345 .82179 .50373 Mtetra
.691 .981 .865 r
.82179 .50373 .8262 .50345 .83786 .49637 .83344 .49571 Mtetra
.736 .982 .909 r
.83344 .49571 .83786 .49637 .84957 .48942 .84512 .48787 Mtetra
.757 .964 .932 r
.84512 .48787 .84957 .48942 .86132 .48269 .85685 .4803 Mtetra
.762 .937 .941 r
.85685 .4803 .86132 .48269 .87313 .47624 .86863 .47308 Mtetra
.757 .907 .943 r
.86863 .47308 .87313 .47624 .885 .47009 .88049 .46624 Mtetra
.747 .878 .94 r
.88049 .46624 .885 .47009 .89694 .46426 .89242 .45982 Mtetra
.735 .852 .936 r
.89242 .45982 .89694 .46426 .90896 .45875 .90443 .4538 Mtetra
.723 .829 .931 r
.90443 .4538 .90896 .45875 .92105 .45354 .91651 .44816 Mtetra
.712 .811 .927 r
.91651 .44816 .92105 .45354 .93321 .44859 .92868 .44286 Mtetra
.702 .795 .923 r
.92868 .44286 .93321 .44859 .94545 .44388 .94093 .43786 Mtetra
.694 .783 .92 r
.94093 .43786 .94545 .44388 .95776 .43936 .95326 .43312 Mtetra
.687 .773 .917 r
.95326 .43312 .95776 .43936 .97014 .43501 .96566 .42858 Mtetra
.657 .747 .916 r
.39286 .59271 .39901 .59822 .40928 .59528 .40314 .58977 Mtetra
.656 .747 .917 r
.40314 .58977 .40928 .59528 .41958 .59235 .41347 .58683 Mtetra
.655 .748 .918 r
.41347 .58683 .41958 .59235 .42992 .58943 .42384 .58391 Mtetra
.653 .748 .919 r
.42384 .58391 .42992 .58943 .44031 .58652 .43425 .58102 Mtetra
.651 .749 .921 r
.43425 .58102 .44031 .58652 .45073 .58364 .4447 .57816 Mtetra
.648 .75 .923 r
.4447 .57816 .45073 .58364 .4612 .58081 .45519 .57537 Mtetra
.644 .75 .926 r
.45519 .57537 .4612 .58081 .4717 .57805 .46572 .57265 Mtetra
.639 .751 .93 r
.46572 .57265 .4717 .57805 .48225 .57538 .47629 .57006 Mtetra
.631 .753 .935 r
.47629 .57006 .48225 .57538 .49284 .57284 .48691 .56762 Mtetra
.62 .754 .942 r
.48691 .56762 .49284 .57284 .50348 .57047 .49757 .56539 Mtetra
.605 .756 .95 r
.49757 .56539 .50348 .57047 .51416 .5683 .50828 .56341 Mtetra
.586 .758 .96 r
.50828 .56341 .51416 .5683 .52489 .56637 .51904 .56173 Mtetra
.559 .759 .971 r
.51904 .56173 .52489 .56637 .53567 .56475 .52985 .56042 Mtetra
.522 .759 .983 r
.52985 .56042 .53567 .56475 .5465 .56345 .54072 .55952 Mtetra
.471 .756 .992 r
.54072 .55952 .5465 .56345 .5574 .56252 .55165 .55906 Mtetra
.399 .745 .993 r
.55165 .55906 .5574 .56252 .56836 .56196 .56264 .55908 Mtetra
.302 .718 .974 r
.56264 .55908 .56836 .56196 .57938 .56179 .57371 .55956 Mtetra
.175 .666 .921 r
.57371 .55956 .57938 .56179 .59048 .56198 .58486 .5605 Mtetra
.026 .582 .819 r
.58486 .5605 .59048 .56198 .60165 .56248 .59608 .56183 Mtetra
.122 0 0 r
.59608 .56183 .60165 .56248 .61289 .56322 .60739 .56347 Mtetra
.246 0 0 r
.60739 .56347 .61289 .56322 .62421 .56411 .61879 .56531 Mtetra
.334 0 0 r
.61879 .56531 .62421 .56411 .63561 .56503 .63026 .5672 Mtetra
.389 0 0 r
.63026 .5672 .63561 .56503 .64708 .56585 .64182 .56899 Mtetra
.416 0 0 r
.64182 .56899 .64708 .56585 .65861 .56643 .65344 .5705 Mtetra
.424 0 0 r
.65344 .5705 .65861 .56643 .6702 .56661 .66513 .57154 Mtetra
.418 0 0 r
.66513 .57154 .6702 .56661 .68184 .56626 .67687 .57194 Mtetra
.401 0 .005 r
.67687 .57194 .68184 .56626 .69351 .56524 .68864 .57154 Mtetra
.374 0 .02 r
.68864 .57154 .69351 .56524 .7052 .56345 .70043 .5702 Mtetra
.337 0 .022 r
.70043 .5702 .7052 .56345 .71691 .56082 .71223 .56782 Mtetra
.291 0 .01 r
.71223 .56782 .71691 .56082 .72862 .5573 .72403 .56436 Mtetra
.233 0 0 r
.72403 .56436 .72862 .5573 .74031 .55288 .7358 .55978 Mtetra
.163 0 0 r
.7358 .55978 .74031 .55288 .752 .5476 .74754 .55414 Mtetra
.077 0 0 r
.74754 .55414 .752 .5476 .76366 .54154 .75926 .54752 Mtetra
0 0 0 r
.75926 .54752 .76366 .54154 .77531 .53478 .77093 .54004 Mtetra
.77093 .54004 .77531 .53478 .78693 .52748 .78258 .53186 Mtetra
.78258 .53186 .78693 .52748 .79855 .51976 .7942 .52317 Mtetra
.7942 .52317 .79855 .51976 .81016 .51179 .80581 .51416 Mtetra
.562 .905 .681 r
.80581 .51416 .81016 .51179 .82179 .50373 .81741 .50502 Mtetra
.665 .967 .785 r
.81741 .50502 .82179 .50373 .83344 .49571 .82904 .49594 Mtetra
.733 .991 .858 r
.82904 .49594 .83344 .49571 .84512 .48787 .84069 .48706 Mtetra
.768 .985 .902 r
.84069 .48706 .84512 .48787 .85685 .4803 .85239 .47853 Mtetra
.779 .962 .925 r
.85239 .47853 .85685 .4803 .86863 .47308 .86415 .47042 Mtetra
.776 .931 .934 r
.86415 .47042 .86863 .47308 .88049 .46624 .87598 .4628 Mtetra
.765 .9 .936 r
.87598 .4628 .88049 .46624 .89242 .45982 .88789 .45569 Mtetra
.751 .87 .934 r
.88789 .45569 .89242 .45982 .90443 .4538 .89989 .44908 Mtetra
.737 .845 .93 r
.89989 .44908 .90443 .4538 .91651 .44816 .91197 .44295 Mtetra
.723 .823 .927 r
.91197 .44295 .91651 .44816 .92868 .44286 .92414 .43725 Mtetra
.711 .805 .923 r
.92414 .43725 .92868 .44286 .94093 .43786 .93639 .43193 Mtetra
.701 .79 .92 r
.93639 .43193 .94093 .43786 .95326 .43312 .94873 .42692 Mtetra
.692 .779 .918 r
.94873 .42692 .95326 .43312 .96566 .42858 .96115 .42217 Mtetra
.656 .747 .917 r
.38666 .58717 .39286 .59271 .40314 .58977 .39697 .58422 Mtetra
.655 .747 .918 r
.39697 .58422 .40314 .58977 .41347 .58683 .40732 .58129 Mtetra
.654 .748 .919 r
.40732 .58129 .41347 .58683 .42384 .58391 .41771 .57838 Mtetra
.652 .749 .92 r
.41771 .57838 .42384 .58391 .43425 .58102 .42815 .5755 Mtetra
.649 .749 .922 r
.42815 .5755 .43425 .58102 .4447 .57816 .43862 .57266 Mtetra
.646 .75 .925 r
.43862 .57266 .4447 .57816 .45519 .57537 .44914 .5699 Mtetra
.641 .75 .928 r
.44914 .5699 .45519 .57537 .46572 .57265 .45969 .56725 Mtetra
.634 .751 .933 r
.45969 .56725 .46572 .57265 .47629 .57006 .47029 .56473 Mtetra
.624 .752 .938 r
.47029 .56473 .47629 .57006 .48691 .56762 .48094 .56241 Mtetra
.611 .753 .946 r
.48094 .56241 .48691 .56762 .49757 .56539 .49162 .56033 Mtetra
.593 .754 .955 r
.49162 .56033 .49757 .56539 .50828 .56341 .50236 .55855 Mtetra
.568 .755 .966 r
.50236 .55855 .50828 .56341 .51904 .56173 .51314 .55715 Mtetra
.534 .754 .977 r
.51314 .55715 .51904 .56173 .52985 .56042 .52398 .55618 Mtetra
.485 .75 .988 r
.52398 .55618 .52985 .56042 .54072 .55952 .53488 .5557 Mtetra
.417 .738 .992 r
.53488 .5557 .54072 .55952 .55165 .55906 .54584 .55576 Mtetra
.321 .712 .981 r
.54584 .55576 .55165 .55906 .56264 .55908 .55688 .5564 Mtetra
.191 .661 .937 r
.55688 .5564 .56264 .55908 .57371 .55956 .56799 .5576 Mtetra
.032 .575 .843 r
.56799 .5576 .57371 .55956 .58486 .5605 .57918 .55936 Mtetra
0 .456 .696 r
.57918 .55936 .58486 .5605 .59608 .56183 .59047 .5616 Mtetra
.281 0 0 r
.59047 .5616 .59608 .56183 .60739 .56347 .60184 .56423 Mtetra
.385 0 0 r
.60184 .56423 .60739 .56347 .61879 .56531 .61331 .56711 Mtetra
.45 0 0 r
.61331 .56711 .61879 .56531 .63026 .5672 .62487 .57009 Mtetra
.484 0 0 r
.62487 .57009 .63026 .5672 .64182 .56899 .63651 .57296 Mtetra
.497 0 0 r
.63651 .57296 .64182 .56899 .65344 .5705 .64824 .57551 Mtetra
.495 .008 .028 r
.64824 .57551 .65344 .5705 .66513 .57154 .66003 .57752 Mtetra
.481 .014 .067 r
.66003 .57752 .66513 .57154 .67687 .57194 .67187 .57879 Mtetra
.459 .008 .091 r
.67187 .57879 .67687 .57194 .68864 .57154 .68375 .5791 Mtetra
.428 0 .103 r
.68375 .5791 .68864 .57154 .70043 .5702 .69565 .5783 Mtetra
.39 0 .103 r
.69565 .5783 .70043 .5702 .71223 .56782 .70756 .57625 Mtetra
.342 0 .092 r
.70756 .57625 .71223 .56782 .72403 .56436 .71944 .57288 Mtetra
.285 0 .069 r
.71944 .57288 .72403 .56436 .7358 .55978 .7313 .56817 Mtetra
.216 0 .032 r
.7313 .56817 .7358 .55978 .74754 .55414 .74311 .56216 Mtetra
.133 0 0 r
.74311 .56216 .74754 .55414 .75926 .54752 .75488 .55494 Mtetra
.032 0 0 r
.75488 .55494 .75926 .54752 .77093 .54004 .76659 .54667 Mtetra
0 0 0 r
.76659 .54667 .77093 .54004 .78258 .53186 .77826 .53754 Mtetra
.77826 .53754 .78258 .53186 .7942 .52317 .78988 .52777 Mtetra
.78988 .52777 .7942 .52317 .80581 .51416 .80148 .51761 Mtetra
.517 .852 .574 r
.80148 .51761 .80581 .51416 .81741 .50502 .81307 .50727 Mtetra
.641 .94 .7 r
.81307 .50727 .81741 .50502 .82904 .49594 .82466 .497 Mtetra
.728 .987 .797 r
.82466 .497 .82904 .49594 .84069 .48706 .83628 .48697 Mtetra
.778 .996 .862 r
.83628 .48697 .84069 .48706 .85239 .47853 .84795 .47735 Mtetra
.797 .981 .9 r
.84795 .47735 .85239 .47853 .86415 .47042 .85968 .46825 Mtetra
.797 .952 .92 r
.85968 .46825 .86415 .47042 .87598 .4628 .87147 .45975 Mtetra
.786 .92 .928 r
.87147 .45975 .87598 .4628 .88789 .45569 .88336 .45186 Mtetra
.77 .888 .929 r
.88336 .45186 .88789 .45569 .89989 .44908 .89533 .44459 Mtetra
.753 .859 .928 r
.89533 .44459 .89989 .44908 .91197 .44295 .90741 .43791 Mtetra
.736 .835 .926 r
.90741 .43791 .91197 .44295 .92414 .43725 .91957 .43176 Mtetra
.721 .814 .923 r
.91957 .43176 .92414 .43725 .93639 .43193 .93183 .42607 Mtetra
.709 .798 .92 r
.93183 .42607 .93639 .43193 .94873 .42692 .94418 .42077 Mtetra
.698 .785 .918 r
.94418 .42077 .94873 .42692 .96115 .42217 .95662 .41579 Mtetra
.655 .747 .918 r
.38041 .5816 .38666 .58717 .39697 .58422 .39075 .57866 Mtetra
.654 .748 .919 r
.39075 .57866 .39697 .58422 .40732 .58129 .40113 .57573 Mtetra
.653 .748 .92 r
.40113 .57573 .40732 .58129 .41771 .57838 .41154 .57282 Mtetra
.65 .749 .921 r
.41154 .57282 .41771 .57838 .42815 .5755 .422 .56996 Mtetra
.648 .749 .924 r
.422 .56996 .42815 .5755 .43862 .57266 .4325 .56715 Mtetra
.643 .75 .926 r
.4325 .56715 .43862 .57266 .44914 .5699 .44304 .56443 Mtetra
.637 .75 .93 r
.44304 .56443 .44914 .5699 .45969 .56725 .45362 .56183 Mtetra
.629 .751 .935 r
.45362 .56183 .45969 .56725 .47029 .56473 .46425 .5594 Mtetra
.618 .751 .941 r
.46425 .5594 .47029 .56473 .48094 .56241 .47491 .55719 Mtetra
.602 .752 .949 r
.47491 .55719 .48094 .56241 .49162 .56033 .48563 .55527 Mtetra
.58 .751 .959 r
.48563 .55527 .49162 .56033 .50236 .55855 .49639 .55371 Mtetra
.549 .75 .97 r
.49639 .55371 .50236 .55855 .51314 .55715 .5072 .55259 Mtetra
.506 .746 .981 r
.5072 .55259 .51314 .55715 .52398 .55618 .51806 .55198 Mtetra
.445 .735 .989 r
.51806 .55198 .52398 .55618 .53488 .5557 .52899 .55194 Mtetra
.358 .713 .986 r
.52899 .55194 .53488 .5557 .54584 .55576 .53999 .55255 Mtetra
.236 .669 .958 r
.53999 .55255 .54584 .55576 .55688 .5564 .55106 .55383 Mtetra
.078 .591 .885 r
.55106 .55383 .55688 .5564 .56799 .5576 .56221 .55579 Mtetra
0 .474 .754 r
.56221 .55579 .56799 .5576 .57918 .55936 .57346 .55841 Mtetra
.27 0 0 r
.57346 .55841 .57918 .55936 .59047 .5616 .5848 .56162 Mtetra
.399 0 0 r
.5848 .56162 .59047 .5616 .60184 .56423 .59624 .5653 Mtetra
.482 0 0 r
.59624 .5653 .60184 .56423 .61331 .56711 .60778 .56931 Mtetra
.528 0 0 r
.60778 .56931 .61331 .56711 .62487 .57009 .61942 .57344 Mtetra
.549 .032 0 r
.61942 .57344 .62487 .57009 .63651 .57296 .63115 .57749 Mtetra
.552 .061 .044 r
.63115 .57749 .63651 .57296 .64824 .57551 .64298 .58118 Mtetra
.543 .075 .092 r
.64298 .58118 .64824 .57551 .66003 .57752 .65488 .58428 Mtetra
.525 .075 .124 r
.65488 .58428 .66003 .57752 .67187 .57879 .66683 .58651 Mtetra
.499 .064 .144 r
.66683 .58651 .67187 .57879 .68375 .5791 .67883 .58763 Mtetra
.465 .043 .153 r
.67883 .58763 .68375 .5791 .69565 .5783 .69084 .58745 Mtetra
.424 .013 .153 r
.69084 .58745 .69565 .5783 .70756 .57625 .70285 .5858 Mtetra
.375 0 .142 r
.70285 .5858 .70756 .57625 .71944 .57288 .71484 .58259 Mtetra
.315 0 .12 r
.71484 .58259 .71944 .57288 .7313 .56817 .72679 .57777 Mtetra
.245 0 .085 r
.72679 .57777 .7313 .56817 .74311 .56216 .73867 .5714 Mtetra
.161 0 .036 r
.73867 .5714 .74311 .56216 .75488 .55494 .7505 .56357 Mtetra
.06 0 0 r
.7505 .56357 .75488 .55494 .76659 .54667 .76225 .55448 Mtetra
0 0 0 r
.76225 .55448 .76659 .54667 .77826 .53754 .77394 .54434 Mtetra
.77394 .54434 .77826 .53754 .78988 .52777 .78558 .53342 Mtetra
.78558 .53342 .78988 .52777 .80148 .51761 .79717 .522 Mtetra
.79717 .522 .80148 .51761 .81307 .50727 .80873 .51037 Mtetra
.628 .913 .626 r
.80873 .51037 .81307 .50727 .82466 .497 .8203 .4988 Mtetra
.728 .975 .738 r
.8203 .4988 .82466 .497 .83628 .48697 .83188 .48752 Mtetra
.789 .999 .818 r
.83188 .48752 .83628 .48697 .84795 .47735 .84351 .47671 Mtetra
.815 .992 .87 r
.84351 .47671 .84795 .47735 .85968 .46825 .8552 .46653 Mtetra
.818 .968 .9 r
.8552 .46653 .85968 .46825 .87147 .45975 .86696 .45705 Mtetra
.807 .936 .915 r
.86696 .45705 .87147 .45975 .88336 .45186 .87882 .44831 Mtetra
.789 .903 .922 r
.87882 .44831 .88336 .45186 .89533 .44459 .89077 .44032 Mtetra
.769 .873 .923 r
.89077 .44032 .89533 .44459 .90741 .43791 .90283 .43302 Mtetra
.75 .846 .923 r
.90283 .43302 .90741 .43791 .91957 .43176 .91499 .42637 Mtetra
.732 .823 .921 r
.91499 .42637 .91957 .43176 .93183 .42607 .92725 .42027 Mtetra
.718 .805 .919 r
.92725 .42027 .93183 .42607 .94418 .42077 .93961 .41465 Mtetra
.705 .79 .917 r
.93961 .41465 .94418 .42077 .95662 .41579 .95206 .40942 Mtetra
.654 .747 .918 r
.37412 .576 .38041 .5816 .39075 .57866 .38448 .57306 Mtetra
.653 .748 .919 r
.38448 .57306 .39075 .57866 .40113 .57573 .39488 .57013 Mtetra
.651 .748 .921 r
.39488 .57013 .40113 .57573 .41154 .57282 .40532 .56724 Mtetra
.649 .749 .922 r
.40532 .56724 .41154 .57282 .422 .56996 .41581 .56439 Mtetra
.646 .749 .925 r
.41581 .56439 .422 .56996 .4325 .56715 .42633 .56161 Mtetra
.641 .75 .928 r
.42633 .56161 .4325 .56715 .44304 .56443 .4369 .55893 Mtetra
.634 .75 .932 r
.4369 .55893 .44304 .56443 .45362 .56183 .4475 .55639 Mtetra
.624 .75 .937 r
.4475 .55639 .45362 .56183 .46425 .5594 .45815 .55404 Mtetra
.611 .75 .944 r
.45815 .55404 .46425 .5594 .47491 .55719 .46884 .55195 Mtetra
.593 .749 .952 r
.46884 .55195 .47491 .55719 .48563 .55527 .47958 .5502 Mtetra
.567 .748 .962 r
.47958 .5502 .48563 .55527 .49639 .55371 .49037 .54885 Mtetra
.53 .743 .973 r
.49037 .54885 .49639 .55371 .5072 .55259 .5012 .54801 Mtetra
.478 .735 .983 r
.5012 .54801 .5072 .55259 .51806 .55198 .5121 .54776 Mtetra
.404 .717 .987 r
.5121 .54776 .51806 .55198 .52899 .55194 .52305 .54817 Mtetra
.299 .683 .975 r
.52305 .54817 .52899 .55194 .53999 .55255 .53408 .54933 Mtetra
.155 .619 .93 r
.53408 .54933 .53999 .55255 .55106 .55383 .54519 .55126 Mtetra
0 .517 .83 r
.54519 .55126 .55106 .55383 .56221 .55579 .55638 .554 Mtetra
.211 0 0 r
.55638 .554 .56221 .55579 .57346 .55841 .56767 .55749 Mtetra
.37 0 0 r
.56767 .55749 .57346 .55841 .5848 .56162 .57906 .56169 Mtetra
.482 0 0 r
.57906 .56169 .5848 .56162 .59624 .5653 .59056 .56646 Mtetra
.549 0 0 r
.59056 .56646 .59624 .5653 .60778 .56931 .60217 .57162 Mtetra
.583 .051 0 r
.60217 .57162 .60778 .56931 .61942 .57344 .6139 .57697 Mtetra
.596 .092 .025 r
.6139 .57697 .61942 .57344 .63115 .57749 .62572 .58225 Mtetra
.593 .113 .084 r
.62572 .58225 .63115 .57749 .64298 .58118 .63765 .58716 Mtetra
.58 .121 .127 r
.63765 .58716 .64298 .58118 .65488 .58428 .64965 .59141 Mtetra
.558 .116 .155 r
.64965 .59141 .65488 .58428 .66683 .58651 .66172 .59468 Mtetra
.529 .101 .172 r
.66172 .59468 .66683 .58651 .67883 .58763 .67384 .59671 Mtetra
.492 .077 .18 r
.67384 .59671 .67883 .58763 .69084 .58745 .68597 .59723 Mtetra
.448 .043 .178 r
.68597 .59723 .69084 .58745 .70285 .5858 .69809 .59606 Mtetra
.394 0 .167 r
.69809 .59606 .70285 .5858 .71484 .58259 .71019 .59306 Mtetra
.331 0 .145 r
.71019 .59306 .71484 .58259 .72679 .57777 .72223 .58819 Mtetra
.256 0 .111 r
.72223 .58819 .72679 .57777 .73867 .5714 .7342 .58149 Mtetra
.166 0 .064 r
.7342 .58149 .73867 .5714 .7505 .56357 .74609 .57308 Mtetra
.061 0 0 r
.74609 .57308 .7505 .56357 .76225 .55448 .7579 .56315 Mtetra
0 0 0 r
.7579 .56315 .76225 .55448 .77394 .54434 .76961 .55197 Mtetra
.76961 .55197 .77394 .54434 .78558 .53342 .78126 .53985 Mtetra
.78126 .53985 .78558 .53342 .79717 .522 .79284 .52713 Mtetra
.79284 .52713 .79717 .522 .80873 .51037 .80439 .51413 Mtetra
.637 .897 .576 r
.80439 .51413 .80873 .51037 .8203 .4988 .81593 .50119 Mtetra
.74 .966 .691 r
.81593 .50119 .8203 .4988 .83188 .48752 .82747 .48857 Mtetra
.804 .997 .779 r
.82747 .48857 .83188 .48752 .84351 .47671 .83906 .4765 Mtetra
.834 .997 .839 r
.83906 .4765 .84351 .47671 .8552 .46653 .85071 .46515 Mtetra
.839 .977 .877 r
.85071 .46515 .8552 .46653 .86696 .45705 .86244 .45463 Mtetra
.828 .948 .9 r
.86244 .45463 .86696 .45705 .87882 .44831 .87426 .44499 Mtetra
.808 .916 .911 r
.87426 .44499 .87882 .44831 .89077 .44032 .88619 .43621 Mtetra
.786 .884 .917 r
.88619 .43621 .89077 .44032 .90283 .43302 .89822 .42826 Mtetra
.764 .856 .918 r
.89822 .42826 .90283 .43302 .91499 .42637 .91037 .42107 Mtetra
.744 .832 .918 r
.91037 .42107 .91499 .42637 .92725 .42027 .92263 .41454 Mtetra
.727 .812 .918 r
.92263 .41454 .92725 .42027 .93961 .41465 .935 .40857 Mtetra
.712 .796 .916 r
.935 .40857 .93961 .41465 .95206 .40942 .94747 .40306 Mtetra
.653 .748 .919 r
.36778 .57037 .37412 .576 .38448 .57306 .37817 .56743 Mtetra
.652 .748 .92 r
.37817 .56743 .38448 .57306 .39488 .57013 .38859 .56451 Mtetra
.65 .749 .922 r
.38859 .56451 .39488 .57013 .40532 .56724 .39906 .56163 Mtetra
.647 .749 .923 r
.39906 .56163 .40532 .56724 .41581 .56439 .40957 .55879 Mtetra
.644 .749 .926 r
.40957 .55879 .41581 .56439 .42633 .56161 .42012 .55604 Mtetra
.638 .749 .929 r
.42012 .55604 .42633 .56161 .4369 .55893 .43071 .55339 Mtetra
.631 .749 .933 r
.43071 .55339 .4369 .55893 .4475 .55639 .44134 .55091 Mtetra
.62 .749 .939 r
.44134 .55091 .4475 .55639 .45815 .55404 .45201 .54865 Mtetra
.605 .748 .946 r
.45201 .54865 .45815 .55404 .46884 .55195 .46273 .54668 Mtetra
.583 .746 .954 r
.46273 .54668 .46884 .55195 .47958 .5502 .47349 .54507 Mtetra
.554 .743 .964 r
.47349 .54507 .47958 .5502 .49037 .54885 .4843 .54394 Mtetra
.512 .736 .975 r
.4843 .54394 .49037 .54885 .5012 .54801 .49516 .54337 Mtetra
.452 .722 .983 r
.49516 .54337 .5012 .54801 .5121 .54776 .50608 .54346 Mtetra
.366 .697 .983 r
.50608 .54346 .5121 .54776 .52305 .54817 .51706 .54431 Mtetra
.246 .65 .962 r
.51706 .54431 .52305 .54817 .53408 .54933 .52812 .54599 Mtetra
.086 .57 .902 r
.52812 .54599 .53408 .54933 .54519 .55126 .53926 .54856 Mtetra
0 .451 .785 r
.53926 .54856 .54519 .55126 .55638 .554 .55049 .55204 Mtetra
.289 0 0 r
.55049 .55204 .55638 .554 .56767 .55749 .56182 .5564 Mtetra
.438 0 0 r
.56182 .5564 .56767 .55749 .57906 .56169 .57326 .56157 Mtetra
.537 0 0 r
.57326 .56157 .57906 .56169 .59056 .56646 .58482 .56741 Mtetra
.595 .041 0 r
.58482 .56741 .59056 .56646 .60217 .57162 .59649 .57373 Mtetra
.623 .098 0 r
.59649 .57373 .60217 .57162 .6139 .57697 .60829 .5803 Mtetra
.632 .132 .045 r
.60829 .5803 .6139 .57697 .62572 .58225 .62021 .58683 Mtetra
.626 .148 .099 r
.62021 .58683 .62572 .58225 .63765 .58716 .63223 .59299 Mtetra
.61 .151 .138 r
.63223 .59299 .63765 .58716 .64965 .59141 .64434 .59843 Mtetra
.586 .143 .164 r
.64434 .59843 .64965 .59141 .66172 .59468 .65652 .60281 Mtetra
.553 .124 .18 r
.65652 .60281 .66172 .59468 .67384 .59671 .66876 .6058 Mtetra
.513 .096 .186 r
.66876 .6058 .67384 .59671 .68597 .59723 .68101 .60711 Mtetra
.463 .057 .183 r
.68101 .60711 .68597 .59723 .69809 .59606 .69325 .60649 Mtetra
.404 .008 .171 r
.69325 .60649 .69809 .59606 .71019 .59306 .70546 .60378 Mtetra
.334 0 .148 r
.70546 .60378 .71019 .59306 .72223 .58819 .7176 .59893 Mtetra
.25 0 .113 r
.7176 .59893 .72223 .58819 .7342 .58149 .72966 .59196 Mtetra
.152 0 .063 r
.72966 .59196 .7342 .58149 .74609 .57308 .74163 .58299 Mtetra
.037 0 0 r
.74163 .58299 .74609 .57308 .7579 .56315 .75348 .57226 Mtetra
0 0 0 r
.75348 .57226 .7579 .56315 .76961 .55197 .76524 .56005 Mtetra
.76524 .56005 .76961 .55197 .78126 .53985 .7769 .54673 Mtetra
.7769 .54673 .78126 .53985 .79284 .52713 .78848 .53268 Mtetra
.78848 .53268 .79284 .52713 .80439 .51413 .80002 .5183 Mtetra
.669 .899 .554 r
.80002 .5183 .80439 .51413 .81593 .50119 .81152 .50394 Mtetra
.766 .963 .663 r
.81152 .50394 .81593 .50119 .82747 .48857 .82304 .48994 Mtetra
.827 .994 .749 r
.82304 .48994 .82747 .48857 .83906 .4765 .83458 .47657 Mtetra
.856 .997 .812 r
.83458 .47657 .83906 .4765 .85071 .46515 .84619 .46402 Mtetra
.86 .981 .855 r
.84619 .46402 .85071 .46515 .86244 .45463 .85788 .45241 Mtetra
.848 .954 .882 r
.85788 .45241 .86244 .45463 .87426 .44499 .86967 .44181 Mtetra
.827 .923 .898 r
.86967 .44181 .87426 .44499 .88619 .43621 .88157 .43222 Mtetra
.803 .893 .908 r
.88157 .43222 .88619 .43621 .89822 .42826 .89359 .42359 Mtetra
.779 .864 .912 r
.89359 .42359 .89822 .42826 .91037 .42107 .90573 .41583 Mtetra
.756 .839 .914 r
.90573 .41583 .91037 .42107 .92263 .41454 .91799 .40884 Mtetra
.736 .818 .915 r
.91799 .40884 .92263 .41454 .935 .40857 .93036 .4025 Mtetra
.72 .801 .915 r
.93036 .4025 .935 .40857 .94747 .40306 .94284 .3967 Mtetra
.652 .748 .92 r
.3614 .56472 .36778 .57037 .37817 .56743 .37181 .56178 Mtetra
.651 .748 .921 r
.37181 .56178 .37817 .56743 .38859 .56451 .38226 .55886 Mtetra
.649 .749 .922 r
.38226 .55886 .38859 .56451 .39906 .56163 .39275 .55598 Mtetra
.646 .749 .924 r
.39275 .55598 .39906 .56163 .40957 .55879 .40328 .55316 Mtetra
.642 .749 .927 r
.40328 .55316 .40957 .55879 .42012 .55604 .41385 .55043 Mtetra
.636 .749 .93 r
.41385 .55043 .42012 .55604 .43071 .55339 .42447 .54782 Mtetra
.627 .749 .934 r
.42447 .54782 .43071 .55339 .44134 .55091 .43512 .5454 Mtetra
.615 .748 .94 r
.43512 .5454 .44134 .55091 .45201 .54865 .44582 .54321 Mtetra
.599 .746 .947 r
.44582 .54321 .45201 .54865 .46273 .54668 .45656 .54134 Mtetra
.575 .743 .956 r
.45656 .54134 .46273 .54668 .47349 .54507 .46735 .53988 Mtetra
.542 .737 .966 r
.46735 .53988 .47349 .54507 .4843 .54394 .47818 .53893 Mtetra
.495 .727 .975 r
.47818 .53893 .4843 .54394 .49516 .54337 .48907 .5386 Mtetra
.429 .709 .982 r
.48907 .5386 .49516 .54337 .50608 .54346 .50001 .53901 Mtetra
.335 .676 .977 r
.50001 .53901 .50608 .54346 .51706 .54431 .51102 .54025 Mtetra
.205 .619 .95 r
.51102 .54025 .51706 .54431 .52812 .54599 .5221 .54243 Mtetra
.036 .528 .88 r
.5221 .54243 .52812 .54599 .53926 .54856 .53327 .54558 Mtetra
0 .4 .756 r
.53327 .54558 .53926 .54856 .55049 .55204 .54453 .54976 Mtetra
.337 0 0 r
.54453 .54976 .55049 .55204 .56182 .5564 .5559 .55492 Mtetra
.478 0 0 r
.5559 .55492 .56182 .5564 .57326 .56157 .56739 .561 Mtetra
.572 0 0 r
.56739 .561 .57326 .56157 .58482 .56741 .579 .56785 Mtetra
.626 .074 0 r
.579 .56785 .58482 .56741 .59649 .57373 .59073 .57528 Mtetra
.653 .126 0 r
.59073 .57528 .59649 .57373 .60829 .5803 .6026 .58303 Mtetra
.66 .157 .038 r
.6026 .58303 .60829 .5803 .62021 .58683 .6146 .59078 Mtetra
.654 .17 .091 r
.6146 .59078 .62021 .58683 .63223 .59299 .62671 .59816 Mtetra
.637 .17 .128 r
.62671 .59816 .63223 .59299 .64434 .59843 .63892 .60481 Mtetra
.61 .158 .153 r
.63892 .60481 .64434 .59843 .65652 .60281 .65121 .61032 Mtetra
.574 .135 .168 r
.65121 .61032 .65652 .60281 .66876 .6058 .66356 .61431 Mtetra
.529 .101 .173 r
.66356 .61431 .66876 .6058 .68101 .60711 .67593 .61645 Mtetra
.473 .057 .168 r
.67593 .61645 .68101 .60711 .69325 .60649 .68829 .61646 Mtetra
.406 0 .153 r
.68829 .61646 .69325 .60649 .70546 .60378 .70061 .61413 Mtetra
.324 0 .127 r
.70061 .61413 .70546 .60378 .7176 .59893 .71286 .60937 Mtetra
.227 0 .088 r
.71286 .60937 .7176 .59893 .72966 .59196 .72502 .60221 Mtetra
.113 0 .034 r
.72502 .60221 .72966 .59196 .74163 .58299 .73706 .59278 Mtetra
0 0 0 r
.73706 .59278 .74163 .58299 .75348 .57226 .74898 .58131 Mtetra
.74898 .58131 .75348 .57226 .76524 .56005 .76078 .56813 Mtetra
.76078 .56813 .76524 .56005 .7769 .54673 .77246 .55365 Mtetra
.77246 .55365 .7769 .54673 .78848 .53268 .78406 .53831 Mtetra
.608 .836 .452 r
.78406 .53831 .78848 .53268 .80002 .5183 .79558 .52255 Mtetra
.722 .916 .56 r
.79558 .52255 .80002 .5183 .81152 .50394 .80707 .5068 Mtetra
.805 .967 .655 r
.80707 .5068 .81152 .50394 .82304 .48994 .81855 .49142 Mtetra
.856 .991 .732 r
.81855 .49142 .82304 .48994 .83458 .47657 .83006 .47674 Mtetra
.879 .993 .791 r
.83006 .47674 .83458 .47657 .84619 .46402 .84163 .46297 Mtetra
.88 .979 .834 r
.84163 .46297 .84619 .46402 .85788 .45241 .85329 .45027 Mtetra
.866 .955 .864 r
.85329 .45027 .85788 .45241 .86967 .44181 .86505 .4387 Mtetra
.845 .926 .884 r
.86505 .4387 .86967 .44181 .88157 .43222 .87693 .42828 Mtetra
.819 .897 .897 r
.87693 .42828 .88157 .43222 .89359 .42359 .88893 .41894 Mtetra
.793 .869 .905 r
.88893 .41894 .89359 .42359 .90573 .41583 .90106 .4106 Mtetra
.768 .844 .909 r
.90106 .4106 .90573 .41583 .91799 .40884 .91332 .40314 Mtetra
.746 .823 .912 r
.91332 .40314 .91799 .40884 .93036 .4025 .92569 .39643 Mtetra
.727 .805 .913 r
.92569 .39643 .93036 .4025 .94284 .3967 .93819 .39033 Mtetra
.651 .748 .92 r
.35497 .55903 .3614 .56472 .37181 .56178 .3654 .55609 Mtetra
.65 .748 .922 r
.3654 .55609 .37181 .56178 .38226 .55886 .37587 .55318 Mtetra
.647 .749 .923 r
.37587 .55318 .38226 .55886 .39275 .55598 .38639 .55031 Mtetra
.644 .749 .925 r
.38639 .55031 .39275 .55598 .40328 .55316 .39695 .5475 Mtetra
.64 .749 .928 r
.39695 .5475 .40328 .55316 .41385 .55043 .40754 .54479 Mtetra
.633 .748 .931 r
.40754 .54479 .41385 .55043 .42447 .54782 .41818 .54221 Mtetra
.624 .748 .935 r
.41818 .54221 .42447 .54782 .43512 .5454 .42886 .53983 Mtetra
.612 .746 .941 r
.42886 .53983 .43512 .5454 .44582 .54321 .43959 .5377 Mtetra
.594 .744 .948 r
.43959 .5377 .44582 .54321 .45656 .54134 .45035 .53592 Mtetra
.568 .739 .956 r
.45035 .53592 .45656 .54134 .46735 .53988 .46116 .53458 Mtetra
.533 .731 .966 r
.46116 .53458 .46735 .53988 .47818 .53893 .47202 .53379 Mtetra
.483 .718 .974 r
.47202 .53379 .47818 .53893 .48907 .5386 .48293 .53367 Mtetra
.412 .695 .979 r
.48293 .53367 .48907 .5386 .50001 .53901 .49389 .53435 Mtetra
.313 .657 .972 r
.49389 .53435 .50001 .53901 .51102 .54025 .50492 .53593 Mtetra
.179 .594 .941 r
.50492 .53593 .51102 .54025 .5221 .54243 .51603 .53852 Mtetra
.01 .498 .87 r
.51603 .53852 .5221 .54243 .53327 .54558 .52723 .54218 Mtetra
0 .37 .75 r
.52723 .54218 .53327 .54558 .54453 .54976 .53852 .54696 Mtetra
.354 0 0 r
.53852 .54696 .54453 .54976 .5559 .55492 .54992 .55283 Mtetra
.493 0 0 r
.54992 .55283 .5559 .55492 .56739 .561 .56144 .55971 Mtetra
.587 .012 0 r
.56144 .55971 .56739 .561 .579 .56785 .57309 .56748 Mtetra
.644 .088 0 r
.57309 .56748 .579 .56785 .59073 .57528 .58488 .57591 Mtetra
.673 .138 0 r
.58488 .57591 .59073 .57528 .6026 .58303 .59681 .58473 Mtetra
.682 .167 .004 r
.59681 .58473 .6026 .58303 .6146 .59078 .60888 .59362 Mtetra
.677 .179 .056 r
.60888 .59362 .6146 .59078 .62671 .59816 .62107 .60217 Mtetra
.66 .177 .093 r
.62107 .60217 .62671 .59816 .63892 .60481 .63337 .60997 Mtetra
.632 .161 .117 r
.63337 .60997 .63892 .60481 .65121 .61032 .64576 .61659 Mtetra
.593 .133 .131 r
.64576 .61659 .65121 .61032 .66356 .61431 .65822 .62159 Mtetra
.542 .093 .134 r
.65822 .62159 .66356 .61431 .67593 .61645 .6707 .6246 Mtetra
.477 .039 .126 r
.6707 .6246 .67593 .61645 .68829 .61646 .68318 .62529 Mtetra
.396 0 .107 r
.68318 .62529 .68829 .61646 .70061 .61413 .69562 .62341 Mtetra
.298 0 .075 r
.69562 .62341 .70061 .61413 .71286 .60937 .70798 .61885 Mtetra
.179 0 .027 r
.70798 .61885 .71286 .60937 .72502 .60221 .72023 .61161 Mtetra
.041 0 0 r
.72023 .61161 .72502 .60221 .73706 .59278 .73236 .60181 Mtetra
0 0 0 r
.73236 .60181 .73706 .59278 .74898 .58131 .74435 .58971 Mtetra
.74435 .58971 .74898 .58131 .76078 .56813 .7562 .57568 Mtetra
.7562 .57568 .76078 .56813 .77246 .55365 .76792 .56014 Mtetra
.76792 .56014 .77246 .55365 .78406 .53831 .77953 .54359 Mtetra
.699 .885 .502 r
.77953 .54359 .78406 .53831 .79558 .52255 .79105 .52653 Mtetra
.79 .941 .588 r
.79105 .52653 .79558 .52255 .80707 .5068 .80253 .50944 Mtetra
.852 .974 .664 r
.80253 .50944 .80707 .5068 .81855 .49142 .81399 .49274 Mtetra
.888 .987 .726 r
.81399 .49274 .81855 .49142 .83006 .47674 .82547 .47678 Mtetra
.901 .985 .777 r
.82547 .47678 .83006 .47674 .84163 .46297 .83702 .46183 Mtetra
.898 .971 .817 r
.83702 .46183 .84163 .46297 .85329 .45027 .84864 .44805 Mtetra
.883 .95 .848 r
.84864 .44805 .85329 .45027 .86505 .4387 .86038 .43554 Mtetra
.86 .925 .87 r
.86038 .43554 .86505 .4387 .87693 .42828 .87223 .4243 Mtetra
.833 .898 .886 r
.87223 .4243 .87693 .42828 .88893 .41894 .88422 .41427 Mtetra
.805 .872 .896 r
.88422 .41427 .88893 .41894 .90106 .4106 .89634 .40535 Mtetra
.779 .847 .903 r
.89634 .40535 .90106 .4106 .91332 .40314 .9086 .39742 Mtetra
.755 .826 .907 r
.9086 .39742 .91332 .40314 .92569 .39643 .92099 .39033 Mtetra
.735 .808 .91 r
.92099 .39033 .92569 .39643 .93819 .39033 .93349 .38393 Mtetra
.65 .748 .921 r
.34849 .5533 .35497 .55903 .3654 .55609 .35894 .55036 Mtetra
.649 .748 .922 r
.35894 .55036 .3654 .55609 .37587 .55318 .36944 .54746 Mtetra
.646 .748 .924 r
.36944 .54746 .37587 .55318 .38639 .55031 .37998 .54459 Mtetra
.643 .749 .926 r
.37998 .54459 .38639 .55031 .39695 .5475 .39056 .54179 Mtetra
.638 .748 .928 r
.39056 .54179 .39695 .5475 .40754 .54479 .40119 .5391 Mtetra
.632 .748 .932 r
.40119 .5391 .40754 .54479 .41818 .54221 .41185 .53655 Mtetra
.622 .747 .936 r
.41185 .53655 .41818 .54221 .42886 .53983 .42256 .53419 Mtetra
.609 .745 .941 r
.42256 .53419 .42886 .53983 .43959 .5377 .4333 .53212 Mtetra
.59 .741 .948 r
.4333 .53212 .43959 .5377 .45035 .53592 .44409 .5304 Mtetra
.563 .735 .956 r
.44409 .5304 .45035 .53592 .46116 .53458 .45492 .52915 Mtetra
.526 .725 .965 r
.45492 .52915 .46116 .53458 .47202 .53379 .4658 .52849 Mtetra
.475 .71 .972 r
.4658 .52849 .47202 .53379 .48293 .53367 .47674 .52853 Mtetra
.403 .684 .975 r
.47674 .52853 .48293 .53367 .49389 .53435 .48772 .52941 Mtetra
.304 .642 .967 r
.48772 .52941 .49389 .53435 .50492 .53593 .49878 .53125 Mtetra
.172 .576 .936 r
.49878 .53125 .50492 .53593 .51603 .53852 .50991 .53417 Mtetra
.009 .481 .87 r
.50991 .53417 .51603 .53852 .52723 .54218 .52113 .53823 Mtetra
0 .358 .762 r
.52113 .53823 .52723 .54218 .53852 .54696 .53244 .54349 Mtetra
0 .223 .622 r
.53244 .54349 .53852 .54696 .54992 .55283 .54387 .54992 Mtetra
.48 0 0 r
.54387 .54992 .54992 .55283 .56144 .55971 .55542 .55747 Mtetra
.579 .006 0 r
.55542 .55747 .56144 .55971 .57309 .56748 .56711 .56599 Mtetra
.642 .082 0 r
.56711 .56599 .57309 .56748 .58488 .57591 .57894 .57527 Mtetra
.678 .132 0 r
.57894 .57527 .58488 .57591 .59681 .58473 .59092 .58502 Mtetra
.693 .162 0 r
.59092 .58502 .59681 .58473 .60888 .59362 .60305 .5949 Mtetra
.692 .173 0 r
.60305 .5949 .60888 .59362 .62107 .60217 .61531 .6045 Mtetra
.678 .169 .025 r
.61531 .6045 .62107 .60217 .63337 .60997 .62769 .61336 Mtetra
.65 .15 .048 r
.62769 .61336 .63337 .60997 .64576 .61659 .64017 .62102 Mtetra
.608 .115 .059 r
.64017 .62102 .64576 .61659 .65822 .62159 .65272 .62701 Mtetra
.549 .065 .058 r
.65272 .62701 .65822 .62159 .6707 .6246 .66531 .63089 Mtetra
.471 0 .044 r
.66531 .63089 .6707 .6246 .68318 .62529 .6779 .63229 Mtetra
.37 0 .015 r
.6779 .63229 .68318 .62529 .69562 .62341 .69044 .63094 Mtetra
.243 0 0 r
.69044 .63094 .69562 .62341 .70798 .61885 .70291 .62668 Mtetra
.089 0 0 r
.70291 .62668 .70798 .61885 .72023 .61161 .71527 .61948 Mtetra
0 0 0 r
.71527 .61948 .72023 .61161 .73236 .60181 .72748 .60946 Mtetra
.72748 .60946 .73236 .60181 .74435 .58971 .73955 .59688 Mtetra
.73955 .59688 .74435 .58971 .7562 .57568 .75146 .58213 Mtetra
.589 .816 .424 r
.75146 .58213 .7562 .57568 .76792 .56014 .76322 .56569 Mtetra
.709 .887 .501 r
.76322 .56569 .76792 .56014 .77953 .54359 .77486 .54807 Mtetra
.798 .934 .569 r
.77486 .54807 .77953 .54359 .79105 .52653 .7864 .52985 Mtetra
.86 .962 .629 r
.7864 .52985 .79105 .52653 .80253 .50944 .79788 .51154 Mtetra
.898 .976 .682 r
.79788 .51154 .80253 .50944 .81399 .49274 .80933 .49362 Mtetra
.917 .979 .729 r
.80933 .49362 .81399 .49274 .82547 .47678 .8208 .47648 Mtetra
.921 .972 .769 r
.8208 .47648 .82547 .47678 .83702 .46183 .83232 .46041 Mtetra
.913 .959 .804 r
.83232 .46041 .83702 .46183 .84864 .44805 .84393 .44563 Mtetra
.896 .94 .833 r
.84393 .44563 .84864 .44805 .86038 .43554 .85564 .43221 Mtetra
.872 .918 .856 r
.85564 .43221 .86038 .43554 .87223 .4243 .86748 .42018 Mtetra
.844 .895 .874 r
.86748 .42018 .87223 .4243 .88422 .41427 .87946 .40948 Mtetra
.816 .871 .887 r
.87946 .40948 .88422 .41427 .89634 .40535 .89158 .40001 Mtetra
.788 .848 .896 r
.89158 .40001 .89634 .40535 .9086 .39742 .90384 .39163 Mtetra
.763 .828 .902 r
.90384 .39163 .9086 .39742 .92099 .39033 .91624 .38417 Mtetra
.742 .81 .906 r
.91624 .38417 .92099 .39033 .93349 .38393 .92876 .37747 Mtetra
.649 .748 .921 r
.34196 .54754 .34849 .5533 .35894 .55036 .35244 .5446 Mtetra
.648 .748 .923 r
.35244 .5446 .35894 .55036 .36944 .54746 .36296 .5417 Mtetra
.645 .748 .924 r
.36296 .5417 .36944 .54746 .37998 .54459 .37353 .53884 Mtetra
.642 .748 .926 r
.37353 .53884 .37998 .54459 .39056 .54179 .38413 .53605 Mtetra
.637 .748 .929 r
.38413 .53605 .39056 .54179 .40119 .5391 .39478 .53336 Mtetra
.63 .747 .932 r
.39478 .53336 .40119 .5391 .41185 .53655 .40547 .53082 Mtetra
.62 .746 .936 r
.40547 .53082 .41185 .53655 .42256 .53419 .4162 .52849 Mtetra
.606 .743 .941 r
.4162 .52849 .42256 .53419 .4333 .53212 .42697 .52645 Mtetra
.587 .739 .948 r
.42697 .52645 .4333 .53212 .44409 .5304 .43778 .52477 Mtetra
.56 .731 .955 r
.43778 .52477 .44409 .5304 .45492 .52915 .44864 .52358 Mtetra
.523 .72 .963 r
.44864 .52358 .45492 .52915 .4658 .52849 .45954 .52299 Mtetra
.472 .702 .969 r
.45954 .52299 .4658 .52849 .47674 .52853 .4705 .52313 Mtetra
.401 .674 .971 r
.4705 .52313 .47674 .52853 .48772 .52941 .48151 .52415 Mtetra
.306 .631 .963 r
.48151 .52415 .48772 .52941 .49878 .53125 .49259 .52616 Mtetra
.182 .567 .936 r
.49259 .52616 .49878 .53125 .50991 .53417 .50374 .52929 Mtetra
.03 .477 .879 r
.50374 .52929 .50991 .53417 .52113 .53823 .51497 .53362 Mtetra
0 .364 .789 r
.51497 .53362 .52113 .53823 .53244 .54349 .52631 .53921 Mtetra
0 .24 .671 r
.52631 .53921 .53244 .54349 .54387 .54992 .53776 .54605 Mtetra
.437 0 0 r
.53776 .54605 .54387 .54992 .55542 .55747 .54934 .55408 Mtetra
.541 0 0 r
.54934 .55408 .55542 .55747 .56711 .56599 .56105 .56316 Mtetra
.613 .053 0 r
.56105 .56316 .56711 .56599 .57894 .57527 .57292 .57308 Mtetra
.658 .104 0 r
.57292 .57308 .57894 .57527 .59092 .58502 .58493 .58357 Mtetra
.682 .135 0 r
.58493 .58357 .59092 .58502 .60305 .5949 .5971 .59426 Mtetra
.689 .147 0 r
.5971 .59426 .60305 .5949 .61531 .6045 .60942 .60472 Mtetra
.679 .14 0 r
.60942 .60472 .61531 .6045 .62769 .61336 .62186 .6145 Mtetra
.653 .116 0 r
.62186 .6145 .62769 .61336 .64017 .62102 .63442 .62309 Mtetra
.608 .071 0 r
.63442 .62309 .64017 .62102 .65272 .62701 .64705 .62998 Mtetra
.54 .003 0 r
.64705 .62998 .65272 .62701 .66531 .63089 .65974 .6347 Mtetra
.441 0 0 r
.65974 .6347 .66531 .63089 .6779 .63229 .67242 .63684 Mtetra
.305 0 0 r
.67242 .63684 .6779 .63229 .69044 .63094 .68507 .63607 Mtetra
.129 0 0 r
.68507 .63607 .69044 .63094 .70291 .62668 .69764 .6322 Mtetra
0 0 0 r
.69764 .6322 .70291 .62668 .71527 .61948 .7101 .62517 Mtetra
.7101 .62517 .71527 .61948 .72748 .60946 .72241 .61509 Mtetra
.72241 .61509 .72748 .60946 .73955 .59688 .73455 .60222 Mtetra
.644 .877 .52 r
.73455 .60222 .73955 .59688 .75146 .58213 .74653 .58695 Mtetra
.756 .926 .566 r
.74653 .58695 .75146 .58213 .76322 .56569 .75835 .56979 Mtetra
.833 .952 .605 r
.75835 .56979 .76322 .56569 .77486 .54807 .77003 .55131 Mtetra
.884 .965 .639 r
.77003 .55131 .77486 .54807 .7864 .52985 .7816 .5321 Mtetra
.916 .97 .671 r
.7816 .5321 .7864 .52985 .79788 .51154 .79309 .51275 Mtetra
.933 .968 .703 r
.79309 .51275 .79788 .51154 .80933 .49362 .80455 .49376 Mtetra
.939 .963 .734 r
.80455 .49376 .80933 .49362 .8208 .47648 .81601 .47557 Mtetra
.935 .954 .765 r
.81601 .47557 .8208 .47648 .83232 .46041 .82753 .45852 Mtetra
.923 .942 .794 r
.82753 .45852 .83232 .46041 .84393 .44563 .83912 .44282 Mtetra
.904 .926 .82 r
.83912 .44282 .84393 .44563 .85564 .43221 .85083 .42858 Mtetra
.88 .908 .844 r
.85083 .42858 .85564 .43221 .86748 .42018 .86266 .41584 Mtetra
.853 .888 .863 r
.86266 .41584 .86748 .42018 .87946 .40948 .87464 .40452 Mtetra
.824 .867 .878 r
.87464 .40452 .87946 .40948 .89158 .40001 .88676 .39454 Mtetra
.796 .847 .889 r
.88676 .39454 .89158 .40001 .90384 .39163 .89903 .38572 Mtetra
.77 .828 .897 r
.89903 .38572 .90384 .39163 .91624 .38417 .91144 .37792 Mtetra
.748 .811 .902 r
.91144 .37792 .91624 .38417 .92876 .37747 .92398 .37094 Mtetra
.648 .748 .922 r
.33538 .54174 .34196 .54754 .35244 .5446 .34588 .5388 Mtetra
.647 .748 .923 r
.34588 .5388 .35244 .5446 .36296 .5417 .35643 .5359 Mtetra
.644 .748 .925 r
.35643 .5359 .36296 .5417 .37353 .53884 .36702 .53304 Mtetra
.641 .748 .927 r
.36702 .53304 .37353 .53884 .38413 .53605 .37765 .53025 Mtetra
.636 .748 .929 r
.37765 .53025 .38413 .53605 .39478 .53336 .38833 .52757 Mtetra
.629 .747 .932 r
.38833 .52757 .39478 .53336 .40547 .53082 .39904 .52504 Mtetra
.619 .745 .936 r
.39904 .52504 .40547 .53082 .4162 .52849 .4098 .52272 Mtetra
.605 .741 .941 r
.4098 .52272 .4162 .52849 .42697 .52645 .42059 .52068 Mtetra
.586 .736 .947 r
.42059 .52068 .42697 .52645 .43778 .52477 .43143 .51902 Mtetra
.56 .728 .953 r
.43143 .51902 .43778 .52477 .44864 .52358 .44231 .51785 Mtetra
.523 .716 .96 r
.44231 .51785 .44864 .52358 .45954 .52299 .45324 .51728 Mtetra
.473 .697 .966 r
.45324 .51728 .45954 .52299 .4705 .52313 .46422 .51746 Mtetra
.407 .668 .967 r
.46422 .51746 .4705 .52313 .48151 .52415 .47525 .51853 Mtetra
.318 .625 .96 r
.47525 .51853 .48151 .52415 .49259 .52616 .48634 .52061 Mtetra
.205 .565 .937 r
.48634 .52061 .49259 .52616 .50374 .52929 .49751 .52383 Mtetra
.07 .483 .892 r
.49751 .52383 .50374 .52929 .51497 .53362 .50877 .52829 Mtetra
0 .383 .822 r
.50877 .52829 .51497 .53362 .52631 .53921 .52012 .53404 Mtetra
0 .273 .729 r
.52012 .53404 .52631 .53921 .53776 .54605 .53159 .5411 Mtetra
0 .166 .627 r
.53159 .5411 .53776 .54605 .54934 .55408 .54318 .54939 Mtetra
.465 0 0 r
.54318 .54939 .54934 .55408 .56105 .56316 .55492 .55881 Mtetra
.544 0 0 r
.55492 .55881 .56105 .56316 .57292 .57308 .5668 .56915 Mtetra
.597 .05 0 r
.5668 .56915 .57292 .57308 .58493 .58357 .57885 .58013 Mtetra
.629 .08 0 r
.57885 .58013 .58493 .58357 .5971 .59426 .59105 .5914 Mtetra
.642 .089 0 r
.59105 .5914 .5971 .59426 .60942 .60472 .6034 .60252 Mtetra
.637 .078 0 r
.6034 .60252 .60942 .60472 .62186 .6145 .61589 .61302 Mtetra
.613 .044 0 r
.61589 .61302 .62186 .6145 .63442 .62309 .62851 .62238 Mtetra
.562 0 0 r
.62851 .62238 .63442 .62309 .64705 .62998 .64121 .63006 Mtetra
.477 0 0 r
.64121 .63006 .64705 .62998 .65974 .6347 .65397 .63555 Mtetra
.342 0 0 r
.65397 .63555 .65974 .6347 .67242 .63684 .66674 .63841 Mtetra
.146 0 0 r
.66674 .63841 .67242 .63684 .68507 .63607 .67948 .63825 Mtetra
0 0 0 r
.67948 .63825 .68507 .63607 .69764 .6322 .69214 .63486 Mtetra
.367 .808 .659 r
.69214 .63486 .69764 .6322 .7101 .62517 .7047 .62813 Mtetra
.582 .916 .691 r
.7047 .62813 .7101 .62517 .72241 .61509 .7171 .61816 Mtetra
.731 .966 .697 r
.7171 .61816 .72241 .61509 .73455 .60222 .72934 .60519 Mtetra
.825 .981 .693 r
.72934 .60519 .73455 .60222 .74653 .58695 .74139 .58962 Mtetra
.883 .98 .688 r
.74139 .58962 .74653 .58695 .75835 .56979 .75328 .57198 Mtetra
.918 .973 .688 r
.75328 .57198 .75835 .56979 .77003 .55131 .76501 .55287 Mtetra
.939 .964 .694 r
.76501 .55287 .77003 .55131 .7816 .5321 .77662 .53291 Mtetra
.95 .956 .705 r
.77662 .53291 .7816 .5321 .79309 .51275 .78814 .51273 Mtetra
.953 .948 .72 r
.78814 .51273 .79309 .51275 .80455 .49376 .79962 .49288 Mtetra
.95 .94 .74 r
.79962 .49288 .80455 .49376 .81601 .47557 .8111 .47383 Mtetra
.942 .931 .762 r
.8111 .47383 .81601 .47557 .82753 .45852 .82262 .45595 Mtetra
.927 .921 .786 r
.82262 .45595 .82753 .45852 .83912 .44282 .83422 .43947 Mtetra
.908 .908 .81 r
.83422 .43947 .83912 .44282 .85083 .42858 .84593 .42453 Mtetra
.885 .894 .832 r
.84593 .42453 .85083 .42858 .86266 .41584 .85777 .41116 Mtetra
.858 .878 .852 r
.85777 .41116 .86266 .41584 .87464 .40452 .86975 .39931 Mtetra
.83 .86 .868 r
.86975 .39931 .87464 .40452 .88676 .39454 .88189 .38886 Mtetra
.802 .843 .881 r
.88189 .38886 .88676 .39454 .89903 .38572 .89417 .37967 Mtetra
.776 .826 .891 r
.89417 .37967 .89903 .38572 .91144 .37792 .90659 .37155 Mtetra
.753 .81 .898 r
.90659 .37155 .91144 .37792 .92398 .37094 .91916 .36432 Mtetra
.648 .748 .922 r
.32875 .53589 .33538 .54174 .34588 .5388 .33928 .53296 Mtetra
.646 .748 .924 r
.33928 .53296 .34588 .5388 .35643 .5359 .34985 .53005 Mtetra
.643 .748 .925 r
.34985 .53005 .35643 .5359 .36702 .53304 .36047 .52719 Mtetra
.64 .748 .927 r
.36047 .52719 .36702 .53304 .37765 .53025 .37113 .5244 Mtetra
.635 .747 .929 r
.37113 .5244 .37765 .53025 .38833 .52757 .38182 .52172 Mtetra
.628 .746 .932 r
.38182 .52172 .38833 .52757 .39904 .52504 .39256 .51919 Mtetra
.618 .744 .936 r
.39256 .51919 .39904 .52504 .4098 .52272 .40335 .51686 Mtetra
.605 .74 .94 r
.40335 .51686 .4098 .52272 .42059 .52068 .41417 .51481 Mtetra
.586 .734 .945 r
.41417 .51481 .42059 .52068 .43143 .51902 .42503 .51314 Mtetra
.561 .726 .951 r
.42503 .51314 .43143 .51902 .44231 .51785 .43594 .51195 Mtetra
.526 .713 .957 r
.43594 .51195 .44231 .51785 .45324 .51728 .44689 .51136 Mtetra
.48 .693 .962 r
.44689 .51136 .45324 .51728 .46422 .51746 .45789 .51151 Mtetra
.418 .664 .962 r
.45789 .51151 .46422 .51746 .47525 .51853 .46894 .51254 Mtetra
.339 .624 .956 r
.46894 .51254 .47525 .51853 .48634 .52061 .48006 .51459 Mtetra
.239 .568 .939 r
.48006 .51459 .48634 .52061 .49751 .52383 .49125 .51778 Mtetra
.122 .495 .905 r
.49125 .51778 .49751 .52383 .50877 .52829 .50252 .52221 Mtetra
0 .409 .852 r
.50252 .52221 .50877 .52829 .52012 .53404 .51389 .52795 Mtetra
0 .314 .784 r
.51389 .52795 .52012 .53404 .53159 .5411 .52537 .53502 Mtetra
0 .222 .709 r
.52537 .53502 .53159 .5411 .54318 .54939 .53697 .54336 Mtetra
0 .141 .634 r
.53697 .54336 .54318 .54939 .55492 .55881 .54872 .55288 Mtetra
0 .076 .569 r
.54872 .55288 .55492 .55881 .5668 .56915 .56062 .56338 Mtetra
0 .03 .519 r
.56062 .56338 .5668 .56915 .57885 .58013 .57267 .57459 Mtetra
.512 0 0 r
.57267 .57459 .57885 .58013 .59105 .5914 .58489 .58618 Mtetra
.523 0 0 r
.58489 .58618 .59105 .5914 .6034 .60252 .59726 .59771 Mtetra
.512 0 0 r
.59726 .59771 .6034 .60252 .61589 .61302 .60979 .6087 Mtetra
.476 0 0 r
.60979 .6087 .61589 .61302 .62851 .62238 .62244 .61863 Mtetra
.404 0 0 r
.62244 .61863 .62851 .62238 .64121 .63006 .63519 .62694 Mtetra
0 .285 .662 r
.63519 .62694 .64121 .63006 .65397 .63555 .64801 .6331 Mtetra
0 .464 .776 r
.64801 .6331 .65397 .63555 .66674 .63841 .66085 .63661 Mtetra
.151 .67 .886 r
.66085 .63661 .66674 .63841 .67948 .63825 .67367 .63708 Mtetra
.419 .849 .945 r
.67367 .63708 .67948 .63825 .69214 .63486 .68642 .63422 Mtetra
.637 .954 .936 r
.68642 .63422 .69214 .63486 .7047 .62813 .69906 .62792 Mtetra
.779 .99 .889 r
.69906 .62792 .7047 .62813 .7171 .61816 .71155 .61822 Mtetra
.862 .99 .835 r
.71155 .61822 .7171 .61816 .72934 .60519 .72388 .60536 Mtetra
.908 .977 .79 r
.72388 .60536 .72934 .60519 .74139 .58962 .73602 .58974 Mtetra
.935 .961 .757 r
.73602 .58974 .74139 .58962 .75328 .57198 .74798 .57188 Mtetra
.949 .946 .737 r
.74798 .57188 .75328 .57198 .76501 .55287 .75978 .5524 Mtetra
.956 .934 .727 r
.75978 .5524 .76501 .55287 .77662 .53291 .77144 .53196 Mtetra
.958 .925 .726 r
.77144 .53196 .77662 .53291 .78814 .51273 .78301 .51121 Mtetra
.956 .917 .732 r
.78301 .51121 .78814 .51273 .79962 .49288 .79453 .49074 Mtetra
.95 .91 .743 r
.79453 .49074 .79962 .49288 .8111 .47383 .80604 .47105 Mtetra
.94 .903 .76 r
.80604 .47105 .8111 .47383 .82262 .45595 .81758 .45252 Mtetra
.926 .896 .779 r
.81758 .45252 .82262 .45595 .83422 .43947 .8292 .43544 Mtetra
.908 .888 .801 r
.8292 .43544 .83422 .43947 .84593 .42453 .84093 .41994 Mtetra
.885 .878 .822 r
.84093 .41994 .84593 .42453 .85777 .41116 .85279 .40606 Mtetra
.86 .865 .842 r
.85279 .40606 .85777 .41116 .86975 .39931 .86479 .39377 Mtetra
.833 .851 .859 r
.86479 .39377 .86975 .39931 .88189 .38886 .87694 .38294 Mtetra
.806 .837 .874 r
.87694 .38294 .88189 .38886 .89417 .37967 .88924 .37342 Mtetra
.78 .822 .885 r
.88924 .37342 .89417 .37967 .90659 .37155 .90169 .36503 Mtetra
.757 .808 .894 r
.90169 .36503 .90659 .37155 .91916 .36432 .91428 .35758 Mtetra
.647 .747 .923 r
.32207 .53001 .32875 .53589 .33928 .53296 .33263 .52707 Mtetra
.645 .748 .924 r
.33263 .52707 .33928 .53296 .34985 .53005 .34322 .52416 Mtetra
.642 .748 .925 r
.34322 .52416 .34985 .53005 .36047 .52719 .35387 .5213 Mtetra
.639 .747 .927 r
.35387 .5213 .36047 .52719 .37113 .5244 .36455 .51851 Mtetra
.634 .747 .929 r
.36455 .51851 .37113 .5244 .38182 .52172 .37527 .51581 Mtetra
.628 .745 .932 r
.37527 .51581 .38182 .52172 .39256 .51919 .38604 .51326 Mtetra
.618 .743 .935 r
.38604 .51326 .39256 .51919 .40335 .51686 .39684 .51092 Mtetra
.606 .739 .939 r
.39684 .51092 .40335 .51686 .41417 .51481 .40769 .50884 Mtetra
.588 .733 .944 r
.40769 .50884 .41417 .51481 .42503 .51314 .41858 .50713 Mtetra
.564 .724 .949 r
.41858 .50713 .42503 .51314 .43594 .51195 .42951 .50588 Mtetra
.532 .71 .954 r
.42951 .50588 .43594 .51195 .44689 .51136 .44049 .50522 Mtetra
.489 .691 .957 r
.44049 .50522 .44689 .51136 .45789 .51151 .45151 .50528 Mtetra
.434 .663 .958 r
.45151 .50528 .45789 .51151 .46894 .51254 .46259 .5062 Mtetra
.364 .625 .953 r
.46259 .5062 .46894 .51254 .48006 .51459 .47373 .50811 Mtetra
.279 .575 .939 r
.47373 .50811 .48006 .51459 .49125 .51778 .48494 .51114 Mtetra
.181 .511 .914 r
.48494 .51114 .49125 .51778 .50252 .52221 .49622 .5154 Mtetra
.074 .437 .876 r
.49622 .5154 .50252 .52221 .51389 .52795 .50761 .52095 Mtetra
0 .358 .827 r
.50761 .52095 .51389 .52795 .52537 .53502 .5191 .52783 Mtetra
0 .281 .774 r
.5191 .52783 .52537 .53502 .53697 .54336 .53071 .536 Mtetra
0 .212 .722 r
.53071 .536 .53697 .54336 .54872 .55288 .54246 .54537 Mtetra
0 .158 .678 r
.54246 .54537 .54872 .55288 .56062 .56338 .55436 .55577 Mtetra
0 .121 .647 r
.55436 .55577 .56062 .56338 .57267 .57459 .56642 .56695 Mtetra
0 .104 .632 r
.56642 .56695 .57267 .57459 .58489 .58618 .57864 .57858 Mtetra
0 .109 .636 r
.57864 .57858 .58489 .58618 .59726 .59771 .59102 .59025 Mtetra
0 .137 .659 r
.59102 .59025 .59726 .59771 .60979 .6087 .60356 .60148 Mtetra
0 .193 .703 r
.60356 .60148 .60979 .6087 .62244 .61863 .61623 .61176 Mtetra
0 .281 .769 r
.61623 .61176 .62244 .61863 .63519 .62694 .62901 .62051 Mtetra
0 .401 .849 r
.62901 .62051 .63519 .62694 .64801 .6331 .64187 .62719 Mtetra
.173 .544 .927 r
.64187 .62719 .64801 .6331 .66085 .63661 .65476 .63127 Mtetra
.376 .686 .979 r
.65476 .63127 .66085 .63661 .67367 .63708 .66764 .63233 Mtetra
.565 .797 .987 r
.66764 .63233 .67367 .63708 .68642 .63422 .68047 .63004 Mtetra
.71 .865 .955 r
.68047 .63004 .68642 .63422 .69906 .62792 .69319 .62425 Mtetra
.808 .896 .906 r
.69319 .62425 .69906 .62792 .71155 .61822 .70577 .61498 Mtetra
.869 .906 .855 r
.70577 .61498 .71155 .61822 .72388 .60536 .71818 .60243 Mtetra
.906 .904 .811 r
.71818 .60243 .72388 .60536 .73602 .58974 .73041 .58699 Mtetra
.928 .899 .778 r
.73041 .58699 .73602 .58974 .74798 .57188 .74245 .56918 Mtetra
.94 .893 .755 r
.74245 .56918 .74798 .57188 .75978 .5524 .75433 .54962 Mtetra
.946 .887 .741 r
.75433 .54962 .75978 .5524 .77144 .53196 .76606 .52898 Mtetra
.948 .882 .735 r
.76606 .52898 .77144 .53196 .78301 .51121 .7777 .50795 Mtetra
.946 .879 .737 r
.7777 .50795 .78301 .51121 .79453 .49074 .78927 .48712 Mtetra
.941 .876 .744 r
.78927 .48712 .79453 .49074 .80604 .47105 .80082 .46704 Mtetra
.932 .873 .757 r
.80082 .46704 .80604 .47105 .81758 .45252 .81241 .4481 Mtetra
.919 .87 .774 r
.81241 .4481 .81758 .45252 .8292 .43544 .82407 .4306 Mtetra
.903 .865 .793 r
.82407 .4306 .8292 .43544 .84093 .41994 .83583 .4147 Mtetra
.883 .859 .813 r
.83583 .4147 .84093 .41994 .85279 .40606 .84771 .40046 Mtetra
.859 .851 .833 r
.84771 .40046 .85279 .40606 .86479 .39377 .85974 .38783 Mtetra
.834 .841 .851 r
.85974 .38783 .86479 .39377 .87694 .38294 .87192 .37671 Mtetra
.808 .829 .867 r
.87192 .37671 .87694 .38294 .88924 .37342 .88426 .36694 Mtetra
.783 .817 .88 r
.88426 .36694 .88924 .37342 .90169 .36503 .89674 .35833 Mtetra
.759 .805 .89 r
.89674 .35833 .90169 .36503 .91428 .35758 .90936 .35069 Mtetra
.646 .747 .923 r
.31534 .52408 .32207 .53001 .33263 .52707 .32592 .52113 Mtetra
.644 .747 .924 r
.32592 .52113 .33263 .52707 .34322 .52416 .33655 .51822 Mtetra
.642 .747 .926 r
.33655 .51822 .34322 .52416 .35387 .5213 .34721 .51535 Mtetra
.639 .747 .927 r
.34721 .51535 .35387 .5213 .36455 .51851 .35792 .51255 Mtetra
.634 .746 .929 r
.35792 .51255 .36455 .51851 .37527 .51581 .36867 .50985 Mtetra
.628 .745 .932 r
.36867 .50985 .37527 .51581 .38604 .51326 .37946 .50728 Mtetra
.619 .742 .934 r
.37946 .50728 .38604 .51326 .39684 .51092 .3903 .50489 Mtetra
.607 .738 .938 r
.3903 .50489 .39684 .51092 .40769 .50884 .40117 .50277 Mtetra
.591 .732 .942 r
.40117 .50277 .40769 .50884 .41858 .50713 .41209 .50099 Mtetra
.569 .723 .946 r
.41209 .50099 .41858 .50713 .42951 .50588 .42305 .49966 Mtetra
.54 .71 .95 r
.42305 .49966 .42951 .50588 .44049 .50522 .43405 .49888 Mtetra
.502 .691 .953 r
.43405 .49888 .44049 .50522 .45151 .50528 .4451 .49879 Mtetra
.453 .664 .953 r
.4451 .49879 .45151 .50528 .46259 .5062 .4562 .49952 Mtetra
.393 .629 .948 r
.4562 .49952 .46259 .5062 .47373 .50811 .46736 .5012 Mtetra
.321 .584 .938 r
.46736 .5012 .47373 .50811 .48494 .51114 .47859 .50396 Mtetra
.24 .529 .918 r
.47859 .50396 .48494 .51114 .49622 .5154 .48989 .50791 Mtetra
.153 .466 .89 r
.48989 .50791 .49622 .5154 .50761 .52095 .50128 .51312 Mtetra
.067 .399 .855 r
.50128 .51312 .50761 .52095 .5191 .52783 .51278 .51962 Mtetra
0 .335 .817 r
.51278 .51962 .5191 .52783 .53071 .536 .5244 .52741 Mtetra
0 .278 .781 r
.5244 .52741 .53071 .536 .54246 .54537 .53615 .53641 Mtetra
0 .233 .75 r
.53615 .53641 .54246 .54537 .55436 .55577 .54805 .54646 Mtetra
0 .204 .73 r
.54805 .54646 .55436 .55577 .56642 .56695 .5601 .55733 Mtetra
0 .192 .722 r
.5601 .55733 .56642 .56695 .57864 .57858 .57231 .56873 Mtetra
0 .199 .728 r
.57231 .56873 .57864 .57858 .59102 .59025 .58469 .58027 Mtetra
0 .227 .747 r
.58469 .58027 .59102 .59025 .60356 .60148 .59723 .59148 Mtetra
0 .275 .779 r
.59723 .59148 .60356 .60148 .61623 .61176 .6099 .60186 Mtetra
.064 .343 .819 r
.6099 .60186 .61623 .61176 .62901 .62051 .62269 .61083 Mtetra
.183 .428 .861 r
.62269 .61083 .62901 .62051 .64187 .62719 .63557 .61786 Mtetra
.32 .521 .895 r
.63557 .61786 .64187 .62719 .65476 .63127 .64849 .62239 Mtetra
.46 .612 .913 r
.64849 .62239 .65476 .63127 .66764 .63233 .66142 .62397 Mtetra
.588 .688 .911 r
.66142 .62397 .66764 .63233 .68047 .63004 .6743 .62225 Mtetra
.693 .745 .891 r
.6743 .62225 .68047 .63004 .69319 .62425 .68709 .61703 Mtetra
.773 .783 .861 r
.68709 .61703 .69319 .62425 .70577 .61498 .69975 .60831 Mtetra
.83 .806 .829 r
.69975 .60831 .70577 .61498 .71818 .60243 .71224 .59625 Mtetra
.868 .82 .798 r
.71224 .59625 .71818 .60243 .73041 .58699 .72456 .58122 Mtetra
.894 .828 .773 r
.72456 .58122 .73041 .58699 .74245 .56918 .73669 .56371 Mtetra
.911 .832 .755 r
.73669 .56371 .74245 .56918 .75433 .54962 .74866 .54435 Mtetra
.921 .835 .742 r
.74866 .54435 .75433 .54962 .76606 .52898 .76047 .52382 Mtetra
.927 .837 .737 r
.76047 .52382 .76606 .52898 .7777 .50795 .77218 .50279 Mtetra
.927 .839 .737 r
.77218 .50279 .7777 .50795 .78927 .48712 .78383 .48189 Mtetra
.925 .841 .743 r
.78383 .48189 .78927 .48712 .80082 .46704 .79545 .46167 Mtetra
.918 .842 .754 r
.79545 .46167 .80082 .46704 .81241 .4481 .80709 .44256 Mtetra
.908 .843 .768 r
.80709 .44256 .81241 .4481 .82407 .4306 .8188 .42486 Mtetra
.894 .842 .786 r
.8188 .42486 .82407 .4306 .83583 .4147 .83061 .40875 Mtetra
.876 .84 .806 r
.83061 .40875 .83583 .4147 .84771 .40046 .84254 .39429 Mtetra
.855 .835 .826 r
.84254 .39429 .84771 .40046 .85974 .38783 .85461 .38146 Mtetra
.832 .829 .844 r
.85461 .38146 .85974 .38783 .87192 .37671 .86683 .37015 Mtetra
.808 .82 .861 r
.86683 .37015 .87192 .37671 .88426 .36694 .8792 .3602 Mtetra
.783 .811 .875 r
.8792 .3602 .88426 .36694 .89674 .35833 .89172 .35143 Mtetra
.761 .801 .886 r
.89172 .35143 .89674 .35833 .90936 .35069 .90438 .34365 Mtetra
.645 .747 .923 r
.30857 .5181 .31534 .52408 .32592 .52113 .31917 .51515 Mtetra
.643 .747 .924 r
.31917 .51515 .32592 .52113 .33655 .51822 .32982 .51223 Mtetra
.641 .747 .926 r
.32982 .51223 .33655 .51822 .34721 .51535 .34051 .50936 Mtetra
.638 .747 .927 r
.34051 .50936 .34721 .51535 .35792 .51255 .35124 .50654 Mtetra
.634 .746 .929 r
.35124 .50654 .35792 .51255 .36867 .50985 .36202 .50382 Mtetra
.628 .744 .931 r
.36202 .50382 .36867 .50985 .37946 .50728 .37284 .50122 Mtetra
.62 .742 .934 r
.37284 .50122 .37946 .50728 .3903 .50489 .3837 .49879 Mtetra
.609 .738 .937 r
.3837 .49879 .3903 .50489 .40117 .50277 .3946 .49661 Mtetra
.594 .732 .94 r
.3946 .49661 .40117 .50277 .41209 .50099 .40554 .49475 Mtetra
.574 .723 .943 r
.40554 .49475 .41209 .50099 .42305 .49966 .41653 .49329 Mtetra
.549 .71 .946 r
.41653 .49329 .42305 .49966 .43405 .49888 .42756 .49236 Mtetra
.515 .692 .948 r
.42756 .49236 .43405 .49888 .4451 .49879 .43864 .49207 Mtetra
.473 .667 .948 r
.43864 .49207 .4451 .49879 .4562 .49952 .44976 .49255 Mtetra
.422 .635 .944 r
.44976 .49255 .4562 .49952 .46736 .5012 .46095 .49392 Mtetra
.362 .595 .935 r
.46095 .49392 .46736 .5012 .47859 .50396 .47219 .49631 Mtetra
.296 .547 .92 r
.47219 .49631 .47859 .50396 .48989 .50791 .48352 .49983 Mtetra
.225 .492 .898 r
.48352 .49983 .48989 .50791 .50128 .51312 .49492 .50455 Mtetra
.157 .436 .871 r
.49492 .50455 .50128 .51312 .51278 .51962 .50643 .51053 Mtetra
.095 .381 .842 r
.50643 .51053 .51278 .51962 .5244 .52741 .51805 .51775 Mtetra
.046 .333 .813 r
.51805 .51775 .5244 .52741 .53615 .53641 .5298 .52616 Mtetra
.012 .295 .79 r
.5298 .52616 .53615 .53641 .54805 .54646 .54169 .53563 Mtetra
0 .27 .773 r
.54169 .53563 .54805 .54646 .5601 .55733 .55373 .54597 Mtetra
0 .259 .765 r
.55373 .54597 .5601 .55733 .57231 .56873 .56593 .55688 Mtetra
.019 .264 .765 r
.56593 .55688 .57231 .56873 .58469 .58027 .57829 .56802 Mtetra
.06 .284 .774 r
.57829 .56802 .58469 .58027 .59723 .59148 .5908 .57896 Mtetra
.12 .32 .789 r
.5908 .57896 .59723 .59148 .6099 .60186 .60347 .58918 Mtetra
.198 .368 .808 r
.60347 .58918 .6099 .60186 .62269 .61083 .61625 .59816 Mtetra
.289 .426 .827 r
.61625 .59816 .62269 .61083 .63557 .61786 .62913 .60534 Mtetra
.389 .49 .841 r
.62913 .60534 .63557 .61786 .64849 .62239 .64207 .61017 Mtetra
.49 .553 .848 r
.64207 .61017 .64849 .62239 .66142 .62397 .65502 .61217 Mtetra
.584 .61 .845 r
.65502 .61217 .66142 .62397 .6743 .62225 .66794 .61097 Mtetra
.666 .659 .833 r
.66794 .61097 .6743 .62225 .68709 .61703 .68079 .60636 Mtetra
.733 .697 .816 r
.68079 .60636 .68709 .61703 .69975 .60831 .69351 .59827 Mtetra
.786 .726 .797 r
.69351 .59827 .69975 .60831 .71224 .59625 .70608 .58684 Mtetra
.826 .748 .777 r
.70608 .58684 .71224 .59625 .72456 .58122 .71848 .57241 Mtetra
.856 .764 .76 r
.71848 .57241 .72456 .58122 .73669 .56371 .73071 .55544 Mtetra
.877 .776 .747 r
.73071 .55544 .73669 .56371 .74866 .54435 .74277 .53655 Mtetra
.891 .786 .738 r
.74277 .53655 .74866 .54435 .76047 .52382 .75468 .5164 Mtetra
.9 .794 .734 r
.75468 .5164 .76047 .52382 .77218 .50279 .76648 .49567 Mtetra
.904 .801 .735 r
.76648 .49567 .77218 .50279 .78383 .48189 .77821 .47498 Mtetra
.905 .807 .74 r
.77821 .47498 .78383 .48189 .79545 .46167 .78991 .4549 Mtetra
.901 .812 .75 r
.78991 .4549 .79545 .46167 .80709 .44256 .80163 .43585 Mtetra
.894 .816 .764 r
.80163 .43585 .80709 .44256 .8188 .42486 .81341 .41817 Mtetra
.883 .819 .781 r
.81341 .41817 .8188 .42486 .83061 .40875 .82528 .40203 Mtetra
.868 .82 .8 r
.82528 .40203 .83061 .40875 .84254 .39429 .83727 .38752 Mtetra
.849 .819 .819 r
.83727 .38752 .84254 .39429 .85461 .38146 .84939 .37461 Mtetra
.828 .816 .838 r
.84939 .37461 .85461 .38146 .86683 .37015 .86166 .36321 Mtetra
.805 .811 .856 r
.86166 .36321 .86683 .37015 .8792 .3602 .87408 .35317 Mtetra
.782 .804 .87 r
.87408 .35317 .8792 .3602 .89172 .35143 .88664 .34431 Mtetra
.761 .796 .882 r
.88664 .34431 .89172 .35143 .90438 .34365 .89934 .33644 Mtetra
.644 .746 .923 r
.30173 .51206 .30857 .5181 .31917 .51515 .31236 .50911 Mtetra
.643 .747 .924 r
.31236 .50911 .31917 .51515 .32982 .51223 .32304 .50619 Mtetra
.641 .747 .926 r
.32304 .50619 .32982 .51223 .34051 .50936 .33375 .5033 Mtetra
.638 .746 .927 r
.33375 .5033 .34051 .50936 .35124 .50654 .34451 .50047 Mtetra
.634 .746 .929 r
.34451 .50047 .35124 .50654 .36202 .50382 .35531 .49773 Mtetra
.629 .744 .931 r
.35531 .49773 .36202 .50382 .37284 .50122 .36616 .49509 Mtetra
.621 .742 .933 r
.36616 .49509 .37284 .50122 .3837 .49879 .37705 .49262 Mtetra
.612 .738 .935 r
.37705 .49262 .3837 .49879 .3946 .49661 .38798 .49036 Mtetra
.598 .732 .938 r
.38798 .49036 .3946 .49661 .40554 .49475 .39895 .48839 Mtetra
.581 .723 .94 r
.39895 .48839 .40554 .49475 .41653 .49329 .40997 .4868 Mtetra
.558 .711 .943 r
.40997 .4868 .41653 .49329 .42756 .49236 .42102 .48569 Mtetra
.529 .694 .944 r
.42102 .48569 .42756 .49236 .43864 .49207 .43213 .48516 Mtetra
.494 .672 .943 r
.43213 .48516 .43864 .49207 .44976 .49255 .44328 .48534 Mtetra
.451 .643 .939 r
.44328 .48534 .44976 .49255 .46095 .49392 .45449 .48634 Mtetra
.401 .607 .931 r
.45449 .48634 .46095 .49392 .47219 .49631 .46576 .48829 Mtetra
.347 .564 .919 r
.46576 .48829 .47219 .49631 .48352 .49983 .4771 .49128 Mtetra
.29 .517 .901 r
.4771 .49128 .48352 .49983 .49492 .50455 .48853 .49541 Mtetra
.235 .468 .878 r
.48853 .49541 .49492 .50455 .50643 .51053 .50004 .50072 Mtetra
.186 .42 .854 r
.50004 .50072 .50643 .51053 .51805 .51775 .51167 .50723 Mtetra
.147 .377 .83 r
.51167 .50723 .51805 .51775 .5298 .52616 .52341 .51488 Mtetra
.122 .343 .809 r
.52341 .51488 .5298 .52616 .54169 .53563 .53529 .52358 Mtetra
.111 .32 .792 r
.53529 .52358 .54169 .53563 .55373 .54597 .54731 .53316 Mtetra
.115 .308 .781 r
.54731 .53316 .55373 .54597 .56593 .55688 .55949 .54337 Mtetra
.135 .309 .776 r
.55949 .54337 .56593 .55688 .57829 .56802 .57183 .55388 Mtetra
.17 .322 .776 r
.57183 .55388 .57829 .56802 .5908 .57896 .58432 .56429 Mtetra
.219 .346 .78 r
.58432 .56429 .5908 .57896 .60347 .58918 .59695 .57414 Mtetra
.28 .38 .787 r
.59695 .57414 .60347 .58918 .61625 .59816 .60972 .58289 Mtetra
.35 .422 .795 r
.60972 .58289 .61625 .59816 .62913 .60534 .62258 .59001 Mtetra
.426 .468 .8 r
.62258 .59001 .62913 .60534 .64207 .61017 .63552 .59497 Mtetra
.503 .515 .802 r
.63552 .59497 .64207 .61017 .65502 .61217 .64848 .59727 Mtetra
.576 .56 .799 r
.64848 .59727 .65502 .61217 .66794 .61097 .66142 .59652 Mtetra
.643 .601 .792 r
.66142 .59652 .66794 .61097 .68079 .60636 .67431 .59249 Mtetra
.701 .637 .782 r
.67431 .59249 .68079 .60636 .69351 .59827 .68709 .58507 Mtetra
.749 .667 .77 r
.68709 .58507 .69351 .59827 .70608 .58684 .69973 .57438 Mtetra
.788 .692 .758 r
.69973 .57438 .70608 .58684 .71848 .57241 .71221 .5607 Mtetra
.819 .712 .747 r
.71221 .5607 .71848 .57241 .73071 .55544 .72453 .54448 Mtetra
.843 .728 .738 r
.72453 .54448 .73071 .55544 .74277 .53655 .73668 .52629 Mtetra
.86 .743 .732 r
.73668 .52629 .74277 .53655 .75468 .5164 .74869 .50678 Mtetra
.872 .755 .73 r
.74869 .50678 .75468 .5164 .76648 .49567 .76059 .4866 Mtetra
.88 .765 .732 r
.76059 .4866 .76648 .49567 .77821 .47498 .77242 .46639 Mtetra
.883 .775 .737 r
.77242 .46639 .77821 .47498 .78991 .4549 .78422 .4467 Mtetra
.883 .784 .747 r
.78422 .4467 .78991 .4549 .80163 .43585 .79603 .42796 Mtetra
.878 .791 .76 r
.79603 .42796 .80163 .43585 .81341 .41817 .80789 .4105 Mtetra
.87 .797 .777 r
.80789 .4105 .81341 .41817 .82528 .40203 .81984 .39453 Mtetra
.857 .801 .795 r
.81984 .39453 .82528 .40203 .83727 .38752 .8319 .38012 Mtetra
.841 .804 .815 r
.8319 .38012 .83727 .38752 .84939 .37461 .84408 .36727 Mtetra
.822 .803 .834 r
.84408 .36727 .84939 .37461 .86166 .36321 .85641 .3559 Mtetra
.801 .801 .851 r
.85641 .3559 .86166 .36321 .87408 .35317 .86888 .34585 Mtetra
.78 .797 .866 r
.86888 .34585 .87408 .35317 .88664 .34431 .8815 .33696 Mtetra
.759 .791 .879 r
.8815 .33696 .88664 .34431 .89934 .33644 .89425 .32905 Mtetra
.644 .746 .923 r
.29485 .50598 .30173 .51206 .31236 .50911 .30551 .50302 Mtetra
.642 .746 .924 r
.30551 .50302 .31236 .50911 .32304 .50619 .3162 .50009 Mtetra
.64 .746 .926 r
.3162 .50009 .32304 .50619 .33375 .5033 .32694 .49719 Mtetra
.638 .746 .927 r
.32694 .49719 .33375 .5033 .34451 .50047 .33773 .49435 Mtetra
.634 .745 .928 r
.33773 .49435 .34451 .50047 .35531 .49773 .34856 .49157 Mtetra
.629 .744 .93 r
.34856 .49157 .35531 .49773 .36616 .49509 .35943 .4889 Mtetra
.623 .741 .932 r
.35943 .4889 .36616 .49509 .37705 .49262 .37035 .48637 Mtetra
.614 .738 .934 r
.37035 .48637 .37705 .49262 .38798 .49036 .38131 .48403 Mtetra
.603 .732 .936 r
.38131 .48403 .38798 .49036 .39895 .48839 .39231 .48195 Mtetra
.587 .724 .938 r
.39231 .48195 .39895 .48839 .40997 .4868 .40335 .48021 Mtetra
.568 .713 .939 r
.40335 .48021 .40997 .4868 .42102 .48569 .41444 .47889 Mtetra
.544 .697 .94 r
.41444 .47889 .42102 .48569 .43213 .48516 .42558 .4781 Mtetra
.513 .677 .939 r
.42558 .4781 .43213 .48516 .44328 .48534 .43676 .47795 Mtetra
.478 .651 .935 r
.43676 .47795 .44328 .48534 .45449 .48634 .448 .47854 Mtetra
.437 .619 .928 r
.448 .47854 .45449 .48634 .46576 .48829 .45929 .47999 Mtetra
.392 .581 .917 r
.45929 .47999 .46576 .48829 .4771 .49128 .47065 .4824 Mtetra
.346 .54 .901 r
.47065 .4824 .4771 .49128 .48853 .49541 .48209 .48585 Mtetra
.301 .496 .882 r
.48209 .48585 .48853 .49541 .50004 .50072 .49362 .4904 Mtetra
.261 .453 .86 r
.49362 .4904 .50004 .50072 .51167 .50723 .50525 .49607 Mtetra
.23 .415 .838 r
.50525 .49607 .51167 .50723 .52341 .51488 .51699 .50284 Mtetra
.209 .383 .818 r
.51699 .50284 .52341 .51488 .53529 .52358 .52886 .51063 Mtetra
.199 .36 .8 r
.52886 .51063 .53529 .52358 .54731 .53316 .54086 .51928 Mtetra
.203 .346 .787 r
.54086 .51928 .54731 .53316 .55949 .54337 .55302 .52859 Mtetra
.219 .343 .777 r
.55302 .52859 .55949 .54337 .57183 .55388 .56532 .53827 Mtetra
.247 .35 .772 r
.56532 .53827 .57183 .55388 .58432 .56429 .57778 .54795 Mtetra
.286 .365 .77 r
.57778 .54795 .58432 .56429 .59695 .57414 .59038 .55719 Mtetra
.334 .389 .77 r
.59038 .55719 .59695 .57414 .60972 .58289 .60311 .56551 Mtetra
.389 .42 .771 r
.60311 .56551 .60972 .58289 .62258 .59001 .61595 .57238 Mtetra
.449 .454 .772 r
.61595 .57238 .62258 .59001 .63552 .59497 .62887 .57728 Mtetra
.51 .491 .772 r
.62887 .57728 .63552 .59497 .64848 .59727 .64183 .57973 Mtetra
.57 .528 .769 r
.64183 .57973 .64848 .59727 .66142 .59652 .65478 .57934 Mtetra
.626 .563 .764 r
.65478 .57934 .66142 .59652 .67431 .59249 .66769 .57583 Mtetra
.676 .595 .757 r
.66769 .57583 .67431 .59249 .68709 .58507 .68051 .56908 Mtetra
.72 .624 .749 r
.68051 .56908 .68709 .58507 .69973 .57438 .69321 .55918 Mtetra
.757 .649 .742 r
.69321 .55918 .69973 .57438 .71221 .5607 .70576 .54636 Mtetra
.788 .671 .735 r
.70576 .54636 .71221 .5607 .72453 .54448 .71817 .53104 Mtetra
.812 .69 .729 r
.71817 .53104 .72453 .54448 .73668 .52629 .73042 .51374 Mtetra
.832 .706 .726 r
.73042 .51374 .73668 .52629 .74869 .50678 .74253 .49509 Mtetra
.846 .721 .726 r
.74253 .49509 .74869 .50678 .76059 .4866 .75454 .47571 Mtetra
.856 .735 .728 r
.75454 .47571 .76059 .4866 .77242 .46639 .76648 .45621 Mtetra
.862 .747 .735 r
.76648 .45621 .77242 .46639 .78422 .4467 .77838 .43713 Mtetra
.864 .758 .745 r
.77838 .43713 .78422 .4467 .79603 .42796 .79029 .41892 Mtetra
.861 .768 .758 r
.79029 .41892 .79603 .42796 .80789 .4105 .80225 .40189 Mtetra
.855 .777 .774 r
.80225 .40189 .80789 .4105 .81984 .39453 .81428 .38626 Mtetra
.845 .784 .792 r
.81428 .38626 .81984 .39453 .8319 .38012 .82642 .37211 Mtetra
.831 .788 .811 r
.82642 .37211 .8319 .38012 .84408 .36727 .83869 .35945 Mtetra
.815 .791 .83 r
.83869 .35945 .84408 .36727 .85641 .3559 .85109 .3482 Mtetra
.796 .791 .848 r
.85109 .3482 .85641 .3559 .86888 .34585 .86362 .33823 Mtetra
.776 .789 .863 r
.86362 .33823 .86888 .34585 .8815 .33696 .87629 .32938 Mtetra
.757 .785 .876 r
.87629 .32938 .8815 .33696 .89425 .32905 .8891 .32148 Mtetra
.643 .745 .923 r
.28792 .49984 .29485 .50598 .30551 .50302 .2986 .49687 Mtetra
.641 .746 .924 r
.2986 .49687 .30551 .50302 .3162 .50009 .30932 .49393 Mtetra
.64 .746 .926 r
.30932 .49393 .3162 .50009 .32694 .49719 .32008 .49102 Mtetra
.637 .745 .927 r
.32008 .49102 .32694 .49719 .33773 .49435 .3309 .48816 Mtetra
.634 .745 .928 r
.3309 .48816 .33773 .49435 .34856 .49157 .34175 .48536 Mtetra
.63 .743 .929 r
.34175 .48536 .34856 .49157 .35943 .4889 .35265 .48264 Mtetra
.624 .741 .931 r
.35265 .48264 .35943 .4889 .37035 .48637 .3636 .48005 Mtetra
.617 .738 .933 r
.3636 .48005 .37035 .48637 .38131 .48403 .37459 .47763 Mtetra
.607 .733 .934 r
.37459 .47763 .38131 .48403 .39231 .48195 .38562 .47544 Mtetra
.594 .725 .936 r
.38562 .47544 .39231 .48195 .40335 .48021 .39669 .47353 Mtetra
.578 .715 .936 r
.39669 .47353 .40335 .48021 .41444 .47889 .40781 .472 Mtetra
.557 .701 .937 r
.40781 .472 .41444 .47889 .42558 .4781 .41898 .47094 Mtetra
.532 .683 .935 r
.41898 .47094 .42558 .4781 .43676 .47795 .43019 .47043 Mtetra
.502 .66 .931 r
.43019 .47043 .43676 .47795 .448 .47854 .44145 .47059 Mtetra
.468 .631 .925 r
.44145 .47059 .448 .47854 .45929 .47999 .45278 .47152 Mtetra
.431 .598 .915 r
.45278 .47152 .45929 .47999 .47065 .4824 .46416 .4733 Mtetra
.393 .561 .901 r
.46416 .4733 .47065 .4824 .48209 .48585 .47562 .47603 Mtetra
.356 .522 .883 r
.47562 .47603 .48209 .48585 .49362 .4904 .48716 .47976 Mtetra
.323 .484 .864 r
.48716 .47976 .49362 .4904 .50525 .49607 .4988 .48453 Mtetra
.296 .448 .843 r
.4988 .48453 .50525 .49607 .51699 .50284 .51054 .49032 Mtetra
.278 .417 .823 r
.51054 .49032 .51699 .50284 .52886 .51063 .5224 .49708 Mtetra
.269 .393 .805 r
.5224 .49708 .52886 .51063 .54086 .51928 .53439 .50469 Mtetra
.27 .378 .789 r
.53439 .50469 .54086 .51928 .55302 .52859 .54652 .51297 Mtetra
.282 .371 .777 r
.54652 .51297 .55302 .52859 .56532 .53827 .55879 .52166 Mtetra
.304 .372 .768 r
.55879 .52166 .56532 .53827 .57778 .54795 .57121 .53043 Mtetra
.334 .382 .762 r
.57121 .53043 .57778 .54795 .59038 .55719 .58377 .53889 Mtetra
.373 .399 .759 r
.58377 .53889 .59038 .55719 .60311 .56551 .59647 .54658 Mtetra
.417 .421 .756 r
.59647 .54658 .60311 .56551 .61595 .57238 .60927 .55301 Mtetra
.466 .448 .754 r
.60927 .55301 .61595 .57238 .62887 .57728 .62216 .55768 Mtetra
.516 .477 .752 r
.62216 .55768 .62887 .57728 .64183 .57973 .63509 .56013 Mtetra
.566 .508 .749 r
.63509 .56013 .64183 .57973 .65478 .57934 .64804 .55996 Mtetra
.614 .537 .745 r
.64804 .55996 .65478 .57934 .66769 .57583 .66096 .55689 Mtetra
.658 .566 .74 r
.66096 .55689 .66769 .57583 .68051 .56908 .67381 .55078 Mtetra
.697 .593 .735 r
.67381 .55078 .68051 .56908 .69321 .55918 .68655 .54168 Mtetra
.732 .617 .73 r
.68655 .54168 .69321 .55918 .70576 .54636 .69918 .52978 Mtetra
.762 .639 .725 r
.69918 .52978 .70576 .54636 .71817 .53104 .71166 .51546 Mtetra
.786 .659 .722 r
.71166 .51546 .71817 .53104 .73042 .51374 .72401 .4992 Mtetra
.806 .677 .721 r
.72401 .4992 .73042 .51374 .74253 .49509 .73623 .48157 Mtetra
.822 .693 .722 r
.73623 .48157 .74253 .49509 .75454 .47571 .74835 .46317 Mtetra
.833 .708 .726 r
.74835 .46317 .75454 .47571 .76648 .45621 .7604 .44459 Mtetra
.841 .722 .733 r
.7604 .44459 .76648 .45621 .77838 .43713 .77241 .42633 Mtetra
.845 .735 .743 r
.77241 .42633 .77838 .43713 .79029 .41892 .78443 .40883 Mtetra
.844 .748 .756 r
.78443 .40883 .79029 .41892 .80225 .40189 .7965 .39241 Mtetra
.84 .758 .772 r
.7965 .39241 .80225 .40189 .81428 .38626 .80863 .37727 Mtetra
.832 .767 .79 r
.80863 .37727 .81428 .38626 .82642 .37211 .82086 .36352 Mtetra
.821 .774 .809 r
.82086 .36352 .82642 .37211 .83869 .35945 .83321 .35116 Mtetra
.806 .779 .828 r
.83321 .35116 .83869 .35945 .85109 .3482 .84568 .34014 Mtetra
.789 .781 .846 r
.84568 .34014 .85109 .3482 .86362 .33823 .85829 .33032 Mtetra
.771 .781 .861 r
.85829 .33032 .86362 .33823 .87629 .32938 .87103 .32157 Mtetra
.754 .78 .874 r
.87103 .32157 .87629 .32938 .8891 .32148 .88389 .31373 Mtetra
.642 .745 .923 r
.28093 .49364 .28792 .49984 .2986 .49687 .29163 .49067 Mtetra
.641 .745 .924 r
.29163 .49067 .2986 .49687 .30932 .49393 .30238 .48771 Mtetra
.639 .745 .925 r
.30238 .48771 .30932 .49393 .32008 .49102 .31317 .48479 Mtetra
.637 .745 .926 r
.31317 .48479 .32008 .49102 .3309 .48816 .32401 .48191 Mtetra
.634 .744 .928 r
.32401 .48191 .3309 .48816 .34175 .48536 .33489 .47908 Mtetra
.631 .743 .929 r
.33489 .47908 .34175 .48536 .35265 .48264 .34582 .47632 Mtetra
.626 .741 .93 r
.34582 .47632 .35265 .48264 .3636 .48005 .35679 .47367 Mtetra
.62 .738 .931 r
.35679 .47367 .3636 .48005 .37459 .47763 .36781 .47117 Mtetra
.611 .734 .933 r
.36781 .47117 .37459 .47763 .38562 .47544 .37887 .46885 Mtetra
.6 .727 .934 r
.37887 .46885 .38562 .47544 .39669 .47353 .38998 .46679 Mtetra
.587 .718 .934 r
.38998 .46679 .39669 .47353 .40781 .472 .40113 .46505 Mtetra
.569 .705 .934 r
.40113 .46505 .40781 .472 .41898 .47094 .41233 .46371 Mtetra
.549 .689 .932 r
.41233 .46371 .41898 .47094 .43019 .47043 .42357 .46285 Mtetra
.524 .669 .928 r
.42357 .46285 .43019 .47043 .44145 .47059 .43487 .46257 Mtetra
.496 .644 .922 r
.43487 .46257 .44145 .47059 .45278 .47152 .44622 .46296 Mtetra
.466 .615 .913 r
.44622 .46296 .45278 .47152 .46416 .4733 .45763 .46411 Mtetra
.434 .582 .9 r
.45763 .46411 .46416 .4733 .47562 .47603 .46911 .46611 Mtetra
.403 .547 .885 r
.46911 .46611 .47562 .47603 .48716 .47976 .48067 .469 Mtetra
.375 .511 .867 r
.48067 .469 .48716 .47976 .4988 .48453 .49232 .47283 Mtetra
.351 .478 .848 r
.49232 .47283 .4988 .48453 .51054 .49032 .50406 .4776 Mtetra
.334 .448 .828 r
.50406 .4776 .51054 .49032 .5224 .49708 .51592 .48327 Mtetra
.324 .424 .809 r
.51592 .48327 .5224 .49708 .53439 .50469 .52789 .48976 Mtetra
.323 .406 .793 r
.52789 .48976 .53439 .50469 .54652 .51297 .54 .4969 Mtetra
.331 .396 .779 r
.54 .4969 .54652 .51297 .55879 .52166 .55224 .50449 Mtetra
.348 .394 .768 r
.55224 .50449 .55879 .52166 .57121 .53043 .56462 .51222 Mtetra
.372 .398 .759 r
.56462 .51222 .57121 .53043 .58377 .53889 .57714 .51975 Mtetra
.403 .409 .752 r
.57714 .51975 .58377 .53889 .59647 .54658 .58979 .52665 Mtetra
.439 .426 .748 r
.58979 .52665 .59647 .54658 .60927 .55301 .60255 .53248 Mtetra
.479 .446 .744 r
.60255 .53248 .60927 .55301 .62216 .55768 .6154 .53676 Mtetra
.521 .47 .74 r
.6154 .53676 .62216 .55768 .63509 .56013 .62831 .53906 Mtetra
.564 .495 .737 r
.62831 .53906 .63509 .56013 .64804 .55996 .64124 .53898 Mtetra
.605 .521 .733 r
.64124 .53898 .64804 .55996 .66096 .55689 .65415 .53624 Mtetra
.644 .546 .729 r
.65415 .53624 .66096 .55689 .67381 .55078 .66702 .53071 Mtetra
.68 .57 .725 r
.66702 .53071 .67381 .55078 .68655 .54168 .6798 .52237 Mtetra
.712 .593 .722 r
.6798 .52237 .68655 .54168 .69918 .52978 .69248 .51141 Mtetra
.74 .615 .719 r
.69248 .51141 .69918 .52978 .71166 .51546 .70504 .49814 Mtetra
.764 .634 .717 r
.70504 .49814 .71166 .51546 .72401 .4992 .71748 .48301 Mtetra
.784 .653 .718 r
.71748 .48301 .72401 .4992 .73623 .48157 .7298 .46653 Mtetra
.8 .67 .72 r
.7298 .46653 .73623 .48157 .74835 .46317 .74203 .44926 Mtetra
.813 .686 .725 r
.74203 .44926 .74835 .46317 .7604 .44459 .7542 .43173 Mtetra
.821 .702 .733 r
.7542 .43173 .7604 .44459 .77241 .42633 .76633 .41445 Mtetra
.827 .716 .743 r
.76633 .41445 .77241 .42633 .78443 .40883 .77847 .39782 Mtetra
.828 .73 .756 r
.77847 .39782 .78443 .40883 .7965 .39241 .79064 .38215 Mtetra
.826 .742 .772 r
.79064 .38215 .7965 .39241 .80863 .37727 .80288 .36764 Mtetra
.819 .753 .79 r
.80288 .36764 .80863 .37727 .82086 .36352 .81521 .3544 Mtetra
.81 .762 .808 r
.81521 .3544 .82086 .36352 .83321 .35116 .82765 .34245 Mtetra
.797 .768 .827 r
.82765 .34245 .83321 .35116 .84568 .34014 .84021 .33173 Mtetra
.782 .772 .844 r
.84021 .33173 .84568 .34014 .85829 .33032 .85289 .32214 Mtetra
.766 .774 .86 r
.85289 .32214 .85829 .33032 .87103 .32157 .8657 .31355 Mtetra
.75 .774 .873 r
.8657 .31355 .87103 .32157 .88389 .31373 .87862 .3058 Mtetra
.642 .744 .923 r
.27389 .48737 .28093 .49364 .29163 .49067 .28462 .48439 Mtetra
.64 .744 .924 r
.28462 .48439 .29163 .49067 .30238 .48771 .29539 .48143 Mtetra
.639 .745 .925 r
.29539 .48143 .30238 .48771 .31317 .48479 .30621 .47849 Mtetra
.637 .744 .926 r
.30621 .47849 .31317 .48479 .32401 .48191 .31707 .47559 Mtetra
.635 .744 .927 r
.31707 .47559 .32401 .48191 .33489 .47908 .32798 .47273 Mtetra
.631 .743 .928 r
.32798 .47273 .33489 .47908 .34582 .47632 .33894 .46994 Mtetra
.627 .741 .929 r
.33894 .46994 .34582 .47632 .35679 .47367 .34994 .46723 Mtetra
.622 .739 .93 r
.34994 .46723 .35679 .47367 .36781 .47117 .36099 .46464 Mtetra
.615 .735 .931 r
.36099 .46464 .36781 .47117 .37887 .46885 .37208 .46221 Mtetra
.606 .729 .932 r
.37208 .46221 .37887 .46885 .38998 .46679 .38322 .46 Mtetra
.595 .721 .932 r
.38322 .46 .38998 .46679 .40113 .46505 .3944 .45805 Mtetra
.581 .71 .931 r
.3944 .45805 .40113 .46505 .41233 .46371 .40563 .45644 Mtetra
.564 .696 .93 r
.40563 .45644 .41233 .46371 .42357 .46285 .41691 .45524 Mtetra
.544 .678 .926 r
.41691 .45524 .42357 .46285 .43487 .46257 .42823 .45454 Mtetra
.521 .656 .92 r
.42823 .45454 .43487 .46257 .44622 .46296 .43962 .45441 Mtetra
.496 .63 .912 r
.43962 .45441 .44622 .46296 .45763 .46411 .45106 .45494 Mtetra
.469 .601 .901 r
.45106 .45494 .45763 .46411 .46911 .46611 .46256 .4562 Mtetra
.443 .57 .887 r
.46256 .4562 .46911 .46611 .48067 .469 .47414 .45826 Mtetra
.418 .537 .87 r
.47414 .45826 .48067 .469 .49232 .47283 .4858 .46116 Mtetra
.397 .506 .852 r
.4858 .46116 .49232 .47283 .50406 .4776 .49755 .4649 Mtetra
.381 .477 .833 r
.49755 .4649 .50406 .4776 .51592 .48327 .50941 .46948 Mtetra
.371 .453 .815 r
.50941 .46948 .51592 .48327 .52789 .48976 .52137 .47481 Mtetra
.368 .434 .798 r
.52137 .47481 .52789 .48976 .54 .4969 .53346 .48077 Mtetra
.372 .421 .783 r
.53346 .48077 .54 .4969 .55224 .50449 .54568 .48718 Mtetra
.384 .415 .77 r
.54568 .48718 .55224 .50449 .56462 .51222 .55802 .49379 Mtetra
.403 .415 .759 r
.55802 .49379 .56462 .51222 .57714 .51975 .5705 .50028 Mtetra
.427 .422 .751 r
.5705 .50028 .57714 .51975 .58979 .52665 .5831 .50627 Mtetra
.457 .433 .744 r
.5831 .50627 .58979 .52665 .60255 .53248 .59582 .51136 Mtetra
.491 .449 .738 r
.59582 .51136 .60255 .53248 .6154 .53676 .60862 .51512 Mtetra
.527 .468 .734 r
.60862 .51512 .6154 .53676 .62831 .53906 .62149 .51712 Mtetra
.563 .489 .73 r
.62149 .51712 .62831 .53906 .64124 .53898 .6344 .517 Mtetra
.6 .511 .726 r
.6344 .517 .64124 .53898 .65415 .53624 .64731 .51449 Mtetra
.634 .533 .722 r
.64731 .51449 .65415 .53624 .66702 .53071 .66018 .50943 Mtetra
.667 .555 .719 r
.66018 .50943 .66702 .53071 .6798 .52237 .67299 .50181 Mtetra
.696 .576 .717 r
.67299 .50181 .6798 .52237 .69248 .51141 .68572 .49176 Mtetra
.722 .597 .715 r
.68572 .49176 .69248 .51141 .70504 .49814 .69834 .47955 Mtetra
.745 .616 .715 r
.69834 .47955 .70504 .49814 .71748 .48301 .71086 .46558 Mtetra
.765 .634 .716 r
.71086 .46558 .71748 .48301 .7298 .46653 .72328 .45031 Mtetra
.781 .652 .72 r
.72328 .45031 .7298 .46653 .74203 .44926 .73562 .43425 Mtetra
.794 .668 .725 r
.73562 .43425 .74203 .44926 .7542 .43173 .7479 .4179 Mtetra
.803 .685 .733 r
.7479 .4179 .7542 .43173 .76633 .41445 .76015 .40171 Mtetra
.81 .7 .744 r
.76015 .40171 .76633 .41445 .77847 .39782 .77241 .38606 Mtetra
.812 .715 .758 r
.77241 .38606 .77847 .39782 .79064 .38215 .7847 .37125 Mtetra
.811 .728 .773 r
.7847 .37125 .79064 .38215 .80288 .36764 .79705 .35748 Mtetra
.806 .74 .791 r
.79705 .35748 .80288 .36764 .81521 .3544 .80949 .34485 Mtetra
.798 .751 .809 r
.80949 .34485 .81521 .3544 .82765 .34245 .82202 .33338 Mtetra
.787 .759 .827 r
.82202 .33338 .82765 .34245 .84021 .33173 .83467 .32304 Mtetra
.774 .765 .844 r
.83467 .32304 .84021 .33173 .85289 .32214 .84743 .31372 Mtetra
.759 .768 .86 r
.84743 .31372 .85289 .32214 .8657 .31355 .86031 .30533 Mtetra
.745 .769 .873 r
.86031 .30533 .8657 .31355 .87862 .3058 .8733 .2977 Mtetra
.641 .744 .923 r
.2668 .48105 .27389 .48737 .28462 .48439 .27755 .47806 Mtetra
.64 .744 .924 r
.27755 .47806 .28462 .48439 .29539 .48143 .28835 .47508 Mtetra
.638 .744 .925 r
.28835 .47508 .29539 .48143 .30621 .47849 .29919 .47213 Mtetra
.637 .744 .926 r
.29919 .47213 .30621 .47849 .31707 .47559 .31008 .46921 Mtetra
.635 .743 .927 r
.31008 .46921 .31707 .47559 .32798 .47273 .32102 .46632 Mtetra
.632 .743 .928 r
.32102 .46632 .32798 .47273 .33894 .46994 .332 .46348 Mtetra
.629 .741 .928 r
.332 .46348 .33894 .46994 .34994 .46723 .34303 .46072 Mtetra
.624 .739 .929 r
.34303 .46072 .34994 .46723 .36099 .46464 .35411 .45806 Mtetra
.618 .735 .93 r
.35411 .45806 .36099 .46464 .37208 .46221 .36523 .45552 Mtetra
.611 .73 .93 r
.36523 .45552 .37208 .46221 .38322 .46 .3764 .45316 Mtetra
.602 .724 .93 r
.3764 .45316 .38322 .46 .3944 .45805 .38761 .45102 Mtetra
.591 .714 .929 r
.38761 .45102 .3944 .45805 .40563 .45644 .39888 .44916 Mtetra
.577 .702 .928 r
.39888 .44916 .40563 .45644 .41691 .45524 .41019 .44764 Mtetra
.56 .687 .924 r
.41019 .44764 .41691 .45524 .42823 .45454 .42155 .44654 Mtetra
.542 .668 .919 r
.42155 .44654 .42823 .45454 .43962 .45441 .43296 .44592 Mtetra
.521 .646 .912 r
.43296 .44592 .43962 .45441 .45106 .45494 .44444 .44586 Mtetra
.499 .62 .902 r
.44444 .44586 .45106 .45494 .46256 .4562 .45597 .44643 Mtetra
.477 .592 .889 r
.45597 .44643 .46256 .4562 .47414 .45826 .46757 .44769 Mtetra
.455 .562 .875 r
.46757 .44769 .47414 .45826 .4858 .46116 .47925 .44968 Mtetra
.436 .533 .858 r
.47925 .44968 .4858 .46116 .49755 .4649 .49101 .45243 Mtetra
.421 .505 .84 r
.49101 .45243 .49755 .4649 .50941 .46948 .50287 .45592 Mtetra
.41 .481 .822 r
.50287 .45592 .50941 .46948 .52137 .47481 .51483 .4601 Mtetra
.405 .461 .805 r
.51483 .4601 .52137 .47481 .53346 .48077 .52691 .46487 Mtetra
.407 .446 .789 r
.52691 .46487 .53346 .48077 .54568 .48718 .5391 .47009 Mtetra
.415 .437 .775 r
.5391 .47009 .54568 .48718 .55802 .49379 .55142 .47553 Mtetra
.429 .434 .763 r
.55142 .47553 .55802 .49379 .5705 .50028 .56386 .48091 Mtetra
.449 .437 .753 r
.56386 .48091 .5705 .50028 .5831 .50627 .57642 .48592 Mtetra
.474 .444 .744 r
.57642 .48592 .5831 .50627 .59582 .51136 .58908 .49017 Mtetra
.502 .456 .738 r
.58908 .49017 .59582 .51136 .60862 .51512 .60185 .49328 Mtetra
.533 .471 .732 r
.60185 .49328 .60862 .51512 .62149 .51712 .61468 .49487 Mtetra
.565 .488 .727 r
.61468 .49487 .62149 .51712 .6344 .517 .62755 .49459 Mtetra
.597 .507 .723 r
.62755 .49459 .6344 .517 .64731 .51449 .64044 .49219 Mtetra
.627 .526 .72 r
.64044 .49219 .64731 .51449 .66018 .50943 .65332 .48751 Mtetra
.657 .546 .717 r
.65332 .48751 .66018 .50943 .67299 .50181 .66614 .48052 Mtetra
.684 .565 .715 r
.66614 .48052 .67299 .50181 .68572 .49176 .67891 .47133 Mtetra
.708 .584 .714 r
.67891 .47133 .68572 .49176 .69834 .47955 .69159 .46015 Mtetra
.73 .602 .715 r
.69159 .46015 .69834 .47955 .71086 .46558 .70418 .44734 Mtetra
.749 .62 .717 r
.70418 .44734 .71086 .46558 .72328 .45031 .71669 .43331 Mtetra
.764 .638 .721 r
.71669 .43331 .72328 .45031 .73562 .43425 .72914 .4185 Mtetra
.777 .655 .727 r
.72914 .4185 .73562 .43425 .7479 .4179 .74153 .40337 Mtetra
.787 .671 .736 r
.74153 .40337 .7479 .4179 .76015 .40171 .75391 .38833 Mtetra
.794 .687 .747 r
.75391 .38833 .76015 .40171 .77241 .38606 .76628 .37374 Mtetra
.797 .703 .76 r
.76628 .37374 .77241 .38606 .7847 .37125 .77869 .35986 Mtetra
.797 .717 .776 r
.77869 .35986 .7847 .37125 .79705 .35748 .79116 .34689 Mtetra
.794 .73 .793 r
.79116 .34689 .79705 .35748 .80949 .34485 .8037 .33493 Mtetra
.787 .742 .811 r
.8037 .33493 .80949 .34485 .82202 .33338 .81633 .32401 Mtetra
.778 .751 .829 r
.81633 .32401 .82202 .33338 .83467 .32304 .82907 .31409 Mtetra
.766 .758 .845 r
.82907 .31409 .83467 .32304 .84743 .31372 .84191 .3051 Mtetra
.753 .762 .86 r
.84191 .3051 .84743 .31372 .86031 .30533 .85487 .29693 Mtetra
.74 .765 .873 r
.85487 .29693 .86031 .30533 .8733 .2977 .86793 .28947 Mtetra
.641 .743 .923 r
.25965 .47465 .2668 .48105 .27755 .47806 .27043 .47165 Mtetra
.639 .743 .924 r
.27043 .47165 .27755 .47806 .28835 .47508 .28125 .46866 Mtetra
.638 .743 .925 r
.28125 .46866 .28835 .47508 .29919 .47213 .29212 .46569 Mtetra
.637 .743 .925 r
.29212 .46569 .29919 .47213 .31008 .46921 .30304 .46275 Mtetra
.635 .743 .926 r
.30304 .46275 .31008 .46921 .32102 .46632 .314 .45984 Mtetra
.633 .742 .927 r
.314 .45984 .32102 .46632 .332 .46348 .32501 .45697 Mtetra
.63 .741 .928 r
.32501 .45697 .332 .46348 .34303 .46072 .33607 .45415 Mtetra
.626 .739 .928 r
.33607 .45415 .34303 .46072 .35411 .45806 .34717 .45142 Mtetra
.622 .736 .929 r
.34717 .45142 .35411 .45806 .36523 .45552 .35833 .44878 Mtetra
.616 .732 .929 r
.35833 .44878 .36523 .45552 .3764 .45316 .36953 .44629 Mtetra
.608 .726 .929 r
.36953 .44629 .3764 .45316 .38761 .45102 .38078 .44398 Mtetra
.599 .718 .928 r
.38078 .44398 .38761 .45102 .39888 .44916 .39207 .44189 Mtetra
.588 .708 .926 r
.39207 .44189 .39888 .44916 .41019 .44764 .40342 .44008 Mtetra
.575 .695 .923 r
.40342 .44008 .41019 .44764 .42155 .44654 .41481 .43861 Mtetra
.56 .679 .919 r
.41481 .43861 .42155 .44654 .43296 .44592 .42626 .43754 Mtetra
.543 .66 .912 r
.42626 .43754 .43296 .44592 .44444 .44586 .43776 .43693 Mtetra
.525 .637 .904 r
.43776 .43693 .44444 .44586 .45597 .44643 .44933 .43686 Mtetra
.506 .613 .893 r
.44933 .43686 .45597 .44643 .46757 .44769 .46096 .43737 Mtetra
.487 .586 .879 r
.46096 .43737 .46757 .44769 .47925 .44968 .47266 .43852 Mtetra
.47 .559 .864 r
.47266 .43852 .47925 .44968 .49101 .45243 .48444 .44031 Mtetra
.455 .533 .847 r
.48444 .44031 .49101 .45243 .50287 .45592 .49631 .44277 Mtetra
.445 .509 .83 r
.49631 .44277 .50287 .45592 .51483 .4601 .50827 .44584 Mtetra
.439 .488 .813 r
.50827 .44584 .51483 .4601 .52691 .46487 .52033 .44946 Mtetra
.438 .472 .797 r
.52033 .44946 .52691 .46487 .5391 .47009 .53251 .45349 Mtetra
.443 .46 .782 r
.53251 .45349 .5391 .47009 .55142 .47553 .5448 .45775 Mtetra
.454 .454 .769 r
.5448 .45775 .55142 .47553 .56386 .48091 .55721 .46201 Mtetra
.47 .454 .758 r
.55721 .46201 .56386 .48091 .57642 .48592 .56973 .46598 Mtetra
.49 .458 .748 r
.56973 .46598 .57642 .48592 .58908 .49017 .58236 .46934 Mtetra
.514 .466 .74 r
.58236 .46934 .58908 .49017 .60185 .49328 .59508 .47172 Mtetra
.54 .477 .734 r
.59508 .47172 .60185 .49328 .61468 .49487 .60787 .4728 Mtetra
.568 .491 .728 r
.60787 .4728 .61468 .49487 .62755 .49459 .62071 .47227 Mtetra
.596 .506 .724 r
.62071 .47227 .62755 .49459 .64044 .49219 .63358 .46988 Mtetra
.623 .523 .72 r
.63358 .46988 .64044 .49219 .65332 .48751 .64645 .46548 Mtetra
.65 .541 .717 r
.64645 .46548 .65332 .48751 .66614 .48052 .65929 .45903 Mtetra
.674 .558 .716 r
.65929 .45903 .66614 .48052 .67891 .47133 .67208 .4506 Mtetra
.697 .576 .716 r
.67208 .4506 .67891 .47133 .69159 .46015 .68481 .4404 Mtetra
.717 .593 .717 r
.68481 .4404 .69159 .46015 .70418 .44734 .69747 .42871 Mtetra
.735 .611 .719 r
.69747 .42871 .70418 .44734 .71669 .43331 .71007 .41588 Mtetra
.75 .628 .724 r
.71007 .41588 .71669 .43331 .72914 .4185 .72261 .40232 Mtetra
.763 .645 .731 r
.72261 .40232 .72914 .4185 .74153 .40337 .73512 .38842 Mtetra
.773 .661 .74 r
.73512 .38842 .74153 .40337 .75391 .38833 .7476 .37456 Mtetra
.78 .678 .751 r
.7476 .37456 .75391 .38833 .76628 .37374 .7601 .36105 Mtetra
.784 .694 .765 r
.7601 .36105 .76628 .37374 .77869 .35986 .77262 .34815 Mtetra
.784 .709 .78 r
.77262 .34815 .77869 .35986 .79116 .34689 .7852 .33602 Mtetra
.782 .722 .797 r
.7852 .33602 .79116 .34689 .8037 .33493 .79785 .32476 Mtetra
.776 .734 .814 r
.79785 .32476 .8037 .33493 .81633 .32401 .81058 .31441 Mtetra
.768 .744 .831 r
.81058 .31441 .81633 .32401 .82907 .31409 .82341 .30495 Mtetra
.758 .752 .847 r
.82341 .30495 .82907 .31409 .84191 .3051 .83634 .2963 Mtetra
.746 .757 .862 r
.83634 .2963 .84191 .3051 .85487 .29693 .84937 .28839 Mtetra
.734 .761 .874 r
.84937 .28839 .85487 .29693 .86793 .28947 .8625 .2811 Mtetra
.64 .742 .923 r
.25245 .46818 .25965 .47465 .27043 .47165 .26325 .46517 Mtetra
.639 .742 .923 r
.26325 .46517 .27043 .47165 .28125 .46866 .2741 .46217 Mtetra
.638 .742 .924 r
.2741 .46217 .28125 .46866 .29212 .46569 .28499 .45919 Mtetra
.636 .742 .925 r
.28499 .45919 .29212 .46569 .30304 .46275 .29594 .45622 Mtetra
.635 .742 .926 r
.29594 .45622 .30304 .46275 .314 .45984 .30693 .45328 Mtetra
.633 .741 .926 r
.30693 .45328 .314 .45984 .32501 .45697 .31796 .45038 Mtetra
.631 .741 .927 r
.31796 .45038 .32501 .45697 .33607 .45415 .32905 .44751 Mtetra
.628 .739 .927 r
.32905 .44751 .33607 .45415 .34717 .45142 .34019 .44471 Mtetra
.624 .737 .928 r
.34019 .44471 .34717 .45142 .35833 .44878 .35137 .442 Mtetra
.619 .733 .928 r
.35137 .442 .35833 .44878 .36953 .44629 .3626 .43938 Mtetra
.614 .729 .928 r
.3626 .43938 .36953 .44629 .38078 .44398 .37388 .43691 Mtetra
.606 .722 .927 r
.37388 .43691 .38078 .44398 .39207 .44189 .38521 .43462 Mtetra
.598 .714 .925 r
.38521 .43462 .39207 .44189 .40342 .44008 .39659 .43255 Mtetra
.587 .703 .923 r
.39659 .43255 .40342 .44008 .41481 .43861 .40802 .43075 Mtetra
.575 .689 .919 r
.40802 .43075 .41481 .43861 .42626 .43754 .4195 .42928 Mtetra
.561 .673 .913 r
.4195 .42928 .42626 .43754 .43776 .43693 .43104 .42819 Mtetra
.546 .654 .906 r
.43104 .42819 .43776 .43693 .44933 .43686 .44264 .42753 Mtetra
.531 .632 .896 r
.44264 .42753 .44933 .43686 .46096 .43737 .4543 .42737 Mtetra
.515 .609 .884 r
.4543 .42737 .46096 .43737 .47266 .43852 .46602 .42773 Mtetra
.499 .584 .871 r
.46602 .42773 .47266 .43852 .48444 .44031 .47782 .42866 Mtetra
.486 .559 .856 r
.47782 .42866 .48444 .44031 .49631 .44277 .4897 .43014 Mtetra
.476 .536 .839 r
.4897 .43014 .49631 .44277 .50827 .44584 .50167 .43218 Mtetra
.469 .515 .823 r
.50167 .43218 .50827 .44584 .52033 .44946 .51374 .43469 Mtetra
.467 .498 .807 r
.51374 .43469 .52033 .44946 .53251 .45349 .5259 .43758 Mtetra
.469 .485 .792 r
.5259 .43758 .53251 .45349 .5448 .45775 .53818 .44071 Mtetra
.477 .476 .778 r
.53818 .44071 .5448 .45775 .55721 .46201 .55056 .44385 Mtetra
.489 .473 .766 r
.55056 .44385 .55721 .46201 .56973 .46598 .56305 .44678 Mtetra
.506 .474 .755 r
.56305 .44678 .56973 .46598 .58236 .46934 .57564 .44921 Mtetra
.526 .478 .746 r
.57564 .44921 .58236 .46934 .59508 .47172 .58832 .45083 Mtetra
.548 .487 .739 r
.58832 .45083 .59508 .47172 .60787 .4728 .60108 .45134 Mtetra
.572 .497 .732 r
.60108 .45134 .60787 .4728 .62071 .47227 .61389 .45047 Mtetra
.597 .51 .727 r
.61389 .45047 .62071 .47227 .63358 .46988 .62674 .44799 Mtetra
.621 .525 .723 r
.62674 .44799 .63358 .46988 .64645 .46548 .6396 .44378 Mtetra
.645 .54 .721 r
.6396 .44378 .64645 .46548 .65929 .45903 .65244 .43777 Mtetra
.667 .556 .719 r
.65244 .43777 .65929 .45903 .67208 .4506 .66526 .43003 Mtetra
.688 .572 .719 r
.66526 .43003 .67208 .4506 .68481 .4404 .67803 .42071 Mtetra
.707 .588 .721 r
.67803 .42071 .68481 .4404 .69747 .42871 .69076 .41006 Mtetra
.724 .605 .724 r
.69076 .41006 .69747 .42871 .71007 .41588 .70343 .39838 Mtetra
.738 .622 .729 r
.70343 .39838 .71007 .41588 .72261 .40232 .71606 .38602 Mtetra
.75 .638 .736 r
.71606 .38602 .72261 .40232 .73512 .38842 .72867 .37333 Mtetra
.76 .655 .746 r
.72867 .37333 .73512 .38842 .7476 .37456 .74127 .36062 Mtetra
.767 .671 .757 r
.74127 .36062 .7476 .37456 .7601 .36105 .75387 .34819 Mtetra
.771 .687 .771 r
.75387 .34819 .7601 .36105 .77262 .34815 .76651 .33625 Mtetra
.772 .702 .786 r
.76651 .33625 .77262 .34815 .7852 .33602 .7792 .32497 Mtetra
.77 .716 .802 r
.7792 .32497 .7852 .33602 .79785 .32476 .79195 .31443 Mtetra
.765 .729 .819 r
.79195 .31443 .79785 .32476 .81058 .31441 .80478 .30466 Mtetra
.758 .739 .835 r
.80478 .30466 .81058 .31441 .82341 .30495 .8177 .29566 Mtetra
.749 .748 .85 r
.8177 .29566 .82341 .30495 .83634 .2963 .83072 .28738 Mtetra
.739 .754 .864 r
.83072 .28738 .83634 .2963 .84937 .28839 .84382 .27972 Mtetra
.729 .757 .875 r
.84382 .27972 .84937 .28839 .8625 .2811 .85703 .27261 Mtetra
.64 .741 .922 r
.2452 .46164 .25245 .46818 .26325 .46517 .25602 .45861 Mtetra
.639 .741 .923 r
.25602 .45861 .26325 .46517 .2741 .46217 .26689 .4556 Mtetra
.637 .741 .924 r
.26689 .4556 .2741 .46217 .28499 .45919 .27781 .4526 Mtetra
.636 .741 .924 r
.27781 .4526 .28499 .45919 .29594 .45622 .28878 .44961 Mtetra
.635 .741 .925 r
.28878 .44961 .29594 .45622 .30693 .45328 .2998 .44665 Mtetra
.633 .741 .926 r
.2998 .44665 .30693 .45328 .31796 .45038 .31086 .44371 Mtetra
.631 .74 .926 r
.31086 .44371 .31796 .45038 .32905 .44751 .32198 .44081 Mtetra
.629 .739 .927 r
.32198 .44081 .32905 .44751 .34019 .44471 .33314 .43795 Mtetra
.626 .737 .927 r
.33314 .43795 .34019 .44471 .35137 .442 .34436 .43515 Mtetra
.622 .734 .927 r
.34436 .43515 .35137 .442 .3626 .43938 .35562 .43244 Mtetra
.618 .731 .927 r
.35562 .43244 .3626 .43938 .37388 .43691 .36693 .42983 Mtetra
.612 .725 .926 r
.36693 .42983 .37388 .43691 .38521 .43462 .3783 .42736 Mtetra
.606 .718 .925 r
.3783 .42736 .38521 .43462 .39659 .43255 .38971 .42506 Mtetra
.597 .71 .922 r
.38971 .42506 .39659 .43255 .40802 .43075 .40117 .42298 Mtetra
.588 .698 .919 r
.40117 .42298 .40802 .43075 .4195 .42928 .41269 .42115 Mtetra
.577 .685 .914 r
.41269 .42115 .4195 .42928 .43104 .42819 .42426 .41963 Mtetra
.565 .669 .908 r
.42426 .41963 .43104 .42819 .44264 .42753 .43589 .41846 Mtetra
.552 .65 .9 r
.43589 .41846 .44264 .42753 .4543 .42737 .44758 .41769 Mtetra
.538 .629 .89 r
.44758 .41769 .4543 .42737 .46602 .42773 .45934 .41736 Mtetra
.525 .607 .878 r
.45934 .41736 .46602 .42773 .47782 .42866 .47116 .4175 Mtetra
.513 .585 .864 r
.47116 .4175 .47782 .42866 .4897 .43014 .48306 .41811 Mtetra
.503 .563 .849 r
.48306 .41811 .4897 .43014 .50167 .43218 .49504 .41918 Mtetra
.496 .542 .834 r
.49504 .41918 .50167 .43218 .51374 .43469 .50711 .42067 Mtetra
.493 .525 .818 r
.50711 .42067 .51374 .43469 .5259 .43758 .51928 .4225 Mtetra
.494 .51 .803 r
.51928 .4225 .5259 .43758 .53818 .44071 .53154 .42454 Mtetra
.499 .5 .789 r
.53154 .42454 .53818 .44071 .55056 .44385 .54391 .42662 Mtetra
.508 .494 .776 r
.54391 .42662 .55056 .44385 .56305 .44678 .55637 .42853 Mtetra
.522 .492 .765 r
.55637 .42853 .56305 .44678 .57564 .44921 .56893 .43004 Mtetra
.538 .494 .755 r
.56893 .43004 .57564 .44921 .58832 .45083 .58158 .43087 Mtetra
.557 .499 .746 r
.58158 .43087 .58832 .45083 .60108 .45134 .59431 .43078 Mtetra
.578 .507 .739 r
.59431 .43078 .60108 .45134 .61389 .45047 .60709 .42952 Mtetra
.599 .518 .734 r
.60709 .42952 .61389 .45047 .62674 .44799 .61992 .42689 Mtetra
.621 .53 .73 r
.61992 .42689 .62674 .44799 .6396 .44378 .63277 .42278 Mtetra
.642 .543 .727 r
.63277 .42278 .6396 .44378 .65244 .43777 .64562 .41712 Mtetra
.662 .557 .726 r
.64562 .41712 .65244 .43777 .66526 .43003 .65845 .40997 Mtetra
.681 .572 .726 r
.65845 .40997 .66526 .43003 .67803 .42071 .67127 .40144 Mtetra
.699 .587 .727 r
.67127 .40144 .67803 .42071 .69076 .41006 .68404 .39174 Mtetra
.714 .603 .731 r
.68404 .39174 .69076 .41006 .70343 .39838 .69679 .38113 Mtetra
.728 .619 .736 r
.69679 .38113 .70343 .39838 .71606 .38602 .70951 .36989 Mtetra
.739 .635 .744 r
.70951 .36989 .71606 .38602 .72867 .37333 .72221 .35833 Mtetra
.749 .652 .753 r
.72221 .35833 .72867 .37333 .74127 .36062 .7349 .34673 Mtetra
.755 .668 .765 r
.7349 .34673 .74127 .36062 .75387 .34819 .74762 .33533 Mtetra
.76 .684 .778 r
.74762 .33533 .75387 .34819 .76651 .33625 .76036 .32433 Mtetra
.761 .699 .793 r
.76036 .32433 .76651 .33625 .7792 .32497 .77315 .31386 Mtetra
.759 .713 .809 r
.77315 .31386 .7792 .32497 .79195 .31443 .78601 .30402 Mtetra
.755 .725 .824 r
.78601 .30402 .79195 .31443 .80478 .30466 .79894 .29483 Mtetra
.749 .736 .84 r
.79894 .29483 .80478 .30466 .8177 .29566 .81195 .28629 Mtetra
.741 .744 .854 r
.81195 .28629 .8177 .29566 .83072 .28738 .82504 .27835 Mtetra
.733 .751 .867 r
.82504 .27835 .83072 .28738 .84382 .27972 .83823 .27096 Mtetra
.724 .755 .877 r
.83823 .27096 .84382 .27972 .85703 .27261 .8515 .26403 Mtetra
.639 .74 .922 r
.23789 .45502 .2452 .46164 .25602 .45861 .24874 .45198 Mtetra
.638 .74 .922 r
.24874 .45198 .25602 .45861 .26689 .4556 .25964 .44895 Mtetra
.637 .74 .923 r
.25964 .44895 .26689 .4556 .27781 .4526 .27058 .44593 Mtetra
.636 .74 .924 r
.27058 .44593 .27781 .4526 .28878 .44961 .28157 .44293 Mtetra
.635 .74 .924 r
.28157 .44293 .28878 .44961 .2998 .44665 .29262 .43994 Mtetra
.634 .74 .925 r
.29262 .43994 .2998 .44665 .31086 .44371 .30371 .43697 Mtetra
.632 .739 .925 r
.30371 .43697 .31086 .44371 .32198 .44081 .31485 .43403 Mtetra
.63 .738 .926 r
.31485 .43403 .32198 .44081 .33314 .43795 .32605 .43112 Mtetra
.628 .737 .926 r
.32605 .43112 .33314 .43795 .34436 .43515 .33729 .42825 Mtetra
.625 .735 .926 r
.33729 .42825 .34436 .43515 .35562 .43244 .34858 .42545 Mtetra
.622 .732 .926 r
.34858 .42545 .35562 .43244 .36693 .42983 .35993 .42272 Mtetra
.617 .728 .925 r
.35993 .42272 .36693 .42983 .3783 .42736 .37132 .4201 Mtetra
.612 .722 .924 r
.37132 .4201 .3783 .42736 .38971 .42506 .38277 .41761 Mtetra
.606 .715 .922 r
.38277 .41761 .38971 .42506 .40117 .42298 .39427 .41528 Mtetra
.598 .706 .919 r
.39427 .41528 .40117 .42298 .41269 .42115 .40582 .41315 Mtetra
.59 .695 .915 r
.40582 .41315 .41269 .42115 .42426 .41963 .41743 .41126 Mtetra
.58 .682 .91 r
.41743 .41126 .42426 .41963 .43589 .41846 .42909 .40964 Mtetra
.57 .666 .903 r
.42909 .40964 .43589 .41846 .44758 .41769 .44081 .40835 Mtetra
.559 .648 .895 r
.44081 .40835 .44758 .41769 .45934 .41736 .4526 .4074 Mtetra
.547 .629 .884 r
.4526 .4074 .45934 .41736 .47116 .4175 .46445 .40684 Mtetra
.537 .609 .872 r
.46445 .40684 .47116 .4175 .48306 .41811 .47637 .40667 Mtetra
.528 .589 .859 r
.47637 .40667 .48306 .41811 .49504 .41918 .48837 .40689 Mtetra
.521 .569 .845 r
.48837 .40689 .49504 .41918 .50711 .42067 .50046 .40745 Mtetra
.517 .552 .83 r
.50046 .40745 .50711 .42067 .51928 .4225 .51263 .4083 Mtetra
.517 .537 .815 r
.51263 .4083 .51928 .4225 .53154 .42454 .52489 .40933 Mtetra
.52 .525 .801 r
.52489 .40933 .53154 .42454 .54391 .42662 .53724 .41041 Mtetra
.527 .517 .788 r
.53724 .41041 .54391 .42662 .55637 .42853 .54969 .41137 Mtetra
.538 .513 .776 r
.54969 .41137 .55637 .42853 .56893 .43004 .56223 .41199 Mtetra
.551 .512 .766 r
.56223 .41199 .56893 .43004 .58158 .43087 .57486 .41206 Mtetra
.567 .515 .756 r
.57486 .41206 .58158 .43087 .59431 .43078 .58756 .41135 Mtetra
.585 .521 .749 r
.58756 .41135 .59431 .43078 .60709 .42952 .60032 .40967 Mtetra
.603 .528 .743 r
.60032 .40967 .60709 .42952 .61992 .42689 .61313 .40685 Mtetra
.622 .538 .738 r
.61313 .40685 .61992 .42689 .63277 .42278 .62597 .40276 Mtetra
.641 .55 .735 r
.62597 .40276 .63277 .42278 .64562 .41712 .63882 .39738 Mtetra
.659 .562 .734 r
.63882 .39738 .64562 .41712 .65845 .40997 .65168 .39071 Mtetra
.676 .575 .734 r
.65168 .39071 .65845 .40997 .67127 .40144 .66452 .38286 Mtetra
.692 .59 .736 r
.66452 .38286 .67127 .40144 .68404 .39174 .67735 .37401 Mtetra
.707 .604 .74 r
.67735 .37401 .68404 .39174 .69679 .38113 .69016 .36435 Mtetra
.719 .62 .745 r
.69016 .36435 .69679 .38113 .70951 .36989 .70295 .35415 Mtetra
.73 .635 .753 r
.70295 .35415 .70951 .36989 .72221 .35833 .71574 .34363 Mtetra
.739 .651 .763 r
.71574 .34363 .72221 .35833 .7349 .34673 .72853 .33305 Mtetra
.745 .667 .774 r
.72853 .33305 .7349 .34673 .74762 .33533 .74134 .32262 Mtetra
.749 .683 .787 r
.74134 .32262 .74762 .33533 .76036 .32433 .75419 .31249 Mtetra
.751 .697 .801 r
.75419 .31249 .76036 .32433 .77315 .31386 .76708 .3028 Mtetra
.749 .711 .816 r
.76708 .3028 .77315 .31386 .78601 .30402 .78003 .29362 Mtetra
.746 .723 .831 r
.78003 .29362 .78601 .30402 .79894 .29483 .79305 .28498 Mtetra
.741 .734 .845 r
.79305 .28498 .79894 .29483 .81195 .28629 .80615 .27687 Mtetra
.734 .742 .858 r
.80615 .27687 .81195 .28629 .82504 .27835 .81933 .26927 Mtetra
.726 .748 .87 r
.81933 .26927 .82504 .27835 .83823 .27096 .83259 .26212 Mtetra
.719 .753 .879 r
.83259 .26212 .83823 .27096 .8515 .26403 .84593 .25537 Mtetra
.639 .739 .921 r
.23053 .44833 .23789 .45502 .24874 .45198 .2414 .44527 Mtetra
.638 .739 .922 r
.2414 .44527 .24874 .45198 .25964 .44895 .25232 .44222 Mtetra
.637 .739 .923 r
.25232 .44222 .25964 .44895 .27058 .44593 .26329 .43918 Mtetra
.636 .739 .923 r
.26329 .43918 .27058 .44593 .28157 .44293 .27431 .43615 Mtetra
.635 .739 .924 r
.27431 .43615 .28157 .44293 .29262 .43994 .28538 .43314 Mtetra
.634 .739 .924 r
.28538 .43314 .29262 .43994 .30371 .43697 .2965 .43014 Mtetra
.632 .739 .925 r
.2965 .43014 .30371 .43697 .31485 .43403 .30767 .42716 Mtetra
.631 .738 .925 r
.30767 .42716 .31485 .43403 .32605 .43112 .31889 .42421 Mtetra
.629 .737 .925 r
.31889 .42421 .32605 .43112 .33729 .42825 .33017 .42128 Mtetra
.627 .735 .925 r
.33017 .42128 .33729 .42825 .34858 .42545 .34149 .4184 Mtetra
.624 .733 .925 r
.34149 .4184 .34858 .42545 .35993 .42272 .35287 .41558 Mtetra
.621 .73 .924 r
.35287 .41558 .35993 .42272 .37132 .4201 .36429 .41283 Mtetra
.617 .725 .923 r
.36429 .41283 .37132 .4201 .38277 .41761 .37577 .41017 Mtetra
.613 .72 .922 r
.37577 .41017 .38277 .41761 .39427 .41528 .38731 .40764 Mtetra
.607 .713 .919 r
.38731 .40764 .39427 .41528 .40582 .41315 .39889 .40525 Mtetra
.6 .704 .916 r
.39889 .40525 .40582 .41315 .41743 .41126 .41054 .40304 Mtetra
.593 .693 .912 r
.41054 .40304 .41743 .41126 .42909 .40964 .42223 .40105 Mtetra
.585 .68 .906 r
.42223 .40105 .42909 .40964 .44081 .40835 .43399 .3993 Mtetra
.576 .665 .899 r
.43399 .3993 .44081 .40835 .4526 .4074 .44581 .39783 Mtetra
.567 .649 .89 r
.44581 .39783 .4526 .4074 .46445 .40684 .45769 .39667 Mtetra
.558 .631 .88 r
.45769 .39667 .46445 .40684 .47637 .40667 .46964 .39581 Mtetra
.55 .613 .868 r
.46964 .39581 .47637 .40667 .48837 .40689 .48166 .39527 Mtetra
.543 .595 .856 r
.48166 .39527 .48837 .40689 .50046 .40745 .49376 .39501 Mtetra
.539 .578 .842 r
.49376 .39501 .50046 .40745 .51263 .4083 .50594 .39498 Mtetra
.538 .563 .828 r
.50594 .39498 .51263 .4083 .52489 .40933 .51821 .39511 Mtetra
.54 .551 .814 r
.51821 .39511 .52489 .40933 .53724 .41041 .53056 .39528 Mtetra
.545 .541 .801 r
.53056 .39528 .53724 .41041 .54969 .41137 .543 .39534 Mtetra
.554 .536 .789 r
.543 .39534 .54969 .41137 .56223 .41199 .55553 .39514 Mtetra
.565 .533 .778 r
.55553 .39514 .56223 .41199 .57486 .41206 .56814 .39448 Mtetra
.578 .533 .769 r
.56814 .39448 .57486 .41206 .58756 .41135 .58082 .39318 Mtetra
.593 .537 .761 r
.58082 .39318 .58756 .41135 .60032 .40967 .59357 .39108 Mtetra
.609 .542 .754 r
.59357 .39108 .60032 .40967 .61313 .40685 .60636 .38802 Mtetra
.625 .55 .749 r
.60636 .38802 .61313 .40685 .62597 .40276 .6192 .38392 Mtetra
.642 .559 .746 r
.6192 .38392 .62597 .40276 .63882 .39738 .63206 .37872 Mtetra
.658 .57 .745 r
.63206 .37872 .63882 .39738 .65168 .39071 .64493 .37245 Mtetra
.673 .582 .745 r
.64493 .37245 .65168 .39071 .66452 .38286 .6578 .36519 Mtetra
.688 .595 .747 r
.6578 .36519 .66452 .38286 .67735 .37401 .67067 .35707 Mtetra
.701 .609 .751 r
.67067 .35707 .67735 .37401 .69016 .36435 .68354 .34826 Mtetra
.712 .623 .756 r
.68354 .34826 .69016 .36435 .70295 .35415 .6964 .33896 Mtetra
.722 .638 .764 r
.6964 .33896 .70295 .35415 .71574 .34363 .70927 .32939 Mtetra
.73 .654 .773 r
.70927 .32939 .71574 .34363 .72853 .33305 .72215 .31973 Mtetra
.736 .669 .785 r
.72215 .31973 .72853 .33305 .74134 .32262 .73506 .31017 Mtetra
.74 .684 .797 r
.73506 .31017 .74134 .32262 .75419 .31249 .748 .30084 Mtetra
.741 .698 .81 r
.748 .30084 .75419 .31249 .76708 .3028 .76098 .29186 Mtetra
.74 .711 .824 r
.76098 .29186 .76708 .3028 .78003 .29362 .77402 .28328 Mtetra
.737 .723 .838 r
.77402 .28328 .78003 .29362 .79305 .28498 .78713 .27514 Mtetra
.733 .733 .851 r
.78713 .27514 .79305 .28498 .80615 .27687 .80031 .26744 Mtetra
.727 .741 .863 r
.80031 .26744 .80615 .27687 .81933 .26927 .81357 .26015 Mtetra
.721 .747 .873 r
.81357 .26015 .81933 .26927 .83259 .26212 .8269 .25323 Mtetra
.714 .752 .882 r
.8269 .25323 .83259 .26212 .84593 .25537 .84031 .24664 Mtetra
.639 .739 .921 r
.22311 .44155 .23053 .44833 .2414 .44527 .23401 .43847 Mtetra
.638 .738 .921 r
.23401 .43847 .2414 .44527 .25232 .44222 .24495 .4354 Mtetra
.637 .738 .922 r
.24495 .4354 .25232 .44222 .26329 .43918 .25595 .43234 Mtetra
.636 .738 .922 r
.25595 .43234 .26329 .43918 .27431 .43615 .26699 .42929 Mtetra
.635 .738 .923 r
.26699 .42929 .27431 .43615 .28538 .43314 .27809 .42625 Mtetra
.634 .738 .923 r
.27809 .42625 .28538 .43314 .2965 .43014 .28924 .42323 Mtetra
.633 .738 .924 r
.28924 .42323 .2965 .43014 .30767 .42716 .30044 .42021 Mtetra
.632 .737 .924 r
.30044 .42021 .30767 .42716 .31889 .42421 .31169 .41722 Mtetra
.63 .736 .924 r
.31169 .41722 .31889 .42421 .33017 .42128 .32299 .41424 Mtetra
.629 .735 .924 r
.32299 .41424 .33017 .42128 .34149 .4184 .33434 .41129 Mtetra
.627 .733 .924 r
.33434 .41129 .34149 .4184 .35287 .41558 .34575 .40838 Mtetra
.624 .731 .923 r
.34575 .40838 .35287 .41558 .36429 .41283 .35721 .40552 Mtetra
.621 .728 .923 r
.35721 .40552 .36429 .41283 .37577 .41017 .36872 .40273 Mtetra
.618 .723 .921 r
.36872 .40273 .37577 .41017 .38731 .40764 .38029 .40002 Mtetra
.614 .718 .919 r
.38029 .40002 .38731 .40764 .39889 .40525 .39191 .39742 Mtetra
.609 .711 .917 r
.39191 .39742 .39889 .40525 .41054 .40304 .40359 .39496 Mtetra
.603 .702 .913 r
.40359 .39496 .41054 .40304 .42223 .40105 .41532 .39265 Mtetra
.597 .692 .909 r
.41532 .39265 .42223 .40105 .43399 .3993 .42711 .39052 Mtetra
.59 .679 .903 r
.42711 .39052 .43399 .3993 .44581 .39783 .43896 .38861 Mtetra
.583 .666 .896 r
.43896 .38861 .44581 .39783 .45769 .39667 .45087 .38692 Mtetra
.575 .651 .887 r
.45087 .38692 .45769 .39667 .46964 .39581 .46285 .38548 Mtetra
.569 .635 .877 r
.46285 .38548 .46964 .39581 .48166 .39527 .4749 .38428 Mtetra
.563 .619 .866 r
.4749 .38428 .48166 .39527 .49376 .39501 .48702 .3833 Mtetra
.56 .603 .854 r
.48702 .3833 .49376 .39501 .50594 .39498 .49922 .38251 Mtetra
.558 .589 .841 r
.49922 .38251 .50594 .39498 .51821 .39511 .51149 .38184 Mtetra
.559 .576 .828 r
.51149 .38184 .51821 .39511 .53056 .39528 .52385 .38119 Mtetra
.563 .566 .815 r
.52385 .38119 .53056 .39528 .543 .39534 .53629 .38045 Mtetra
.569 .559 .803 r
.53629 .38045 .543 .39534 .55553 .39514 .54882 .3795 Mtetra
.578 .555 .792 r
.54882 .3795 .55553 .39514 .56814 .39448 .56142 .37817 Mtetra
.589 .554 .783 r
.56142 .37817 .56814 .39448 .58082 .39318 .57409 .37631 Mtetra
.602 .555 .774 r
.57409 .37631 .58082 .39318 .59357 .39108 .58683 .3738 Mtetra
.615 .559 .768 r
.58683 .3738 .59357 .39108 .60636 .38802 .59962 .3705 Mtetra
.629 .564 .763 r
.59962 .3705 .60636 .38802 .6192 .38392 .61245 .36634 Mtetra
.644 .572 .759 r
.61245 .36634 .6192 .38392 .63206 .37872 .62532 .36127 Mtetra
.658 .581 .758 r
.62532 .36127 .63206 .37872 .64493 .37245 .63821 .35532 Mtetra
.672 .592 .758 r
.63821 .35532 .64493 .37245 .6578 .36519 .65111 .34854 Mtetra
.685 .604 .76 r
.65111 .34854 .6578 .36519 .67067 .35707 .66402 .34104 Mtetra
.696 .617 .763 r
.66402 .34104 .67067 .35707 .68354 .34826 .67694 .33296 Mtetra
.707 .63 .769 r
.67694 .33296 .68354 .34826 .6964 .33896 .68987 .32445 Mtetra
.716 .644 .776 r
.68987 .32445 .6964 .33896 .70927 .32939 .70281 .3157 Mtetra
.723 .659 .786 r
.70281 .3157 .70927 .32939 .72215 .31973 .71577 .30685 Mtetra
.728 .673 .796 r
.71577 .30685 .72215 .31973 .73506 .31017 .72876 .29806 Mtetra
.731 .687 .808 r
.72876 .29806 .73506 .31017 .748 .30084 .74179 .28945 Mtetra
.733 .701 .82 r
.74179 .28945 .748 .30084 .76098 .29186 .75486 .28109 Mtetra
.732 .713 .833 r
.75486 .28109 .76098 .29186 .77402 .28328 .76799 .27305 Mtetra
.729 .724 .845 r
.76799 .27305 .77402 .28328 .78713 .27514 .78118 .26536 Mtetra
.725 .733 .857 r
.78118 .26536 .78713 .27514 .80031 .26744 .79444 .25802 Mtetra
.721 .741 .868 r
.79444 .25802 .80031 .26744 .81357 .26015 .80776 .25101 Mtetra
.715 .747 .877 r
.80776 .25101 .81357 .26015 .8269 .25323 .82116 .24429 Mtetra
.71 .751 .884 r
.82116 .24429 .8269 .25323 .84031 .24664 .83464 .23784 Mtetra
.639 .738 .92 r
.21563 .43469 .22311 .44155 .23401 .43847 .22656 .43159 Mtetra
.638 .737 .921 r
.22656 .43159 .23401 .43847 .24495 .4354 .23753 .4285 Mtetra
.637 .737 .921 r
.23753 .4285 .24495 .4354 .25595 .43234 .24855 .42542 Mtetra
.636 .737 .922 r
.24855 .42542 .25595 .43234 .26699 .42929 .25962 .42234 Mtetra
.635 .737 .922 r
.25962 .42234 .26699 .42929 .27809 .42625 .27074 .41928 Mtetra
.634 .737 .922 r
.27074 .41928 .27809 .42625 .28924 .42323 .28192 .41622 Mtetra
.633 .737 .923 r
.28192 .41622 .28924 .42323 .30044 .42021 .29314 .41317 Mtetra
.632 .736 .923 r
.29314 .41317 .30044 .42021 .31169 .41722 .30442 .41014 Mtetra
.631 .736 .923 r
.30442 .41014 .31169 .41722 .32299 .41424 .31575 .40711 Mtetra
.63 .735 .923 r
.31575 .40711 .32299 .41424 .33434 .41129 .32714 .40411 Mtetra
.628 .733 .923 r
.32714 .40411 .33434 .41129 .34575 .40838 .33857 .40113 Mtetra
.627 .732 .923 r
.33857 .40113 .34575 .40838 .35721 .40552 .35006 .39818 Mtetra
.625 .729 .922 r
.35006 .39818 .35721 .40552 .36872 .40273 .36161 .39527 Mtetra
.622 .726 .921 r
.36161 .39527 .36872 .40273 .38029 .40002 .37321 .39242 Mtetra
.619 .722 .919 r
.37321 .39242 .38029 .40002 .39191 .39742 .38486 .38965 Mtetra
.616 .716 .917 r
.38486 .38965 .39191 .39742 .40359 .39496 .39657 .38696 Mtetra
.611 .709 .914 r
.39657 .38696 .40359 .39496 .41532 .39265 .40834 .38439 Mtetra
.607 .701 .911 r
.40834 .38439 .41532 .39265 .42711 .39052 .42017 .38195 Mtetra
.602 .691 .906 r
.42017 .38195 .42711 .39052 .43896 .38861 .43205 .37966 Mtetra
.596 .68 .9 r
.43205 .37966 .43896 .38861 .45087 .38692 .444 .37755 Mtetra
.59 .668 .893 r
.444 .37755 .45087 .38692 .46285 .38548 .45601 .37561 Mtetra
.585 .654 .884 r
.45601 .37561 .46285 .38548 .4749 .38428 .46809 .37385 Mtetra
.581 .64 .875 r
.46809 .37385 .4749 .38428 .48702 .3833 .48023 .37226 Mtetra
.577 .626 .864 r
.48023 .37226 .48702 .3833 .49922 .38251 .49245 .37081 Mtetra
.576 .613 .853 r
.49245 .37081 .49922 .38251 .51149 .38184 .50474 .36944 Mtetra
.576 .601 .841 r
.50474 .36944 .51149 .38184 .52385 .38119 .51712 .36808 Mtetra
.579 .591 .829 r
.51712 .36808 .52385 .38119 .53629 .38045 .52956 .36664 Mtetra
.584 .583 .818 r
.52956 .36664 .53629 .38045 .54882 .3795 .54209 .36501 Mtetra
.591 .578 .807 r
.54209 .36501 .54882 .3795 .56142 .37817 .55469 .36308 Mtetra
.6 .575 .798 r
.55469 .36308 .56142 .37817 .57409 .37631 .56736 .36072 Mtetra
.611 .575 .789 r
.56736 .36072 .57409 .37631 .58683 .3738 .5801 .35782 Mtetra
.622 .577 .783 r
.5801 .35782 .58683 .3738 .59962 .3705 .59289 .35428 Mtetra
.634 .581 .777 r
.59289 .35428 .59962 .3705 .61245 .36634 .60573 .35004 Mtetra
.647 .587 .774 r
.60573 .35004 .61245 .36634 .62532 .36127 .6186 .34506 Mtetra
.659 .595 .772 r
.6186 .34506 .62532 .36127 .63821 .35532 .63151 .33935 Mtetra
.671 .604 .772 r
.63151 .33935 .63821 .35532 .65111 .34854 .64444 .33297 Mtetra
.683 .615 .774 r
.64444 .33297 .65111 .34854 .66402 .34104 .65739 .32598 Mtetra
.693 .627 .778 r
.65739 .32598 .66402 .34104 .67694 .33296 .67036 .31851 Mtetra
.702 .639 .783 r
.67036 .31851 .67694 .33296 .68987 .32445 .68335 .31067 Mtetra
.71 .652 .79 r
.68335 .31067 .68987 .32445 .70281 .3157 .69635 .30262 Mtetra
.716 .665 .799 r
.69635 .30262 .70281 .3157 .71577 .30685 .70939 .29447 Mtetra
.721 .679 .808 r
.70939 .29447 .71577 .30685 .72876 .29806 .72245 .28634 Mtetra
.724 .692 .819 r
.72245 .28634 .72876 .29806 .74179 .28945 .73556 .27834 Mtetra
.725 .704 .831 r
.73556 .27834 .74179 .28945 .75486 .28109 .74871 .27053 Mtetra
.724 .716 .842 r
.74871 .27053 .75486 .28109 .76799 .27305 .76192 .26296 Mtetra
.722 .726 .853 r
.76192 .26296 .76799 .27305 .78118 .26536 .77519 .25566 Mtetra
.719 .734 .863 r
.77519 .25566 .78118 .26536 .79444 .25802 .78852 .24863 Mtetra
.715 .741 .872 r
.78852 .24863 .79444 .25802 .80776 .25101 .80192 .24185 Mtetra
.71 .746 .88 r
.80192 .24185 .80776 .25101 .82116 .24429 .81539 .23531 Mtetra
.706 .75 .886 r
.81539 .23531 .82116 .24429 .83464 .23784 .82892 .22898 Mtetra
.639 .737 .92 r
.2081 .42775 .21563 .43469 .22656 .43159 .21905 .42462 Mtetra
.638 .736 .92 r
.21905 .42462 .22656 .43159 .23753 .4285 .23005 .4215 Mtetra
.637 .736 .92 r
.23005 .4215 .23753 .4285 .24855 .42542 .2411 .4184 Mtetra
.636 .736 .921 r
.2411 .4184 .24855 .42542 .25962 .42234 .25219 .4153 Mtetra
.635 .736 .921 r
.25219 .4153 .25962 .42234 .27074 .41928 .26334 .4122 Mtetra
.634 .736 .922 r
.26334 .4122 .27074 .41928 .28192 .41622 .27454 .40912 Mtetra
.633 .736 .922 r
.27454 .40912 .28192 .41622 .29314 .41317 .2858 .40604 Mtetra
.632 .735 .922 r
.2858 .40604 .29314 .41317 .30442 .41014 .2971 .40297 Mtetra
.2971 .40297 .30442 .41014 .31575 .40711 .30846 .3999 Mtetra
.631 .734 .922 r
.30846 .3999 .31575 .40711 .32714 .40411 .31987 .39684 Mtetra
.63 .733 .922 r
.31987 .39684 .32714 .40411 .33857 .40113 .33134 .3938 Mtetra
.629 .732 .922 r
.33134 .3938 .33857 .40113 .35006 .39818 .34286 .39077 Mtetra
.627 .73 .921 r
.34286 .39077 .35006 .39818 .36161 .39527 .35444 .38777 Mtetra
.625 .727 .92 r
.35444 .38777 .36161 .39527 .37321 .39242 .36607 .3848 Mtetra
.623 .724 .919 r
.36607 .3848 .37321 .39242 .38486 .38965 .37776 .38188 Mtetra
.621 .72 .917 r
.37776 .38188 .38486 .38965 .39657 .38696 .38951 .37902 Mtetra
.618 .715 .915 r
.38951 .37902 .39657 .38696 .40834 .38439 .40131 .37623 Mtetra
.615 .709 .912 r
.40131 .37623 .40834 .38439 .42017 .38195 .41317 .37353 Mtetra
.611 .701 .908 r
.41317 .37353 .42017 .38195 .43205 .37966 .42509 .37094 Mtetra
.607 .692 .903 r
.42509 .37094 .43205 .37966 .444 .37755 .43707 .36847 Mtetra
.603 .682 .897 r
.43707 .36847 .444 .37755 .45601 .37561 .44911 .36612 Mtetra
.599 .671 .89 r
.44911 .36612 .45601 .37561 .46809 .37385 .46122 .3639 Mtetra
.595 .659 .882 r
.46122 .3639 .46809 .37385 .48023 .37226 .47339 .36179 Mtetra
.593 .647 .873 r
.47339 .36179 .48023 .37226 .49245 .37081 .48564 .35978 Mtetra
.592 .636 .863 r
.48564 .35978 .49245 .37081 .50474 .36944 .49795 .35781 Mtetra
.592 .625 .853 r
.49795 .35781 .50474 .36944 .51712 .36808 .51034 .35585 Mtetra
.594 .615 .842 r
.51034 .35585 .51712 .36808 .52956 .36664 .5228 .3538 Mtetra
.598 .607 .832 r
.5228 .3538 .52956 .36664 .54209 .36501 .53534 .3516 Mtetra
.604 .601 .822 r
.53534 .3516 .54209 .36501 .55469 .36308 .54795 .34914 Mtetra
.611 .598 .813 r
.54795 .34914 .55469 .36308 .56736 .36072 .56062 .34633 Mtetra
.62 .596 .805 r
.56062 .34633 .56736 .36072 .5801 .35782 .57336 .34308 Mtetra
.629 .597 .798 r
.57336 .34308 .5801 .35782 .59289 .35428 .58616 .33932 Mtetra
.64 .6 .793 r
.58616 .33932 .59289 .35428 .60573 .35004 .59901 .33498 Mtetra
.65 .604 .79 r
.59901 .33498 .60573 .35004 .6186 .34506 .6119 .33005 Mtetra
.661 .611 .788 r
.6119 .33005 .6186 .34506 .63151 .33935 .62483 .32453 Mtetra
.671 .619 .788 r
.62483 .32453 .63151 .33935 .64444 .33297 .63779 .31845 Mtetra
.681 .628 .789 r
.63779 .31845 .64444 .33297 .65739 .32598 .65078 .31188 Mtetra
.69 .639 .793 r
.65078 .31188 .65739 .32598 .67036 .31851 .66379 .3049 Mtetra
.698 .65 .798 r
.66379 .3049 .67036 .31851 .68335 .31067 .67683 .29763 Mtetra
.705 .662 .804 r
.67683 .29763 .68335 .31067 .69635 .30262 .6899 .29015 Mtetra
.711 .674 .812 r
.6899 .29015 .69635 .30262 .70939 .29447 .703 .28259 Mtetra
.715 .686 .821 r
.703 .28259 .70939 .29447 .72245 .28634 .71614 .27502 Mtetra
.717 .698 .831 r
.71614 .27502 .72245 .28634 .73556 .27834 .72932 .26753 Mtetra
.718 .709 .841 r
.72932 .26753 .73556 .27834 .74871 .27053 .74254 .26018 Mtetra
.718 .719 .851 r
.74254 .26018 .74871 .27053 .76192 .26296 .75583 .25301 Mtetra
.716 .728 .86 r
.75583 .25301 .76192 .26296 .77519 .25566 .76916 .24603 Mtetra
.713 .736 .869 r
.76916 .24603 .77519 .25566 .78852 .24863 .78257 .23926 Mtetra
.71 .742 .876 r
.78257 .23926 .78852 .24863 .80192 .24185 .79603 .23269 Mtetra
.706 .746 .883 r
.79603 .23269 .80192 .24185 .81539 .23531 .80956 .2263 Mtetra
.703 .75 .888 r
.80956 .2263 .81539 .23531 .82892 .22898 .82316 .22007 Mtetra
.639 .736 .919 r
.20052 .42072 .2081 .42775 .21905 .42462 .21149 .41756 Mtetra
.638 .736 .919 r
.21149 .41756 .21905 .42462 .23005 .4215 .22251 .41442 Mtetra
.637 .735 .92 r
.22251 .41442 .23005 .4215 .2411 .4184 .23359 .41128 Mtetra
.636 .735 .92 r
.23359 .41128 .2411 .4184 .25219 .4153 .24471 .40816 Mtetra
.635 .735 .92 r
.24471 .40816 .25219 .4153 .26334 .4122 .25589 .40503 Mtetra
.634 .735 .921 r
.25589 .40503 .26334 .4122 .27454 .40912 .26711 .40192 Mtetra
.633 .734 .921 r
.26711 .40192 .27454 .40912 .2858 .40604 .27839 .3988 Mtetra
.27839 .3988 .2858 .40604 .2971 .40297 .28973 .39569 Mtetra
.632 .734 .921 r
.28973 .39569 .2971 .40297 .30846 .3999 .30111 .39259 Mtetra
.631 .733 .921 r
.30111 .39259 .30846 .3999 .31987 .39684 .31256 .38948 Mtetra
.631 .732 .921 r
.31256 .38948 .31987 .39684 .33134 .3938 .32405 .38638 Mtetra
.63 .731 .921 r
.32405 .38638 .33134 .3938 .34286 .39077 .3356 .38329 Mtetra
.629 .73 .92 r
.3356 .38329 .34286 .39077 .35444 .38777 .34721 .38021 Mtetra
.628 .728 .919 r
.34721 .38021 .35444 .38777 .36607 .3848 .35888 .37714 Mtetra
.627 .726 .918 r
.35888 .37714 .36607 .3848 .37776 .38188 .3706 .3741 Mtetra
.625 .723 .917 r
.3706 .3741 .37776 .38188 .38951 .37902 .38238 .37109 Mtetra
.623 .719 .915 r
.38238 .37109 .38951 .37902 .40131 .37623 .39421 .36813 Mtetra
.621 .714 .913 r
.39421 .36813 .40131 .37623 .41317 .37353 .40611 .36522 Mtetra
.618 .708 .91 r
.40611 .36522 .41317 .37353 .42509 .37094 .41806 .36238 Mtetra
.616 .701 .906 r
.41806 .36238 .42509 .37094 .43707 .36847 .43008 .35961 Mtetra
.613 .694 .901 r
.43008 .35961 .43707 .36847 .44911 .36612 .44215 .35693 Mtetra
.61 .685 .895 r
.44215 .35693 .44911 .36612 .46122 .3639 .45429 .35432 Mtetra
.608 .675 .889 r
.45429 .35432 .46122 .3639 .47339 .36179 .4665 .35179 Mtetra
.606 .665 .881 r
.4665 .35179 .47339 .36179 .48564 .35978 .47877 .34931 Mtetra
.605 .655 .873 r
.47877 .34931 .48564 .35978 .49795 .35781 .49111 .34686 Mtetra
.606 .646 .864 r
.49111 .34686 .49795 .35781 .51034 .35585 .50352 .34438 Mtetra
.607 .637 .854 r
.50352 .34438 .51034 .35585 .5228 .3538 .516 .34183 Mtetra
.611 .629 .845 r
.516 .34183 .5228 .3538 .53534 .3516 .52856 .33913 Mtetra
.615 .624 .836 r
.52856 .33913 .53534 .3516 .54795 .34914 .54118 .33623 Mtetra
.621 .62 .828 r
.54118 .33623 .54795 .34914 .56062 .34633 .55386 .33303 Mtetra
.628 .617 .82 r
.55386 .33303 .56062 .34633 .57336 .34308 .56662 .32947 Mtetra
.636 .617 .814 r
.56662 .32947 .57336 .34308 .58616 .33932 .57943 .3255 Mtetra
.645 .619 .809 r
.57943 .3255 .58616 .33932 .59901 .33498 .59229 .32107 Mtetra
.654 .623 .806 r
.59229 .32107 .59901 .33498 .6119 .33005 .6052 .31615 Mtetra
.663 .628 .804 r
.6052 .31615 .6119 .33005 .62483 .32453 .61815 .31076 Mtetra
.672 .635 .804 r
.61815 .31076 .62483 .32453 .63779 .31845 .63114 .30492 Mtetra
.681 .643 .805 r
.63114 .30492 .63779 .31845 .65078 .31188 .64417 .29868 Mtetra
.689 .652 .808 r
.64417 .29868 .65078 .31188 .66379 .3049 .65722 .29211 Mtetra
.695 .662 .813 r
.65722 .29211 .66379 .3049 .67683 .29763 .67032 .28528 Mtetra
.701 .672 .819 r
.67032 .28528 .67683 .29763 .6899 .29015 .68344 .27828 Mtetra
.706 .683 .826 r
.68344 .27828 .6899 .29015 .703 .28259 .6966 .27119 Mtetra
.709 .694 .833 r
.6966 .27119 .703 .28259 .71614 .27502 .7098 .26408 Mtetra
.711 .704 .842 r
.7098 .26408 .71614 .27502 .72932 .26753 .72305 .25701 Mtetra
.712 .714 .85 r
.72305 .25701 .72932 .26753 .74254 .26018 .73635 .25004 Mtetra
.712 .723 .859 r
.73635 .25004 .74254 .26018 .75583 .25301 .7497 .24319 Mtetra
.71 .731 .867 r
.7497 .24319 .75583 .25301 .76916 .24603 .7631 .23648 Mtetra
.708 .737 .874 r
.7631 .23648 .76916 .24603 .78257 .23926 .77657 .22993 Mtetra
.705 .743 .88 r
.77657 .22993 .78257 .23926 .79603 .23269 .7901 .22351 Mtetra
.703 .747 .886 r
.7901 .22351 .79603 .23269 .80956 .2263 .80369 .21724 Mtetra
.7 .749 .89 r
.80369 .21724 .80956 .2263 .82316 .22007 .81735 .21108 Mtetra
.639 .735 .918 r
.19287 .4136 .20052 .42072 .21149 .41756 .20387 .41042 Mtetra
.638 .735 .918 r
.20387 .41042 .21149 .41756 .22251 .41442 .21492 .40724 Mtetra
.637 .734 .919 r
.21492 .40724 .22251 .41442 .23359 .41128 .22602 .40408 Mtetra
.636 .734 .919 r
.22602 .40408 .23359 .41128 .24471 .40816 .23717 .40092 Mtetra
.635 .734 .919 r
.23717 .40092 .24471 .40816 .25589 .40503 .24837 .39776 Mtetra
.634 .733 .92 r
.24837 .39776 .25589 .40503 .26711 .40192 .25963 .39461 Mtetra
.25963 .39461 .26711 .40192 .27839 .3988 .27093 .39147 Mtetra
.633 .733 .92 r
.27093 .39147 .27839 .3988 .28973 .39569 .2823 .38832 Mtetra
.2823 .38832 .28973 .39569 .30111 .39259 .29371 .38517 Mtetra
.632 .732 .92 r
.29371 .38517 .30111 .39259 .31256 .38948 .30518 .38202 Mtetra
.30518 .38202 .31256 .38948 .32405 .38638 .31671 .37887 Mtetra
.631 .731 .919 r
.31671 .37887 .32405 .38638 .3356 .38329 .32829 .37572 Mtetra
.631 .73 .919 r
.32829 .37572 .3356 .38329 .34721 .38021 .33993 .37257 Mtetra
.63 .728 .918 r
.33993 .37257 .34721 .38021 .35888 .37714 .35162 .36942 Mtetra
.629 .727 .918 r
.35162 .36942 .35888 .37714 .3706 .3741 .36338 .36628 Mtetra
.628 .725 .916 r
.36338 .36628 .3706 .3741 .38238 .37109 .37519 .36315 Mtetra
.627 .722 .915 r
.37519 .36315 .38238 .37109 .39421 .36813 .38706 .36005 Mtetra
.626 .718 .913 r
.38706 .36005 .39421 .36813 .40611 .36522 .39899 .35697 Mtetra
.624 .714 .91 r
.39899 .35697 .40611 .36522 .41806 .36238 .41098 .35393 Mtetra
.622 .709 .907 r
.41098 .35393 .41806 .36238 .43008 .35961 .42302 .35092 Mtetra
.621 .703 .904 r
.42302 .35092 .43008 .35961 .44215 .35693 .43514 .34796 Mtetra
.619 .696 .899 r
.43514 .34796 .44215 .35693 .45429 .35432 .44731 .34505 Mtetra
.618 .688 .894 r
.44731 .34505 .45429 .35432 .4665 .35179 .45955 .34217 Mtetra
.617 .68 .887 r
.45955 .34217 .4665 .35179 .47877 .34931 .47185 .33931 Mtetra
.616 .672 .88 r
.47185 .33931 .47877 .34931 .49111 .34686 .48422 .33645 Mtetra
.617 .664 .873 r
.48422 .33645 .49111 .34686 .50352 .34438 .49665 .33355 Mtetra
.619 .656 .865 r
.49665 .33355 .50352 .34438 .516 .34183 .50916 .33058 Mtetra
.621 .65 .857 r
.50916 .33058 .516 .34183 .52856 .33913 .52173 .32748 Mtetra
.625 .644 .849 r
.52173 .32748 .52856 .33913 .54118 .33623 .53437 .32419 Mtetra
.63 .64 .842 r
.53437 .32419 .54118 .33623 .55386 .33303 .54708 .32066 Mtetra
.636 .638 .835 r
.54708 .32066 .55386 .33303 .56662 .32947 .55985 .31684 Mtetra
.643 .637 .829 r
.55985 .31684 .56662 .32947 .57943 .3255 .57267 .31269 Mtetra
.65 .638 .825 r
.57267 .31269 .57943 .3255 .59229 .32107 .58556 .30816 Mtetra
.658 .641 .822 r
.58556 .30816 .59229 .32107 .6052 .31615 .59849 .30325 Mtetra
.666 .645 .82 r
.59849 .30325 .6052 .31615 .61815 .31076 .61147 .29795 Mtetra
.673 .651 .82 r
.61147 .29795 .61815 .31076 .63114 .30492 .62449 .29229 Mtetra
.68 .658 .821 r
.62449 .29229 .63114 .30492 .64417 .29868 .63755 .2863 Mtetra
.687 .665 .823 r
.63755 .2863 .64417 .29868 .65722 .29211 .65065 .28004 Mtetra
.693 .674 .827 r
.65065 .28004 .65722 .29211 .67032 .28528 .66379 .27357 Mtetra
.698 .683 .832 r
.66379 .27357 .67032 .28528 .68344 .27828 .67697 .26694 Mtetra
.702 .693 .838 r
.67697 .26694 .68344 .27828 .6966 .27119 .69019 .26023 Mtetra
.705 .702 .845 r
.69019 .26023 .6966 .27119 .7098 .26408 .70345 .25348 Mtetra
.706 .711 .852 r
.70345 .25348 .7098 .26408 .72305 .25701 .71676 .24675 Mtetra
.707 .719 .859 r
.71676 .24675 .72305 .25701 .73635 .25004 .73012 .24008 Mtetra
.707 .727 .866 r
.73012 .24008 .73635 .25004 .7497 .24319 .74353 .23348 Mtetra
.705 .733 .873 r
.74353 .23348 .7497 .24319 .7631 .23648 .757 .22699 Mtetra
.704 .739 .879 r
.757 .22699 .7631 .23648 .77657 .22993 .77053 .2206 Mtetra
.702 .743 .884 r
.77053 .2206 .77657 .22993 .7901 .22351 .78412 .21432 Mtetra
.699 .747 .888 r
.78412 .21432 .7901 .22351 .80369 .21724 .79777 .20813 Mtetra
.697 .749 .892 r
.79777 .20813 .80369 .21724 .81735 .21108 .81149 .20203 Mtetra
.639 .734 .917 r
.18517 .4064 .19287 .4136 .20387 .41042 .1962 .40318 Mtetra
.638 .734 .918 r
.1962 .40318 .20387 .41042 .21492 .40724 .20727 .39997 Mtetra
.637 .733 .918 r
.20727 .39997 .21492 .40724 .22602 .40408 .2184 .39677 Mtetra
.636 .733 .918 r
.2184 .39677 .22602 .40408 .23717 .40092 .22957 .39358 Mtetra
.635 .733 .918 r
.22957 .39358 .23717 .40092 .24837 .39776 .2408 .39039 Mtetra
.635 .732 .919 r
.2408 .39039 .24837 .39776 .25963 .39461 .25208 .38721 Mtetra
.634 .732 .919 r
.25208 .38721 .25963 .39461 .27093 .39147 .26342 .38402 Mtetra
.26342 .38402 .27093 .39147 .2823 .38832 .27481 .38084 Mtetra
.633 .731 .919 r
.27481 .38084 .2823 .38832 .29371 .38517 .28625 .37765 Mtetra
.28625 .37765 .29371 .38517 .30518 .38202 .29775 .37446 Mtetra
.632 .73 .918 r
.29775 .37446 .30518 .38202 .31671 .37887 .30931 .37126 Mtetra
.30931 .37126 .31671 .37887 .32829 .37572 .32092 .36805 Mtetra
.632 .729 .918 r
.32092 .36805 .32829 .37572 .33993 .37257 .33259 .36484 Mtetra
.631 .728 .917 r
.33259 .36484 .33993 .37257 .35162 .36942 .34431 .36162 Mtetra
.631 .727 .917 r
.34431 .36162 .35162 .36942 .36338 .36628 .3561 .35839 Mtetra
.631 .725 .916 r
.3561 .35839 .36338 .36628 .37519 .36315 .36794 .35517 Mtetra
.63 .723 .914 r
.36794 .35517 .37519 .36315 .38706 .36005 .37985 .35195 Mtetra
.629 .721 .913 r
.37985 .35195 .38706 .36005 .39899 .35697 .39181 .34873 Mtetra
.629 .718 .911 r
.39181 .34873 .39899 .35697 .41098 .35393 .40383 .34552 Mtetra
.628 .714 .908 r
.40383 .34552 .41098 .35393 .42302 .35092 .41591 .34233 Mtetra
.627 .709 .905 r
.41591 .34233 .42302 .35092 .43514 .34796 .42806 .33915 Mtetra
.626 .704 .901 r
.42806 .33915 .43514 .34796 .44731 .34505 .44027 .33598 Mtetra
.625 .698 .897 r
.44027 .33598 .44731 .34505 .45955 .34217 .45254 .33282 Mtetra
.625 .692 .892 r
.45254 .33282 .45955 .34217 .47185 .33931 .46487 .32966 Mtetra
.625 .686 .886 r
.46487 .32966 .47185 .33931 .48422 .33645 .47727 .32647 Mtetra
.626 .679 .88 r
.47727 .32647 .48422 .33645 .49665 .33355 .48974 .32323 Mtetra
.628 .673 .874 r
.48974 .32323 .49665 .33355 .50916 .33058 .50227 .31991 Mtetra
.63 .667 .867 r
.50227 .31991 .50916 .33058 .52173 .32748 .51487 .31648 Mtetra
.634 .663 .86 r
.51487 .31648 .52173 .32748 .53437 .32419 .52753 .31288 Mtetra
.638 .659 .854 r
.52753 .31288 .53437 .32419 .54708 .32066 .54026 .30908 Mtetra
.643 .657 .848 r
.54026 .30908 .54708 .32066 .55985 .31684 .55305 .30504 Mtetra
.649 .656 .843 r
.55305 .30504 .55985 .31684 .57267 .31269 .5659 .30073 Mtetra
.655 .656 .839 r
.5659 .30073 .57267 .31269 .58556 .30816 .5788 .29611 Mtetra
.661 .658 .836 r
.5788 .29611 .58556 .30816 .59849 .30325 .59176 .29118 Mtetra
.668 .662 .835 r
.59176 .29118 .59849 .30325 .61147 .29795 .60477 .28595 Mtetra
.674 .666 .834 r
.60477 .28595 .61147 .29795 .62449 .29229 .61782 .28042 Mtetra
.68 .672 .835 r
.61782 .28042 .62449 .29229 .63755 .2863 .63092 .27462 Mtetra
.686 .679 .837 r
.63092 .27462 .63755 .2863 .65065 .28004 .64407 .2686 Mtetra
.691 .686 .841 r
.64407 .2686 .65065 .28004 .66379 .27357 .65725 .2624 Mtetra
.695 .694 .845 r
.65725 .2624 .66379 .27357 .67697 .26694 .67048 .25606 Mtetra
.698 .702 .85 r
.67048 .25606 .67697 .26694 .69019 .26023 .68375 .24963 Mtetra
.7 .71 .855 r
.68375 .24963 .69019 .26023 .70345 .25348 .69707 .24317 Mtetra
.702 .717 .861 r
.69707 .24317 .70345 .25348 .71676 .24675 .71044 .2367 Mtetra
.702 .724 .867 r
.71044 .2367 .71676 .24675 .73012 .24008 .72386 .23026 Mtetra
.702 .73 .872 r
.72386 .23026 .73012 .24008 .74353 .23348 .73733 .22387 Mtetra
.701 .736 .878 r
.73733 .22387 .74353 .23348 .757 .22699 .75086 .21753 Mtetra
.7 .74 .882 r
.75086 .21753 .757 .22699 .77053 .2206 .76445 .21127 Mtetra
.699 .744 .887 r
.76445 .21127 .77053 .2206 .78412 .21432 .7781 .20508 Mtetra
.697 .747 .89 r
.7781 .20508 .78412 .21432 .79777 .20813 .79181 .19896 Mtetra
.695 .749 .893 r
.79181 .19896 .79777 .20813 .81149 .20203 .80558 .1929 Mtetra
.639 .733 .917 r
.17742 .39911 .18517 .4064 .1962 .40318 .18847 .39585 Mtetra
.638 .733 .917 r
.18847 .39585 .1962 .40318 .20727 .39997 .19957 .39261 Mtetra
.637 .732 .917 r
.19957 .39261 .20727 .39997 .2184 .39677 .21072 .38937 Mtetra
.636 .732 .917 r
.21072 .38937 .2184 .39677 .22957 .39358 .22192 .38614 Mtetra
.22192 .38614 .22957 .39358 .2408 .39039 .23318 .38292 Mtetra
.635 .731 .917 r
.23318 .38292 .2408 .39039 .25208 .38721 .24449 .3797 Mtetra
.634 .731 .918 r
.24449 .3797 .25208 .38721 .26342 .38402 .25585 .37647 Mtetra
.634 .73 .918 r
.25585 .37647 .26342 .38402 .27481 .38084 .26726 .37325 Mtetra
.26726 .37325 .27481 .38084 .28625 .37765 .27874 .37002 Mtetra
.633 .73 .917 r
.27874 .37002 .28625 .37765 .29775 .37446 .29026 .36678 Mtetra
.633 .729 .917 r
.29026 .36678 .29775 .37446 .30931 .37126 .30185 .36353 Mtetra
.30185 .36353 .30931 .37126 .32092 .36805 .31349 .36028 Mtetra
.633 .728 .917 r
.31349 .36028 .32092 .36805 .33259 .36484 .32519 .35701 Mtetra
.633 .727 .916 r
.32519 .35701 .33259 .36484 .34431 .36162 .33695 .35372 Mtetra
.633 .727 .915 r
.33695 .35372 .34431 .36162 .3561 .35839 .34876 .35043 Mtetra
.633 .725 .915 r
.34876 .35043 .3561 .35839 .36794 .35517 .36064 .34712 Mtetra
.632 .724 .914 r
.36064 .34712 .36794 .35517 .37985 .35195 .37257 .34379 Mtetra
.632 .722 .912 r
.37257 .34379 .37985 .35195 .39181 .34873 .38457 .34046 Mtetra
.632 .72 .911 r
.38457 .34046 .39181 .34873 .40383 .34552 .39663 .33712 Mtetra
.632 .717 .909 r
.39663 .33712 .40383 .34552 .41591 .34233 .40874 .33377 Mtetra
.632 .714 .906 r
.40874 .33377 .41591 .34233 .42806 .33915 .42092 .33042 Mtetra
.632 .71 .903 r
.42092 .33042 .42806 .33915 .44027 .33598 .43316 .32705 Mtetra
.632 .706 .9 r
.43316 .32705 .44027 .33598 .45254 .33282 .44547 .32367 Mtetra
.632 .701 .896 r
.44547 .32367 .45254 .33282 .46487 .32966 .45783 .32026 Mtetra
.632 .696 .891 r
.45783 .32026 .46487 .32966 .47727 .32647 .47027 .31681 Mtetra
.634 .691 .886 r
.47027 .31681 .47727 .32647 .48974 .32323 .48276 .3133 Mtetra
.635 .686 .881 r
.48276 .3133 .48974 .32323 .50227 .31991 .49532 .30971 Mtetra
.638 .682 .875 r
.49532 .30971 .50227 .31991 .51487 .31648 .50795 .306 Mtetra
.641 .678 .87 r
.50795 .306 .51487 .31648 .52753 .31288 .52064 .30216 Mtetra
.644 .675 .865 r
.52064 .30216 .52753 .31288 .54026 .30908 .5334 .29814 Mtetra
.649 .673 .86 r
.5334 .29814 .54026 .30908 .55305 .30504 .54621 .29391 Mtetra
.654 .672 .856 r
.54621 .29391 .55305 .30504 .5659 .30073 .55909 .28946 Mtetra
.659 .673 .852 r
.55909 .28946 .5659 .30073 .5788 .29611 .57202 .28477 Mtetra
.664 .674 .85 r
.57202 .28477 .5788 .29611 .59176 .29118 .58501 .27982 Mtetra
.67 .677 .848 r
.58501 .27982 .59176 .29118 .60477 .28595 .59805 .27462 Mtetra
.675 .681 .848 r
.59805 .27462 .60477 .28595 .61782 .28042 .61114 .26918 Mtetra
.68 .685 .848 r
.61114 .26918 .61782 .28042 .63092 .27462 .62427 .26352 Mtetra
.685 .691 .85 r
.62427 .26352 .63092 .27462 .64407 .2686 .63746 .25767 Mtetra
.689 .697 .852 r
.63746 .25767 .64407 .2686 .65725 .2624 .65069 .25167 Mtetra
.692 .703 .856 r
.65069 .25167 .65725 .2624 .67048 .25606 .66396 .24554 Mtetra
.695 .71 .86 r
.66396 .24554 .67048 .25606 .68375 .24963 .67729 .23934 Mtetra
.697 .716 .864 r
.67729 .23934 .68375 .24963 .69707 .24317 .69066 .23309 Mtetra
.698 .723 .869 r
.69066 .23309 .69707 .24317 .71044 .2367 .70408 .22681 Mtetra
.699 .728 .873 r
.70408 .22681 .71044 .2367 .72386 .23026 .71756 .22055 Mtetra
.699 .733 .878 r
.71756 .22055 .72386 .23026 .73733 .22387 .73109 .2143 Mtetra
.698 .738 .882 r
.73109 .2143 .73733 .22387 .75086 .21753 .74468 .20809 Mtetra
.697 .741 .885 r
.74468 .20809 .75086 .21753 .76445 .21127 .75832 .20192 Mtetra
.696 .744 .889 r
.75832 .20192 .76445 .21127 .7781 .20508 .77202 .1958 Mtetra
.695 .747 .892 r
.77202 .1958 .7781 .20508 .79181 .19896 .78579 .18972 Mtetra
.693 .748 .894 r
.78579 .18972 .79181 .19896 .80558 .1929 .79961 .18369 Mtetra
.639 .732 .916 r
.1696 .39173 .17742 .39911 .18847 .39585 .18068 .38844 Mtetra
.638 .732 .916 r
.18068 .38844 .18847 .39585 .19957 .39261 .1918 .38515 Mtetra
.638 .731 .916 r
.1918 .38515 .19957 .39261 .21072 .38937 .20298 .38188 Mtetra
.637 .731 .916 r
.20298 .38188 .21072 .38937 .22192 .38614 .21421 .37861 Mtetra
.636 .73 .916 r
.21421 .37861 .22192 .38614 .23318 .38292 .22549 .37534 Mtetra
.635 .73 .916 r
.22549 .37534 .23318 .38292 .24449 .3797 .23683 .37208 Mtetra
.23683 .37208 .24449 .3797 .25585 .37647 .24822 .36882 Mtetra
.634 .729 .916 r
.24822 .36882 .25585 .37647 .26726 .37325 .25966 .36555 Mtetra
.25966 .36555 .26726 .37325 .27874 .37002 .27116 .36228 Mtetra
.634 .728 .916 r
.27116 .36228 .27874 .37002 .29026 .36678 .28272 .35899 Mtetra
.28272 .35899 .29026 .36678 .30185 .36353 .29433 .3557 Mtetra
.29433 .3557 .30185 .36353 .31349 .36028 .306 .35239 Mtetra
.634 .727 .915 r
.306 .35239 .31349 .36028 .32519 .35701 .31773 .34907 Mtetra
.31773 .34907 .32519 .35701 .33695 .35372 .32952 .34572 Mtetra
.634 .726 .914 r
.32952 .34572 .33695 .35372 .34876 .35043 .34137 .34236 Mtetra
.634 .725 .913 r
.34137 .34236 .34876 .35043 .36064 .34712 .35328 .33898 Mtetra
.634 .724 .912 r
.35328 .33898 .36064 .34712 .37257 .34379 .36524 .33557 Mtetra
.634 .723 .911 r
.36524 .33557 .37257 .34379 .38457 .34046 .37727 .33214 Mtetra
.635 .721 .91 r
.37727 .33214 .38457 .34046 .39663 .33712 .38936 .32869 Mtetra
.635 .719 .908 r
.38936 .32869 .39663 .33712 .40874 .33377 .40151 .32522 Mtetra
.635 .717 .906 r
.40151 .32522 .40874 .33377 .42092 .33042 .41372 .32172 Mtetra
.636 .714 .904 r
.41372 .32172 .42092 .33042 .43316 .32705 .426 .31819 Mtetra
.636 .711 .901 r
.426 .31819 .43316 .32705 .44547 .32367 .43834 .31463 Mtetra
.637 .708 .898 r
.43834 .31463 .44547 .32367 .45783 .32026 .45074 .31103 Mtetra
.638 .704 .894 r
.45074 .31103 .45783 .32026 .47027 .31681 .4632 .30737 Mtetra
.639 .701 .89 r
.4632 .30737 .47027 .31681 .48276 .3133 .47573 .30365 Mtetra
.641 .697 .886 r
.47573 .30365 .48276 .3133 .49532 .30971 .48833 .29984 Mtetra
.643 .694 .882 r
.48833 .29984 .49532 .30971 .50795 .306 .50098 .29592 Mtetra
.646 .691 .877 r
.50098 .29592 .50795 .306 .52064 .30216 .5137 .29187 Mtetra
.65 .688 .873 r
.5137 .29187 .52064 .30216 .5334 .29814 .52649 .28767 Mtetra
.653 .687 .869 r
.52649 .28767 .5334 .29814 .54621 .29391 .53933 .2833 Mtetra
.657 .686 .866 r
.53933 .2833 .54621 .29391 .55909 .28946 .55224 .27874 Mtetra
.662 .687 .863 r
.55224 .27874 .55909 .28946 .57202 .28477 .5652 .27397 Mtetra
.666 .688 .861 r
.5652 .27397 .57202 .28477 .58501 .27982 .57822 .26899 Mtetra
.671 .69 .859 r
.57822 .26899 .58501 .27982 .59805 .27462 .59129 .26381 Mtetra
.675 .693 .859 r
.59129 .26381 .59805 .27462 .61114 .26918 .60442 .25843 Mtetra
.68 .697 .859 r
.60442 .25843 .61114 .26918 .62427 .26352 .61759 .25286 Mtetra
.683 .701 .86 r
.61759 .25286 .62427 .26352 .63746 .25767 .63082 .24714 Mtetra
.687 .706 .862 r
.63082 .24714 .63746 .25767 .65069 .25167 .64409 .24128 Mtetra
.69 .711 .865 r
.64409 .24128 .65069 .25167 .66396 .24554 .65741 .23532 Mtetra
.692 .717 .868 r
.65741 .23532 .66396 .24554 .67729 .23934 .67079 .22927 Mtetra
.694 .722 .871 r
.67079 .22927 .67729 .23934 .69066 .23309 .68421 .22317 Mtetra
.695 .727 .875 r
.68421 .22317 .69066 .23309 .70408 .22681 .69769 .21704 Mtetra
.695 .732 .878 r
.69769 .21704 .70408 .22681 .71756 .22055 .71122 .2109 Mtetra
.696 .736 .882 r
.71122 .2109 .71756 .22055 .73109 .2143 .7248 .20476 Mtetra
.695 .739 .885 r
.7248 .20476 .73109 .2143 .74468 .20809 .73844 .19863 Mtetra
.695 .742 .888 r
.73844 .19863 .74468 .20809 .75832 .20192 .75214 .19253 Mtetra
.694 .745 .89 r
.75214 .19253 .75832 .20192 .77202 .1958 .7659 .18645 Mtetra
.693 .746 .893 r
.7659 .18645 .77202 .1958 .78579 .18972 .77972 .1804 Mtetra
.692 .748 .894 r
.77972 .1804 .78579 .18972 .79961 .18369 .79359 .17437 Mtetra
.64 .732 .915 r
.16172 .38426 .1696 .39173 .18068 .38844 .17283 .38093 Mtetra
.639 .731 .915 r
.17283 .38093 .18068 .38844 .1918 .38515 .18398 .3776 Mtetra
.638 .731 .915 r
.18398 .3776 .1918 .38515 .20298 .38188 .19519 .37429 Mtetra
.637 .73 .915 r
.19519 .37429 .20298 .38188 .21421 .37861 .20644 .37097 Mtetra
.20644 .37097 .21421 .37861 .22549 .37534 .21775 .36767 Mtetra
.636 .729 .915 r
.21775 .36767 .22549 .37534 .23683 .37208 .22912 .36436 Mtetra
.635 .729 .915 r
.22912 .36436 .23683 .37208 .24822 .36882 .24053 .36105 Mtetra
.635 .728 .915 r
.24053 .36105 .24822 .36882 .25966 .36555 .25201 .35774 Mtetra
.25201 .35774 .25966 .36555 .27116 .36228 .26353 .35442 Mtetra
.634 .727 .915 r
.26353 .35442 .27116 .36228 .28272 .35899 .27512 .35109 Mtetra
.27512 .35109 .28272 .35899 .29433 .3557 .28676 .34775 Mtetra
.634 .726 .914 r
.28676 .34775 .29433 .3557 .306 .35239 .29846 .34439 Mtetra
.29846 .34439 .306 .35239 .31773 .34907 .31022 .34101 Mtetra
.635 .725 .913 r
.31022 .34101 .31773 .34907 .32952 .34572 .32204 .33761 Mtetra
.32204 .33761 .32952 .34572 .34137 .34236 .33392 .33419 Mtetra
.635 .724 .912 r
.33392 .33419 .34137 .34236 .35328 .33898 .34586 .33074 Mtetra
.636 .724 .911 r
.34586 .33074 .35328 .33898 .36524 .33557 .35786 .32726 Mtetra
.636 .723 .91 r
.35786 .32726 .36524 .33557 .37727 .33214 .36992 .32375 Mtetra
.637 .722 .909 r
.36992 .32375 .37727 .33214 .38936 .32869 .38204 .32021 Mtetra
.637 .72 .908 r
.38204 .32021 .38936 .32869 .40151 .32522 .39422 .31663 Mtetra
.638 .719 .906 r
.39422 .31663 .40151 .32522 .41372 .32172 .40647 .31301 Mtetra
.639 .717 .904 r
.40647 .31301 .41372 .32172 .426 .31819 .41878 .30935 Mtetra
.64 .715 .902 r
.41878 .30935 .426 .31819 .43834 .31463 .43115 .30565 Mtetra
.641 .712 .899 r
.43115 .30565 .43834 .31463 .45074 .31103 .44358 .30189 Mtetra
.642 .71 .896 r
.44358 .30189 .45074 .31103 .4632 .30737 .45608 .29807 Mtetra
.644 .707 .893 r
.45608 .29807 .4632 .30737 .47573 .30365 .46865 .29418 Mtetra
.645 .705 .89 r
.46865 .29418 .47573 .30365 .48833 .29984 .48127 .29019 Mtetra
.648 .702 .886 r
.48127 .29019 .48833 .29984 .50098 .29592 .49396 .28611 Mtetra
.65 .7 .883 r
.49396 .28611 .50098 .29592 .5137 .29187 .50671 .2819 Mtetra
.653 .699 .88 r
.50671 .2819 .5137 .29187 .52649 .28767 .51953 .27756 Mtetra
.657 .698 .876 r
.51953 .27756 .52649 .28767 .53933 .2833 .53241 .27306 Mtetra
.66 .697 .874 r
.53241 .27306 .53933 .2833 .55224 .27874 .54534 .26841 Mtetra
.664 .698 .871 r
.54534 .26841 .55224 .27874 .5652 .27397 .55834 .26358 Mtetra
.668 .699 .869 r
.55834 .26358 .5652 .27397 .57822 .26899 .57139 .25857 Mtetra
.672 .701 .868 r
.57139 .25857 .57822 .26899 .59129 .26381 .5845 .25339 Mtetra
.675 .703 .868 r
.5845 .25339 .59129 .26381 .60442 .25843 .59766 .24804 Mtetra
.679 .706 .868 r
.59766 .24804 .60442 .25843 .61759 .25286 .61087 .24254 Mtetra
.682 .71 .869 r
.61087 .24254 .61759 .25286 .63082 .24714 .62414 .2369 Mtetra
.685 .714 .87 r
.62414 .2369 .63082 .24714 .64409 .24128 .63745 .23114 Mtetra
.688 .718 .872 r
.63745 .23114 .64409 .24128 .65741 .23532 .65082 .22529 Mtetra
.69 .722 .874 r
.65082 .22529 .65741 .23532 .67079 .22927 .66424 .21935 Mtetra
.691 .726 .877 r
.66424 .21935 .67079 .22927 .68421 .22317 .67772 .21336 Mtetra
.692 .73 .88 r
.67772 .21336 .68421 .22317 .69769 .21704 .69125 .20733 Mtetra
.693 .734 .882 r
.69125 .20733 .69769 .21704 .71122 .2109 .70483 .20127 Mtetra
.693 .737 .885 r
.70483 .20127 .71122 .2109 .7248 .20476 .71846 .19521 Mtetra
.693 .74 .887 r
.71846 .19521 .7248 .20476 .73844 .19863 .73216 .18914 Mtetra
.693 .742 .889 r
.73216 .18914 .73844 .19863 .75214 .19253 .74591 .18307 Mtetra
.692 .744 .891 r
.74591 .18307 .75214 .19253 .7659 .18645 .75972 .17702 Mtetra
.691 .746 .893 r
.75972 .17702 .7659 .18645 .77972 .1804 .77359 .17098 Mtetra
.691 .747 .895 r
.77359 .17098 .77972 .1804 .79359 .17437 .78752 .16496 Mtetra
.64 .731 .914 r
.15379 .37671 .16172 .38426 .17283 .38093 .16492 .37333 Mtetra
.639 .73 .914 r
.16492 .37333 .17283 .38093 .18398 .3776 .1761 .36996 Mtetra
.1761 .36996 .18398 .3776 .19519 .37429 .18733 .3666 Mtetra
.638 .729 .914 r
.18733 .3666 .19519 .37429 .20644 .37097 .19862 .36324 Mtetra
.637 .729 .914 r
.19862 .36324 .20644 .37097 .21775 .36767 .20995 .35989 Mtetra
.636 .728 .914 r
.20995 .35989 .21775 .36767 .22912 .36436 .22134 .35654 Mtetra
.22134 .35654 .22912 .36436 .24053 .36105 .23279 .35318 Mtetra
.635 .727 .914 r
.23279 .35318 .24053 .36105 .25201 .35774 .24429 .34982 Mtetra
.24429 .34982 .25201 .35774 .26353 .35442 .25585 .34645 Mtetra
.635 .726 .914 r
.25585 .34645 .26353 .35442 .27512 .35109 .26746 .34308 Mtetra
.635 .726 .913 r
.26746 .34308 .27512 .35109 .28676 .34775 .27913 .33968 Mtetra
.635 .725 .913 r
.27913 .33968 .28676 .34775 .29846 .34439 .29086 .33627 Mtetra
.29086 .33627 .29846 .34439 .31022 .34101 .30265 .33284 Mtetra
.635 .724 .912 r
.30265 .33284 .31022 .34101 .32204 .33761 .3145 .32939 Mtetra
.636 .724 .911 r
.3145 .32939 .32204 .33761 .33392 .33419 .32641 .32591 Mtetra
.636 .723 .911 r
.32641 .32591 .33392 .33419 .34586 .33074 .33838 .32239 Mtetra
.637 .723 .91 r
.33838 .32239 .34586 .33074 .35786 .32726 .35041 .31884 Mtetra
.637 .722 .909 r
.35041 .31884 .35786 .32726 .36992 .32375 .3625 .31526 Mtetra
.638 .721 .908 r
.3625 .31526 .36992 .32375 .38204 .32021 .37466 .31164 Mtetra
.639 .72 .907 r
.37466 .31164 .38204 .32021 .39422 .31663 .38687 .30797 Mtetra
.64 .719 .905 r
.38687 .30797 .39422 .31663 .40647 .31301 .39915 .30426 Mtetra
.641 .718 .904 r
.39915 .30426 .40647 .31301 .41878 .30935 .4115 .30049 Mtetra
.642 .717 .902 r
.4115 .30049 .41878 .30935 .43115 .30565 .4239 .29667 Mtetra
.643 .715 .9 r
.4239 .29667 .43115 .30565 .44358 .30189 .43637 .29279 Mtetra
.645 .714 .898 r
.43637 .29279 .44358 .30189 .45608 .29807 .4489 .28884 Mtetra
.647 .712 .895 r
.4489 .28884 .45608 .29807 .46865 .29418 .4615 .28481 Mtetra
.649 .71 .893 r
.4615 .28481 .46865 .29418 .48127 .29019 .47416 .28069 Mtetra
.651 .709 .89 r
.47416 .28069 .48127 .29019 .49396 .28611 .48688 .27647 Mtetra
.653 .707 .887 r
.48688 .27647 .49396 .28611 .50671 .2819 .49967 .27214 Mtetra
.656 .706 .884 r
.49967 .27214 .50671 .2819 .51953 .27756 .51252 .26768 Mtetra
.659 .706 .882 r
.51252 .26768 .51953 .27756 .53241 .27306 .52543 .26309 Mtetra
.662 .706 .88 r
.52543 .26309 .53241 .27306 .54534 .26841 .5384 .25835 Mtetra
.665 .706 .878 r
.5384 .25835 .54534 .26841 .55834 .26358 .55142 .25347 Mtetra
.669 .707 .876 r
.55142 .25347 .55834 .26358 .57139 .25857 .56451 .24843 Mtetra
.672 .709 .875 r
.56451 .24843 .57139 .25857 .5845 .25339 .57765 .24324 Mtetra
.675 .711 .875 r
.57765 .24324 .5845 .25339 .59766 .24804 .59085 .23791 Mtetra
.678 .713 .875 r
.59085 .23791 .59766 .24804 .61087 .24254 .60411 .23245 Mtetra
.681 .716 .875 r
.60411 .23245 .61087 .24254 .62414 .2369 .61741 .22686 Mtetra
.684 .719 .876 r
.61741 .22686 .62414 .2369 .63745 .23114 .63078 .22117 Mtetra
.686 .723 .878 r
.63078 .22117 .63745 .23114 .65082 .22529 .64419 .21538 Mtetra
.688 .726 .879 r
.64419 .21538 .65082 .22529 .66424 .21935 .65766 .20952 Mtetra
.689 .729 .881 r
.65766 .20952 .66424 .21935 .67772 .21336 .67118 .2036 Mtetra
.69 .733 .883 r
.67118 .2036 .67772 .21336 .69125 .20733 .68475 .19763 Mtetra
.691 .735 .885 r
.68475 .19763 .69125 .20733 .70483 .20127 .69839 .19163 Mtetra
.691 .738 .887 r
.69839 .19163 .70483 .20127 .71846 .19521 .71207 .18561 Mtetra
.691 .74 .889 r
.71207 .18561 .71846 .19521 .73216 .18914 .72582 .17958 Mtetra
.691 .742 .891 r
.72582 .17958 .73216 .18914 .74591 .18307 .73962 .17354 Mtetra
.691 .744 .892 r
.73962 .17354 .74591 .18307 .75972 .17702 .75348 .1675 Mtetra
.69 .745 .893 r
.75348 .1675 .75972 .17702 .77359 .17098 .76741 .16147 Mtetra
.689 .746 .895 r
.76741 .16147 .77359 .17098 .78752 .16496 .78139 .15544 Mtetra
.641 .731 .914 r
.1458 .36907 .15379 .37671 .16492 .37333 .15695 .36565 Mtetra
.64 .73 .914 r
.15695 .36565 .16492 .37333 .1761 .36996 .16816 .36223 Mtetra
.639 .729 .914 r
.16816 .36223 .1761 .36996 .18733 .3666 .17942 .35882 Mtetra
.638 .729 .914 r
.17942 .35882 .18733 .3666 .19862 .36324 .19073 .35541 Mtetra
.638 .728 .913 r
.19073 .35541 .19862 .36324 .20995 .35989 .2021 .35201 Mtetra
.637 .727 .913 r
.2021 .35201 .20995 .35989 .22134 .35654 .21352 .34861 Mtetra
.21352 .34861 .22134 .35654 .23279 .35318 .22499 .3452 Mtetra
.636 .726 .913 r
.22499 .3452 .23279 .35318 .24429 .34982 .23652 .34179 Mtetra
.23652 .34179 .24429 .34982 .25585 .34645 .2481 .33838 Mtetra
.636 .725 .912 r
.2481 .33838 .25585 .34645 .26746 .34308 .25975 .33495 Mtetra
.636 .724 .912 r
.25975 .33495 .26746 .34308 .27913 .33968 .27145 .3315 Mtetra
.27145 .3315 .27913 .33968 .29086 .33627 .28321 .32804 Mtetra
.636 .724 .911 r
.28321 .32804 .29086 .33627 .30265 .33284 .29503 .32455 Mtetra
.636 .723 .911 r
.29503 .32455 .30265 .33284 .3145 .32939 .3069 .32104 Mtetra
.637 .723 .91 r
.3069 .32104 .3145 .32939 .32641 .32591 .31884 .3175 Mtetra
.637 .722 .909 r
.31884 .3175 .32641 .32591 .33838 .32239 .33084 .31393 Mtetra
.638 .722 .909 r
.33084 .31393 .33838 .32239 .35041 .31884 .34291 .31032 Mtetra
.639 .721 .908 r
.34291 .31032 .35041 .31884 .3625 .31526 .35503 .30667 Mtetra
.639 .721 .907 r
.35503 .30667 .3625 .31526 .37466 .31164 .36722 .30297 Mtetra
.64 .72 .906 r
.36722 .30297 .37466 .31164 .38687 .30797 .37947 .29922 Mtetra
.641 .72 .905 r
.37947 .29922 .38687 .30797 .39915 .30426 .39178 .29543 Mtetra
.643 .719 .903 r
.39178 .29543 .39915 .30426 .4115 .30049 .40416 .29157 Mtetra
.644 .718 .902 r
.40416 .29157 .4115 .30049 .4239 .29667 .41659 .28766 Mtetra
.645 .717 .9 r
.41659 .28766 .4239 .29667 .43637 .29279 .4291 .28367 Mtetra
.647 .716 .898 r
.4291 .28367 .43637 .29279 .4489 .28884 .44166 .27962 Mtetra
.649 .715 .896 r
.44166 .27962 .4489 .28884 .4615 .28481 .45429 .27548 Mtetra
.651 .714 .894 r
.45429 .27548 .4615 .28481 .47416 .28069 .46699 .27125 Mtetra
.653 .713 .892 r
.46699 .27125 .47416 .28069 .48688 .27647 .47975 .26692 Mtetra
.655 .712 .89 r
.47975 .26692 .48688 .27647 .49967 .27214 .49257 .26249 Mtetra
.658 .712 .888 r
.49257 .26249 .49967 .27214 .51252 .26768 .50545 .25794 Mtetra
.661 .712 .886 r
.50545 .25794 .51252 .26768 .52543 .26309 .51839 .25327 Mtetra
.664 .712 .884 r
.51839 .25327 .52543 .26309 .5384 .25835 .5314 .24846 Mtetra
.666 .712 .882 r
.5314 .24846 .5384 .25835 .55142 .25347 .54446 .24353 Mtetra
.669 .713 .881 r
.54446 .24353 .55142 .25347 .56451 .24843 .55758 .23846 Mtetra
.672 .715 .88 r
.55758 .23846 .56451 .24843 .57765 .24324 .57076 .23326 Mtetra
.675 .716 .88 r
.57076 .23326 .57765 .24324 .59085 .23791 .584 .22793 Mtetra
.678 .718 .88 r
.584 .22793 .59085 .23791 .60411 .23245 .5973 .22249 Mtetra
.68 .721 .88 r
.5973 .22249 .60411 .23245 .61741 .22686 .61064 .21693 Mtetra
.682 .723 .881 r
.61064 .21693 .61741 .22686 .63078 .22117 .62405 .21128 Mtetra
.684 .726 .882 r
.62405 .21128 .63078 .22117 .64419 .21538 .63751 .20553 Mtetra
.686 .729 .883 r
.63751 .20553 .64419 .21538 .65766 .20952 .65102 .19972 Mtetra
.687 .731 .884 r
.65102 .19972 .65766 .20952 .67118 .2036 .66459 .19384 Mtetra
.688 .734 .885 r
.66459 .19384 .67118 .2036 .68475 .19763 .67821 .18792 Mtetra
.689 .736 .887 r
.67821 .18792 .68475 .19763 .69839 .19163 .69189 .18195 Mtetra
.689 .738 .888 r
.69189 .18195 .69839 .19163 .71207 .18561 .70563 .17596 Mtetra
.69 .74 .89 r
.70563 .17596 .71207 .18561 .72582 .17958 .71943 .16995 Mtetra
.69 .742 .891 r
.71943 .16995 .72582 .17958 .73962 .17354 .73328 .16392 Mtetra
.689 .743 .892 r
.73328 .16392 .73962 .17354 .75348 .1675 .74719 .15789 Mtetra
.689 .744 .894 r
.74719 .15789 .75348 .1675 .76741 .16147 .76117 .15185 Mtetra
.688 .745 .895 r
.76117 .15185 .76741 .16147 .78139 .15544 .7752 .14581 Mtetra
.641 .73 .913 r
.13774 .36135 .1458 .36907 .15695 .36565 .14892 .35787 Mtetra
.641 .729 .913 r
.14892 .35787 .15695 .36565 .16816 .36223 .16016 .35441 Mtetra
.64 .729 .913 r
.16016 .35441 .16816 .36223 .17942 .35882 .17145 .35095 Mtetra
.639 .728 .913 r
.17145 .35095 .17942 .35882 .19073 .35541 .18279 .34749 Mtetra
.638 .727 .912 r
.18279 .34749 .19073 .35541 .2021 .35201 .19418 .34404 Mtetra
.19418 .34404 .2021 .35201 .21352 .34861 .20563 .34058 Mtetra
.637 .726 .912 r
.20563 .34058 .21352 .34861 .22499 .3452 .21713 .33712 Mtetra
.637 .725 .912 r
.21713 .33712 .22499 .3452 .23652 .34179 .22869 .33366 Mtetra
.22869 .33366 .23652 .34179 .2481 .33838 .2403 .33019 Mtetra
.636 .724 .911 r
.2403 .33019 .2481 .33838 .25975 .33495 .25197 .32671 Mtetra
.636 .723 .911 r
.25197 .32671 .25975 .33495 .27145 .3315 .2637 .32321 Mtetra
.636 .723 .91 r
.2637 .32321 .27145 .3315 .28321 .32804 .27549 .31969 Mtetra
.637 .722 .91 r
.27549 .31969 .28321 .32804 .29503 .32455 .28734 .31615 Mtetra
.637 .722 .909 r
.28734 .31615 .29503 .32455 .3069 .32104 .29925 .31258 Mtetra
.29925 .31258 .3069 .32104 .31884 .3175 .31122 .30898 Mtetra
.638 .721 .908 r
.31122 .30898 .31884 .3175 .33084 .31393 .32325 .30535 Mtetra
.639 .721 .907 r
.32325 .30535 .33084 .31393 .34291 .31032 .33534 .30167 Mtetra
.639 .72 .907 r
.33534 .30167 .34291 .31032 .35503 .30667 .3475 .29796 Mtetra
.64 .72 .906 r
.3475 .29796 .35503 .30667 .36722 .30297 .35972 .29419 Mtetra
.641 .72 .905 r
.35972 .29419 .36722 .30297 .37947 .29922 .372 .29038 Mtetra
.643 .719 .904 r
.372 .29038 .37947 .29922 .39178 .29543 .38435 .28651 Mtetra
.644 .719 .902 r
.38435 .28651 .39178 .29543 .40416 .29157 .39676 .28258 Mtetra
.645 .718 .901 r
.39676 .28258 .40416 .29157 .41659 .28766 .40923 .27858 Mtetra
.647 .718 .9 r
.40923 .27858 .41659 .28766 .4291 .28367 .42177 .27451 Mtetra
.649 .717 .898 r
.42177 .27451 .4291 .28367 .44166 .27962 .43437 .27036 Mtetra
.65 .717 .896 r
.43437 .27036 .44166 .27962 .45429 .27548 .44703 .26614 Mtetra
.652 .716 .895 r
.44703 .26614 .45429 .27548 .46699 .27125 .45976 .26182 Mtetra
.655 .716 .893 r
.45976 .26182 .46699 .27125 .47975 .26692 .47255 .2574 Mtetra
.657 .715 .891 r
.47255 .2574 .47975 .26692 .49257 .26249 .48541 .25289 Mtetra
.659 .715 .89 r
.48541 .25289 .49257 .26249 .50545 .25794 .49832 .24826 Mtetra
.662 .715 .888 r
.49832 .24826 .50545 .25794 .51839 .25327 .5113 .24352 Mtetra
.664 .716 .887 r
.5113 .24352 .51839 .25327 .5314 .24846 .52434 .23866 Mtetra
.667 .716 .885 r
.52434 .23866 .5314 .24846 .54446 .24353 .53744 .23368 Mtetra
.67 .717 .884 r
.53744 .23368 .54446 .24353 .55758 .23846 .5506 .22858 Mtetra
.672 .719 .884 r
.5506 .22858 .55758 .23846 .57076 .23326 .56382 .22337 Mtetra
.675 .72 .883 r
.56382 .22337 .57076 .23326 .584 .22793 .5771 .21803 Mtetra
.677 .722 .883 r
.5771 .21803 .584 .22793 .5973 .22249 .59043 .21259 Mtetra
.679 .724 .883 r
.59043 .21259 .5973 .22249 .61064 .21693 .60382 .20705 Mtetra
.681 .726 .884 r
.60382 .20705 .61064 .21693 .62405 .21128 .61727 .20141 Mtetra
.683 .728 .884 r
.61727 .20141 .62405 .21128 .63751 .20553 .63077 .19569 Mtetra
.685 .73 .885 r
.63077 .19569 .63751 .20553 .65102 .19972 .64433 .18991 Mtetra
.686 .732 .886 r
.64433 .18991 .65102 .19972 .66459 .19384 .65794 .18405 Mtetra
.687 .735 .887 r
.65794 .18405 .66459 .19384 .67821 .18792 .67162 .17815 Mtetra
.687 .736 .888 r
.67162 .17815 .67821 .18792 .69189 .18195 .68535 .17221 Mtetra
.688 .738 .889 r
.68535 .17221 .69189 .18195 .70563 .17596 .69913 .16623 Mtetra
.688 .74 .89 r
.69913 .16623 .70563 .17596 .71943 .16995 .71298 .16022 Mtetra
.688 .741 .891 r
.71298 .16022 .71943 .16995 .73328 .16392 .72688 .1542 Mtetra
.688 .742 .892 r
.72688 .1542 .73328 .16392 .74719 .15789 .74084 .14816 Mtetra
.688 .743 .893 r
.74084 .14816 .74719 .15789 .76117 .15185 .75487 .14211 Mtetra
.687 .744 .894 r
.75487 .14211 .76117 .15185 .7752 .14581 .76896 .13606 Mtetra
.642 .73 .912 r
.12962 .35354 .13774 .36135 .14892 .35787 .14083 .35002 Mtetra
.641 .729 .912 r
.14083 .35002 .14892 .35787 .16016 .35441 .1521 .3465 Mtetra
.641 .728 .912 r
.1521 .3465 .16016 .35441 .17145 .35095 .16341 .34299 Mtetra
.64 .727 .912 r
.16341 .34299 .17145 .35095 .18279 .34749 .17478 .33948 Mtetra
.639 .727 .912 r
.17478 .33948 .18279 .34749 .19418 .34404 .1862 .33597 Mtetra
.639 .726 .911 r
.1862 .33597 .19418 .34404 .20563 .34058 .19768 .33246 Mtetra
.638 .725 .911 r
.19768 .33246 .20563 .34058 .21713 .33712 .20921 .32894 Mtetra
.20921 .32894 .21713 .33712 .22869 .33366 .22079 .32543 Mtetra
.637 .724 .91 r
.22079 .32543 .22869 .33366 .2403 .33019 .23244 .3219 Mtetra
.637 .723 .91 r
.23244 .3219 .2403 .33019 .25197 .32671 .24414 .31836 Mtetra
.24414 .31836 .25197 .32671 .2637 .32321 .2559 .3148 Mtetra
.637 .722 .909 r
.2559 .3148 .2637 .32321 .27549 .31969 .26772 .31122 Mtetra
.26772 .31122 .27549 .31969 .28734 .31615 .2796 .30763 Mtetra
.638 .721 .908 r
.2796 .30763 .28734 .31615 .29925 .31258 .29154 .304 Mtetra
.638 .721 .907 r
.29154 .304 .29925 .31258 .31122 .30898 .30354 .30034 Mtetra
.639 .72 .907 r
.30354 .30034 .31122 .30898 .32325 .30535 .3156 .29665 Mtetra
.639 .72 .906 r
.3156 .29665 .32325 .30535 .33534 .30167 .32772 .29291 Mtetra
.64 .719 .905 r
.32772 .29291 .33534 .30167 .3475 .29796 .33991 .28913 Mtetra
.641 .719 .904 r
.33991 .28913 .3475 .29796 .35972 .29419 .35216 .28531 Mtetra
.642 .719 .903 r
.35216 .28531 .35972 .29419 .372 .29038 .36448 .28142 Mtetra
.644 .719 .902 r
.36448 .28142 .372 .29038 .38435 .28651 .37685 .27749 Mtetra
.645 .718 .901 r
.37685 .27749 .38435 .28651 .39676 .28258 .3893 .27348 Mtetra
.646 .718 .9 r
.3893 .27348 .39676 .28258 .40923 .27858 .4018 .26941 Mtetra
.648 .718 .899 r
.4018 .26941 .40923 .27858 .42177 .27451 .41437 .26527 Mtetra
.65 .717 .898 r
.41437 .26527 .42177 .27451 .43437 .27036 .42701 .26105 Mtetra
.652 .717 .896 r
.42701 .26105 .43437 .27036 .44703 .26614 .43971 .25674 Mtetra
.654 .717 .895 r
.43971 .25674 .44703 .26614 .45976 .26182 .45247 .25235 Mtetra
.656 .717 .893 r
.45247 .25235 .45976 .26182 .47255 .2574 .4653 .24786 Mtetra
.658 .717 .892 r
.4653 .24786 .47255 .2574 .48541 .25289 .47819 .24328 Mtetra
.66 .717 .891 r
.47819 .24328 .48541 .25289 .49832 .24826 .49114 .23859 Mtetra
.662 .718 .889 r
.49114 .23859 .49832 .24826 .5113 .24352 .50415 .23379 Mtetra
.665 .718 .888 r
.50415 .23379 .5113 .24352 .52434 .23866 .51723 .22888 Mtetra
.667 .719 .887 r
.51723 .22888 .52434 .23866 .53744 .23368 .53037 .22386 Mtetra
.67 .72 .886 r
.53037 .22386 .53744 .23368 .5506 .22858 .54357 .21873 Mtetra
.672 .721 .886 r
.54357 .21873 .5506 .22858 .56382 .22337 .55682 .21349 Mtetra
.674 .722 .885 r
.55682 .21349 .56382 .22337 .5771 .21803 .57014 .20815 Mtetra
.676 .724 .885 r
.57014 .20815 .5771 .21803 .59043 .21259 .58351 .2027 Mtetra
.678 .726 .885 r
.58351 .2027 .59043 .21259 .60382 .20705 .59694 .19716 Mtetra
.68 .727 .886 r
.59694 .19716 .60382 .20705 .61727 .20141 .61043 .19153 Mtetra
.682 .729 .886 r
.61043 .19153 .61727 .20141 .63077 .19569 .62398 .18582 Mtetra
.683 .731 .887 r
.62398 .18582 .63077 .19569 .64433 .18991 .63758 .18004 Mtetra
.684 .733 .887 r
.63758 .18004 .64433 .18991 .65794 .18405 .65125 .1742 Mtetra
.685 .735 .888 r
.65125 .1742 .65794 .18405 .67162 .17815 .66496 .16831 Mtetra
.686 .736 .889 r
.66496 .16831 .67162 .17815 .68535 .17221 .67874 .16237 Mtetra
.687 .738 .89 r
.67874 .16237 .68535 .17221 .69913 .16623 .69258 .1564 Mtetra
.687 .739 .891 r
.69258 .1564 .69913 .16623 .71298 .16022 .70647 .15039 Mtetra
.687 .74 .892 r
.70647 .15039 .71298 .16022 .72688 .1542 .72042 .14436 Mtetra
.687 .741 .892 r
.72042 .14436 .72688 .1542 .74084 .14816 .73444 .13831 Mtetra
.687 .742 .893 r
.73444 .13831 .74084 .14816 .75487 .14211 .74852 .13225 Mtetra
.686 .743 .894 r
.74852 .13225 .75487 .14211 .76896 .13606 .76265 .12619 Mtetra
.643 .729 .911 r
.12144 .34565 .12962 .35354 .14083 .35002 .13268 .34208 Mtetra
.642 .729 .911 r
.13268 .34208 .14083 .35002 .1521 .3465 .14397 .3385 Mtetra
.641 .728 .911 r
.14397 .3385 .1521 .3465 .16341 .34299 .15532 .33494 Mtetra
.641 .727 .911 r
.15532 .33494 .16341 .34299 .17478 .33948 .16671 .33137 Mtetra
.64 .726 .911 r
.16671 .33137 .17478 .33948 .1862 .33597 .17816 .3278 Mtetra
.639 .725 .91 r
.17816 .3278 .1862 .33597 .19768 .33246 .18967 .32424 Mtetra
.18967 .32424 .19768 .33246 .20921 .32894 .20123 .32067 Mtetra
.639 .724 .91 r
.20123 .32067 .20921 .32894 .22079 .32543 .21284 .31709 Mtetra
.638 .723 .909 r
.21284 .31709 .22079 .32543 .23244 .3219 .22452 .3135 Mtetra
.22452 .3135 .23244 .3219 .24414 .31836 .23625 .3099 Mtetra
.638 .722 .909 r
.23625 .3099 .24414 .31836 .2559 .3148 .24804 .30629 Mtetra
.638 .721 .908 r
.24804 .30629 .2559 .3148 .26772 .31122 .25989 .30265 Mtetra
.638 .721 .907 r
.25989 .30265 .26772 .31122 .2796 .30763 .27179 .29899 Mtetra
.639 .72 .907 r
.27179 .29899 .2796 .30763 .29154 .304 .28376 .2953 Mtetra
.639 .72 .906 r
.28376 .2953 .29154 .304 .30354 .30034 .2958 .29158 Mtetra
.64 .719 .906 r
.2958 .29158 .30354 .30034 .3156 .29665 .30789 .28783 Mtetra
.64 .719 .905 r
.30789 .28783 .3156 .29665 .32772 .29291 .32004 .28403 Mtetra
.641 .719 .904 r
.32004 .28403 .32772 .29291 .33991 .28913 .33226 .28019 Mtetra
.642 .718 .903 r
.33226 .28019 .33991 .28913 .35216 .28531 .34455 .2763 Mtetra
.643 .718 .902 r
.34455 .2763 .35216 .28531 .36448 .28142 .35689 .27236 Mtetra
.644 .718 .901 r
.35689 .27236 .36448 .28142 .37685 .27749 .3693 .26835 Mtetra
.646 .718 .9 r
.3693 .26835 .37685 .27749 .3893 .27348 .38178 .26428 Mtetra
.647 .717 .899 r
.38178 .26428 .3893 .27348 .4018 .26941 .39432 .26015 Mtetra
.649 .717 .898 r
.39432 .26015 .4018 .26941 .41437 .26527 .40692 .25594 Mtetra
.651 .717 .897 r
.40692 .25594 .41437 .26527 .42701 .26105 .41959 .25165 Mtetra
.652 .717 .896 r
.41959 .25165 .42701 .26105 .43971 .25674 .43232 .24728 Mtetra
.654 .717 .895 r
.43232 .24728 .43971 .25674 .45247 .25235 .44512 .24282 Mtetra
.656 .718 .893 r
.44512 .24282 .45247 .25235 .4653 .24786 .45798 .23827 Mtetra
.658 .718 .892 r
.45798 .23827 .4653 .24786 .47819 .24328 .47091 .23362 Mtetra
.661 .718 .891 r
.47091 .23362 .47819 .24328 .49114 .23859 .4839 .22888 Mtetra
.663 .719 .89 r
.4839 .22888 .49114 .23859 .50415 .23379 .49695 .22403 Mtetra
.665 .719 .889 r
.49695 .22403 .50415 .23379 .51723 .22888 .51006 .21908 Mtetra
.667 .72 .888 r
.51006 .21908 .51723 .22888 .53037 .22386 .52324 .21402 Mtetra
.67 .721 .888 r
.52324 .21402 .53037 .22386 .54357 .21873 .53647 .20886 Mtetra
.672 .722 .887 r
.53647 .20886 .54357 .21873 .55682 .21349 .54977 .20359 Mtetra
.674 .723 .887 r
.54977 .20359 .55682 .21349 .57014 .20815 .56312 .19823 Mtetra
.676 .725 .887 r
.56312 .19823 .57014 .20815 .58351 .2027 .57654 .19277 Mtetra
.678 .726 .887 r
.57654 .19277 .58351 .2027 .59694 .19716 .59001 .18722 Mtetra
.679 .728 .887 r
.59001 .18722 .59694 .19716 .61043 .19153 .60354 .18159 Mtetra
.681 .729 .887 r
.60354 .18159 .61043 .19153 .62398 .18582 .61713 .17589 Mtetra
.682 .731 .887 r
.61713 .17589 .62398 .18582 .63758 .18004 .63078 .17011 Mtetra
.683 .733 .888 r
.63078 .17011 .63758 .18004 .65125 .1742 .64449 .16427 Mtetra
.684 .734 .888 r
.64449 .16427 .65125 .1742 .66496 .16831 .65825 .15838 Mtetra
.685 .736 .889 r
.65825 .15838 .66496 .16831 .67874 .16237 .67208 .15244 Mtetra
.685 .737 .89 r
.67208 .15244 .67874 .16237 .69258 .1564 .68596 .14646 Mtetra
.686 .738 .891 r
.68596 .14646 .69258 .1564 .70647 .15039 .6999 .14045 Mtetra
.686 .739 .891 r
.6999 .14045 .70647 .15039 .72042 .14436 .71391 .13441 Mtetra
.686 .74 .892 r
.71391 .13441 .72042 .14436 .73444 .13831 .72797 .12835 Mtetra
.686 .741 .893 r
.72797 .12835 .73444 .13831 .74852 .13225 .7421 .12228 Mtetra
.685 .742 .894 r
.7421 .12228 .74852 .13225 .76265 .12619 .75629 .1162 Mtetra
.644 .729 .911 r
.1132 .33769 .12144 .34565 .13268 .34208 .12447 .33405 Mtetra
.643 .728 .911 r
.12447 .33405 .13268 .34208 .14397 .3385 .13579 .33043 Mtetra
.642 .727 .91 r
.13579 .33043 .14397 .3385 .15532 .33494 .14716 .3268 Mtetra
.641 .727 .91 r
.14716 .3268 .15532 .33494 .16671 .33137 .15858 .32318 Mtetra
.641 .726 .91 r
.15858 .32318 .16671 .33137 .17816 .3278 .17006 .31955 Mtetra
.64 .725 .91 r
.17006 .31955 .17816 .3278 .18967 .32424 .18159 .31592 Mtetra
.64 .724 .909 r
.18159 .31592 .18967 .32424 .20123 .32067 .19318 .31229 Mtetra
.639 .723 .909 r
.19318 .31229 .20123 .32067 .21284 .31709 .20483 .30865 Mtetra
.20483 .30865 .21284 .31709 .22452 .3135 .21653 .30501 Mtetra
.639 .722 .908 r
.21653 .30501 .22452 .3135 .23625 .3099 .22829 .30134 Mtetra
.639 .721 .908 r
.22829 .30134 .23625 .3099 .24804 .30629 .24011 .29767 Mtetra
.639 .721 .907 r
.24011 .29767 .24804 .30629 .25989 .30265 .25199 .29397 Mtetra
.639 .72 .906 r
.25199 .29397 .25989 .30265 .27179 .29899 .26393 .29025 Mtetra
.639 .719 .906 r
.26393 .29025 .27179 .29899 .28376 .2953 .27593 .2865 Mtetra
.64 .719 .905 r
.27593 .2865 .28376 .2953 .2958 .29158 .28799 .28272 Mtetra
.64 .718 .904 r
.28799 .28272 .2958 .29158 .30789 .28783 .30012 .2789 Mtetra
.641 .718 .904 r
.30012 .2789 .30789 .28783 .32004 .28403 .31231 .27504 Mtetra
.642 .718 .903 r
.31231 .27504 .32004 .28403 .33226 .28019 .32456 .27114 Mtetra
.643 .717 .902 r
.32456 .27114 .33226 .28019 .34455 .2763 .33687 .26718 Mtetra
.644 .717 .901 r
.33687 .26718 .34455 .2763 .35689 .27236 .34925 .26317 Mtetra
.645 .717 .9 r
.34925 .26317 .35689 .27236 .3693 .26835 .36169 .25911 Mtetra
.646 .717 .899 r
.36169 .25911 .3693 .26835 .38178 .26428 .3742 .25497 Mtetra
.648 .717 .898 r
.3742 .25497 .38178 .26428 .39432 .26015 .38677 .25077 Mtetra
.649 .717 .897 r
.38677 .25077 .39432 .26015 .40692 .25594 .39941 .2465 Mtetra
.651 .717 .896 r
.39941 .2465 .40692 .25594 .41959 .25165 .41211 .24215 Mtetra
.653 .717 .895 r
.41211 .24215 .41959 .25165 .43232 .24728 .42488 .23772 Mtetra
.655 .717 .894 r
.42488 .23772 .43232 .24728 .44512 .24282 .43771 .2332 Mtetra
.657 .717 .893 r
.43771 .2332 .44512 .24282 .45798 .23827 .45061 .22859 Mtetra
.659 .718 .892 r
.45061 .22859 .45798 .23827 .47091 .23362 .46357 .22389 Mtetra
.661 .718 .891 r
.46357 .22389 .47091 .23362 .4839 .22888 .47659 .2191 Mtetra
.663 .719 .89 r
.47659 .2191 .4839 .22888 .49695 .22403 .48968 .2142 Mtetra
.665 .72 .889 r
.48968 .2142 .49695 .22403 .51006 .21908 .50283 .20921 Mtetra
.667 .72 .889 r
.50283 .20921 .51006 .21908 .52324 .21402 .51604 .20412 Mtetra
.669 .721 .888 r
.51604 .20412 .52324 .21402 .53647 .20886 .52932 .19892 Mtetra
.671 .723 .888 r
.52932 .19892 .53647 .20886 .54977 .20359 .54265 .19364 Mtetra
.673 .724 .887 r
.54265 .19364 .54977 .20359 .56312 .19823 .55605 .18825 Mtetra
.675 .725 .887 r
.55605 .18825 .56312 .19823 .57654 .19277 .5695 .18278 Mtetra
.677 .726 .887 r
.5695 .18278 .57654 .19277 .59001 .18722 .58302 .17722 Mtetra
.678 .728 .887 r
.58302 .17722 .59001 .18722 .60354 .18159 .59659 .17158 Mtetra
.68 .729 .887 r
.59659 .17158 .60354 .18159 .61713 .17589 .61023 .16586 Mtetra
.681 .731 .888 r
.61023 .16586 .61713 .17589 .63078 .17011 .62392 .16008 Mtetra
.682 .732 .888 r
.62392 .16008 .63078 .17011 .64449 .16427 .63767 .15424 Mtetra
.683 .733 .889 r
.63767 .15424 .64449 .16427 .65825 .15838 .65148 .14834 Mtetra
.684 .735 .889 r
.65148 .14834 .65825 .15838 .67208 .15244 .66536 .1424 Mtetra
.684 .736 .89 r
.66536 .1424 .67208 .15244 .68596 .14646 .67929 .13641 Mtetra
.685 .737 .891 r
.67929 .13641 .68596 .14646 .6999 .14045 .69328 .13039 Mtetra
.685 .738 .891 r
.69328 .13039 .6999 .14045 .71391 .13441 .70733 .12434 Mtetra
.685 .739 .892 r
.70733 .12434 .71391 .13441 .72797 .12835 .72145 .11827 Mtetra
.685 .74 .893 r
.72145 .11827 .72797 .12835 .7421 .12228 .73563 .11219 Mtetra
.684 .741 .894 r
.73563 .11219 .7421 .12228 .75629 .1162 .74987 .10609 Mtetra
.644 .729 .91 r
.10489 .32964 .1132 .33769 .12447 .33405 .11619 .32595 Mtetra
.644 .728 .91 r
.11619 .32595 .12447 .33405 .13579 .33043 .12753 .32226 Mtetra
.643 .727 .91 r
.12753 .32226 .13579 .33043 .14716 .3268 .13894 .31858 Mtetra
.642 .726 .91 r
.13894 .31858 .14716 .3268 .15858 .32318 .15039 .3149 Mtetra
.642 .726 .909 r
.15039 .3149 .15858 .32318 .17006 .31955 .1619 .31121 Mtetra
.641 .725 .909 r
.1619 .31121 .17006 .31955 .18159 .31592 .17346 .30752 Mtetra
.641 .724 .909 r
.17346 .30752 .18159 .31592 .19318 .31229 .18508 .30383 Mtetra
.64 .723 .908 r
.18508 .30383 .19318 .31229 .20483 .30865 .19675 .30013 Mtetra
.64 .722 .908 r
.19675 .30013 .20483 .30865 .21653 .30501 .20849 .29642 Mtetra
.64 .722 .907 r
.20849 .29642 .21653 .30501 .22829 .30134 .22028 .29269 Mtetra
.64 .721 .907 r
.22028 .29269 .22829 .30134 .24011 .29767 .23213 .28895 Mtetra
.64 .72 .906 r
.23213 .28895 .24011 .29767 .25199 .29397 .24404 .28518 Mtetra
.64 .719 .905 r
.24404 .28518 .25199 .29397 .26393 .29025 .25601 .2814 Mtetra
.25601 .2814 .26393 .29025 .27593 .2865 .26804 .27758 Mtetra
.641 .718 .904 r
.26804 .27758 .27593 .2865 .28799 .28272 .28013 .27374 Mtetra
.641 .718 .903 r
.28013 .27374 .28799 .28272 .30012 .2789 .29229 .26986 Mtetra
.642 .717 .903 r
.29229 .26986 .30012 .2789 .31231 .27504 .30451 .26593 Mtetra
.643 .717 .902 r
.30451 .26593 .31231 .27504 .32456 .27114 .31679 .26197 Mtetra
.644 .717 .901 r
.31679 .26197 .32456 .27114 .33687 .26718 .32914 .25795 Mtetra
.645 .716 .9 r
.32914 .25795 .33687 .26718 .34925 .26317 .34155 .25388 Mtetra
.646 .716 .899 r
.34155 .25388 .34925 .26317 .36169 .25911 .35402 .24975 Mtetra
.647 .716 .898 r
.35402 .24975 .36169 .25911 .3742 .25497 .36656 .24555 Mtetra
.648 .716 .897 r
.36656 .24555 .3742 .25497 .38677 .25077 .37917 .24129 Mtetra
.65 .716 .896 r
.37917 .24129 .38677 .25077 .39941 .2465 .39184 .23696 Mtetra
.652 .716 .896 r
.39184 .23696 .39941 .2465 .41211 .24215 .40458 .23255 Mtetra
.653 .717 .895 r
.40458 .23255 .41211 .24215 .42488 .23772 .41738 .22806 Mtetra
.655 .717 .894 r
.41738 .22806 .42488 .23772 .43771 .2332 .43025 .22349 Mtetra
.657 .717 .893 r
.43025 .22349 .43771 .2332 .45061 .22859 .44318 .21883 Mtetra
.659 .718 .892 r
.44318 .21883 .45061 .22859 .46357 .22389 .45617 .21408 Mtetra
.661 .718 .891 r
.45617 .21408 .46357 .22389 .47659 .2191 .46923 .20923 Mtetra
.663 .719 .89 r
.46923 .20923 .47659 .2191 .48968 .2142 .48236 .20429 Mtetra
.665 .72 .89 r
.48236 .20429 .48968 .2142 .50283 .20921 .49554 .19926 Mtetra
.667 .72 .889 r
.49554 .19926 .50283 .20921 .51604 .20412 .50879 .19413 Mtetra
.669 .721 .888 r
.50879 .19413 .51604 .20412 .52932 .19892 .52211 .18891 Mtetra
.671 .722 .888 r
.52211 .18891 .52932 .19892 .54265 .19364 .53548 .1836 Mtetra
.673 .724 .888 r
.53548 .1836 .54265 .19364 .55605 .18825 .54891 .17819 Mtetra
.674 .725 .887 r
.54891 .17819 .55605 .18825 .5695 .18278 .56241 .1727 Mtetra
.676 .726 .887 r
.56241 .1727 .5695 .18278 .58302 .17722 .57597 .16712 Mtetra
.677 .727 .887 r
.57597 .16712 .58302 .17722 .59659 .17158 .58958 .16147 Mtetra
.679 .729 .888 r
.58958 .16147 .59659 .17158 .61023 .16586 .60326 .15575 Mtetra
.68 .73 .888 r
.60326 .15575 .61023 .16586 .62392 .16008 .617 .14995 Mtetra
.681 .731 .888 r
.617 .14995 .62392 .16008 .63767 .15424 .6308 .1441 Mtetra
.682 .733 .889 r
.6308 .1441 .63767 .15424 .65148 .14834 .64465 .1382 Mtetra
.683 .734 .889 r
.64465 .1382 .65148 .14834 .66536 .1424 .65857 .13224 Mtetra
.683 .735 .89 r
.65857 .13224 .66536 .1424 .67929 .13641 .67255 .12625 Mtetra
.684 .736 .89 r
.67255 .12625 .67929 .13641 .69328 .13039 .68659 .12022 Mtetra
.684 .737 .891 r
.68659 .12022 .69328 .13039 .70733 .12434 .7007 .11416 Mtetra
.684 .738 .892 r
.7007 .11416 .70733 .12434 .72145 .11827 .71486 .10808 Mtetra
.684 .739 .893 r
.71486 .10808 .72145 .11827 .73563 .11219 .72909 .10197 Mtetra
.72909 .10197 .73563 .11219 .74987 .10609 .74339 .09586 Mtetra
.645 .729 .91 r
.09652 .32152 .10489 .32964 .11619 .32595 .10784 .31777 Mtetra
.645 .728 .909 r
.10784 .31777 .11619 .32595 .12753 .32226 .11922 .31402 Mtetra
.644 .727 .909 r
.11922 .31402 .12753 .32226 .13894 .31858 .13065 .31028 Mtetra
.643 .726 .909 r
.13065 .31028 .13894 .31858 .15039 .3149 .14213 .30653 Mtetra
.643 .725 .909 r
.14213 .30653 .15039 .3149 .1619 .31121 .15367 .30279 Mtetra
.642 .725 .908 r
.15367 .30279 .1619 .31121 .17346 .30752 .16526 .29903 Mtetra
.642 .724 .908 r
.16526 .29903 .17346 .30752 .18508 .30383 .17691 .29528 Mtetra
.641 .723 .907 r
.17691 .29528 .18508 .30383 .19675 .30013 .18862 .29151 Mtetra
.641 .722 .907 r
.18862 .29151 .19675 .30013 .20849 .29642 .20038 .28773 Mtetra
.641 .721 .906 r
.20038 .28773 .20849 .29642 .22028 .29269 .2122 .28394 Mtetra
.2122 .28394 .22028 .29269 .23213 .28895 .22408 .28013 Mtetra
.641 .72 .905 r
.22408 .28013 .23213 .28895 .24404 .28518 .23602 .2763 Mtetra
.641 .719 .905 r
.23602 .2763 .24404 .28518 .25601 .2814 .24802 .27245 Mtetra
.641 .718 .904 r
.24802 .27245 .25601 .2814 .26804 .27758 .26008 .26857 Mtetra
.642 .718 .903 r
.26008 .26857 .26804 .27758 .28013 .27374 .27221 .26466 Mtetra
.642 .717 .902 r
.27221 .26466 .28013 .27374 .29229 .26986 .2844 .26071 Mtetra
.643 .717 .902 r
.2844 .26071 .29229 .26986 .30451 .26593 .29665 .25672 Mtetra
.643 .716 .901 r
.29665 .25672 .30451 .26593 .31679 .26197 .30896 .25269 Mtetra
.644 .716 .9 r
.30896 .25269 .31679 .26197 .32914 .25795 .32134 .24861 Mtetra
.645 .716 .899 r
.32134 .24861 .32914 .25795 .34155 .25388 .33378 .24447 Mtetra
.646 .716 .898 r
.33378 .24447 .34155 .25388 .35402 .24975 .34629 .24028 Mtetra
.648 .716 .897 r
.34629 .24028 .35402 .24975 .36656 .24555 .35887 .23602 Mtetra
.649 .716 .897 r
.35887 .23602 .36656 .24555 .37917 .24129 .3715 .2317 Mtetra
.65 .716 .896 r
.3715 .2317 .37917 .24129 .39184 .23696 .38421 .22731 Mtetra
.652 .716 .895 r
.38421 .22731 .39184 .23696 .40458 .23255 .39698 .22284 Mtetra
.654 .716 .894 r
.39698 .22284 .40458 .23255 .41738 .22806 .40981 .2183 Mtetra
.655 .716 .893 r
.40981 .2183 .41738 .22806 .43025 .22349 .42272 .21367 Mtetra
.657 .717 .892 r
.42272 .21367 .43025 .22349 .44318 .21883 .43568 .20896 Mtetra
.659 .717 .891 r
.43568 .20896 .44318 .21883 .45617 .21408 .44871 .20416 Mtetra
.661 .718 .891 r
.44871 .20416 .45617 .21408 .46923 .20923 .46181 .19927 Mtetra
.663 .718 .89 r
.46181 .19927 .46923 .20923 .48236 .20429 .47497 .19429 Mtetra
.665 .719 .889 r
.47497 .19429 .48236 .20429 .49554 .19926 .48819 .18922 Mtetra
.667 .72 .889 r
.48819 .18922 .49554 .19926 .50879 .19413 .50148 .18406 Mtetra
.668 .721 .888 r
.50148 .18406 .50879 .19413 .52211 .18891 .51483 .1788 Mtetra
.67 .722 .888 r
.51483 .1788 .52211 .18891 .53548 .1836 .52825 .17346 Mtetra
.672 .723 .888 r
.52825 .17346 .53548 .1836 .54891 .17819 .54172 .16803 Mtetra
.674 .724 .888 r
.54172 .16803 .54891 .17819 .56241 .1727 .55526 .16252 Mtetra
.675 .725 .887 r
.55526 .16252 .56241 .1727 .57597 .16712 .56886 .15693 Mtetra
.677 .727 .888 r
.56886 .15693 .57597 .16712 .58958 .16147 .58252 .15126 Mtetra
.678 .728 .888 r
.58252 .15126 .58958 .16147 .60326 .15575 .59624 .14552 Mtetra
.679 .729 .888 r
.59624 .14552 .60326 .15575 .617 .14995 .61002 .13972 Mtetra
.68 .73 .888 r
.61002 .13972 .617 .14995 .6308 .1441 .62386 .13386 Mtetra
.681 .732 .889 r
.62386 .13386 .6308 .1441 .64465 .1382 .63776 .12794 Mtetra
.682 .733 .889 r
.63776 .12794 .64465 .1382 .65857 .13224 .65173 .12198 Mtetra
.682 .734 .89 r
.65173 .12198 .65857 .13224 .67255 .12625 .66576 .11597 Mtetra
.682 .735 .89 r
.66576 .11597 .67255 .12625 .68659 .12022 .67985 .10993 Mtetra
.683 .736 .891 r
.67985 .10993 .68659 .12022 .7007 .11416 .694 .10386 Mtetra
.683 .737 .892 r
.694 .10386 .7007 .11416 .71486 .10808 .70822 .09776 Mtetra
.683 .738 .892 r
.70822 .09776 .71486 .10808 .72909 .10197 .7225 .09164 Mtetra
.683 .738 .893 r
.7225 .09164 .72909 .10197 .74339 .09586 .73685 .08551 Mtetra
.646 .729 .909 r
.08808 .31332 .09652 .32152 .10784 .31777 .09943 .30952 Mtetra
.645 .728 .909 r
.09943 .30952 .10784 .31777 .11922 .31402 .11084 .30571 Mtetra
.645 .727 .909 r
.11084 .30571 .11922 .31402 .13065 .31028 .12229 .3019 Mtetra
.644 .726 .908 r
.12229 .3019 .13065 .31028 .14213 .30653 .13381 .29809 Mtetra
.644 .725 .908 r
.13381 .29809 .14213 .30653 .15367 .30279 .14538 .29428 Mtetra
.643 .725 .908 r
.14538 .29428 .15367 .30279 .16526 .29903 .157 .29046 Mtetra
.643 .724 .907 r
.157 .29046 .16526 .29903 .17691 .29528 .16868 .28664 Mtetra
.642 .723 .907 r
.16868 .28664 .17691 .29528 .18862 .29151 .18041 .28281 Mtetra
.642 .722 .906 r
.18041 .28281 .18862 .29151 .20038 .28773 .19221 .27896 Mtetra
.642 .721 .906 r
.19221 .27896 .20038 .28773 .2122 .28394 .20406 .2751 Mtetra
.642 .72 .905 r
.20406 .2751 .2122 .28394 .22408 .28013 .21597 .27123 Mtetra
.642 .72 .904 r
.21597 .27123 .22408 .28013 .23602 .2763 .22794 .26733 Mtetra
.642 .719 .904 r
.22794 .26733 .23602 .2763 .24802 .27245 .23997 .26341 Mtetra
.642 .718 .903 r
.23997 .26341 .24802 .27245 .26008 .26857 .25207 .25946 Mtetra
.642 .718 .902 r
.25207 .25946 .26008 .26857 .27221 .26466 .26422 .25548 Mtetra
.643 .717 .902 r
.26422 .25548 .27221 .26466 .2844 .26071 .27644 .25146 Mtetra
.644 .717 .901 r
.27644 .25146 .2844 .26071 .29665 .25672 .28872 .24741 Mtetra
.644 .716 .9 r
.28872 .24741 .29665 .25672 .30896 .25269 .30107 .24331 Mtetra
.645 .716 .899 r
.30107 .24331 .30896 .25269 .32134 .24861 .31348 .23916 Mtetra
.646 .715 .898 r
.31348 .23916 .32134 .24861 .33378 .24447 .32596 .23496 Mtetra
.647 .715 .898 r
.32596 .23496 .33378 .24447 .34629 .24028 .3385 .2307 Mtetra
.648 .715 .897 r
.3385 .2307 .34629 .24028 .35887 .23602 .35111 .22639 Mtetra
.65 .715 .896 r
.35111 .22639 .35887 .23602 .3715 .2317 .36378 .22201 Mtetra
.651 .715 .895 r
.36378 .22201 .3715 .2317 .38421 .22731 .37652 .21755 Mtetra
.652 .715 .894 r
.37652 .21755 .38421 .22731 .39698 .22284 .38932 .21303 Mtetra
.654 .715 .893 r
.38932 .21303 .39698 .22284 .40981 .2183 .40219 .20843 Mtetra
.656 .716 .893 r
.40219 .20843 .40981 .2183 .42272 .21367 .41513 .20375 Mtetra
.657 .716 .892 r
.41513 .20375 .42272 .21367 .43568 .20896 .42813 .19899 Mtetra
.659 .717 .891 r
.42813 .19899 .43568 .20896 .44871 .20416 .44119 .19414 Mtetra
.661 .717 .89 r
.44119 .19414 .44871 .20416 .46181 .19927 .45433 .18921 Mtetra
.663 .718 .89 r
.45433 .18921 .46181 .19927 .47497 .19429 .46752 .18419 Mtetra
.664 .719 .889 r
.46752 .18419 .47497 .19429 .48819 .18922 .48078 .17908 Mtetra
.666 .72 .889 r
.48078 .17908 .48819 .18922 .50148 .18406 .49411 .17388 Mtetra
.668 .72 .888 r
.49411 .17388 .50148 .18406 .51483 .1788 .5075 .1686 Mtetra
.67 .721 .888 r
.5075 .1686 .51483 .1788 .52825 .17346 .52095 .16323 Mtetra
.671 .722 .888 r
.52095 .16323 .52825 .17346 .54172 .16803 .53447 .15777 Mtetra
.673 .724 .888 r
.53447 .15777 .54172 .16803 .55526 .16252 .54804 .15224 Mtetra
.674 .725 .887 r
.54804 .15224 .55526 .16252 .56886 .15693 .56168 .14663 Mtetra
.676 .726 .888 r
.56168 .14663 .56886 .15693 .58252 .15126 .57539 .14094 Mtetra
.677 .727 .888 r
.57539 .14094 .58252 .15126 .59624 .14552 .58915 .13519 Mtetra
.678 .728 .888 r
.58915 .13519 .59624 .14552 .61002 .13972 .60298 .12937 Mtetra
.679 .729 .888 r
.60298 .12937 .61002 .13972 .62386 .13386 .61686 .1235 Mtetra
.68 .731 .889 r
.61686 .1235 .62386 .13386 .63776 .12794 .63081 .11757 Mtetra
.68 .732 .889 r
.63081 .11757 .63776 .12794 .65173 .12198 .64483 .1116 Mtetra
.681 .733 .89 r
.64483 .1116 .65173 .12198 .66576 .11597 .6589 .10558 Mtetra
.681 .734 .89 r
.6589 .10558 .66576 .11597 .67985 .10993 .67304 .09953 Mtetra
.682 .735 .891 r
.67304 .09953 .67985 .10993 .694 .10386 .68724 .09344 Mtetra
.682 .736 .892 r
.68724 .09344 .694 .10386 .70822 .09776 .70151 .08733 Mtetra
.682 .737 .892 r
.70151 .08733 .70822 .09776 .7225 .09164 .71584 .0812 Mtetra
.681 .738 .893 r
.71584 .0812 .7225 .09164 .73685 .08551 .73024 .07505 Mtetra
.647 .729 .909 r
.07957 .30506 .08808 .31332 .09943 .30952 .09095 .30119 Mtetra
.646 .728 .908 r
.09095 .30119 .09943 .30952 .11084 .30571 .10239 .29732 Mtetra
.646 .727 .908 r
.10239 .29732 .11084 .30571 .12229 .3019 .11387 .29345 Mtetra
.645 .726 .908 r
.11387 .29345 .12229 .3019 .13381 .29809 .12542 .28957 Mtetra
.645 .726 .907 r
.12542 .28957 .13381 .29809 .14538 .29428 .13701 .2857 Mtetra
.644 .725 .907 r
.13701 .2857 .14538 .29428 .157 .29046 .14867 .28181 Mtetra
.644 .724 .907 r
.14867 .28181 .157 .29046 .16868 .28664 .16038 .27792 Mtetra
.643 .723 .906 r
.16038 .27792 .16868 .28664 .18041 .28281 .17214 .27402 Mtetra
.643 .722 .906 r
.17214 .27402 .18041 .28281 .19221 .27896 .18397 .27011 Mtetra
.643 .721 .905 r
.18397 .27011 .19221 .27896 .20406 .2751 .19585 .26618 Mtetra
.643 .72 .904 r
.19585 .26618 .20406 .2751 .21597 .27123 .20779 .26223 Mtetra
.20779 .26223 .21597 .27123 .22794 .26733 .2198 .25827 Mtetra
.643 .719 .903 r
.2198 .25827 .22794 .26733 .23997 .26341 .23186 .25427 Mtetra
.643 .718 .902 r
.23186 .25427 .23997 .26341 .25207 .25946 .24399 .25026 Mtetra
.643 .717 .902 r
.24399 .25026 .25207 .25946 .26422 .25548 .25617 .24621 Mtetra
.644 .717 .901 r
.25617 .24621 .26422 .25548 .27644 .25146 .26843 .24212 Mtetra
.644 .716 .9 r
.26843 .24212 .27644 .25146 .28872 .24741 .28074 .238 Mtetra
.645 .716 .899 r
.28074 .238 .28872 .24741 .30107 .24331 .29312 .23383 Mtetra
.646 .715 .899 r
.29312 .23383 .30107 .24331 .31348 .23916 .30556 .22962 Mtetra
.647 .715 .898 r
.30556 .22962 .31348 .23916 .32596 .23496 .31807 .22535 Mtetra
.648 .715 .897 r
.31807 .22535 .32596 .23496 .3385 .2307 .33064 .22103 Mtetra
.649 .715 .896 r
.33064 .22103 .3385 .2307 .35111 .22639 .34328 .21665 Mtetra
.65 .715 .895 r
.34328 .21665 .35111 .22639 .36378 .22201 .35599 .21221 Mtetra
.651 .715 .894 r
.35599 .21221 .36378 .22201 .37652 .21755 .36876 .2077 Mtetra
.653 .715 .894 r
.36876 .2077 .37652 .21755 .38932 .21303 .3816 .20312 Mtetra
.654 .715 .893 r
.3816 .20312 .38932 .21303 .40219 .20843 .3945 .19846 Mtetra
.656 .715 .892 r
.3945 .19846 .40219 .20843 .41513 .20375 .40747 .19373 Mtetra
.657 .716 .891 r
.40747 .19373 .41513 .20375 .42813 .19899 .42051 .18892 Mtetra
.659 .716 .891 r
.42051 .18892 .42813 .19899 .44119 .19414 .43361 .18402 Mtetra
.661 .717 .89 r
.43361 .18402 .44119 .19414 .45433 .18921 .44678 .17905 Mtetra
.662 .717 .889 r
.44678 .17905 .45433 .18921 .46752 .18419 .46001 .17399 Mtetra
.664 .718 .889 r
.46001 .17399 .46752 .18419 .48078 .17908 .47331 .16884 Mtetra
.666 .719 .888 r
.47331 .16884 .48078 .17908 .49411 .17388 .48668 .16361 Mtetra
.668 .72 .888 r
.48668 .16361 .49411 .17388 .5075 .1686 .5001 .15829 Mtetra
.669 .721 .888 r
.5001 .15829 .5075 .1686 .52095 .16323 .5136 .15289 Mtetra
.671 .722 .888 r
.5136 .15289 .52095 .16323 .53447 .15777 .52715 .14741 Mtetra
.672 .723 .887 r
.52715 .14741 .53447 .15777 .54804 .15224 .54077 .14186 Mtetra
.674 .724 .887 r
.54077 .14186 .54804 .15224 .56168 .14663 .55445 .13623 Mtetra
.675 .725 .888 r
.55445 .13623 .56168 .14663 .57539 .14094 .5682 .13052 Mtetra
.676 .726 .888 r
.5682 .13052 .57539 .14094 .58915 .13519 .582 .12475 Mtetra
.677 .728 .888 r
.582 .12475 .58915 .13519 .60298 .12937 .59587 .11892 Mtetra
.678 .729 .888 r
.59587 .11892 .60298 .12937 .61686 .1235 .60981 .11303 Mtetra
.679 .73 .889 r
.60981 .11303 .61686 .1235 .63081 .11757 .6238 .10709 Mtetra
.679 .731 .889 r
.6238 .10709 .63081 .11757 .64483 .1116 .63786 .10111 Mtetra
.68 .732 .89 r
.63786 .10111 .64483 .1116 .6589 .10558 .65198 .09508 Mtetra
.68 .733 .89 r
.65198 .09508 .6589 .10558 .67304 .09953 .66617 .08901 Mtetra
.681 .734 .891 r
.66617 .08901 .67304 .09953 .68724 .09344 .68042 .08291 Mtetra
.681 .735 .892 r
.68042 .08291 .68724 .09344 .70151 .08733 .69474 .07679 Mtetra
.681 .736 .892 r
.69474 .07679 .70151 .08733 .71584 .0812 .70913 .07065 Mtetra
.68 .737 .893 r
.70913 .07065 .71584 .0812 .73024 .07505 .72358 .06448 Mtetra
.648 .729 .908 r
.07099 .29672 .07957 .30506 .09095 .30119 .0824 .29279 Mtetra
.647 .728 .908 r
.0824 .29279 .09095 .30119 .10239 .29732 .09387 .28885 Mtetra
.647 .727 .908 r
.09387 .28885 .10239 .29732 .11387 .29345 .10539 .28492 Mtetra
.646 .727 .907 r
.10539 .28492 .11387 .29345 .12542 .28957 .11696 .28098 Mtetra
.646 .726 .907 r
.11696 .28098 .12542 .28957 .13701 .2857 .12859 .27704 Mtetra
.645 .725 .906 r
.12859 .27704 .13701 .2857 .14867 .28181 .14027 .27308 Mtetra
.645 .724 .906 r
.14027 .27308 .14867 .28181 .16038 .27792 .15201 .26913 Mtetra
.644 .723 .906 r
.15201 .26913 .16038 .27792 .17214 .27402 .16381 .26516 Mtetra
.644 .722 .905 r
.16381 .26516 .17214 .27402 .18397 .27011 .17566 .26117 Mtetra
.644 .721 .904 r
.17566 .26117 .18397 .27011 .19585 .26618 .18758 .25717 Mtetra
.644 .72 .904 r
.18758 .25717 .19585 .26618 .20779 .26223 .19955 .25316 Mtetra
.644 .72 .903 r
.19955 .25316 .20779 .26223 .2198 .25827 .21159 .24912 Mtetra
.644 .719 .903 r
.21159 .24912 .2198 .25827 .23186 .25427 .22368 .24506 Mtetra
.644 .718 .902 r
.22368 .24506 .23186 .25427 .24399 .25026 .23584 .24097 Mtetra
.644 .718 .901 r
.23584 .24097 .24399 .25026 .25617 .24621 .24806 .23685 Mtetra
.645 .717 .9 r
.24806 .23685 .25617 .24621 .26843 .24212 .26034 .23269 Mtetra
.645 .716 .9 r
.26034 .23269 .26843 .24212 .28074 .238 .27269 .2285 Mtetra
.646 .716 .899 r
.27269 .2285 .28074 .238 .29312 .23383 .2851 .22426 Mtetra
.647 .715 .898 r
.2851 .22426 .29312 .23383 .30556 .22962 .29758 .21998 Mtetra
.647 .715 .897 r
.29758 .21998 .30556 .22962 .31807 .22535 .31012 .21565 Mtetra
.648 .715 .896 r
.31012 .21565 .31807 .22535 .33064 .22103 .32273 .21126 Mtetra
.649 .715 .896 r
.32273 .21126 .33064 .22103 .34328 .21665 .3354 .20682 Mtetra
.651 .715 .895 r
.3354 .20682 .34328 .21665 .35599 .21221 .34814 .20232 Mtetra
.652 .715 .894 r
.34814 .20232 .35599 .21221 .36876 .2077 .36094 .19775 Mtetra
.653 .715 .893 r
.36094 .19775 .36876 .2077 .3816 .20312 .37382 .19311 Mtetra
.655 .715 .892 r
.37382 .19311 .3816 .20312 .3945 .19846 .38675 .1884 Mtetra
.656 .715 .892 r
.38675 .1884 .3945 .19846 .40747 .19373 .39976 .18361 Mtetra
.658 .715 .891 r
.39976 .18361 .40747 .19373 .42051 .18892 .41283 .17875 Mtetra
.659 .716 .89 r
.41283 .17875 .42051 .18892 .43361 .18402 .42597 .17381 Mtetra
.661 .716 .89 r
.42597 .17381 .43361 .18402 .44678 .17905 .43917 .16879 Mtetra
.662 .717 .889 r
.43917 .16879 .44678 .17905 .46001 .17399 .45244 .16369 Mtetra
.664 .718 .889 r
.45244 .16369 .46001 .17399 .47331 .16884 .46578 .1585 Mtetra
.665 .719 .888 r
.46578 .1585 .47331 .16884 .48668 .16361 .47918 .15323 Mtetra
.667 .719 .888 r
.47918 .15323 .48668 .16361 .5001 .15829 .49265 .14789 Mtetra
.669 .72 .888 r
.49265 .14789 .5001 .15829 .5136 .15289 .50618 .14246 Mtetra
.67 .721 .888 r
.50618 .14246 .5136 .15289 .52715 .14741 .51977 .13695 Mtetra
.671 .722 .887 r
.51977 .13695 .52715 .14741 .54077 .14186 .53343 .13137 Mtetra
.673 .723 .887 r
.53343 .13137 .54077 .14186 .55445 .13623 .54715 .12572 Mtetra
.674 .725 .888 r
.54715 .12572 .55445 .13623 .5682 .13052 .56094 .12 Mtetra
.675 .726 .888 r
.56094 .12 .5682 .13052 .582 .12475 .57479 .11421 Mtetra
.676 .727 .888 r
.57479 .11421 .582 .12475 .59587 .11892 .58871 .10837 Mtetra
.677 .728 .888 r
.58871 .10837 .59587 .11892 .60981 .11303 .60269 .10246 Mtetra
.678 .729 .889 r
.60269 .10246 .60981 .11303 .6238 .10709 .61673 .09651 Mtetra
.678 .73 .889 r
.61673 .09651 .6238 .10709 .63786 .10111 .63083 .09051 Mtetra
.679 .731 .89 r
.63083 .09051 .63786 .10111 .65198 .09508 .64501 .08447 Mtetra
.679 .732 .89 r
.64501 .08447 .65198 .09508 .66617 .08901 .65924 .07839 Mtetra
.679 .733 .891 r
.65924 .07839 .66617 .08901 .68042 .08291 .67354 .07228 Mtetra
.68 .734 .892 r
.67354 .07228 .68042 .08291 .69474 .07679 .68791 .06614 Mtetra
.68 .735 .893 r
.68791 .06614 .69474 .07679 .70913 .07065 .70235 .05998 Mtetra
.679 .736 .893 r
.70235 .05998 .70913 .07065 .72358 .06448 .71685 .0538 Mtetra
.649 .729 .908 r
.06234 .28831 .07099 .29672 .0824 .29279 .07378 .28431 Mtetra
.648 .729 .908 r
.07378 .28431 .0824 .29279 .09387 .28885 .08528 .28032 Mtetra
.648 .728 .907 r
.08528 .28032 .09387 .28885 .10539 .28492 .09683 .27632 Mtetra
.647 .727 .907 r
.09683 .27632 .10539 .28492 .11696 .28098 .10843 .27231 Mtetra
.647 .726 .906 r
.10843 .27231 .11696 .28098 .12859 .27704 .12009 .2683 Mtetra
.646 .725 .906 r
.12009 .2683 .12859 .27704 .14027 .27308 .1318 .26428 Mtetra
.646 .724 .906 r
.1318 .26428 .14027 .27308 .15201 .26913 .14358 .26026 Mtetra
.645 .723 .905 r
.14358 .26026 .15201 .26913 .16381 .26516 .1554 .25622 Mtetra
.645 .722 .905 r
.1554 .25622 .16381 .26516 .17566 .26117 .16729 .25216 Mtetra
.645 .722 .904 r
.16729 .25216 .17566 .26117 .18758 .25717 .17924 .24809 Mtetra
.645 .721 .903 r
.17924 .24809 .18758 .25717 .19955 .25316 .19124 .244 Mtetra
.645 .72 .903 r
.19124 .244 .19955 .25316 .21159 .24912 .20331 .23989 Mtetra
.645 .719 .902 r
.20331 .23989 .21159 .24912 .22368 .24506 .21544 .23576 Mtetra
.645 .718 .901 r
.21544 .23576 .22368 .24506 .23584 .24097 .22763 .2316 Mtetra
.22763 .2316 .23584 .24097 .24806 .23685 .23988 .22741 Mtetra
.646 .717 .9 r
.23988 .22741 .24806 .23685 .26034 .23269 .2522 .22318 Mtetra
.646 .717 .899 r
.2522 .22318 .26034 .23269 .27269 .2285 .26457 .21891 Mtetra
.647 .716 .898 r
.26457 .21891 .27269 .2285 .2851 .22426 .27702 .21461 Mtetra
.27702 .21461 .2851 .22426 .29758 .21998 .28953 .21026 Mtetra
.648 .715 .897 r
.28953 .21026 .29758 .21998 .31012 .21565 .3021 .20586 Mtetra
.649 .715 .896 r
.3021 .20586 .31012 .21565 .32273 .21126 .31474 .20141 Mtetra
.65 .715 .895 r
.31474 .20141 .32273 .21126 .3354 .20682 .32745 .1969 Mtetra
.651 .715 .894 r
.32745 .1969 .3354 .20682 .34814 .20232 .34022 .19233 Mtetra
.652 .715 .894 r
.34022 .19233 .34814 .20232 .36094 .19775 .35306 .1877 Mtetra
.654 .715 .893 r
.35306 .1877 .36094 .19775 .37382 .19311 .36597 .18301 Mtetra
.655 .715 .892 r
.36597 .18301 .37382 .19311 .38675 .1884 .37894 .17824 Mtetra
.656 .715 .891 r
.37894 .17824 .38675 .1884 .39976 .18361 .39198 .1734 Mtetra
.658 .715 .891 r
.39198 .1734 .39976 .18361 .41283 .17875 .40509 .16849 Mtetra
.659 .716 .89 r
.40509 .16849 .41283 .17875 .42597 .17381 .41826 .1635 Mtetra
.661 .716 .89 r
.41826 .1635 .42597 .17381 .43917 .16879 .4315 .15844 Mtetra
.662 .717 .889 r
.4315 .15844 .43917 .16879 .45244 .16369 .44481 .15329 Mtetra
.664 .718 .889 r
.44481 .15329 .45244 .16369 .46578 .1585 .45818 .14807 Mtetra
.665 .718 .888 r
.45818 .14807 .46578 .1585 .47918 .15323 .47162 .14277 Mtetra
.667 .719 .888 r
.47162 .14277 .47918 .15323 .49265 .14789 .48513 .13739 Mtetra
.668 .72 .888 r
.48513 .13739 .49265 .14789 .50618 .14246 .4987 .13193 Mtetra
.669 .721 .888 r
.4987 .13193 .50618 .14246 .51977 .13695 .51233 .1264 Mtetra
.671 .722 .888 r
.51233 .1264 .51977 .13695 .53343 .13137 .52603 .12079 Mtetra
.672 .723 .888 r
.52603 .12079 .53343 .13137 .54715 .12572 .5398 .11512 Mtetra
.673 .724 .888 r
.5398 .11512 .54715 .12572 .56094 .12 .55363 .10938 Mtetra
.674 .725 .888 r
.55363 .10938 .56094 .12 .57479 .11421 .56752 .10357 Mtetra
.675 .726 .888 r
.56752 .10357 .57479 .11421 .58871 .10837 .58148 .09771 Mtetra
.676 .727 .889 r
.58148 .09771 .58871 .10837 .60269 .10246 .5955 .09179 Mtetra
.677 .729 .889 r
.5955 .09179 .60269 .10246 .61673 .09651 .60959 .08582 Mtetra
.677 .73 .889 r
.60959 .08582 .61673 .09651 .63083 .09051 .62374 .07981 Mtetra
.678 .731 .89 r
.62374 .07981 .63083 .09051 .64501 .08447 .63796 .07375 Mtetra
.678 .732 .891 r
.63796 .07375 .64501 .08447 .65924 .07839 .65225 .06766 Mtetra
.678 .733 .891 r
.65225 .06766 .65924 .07839 .67354 .07228 .6666 .06154 Mtetra
.679 .734 .892 r
.6666 .06154 .67354 .07228 .68791 .06614 .68102 .05539 Mtetra
.679 .735 .893 r
.68102 .05539 .68791 .06614 .70235 .05998 .69551 .04921 Mtetra
.678 .735 .893 r
.69551 .04921 .70235 .05998 .71685 .0538 .71006 .04302 Mtetra
.65 .73 .907 r
.05362 .27983 .06234 .28831 .07378 .28431 .06509 .27578 Mtetra
.649 .729 .907 r
.06509 .27578 .07378 .28431 .08528 .28032 .07662 .27172 Mtetra
.649 .728 .907 r
.07662 .27172 .08528 .28032 .09683 .27632 .0882 .26765 Mtetra
.648 .727 .907 r
.0882 .26765 .09683 .27632 .10843 .27231 .09983 .26358 Mtetra
.648 .726 .906 r
.09983 .26358 .10843 .27231 .12009 .2683 .11152 .2595 Mtetra
.647 .725 .906 r
.11152 .2595 .12009 .2683 .1318 .26428 .12327 .25541 Mtetra
.647 .725 .905 r
.12327 .25541 .1318 .26428 .14358 .26026 .13507 .25131 Mtetra
.647 .724 .905 r
.13507 .25131 .14358 .26026 .1554 .25622 .14693 .2472 Mtetra
.646 .723 .904 r
.14693 .2472 .1554 .25622 .16729 .25216 .15885 .24308 Mtetra
.646 .722 .904 r
.15885 .24308 .16729 .25216 .17924 .24809 .17083 .23894 Mtetra
.646 .721 .903 r
.17083 .23894 .17924 .24809 .19124 .244 .18287 .23478 Mtetra
.646 .72 .902 r
.18287 .23478 .19124 .244 .20331 .23989 .19496 .23059 Mtetra
.19496 .23059 .20331 .23989 .21544 .23576 .20712 .22639 Mtetra
.646 .719 .901 r
.20712 .22639 .21544 .23576 .22763 .2316 .21935 .22215 Mtetra
.646 .718 .9 r
.21935 .22215 .22763 .2316 .23988 .22741 .23163 .21789 Mtetra
.647 .717 .9 r
.23163 .21789 .23988 .22741 .2522 .22318 .24398 .21359 Mtetra
.647 .717 .899 r
.24398 .21359 .2522 .22318 .26457 .21891 .25639 .20925 Mtetra
.648 .716 .898 r
.25639 .20925 .26457 .21891 .27702 .21461 .26887 .20488 Mtetra
.648 .716 .897 r
.26887 .20488 .27702 .21461 .28953 .21026 .28141 .20046 Mtetra
.649 .715 .897 r
.28141 .20046 .28953 .21026 .3021 .20586 .29402 .19599 Mtetra
.65 .715 .896 r
.29402 .19599 .3021 .20586 .31474 .20141 .30669 .19147 Mtetra
.651 .715 .895 r
.30669 .19147 .31474 .20141 .32745 .1969 .31943 .1869 Mtetra
.652 .715 .894 r
.31943 .1869 .32745 .1969 .34022 .19233 .33224 .18227 Mtetra
.653 .715 .893 r
.33224 .18227 .34022 .19233 .35306 .1877 .34511 .17758 Mtetra
.654 .715 .893 r
.34511 .17758 .35306 .1877 .36597 .18301 .35805 .17282 Mtetra
.655 .715 .892 r
.35805 .17282 .36597 .18301 .37894 .17824 .37106 .168 Mtetra
.656 .715 .891 r
.37106 .168 .37894 .17824 .39198 .1734 .38414 .16311 Mtetra
.658 .715 .891 r
.38414 .16311 .39198 .1734 .40509 .16849 .39728 .15814 Mtetra
.659 .716 .89 r
.39728 .15814 .40509 .16849 .41826 .1635 .41049 .15311 Mtetra
.661 .716 .89 r
.41049 .15311 .41826 .1635 .4315 .15844 .42377 .148 Mtetra
.662 .717 .889 r
.42377 .148 .4315 .15844 .44481 .15329 .43711 .14281 Mtetra
.663 .717 .889 r
.43711 .14281 .44481 .15329 .45818 .14807 .45052 .13755 Mtetra
.665 .718 .888 r
.45052 .13755 .45818 .14807 .47162 .14277 .464 .13221 Mtetra
.666 .719 .888 r
.464 .13221 .47162 .14277 .48513 .13739 .47754 .1268 Mtetra
.668 .72 .888 r
.47754 .1268 .48513 .13739 .4987 .13193 .49115 .12131 Mtetra
.669 .721 .888 r
.49115 .12131 .4987 .13193 .51233 .1264 .50483 .11575 Mtetra
.67 .722 .888 r
.50483 .11575 .51233 .1264 .52603 .12079 .51857 .11012 Mtetra
.671 .723 .888 r
.51857 .11012 .52603 .12079 .5398 .11512 .53237 .10442 Mtetra
.672 .724 .888 r
.53237 .10442 .5398 .11512 .55363 .10938 .54625 .09866 Mtetra
.673 .725 .888 r
.54625 .09866 .55363 .10938 .56752 .10357 .56018 .09283 Mtetra
.674 .726 .888 r
.56018 .09283 .56752 .10357 .58148 .09771 .57419 .08695 Mtetra
.675 .727 .889 r
.57419 .08695 .58148 .09771 .5955 .09179 .58826 .08102 Mtetra
.676 .728 .889 r
.58826 .08102 .5955 .09179 .60959 .08582 .60239 .07504 Mtetra
.676 .729 .89 r
.60239 .07504 .60959 .08582 .62374 .07981 .61659 .06901 Mtetra
.677 .73 .89 r
.61659 .06901 .62374 .07981 .63796 .07375 .63086 .06294 Mtetra
.677 .731 .891 r
.63086 .06294 .63796 .07375 .65225 .06766 .64519 .05684 Mtetra
.677 .732 .892 r
.64519 .05684 .65225 .06766 .6666 .06154 .65959 .0507 Mtetra
.677 .733 .892 r
.65959 .0507 .6666 .06154 .68102 .05539 .67406 .04453 Mtetra
.678 .734 .893 r
.67406 .04453 .68102 .05539 .69551 .04921 .6886 .03834 Mtetra
.677 .735 .894 r
.6886 .03834 .69551 .04921 .71006 .04302 .70321 .03213 Mtetra
.651 .73 .907 r
.04483 .27129 .05362 .27983 .06509 .27578 .05633 .26717 Mtetra
.65 .729 .907 r
.05633 .26717 .06509 .27578 .07662 .27172 .06789 .26305 Mtetra
.65 .728 .907 r
.06789 .26305 .07662 .27172 .0882 .26765 .0795 .25891 Mtetra
.649 .728 .906 r
.0795 .25891 .0882 .26765 .09983 .26358 .09116 .25478 Mtetra
.649 .727 .906 r
.09116 .25478 .09983 .26358 .11152 .2595 .10288 .25063 Mtetra
.648 .726 .905 r
.10288 .25063 .11152 .2595 .12327 .25541 .11466 .24647 Mtetra
.648 .725 .905 r
.11466 .24647 .12327 .25541 .13507 .25131 .1265 .2423 Mtetra
.648 .724 .904 r
.1265 .2423 .13507 .25131 .14693 .2472 .13839 .23812 Mtetra
.647 .723 .904 r
.13839 .23812 .14693 .2472 .15885 .24308 .15034 .23393 Mtetra
.647 .722 .903 r
.15034 .23393 .15885 .24308 .17083 .23894 .16235 .22971 Mtetra
.16235 .22971 .17083 .23894 .18287 .23478 .17442 .22548 Mtetra
.647 .721 .902 r
.17442 .22548 .18287 .23478 .19496 .23059 .18655 .22122 Mtetra
.647 .72 .901 r
.18655 .22122 .19496 .23059 .20712 .22639 .19874 .21694 Mtetra
.647 .719 .901 r
.19874 .21694 .20712 .22639 .21935 .22215 .211 .21263 Mtetra
.647 .719 .9 r
.211 .21263 .21935 .22215 .23163 .21789 .22331 .2083 Mtetra
.648 .718 .899 r
.22331 .2083 .23163 .21789 .24398 .21359 .2357 .20393 Mtetra
.648 .717 .899 r
.2357 .20393 .24398 .21359 .25639 .20925 .24814 .19952 Mtetra
.649 .717 .898 r
.24814 .19952 .25639 .20925 .26887 .20488 .26065 .19507 Mtetra
.649 .716 .897 r
.26065 .19507 .26887 .20488 .28141 .20046 .27323 .19058 Mtetra
.65 .716 .896 r
.27323 .19058 .28141 .20046 .29402 .19599 .28587 .18605 Mtetra
.651 .716 .896 r
.28587 .18605 .29402 .19599 .30669 .19147 .29858 .18146 Mtetra
.651 .715 .895 r
.29858 .18146 .30669 .19147 .31943 .1869 .31135 .17682 Mtetra
.652 .715 .894 r
.31135 .17682 .31943 .1869 .33224 .18227 .32419 .17213 Mtetra
.653 .715 .893 r
.32419 .17213 .33224 .18227 .34511 .17758 .3371 .16737 Mtetra
.654 .715 .893 r
.3371 .16737 .34511 .17758 .35805 .17282 .35007 .16256 Mtetra
.656 .715 .892 r
.35007 .16256 .35805 .17282 .37106 .168 .36312 .15768 Mtetra
.657 .715 .891 r
.36312 .15768 .37106 .168 .38414 .16311 .37623 .15273 Mtetra
.658 .716 .891 r
.37623 .15273 .38414 .16311 .39728 .15814 .38941 .14772 Mtetra
.659 .716 .89 r
.38941 .14772 .39728 .15814 .41049 .15311 .40265 .14263 Mtetra
.661 .716 .89 r
.40265 .14263 .41049 .15311 .42377 .148 .41597 .13748 Mtetra
.662 .717 .889 r
.41597 .13748 .42377 .148 .43711 .14281 .42935 .13225 Mtetra
.663 .718 .889 r
.42935 .13225 .43711 .14281 .45052 .13755 .44279 .12694 Mtetra
.665 .718 .889 r
.44279 .12694 .45052 .13755 .464 .13221 .45631 .12157 Mtetra
.666 .719 .888 r
.45631 .12157 .464 .13221 .47754 .1268 .46989 .11612 Mtetra
.667 .72 .888 r
.46989 .11612 .47754 .1268 .49115 .12131 .48354 .1106 Mtetra
.668 .721 .888 r
.48354 .1106 .49115 .12131 .50483 .11575 .49726 .10501 Mtetra
.669 .722 .888 r
.49726 .10501 .50483 .11575 .51857 .11012 .51104 .09936 Mtetra
.671 .723 .888 r
.51104 .09936 .51857 .11012 .53237 .10442 .52489 .09364 Mtetra
.672 .724 .888 r
.52489 .09364 .53237 .10442 .54625 .09866 .5388 .08785 Mtetra
.673 .725 .889 r
.5388 .08785 .54625 .09866 .56018 .09283 .55278 .08201 Mtetra
.673 .726 .889 r
.55278 .08201 .56018 .09283 .57419 .08695 .56683 .07611 Mtetra
.674 .727 .889 r
.56683 .07611 .57419 .08695 .58826 .08102 .58094 .07016 Mtetra
.675 .728 .89 r
.58094 .07016 .58826 .08102 .60239 .07504 .59513 .06416 Mtetra
.675 .729 .89 r
.59513 .06416 .60239 .07504 .61659 .06901 .60937 .05812 Mtetra
.676 .73 .891 r
.60937 .05812 .61659 .06901 .63086 .06294 .62369 .05203 Mtetra
.676 .731 .891 r
.62369 .05203 .63086 .06294 .64519 .05684 .63807 .04591 Mtetra
.676 .732 .892 r
.63807 .04591 .64519 .05684 .65959 .0507 .65252 .03976 Mtetra
.676 .733 .893 r
.65252 .03976 .65959 .0507 .67406 .04453 .66705 .03358 Mtetra
.677 .734 .893 r
.66705 .03358 .67406 .04453 .6886 .03834 .68164 .02738 Mtetra
.676 .735 .894 r
.68164 .02738 .6886 .03834 .70321 .03213 .6963 .02115 Mtetra
.651 .73 .907 r
.03596 .26268 .04483 .27129 .05633 .26717 .0475 .2585 Mtetra
.0475 .2585 .05633 .26717 .06789 .26305 .05908 .25431 Mtetra
.651 .729 .906 r
.05908 .25431 .06789 .26305 .0795 .25891 .07072 .25011 Mtetra
.65 .728 .906 r
.07072 .25011 .0795 .25891 .09116 .25478 .08242 .24591 Mtetra
.65 .727 .906 r
.08242 .24591 .09116 .25478 .10288 .25063 .09417 .24169 Mtetra
.649 .726 .905 r
.09417 .24169 .10288 .25063 .11466 .24647 .10598 .23747 Mtetra
.10598 .23747 .11466 .24647 .1265 .2423 .11785 .23323 Mtetra
.649 .725 .904 r
.11785 .23323 .1265 .2423 .13839 .23812 .12977 .22898 Mtetra
.648 .724 .904 r
.12977 .22898 .13839 .23812 .15034 .23393 .14175 .22471 Mtetra
.648 .723 .903 r
.14175 .22471 .15034 .23393 .16235 .22971 .1538 .22042 Mtetra
.648 .722 .903 r
.1538 .22042 .16235 .22971 .17442 .22548 .1659 .21611 Mtetra
.648 .721 .902 r
.1659 .21611 .17442 .22548 .18655 .22122 .17806 .21178 Mtetra
.648 .721 .901 r
.17806 .21178 .18655 .22122 .19874 .21694 .19029 .20743 Mtetra
.648 .72 .901 r
.19029 .20743 .19874 .21694 .211 .21263 .20258 .20305 Mtetra
.648 .719 .9 r
.20258 .20305 .211 .21263 .22331 .2083 .21493 .19864 Mtetra
.649 .719 .899 r
.21493 .19864 .22331 .2083 .2357 .20393 .22734 .1942 Mtetra
.649 .718 .899 r
.22734 .1942 .2357 .20393 .24814 .19952 .23982 .18972 Mtetra
.649 .717 .898 r
.23982 .18972 .24814 .19952 .26065 .19507 .25236 .1852 Mtetra
.65 .717 .897 r
.25236 .1852 .26065 .19507 .27323 .19058 .26497 .18064 Mtetra
.651 .717 .896 r
.26497 .18064 .27323 .19058 .28587 .18605 .27765 .17603 Mtetra
.651 .716 .896 r
.27765 .17603 .28587 .18605 .29858 .18146 .29039 .17138 Mtetra
.652 .716 .895 r
.29039 .17138 .29858 .18146 .31135 .17682 .3032 .16667 Mtetra
.653 .716 .894 r
.3032 .16667 .31135 .17682 .32419 .17213 .31607 .16192 Mtetra
.654 .716 .894 r
.31607 .16192 .32419 .17213 .3371 .16737 .32902 .1571 Mtetra
.655 .716 .893 r
.32902 .1571 .3371 .16737 .35007 .16256 .34203 .15223 Mtetra
.656 .716 .892 r
.34203 .15223 .35007 .16256 .36312 .15768 .35511 .14729 Mtetra
.657 .716 .892 r
.35511 .14729 .36312 .15768 .37623 .15273 .36825 .14229 Mtetra
.658 .716 .891 r
.36825 .14229 .37623 .15273 .38941 .14772 .38147 .13722 Mtetra
.659 .716 .891 r
.38147 .13722 .38941 .14772 .40265 .14263 .39475 .13209 Mtetra
.661 .717 .89 r
.39475 .13209 .40265 .14263 .41597 .13748 .4081 .12688 Mtetra
.662 .717 .89 r
.4081 .12688 .41597 .13748 .42935 .13225 .42152 .12161 Mtetra
.663 .718 .889 r
.42152 .12161 .42935 .13225 .44279 .12694 .435 .11626 Mtetra
.664 .718 .889 r
.435 .11626 .44279 .12694 .45631 .12157 .44856 .11085 Mtetra
.665 .719 .889 r
.44856 .11085 .45631 .12157 .46989 .11612 .46218 .10537 Mtetra
.667 .72 .889 r
.46218 .10537 .46989 .11612 .48354 .1106 .47587 .09982 Mtetra
.668 .721 .889 r
.47587 .09982 .48354 .1106 .49726 .10501 .48962 .0942 Mtetra
.669 .722 .889 r
.48962 .0942 .49726 .10501 .51104 .09936 .50344 .08852 Mtetra
.67 .723 .889 r
.50344 .08852 .51104 .09936 .52489 .09364 .51733 .08277 Mtetra
.671 .724 .889 r
.51733 .08277 .52489 .09364 .5388 .08785 .53129 .07696 Mtetra
.672 .725 .889 r
.53129 .07696 .5388 .08785 .55278 .08201 .54532 .0711 Mtetra
.673 .726 .889 r
.54532 .0711 .55278 .08201 .56683 .07611 .55941 .06518 Mtetra
.673 .727 .89 r
.55941 .06518 .56683 .07611 .58094 .07016 .57357 .05921 Mtetra
.674 .728 .89 r
.57357 .05921 .58094 .07016 .59513 .06416 .5878 .05319 Mtetra
.674 .729 .891 r
.5878 .05319 .59513 .06416 .60937 .05812 .60209 .04714 Mtetra
.675 .73 .891 r
.60209 .04714 .60937 .05812 .62369 .05203 .61646 .04104 Mtetra
.675 .731 .892 r
.61646 .04104 .62369 .05203 .63807 .04591 .63089 .0349 Mtetra
.675 .732 .892 r
.63089 .0349 .63807 .04591 .65252 .03976 .64539 .02873 Mtetra
.675 .733 .893 r
.64539 .02873 .65252 .03976 .66705 .03358 .65996 .02254 Mtetra
.676 .733 .894 r
.65996 .02254 .66705 .03358 .68164 .02738 .67461 .01631 Mtetra
.675 .734 .895 r
.67461 .01631 .68164 .02738 .6963 .02115 .68932 .01007 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.629 .51779 m
.6548 .51185 L
.6806 .51106 L
.7064 .5153 L
.7322 .52516 L
.73352 .5258 L
.758 .54197 L
.7684 .5516 L
.7838 .57066 L
.7879 .5774 L
.79957 .6032 L
.8053 .629 L
.80594 .6548 L
.80158 .6806 L
.7916 .7064 L
.7838 .72006 L
.7745 .7322 L
.758 .74857 L
.74547 .758 L
.7322 .76541 L
.7064 .77522 L
.6806 .77943 L
.6548 .77864 L
.629 .77274 L
.6032 .76086 L
.59847 .758 L
.5774 .74106 L
.56921 .7322 L
.55212 .7064 L
.5516 .70569 L
.54208 .6806 L
.53768 .6548 L
.53833 .629 L
.54411 .6032 L
.5516 .58407 L
.55573 .5774 L
.57538 .5516 L
.5774 .54956 L
.6032 .52961 L
.60923 .5258 L
.629 .51779 L
s
.2678 .10495 m
.2936 .09812 L
.3194 .09346 L
.3452 .09087 L
.371 .09031 L
.3968 .09177 L
.4226 .09527 L
.4484 .10089 L
.4742 .10873 L
.48582 .113 L
.5 .11897 L
.5258 .13186 L
.53772 .1388 L
.5516 .14779 L
.57412 .1646 L
.5774 .16731 L
.60228 .1904 L
.6032 .19136 L
.62488 .2162 L
.629 .22153 L
.64329 .242 L
.6548 .2613 L
.65828 .2678 L
.67037 .2936 L
.67988 .3194 L
.6806 .32157 L
.68707 .3452 L
.69206 .371 L
.69496 .3968 L
.69583 .4226 L
.69469 .4484 L
.69151 .4742 L
.68622 .5 L
.6806 .52021 L
.67873 .5258 L
.66888 .5516 L
.65642 .5774 L
.6548 .58038 L
.641 .6032 L
.629 .62017 L
.62208 .629 L
.6032 .65035 L
.59882 .6548 L
.5774 .67439 L
.56975 .6806 L
.5516 .69391 L
.53184 .7064 L
.5258 .70983 L
.5 .72273 L
.47639 .7322 L
Mistroke
.4742 .73296 L
.4484 .74081 L
.4226 .74642 L
.3968 .74993 L
.371 .75138 L
.3452 .75083 L
.3194 .74824 L
.2936 .74358 L
.2678 .73674 L
.25402 .7322 L
.242 .7276 L
.2162 .71593 L
.19865 .7064 L
.1904 .70141 L
.1646 .68358 L
.16076 .6806 L
.1388 .6617 L
.13168 .6548 L
.113 .63453 L
.10842 .629 L
.08951 .6032 L
.0872 .59967 L
.07408 .5774 L
.06163 .5516 L
.0614 .55109 L
.05177 .5258 L
.04428 .5 L
.039 .4742 L
.03582 .4484 L
.0356 .44567 L
.03468 .4226 L
.03555 .3968 L
.0356 .39602 L
.03845 .371 L
.04344 .3452 L
.05062 .3194 L
.06014 .2936 L
.0614 .29059 L
.07223 .2678 L
.0872 .24204 L
.08723 .242 L
.10562 .2162 L
.113 .20716 L
.12822 .1904 L
.1388 .18 L
.15638 .1646 L
.1646 .15812 L
.1904 .14029 L
.1928 .1388 L
.2162 .12577 L
Mistroke
.242 .1141 L
.24472 .113 L
.2678 .10495 L
Mfstroke
.6032 .06076 m
.629 .05439 L
.6548 .0504 L
.6806 .04868 L
.7064 .0492 L
.7322 .05196 L
.758 .05704 L
.77428 .0614 L
.7838 .06455 L
.8096 .0747 L
.83434 .0872 L
.8354 .08781 L
.8612 .10432 L
.87275 .113 L
.887 .12502 L
.90135 .1388 L
.9128 .15124 L
.92375 .1646 L
.9386 .18563 L
.94159 .1904 L
.95581 .2162 L
.9644 .23546 L
.96692 .242 L
.9753 .2678 L
.98119 .2936 L
.98474 .3194 L
.98603 .3452 L
.98507 .371 L
.98187 .3968 L
.97633 .4226 L
.96834 .4484 L
.9644 .45885 L
.95766 .4742 L
.94394 .5 L
.9386 .50865 L
.92669 .5258 L
.9128 .54303 L
.90505 .5516 L
.887 .56925 L
.87753 .5774 L
.8612 .58995 L
.84101 .6032 L
.8354 .60647 L
.8096 .61957 L
.7859 .629 L
.7838 .62971 L
.758 .63723 L
.7322 .64231 L
.7064 .64508 L
.6806 .64559 L
Mistroke
.6548 .64388 L
.629 .63988 L
.6032 .63352 L
.58897 .629 L
.5774 .62462 L
.5516 .61294 L
.534 .6032 L
.5258 .59808 L
.5 .57943 L
.49751 .5774 L
.4742 .556 L
.46998 .5516 L
.4484 .52587 L
.44834 .5258 L
.43108 .5 L
.4226 .48483 L
.41737 .4742 L
.40667 .4484 L
.39867 .4226 L
.3968 .4157 L
.39314 .3968 L
.38993 .371 L
.38898 .3452 L
.39027 .3194 L
.39382 .2936 L
.3968 .27861 L
.39971 .2678 L
.4081 .242 L
.41922 .2162 L
.4226 .20946 L
.43342 .1904 L
.4484 .16838 L
.45128 .1646 L
.47369 .1388 L
.4742 .13828 L
.5 .11484 L
.50229 .113 L
.5258 .09619 L
.54064 .0872 L
.5516 .08133 L
.5774 .06965 L
.60098 .0614 L
.6032 .06076 L
Mfstroke
.6032 .65106 m
.629 .64458 L
.6548 .6433 L
.6806 .64705 L
.70437 .6548 L
.7064 .65629 L
.7322 .67234 L
.7417 .6806 L
.758 .69944 L
.76255 .7064 L
.7751 .7322 L
.78152 .758 L
.7828 .7838 L
.77913 .8096 L
.76997 .8354 L
.758 .85597 L
.7539 .8612 L
.7322 .88292 L
.72702 .887 L
.7064 .89903 L
.6806 .90821 L
.6548 .91191 L
.629 .91065 L
.6032 .90426 L
.5774 .89174 L
.57016 .887 L
.5516 .87094 L
.54313 .8612 L
.52712 .8354 L
.5258 .83363 L
.51791 .8096 L
.51418 .7838 L
.51548 .758 L
.52199 .7322 L
.5258 .72191 L
.53442 .7064 L
.5516 .68435 L
.55535 .6806 L
.5774 .66346 L
.59305 .6548 L
.6032 .65106 L
s
.4742 .65183 m
.5 .64675 L
.5258 .64673 L
.5516 .65176 L
.56194 .6548 L
.5774 .66235 L
.6032 .68052 L
.60328 .6806 L
.62578 .7064 L
.629 .71104 L
.63927 .7322 L
.64655 .758 L
.64862 .7838 L
.64576 .8096 L
.63757 .8354 L
.629 .85252 L
.62297 .8612 L
.6032 .88307 L
.59869 .887 L
.5774 .90114 L
.5516 .91172 L
.5477 .9128 L
.5258 .91673 L
.5 .91671 L
.47832 .9128 L
.4742 .91165 L
.4484 .90102 L
.42733 .887 L
.4226 .88288 L
.40305 .8612 L
.3968 .85216 L
.38845 .8354 L
.38027 .8096 L
.3774 .7838 L
.37947 .758 L
.38675 .7322 L
.3968 .71138 L
.40024 .7064 L
.4226 .68072 L
.42273 .6806 L
.4484 .66247 L
.46412 .6548 L
.4742 .65183 L
s
0 g
.03 w
.67183 .64526 Mdot
.36525 .42085 Mdot
.68751 .34714 Mdot
.64852 .77763 Mdot
.51301 .78174 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.61765 .67053 m
.63725 .67083 L
.65205 .67647 L
.65686 .679 L
.67131 .69608 L
.67642 .71569 L
.67535 .73529 L
.66816 .7549 L
.65686 .7706 L
.65289 .77451 L
.63725 .78481 L
.61765 .79143 L
.59804 .79201 L
.57843 .78614 L
.56395 .77451 L
.55882 .76562 L
.55466 .7549 L
.5536 .73529 L
.55882 .717 L
.55936 .71569 L
.57214 .69608 L
.57843 .68972 L
.59804 .67675 L
.5987 .67647 L
.61765 .67053 L
s
.61765 .63463 m
.63725 .63345 L
.65686 .63689 L
.65834 .63725 L
.67647 .64617 L
.68918 .65686 L
.69608 .66538 L
.70237 .67647 L
.70902 .69608 L
.71107 .71569 L
.70924 .73529 L
.70356 .7549 L
.69608 .77068 L
.69351 .77451 L
.67754 .79412 L
.67647 .79515 L
.65686 .81024 L
.65123 .81373 L
.63725 .81964 L
.61765 .82478 L
.59804 .82609 L
.57843 .82351 L
.55882 .81627 L
.55404 .81373 L
.53922 .80242 L
.53201 .79412 L
.52139 .77451 L
.51961 .76882 L
.5171 .7549 L
.51767 .73529 L
.51961 .72545 L
.52255 .71569 L
.53177 .69608 L
.53922 .68468 L
.54594 .67647 L
.55882 .66359 L
.56704 .65686 L
.57843 .64936 L
.59804 .63991 L
.60616 .63725 L
.61765 .63463 L
s
.59804 .61016 m
.61765 .60518 L
.63725 .60345 L
.65686 .60521 L
.67647 .61103 L
.68982 .61765 L
.69608 .62208 L
.7124 .63725 L
.71569 .64131 L
.72549 .65686 L
.73328 .67647 L
.73529 .68435 L
.7373 .69608 L
.73816 .71569 L
.7361 .73529 L
.73529 .74075 L
.73113 .7549 L
.72296 .77451 L
.71569 .78734 L
.71099 .79412 L
.69608 .81154 L
.69384 .81373 L
.67647 .82786 L
.66803 .83333 L
.65686 .8392 L
.63725 .84681 L
.61765 .85124 L
.59804 .85275 L
.57843 .85134 L
.55882 .84676 L
.53922 .83832 L
.53093 .83333 L
.51961 .82455 L
.50927 .81373 L
.5 .80049 L
.49681 .79412 L
.48995 .77451 L
.48739 .7549 L
.48851 .73529 L
.49302 .71569 L
.5 .69775 L
.50091 .69608 L
.51235 .67647 L
.51961 .66655 L
.52789 .65686 L
.53922 .64554 L
.54891 .63725 L
.55882 .62996 L
.57843 .61836 L
.57973 .61765 L
Mistroke
.59804 .61016 L
Mfstroke
.61765 .5776 m
.63725 .57558 L
.65686 .57646 L
.6683 .57843 L
.67647 .58055 L
.69608 .58843 L
.71168 .59804 L
.71569 .6012 L
.73234 .61765 L
.73529 .62136 L
.74565 .63725 L
.75442 .65686 L
.7549 .65801 L
.75988 .67647 L
.76255 .69608 L
.76275 .71569 L
.76057 .73529 L
.756 .7549 L
.7549 .75865 L
.74889 .77451 L
.73886 .79412 L
.73529 .79989 L
.72529 .81373 L
.71569 .82471 L
.70686 .83333 L
.69608 .84231 L
.68048 .85294 L
.67647 .85526 L
.65686 .86473 L
.63725 .87128 L
.63424 .87255 L
.61765 .87528 L
.59804 .87687 L
.57843 .87607 L
.55882 .87276 L
.55785 .87255 L
.53922 .86666 L
.51961 .85712 L
.51296 .85294 L
.5 .84293 L
.49031 .83333 L
.48039 .82081 L
.476 .81373 L
.46694 .79412 L
.46191 .77451 L
.46078 .76588 L
.46023 .7549 L
.46078 .74218 L
.46159 .73529 L
.4658 .71569 L
Mistroke
.47283 .69608 L
.48039 .68057 L
.48276 .67647 L
.49581 .65686 L
.5 .65145 L
.51243 .63725 L
.51961 .63006 L
.53368 .61765 L
.53922 .61331 L
.55882 .60007 L
.56225 .59804 L
.57843 .58983 L
.59804 .58236 L
.61194 .57843 L
.61765 .5776 L
Mfstroke
.59804 .55436 m
.61765 .54978 L
.63725 .54761 L
.65686 .54794 L
.67647 .55098 L
.69608 .55704 L
.7005 .55882 L
.71569 .5667 L
.73231 .57843 L
.73529 .581 L
.75171 .59804 L
.7549 .60212 L
.76515 .61765 L
.77451 .63691 L
.77465 .63725 L
.78115 .65686 L
.78515 .67647 L
.78695 .69608 L
.78669 .71569 L
.78443 .73529 L
.78015 .7549 L
.77451 .77258 L
.77375 .77451 L
.76498 .79412 L
.7549 .81155 L
.75346 .81373 L
.73854 .83333 L
.73529 .83699 L
.71897 .85294 L
.71569 .85572 L
.69608 .87002 L
.69202 .87255 L
.67647 .88096 L
.65686 .88916 L
.64806 .89216 L
.63725 .89498 L
.61765 .89864 L
.59804 .90026 L
.57843 .89984 L
.55882 .89735 L
.53922 .89259 L
.53775 .89216 L
.51961 .88529 L
.5 .87486 L
.49642 .87255 L
.48039 .86026 L
.47269 .85294 L
.46078 .83908 L
.45673 .83333 L
.44579 .81373 L
Mistroke
.44118 .80268 L
.43866 .79412 L
.43471 .77451 L
.43355 .7549 L
.43499 .73529 L
.43891 .71569 L
.44118 .70738 L
.44526 .69608 L
.45409 .67647 L
.46078 .66437 L
.46549 .65686 L
.47966 .63725 L
.48039 .63634 L
.49699 .61765 L
.5 .61461 L
.51828 .59804 L
.51961 .59695 L
.53922 .58244 L
.54536 .57843 L
.55882 .57062 L
.57843 .5613 L
.58443 .55882 L
.59804 .55436 L
Mfstroke
.63725 .51771 m
.65686 .5177 L
.67404 .51961 L
.67647 .52003 L
.69608 .5249 L
.71569 .53264 L
.72811 .53922 L
.73529 .54379 L
.75439 .55882 L
.7549 .5593 L
.7725 .57843 L
.77451 .58105 L
.78579 .59804 L
.79412 .61413 L
.79566 .61765 L
.80286 .63725 L
.80781 .65686 L
.81077 .67647 L
.8119 .69608 L
.81128 .71569 L
.80896 .73529 L
.80489 .7549 L
.79901 .77451 L
.79412 .7874 L
.79116 .79412 L
.78108 .81373 L
.77451 .82444 L
.76838 .83333 L
.7549 .85017 L
.7524 .85294 L
.73529 .86971 L
.732 .87255 L
.71569 .88504 L
.70477 .89216 L
.69608 .89716 L
.67647 .90666 L
.66338 .91176 L
.65686 .91391 L
.63725 .91915 L
.61765 .92253 L
.59804 .92414 L
.57843 .92399 L
.55882 .92207 L
.53922 .91826 L
.51961 .9124 L
.51783 .91176 L
.5 .90418 L
.48039 .89311 L
.47894 .89216 L
.46078 .87831 L
Mistroke
.45452 .87255 L
.44118 .85799 L
.43726 .85294 L
.42476 .83333 L
.42157 .8272 L
.4159 .81373 L
.41003 .79412 L
.40679 .77451 L
.40593 .7549 L
.40734 .73529 L
.41091 .71569 L
.41663 .69608 L
.42157 .68306 L
.4245 .67647 L
.43457 .65686 L
.44118 .64591 L
.44694 .63725 L
.46078 .61885 L
.46177 .61765 L
.47936 .59804 L
.48039 .59699 L
.5 .57868 L
.50029 .57843 L
.51961 .5632 L
.52579 .55882 L
.53922 .55017 L
.55882 .53939 L
.55917 .53922 L
.57843 .53079 L
.59804 .52431 L
.61765 .51994 L
.61966 .51961 L
.63725 .51771 L
Mfstroke
.57843 .49562 m
.59804 .48961 L
.61765 .48551 L
.63725 .48334 L
.65686 .48315 L
.67647 .48502 L
.69608 .48908 L
.71569 .49551 L
.72623 .5 L
.73529 .50463 L
.7549 .51693 L
.75854 .51961 L
.77451 .53322 L
.78052 .53922 L
.79412 .55505 L
.79695 .55882 L
.80964 .57843 L
.81373 .58597 L
.81946 .59804 L
.82696 .61765 L
.83247 .63725 L
.83333 .64074 L
.8362 .65686 L
.83829 .67647 L
.83885 .69608 L
.83792 .71569 L
.83552 .73529 L
.83333 .74763 L
.83161 .7549 L
.82614 .77451 L
.81899 .79412 L
.81373 .80617 L
.81001 .81373 L
.79893 .83333 L
.79412 .84076 L
.78537 .85294 L
.77451 .86619 L
.76871 .87255 L
.7549 .88608 L
.74794 .89216 L
.73529 .90207 L
.72104 .91176 L
.71569 .91503 L
.69608 .92551 L
.68286 .93137 L
.67647 .93386 L
.65686 .94032 L
.63725 .94506 L
.61765 .9482 L
.59804 .94978 L
Mistroke
.57843 .94984 L
.55882 .94835 L
.53922 .94527 L
.51961 .94047 L
.5 .93379 L
.49405 .93137 L
.48039 .92496 L
.46078 .91356 L
.45809 .91176 L
.44118 .89889 L
.43366 .89216 L
.42157 .87966 L
.41561 .87255 L
.40196 .85294 L
.40196 .85294 L
.39172 .83333 L
.38427 .81373 L
.38235 .80777 L
.37928 .79412 L
.37651 .77451 L
.37579 .7549 L
.37702 .73529 L
.38017 .71569 L
.38235 .70588 L
.38519 .69608 L
.39211 .67647 L
.40092 .65686 L
.40196 .65479 L
.41169 .63725 L
.42157 .62183 L
.42448 .61765 L
.4394 .59804 L
.44118 .59589 L
.45667 .57843 L
.46078 .57415 L
.47665 .55882 L
.48039 .55546 L
.5 .53928 L
.50008 .53922 L
.51961 .52533 L
.52861 .51961 L
.53922 .51345 L
.55882 .50356 L
.56695 .5 L
.57843 .49562 L
Mfstroke
.61765 .44084 m
.63725 .43894 L
.65686 .43882 L
.67647 .44051 L
.68198 .44118 L
.69608 .4441 L
.71569 .44972 L
.73529 .45751 L
.74218 .46078 L
.7549 .46776 L
.77389 .48039 L
.77451 .48086 L
.79412 .49748 L
.79673 .5 L
.81373 .51871 L
.81445 .51961 L
.82861 .53922 L
.83333 .54681 L
.84003 .55882 L
.84922 .57843 L
.85294 .58782 L
.85649 .59804 L
.86207 .61765 L
.86612 .63725 L
.86875 .65686 L
.87004 .67647 L
.87004 .69608 L
.86877 .71569 L
.86623 .73529 L
.86241 .7549 L
.85726 .77451 L
.85294 .78796 L
.8507 .79412 L
.84259 .81373 L
.83333 .83237 L
.83281 .83333 L
.82106 .85294 L
.81373 .86364 L
.80703 .87255 L
.79412 .88791 L
.7902 .89216 L
.77451 .90752 L
.7697 .91176 L
.7549 .92365 L
.74404 .93137 L
.73529 .93702 L
.71569 .94811 L
.70994 .95098 L
.69608 .9572 L
.67647 .96456 L
Mistroke
.65686 .97033 L
.65589 .97059 L
.63725 .97463 L
.61765 .97753 L
.59804 .97908 L
.57843 .97929 L
.55882 .97817 L
.53922 .97568 L
.51961 .97174 L
.51489 .97059 L
.5 .96626 L
.48039 .9591 L
.46266 .95098 L
.46078 .95002 L
.44118 .93867 L
.43049 .93137 L
.42157 .92457 L
.40695 .91176 L
.40196 .90685 L
.38879 .89216 L
.38235 .88391 L
.37451 .87255 L
.36329 .85294 L
.36275 .85186 L
.35465 .83333 L
.34824 .81373 L
.34383 .79412 L
.34314 .78994 L
.34129 .77451 L
.34051 .7549 L
.3414 .73529 L
.34314 .71826 L
.34394 .71569 L
.34811 .69608 L
.35389 .67647 L
.36129 .65686 L
.36275 .65343 L
.37034 .63725 L
.38105 .61765 L
.38235 .61544 L
.39347 .59804 L
.40196 .586 L
.40765 .57843 L
.42157 .5613 L
.4237 .55882 L
.44118 .53985 L
.4418 .53922 L
.46078 .52097 L
.4623 .51961 L
.48039 .50431 L
Mistroke
.48589 .5 L
.5 .48968 L
.51401 .48039 L
.51961 .47697 L
.53922 .46614 L
.55035 .46078 L
.55882 .45714 L
.57843 .44995 L
.59804 .44451 L
.61503 .44118 L
.61765 .44084 L
Mfstroke
.71177 .9902 m
.71569 .98852 L
.73529 .97912 L
.75052 .97059 L
.7549 .96792 L
.77451 .95474 L
.77956 .95098 L
.79412 .9392 L
.80288 .93137 L
.81373 .9208 L
.82222 .91176 L
.83333 .89879 L
.83856 .89216 L
.85252 .87255 L
.85294 .87191 L
.86446 .85294 L
.87255 .83775 L
.87471 .83333 L
.88343 .81373 L
.89082 .79412 L
.89216 .79019 L
.89693 .77451 L
.90188 .7549 L
.90575 .73529 L
.90854 .71569 L
.91029 .69608 L
.91099 .67647 L
.91064 .65686 L
.90922 .63725 L
.90671 .61765 L
.90304 .59804 L
.89818 .57843 L
.89216 .55914 L
.89204 .55882 L
.88448 .53922 L
.8754 .51961 L
.87255 .51409 L
.8646 .5 L
.85294 .48199 L
.85182 .48039 L
.83669 .46078 L
.83333 .45686 L
.81867 .44118 L
.81373 .4364 L
.7968 .42157 L
.79412 .41944 L
.77451 .40533 L
.76929 .40196 L
.7549 .39363 L
.73529 .38401 L
Mistroke
.73149 .38235 L
.71569 .37637 L
.69608 .37051 L
.67647 .36635 L
.65686 .36385 L
.63725 .36299 L
.61765 .36377 L
.59804 .36621 L
.57843 .37034 L
.55882 .37617 L
.54252 .38235 L
.53922 .38378 L
.51961 .39329 L
.50435 .40196 L
.5 .40467 L
.48039 .41807 L
.47569 .42157 L
.46078 .43352 L
.4519 .44118 L
.44118 .45106 L
.43119 .46078 L
.42157 .47074 L
.41266 .48039 L
.40196 .49267 L
.39584 .5 L
.38235 .5171 L
.38046 .51961 L
.36639 .53922 L
.36275 .5446 L
.35357 .55882 L
.34314 .57635 L
.34196 .57843 L
.33161 .59804 L
.32353 .61521 L
.32247 .61765 L
.3146 .63725 L
.30797 .65686 L
.30392 .67113 L
.3026 .67647 L
.29853 .69608 L
.29574 .71569 L
.29425 .73529 L
.2941 .7549 L
.29532 .77451 L
.29797 .79412 L
.30211 .81373 L
.30392 .82067 L
.30788 .83333 L
.3154 .85294 L
.32353 .87008 L
Mistroke
.32484 .87255 L
.33652 .89216 L
.34314 .90177 L
.35077 .91176 L
.36275 .92567 L
.36819 .93137 L
.38235 .94474 L
.38974 .95098 L
.40196 .96035 L
.41716 .97059 L
.42157 .9733 L
.44118 .98405 L
.45438 .9902 L
Mfstroke
.82245 .9902 m
.83333 .98125 L
.8452 .97059 L
.85294 .96315 L
.86469 .95098 L
.87255 .94223 L
.88162 .93137 L
.89216 .91775 L
.89647 .91176 L
.90957 .89216 L
.91176 .88863 L
.92111 .87255 L
.93137 .85297 L
.93139 .85294 L
.94039 .83333 L
.94839 .81373 L
.95098 .80683 L
.95537 .79412 L
.96144 .77451 L
.96669 .7549 L
.97059 .73798 L
.97115 .73529 L
.97483 .71569 L
.97776 .69608 L
.97996 .67647 L
.98145 .65686 L
.98226 .63725 L
.98239 .61765 L
.98187 .59804 L
.98071 .57843 L
.97893 .55882 L
.97655 .53922 L
.97359 .51961 L
.97059 .50265 L
.97009 .5 L
.96609 .48039 L
.96163 .46078 L
.95677 .44118 L
.95153 .42157 L
.95098 .41956 L
.94597 .40196 L
.94009 .38235 L
.93391 .36275 L
.93137 .35496 L
.92739 .34314 L
.92046 .32353 L
.91299 .30392 L
.91176 .30085 L
.90483 .28431 L
.89579 .26471 L
Mistroke
.89216 .25742 L
.88563 .2451 L
.87409 .22549 L
.87255 .22306 L
.86085 .20588 L
.85294 .19541 L
.84551 .18627 L
.83333 .17262 L
.82757 .16667 L
.81373 .15353 L
.80626 .14706 L
.79412 .13735 L
.78038 .12745 L
.77451 .12354 L
.7549 .11176 L
.74765 .10784 L
.73529 .10171 L
.71569 .09322 L
.70234 .08824 L
.69608 .08612 L
.67647 .0803 L
.65686 .07567 L
.63725 .07216 L
.61765 .06972 L
.60397 .06863 L
.59804 .0683 L
.57843 .06788 L
.55882 .06843 L
.55385 .06863 L
.53922 .06994 L
.51961 .07242 L
.5 .07586 L
.48039 .08029 L
.46078 .08573 L
.45279 .08824 L
.44118 .09222 L
.42157 .09981 L
.40351 .10784 L
.40196 .10858 L
.38235 .11862 L
.36701 .12745 L
.36275 .13007 L
.34314 .14308 L
.33762 .14706 L
.32353 .15791 L
.31307 .16667 L
.30392 .17488 L
.29218 .18627 L
.28431 .19451 L
.27424 .20588 L
Mistroke
.26471 .21763 L
.25879 .22549 L
.2455 .2451 L
.2451 .24573 L
.23413 .26471 L
.22549 .28216 L
.22452 .28431 L
.21651 .30392 L
.21001 .32353 L
.20588 .33889 L
.2049 .34314 L
.20111 .36275 L
.19854 .38235 L
.19707 .40196 L
.19657 .42157 L
.19688 .44118 L
.19779 .46078 L
.19906 .48039 L
.20044 .5 L
.20171 .51961 L
.20271 .53922 L
.20338 .55882 L
.20372 .57843 L
.20381 .59804 L
.20377 .61765 L
.20373 .63725 L
.20384 .65686 L
.20423 .67647 L
.20501 .69608 L
.20588 .71112 L
.20629 .71569 L
.2082 .73529 L
.2108 .7549 L
.21419 .77451 L
.21843 .79412 L
.2236 .81373 L
.22549 .82013 L
.22985 .83333 L
.23727 .85294 L
.2451 .87085 L
.24591 .87255 L
.25605 .89216 L
.26471 .90697 L
.26774 .91176 L
.28131 .93137 L
.28431 .93536 L
.29706 .95098 L
.30392 .95869 L
.31542 .97059 L
.32353 .97835 L
Mistroke
.33709 .9902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooH@00
00000ol0000000000000000500000003o`00000000000000044000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooomL000001806ATI?`000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?oooooooooooooooeD00000800I6ATh000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooDP00000W01TI6C@000001?oo
ool00`00003oooooooooo`2;ooooo`;o0000@_ooool000Wooooo00@00000ooooooooooooooooC`00
000[01TI6@03o`00000000000000030000001?ooool00`00003oooooooooo`28ooooo`?o000000?o
ooooo`000?ooool0@Oooool000Wooooo00@00000ooooooooooooooooB`00000d01TI6Bh000001?oo
ool00`00003oooooooooo`26ooooo`;o00001?ooool2o`00047ooooo0009ooooo`0400000?oooooo
ooooooooodX00000=P0I6AT]000000Cooooo00<00000ooooooooool0Poooool3o`0000Gooooo00Co
[;_Uo`000?oooooo0000@?ooool000Wooooo00@00000ooooooooooooooooA`00000k01TI6B/00000
1?ooool00`00003oooooooooo`20ooooo`?o00001Oooool01on]^nCo[;_UojbkiOn/^nGo0000oooo
ool00000@?ooool000Wooooo00@00000ooooooooooooooooA000001001TI6BT000001?ooool00`00
003oooooooooo`1nooooo`;o00001Oooool2ojbki0?o[K_T0_n/^nD01?l0003oooooooooool0000o
ooooo`002Oooool01000003ooooooooooooooom3000004<06ATI9`000004ooooo`0300000?oooooo
oooo07_ooooo0ol00005ooooo`Go[;_T0on]^n@00on]_>Co0000ojfli002ooooo`03o`000?oooooo
oooo03cooooo0009ooooo`0400000?ooooooooooooooocl0000000?o00000000000I6AT0A@0I6AT0
0`00003o00000000000S000000Cooooo00<00000ooooooooool0NOooool2o`0000Kooooo1_n/^n@5
ojfki005o`000?n]_>Coooooooooool00000?_ooool000Wooooo00@00000oooooooooooooooo?`00
001;01TI6B<000001?ooool00`00003oooooooooo`1fooooo`?o00001oooool4ojbki0So[K_T00?o
0000ojfli?n]_>@00_ooool00ol0003oooooooooo`0kooooo`002Oooool01000003ooooooooooooo
oolm000004h06ATI8P000004ooooo`0300000?oooooooooo07Cooooo0_l00008ooooo`04ojbji?n/
^nCo[;_Tojbki0[o[K_T00Ko0000ojfli?n]_>Co[KcTooooool0000mooooo`002Oooool01000003o
oooooooooooooolk00000003o`00000I6AT06ATI04h06ATI8@000004ooooo`0300000?oooooooooo
077ooooo0ol00007ooooo`Go[;[T00?o[;_Tojfki?n]^n@02On]^n@00ol0003o[KcTojfli002ojfl
i003ooooool0003ooooo03_ooooo0009ooooo`0400000?oooooooooooooooc/00000DP0I6ATP0000
00Cooooo00<00000ooooooooool0K_ooool3o`0000Oooooo0_n/^^<5ojbji003ojfji?n]^nCo[K_T
00So[K_T0_n]_>@00ol0003o[KcTojfli002ojfli0;ooooo00?o0000ooooooooool0>Oooool000Wo
oooo00@00000oooooooooooooooo>@00001E01TI6@03o`0000000000000001`000001?ooool00`00
003oooooooooo`1/ooooo`;o00002?ooool5ojbjh`03ojbji?n/^^?o[;[S00?o[K[T2_n]^n@2ojfl
i003o`000?n]_>Co[KcT00;o[KcT00?oooooo`000?ooool0>_ooool000Wooooo00@00000oooooooo
oooooooo>000001H01TI6Ad000001?ooool00`00003oooooooooo`1Yooooo`?o00001oooool2ojbi
h`[o[;[S00?o[K[Tojfjhon]^^<02?n]^n@2ojjki003ojjli?l0003o[[cT00;o[KcT00Co[[cToooo
oooooooo0000>_ooool000Wooooo00@00000oooooooooooooooo=P00001K01TI6A`000001?ooool0
0`00003oooooooooo`1Wooooo`;o00002?ooool5ojbih`So[;[S1?n]^^<00on]^n?o[K_Tojfki004
ojfki0Co[[_T00?o0000ojjli?n^_>@00on^_>@2ooooo`03o`000?oooooooooo03Oooooo0009oooo
o`0400000?ooooooooooooooocH00000G00I6AT00ol0000000000000000H000000Cooooo00<00000
ooooooooool0I?ooool3o`0000Oooooo00?oZkWSojbihon/^N<01On/^N<5ojbjh`Ko[K[S0on]^n<0
0on]^nCo[K_Sojfkh`03ojfki0;o[[_T00?o[[cTo`000?n^_>@01?n^_>@2ooooo`03o`000?oooooo
oooo03Oooooo0009ooooo`0400000?ooooooooooooooocD00000G@0I6ATK000000Cooooo00<00000
ooooooooool0H_ooool2o`0000Sooooo1?n[^N<7ojbih`?o[;[S1on]^^<7ojfkh`03ojfki?n^^nCo
[[cT00;o[[cT00?o0000ojjli?n^_>@01?n^_>@2ooooo`03o`000?oooooooooo03Kooooo0009oooo
o`0400000?oooooooooooooooc@00000G`0I6ATJ000000Cooooo00<00000ooooooooool0Goooool3
o`0000Oooooo00?oZkSSoj^ihon[^N<00on[^N<8ojbih`Co[;[S1_n]^^<6ojfkh`04ojjkhon^^nCo
[[_Tojjki0;o[[cT00?o0000ojjli?n^_>@01_n^_>@00ooooooo0000ooooo`0fooooo`002Oooool0
1000003ooooooooooooooolc000006406ATI6@000004ooooo`0300000?oooooooooo05gooooo0_l0
0008ooooo`CoZkSS0on[^N<:ojbih`;o[;[S2?n]^^<2ojfkh`Go[[_S00Go[[_Tojjli?n^_>Co[[cT
o`000007ojjli003ojnmi?oooooo000003Oooooo0009ooooo`0400000?oooooooooooooooc400000
H`0I6ATI000000Cooooo00<00000ooooooooool0F_ooool3o`0000Oooooo00?oZ[SSoj^hhon[^><0
1On[^><3oj^ih`[o[;WS2?n]^^<2ojfkh`Ko[[_S1?n^_>@00ol0003o[[cTojjli004ojjli0?o[kgT
00?oooooo`000?ooool0=Oooool000Wooooo00@00000oooooooooooooooo<000001U01TI6AP00000
1?ooool00`00003oooooooooo`1Gooooo`?o00002?ooool4ojZhh`OoZkSS0on[^N<:ojbih`Ko[K[S
1?n]^n<6ojjkh`?o[[cT00?o0000ojjli?n^_>@00_n^_>@5ojnmi0;ooooo00?o0000ooooooooool0
<oooool000Wooooo00@00000oooooooooooooooo;`00001W01TI6@03o`0000000000000001@00000
1?ooool00`00003oooooooooo`1Eooooo`;o00002?ooool2ojVgh`KoZ[SS1_n[^><4oj^ih`So[;WS
2?n]^^<2ojfkh`Ko[[_S00Ko[[cSojjli?n^_>Co[[cTo`000?n^_>@2ojnli0Oo[kgT00?oooooo`00
0?ooool0=?ooool000Wooooo00@00000oooooooooooooooo;`00001W01TI6AL000001?ooool00`00
003oooooooooo`1Booooo`?o00002?ooool5ojVgh`KoZ[SS1_n[^><2oj^ih`Oo[;WS2On]^^<8ojjk
h`?o[[cS0_n^_>@00ol0003o[kcTojnli002ojnli0Ko[kgT0_ooool00ol0003oooooooooo`0boooo
o`002Oooool01000003oooooooooooooool^000006T06ATI5P000004ooooo`0300000?oooooooooo
053ooooo0_l00008ooooo`OoZKOS00?oZ[OSojZhhonZ^><00onZ^><8oj^hh`Wo[;WS1on]^^<:ojjk
h`05ojjlhon__>?o[kcTojnli?l000000on__>@8ojnmi003ooooool0003ooooo03?ooooo0009oooo
o`0400000?ooooooooooooooobh00000JP0I6ATE000000Cooooo00<00000ooooooooool0COooool3
o`0000Sooooo2?nY]n<3ojZgh`?oZ[SS2_n[^><7ojbih`;o[KWS1on]^^<8ojjkh`06ojjlhon__>?o
[kcSojnlhon__>Co00000_n__>@8ojnmi004ojnni?ooooooooooo`0003?ooooo0009ooooo`040000
0?ooooooooooooooobd00000K00I6AT00ol0000000000000000A000000Cooooo00<00000oooooooo
ool0Boooool2o`0000Sooooo0_nX]n@:ojVgh`;oZ[OS1?nZ^><9oj^hh`Ko[;WS1?n]^N<5ojfjh`03
ojjjhon^^n?o[[_S00Co[[_S1?n^_><01?n__>?o[kcTojnli?l00002ojnli0Oo[kgT0on__^@2oooo
o`03o`000?oooooooooo033ooooo0009ooooo`0400000?ooooooooooooooob`00000K@0I6ATD0000
00Cooooo00<00000ooooooooool0B?ooool3o`0000Sooooo1OnX]n@9ojVgh`?oZ[OS0onZ^><:oj^h
h`Ko[;WS0_n]^N<5ojfjh`?o[[[S1_n^^n<2ojjlh`06ojnlhon__>Co[kcTojnli?l0003o[kcT2On_
_N@3ojnni003ooooool0003ooooo037ooooo0009ooooo`0400000?ooooooooooooooob/00000K`0I
6ATC000000Cooooo00<00000ooooooooool0AOooool3o`0000Wooooo1_nX]n@00onX]n?oZKOSojVg
h`08ojVgh`?oZ[OS0onZ^><8oj^hh`Ko[;WS0_n]^N<7ojfjh`03ojjjhon^^n?o[[_S00Co[[_S1On_
_><2ojnli003o`000?n__>Co[kgT00Oo[kgT00Co/;kTojnni?n__^Co[kkT0_ooool00ol0003ooooo
ooooo`0_ooooo`002Oooool01000003ooooooooooooooolZ000007406ATI4P000004ooooo`030000
0?oooooooooo04?ooooo0_l00009ooooo`;oYkOT1_nX]n@3ojRgh`WoZKOS1?nZ]n<2ojZhh`OoZkSS
1_n/^N<3ojfih`Ko[K[S00?o[[[Sojjkhon^^n<01?n^^n<7ojnlh`03ojnli?l0003o[kgT00Go[kgT
00?o/;gTok2ni?n`_^@00_n`_^@00on__^Co/;kUok2ni@02ooooo`03o`000?oooooooooo02kooooo
0009ooooo`0400000?ooooooooooooooobX00000L@0I6ATB000000Cooooo00<00000ooooooooool0
@?ooool3o`0000Wooooo1OnW]n@6ojRgi0?oZ;OS2OnY]n<2ojZgh`CoZ[SS1on[^><6ojbih`03ojfi
hon]^^?o[K[S00?o[K[S1?n^^^<6ojjkh`Oo[kcS00?o0000ojnmi?n__N@00_n__N@4ok2mi0Co/;kT
0_n`_^D2ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?ooooooooooooooobT00000
L`0I6ATA000000Cooooo00<00000ooooooooool0?_ooool2o`0000Oooooo2_nW]n@6ojRgi0CoZ;OS
2OnY]n<4ojZhh`SoZkSS1on/^N<6ojfjh`;o[[[S1_n^^n<00on_^n?o[kcSojnlh`05ojnlh`03o`00
0?n__NCo/;gS00Go/;gT1On`_^@3ok2ni@;ooooo00?o0000ooooooooool0;Oooool000Wooooo00@0
0000oooooooooooooooo:@00001c01TI6A4000001?ooool00`00003oooooooooo`0kooooo`?o0000
1oooool00onV]nGoYkOTojNgi00:ojNgi0;oZ;OT0_nW]n@2ojRgi0?oZ;OS2_nY]n<2ojZhh`[oZkSS
1On/^N<00on]^N?o[K[Sojfjh`03ojfjh`;o[[[S1_n^^n<3ojnkh`Ko[kcS00Co0000ok2mhon`_N?o
/;gS0on`_N@7ok2ni003ok2niOn`_nGo/;oU00;ooooo00?o0000ooooooooool0;?ooool000Wooooo
00@00000oooooooooooooooo:000001e01TI6@03o`0000000000000000d000001?ooool00`00003o
ooooooooo`0iooooo`;o00002?ooool4ojJgi@;oYkOT00?oY[OTojNgi?nW]n@02_nW]n@4ojRgi0;o
Z;OS2OnY]n<3ojZhh`SoZkSS1On/^N<3ojfih`?o[K[S1?n^^^<6ojjkh`03ojnkhon__>?o[kcS00?o
[kcS0_n`_><01?l0003o/;cSok2mhon`_N<4ok2mi0Ko/;kT1?n`_nD00ooooooo0000ooooo`0]oooo
o`002Oooool01000003ooooooooooooooolX000007D06ATI40000004ooooo`0300000?oooooooooo
03Kooooo0ol00007ooooo`SoY[OU0onV]n@<ojNgi0?oZ;OT0onX]n<9ojVgh`CoZ[SS1_n[^><6ojbi
h`?o[KWS0on]^^<3ojjjh`Go[[_S0_n_^n<6ojnlh`03ok2lhol0003o/;cS00?o/;gS1?n`_N@00on`
_^Co/KkTok6ni003ok2ni0;o/;oU0_na_n@00ooooooo0000ooooo`0/ooooo`002Oooool01000003o
oooooooooooooolW000007L06ATI3`000004ooooo`0300000?oooooooooo03?ooooo0ol00008oooo
o`_oY[OU0onV]n@<ojNgi0?oZ;OT00?oZ;OSojRgi?nX]n@01_nY]n<3ojVhh`?oZ[SS1_n[^><6ojbi
h`Co[KWS0_n]^^<4ojjjh`Co[[_S00?o[k_Sojnkh_n__><01?n__><2ok2lh`03o`000?n`_>?o/;cS
00?o/;gS0_n`_N@00ona_N?o/KkTok6ni002ok6ni003ok2ni?na_^Co/KkT00?o/KoT00?oooooo`00
0?ooool0;?ooool000Wooooo00@00000oooooooooooooooo9`00001g01TI6@l000001?ooool00`00
003oooooooooo`0aooooo`;o00001_ooool2ojJgiPkoY[OU1?nV]n@00onW]nCoY[OTojNgi009ojNg
i0KoZ;OT1_nY]n<00onY^>?oZ[SSojZhh`03ojZhh`KoZkSS1_n/^N<3ojfih`?o[K[S0_n^^^<01On^
^^;o[[_Sojjkhon^^n?o[k[R00?o[k_R0_n__><00on`^n;o/;cSok2lh`02ok2lh`04o`000?n`_>?o
/;cSok2mh`Go/KgS0_na_^@01?na_^?o/KkTok6ni?na_^@4ok6oi003ooooool0003ooooo02_ooooo
0009ooooo`0400000?ooooooooooooooobL00000M`0I6AT?000000Cooooo00<00000ooooooooool0
;_ooool3o`0000Kooooo0_nV^>H3ojJgiPkoY[OU1_nV]n@9ojNgi0KoZ;OT1_nY]n<6ojZhh`GoZkSS
00?oZkWSojbihon/^N<00on/^N<5ojfih`03ojfjhon^^^;o[[[R00?o[[[R00Co[[_Sojnjh_n_^^;o
[k[R0_n_^n84ok2khP04ok2lhon`_>;o/;cRo`0000;o/;cS1_na_N<4ok6nh`03ok6ni?na_nCo/KoT
00?o/KoT0_ooool00ol0003oooooooooo`0Yooooo`002Oooool01000003ooooooooooooooolV0000
07T06ATI3P000004ooooo`0300000?oooooooooo02cooooo0_l00007ooooo`03ojFhi_nV^>KoY[SV
00;oY[SV00?oY[OVojFgi_nV]nD01?nV]nD00onU]nGoY[OUojJgi@07ojJgi@KoY[OT2OnW]n@6ojRg
i0;oZKOS00CoZKOTojVghonY]n?oZKOS1_nZ^><3oj^hh`?oZkWS0on/^N<5ojfih`03ojfih_n^^^;o
[[[R00Go[[[R0on_^^83ojnkhP?o/;_R0on`_>801?l0003o/;cSok6lh_na_>82ok6mh`04ok6mh_na
_N?o/KgSok6mh`;o/KkS0_nb_^<00ona_nCo/[oSok6oi003ok6oi003ooooool0003ooooo02[ooooo
0009ooooo`0400000?ooooooooooooooobH00000N@0I6AT>000000Cooooo00<00000ooooooooool0
:Oooool3o`0000Oooooo1?nU^>H2ojJhiPCoYKOV0_nV]nD4ojFgi@;oY[OU00?oYKOUojJgiOnV]nD0
1?nV]nD00onV]nCoY[OUojJgi003ojJgi0SoYkOT1onX]n@3ojVgi003ojVghonY^>?oZKSS00KoZ[SS
0on[^><00on[^N?o[;SSojbhh`03ojbih`;o[KWS1?n]^N82ojjjhP;o[[WR00?o[[[RojnihOn_^N40
0on_^^800on_^n;o/;[Qok2jh@03ok2khP;o/;cR00Co0000ok6khOna_>;o/[cQ1?na_N800ona_N?o
/[gRok:mhP03ok:nh`?o/[oS0_na_n@2ok:oi003ooooool0003ooooo02Wooooo0009ooooo`040000
0?ooooooooooooooobD00000N`0I6AT00ol0000000000000000:000000Cooooo00<00000oooooooo
ool09oooool2o`0000Gooooo2_nU^>H6ojFgiPWoYKOU00?oY[OUojFgiOnU]nD01OnV]nD4ojJgi0So
YkOT1onX]n@2ojVgi0CoZKSS1_nZ^><2oj^hh`Co[;SS00?o[;WSojbhh_n]^N801_n]^N82ojjihP03
ojjihOn_^N7o[kWQ00;o[kWQ00?o[k[Rok2ihOn`^^400on`^^401_n`^n;o/K[Qok6jhOna^n7o0000
ok6kh0?o/[cQ0_na_N82ok:lh@03ok:mh_nc_N7o/[kS00?o/[kS0onb_n<2ok:oi004ok>ohooooooo
ooooo`0002Wooooo0009ooooo`0400000?ooooooooooooooobD00000N`0I6AT=000000Cooooo00<0
0000ooooooooool09?ooool3o`0000Gooooo0_nU^>L;ojFhiPKoYKOV3?nU]nD6ojJgi@03ojJgi?nV
]nGoY[OU00?oY[OT1OnW]n@6ojRgi0?oZKOT0onY^><6ojZhh`?oZkSS0_n/^><4ojbhhP;o[KWR0_n]
^>800on]^N;o[[SQojjhh@03ojjih@;o[kWQ00Co[kWPok2ihOn`^N7o/;WQ0_n`^^42ok2ih004ok6j
hOna^]oo/K_Po`0000;o/K_P00?o/[cQok:kh?nb_>400_nb_>401?nc_>3o/kgQok>mhOnc_N42ok:n
h`04ok>nh_nb_n?o/[oSok:oh`Co/koS00?oooooo`000?ooool0:?ooool000Wooooo00@00000oooo
oooooooooooo9000001m01TI6@`000001?ooool00`00003oooooooooo`0Rooooo`;o00001_ooool0
0onU^NOoYKSWojFhi`02ojFhi`SoYKSV2OnU]nH;ojFgi@[oY[OU00?oY[OTojJgiOnW]n@01OnW]n@6
ojRgi0?oZKOT0onY^><6ojZhh`04oj^hhon[^>;oZkSRoj^hhPKo[;SR00?o[KSRojfghOn^^>400on^
^>400on^^N7o[kSPojnih003ojnih003ok2ihOn`^=oo/;WP00;o/;WP00Oo/KSNok6jgona^]oo/K[O
o`000?na^n3o/[[O00?o/[_P00Go/[cQok>lh?nc_>3o/kcPok>mh@02okBmh@?o/kkR00?o/[oSok>o
h_nc_n800onc_n<2ooooo`03o`000?oooooooooo02Kooooo0009ooooo`0400000?oooooooooooooo
ob@00000O@0I6AT<000000Cooooo00<00000ooooooooool07oooool3o`0000Kooooo1?nU^NL3ojFh
i`WoYKSV3?nU]nH8ojFgi@;oY[OU00?oYKOUojJgiOnV]nD01onV]nD2ojNgi004ojNgiOnW]nCoYkOT
ojNgi0KoZ;OT0onY]n@3ojVhh`KoZ[SS0_n[^>800on[]n;o[;SRojbhhP03ojbhhP04ojbghOn]]n7o
[KOQojfgh@;o[[SQ00Co[[OOojnhh?n_^>3o[kSP0_n_^N001On`]moo/;SOok2hgon`^=oo/;WP00?o
/KSN00?o/K[Ook:ig_l000000onb^]l01_nb^n3o/k[Ook>jgonc^]oo/kcPokBkg`Co];gQ00Co/kkR
okBnhOnd_^7o/koR0_nd_^83ok>oh`;ooooo00?o0000ooooooooool09Oooool000Wooooo00@00000
oooooooooooooooo9000001m01TI6@`000001?ooool00`00003oooooooooo`0Looooo`?o00001?oo
ool5ojJii`?oYKWW1OnU^>L7ojFhiQ7oYKOV2?nU]nD9ojJgi@?oYkOU0onW]n@6ojRgi0?oZKOT00?o
ZKSSojVghonY]n<00onZ]n<00onZ^>?oZ[ORojZghP03oj^ghP03ojbhh_n/]n7o[;OQ00?o[;OQ00?o
[KOQojffgon]]]l00on^]ml00on_^>3o[kKNojnfgP03ok2gg`06ok2hgona]mko/KONok6gg_na^=ko
/[OM0_nb^Mh01?l0003o/[WNok:jgonc^Md3ok>jg`04okBjgOnd^moo];_OokBkg`;o];gQ0_ne_=l0
0ond_^7o]KgPokBnhP03okBnhP05ok>ohond_n;o];oRooooool000009oooool000Wooooo00@00000
oooooooooooooooo8`00001n01TI6@`000001?ooool00`00003oooooooooo`0Jooooo`;o00001Ooo
ool6ojJii`GoYKWW1_nU^>L5ojFhiPCoYKOV00?oY;OVojFgi_nU]nH00onU]nH00onT]nKoYKOVojFg
iP04ojFgiPSoYKOU2_nV]nD2ojNgi@CoYkOT00?oZ;OTojNgi?nX]n@00onX]n@00onY]nCoZ;OTojVg
h`03ojVgh`03ojZghonY]n?oZ[OR00?oZ[OR00?oZkORoj^fhOn/]n401?n/]n400on/]]oo[KKOojff
g`02ojffg`03ojjggon^]Mko[kKN00?o[kKN00?o/;OOok2fgOna]mh00_na]mh01ona]Mco/[OMok:g
gOnb]mgo/[WNo`000?nc]m`00onc^Md01_nc^]oo];[MokBjgOnd^]go];_OokFkg@?o]KcO00Co][cN
okFmh?ne_N3o]KgP0_nd_^82okFnh@05okBoh_ne`>;oooooooooool000009_ooool000Wooooo00@0
0000oooooooooooooooo8P0000000ol000006ATI01TI6@1m01TI6@/000001?ooool00`00003ooooo
ooooo`0Gooooo`?o00001Oooool3ojJji`?oY[WW1onU^NL9ojFhi`03ojFhi_nT^>OoY;SW00GoY;OV
0_nU]nH4ojBgiP03ojFgi_nT]nKoY;OV00?oYKOV00?oYKOUojFgi_nU]nH01OnU]nD2ojJgi@;oYKOU
1OnV]nD3ojNgi@;oYkOT00CoYkOUojNgi?nW]nCoYkOT1_nX]n@6ojVgh`;oZ[OR00CoZ[KQoj^fhOn[
]^7oZkKQ0_n/]n401?n/]Moo[;KOojbfgon/]]l2ojffg`04ojfdg_n^]Mko[[GNojjegP;o[kKN00Go
[kCLok2fgOn`]]go/;KMok6ggP03ok6eg004ok:ggOnc]M[o0000o`0000;o/kOL00?o/kWMokBhfond
^=/00_nd^]d01Onf^M_o]K_MokFkgOne^mgo]KcO00?o][cN00?o]KgPokNmgone_^400_ne_^401?ng
_n3o]L3RokG0h_ne`>82ooooo`03o`000?oooooooooo02?ooooo0009ooooo`0400000?oooooooooo
ooooob<00000O`0I6AT;000000Cooooo00<00000ooooooooool05_ooool2o`0000?ooooo1onV^^L;
ojFii`OoYKSW1OnT^>L>ojBgiP03ojFgi_nT]nKoY;OV00?oYKOV00?oYKOUojFgi_nU]nD01OnU]nD6
ojJgi@03ojNgiOnV]nGoY[OU00?oYkOU0onW]n@4ojRgi003ojRghonY]n?oZKOS00?oZKOS00?oZKKR
ojZfhOnZ]^400_nZ]^400on[]^7oZkCPojbeg`03ojbeg`03ojbfgon//mko[KCN00?o[KCN00?o[[GN
ojjcg?n_]=`00on_]=`00on`]]go/K?Kok6cf`02ok6eg0?o000000Co/kGJo`000?nc]mco];KJ0ond
^=/4okJif`03okFkgOng^]co]k[L00;o][cN00Go^;_LokNmgong_Moo]kgOokFnh@03okNoh005okG0
h_nf`>7o]/3Qooooool000009Oooool000Wooooo00@00000oooooooooooooooo8`00001o01TI6@/0
00001?ooool00`00003oooooooooo`0Fooooo`04o`000?oooooo0000ojJjj0WoY[[W2OnU^NL6ojFh
i`OoY;SW4_nT]nH5ojFgiP;oYKOU00CoYKOVojFgiOnU]nGoYKOU2OnV]nD3ojNgi@?oYkOT0_nX]n@3
ojRgh`;oZKOS1?nY]^82ojZfh@04ojZdh?n[]>3oZkCPoj^dh0;o[;GO1?n//mh2ojfdgP04ojjbfon^
/mco[[?Lojjcg0;o[kCL00?o/;;Jok6cfona/m/00ol00002ok:cf@04ok>ef_nd/mSo];KJo`0000;o
];KJ00?o];SKokJffOnf]]T00_nf^M/01?ng^=Wo]k[LokNjg?ng^]`4okRkg003okNmgonh_Mko^;gN
00;o]koP00Co^;oOokK0hOnf`>7o]/3Q0_ooool00ol0003oooooooooo`0Rooooo`002Oooool01000
003ooooooooooooooolS000008006ATI2P000004ooooo`0300000?oooooooooo01Kooooo00?o0000
ojJjj?nV^^P00_nV^^P00onV^^OoY[[XojJjj004ojJji`_oYKWW00?oYKSWojBhionT^>L02_nT^>L2
ojBgiP03ojBgionT]nKoY;OV00goY;OV2?nU]nH00onU]nGoYKOVojFgiP09ojJgi@03ojNgiOnV]nGo
YkOT00?oYkOT0_nX]n@00onX]n?oZ;KSojRfh`04ojVfhP;oZKCQ0onZ]>000on[]>3oZk;Noj^bgP04
ojbcgP;o[;7K0on^/]/01?n^/mco[k3Iojn`fOn`/]X3o`0000;o/K7H0_nb/mT01onc/MKo];?HokBc
f?nd/mSo];KJo`000?nf]=L00onf]]T4okNhf@03okNjg?nh^M[o^;WJ00;o^;_L00Co^K_KokRmg_nh
_Mko^;gN1?nh_ml01Onf`>7o^<3QokS0hOoooooo000002Cooooo0009ooooo`0400000?oooooooooo
ooooob<00000A`0I6AT;000002h06ATI00?o00000000000000001`000004ooooo`0300000?oooooo
oooo01Kooooo00?o0000ojJjj?nV^^P01_nV^^P01?nV^^OoYK[XojFjj?nU^^P9ojFii`03ojBiionT
^>OoY;SW00goY;SW0_nT]nL00onT]nKoY;OWojBgi`04ojBgiP;oY;OW2OnT]nH8ojFgiP03ojJgiOnU
]nKoY[OU00SoY[OU0_nW]n@01?nW]^CoYkKSojNfhonW]^<3ojRfh`03ojVfh_nX]>7oZKCQ00?oZKCQ
00?oZ[CPojVbg_n[/]h00on[/]h00on//mkoZk3Kojbaf`03ojbaf`03ojjbfon^[mWo[k3I00?o0000
00?o/;;Jok2_eona/MP00_na/MP01Onb[]Co/k7Fok>ae_nc/MKo];?H00;o]K7E00Co][CGo`000?nf
]=Oo][KI0_ng]ML2okNhf@04okVgeonh^M[o^;WJokRifPCo^K_K00?o^;gNokZmg?nj_M`00_nh_ml2
okVogP05okS0hOni`N3o^L7Pooooool000008oooool000Wooooo00@00000oooooooooooooooo8`00
001301TI6@@000002`0c<c<4000002X06ATI2P000004ooooo`0300000?oooooooooo01Gooooo00?o
0000ooooooooool02OnV^^P2ojFjj0WoYKWW0_nT^NL>ojBhi`KoY;OW00?oY;OVojBgionT]nL00onT
]nL00onT]nKoY;OWojBgiP08ojBgiPSoYKOV1onV]nD2ojJfi0?oYkKT00?oYkKSojNdhonW]><00onW
]>82ojRdh@;oZKCQ00CoZ;;OojVbg_nY/]koZK;N0_n[/]h01?nZ/=coZk3Koj^`fon[/=/2ojbaf`04
ojb^fOl0003o0000o`0000;o[k3I00Go[jgFok2_eon`[mOo/:oGok6af003ok:^e003ok>ae_nd[]?o
]K7E00?o]K7E00Co0000okNbe?ng/]Co]kGG0_ni]=@3okVge`03okRif_nj^MSo^[WH00;o^K_K0_nk
^mT00onj_Mco^kgKok^mf`02okVogP04ok_0gOni`N3o^L7PokW1h0;ooooo00?o0000ooooooooool0
8?ooool000Wooooo00@00000oooooooooooooooo8`00001001TI6@<000004`0c<c<3000002L06ATI
2P000004ooooo`0300000?oooooooooo01Gooooo00Co0000oooooooooooooooo1onV^^P4ojFjj003
ojFiionU^NSoYKWX00CoYKWW0_nT^NP3ojBii`goY;SW0_nT]nL00onS^>OoY;OWojBgi`09ojBgi`03
ojBgi_nT]nOoY;OW00CoY;OV0_nT^>H9ojFgiPGoY[OU0onV]^@00onW]^CoY[GSojNdh`03ojNdh`03
ojNdh_nW/^7oZ;;P00?oZ;;P0_nX/]l00onY/]koZJoLojV_g003ojZ`g003oj^`fon[[MWo000000;o
000000?o[:kIojj_fOn^[=D01?n_[MH00on`[mOo/JcCok:^e002ok:^e004ok>/dOnd[]?o]:kCokB^
d`;o]K7E00Co]joBokNbe?l0003o]k;D1?ni]=@01Oni]mOo^kKEok^feOnj^MSo_;WF00?o^k_I00Co
_K_Hok^mfonk_M_o^kgK1?nk`=d01Oni`N3o^/7Ook[1gooooooo000002;ooooo0009ooooo`040000
0?ooooooooooooooob800000?P0I6AT3000001T0<c<c0`00000U01TI6@T000001?ooool00`00003o
ooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo0onV^^P8ojFjj0?oYKWX00?oYKWWojBij?nT
^NP00onT^NP00onT^NOoY;WXojBhi`0;ojBhi`GoXkSW00?oY;OWoj>hionS^>L00onS]nL3ojBgi`?o
Y;SW0_nT]nL00onT]nKoY;SWojBhiP03ojBhiP03ojFgi_nT^>KoYKOV00GoYKOV0onU]nD3ojJgi@03
ojJfi?nV]NCoY[GS00;oY[GS0_nW]><01?nV/n;oYk;QojNbhOnW/^42ojRbh004ojN_g_nX[mgoZ:oM
ojR_g@?oZJoL00GoZ[3Lo`000?l0003o0000oj^]f@02ojb^f@04ojbZeOn^[=Go[ZcEojj/e@;o[jgF
00Go[j[Bok6/dona[=?o/JcCok:^e003ok>/d@;o]:kC1?ng[m800ong/]Co0000okVad@02okVde004
ok^cdOnk]]Go^kKEok^fe@?o_;WF00Go^k_Iokfkf?nm^mSo_K_Hok^mf`02okfnfP;o^l3M0_nm`Md0
1Onj`Moo^l;Ook_2gooooooo0000027ooooo0009ooooo`0400000?ooooooooooooooob800000>P0I
6AT200000003o`0000000000<c<c01h0<c<c00<00000o`00000000008P0I6AT9000000Cooooo00<0
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`?oY[[X2?nU^^P3ojFij0SoY;WX00?o
Y;SWojBhj?nT^>P01?nT^>L00onS^>SoXkSWoj>hi`0:oj>hi`03oj>gionS^>OoXkSW00;oXkSW0_nT
^>L00onS^>OoY;SWojBhi`03ojBhi`;oY;SV00GoY;SWojBhi_nT^>KoY;SVojFgiP02ojBgiP?oYKOV
00?oYKOUojFfiOnU]^D00onU]^D2ojJei003ojJehonU/n;oYK?R00?oY[?R00?oYk;QojJ`gonV/=l0
0onW[mh00onX[mgoYjcKojR/fP03o`0000;oZJcI00?oZjgIoj^YeOn[ZMD00on/Z]D00on^[=Go[ZSB
ojjXdP03ojnZdP03ok6/donaZM3o/jcA00?o/jcA00?o]:kCokJ/conf[<l00_ng[m801?nh[Lko^K7A
okVadOl00004ok^cd@04ok^feOnm]];o_KKBokbieP?o_[WD00?o_K_Hoknleonm_]X00_nm_]X3okg1
g@04okk1g?nk`]oo^l;Ook_2g`;ooooo00?o0000ooooooooool07_ooool000Wooooo00@00000oooo
oooooooooooo8P00000i01TI6@030000000c<c<0<c<c02@0<c<c0P00000P01TI6@T000001?ooool0
0`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?oY[[XojFjj?nU^^P01OnU^^P4
ojFij0_oY;WX0_nT^>P00onT^>OoXkSXoj>hj002oj>hj0;oXkSW00?oXkSXoj>hionS^>L03onS^>L0
0onT^>OoXkSWojBhi`05ojBhi`03ojBhi_nT^>OoY;SW00?oY;OV00?oYKOVojBgi_nU]^D01?nU]^D0
1?nT]>CoYKCSojFdhonU]><3ojFchP03ojJch_nU/>3oY[3O00?oY[3O00?oYjoNojJ/g?nW[=/00_l0
0003ojR/fP03ojV/fOnYZ=KoZjWE00?oZjWE00?o[:[EojbVdOn^Z=800on^Z=800on_Z];o/:K>ok6Y
d002ok6Yd0;o/jcA00Co]:W=okJ/conf[<oo]Zc?1?nh[Lh00oni/M7o0000ok^_cP02ok^cd@04okfb
conm]];o_KKBokffdP?o_[WD00Go`KWBoknleono_=Oo_kcGokfnfP02oknof@05okg1gOnn`Mco_/7L
okk1g?nk`]l00_nm`ml00ooooooo0000ooooo`0Oooooo`002Oooool01000003ooooooooooooooolR
000003L06ATI0P00000Y03<c<`8000007`0I6AT8000000Cooooo00<00000ooooooooool05Oooool0
0ol0003oooooooooo`05ooooo`SoYK[X00?oYKWXojBij?nT^NP02_nT^NP00onS^NSoXkSXoj>hj009
oj>hj003oj>hionS^>SoXkSX00?oXkSX00?oXkSWoj>hj?nS^>P00_nS^>P4oj>hi`04oj>hj?nS^>Oo
XkSWoj>hi`;oY;SW00?oXkSWojBhionT^>L00_nT^>L2ojBgi`GoY;OV0_nU]^D01OnT]NGoY;CTojBd
i?nT]>CoYKCS00;oY;;R0onT/N42ojF`h0;oY[3O00CoY:cMo`000?l0003o00000_nW[=/2ojR/fP04
ojNWe_nYZ=KoZJSFojVXeP;oZjWE00CoZZGAojbVdOn/Y]7o[:KA0_n^Z=801On^Y<ko/:K>ok2Vc_n`
Y/ko/JW@00;o/ZK<0ondZLd00onf[<oo]j[<okNZc003okR]cP;o^jo>00?o0000ok^cdOnm//l00_nm
//l01?nm]];o_kK@oknfd?nn^M@3ol6idP04oknleoo2_MGo`[gEoknof@;o`/3H0_nn`M`2ol33g005
okg3gonna=oo_/COooooool000007oooool000Wooooo00@00000oooooooooooooooo8P00000e01TI
6@03o`0000000000<c<c02`0<c<c00<0000001TI6@0I6AT07@0I6AT7000000Cooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`07ooooo`WoYK[X2_nT^NP3oj>ij003oj>hj?nS^NSoXkWX
01SoXkSX00?oXkSWoj>hj?nS^>P00onS^>L00onT^>OoXkSWoj>hi`03ojBgi`03ojBgi_nS]nKoY;KV
00?oY;KV0_nT]ND00onT]>CoXk?SojBbhP03ojBbhP04ojBahOnS[]ooY:gNojB]gP?o000000?oY:cM
ojJ/g?nTZ=T00onVYmL3ojNWeP03ojVXe_nXY=;oZ:CB00?oZZGA00?o[:KAojbRcOn^Y<h00on^Y<h2
ok2VcPCo/ZK<00?o]:W=okFVb_ngZ/`00ongZ/`01_nh[Lko^Zc;okZ/bonk[lko_Jo<o`0000;o_K;?
00Co`;;=oknfd?no]]3o_kK@0oo1^M801?o3^]7o`[gEol:meOo2_MD3ol;0f0?o`<?L00Co`/CLokk4
gonna=oo_/CO0_ooool00ol0003oooooooooo`0Looooo`002Oooool01000003ooooooooooooooolR
000003<06ATI0P00000`03<c<`03o`00000000006ATI01`06ATI1`000004ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool7ojFjj003ojBjj?nT^NSoY;WX00WoY;WX1_nS^NP0
0onS^>SoXkWXoj>hj00Hoj>hj003oj>hionS^>SoXkSX00?oXkSW00?oY;OWoj>gionS]nH00_nS]nH2
ojBfiP04oj>eiOnS]>CoXkCToj>di0;oXk?S0_nT/^800onR[n7oXjkOo`000002o`000004ojB]g_nT
[=goY:cMoj>XfP?oY:SI0onVYmL00onWYmKoYZ?CojRTdP03ojRTdP03ojZUdOnYX<go[:;=00;o[:;=
0on^Y<h00on`Y/ko/:?;ok2Sb`02ok:Vc004ok>Sb?neY/[o]JK:okFVbP;o]j[<00Co^JS9okZ/bonj
[<_o^Zc;0onm[l`01Ol0003o`;;=ol2bcOo0//go_kK@00;o`[K?00Go`KWBol>jdOo3^]7o`k[Aol:m
e@02olBne004ol;0f?o4`]Soa<;Hol33g0?o`/CL00Go_/COoko6gonoa]ooooooo`00000Nooooo`00
2Oooool01000003ooooooooooooooolR000003806ATI00<0000003<c<`0c<c<0<P0c<c<2000001/0
6ATI1`000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool6ojFjj0;o
Y;[X1onT^NP<oj>ij003oj>hj?nS^NSoXkWX01WoXkSX0onS^>L2oj>gi`03oj>gi_nR]^KoX[KV00?o
XkGU00?oXkCToj6bi?nR/>800_nR/>83o`000003oj>^gonQZ]goXZWL00;oXZWL0onSZ=X00onTZ=Wo
XZ?EojBSe002ojBSe0?oYZ?C0_nXY=801?nWWlkoZJ3=ojVPcOnYX<d2ojbRc@;o[ZC>00Go[Z39ok2S
bon`Xl_o/:?;ok:Vc003ok>Sb0;o]JK:1?niZ<T01_nj[<_o_:_8okb[b?nm[lco_jk9o`0000?o`;;=
0oo2]/l3ol>jd@04olJkd?o4_]Coa;kDolBne0?oa<;H00?oa/?Hol;4g?o2a=`00_o4a]`01Onoa]oo
`LOOol77gooooooo000001gooooo0009ooooo`0400000?ooooooooooooooob800000<@0I6AT00ol0
0000<c<c03<c<`0e03<c<`030000000I6AT06ATI01P06ATI1`000004ooooo`0300000?oooooooooo
01Cooooo00?o0000ooooooooool02_ooool4ojFjj0GoY;[X1OnT^NP@oj>ij003oj>hj?nR^NSoX[WX
00CoXkSX00GoX[WYoj>ij?nS^NSoXkWXoj>hj002oj:ij@?oXkWX2?nS^>P00onS^>OoX[OWoj:fi`02
oj:fi`?oX[KV00CoXkGUoj6ciOnQ/^CoXK;T0ol000000onR/>;oXZoQoj2/g`03oj6Zg@?oXZWL00?o
XjSJoj6SeonRXmD00_nRXmD3ojBSe003ojJSdonUW/ooYio>00?oYio>0_nYX<d00on/X/goZik9oj^N
b@03ojjPb@03ok2SbonaX<Oo/j?800?o/j?800?o]JK:okNTa_ngY<H00_niZ<T01?njYlGo_:_8okb[
b?nlZlP3okn^b@05o`000?o0//go`[;;ol:bboo2]/l00_o5]ld01Oo3^]7oa[_@olJkd?o6^m3oa;kD
00;oal3D00?oa<;HolK3f?o6`mP00oo4a]`01?o5amco`LOOol77goo1aml2ooooo`03o`000?oooooo
oooo01[ooooo0009ooooo`0400000?ooooooooooooooob800000<00I6AT00`000000<c<c03<c<`0f
03<c<`03o`00000000006ATI01P06ATI00?o000000000000000010000004ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool02oooool00onU^^SoY;[XojBjj008ojBjj003ojBij?nS^NWo
XkWY00KoXkWX0_nS^NT4oj>ij0CoX[WY00?oX[WXoj:ijOnR^NT01OnR^NT00onS^NSoX[WYoj:ij@03
oj:ij@03oj>ij?nR^NWoX[WX00;oX[WX1?nS^>P01OnR^>SoX[OWoj:gionR]nOoX[KW00;oXKGW0onQ
]>H3o`0000;oWjoR0onP[N42oj2/g`03oj6ZgOnNY]_oWZKK00;oWjCI0onQXmL3oj:Se@03ojBSe?nR
WM3oYIk?00;oYIk?0onWWlh00onYX<goZIc9oj^Nb@03oj^Nb@03ojjPbOn^WLKo/J3700;o/J370_nc
XlP01OndXLCo]jC6okNTa_ngY<Ko^JS900?o^ZO500?o_:_8okjZa_nnZ/H00_no[/T01?o2[lOo0000
ol:bboo2///3olFgc@?oa[_@0_o9_Ll01?o7`=CobL;ColW2doo6`mP2olS5f005olC6g?o5amcoaLOL
olG7g?o1aml00_o1b>000ooooooo0000ooooo`0Kooooo`002Oooool01000003ooooooooooooooolR
000002l06ATI00<0000003<c<`0c<c<0>@0c<c<00`0000006ATI01TI6@0F01TI6@L000001?ooool0
0`00003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo1?nT^^P2ojBjj@?oY;[X0_nT^^T3
oj>ij@03oj>ij?nS^NWoXkWY00SoXkWY5OnR^NT00onR^NSoX[WYoj:ij@05oj:hj003oj:gionQ]^Oo
XKKW00;oXKGW0ol00002oinai0CoWjoR00CoX:gQoifYgonNYmgoWZOM1?nNY]/2oinTf@03oj6SeonN
W]?oX9gA00;oX9gA0onRWM02ojFNc`;oYio>00CoYY[:ojVLbOnYW<WoZIc90_n[W/T01?n[V/Go[Yg6
ojjMa_n^WLH2ok6Pa`Co]:7400?o]jC6okRS`onhXl<00onjYlD3okjZaP05okn^bOo2[lOo`Zo7o`00
0?o2///00_o5/lT01?o5]lgob;S<olRhc?o6^m03olVmc`?obL;C0oo8aMP01?o9amSoaLOLolG7g?o6
bM`2ol78h0;o`/[Q00?oooooo`000?ooool06_ooool000Wooooo00@00000oooooooooooooooo8P00
000]01TI6@800000?@0c<c<00`0000006ATI01TI6@0F01TI6@H000001?ooool00`00003ooooooooo
o`0Cooooo`03o`000?oooooooooo00kooooo2onT^^T00onS^NWoXk[Yoj>jj@09oj>ijA[oX[WY00?o
X[SXoj6hjOnQ]nP00_nQ]nP01OnQ]^Oo0000o`000?l0003oX;CV00?oWk;U0_nO/N@2oin_hP04oif/
hOnMZMooWJWOoifYg`;oWZOM0_nNY]/00onLXMSoWIoFoifOeP03oijNd`?oX9gA0_nRWM000onUW/oo
XiW;oj>Ib`03ojJJbP;oZIc900CoZik9oj^JaOn[V/GoZi[50_n^WLH00onaX<Oo/Yg3ok:M``03okBQ
a0Co^:?300?o^ZO5okfV`onmY/<00_nnZ/H3ol:_a`04olF_aOl0003oaK?9olFcb@?ob;S<0oo9_Ll2
olc0c`04olW2doo<a=?oc<CColS5f0;obLOH0oo6bM`00oo7c=go`/[Qol;:h@02ol;;h@03o`000?oo
oooooooo01Wooooo0009ooooo`0400000?ooooooooooooooob800000;00I6AT00`000000<c<c03<c
<`0I03<c<`0300000?l00000000000T0000000?o00000000000000005P0c<c<00ol000006ATI01TI
6@0E01TI6@H000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo2?nT
^^T9oj>jj@?oXkWY6?nR^NT2oj6ij@GoXKSY00?oXKOXo`000?l000000onP]NL2oj2diP03oinbiOnN
/>CoWJkS00?oWJkS0_nM[>400onMZMooVjGMoi^SfP02oi^SfP?oW:7H0_nMWmH2oijNd`;oX9gA00?o
WYS>oj6Hc?nQV<`01?nSVL/2ojJJbP03ojVLbOnXV<GoZi[500?oZi[500?o[Yg6ojnJ`_nbWL<00onb
WL<00ondXLCo]Yo1okJO`@02okRS``05okZR`?nmY/?o_JK3okfV`onnZ/H00_o1Zl<01Oo2[lOoaJo5
olF_aOo5[lGo000000;ob;G700Cob;S<ol^jboo;^/_obKg?0oo<`<l3olc4d`05olk7doo9amSobl[I
ol_:fOo6bM`00_o7c=d3ol;;h@03ol;=h_oooooo000001[ooooo0009ooooo`0400000?oooooooooo
ooooob800000:`0I6AT00`000000<c<c03<c<`0F03<c<`@000003`1<C4`3000001@0<c<c00<00000
01TI6@0I6AT0500I6AT6000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0@
ooooo`SoY;[Y2onS^^T00onR^NWoX[[Yoj:jj@03oj:jj@?oX[WY0_nR^^X3oj:ij@GoX[[Z0onR^NT3
oj:ijP;oXKWY0_nQ^>T3o`0000?oX;KX00?oX;GWoijcionN/^H00_nN/^H2oij`i0;oWJkS00?oVj[Q
oiZWgonJYml00onKYMd3oi^SfP;oW:7H00?oWIoFoiZId_nLVM000_nLVM03oijHcP;oXIS<0_nSVL/0
0onRU<KoYIK6ojFFaP03ojRHa@;oZi[500Co[9O2ojnJ`_n_V/;o[i[20_nbWL<01OncVl3o]Yo1okJO
`OnfWl7o^:?300?o^Z;00_nmY/<3ol6[``07olB[`Oo5[lGoaJo5olF_aOo8]LOo0000olRea`03ol^j
b`;oc[g:00Coc<3?olo3c_o?`lkoc<CC0_o>am<3ol_:f@05olg=fOo7c=gob<gNolS=g_o2bn400oo2
cN800ooooooo0000ooooo`0Hooooo`002Oooool01000003ooooooooooooooolR000002X06ATI00<0
000003<c<`0c<c<0500c<c<3000001H0C4a<1000000A03<c<`030000000I6AT06ATI01<06ATI1P00
0004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool4ojBjj@coXk[Y1_nR
^^TAoj:jjP;oX[WZ00?oXKWZoj6ijOl000000_l000001?nQ^>WoXKOYoinfj?nO]^P3oinej0;oW[?W
00?oW[;Voib_iOnK[><00_nK[><3oi^Zh@;oVZOO0_nKYMd2oi^SfP03oiRMeonIVmCoVI_D00?oVYWB
0onLVM02oijHcP03oj6Hc?nOTlSoXYC600?oXYC60_nUU/H00onXV<GoZ9C2ojbG`P03ojbG`P;o[i[2
00Co/Yg3ok>K`?ncVl3o/i_00_nfWl44okZR`004okfV`onoY/3o_jK0ol6[``?oa:_100CoaJo5olRa
`oo8/L?o00000_o<]lH01?o;^/_oc[g:oljmb_o>_LX3olo3cP05om;6coo>am?od<[Dom3:e?o;b]T0
0_o=cMT01?o>cm_ob<gNolS?goo8cml2ol;=hP03ol;>hooooooo000001Wooooo0009ooooo`040000
0?ooooooooooooooob800000:@0I6AT00`000000<c<c03<c<`0B03<c<`<000007@1<C4`00ol00000
<c<c03<c<`0?03<c<`030000000I6AT06ATI01<06ATI1@000004ooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool04_ooool5ojBjj@SoXk[Y1OnR^^TDoj:jjP;oXK[Z0ol000000onQ^NWo
X;SZoj2gj@02oj2gj@?oWkKX00?oWkGXoifcionL/NH00_nL/NH2oib_i@?oVjcS00CoVj[QoiNUgonG
X]coUj;L0onGWmX3oiRMe`;oVI_D0_nJVM82oibId003oiVCc?nLTlWoW9?900?oWi?80onRU<H00onU
U/KoY9;2ojRD`P02ojRD`P?o[9O200?o[i[2ok2H_oncVl000oncVl000onfWl7o^9jnokRN_P02okZR
`004okfR__noY/3o_jK0oknV`0Coa:_10oo8/L<00oo<]lKo0000olbgaP03oljmbP;odL3:00?ocl?>
om;6cooBa/l00oo@b]@01?oBcMGocLgIolk?foo>cm/3olS?g`06olSAhOo2c^?o`LkTol7>i?oooooo
00006?ooool000Wooooo00@00000oooooooooooooooo8P00000X01TI6@03o`00000c<c<0<c<c00l0
<c<c1000000Q04a<C0<000003P0c<c<00ol000006ATI01TI6@0C01TI6@D000001?ooool00`00003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?oY;[YojBkjOnT^nT02_nS^^T00onR^^Wo
X[[Zoj:jjP0Aoj:jjP;oXK[[00GoXK[Zo`000?l0003o0000oj6jj`03oj2ijP;oX;SZ00?oX;OYoijf
jOnN]^T00onN]NP2oifci`03oibai_nJ[^GoVZkU00;oVJ_S0onHZ>42oiNUg`;oUj;L0onGWmX01?nH
WMOoU9ODoiFEdOnEUM42oiNCcPCoVI?<0_nLTlT2oinCb0;oXYC600?oXI33ojBB`_nTT/800onXU<83
ojbG`P?o/9Ro0oncVl03okRN_P04okZR`?nmX[ko_J:nokfR_P;o_jK000?o`ZNnolB[`Oo4Zl400_o7
[L02olRa``05olbc`_o<]lKo0000olnjaOo>_LX00_oA`<X2omC4bP04om;6cooDbLooe<W?om3:e0;o
d/gE00Godm3Folk?foo>dMcoc]7LolS?g`02olSAh@06olOBh_o1c^Co`<oUol3?iOoooooo00005ooo
ool000Wooooo00@00000oooooooooooooooo8P00000W01TI6@030000000c<c<0<c<c00l0<c<c00<0
000004a<C01<C4`09P1<C4`2000000d0<c<c00<0000001TI6@0I6AT04P0I6AT5000000Cooooo00<0
0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`;oY;_Y1_nS^^T5oj>jjPSoX[[Z0onR
^^/3oj:jjPCoXK[[0ol000000onQ^^[oXK[[oj6jj`02oj6jj`03oj2ij_nO^N[oWkSZ00?oWkSZ0_nN
]^T00onN]NSoW;?Xoi^ai`02oi^ai`?oVZkU0_nIZn<01?nHZ>7oU:?Ooi>PgOnCX=d3oi>LfP;oTiWG
0onDUm@2oiFEd@;oUi?>0onITl`2oibCb@03oinCb?nMSlCoXI3300;oXI330onTT/83ojRD`P03ojbG
`_n/U;ko[9Bn00?o/9Ro00?o/i_0okBJ_OndV[d00_nhW[h4okfR_P04oknV`?o2Ykko`ZNnolB[`@?o
ajg000?ob;73olbc`_o</l800_o?^/D00ol0003odkg5om70bP03omC4bP?oe<W?00Koelg@om;=eOoC
d=Kodm3FomCDf?o>dM`2olkDg@05olSAhOo7d^;oam;RolKCi?o0cnD00_nocnH00ol0003ooooooooo
o`0Eooooo`002Oooool01000003ooooooooooooooolR000002H06ATI00<0000003<c<`0c<c<03`0c
<c<00`000000C4a<04a<C00Y04a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT04P0I
6AT4000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`?oXk_Y00?o
Xk[Yoj>kj_nS^nX00onS^nX3oj>jjPGoX[[Z0_nR^n/4oj:jj`CoX[_[00CoXK[[o`000?l0003o0000
0_nQ^n/3oj6jj`04oj2jjonP^N_oX;W[oj2ij`;oWkWZ0_nO^>X01?nN]n[oWKGYoifejOnM]NT2oibc
j003oi^aionH[^KoV:kV00;oUj_T0_nEYn83oiBSg`;oTj3M0onCW=X2oi>Ie`;oU9OD0_nEUM43oiNC
cP04oiVCc?nFSLSoVXk6oiZ>aP?oWHo40onQT<<2ojBB`P;oZ9C200CoZ96nojbD__n/U;ko[9Bn0_n`
V;l01OnaUkco]9ZmokBJ_OndV[go^9jn00;o^Yjl0onmX[h3ol:W_P?oajg000Sobjnoolbc`_o</l;o
c;?2olng`_o?^/Go0000om>ma@?oe<C:0_oHb<X01OoDbLooelg@omWAdOoIdM7odm3F00;oe=CH00Go
eMOIolkDgOo>e]ooc]KOolOBhP02olKCi0?o_loV00?oooooo`000?ooool05Oooool000Wooooo00@0
0000oooooooooooooooo8P00000U01TI6@030000000c<c<0<c<c00h0<c<c00<00000o`00001<C4`0
;01<C4`2000000`0<c<c00<0000001TI6@0I6AT04@0I6AT4000000Cooooo00<00000ooooooooool0
4_ooool00ol0003oooooooooo`0Gooooo`03oj>kjOnS^n[oXk_Z00SoXk_Z00?oX[[Zoj:kj_nR^nX0
0onR^nX2oj:kj`03oj:jjonR^n_oX[_[00;oX[_[0ol00005oj6kj`?oXK[[0_nP^^/00onP^N_oWkW[
oinij`03oijhjP;oW[OZ00?oWKGYoi^cjOnJ/>L00_nJ/>L3oiR^iP;oUj_T0_nEYn801?nDXmooT9kM
ohnJf_n?V]X3ohjFe`;oSi?C0_n@T=02oi6?c@?oThk:0onFSLP2oiZ>aP?oWHo40_nQT<<00onTT/;o
Y8nnojRA_P03ojRA_P;o[9Bn1?naUk`2okBJ_@Co^Yjl00Co_J:noknS_?noXkco`ZNn0_o5ZKd01Oo7
[L3objnool^__oo;[kooc;?200;ockO20_oC_LD00ol0003oel;5omC4bP03omS8bP03omO=d?oIdM7o
fM7A00;of]GC00Goe=CHomGGfOoEfM_oeMWKolkFg`02olgGh@04olKCi?o5dnGoaM?Uoko?iP;o_LoW
00?oooooo`000?ooool05?ooool000Wooooo00@00000oooooooooooooooo8P00000T01TI6@030000
000c<c<0<c<c00h0<c<c00<0000004a<C01<C4`0401<C4`?00000100C4a<00<0000003<c<`0c<c<0
2@0c<c<00`0000006ATI01TI6@0A01TI6@@000001?ooool00`00003oooooooooo`0Booooo`03o`00
0?oooooooooo01Wooooo2?nS^nX6oj:kjPKoX[_[0_l000000onR^n_oXK_[oj6kj`06oj6kj`03oj6j
jonP^^_oWk[[00?oWk[[0_nO^N/00onN^>[oWKOZoibej@02oibej@;oVk?Y00?oV[3WoiN]ionG[NL0
0_nEZ^D2oi>Vh`;oTJ;P0on@W]d2ohnJfP?oSYKG0_n?Tm<2oi2@d0;oTHo=0onCS/X2oiJ=b0;oVXk6
0_nMSl@00onKR/7oWhbooin<_`03ojB?_P?oZ96n00?o[9BnojfC^onaUk`00onaUk`00ondV[go]YZk
okJJ^`02okZN_004okbO^_noXkco_j>loknS_0?oaJVm1?o;[kl3olng`P04om>j`OoC_LGoel;5o`00
00?of<S:00?oflg;omkAc?oIdM400ooJeM<01?oEemWoeMWKomGIfooDg=h2olgGh@;obmSS00CoaM?U
ol?Ci_o3dnKo_LoW0_nlc^P00ol0003oooooooooo`0Cooooo`002Oooool01000003ooooooooooooo
oolR000002<06ATI00?o000003<c<`0c<c<03@0c<c<2000000l0C4a<1000000?06IVIP<000003P1<
C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI01406ATI0`000004ooooo`0300000?oo
oooooooo01;ooooo00?o0000ooooooooool06_ooool8oj>kjP03oj:kj_nR^n_oX[_[00GoX[_[0ol0
0002oj:kj`KoXK_[1?nQ^n`2oj2jj`;oWk[[0_nO^N/2oijhj`;oWKOZ00?oW;GYoiZcjOnH/NP00onH
/NP2oiN]i`;oUJ[U0_nCY^<2oi6Rh0;oT9kM0on?V]X2ohjFe`;oSi?C0_n@T=03oi6?c@04oi>>b_n@
R<OoThS4oi>8a0;oUhW20onKR/43oin<_`?oY8nn00?oZ96nojR?^on]Tk/00_n]Tk/2ok6G_005ok:F
^_nfV[_o]YZkokJJ^onjW[`00onlWkX2oknS_004ol>U^oo5ZKgoaJVmolV[_0?objno00Cock>nolng
`_oC^/7odk[10ooG`/D01Ol0003of<S:om_=booKcL_og]7<00?of]GC00?ofmWEomcMeooEfM/00_oD
g=h01?o=en7obmSSol_Hhoo9fND2ol?CiP03ol7Cj?nlc^So_<kX00;o^/kY00?o0000ooooooooool0
4_ooool000Wooooo00@00000oooooooooooooooo8P00000R01TI6@030000000c<c<0<c<c00d0<c<c
00<0000004a<C01<C4`02`1<C4`4000001H0IVIV0`0000000ol00000C4a<04a<C00904a<C0030000
000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0400I6AT3000000Cooooo00<00000ooooooooool0
4_ooool00ol0003oooooooooo`0Kooooo`CoXk_Z1?nS^n/4oj:kj`?o00001_nR^n/00onQ^n_oXKc/
oj6kk005oj6kk0?oX;_/0_nO^^`00onO^N_oW[W[oifgj`02oifgj`;oVkKZ0_nJ/nT2oiRaj003oiF^
ionCZ^KoTj[V00;oTJKS0_n>XN42ohbLgP?oRiSK0_n9TmL2ohV@d`;oRXg@0_n;R/d3ohf9b@;oT8S7
0_nCR<@3oiN9`P?oVh[10_nOS;l2ojB?_P04ojB<_?nXSk_oZ8nkojR?^`;o[I>k00Co/INlok:F^_nb
U[[o/YJj0_nfV[/4okbO^P04oknS_?o3YK_o`jFkolFY_@?obJ^l00?objnoolnc__o?/kh00ooC^/40
1_oH_l7oel;5om[6a_l0003og/c6om_=b`;og]7<00Ooh=O>om[EdooKfMGofmWEomcMeooKh=[oe=cN
00;od]gP00God=kSolWIiOo7f>OoamSWol7Cj002okkBj@;o^/kY00?o^<gZo`000?ooool04oooool0
00Wooooo00@00000oooooooooooooooo8P00000R01TI6@030000000c<c<0<c<c00`0<c<c00?o0000
04a<C01<C4`02P1<C4`00`00003o000006IVIP0M06IVIP8000002@1<C4`00`000000<c<c03<c<`09
03<c<`030000000I6AT06ATI01006ATI00?o00000000000000001?ooool00`00003oooooooooo`0B
ooooo`03o`000?oooooooooo01cooooo0onS^nX4oj>kj`04oj:kjol0003o0000o`0000GoX[c[0onR
^n/4oj6lk003oj6kk?nQ_>coX;_/00CoX;_/00CoWk_/oijjk?nN^^coW[[/0_nN^N/00onM]n_oVkK[
oiVdjP02oiVdjP?oUk7Y0_nE[^L2oi>ZiP;oTJKS0_n>XN42ohbLgP?oRiSK0_n9TmL2ohV@d`;oRXg@
0_n;R/d3ohf9b@;oT8S70_nCR<@3oiN9`P;oVh[100?oWhbooin9_?nTS;`00_nTS;`3ojR?^`03ojfC
^on^T[Wo/YJj00?o/YJj00?o]YZkokVJ^OniV[T00_nlWkX01?noX;Wo`jFkol>U^oo3YK/4olV[_0?o
ck>n00[odkNnom>j`OoH_l7of;o1omc4`_oJa/Kog/c6o`000?oRdLOog]7<0_oPelh01ooRfm3ofmWE
omcMeooLgMOofn3Jom[Sg?oBgN000_o@g^<01Oo>gnGoamSWolCHj?o4f>So_];Y00;o_=7Z00Co^<gZ
okK;j_nfbn[o00004oooool000Wooooo00@00000oooooooooooooooo8P00000Q01TI6@030000000c
<c<0<c<c00`0<c<c00<0000004a<C01<C4`02@1<C4`200000280IVIV0P00000804a<C0030000000c
<c<0<c<c00T0<c<c00<0000001TI6@0I6AT03`0I6AT3000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Nooooo`04oj>kj_nS_>_oXkc[oj>lj`?o000000?oX[_[oj:ljonR_>/0
1?nR_>/4oj:lk0OoXKc/1?nP^n`2oinkk003oijjk?nM^NcoW;S/00;oW;S/0_nK]^/3oiVdjP04oiNa
jOnD[^SoTJ[Woi6Zi`;oSjGU0_n<XN82ohVKg`?oQiKK0_n5TMP2ohB=e0;oQ8W@0_n5Q/d2ohJ4b@?o
SHW90_n@R<L2oi>8a0;oUhW200?oUHFooiZ7__nJQkh00_nORK`4ojB<_0;oZ8nk0on^T[T3ok:F^P?o
^IZi00Co_9njoknP^OnoX;Wo_j2i0_o3YK/00oo6Yk[obJ^lolV[_002olf_^`03olnc__oC]kkodkNn
00?of;o100Oog<C2omk<a_oNc<Kog/c6o`000?oTelWoh=O>00;oh]_@00?oh^3BomcMeooKh=X00_oJ
hm`01_oHiMood=kSolkOiOo>gnGobmkWolCHj0;o`MKY00Co_=7Zok[?jonjcn_o]/_Z0_ndb^X00ol0
003oooooooooo`0@ooooo`002Oooool01000003ooooooooooooooolS000002006ATI00<0000003<c
<`0c<c<02`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV02@0IVIV00?o000004a<
C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00l06ATI0`000004oooo
o`0300000?oooooooooo017ooooo00?o0000ooooooooool07oooool3o`0000GoXkc[1OnR_>/5oj:l
k0SoXKc/00?oX;_/oinkk?nN^^`00_nN^^`2oifik003oibhk?nK]ncoVkO/00?oVKC[0_nG/NX2oiB^
j0;oTJ[W0_n?YND2ohbQhP;oRI_O0on7U]/2ohFAf0;oQ8gD0_n4RM02ohF6c@04ohJ4bOn9PlKoRH?6
ohV3aP;oSH?40_nAPl43oiF5_`?oVXNn0_nORK`3ojB<_003ojR?^onYS[Wo[Y:i00?o[Y:i00?o/YJj
okBF^?niV[T00_niV[T4oknP^@04ol>U^oo6Yk[oaZNjolV[_0?ocJnk0ooC]kh01_oH_;kof;o1omc4
`_oLa<;oh<[2omk<aP;oh]7700?o0000onOMbooRfm000_oRh=800ooRi=CohNSHom[Sg002omSUg`06
omGUh_o>gnGobmkWol_Nioo7gNWo`MKY0_nne>/01_njcn_o]lk[okO>jondb^[o//S[o`0001;ooooo
0009ooooo`0400000?ooooooooooooooob<000007P0I6AT00`00003o000003<c<`0;03<c<`800000
2P1<C4`00`00003o000006IVIP0<06IVIP0300000?l00000000000P0000000Co0000000000000000
00002`1VIVH2000000P0C4a<00<0000003<c<`0c<c<0200c<c<00ol000006ATI01TI6@0>01TI6@<0
00001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo0ol000000ooooooo
Xkc[oj>lj`06oj>lj`?oX[c[2?nR_>`4oj6lk0?oX;c/0_nO^n`00onN^^coWK[/oifjk003oibhk0;o
VkO/00CoVKC[oiJbjonC[nWoTjoY0on@ZnP2ohfViP03ohVQhon6Vn3oQY_P00?oPiGM0_n0T=T2ogj:
e@;oOXKA0_n4RM02ohF6c@;oQXC90on9PlH2ohf3a0;oTH?10onEQKl2oiZ7_P;oWhVl0_nTS;`01?nT
Rk[oZHjiojV>^OnYS[T2ojjB^@04ok2B^?ndU[So]9JhokBF^0;o^IZi00Co_9bhoknP^OnoX;Wo_j2i
0oo6YkX3olf_^`;od[>k00?odkNnomRl__oH_;h00_oLa<82on3:`P07onC@`ooRdLOoi=O9o`000?oW
gL_oj>?=on;PdP02on;Te003on7Xf?oOjm_of>GO00;oeNGR00KodNGUol_Nioo7gNWoamgYol?Kjonn
e>/2ok_Bj`03okO>jonec>_o]Lc[00;o//S[00?o0000ooooooooool03oooool000Wooooo00@00000
oooooooooooooooo8`00000N01TI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0201<
C4`2000000/0IVIV1000000?07moO`<000002P1VIVH00`000000C4a<04a<C00604a<C0030000000c
<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03P0I6AT3000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Iooooo`?o00001Oooool8oj>lj`WoX[c/00?oXKg/oj6lk?nQ_>`00onQ
_>`00onP_>coWkc]oinlk@02oinkk@03oifjk?nL^NgoW;W]00?oVkO/0_nH]N`2oiJbj`;oTjoY00Co
T:_Xoh^Wion7XNGoQj7U0_n3Vn82ohJKh0?oPiGM0_n0T=T2ogj:e@03ogj6dOmnP/goOX;=00;oOgo9
0on2O/H2ohV3aP;oSH?40onAPl42oiF5_`04oiZ7__nIQ;_oWXNjoij7^PCoY8^j0_nYS[T00on^T[Wo
/9:hok2B^003okBF^003okVJ^OnlW;So_9bh00?o_j2i00Go`j>holJW^_o6Yk[obj^iolf_^`03om:c
^`?of;bn00gogL:nomc4`_oPb/;oh<[2onC@`ooXelCoi=O9onOMbol0003oj>?=onSXcooRi=CohNSH
00;ogn_K00?og>cNomGUh_oAiND00_o=i>P00oo7gNWo`m_[okoHk002ok_Bj`04okS@k?nec>_o]Lc[
ok?:j`?o/LO[00?o0000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo8`00000M
01TI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`01`1<C4`2000000X0IVIV0`00000F
07moO`<00000201VIVH00ol00000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<00000
01TI6@0I6AT03P0I6AT2000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0F
ooooo`?o00002Oooool6oj>lj`;oXkc/1?nR_>`4oj:mk0;oXKg/00?oXKc/oj6lkOnQ_>d00_nP_>d0
0onO_>goWk_]oinkk@03oijkk@;oW;W]00?oVkO/oiVfk?nF/n`00_nF/n`2oi>`j`;oSjcY0_n;YnL2
ohNQi@?oPi_R00?oOiGNogb?fomlSm/00_miRMH2ogR3dP;oOXKA0_mnP/d2ogmob@;oPWk60_n5OL<2
ohUn`@?oSWnn0_nCPKd2oiV4^`?oWXNj0onTRkX00onYS[WoZXjhok2B^003ok2B^0;o]9Jh1?nlW;P0
1?noX;Wo`j>hol>S^?o6YkX2ol^[^@Cod[>k00KoekRkomRl__oM`[kogL:non;8_ooPb/82onC@``0<
onSGa?o[g/Koimg;onSScOl0003oj>S?onO]dOoUl=Gogn_Komc/g_oHkN;odncU0_o=i>P00oo9h^[o
a=o/okoHk002okcEk@05okS@k?nfc^co]/k/ok?:jonab>/00on_aNX00ol0003oooooooooo`0>oooo
o`002Oooool01000003ooooooooooooooolS000001`06ATI00?o000003<c<`0c<c<02P0c<c<00`00
0000C4a<04a<C00704a<C00300000?l00000IVIV00L0IVIV0`00000L07moO`03o`00001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI
00d06ATI0P000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05?ooool2o`00
00gooooo00?oXkc[oj>mjonS_N/00onS_>/2oj>lk003oj:lk?nR_NcoX[g/00GoX[g/0_nQ_N`00onQ
_>goXKg]oj6mk@03oj2lk@;oWk_]00?oW[_]oifjkOnM^^d00_nK^>d2oiVfk004oiJck?nC/NcoSjg[
ohn]j`;oRjSY0on6XnL2oh6Li0;oO9KQ0_mhSmd2ogb?f`;oNHWF00?oN8?BogMoc_mgOlh00_mhO<X3
ogmob@;oPWk60_n5OL<01?n9O/7oSWnnohio__n>Okh2oi>1_@?oVHBk0onNQkX00onTRk[oYHZhojZ>
^002ojZ>^0?o/9:h00?o]9JhokNG]ongUkL00_nlW;P01?noW[Oo`j>hol>S^?o3XkP3ol^[^@03om2_
^OoB/k_od[>k00;oekRk0ooM`[h00ooRb;ooi/noonC@``02onSGa009on_Na_o]iLOoj>?=onSXcol0
003oingAonG`eOoRlmWof>gR00;odncU00Koc^[YolWRj_o4gncoa=o/ol3KkOnleNd2okWBk@03okK>
k?ncbnco/l_/00;o/LS[0_n_aNX00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooo
oooooolS000001/06ATI00<0000003<c<`0c<c<02`0c<c<00ol00000C4a<04a<C00604a<C0030000
001VIVH0IVIV00H0IVIV0P00000P07moO`8000001`1VIVH00`000000C4a<04a<C00504a<C0030000
000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03@0I6AT2000000Cooooo00<00000ooooooooool0
4?ooool00ol0003oooooooooo`0Booooo`?o00004Oooool2oj>mj`03oj>ljonS_NcoXkg/00;oXkg/
1_nR_N`2oj:mk@GoXKg]00?oX;c]oinlkOnO_>d00_nN^nd00onM^^goVkW]oiVgk@02oiVgk@;oU[G]
0_nC/N`2ohn]j`;oRjSY0on6XnL2oh6Li0;oO9KQ00?oN8oMogB8f?mdR=P00_maP]@2ogR3dP;oMgo>
00CoN7c:ogYiaomjNLOoNWW70_mmNL@2ohEm``;oRGk10on>Okh2oi>1_@;oVHBk0_nNQkX00onNQ[Wo
YHZhojF:^003ojZ>^0?o/9:h0ongUkL01?nlW;So_ijgoknN]onoW[L2ol>S^003olNV^?o;ZkWod:ni
00;od:ni00God[>komNh^ooG^;_og;nlomg2_P02on;8_`03onK?_oo[el7oj=O400;ojmk600[okNG7
ong[bOo/lL_o0000onG`eOoRlmWogOCMomWdhOoCk>Goc^[Y0_o9in`01Oo4gnco`=_]okcHk_nlf>ko
^M;]00;o]/o]00?o/l_/ooooooooool00oooool00ol0003oooooooooo`0>ooooo`002Oooool01000
003ooooooooooooooolS000001/06ATI00<0000003<c<`0c<c<02P0c<c<00`000000C4a<04a<C006
04a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl02P1oOgl;000000d0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<00000
01TI6@0I6AT03@0I6AT2000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`?o00005Oooool2oj>mj`GoXkg/1_nR_N`2oj:mk@?oXKg]0_nP_Nd2oinlk@?oWK_]0_nK^Nd0
0onI]ngoUkK]oi>ck@02oi>ck@;oSjo/0on:Zn/2ohFUj@03ognNi_mjUn?oNYOS00;oM8oO0_m_R=/2
ogB8f003og62e?m`O=3oL7c@00;oL7S<0_mhO<X2ogYia`;oOGW40_n1NL42ohIj_P?oSWnn0_nCPKd0
0onIQ;_oV8:joij6^@02oij6^@?oYHZh0onZS[P00on`T[So/Y>gok:C]`02okNG]`Co_ijg00?o`j>h
olNV^?o7Y[P01?o@[kT2omNh^`;og;nl00Ooh/Jlon;8_ooVckooi/noon_G`Oo^gl7ojmk600;okNG7
00KokN_9oncabooYmLgo0000omgdgOoIm>42om?biP06olk_j_o9incoaN?]olGSkOo0g^oo_=S^0_ni
e>h00onfcngoooooooooo`06ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooo
ooooooooob<000006P0I6AT00`000000<c<c03<c<`0:03<c<`030000001<C4`0C4a<00H0C4a<00<0
000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0807moO`<000002`2IVIT4000000X0Ogmo00<0
000006IVIP1VIVH01@1VIVH00ol00000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0
000001TI6@0I6AT0300I6AT2000000Cooooo00<00000ooooooooool04?ooool00ol0003ooooooooo
o`0<ooooo`?o00006?ooool9oj>mk0?oX[g/1?nR_Nd3oj6mk@;oX;g]0_nO_>d00onM^ngoW;[^oibj
kP02oiZikP;oUkK]00?oTk?]oi2bk_n@/^h00_n;[Nd2ohFWj`;oOZ7Y0_mhVNH2ogZGh`;oM8oO00?o
KhSKof^1eom[PML00_maP]@2og1ld004og1hc?maMLSoLGG8og5eb0;oNWW70_mmNL@00on1NL7oQWZn
ohIj_P03ohal_@;oTWnk0onHP[X3oij6^@;oYHZh0_nZS[P01On/S[Oo/Y>gok:C]onbTkOo]iNg00;o
^YZg0onoW[L3olNV^003olb[^?o@[kWod:ni00;oeKFi00CoekRkombo_?oL_kcoh/Jl0_oVckl2on_G
`@0<onkO`Oo`il;okNG7ong[bOo/lL_ojOG=onGhdOoQn]Go0000omKjh?oCl^Koc^oZ0_o9jnd00oo5
hngo`=k_okcJk`02okWDkP[ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooo
oooooooo8`00000J01TI6@030000000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`01P1<C4`00ol0
0000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00@00000o`000000000000004P2IVIT0
1?l00000000000000000000707moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<
C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00`06ATI0P000004ooooo`0300000?oo
oooooooo013ooooo00?o0000ooooooooool02Oooool3o`0001cooooo2OnS_N`2oj:mk003oj:mkOnR
_^goX[k]00;oX[g]0_nQ_Nd3oinmk@;oW[c^00?oW;[^oi^jk_nK^^h00onH^>h2oiBekP;oT;;^0_n;
[Nd2ohFWj`;oOZ7Y0_mhVNH00omaTN?oJhWNof^9gP02ofn8f`03of^1eomXNm;oJ7_B00;oIgK>0_m`
N<`2og5eb0;oM7C40_mmNL@2oh5i`@;oQWZn0_n<O;d2oi9o^`?oV8:j0onNQ[T00onUR[SoYXZgojb>
]`03ojb>]`;o/Y>g1?njV[L01?noW[Oo`j:gol>R]oo7Y[P2olb[^004om2_^OoE]KWoeKFiomFe^@;o
g;nl0_oRa[`00ooWc[goi/noon_G`@02onkO`@0:oo3W`_oak/?okoC3onWecOoUn=7ohO[Eomckf_l0
003oe_[Pom7giP;obN_]0_noh?000onlf^ooooooooooo`0;ooooo`03o`000?oooooooooo00gooooo
0009ooooo`0400000?ooooooooooooooob<000006P0I6AT00`000000<c<c03<c<`0803<c<`030000
001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH0101VIVH00`00003o000007moO`0607moO`030000
002IVIT0VIVI01P0VIVI0P00000607moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00`06ATI0P000004ooooo`030000
0?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`00027ooooo1_nS_N`4oj>nk0;oX[k]
0onQ_^d2oj6mk@04oinmkOnO_NkoWkg^oinmkP;oWKc^0_nK^^h00onH^>koU[O_oi6dk`02oi6dk`;o
S;3^0_n6Znd2ogjTk003ogNMjOm_U>KoKiCV00;oIhcR00?oJhWNofF1f_mUPMX00_mQN]D2ofQkdP04
ofMfc_mXL/WoJ7;9ofQbb@;oLGG800?oM7C4ogQd`_mhM<800_mmMKl3ohIj_P;oS7bm0_nBOk/3oiR2
^P03oij6^OnOQKSoYXZg00;oYXZg0on/S[L00onbTkOo]IFfokZJ]`03okZJ]`?o`j:g00CoajJholb[
^?o<ZkSod[6h0ooE]KT00ooK_;[og;nlon;6_002onO>_@03oncG__o[el7ok]o100;ol>O200SolNk3
onod`ooVo<KohOk:om_ocooEomKoe_[Po`0000;oa^k_00?o`NSaokoPl?ooool03_ooool00ol0003o
ooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolS000001T06ATI00<0000003<c<`0c
<c<0200c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1o
Ogl01@1oOgl2000001d0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP03
0000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0<01TI6@03
00000?oooooooooo00;ooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`?o
00009Oooool00onS_NcoY;k/oj>nk005oj>nk0;oXkk]0_nR_^d4oj6nk@;oX;g]00?oWkg^oijlk_nL
^nh00_nL^nh2oiVjk`;oU[O_00CoTKC_ohjckon8[^ooR:k_0_n0Z>h2ogNQk0;oKYWZ0_m_U>H00omW
S>;oGh;Moen2g@02ofF1fP03of5jeOmNLm3oGW?@00;oIgK>0_mXL/T2ofY_aP;oM7C400?oN7C2ogee
_ommMKl00on3Mkd2ohYj^`;oTWnk0_nHP[X00onHPKWoWhFhoin5^003ojJ:]`?o[8jg0oneUKH2okZJ
]`04okjM]oo3X[Oo`j:gol>R]`?oc:^h0_oB/KP01OoE]KWofkbjom^l^_oQ`k_oh/Jl00;oiljm00oo
k=Nnoo3P__ocj;kol>O2oo7^`oo_m<?oi_c6on7nb_oKolooeOoFom3mg_o<nnKoaoK/o`000?o1j?40
4Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolS000001L06ATI
00<00000o`00000c<c<02@0c<c<00`000000C4a<04a<C00604a<C003o`0000000000IVIV00@0IVIV
00?o00000000001oOgl01@1oOgl2000000T0VIVI00<00000o`000?l000002P00000:09VIV@03o`00
001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000
000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0300I6AT00`00003oooooooooo`02ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo0ol0000Yooooo`;oY;k/1OnS_^`4oj>nk@;o
X[k]0onQ_^d2oj2mkP;oW[c^00?oW;_^oi^kkonK^nl00_nH^Nl2oi>gk`;oS[?_0_n8[^l2oh2XkP;o
Mj7/0_m^VNX01?mTSnKoFhGRoe^5h_mOP]d2oeUjf@;oHG[E00CoGW?@oei_c?mNKlcoGVo<0_mXL/T0
0omZKlKoKFo3ofe_``02ogQd`P;oOGFo0_n3Mkd2ohYj^`;oTGfj0onHPKT3oin5^0?oYXZg00?o[8jg
ojn@]oneUKH00_neUKH01?njV[Oo_YfgokjM]onnWKL2ol>R]`03olRW]oo<ZkSod[6h00;od[6h0ooK
_;X00ooQ`k_oilflonO>_@02oncG_P0>oo3P__ocj;kolo2moo3f^ooSo;Wofofkom?n_oo=olOoaokL
olcki_o7m^co`no`ooooool0000Aooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oo
ooooooooooooob<000005`0I6AT00`000000<c<c03<c<`0903<c<`030000001<C4`0C4a<00D0C4a<
00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI
0`00000=0;>c/`<000001`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00`06ATI
00<00000ooooooooool00_ooool00`00003oooooooooo`0?ooooo`Co0000;_ooool2ojBnk0GoXkk/
0onS_^d2oj:nk@;oXKk]0onO_Nh2oiflkP03oi^kkonJ^nooV[__00;oU[W`0_nA]_02oh^bl0;oPjg`
0_mjY^l2ofnNk@04ofBDj_mHR^KoF8[Voe^5hP;oDW_M00?oFG[IoeEbdomEL]<00_mNLm02oei_c0;o
Gf_80_mZKlH00om]Kl?oLVo0og9_`002ogee_`?oPgNm00CoRWZkoi5m^_nAOK[oTGfj0onHPKT2oin5
^0;oYXZg00CoZ8^gojn@]on_T;Oo[i2g0_neUKH4okjM]`03ol>R]oo8YkOob:Ng00Cod[6h00Sof;Ri
om^l^_oQ`k_ohL>konO=_?o]e[cok=Nnoo3P_P;olnRn00Oolo2mon[j^_oSo;Wofofkom?n_oo7o]co
a?cV00;o`OK^0_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0009oooo
o`0400000?ooooooooooooooob<000005`0I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00D0VIVI0P00000C0;>c/`8000001P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0
IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT0
6ATI00`06ATI00<00000ooooooooool00_ooool00`00003oooooooooo`0?ooooo`;o0000<Oooool2
ojBnk003oj>nk?nT_^coY;k/00;oXkk/0_nS_^d3oj:nk@;oXKk]0onO_Nh2oiflk`03oiZkkonI^o3o
U;W`00;oU;W`0_n>]_42ohNal@;oOZca0_mcY?001?mVVnkoF93[oeR@jomHR^H2odenh@03oe9kgOm;
L]OoBg;G00;oEG;C0_mBK<l2oei_c004oem[b?mRJ/GoHV[5ofe_``;oLVo00omiLKh2oh=g_@;oRWZk
0_nAOKX3oiR1^@03oin5^?nPQ[SoZ8^g00;oZ8^g0on_T;L00oneUKKo^9RgokRH]`03okjM]`?ob:Ng
00?ocZfhom:a^?oB/KP00_oH^;T2on73^`;oilfl00gokMJloo;Q_?o`h;kolnRnoo?`_OoZn[[ohobi
om_m^ooCo[oo^_c<ok_mfonlnnSo`OK^00Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0<ooooo`002Oooool01000003ooooooooooooooolS000001H06ATI00<0000003<c<`0c<c<0
2@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0
101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c01D0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI00<00000ooooooooool0
0_ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo02kooooo1OnT_^`5oj>nk@?oX[k]
0_nQ_^h00onO_NkoW[g^oijmkP02oiblk`;oVK_`00?oU;W`oi:ilOnB^O400on<]O82oh>alP;oNJ[b
00?oK:;aoebHkomHT>/00_m:Q>H00om=O^7o@W?Lod9cg002od]be`;oAf[B00?oDVc?oe9WbomBIl/0
0_mOJlP00omRJ/GoIf[2ofe_``02og9_`0;oNG6n0_n0M;`2ohQh^`?oTGfj0_nHPKT2oj26^0CoZ8^g
0_n_T;L4okRH]`04okjM]oo3X[Oo`j:golRW]`;ocZfh00Ood[6homRh^OoH^;Wof;Riomo1^_oQ`k_o
ilfl00;okMJl00[ol^6looCZ^oocl[SoiOV^om[iZOo>mjOoa?JYok[lc?nkoM_o_?_X1oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
ob<000005P0I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00D0C4a<00?o000006IV
IP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`8000001@2IVIT00`00003o00000000000I0;>c
/`03o`0000000000VIVI00@0VIVI00?o000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0;01TI
6@0300000?oooooooooo00;ooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0^oooo
o`GoY;k/1OnS_^d4oj:nk@03oj6nk_nN_NkoW[g_00;oW[g_0_nK_>l2oiRkl0;oT[Wa00CoS;GbohZe
lon0/??oP;3c0_mcZO<2ofBQlP;oG9S_0om:Q>H2od9cg0;o>V[F00CoAf[BodATc_m4I<koDVO;0_mD
ILL00omRJ/GoIf[2ofMZ`P02og9_`0;oNG6n0_n0M;`2ohQh^`?oT7bj0_nHPKT3oj26^0?oZ8^g00?o
[i2gok:C]onhV;L00onhV;L3ol>R]`?ocZfh0ooH^;T2omo1^P03onK;^ooWcKcokMJl00;ol^6l00Oo
m>Zkoo?b^?oUnJkof_VYolCfZOnZmlSo/?_M00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolS000001H06ATI00<0000003<c<`0c
<c<0200c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1o
Ogl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00P0/k>c2`0000090;>c/`03
0000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP03
0000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0;01TI6@03
00000?oooooooooo00;ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0^ooooo`Go
Y;k/00CoXkk]ojBokOnT_ngoY;o]0_nS_^d3oj:nk@;oX;k^0_nN_Nl3oi^ll0;oUk_a0_nA^O82ohZe
l`;oP;3c0_mcZO<2ofBQlP04oe:El?lmQn_o?HO[ocUmi@;o:6oN00_o;f_JocYZe_leH]7oAf[BodAT
c_m5H<WoDVO;oeAUaomII<CoHV[5ofMZ`P03ofe/`0;oNG6n0_n0M;`01?n8N;_oT7bjoi1l^_n@O;X3
oiR1^@;oX8Jh0_nXRkL01?nZS[So/Y>gok:C]onbTkL2okRH]`;o_Ifh0_o3X[L01Oo9Z;SocZfholj]
^?oD];Wof;Ri00?ogl6j00[oi/^kongF_?o]e[col^6looCZ^oocl[SoiOV^om[iZOn[iXgoSnN^3?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooo
ooooooooob<000005@0I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<0
00000;>c/`2c/k<01P2c/k<3000000/0c<c<0`0000070;>c/`030000002IVIT0VIVI0080VIVI00<0
000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@0300000?oooooooooo00;ooooo00<0
0000ooooooooool05?ooool2o`00033ooooo0onT_^`2ojBok0?oY;o]0_nS_nd3oj:nk@;oX;k^0_nN
_Nl00onK_?3oVkg`oi^ml002oiJkl@;oT;Wb0_n8]O@2ogf`m0;oKjWe0_mMWo<01_m7To3o?HO[ocf7
jolWMn?o:6oNoaQQe`;o9F3D00Go=F;AodATc_m4I<koAF39oeAUa`02oeUTa0;oIf[20_m]K<02ogA^
_P;oP7Bl0_n8N;/3oi1l^P;oV86i00?oX8Jhoj:8^?nZS[P00_nZS[P3ok:C]`05okRH]onmWKSo_Ifh
okfM^?o3X[L00_o9Z;P01?o>[KSoe;BiomBd^OoL_[/2omo1^P;oi/^k00SokMJloo;Q_?obhKcom>Zk
oo?b^?o:l9Ko^>Z?ohoW[Pkooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`002Oooool01000003ooooooooooooooolS000001@06ATI00<0000003<c<`0c<c<01`0c<c<00ol0
0000000004a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl00`1oOgl00`00
0000VIVI09VIV@0309VIV@03o`0000000000/k>c00D0/k>c00?o00000000000000004@3<c<`00ol0
0000/k>c0;>c/`050;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`00
0000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`00
00006ATI01TI6@0:01TI6@0300000?oooooooooo00;ooooo00<00000ooooooooool05_ooool00ol0
003oooooooooo`0^ooooo`03ojBnk?nU_ncoYKo/00;oY;o/0onT_nd2oj>ok@03oj:nkOnR_ngoX;k^
00;oX;k^0_nN_^l00onK_O3oV[g`oiZml002oiJkl@;oSkWc0_n6]_@2ogZamP;oJjWf0_mFWo@02?lm
TO3o;X;Yoa9_h?lBKn3o4FKJoaQQeolUH=Co7eO?0_lbG<`01?m5H<WoB5k6oeAUaomII<@2oemU`P?o
KFc000?oM6jnogeb_?mmL[`00_n6Mk/3oi1l^P03oiR1^OnIP[WoXXRh00;oXXRh0onZS[P2ok:C]`Co
_Ifh0oo9Z;P3omBd^@;og;jk00Wogl6jonK;^oo]e[cokMJloo;Q_?oek;WoloBdomcfXOo:l9H04Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooo
ooooooooob<00000500I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00?o
000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<0
00000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c00C0<c<c0030000002c/k<0/k>c00@0/k>c00<0
000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV00<0
000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI00<0
0000ooooooooool00_ooool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo0onU
_n`2ojBok003ojBokOnT_ncoXko]00;oXko]0_nR_nd3oj2nkP;oW[k_0onJ_O02oiJllP;oSk[c0_n5
]oD2ogVbm`;oJ:_g0_mAWoD01OldT>oo7gkWoa9_h?l0Fm?o05GA00;o2eG@00Go7eO?oc9Lc?lcF<Wo
AF39odQNaP02oeUTa004oemU`_mWJ<3oIfS0ofMX`0;oM6jn00?oOG:lohIg^on6Mk/00on@OKX2oiV2
^@?oXXRh0onZS[P00onbTkOo]YNhokJG^003okfM^005ol>S^Oo9Z;SobJRholn`^_oD];T00ooL_[/0
0ooTbKcoi/^kongF_002oo;Q_003ooG/^OoZn:_ob_2F01?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolS000001@06ATI00<00000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<00000
0<c<c03<c<`05@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@0300000?oooooooooo00;ooooo00<00000
ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`GoYKo/0_nT_n`3oj>ok@;oX[o]00?oX;k^
oj6ok_nQ_nh00_nN_^l00onJ_O3oVkk`oi^nl002oiJmlP;oSk_d0_n5^?H2ogRcn0;oIZch0_m>XOH0
2ol^TNoo4G_To`1Xf_l0Fm?o05GAo`]Ed?l3Bl[o757:oc9Lc?lcF<WoB5k600;oCEo40_mOIL82ofMX
`0;oL6fo0_mmL[`2ohIg^`;oT7fj0onIP[T3oj:8^003ojZ>^?n^TKWo]YNh00?o]YNh00Co_Ifhol>S
^Oo3XkWobJRh0_o?/;X3ombn^`;oi<Vl00KojmFmongF_?obhKcomNbion[hZonbhX0Dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo
8`00000C01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`030;>c/`800000203<c<`8o`0000T0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI
09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02P0I6AT00`00003ooooo
ooooo`02ooooo`0300000?oooooooooo01Wooooo0_l0000_ooooo`GoYKo/0_nT_n`01OnS_ngoY;o]
ojBokOnT_ngoX[o]00CoXKo^00?oW[k_oi^nl?nK__000_nK__000onG_O;oT;cdoi2lm002ohJim`;o
NKGh0_mW[oT2odfTm`0<obbCkol7N^7o06;Bo`1@b?l0AlKo04O7o`=;b_lLDL[o<eS9ocQGa_m8G/Ko
CEo40_mEHL<2ofMX`0;oL6fo0_mjL[h2ohIg^`?oT7fj0_nIP[T2oj:8^004ojB;^_n^TKWo[Y6iojjA
^@;o]YNh00Co^ifjol>S^Oo3XkWo`j>i0oo?/;X00ooG^[cog;jkonC9_002onC9_006on_E_Oobhkgo
m>njooG/^Oo<ki7o/^:05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
0009ooooo`0400000?ooooooooooooooob<000004`0I6AT00`000000<c<c03<c<`0603<c<`030000
001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000
002IVIT0VIVI0080VIVI00<00000o`00002c/k<00`2c/k<2000000L0c<c<0ol000080>KViPCo0000
1P3<c<`00ol00000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0206IVIP03o`0000000000C4a<00<0C4a<00<0000003<c<`0c<c<0
1@0c<c<00`0000006ATI01TI6@0:01TI6@0300000?oooooooooo00;ooooo00<00000ooooooooool0
6oooool00ol0003oooooooooo`0^ooooo`GoYKo/0_nT_n`3ojBok@;oXko]0onQ_nh2oinok`03oi^n
l?nL__3oW;k`00;oV;kb0_nA_O@2ohRkm`03og^gnOmY/O[oJK7j00;oD:Sh00Oo;IS`o`9kg_l0GLWo
04Fjo`0h]Ol0>koo04G500;o7Dk700?o>5O6odeOa?m=Gl@00_mEHL<2ofMX`003og1]_omjL[koNW:n
00?oQGRm0_n@OKX00onIP[WoVXFkojB;^P02ojB;^P?o[Y6i00Co]YNhok^M^_nkWK[o^ifj0_o3XkT0
1?o9Zkcock2jomNj_?oG^[`3onC9_0;ojmFm00Col^>mooC_^_oRmj?o/^:05oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooob<00000
4`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0
0P1VIVH00ol00000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0
0`2c/k<00`000000c<c<0<c<c0050<c<c0;o00003`3Vi^H00ol00000c<c<0<c<c0040<c<c0030000
002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0503<c<`030000
000I6AT06ATI00X06ATI00<00000ooooooooool00_ooool00`00003oooooooooo`0Looooo`03o`00
0?oooooooooo02kooooo1onU_n`3ojBok@;oXko]00?oXKo^oj:ok_nR_nh00_nO_nl00onL__3oWKo`
oifol002oiVnlP;oTkkd0_n:_?L00omn^_WoPkcioh>ln@02og>hn`09oefbnoldW_?o=9kco`1N_ol0
9:;o03^oo`15aOlMC/Oo8To600?o?eW500?oEF73oemV`_mOI/800_m`KKl2ogYb_P;oQGRm0_n@O[`3
oiZ5^`?oY8^j0_n^TKT4ok^M^P04ol>S^Oo9ZkcobJ^loln`^P;oekZl00Soh<JoonC9_?o[eKgojmFm
oo;S_Oodkk[oh_NSo`0001Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`002Oooool01000003ooooooooooooooolS000001806ATI00<0000003<c<`0c<c<01P0c<c<00`00
0000C4a<04a<C00504a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`00
0000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`2o`00
0180i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0:01TI6@0300000?oooooooooo
00;ooooo00<00000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`;oY[o[00?oYKo/ojJo
k?nV_n`00_nU_n`00onT_ngoY;o/ojBok002oj>ok@?oX[o^0_nP_nl00onM_o3oW[o`oijol002oiZo
lP;oUKkd00?oSKkfoi6om_nA_oH00_n7__T2ogZln`;oIkOl00OoC:kioaJAi_l09:;o03Bjo`12`olM
C/Oo8To600;o?eW500?oBEg5oeEQ`omOI/800_mZJl42ogYb_P?oQGRm0_n@O[`2oiZ5^`?oY8^j00?o
[Y6iok:G_?nbUk`00_nkWKX01?o1Y[gobJ^lolV[_?o9Zk`2omNj_0;oh<Jo00KojMC1on_E_Oobhkgo
m>njoo3f/Onehh0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wo
oooo00@00000oooooooooooooooo8`00000A01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<
C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VI
V@2IVIT00`2IVIT00ol00000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KV
iP3Vi^H04`3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00D0000009VI
V@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`0
0`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00X06ATI00<00000ooooooooool00_ooool0
0`00003oooooooooo`0Nooooo`;o0000;oooool2ojJoj`?oY[o/0_nU_n`00onT_ncoYKo/ojFok002
ojBok@03oj:ok_nS_ngoXko]00;oXKo^00?oW[o`oinokonO_nl00_nL_o42oiNol`03oi6om_nD`?Go
U<3e00;oS;oh0_n1__/2og6lo@;oFkKl00Co?:_eo`0d^_l0@/?o8To60_l[D/H01OloFLGoBEg5oemV
`_mOI/;oJV_100?oMg;10_n5N;d2oi1n_0?oVXFk00?oY8^jojR@_OnbUk`00_nbUk`01?nkWK[o`JJm
ol6V_Oo1Y[d2olV[_009om6f_ooG^[coh<Joon36_ooYe<7ol>C1oo;b_?o[nK3oeO>J01cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooo
oolS000001406ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c
/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP0D0>KViP03o`00003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo
00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c
00<0000001TI6@0I6AT02P0I6AT00`00003oooooooooo`02ooooo`0300000?oooooooooo023ooooo
00?o0000ooooooooool0;Oooool2ojJoj`03ojJok?nV_n_oY[o[00;oY[o/0onU_n`2ojBok@03oj>o
kOnT_ngoY;o]00;oX[o^00?oWko_oj70konQ`>l00_nN`?000onJ`?;oW<3boic0lP02oiO1m0;oTL7g
0_n8`OX00oml_ocoQL;kohG2n`02ogS1o@;o036h00Co14?3ob]Ba_l[D/KoBEg50_mEHlD01?mZJl7o
Mg;1ogMb`OmgL/42ohAj`0;oT8:o0onMRKh3ojR@_@;o/YNl1?o1Y[d01Oo9ZkcodKJoom6f_ooK`l;o
h<Jo00;ojMC100Col>C1oo;b_?o[nK3o00007Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`0400000?ooooooooooooooob<000004@0I6AT00`000000<c<c03<c
<`0703<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<
c0040<c<c003o`00003Vi^H0i^KV01D0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c
/`020;>c/`050000002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV06IVIP0206IVIP030000
001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0:01TI6@030000
0?oooooooooo00;ooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0^ooooo`CoY[o[
0_nV_n`00onU_ncoY[o/ojJok002ojFok0?oY;o]0_nS_nh00onQ`>ooX/3^oj;0kP02oio0l003oic0
l_nN`O7oW/7a00;oV/7c0_nF`_D00on?`_SoU<?goiC3m`02ohg3n@;oQ<Cl0_l0<KP01ol4@l?o:e;6
ocQHaom9GLGoEF?5of=[aOmZJl400_mgL/42ohAj`0;oT8:o1?nMRKh2ojR@_@03ok:G_?nhWkoo^9no
00?o`JJm0ooA][l01ooK`l;oi=?5onWD`Oo`i<7ol_:lon_i/?nFd6`07oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooob<000004@0I
6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c
/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00L0i^KV1ol000080>KViP03o`00003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo
00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT02P0I6AT00`00003oooooooooo`02ooooo`0300000?oooooooooo02;ooooo00?o0000oooooooo
ool0;_ooool2ojNoj`05ojJojonW_n_oYko[ojJojonV_n`00_nV_n/2ojFok003ojBokOnU_ncoYKo/
00;oY;o]00?oX/3^oj?0k_nS`>h00_nQ`>l00onN`O7oX<7`oj31l002oig1l@03oiW2m?oooooooooo
00Oooooo00Go03:jo`m8a_l[D/Ko>5S7oeESa@02of=[a@?oMg;10_n4N/02oi22_`?oWHVn00?oZ92m
ojfH`OnhWkl00onhWkl01?o1Y[gobK72olVa`_oA][l2om_3`P05onCCaOo]i/Ool>C1oo;b_?o1kI00
8?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oo
ooooooooooooob<00000400I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0020<c<c0;o00001`3Vi^H3o`0000L0oooo
0_l000070>KViP03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00P2c/k<01@000000VIVI
09VIV@2IVIT0000000@0Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT02P0I6AT00`00003oooooooooo`02ooooo`0300000?oooooooooo
02?ooooo00?o0000ooooooooool0;_ooool7ojNoj`?oY[o[00CoY[o/ojFok?nU_ncoYKo/0_nT_nd0
0onS`>koY<3]ojC0k@02oj;0kP03oj31l?oooooooooo00cooooo00Ko03:jo`m8a_lhF<OoAf79oeES
aOmSJlD3og9da@;oQ7[00_n@P[l2oif9_P04oj2@`on]V<7o[IS1ojfH`@;o^9no00Ko_j[5olVa`_o9
/L;obK72om>oa_oK`l82onCCa@03ongVaoo_m/7oh_Z`02;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolS000001006ATI00<00000
03<c<`0c<c<01`0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00?o0000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00D00000
0<c<c03<c<`0c<c<o`0000070>KViP;o0000303oool00ol00000i^KV0>KViP040>KViP03o`00003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo
00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT02P0I6AT00`00003oooooooooo`02ooooo`0300000?oooooooooo02Cooooo0_l0000_ooooo`Oo
Yko[00?oY[o[ojNojonW_n/00_nV_n/01OnU_ncoY[o/ojJok?nU_ncoY<3]01?ooooo00Co03ZooaiA
bOlhF<OoAf790_mSJlD2og9da@;oPWg50_nAQl@4oj2@``;o[IS100Go^9nooknZaOnoZ/Go_j[5olVa
`P02om>oaP06omkAc?oTdlGokNK7ongVaoo_m/7o00008oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooob<00000400I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH01@000000
Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0020<c<
c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV0>KViP040>KV
iP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0
000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT2000000Cooooo00<00000ooooooooool09_ooool0
0ol0003oooooooooo`0]ooooo`;oYkoZ00?oYko[ojNoj_nW_nX01onW_n/00onV_ncoooooooooo`0E
ooooo`04o`0j_olNDLWoAf79odMQb@;oFFc;0_mbM<D2oh9ma@;oTHO40onPT<<00on]V<7o/j?8oknZ
a@02oknZa@09olVic?oC_lKodko6om>oa_oNdLcoinO?ongVaoo_m/7oY>2502Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolS0000
01006ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c
0080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo
00l0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c
0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<00000
04a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI0P000004
ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool2ojRojP03ojNoj_nX_n[o
Z;oZ00;oYkoZ00?oYko[ooooooooool06_ooool01Ol0A/Oo<Uk>oc9Nc_lbG/koFFc;00;oKGO<0_n2
OLD3oi67a003oj2@`onTVL[o/j?800;o/j?800Go_j[5olVic?o9^LcobKW<om>oaP02omkAc003onOW
cooXn/[odo^a02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Ooo
ool01000003ooooooooooooooolS000001006ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<
04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0209VIV@050000002c/k<0/k>c0;>c/ol000001@3<c<`00ol00000i^KV0>KViP040>KViP03
o`00003oool0oooo00l0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0020<c<c005
0000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI
00T06ATI0P000004ooooo`0300000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool2ojRn
jP03ojRoj_oooooooooo01oooooo00Ko04K7oc9Nc_lbG/koBFgCoeU/bom]Ml`2oh23c@?oTho<0onT
VLX2ok>Sb006ok^bd?o9^LcobKW<olVic?oDc]Cog]7<0_oWill00ooXn/[oooooooooo`0Vooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooo
oooo8`00000@01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0306IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c/`020;>c
/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0@0?oo
o`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0
000000<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@8000001?ooool0
0`00003oooooooooo`0Yooooo`;o0000;Oooool00ol0003oooooooooo`0Rooooo`04o`0a/ol@Em7o
<Uk>odU]d`;oKGO<0_n0Pld3oi>?c0;oY9W:00Go/j?8ok^bd?nk/]3o^k;@olVic002omC>e003omkW
f_oWilooj?[:02[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Ooo
ool01000003ooooooooooooooolR00000003o`00000I6AT06ATI00d06ATI00<0000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl0
0P1oOgl00`000000VIVI09VIV@0209VIV@050000002c/k<0/k>c0;>c/`0000001@3<c<`00ol00000
i^KV0>KViP040>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000
c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207mo
O`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0
6ATI00T06ATI0P000004ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Sooooo`03ogT00?l@Em7oBFgC00;oHggG0on0Pld2oi>?c003ojBIb_nZZ=Go
^k;@00;o^k;@0_o5b=`01?oDc]Cog^OJomkWf_oLoMD[ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo8`00000?01TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<
00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0B0?ooo`03o`00003Vi^H0i^KV00<0i^KV
00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00<0000007moO`1o
Ogl00P1oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0901TI6@8000001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool09Oooool00ol0AlCo;VgLof=me`03ogf=f@;oUIcH0onZZ=D00onk
/]3oaLSLolG8g002olkUi`03omkWf_oLoMGooooo02cooooo00Go0000ooooooooooooooooo`00000;
ooooo`002Oooool01000003ooooooooooooooolS000000l06ATI00<0000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl0
1@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KV
iP040>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<
c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`050000
001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T0
6ATI0P000004ooooo`0300000?oooooooooo02gooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Vooooo`03o`1VfOmAQNGoDHGU00?oOHgI0_nEW=P01?nZZ=Go/KkTok6ni?o5b=`2olkU
i`;oaogS;oooool01?l0003oooooooooool0000;ooooo`002Oooool01000003ooooooooooooooolT
000000h06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@050000002c/k<0
/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo01<0oooo00?o
00000>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0
VIVI0000000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000
<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI0`000004ooooo`0300000?oooooooooo02ko
oooo0_l0000Xooooo`03o`000?oooooooooo02Oooooo00?o06KIoe65iOmAQND00_meW>T3oiJ`j@04
ok6ni?negOCo]MgdolkUi`;oaogS<Oooool00ol0003oooooo`00000;ooooo`002Oooool01000003o
oooooooooooooolT000000h06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VI
V@050000002c/k<0/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0
oooo01<0oooo00?o00000>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<co000000@0/k>c00D0
000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI0`000004ooooo`030000
0?oooooooooo033ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Yooooo`?o;8_]
00GoH:ojoiJ`jOn@c?coT<clokGMm002oj?dkc?ooooo00?o0000ooooool000002oooool000Wooooo
00@00000oooooooooooooooo9000000>01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT01Ol00000/k>c0;>c/`2c/k<0000000D0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol0
0000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00<0i^KV00Go00000<c<c03<c<`0c<c<00000004
0;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@03o`000000
0000000000Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02gooooo0_lVZn800om[fO7oooooooooo`0eooooo`03o`000?oooooo000000[ooooo0009
ooooo`0400000?ooooooooooooooob@000003P0I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>c000000050<c<c003o`00003Vi^H0i^KV00<0i^KV
00?o00000?ooo`3oool04P3oool00ol00000i^KV0>KViP040>KViP05o`00003<c<`0c<c<0<c<c000
0000102c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`00
0000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT30000
00Cooooo00<00000ooooooooool0<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06Sooooo0_l0000:ooooo`002Oooool01000003ooooooooooooooolT000000h06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007mo
O`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<c<`0
0ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H00`3Vi^H0
1Ol00000c<c<0<c<c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000
001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000
000I6AT06ATI00P06ATI10000004ooooo`0300000?oooooooooo03?ooooo0_l0000Sooooo`03o`00
0?oooooooooo06Oooooo0ol0000:ooooo`002Oooool01000003ooooooooooooooolT000000h06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV
00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<
c<`00`3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3V
i^H0103Vi^H01Ol00000c<c<0<c<c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0VIVI00000004
07moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0403<c<`030000000I
6AT06ATI00P06ATI10000004ooooo`0300000?oooooooooo03Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1Sooooo`Co00003Oooool000Wooooo00@00000oooooooooooooooo9000
000>01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000
003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00
003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`050000
002IVIT0VIVI09VIV@000000101oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@@000001?ooool00`00003oooooooooo`0foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`04
00000?ooooooooooooooobD000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI
0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV
00@0i^KV00?o00000?ooo`3oool03P3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<
0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00D00000
06IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I
6AT5000000Cooooo00<00000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo05cooooo1?l0000Dooooo`002Oooool01000003ooooooooooooooolU000000d06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c0080/k>c00<0
00000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP050>KViP03o`00003oool0oooo00`0oooo0_l0
00060>KViP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VI
V@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000
000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT5000000Cooooo00<00000ooooooooool0
>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001Sooooo0009ooooo`0400000?oo
ooooooooooooobD000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00H0i^KV
00?o00000?ooo`3oool02P3oool00ol00000i^KV0>KViP060>KViP03o`00003<c<`0c<c<0080c<c<
00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1V
IVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT0200I6AT5000000Cooooo00<00000ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05Cooooo1?l0000Looooo`002Oooool01000003ooooooooooooooolU000000d0
6ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080
IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080
/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP060>KViP?o00001P3oool3o`0000P0
i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VI
V@000000101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@D000001?ooool00`00003oooooooooo`0koooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`00023ooooo0009ooooo`04
00000?ooooooooooooooobH000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI
0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV
00T0i^KV1_l0000:0>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@00
0000VIVI09VIV@2IVIT0000000@0Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C003o`00000c
<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT6000000Cooooo00<00000ooooooooool0??oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0000Sooooo`002Oooool0
1000003ooooooooooooooolV000000d06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<
C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VI
V@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KV
iP0F0>KViP;o00001@3<c<`00`000000/k>c0;>c/`020;>c/`05o`00002IVIT0VIVI09VIV@000000
101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
100c<c<00ol000006ATI01TI6@0801TI6@H000001?ooool00`00003oooooooooo`0mooooo`;o0000
6Oooool00ol0003oooooooooo`19ooooo`Co00009oooool000Wooooo00@00000oooooooooooooooo
9P00000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT00P2IVIT00`000000/k>c
0;>c/`020;>c/`03o`00003<c<`0c<c<00@0c<c<0_l0000D0>KViP;o00001P3<c<`00`000000/k>c
0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0801TI6@H000001?ooool00`00003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0AOooool4o`0002_ooooo0009ooooo`0400000?ooooooooooooooobH00000
3@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH01@000000Ogmo07moO`1oOgl0000000D0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000
c<c<0<c<c0050<c<c003o`00003Vi^H0i^KV0100i^KV00?o00000<c<c03<c<`01@3<c<`00`000000
/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0801TI6@L000001?ooool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@oooool3o`0002oooooo0009ooooo`0400000?ooooooooooooooobD0
000000?o000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0
C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080
VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c003o`00003Vi^H0i^KV00d0
i^KV0_l000070<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`00003o
000007moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI00?o000000000000000010000004ooooo`03
00000?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co
0000<_ooool000Wooooo00@00000oooooooooooooooo9`00000=01TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080
Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0
c<c<0ol000090>KViP?o0000203<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@L000001?ooool00`00003o
ooooooooo`12ooooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool000Wooooo
00@00000oooooooooooooooo9`00000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00L0c<c<2Ol0000:0<c<c003
0000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`03
0000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`03
0000000I6AT06ATI00T06ATI1`000004ooooo`0300000?oooooooooo04Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0gooooo`Co0000>_ooool000Wooooo00@00000oooooooooooo
oooo:000000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000
/k>c0;>c/`040;>c/`030000003<c<`0c<c<01L0c<c<0P0000050;>c/`030000002IVIT0VIVI00<0
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00?o000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@P000001?ooool00`00003o
ooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0003ko
oooo0009ooooo`0400000?ooooooooooooooobP00000300I6AT00`000000<c<c03<c<`0603<c<`03
0000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`03
0000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`00003o00000000000D0<c<c080
00001@2c/k<2000000@0VIVI00<00000o`00001oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP03
o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00ol00000000001TI6@0:01TI6@P0
00001?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0<?ooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooobP00000300I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000
Ogmo07moO`0407moO`03o`00002IVIT0VIVI00<0VIVI00?o00000000002c/k<01P2c/k<200000100
c<c<0P0000050;>c/`8000001@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV0080
IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00X0
6ATI20000004ooooo`0300000?oooooooooo04Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0/ooooo`Co0000AOooool000Wooooo00@00000oooooooooooooooo:@00000<01TI6@03
0000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP03
0000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`060;>c/`<0
00002@3<c<`4000000H0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03
0000000I6AT06ATI00X06ATI2@000004ooooo`0300000?oooooooooo04Sooooo0_l0000=ooooo`03
o`000?oooooooooo02Sooooo1?l00019ooooo`002Oooool01000003ooooooooooooooolY000000d0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00P0
/k>c2@0000080;>c/`8000001P2IVIT00ol00000Ogmo07moO`0307moO`0300000?l00000IVIV00<0
IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T0
6ATI2P000004ooooo`0300000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`Co0000COooool000Wooooo00@00000oooooooooooooooo:@00000=01TI6@03
0000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP03
o`00001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT0102IVIT00ol0000000000000000F0;>c/`80
00001`2IVIT2000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT:000000Cooooo00<00000oooooooo
ool0Boooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001Aooooo`00
2Oooool01000003ooooooooooooooolZ000000d06ATI00<0000003<c<`0c<c<01@0c<c<00`000000
C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl01@1oOgl00`000000
VIVI09VIV@0609VIV@8000004P2c/k<2000000L0VIVI0P00000507moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T0
6ATI2`000004ooooo`0300000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`Co0000E?ooool000Wooooo00@00000oooooooooooooooo:@0000000ol00000
6ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01`2IVIT2000000h0
/k>c00?o00000000002IVIT01`2IVIT00ol00000Ogmo07moO`0407moO`03o`00001VIVH0IVIV00@0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00X0
6ATI2`000004ooooo`0300000?oooooooooo04gooooo0_l00008ooooo`03o`000?oooooooooo01Wo
oooo1?l0001Hooooo`002Oooool01000003ooooooooooooooolZ000000d06ATI00<0000003<c<`0c
<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00<0IVIV0P00000607moO`80
00002@2IVIT>000000P0VIVI0P00000607moO`8000001@1VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT02@0I6AT<000000Cooooo00<00000oooooooo
ool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0001Looooo`00
2Oooool01000003ooooooooooooooolZ000000d06ATI00<0000003<c<`0c<c<01`0c<c<00`000000
C4a<04a<C00504a<C003o`00001VIVH0IVIV00@0IVIV0P00000607moO`8000006P2IVIT3000000L0
Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0
<c<c00<0000001TI6@0I6AT02@0I6AT=000000Cooooo00<00000ooooooooool0D?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Pooooo`002Oooool01000003ooooo
ooooooooool[000000d06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00504a<C003
0000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01@1oOgl3000001D0VIVI00?o00000000001o
Ogl01`1oOgl2000000D0IVIV0P00000604a<C003o`00000c<c<0<c<c00D0<c<c00<0000001TI6@0I
6AT02@0I6AT>000000Cooooo00<00000ooooooooool0DOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo1?l0001Sooooo`002Oooool01000003oooooooooooooool/000000d0
6ATI00<0000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0
IVIV0P00000807moO`<000003@2IVIT5000000P0Ogmo0P00000606IVIP030000001<C4`0C4a<00D0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000000000/0
00001?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co
0000Ioooool000Wooooo00@00000oooooooooooooooo;000000>01TI6@030000000c<c<0<c<c00H0
<c<c00<0000004a<C01<C4`01P1<C4`00ol00000000006IVIP0606IVIP030000001oOgl0Ogmo00P0
Ogmo3@00000;07moO`8000001`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0
<c<c00?o000001TI6@0I6AT02P0I6AT>000000Cooooo00<00000ooooooooool0E?ooool01?l0003o
ooooooooool00008ooooo`Co0000Joooool000Wooooo00@00000oooooooooooooooo;@00000>01TI
6@03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0506IV
IP<000007P1oOgl00`000000IVIV06IVIP0506IVIP8000001`1<C4`00`000000<c<c03<c<`0603<c
<`030000000I6AT06ATI00X06ATI3`000004ooooo`0300000?oooooooooo05Gooooo00?o0000oooo
ool000001Oooool3o`0006oooooo0009ooooo`0400000?ooooooooooooooobh000003P0I6AT00`00
0000<c<c03<c<`0603<c<`0300000?l00000C4a<00L0C4a<00<0000006IVIP1VIVH01`1VIVH20000
01P0Ogmo00Co000000000000000000001`1VIVH00ol00000C4a<04a<C00504a<C00300000?l00000
<c<c00L0<c<c00<0000001TI6@0I6AT02P0I6AT@000000Cooooo00<00000ooooooooool0E_ooool2
o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooooooo;P00000>
01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`01P1<C4`00ol00000000006IVIP07
06IVIP03o`0000000000000001@0Ogmo0P00000906IVIP800000201<C4`00`000000<c<c03<c<`06
03<c<`030000000I6AT06ATI00/06ATI40000004ooooo`0300000?oooooooooo05Oooooo0_l0001f
ooooo`002Oooool01000003oooooooooooooool_000000h06ATI00<0000003<c<`0c<c<0200c<c<0
0`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00P0IVIV1`00000607moO`L000002@1VIVH2
000000T0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6A4000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool`000000h06ATI00?o0000
03<c<`0c<c<0200c<c<00`000000C4a<04a<C00704a<C08000003`1VIVH6000000h0IVIV0P000009
04a<C0800000200c<c<00`0000006ATI01TI6@0;01TI6A8000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003oooooooooooooool`00000003o`00000I6AT06ATI00`06ATI0P000009
03<c<`03o`0000000000C4a<00P0C4a<00<00000o`00000000007@1VIVH200000003o`00001<C4`0
C4a<00L0C4a<0P00000903<c<`030000000I6AT06ATI00/06ATI4`000004ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?oooooooooooooooc8000003`0I6AT00`000000<c<c03<c<`08
03<c<`8000002P1<C4`2000001T0IVIV0P00000:04a<C08000002@0c<c<00`00003o000001TI6@0<
01TI6A@000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooolc
000000l06ATI00?o000003<c<`0c<c<02@0c<c<2000000X0C4a<1P00000=06IVIPH000002`1<C4`0
0`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00`06ATI5@000004ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?oooooooooooooooc@000003`0I6AT00`000000<c<c03<c<`0:
03<c<`8000003P1<C4`=000000h0C4a<0P0000000ol00000<c<c03<c<`0803<c<`030000000I6AT0
6ATI00`06ATI00?o00000000000000004`000004ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?oooooooooooooooc@00000400I6AT00`000000<c<c03<c<`0;03<c<`030000001<C4`0
C4a<02D0C4a<00<0000003<c<`0c<c<02@0c<c<00`00003o000001TI6@0>01TI6AH000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooole000001006ATI0P00000<
03<c<`<000008P1<C4`2000000/0<c<c00<0000001TI6@0I6AT03P0I6ATG000000Cooooo00<00000
ooooooooool0coooool000Wooooo00@00000oooooooooooooooo=P00000A01TI6@030000000c<c<0
<c<c00`0<c<c0`00000K04a<C0@00000300c<c<00`0000006ATI01TI6@0>01TI6AP000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooolf00000003o`00000I6AT0
6ATI00l06ATI00?o00000000000000003P0c<c<01000003o000000000000000D04a<C0<000003P0c
<c<00`00003o000001TI6@0?01TI6@03o`0000000000000001H000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooooli000001806ATI00<0000003<c<`0c<c<03`0c
<c<D000000h0<c<c0`00000A01TI6AX000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooolj000001806ATI0P00000`03<c<`030000000I6AT06ATI01006ATI7000
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooc/000004`0I
6AT00`000000<c<c03<c<`0[03<c<`03o`00000000006ATI01406ATI7@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo0<oooooo0009oooookH00000dOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool000Wooooo]_l0000AoooookKo00002_ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0LOooool?o`00oc;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo06gooooo1?l00?l?ooooo`Wo003o:Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0JOooool010000?oo003oo`00ool00?lLooooo`;o003o9oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0I_ooool30000ob;ooooo0_l00?lUooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0I?ooool5000004Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
I?ooool20000obOooooo0_l00?lSooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
FOooool900000003o`000000003ooooo00Cooooo00<00000o`00000000001`00000oooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06;ooooo0P000?l[ooooo`;o003o8Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Kooooo0`00000Jooooo`@00000>ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Pooooo`80003o;oooool3
o`00oakooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Booooo`@000008Oooool3
000003Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0G_ooool20000
ocCooooo0_l00?lLooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool20000
0003o`000000003ooooo02Oooooo0P0000000ol000000000ooooo`0cooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03Gooooo60000?l@ooooo`030000oooooooooooo03Ko
oooo0_l00?lJooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Boooool30000033o
oooo0P00000booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo033ooooo
1@000?lHooooo`<0003o2oooool20000oc_ooooo00?o003oooooooooool05oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Sooooo0`00000eooooo`800000<?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0]ooooo`<0003o8?ooool30000o`Oooooo00<0
003oooooooooool0??ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0Aoooool00`00003oooooooooo`0hooooo`800000;_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Zooooo`<0003o9_ooool20000o`Cooooo00<0003o
ooooooooool0?_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0AOooool2000003gooooo0`00000[ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo02Sooooo0P000?l[ooooo`80003o00?o003o0000ooooool0@Oooool00ol0
0?ooooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool20000
04;ooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Uooooo`<0003o;_ooool30000od?ooooo00?o003oooooooooool04oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo047ooooo0P000015ooooo`0300000?oooooooooo02Oo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08oooool20000oc3ooooo
00@0003ooooooooooooooooo0`000?m1ooooo`;o003o4oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03oooooo00?o000000000?ooool0Aoooool00`00003o00000000000Vooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo0P000?laooooo`030000
oooooooooooo00Gooooo0P000?m1ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0nooooo`800000C?ooool00`00003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023ooooo00<0003oooooooooool0<?oo
ool00`000?ooooooooooo`08ooooo`80003o@?ooool00ol00?ooooooooooo`0?ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool2000004oooooo00<00000ooooooooool08_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Oooooo`030000ool00?oo
oooo037ooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0mooooo`03o`00oooooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo053ooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Mooooo`80003o<oooool00`000?ooooooooooo`0<ooooo`80003o?_ooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00`00
003oooooooooo`1Booooo`0300000?oooooooooo023ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool07?ooool00`000?ooooooooooo`0booooo`030000oooooooooooo00oo
oooo00<0003oooooooooool0??ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0>Oooool00`00003oooooooooo`1Dooooo`03o`000000003ooooo01oo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool20000ocCooooo
00<0003oooooooooool04Oooool00`000?ooooooooooo`0looooo`03o`00oooooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`800000FOooool00`00003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo00<0
003oooooooooool0<?ooool30?nf`@030000o`3o]/40okK101<0okK100<0003oooooooooool0??oo
ool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_oo
ool00`00003oooooooooo`0CoooooaT0okK1;_ooool00`00003oooooooooo`0Looooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Sooooo00<0003oooooooooool0;_ooool5
0?nf`@03o`00o`3o]/40okK101D0okK100<0003o0?nf`Oooool0>oooool00ol00?ooooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00`00003oooooooooo`0A
oooooal0okK1;?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Oooooo00<0003oooooooooool0;?ooool80?nf`@030000o`3o]/40okK1
01H0okK100@0003o0?nf`@3o]/40okK1>_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=?ooool00`00003oooooooooo`0?ooooobD0okK1:Oooool0
0`00003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01Kooooo00<0003oooooooooool0:_ooool:0?nf`@030000o`3o]/40okK101P0okK100<0003o0?nf
`@3o]/400`3o]/4hooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0cooooo`0300000?oooooooooo00gooooo:`3o]/4Wooooo`0300000?oooooooooo
01[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05Oooool00`000?oo
ooooooooo`0Xooooo``0okK100<0003o0?nf`@3o]/406P3o]/400`000?l0okK10?nf`@050?nf`CKo
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo0P00000=oooooc40okK19Oooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01Cooooo00<0003oooooooooool09_ooool>0?nf`@030000
o`3o]/40okK101`0okK100<0003o0?nf`@3o]/401`3o]/4cooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`0300000?oooooooooo00[ooooo
=`3o]/4Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool05?ooool00`000?ooooooooooo`0Soooooa40okK100<0003o0?nf`@3o]/407@3o
]/400`000?l0okK10?nf`@070?nf`C;ooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo033ooooo00<00000ooooooooool01ooooolk0?nf`B?ooooo00<0
0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0C
ooooo`030000oooooooooooo02?ooooo4@3o]/400`000?l0okK10?nf`@0O0?nf`@030000o`3o]/40
okK100L0okK1<_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0;oooool00`00003oooooooooo`07ooooocd0okK18oooool00`00003oooooooooo`0F
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo017ooooo0P000?lToooo
oa80okK100<0003o0?nf`@3o]/408@3o]/400`000?l0okK10?nf`@090?nf`C3ooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00<00000oooo
ooooool01Ooooom20?nf`B3ooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0@ooooo`030000oooooooooooo02;ooooo503o]/400ol00?l0
okK10?nf`@0R0?nf`@03o`00o`3o]/40okK100X0okK1;oooool00ol00?ooooooooooo`05ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;_ooool00`00003oooooooooo`04ooooodH0
okK17oooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo013ooooo00<0003oooooooooool08OoooolE0?nf`@030000o`3o]/40okK102<0okK1
00<0003o0?nf`@3o]/402P3o]/4^ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00CoooooB03o]/4Oooooo`030000
0?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03ooo
ool00`000?ooooooooooo`0QoooooaD0okK100<0003o0?nf`@3o]/40903o]/400`000?l0okK10?nf
`@0;0?nf`Bgooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02cooooo00<00000ooooooooool01?oooom:0?nf`Akooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0>ooooo`030000oooooooo
oooo027ooooo5P3o]/400`000?l0okK10?nf`@0U0?nf`@030000o`3o]/40okK100/0okK1;Oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool0
0`00003oooooooooo`04oooood`0okK17Oooool00`00003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00kooooo00<0003oooooooooool07ooooolH0?nf
`@030000o`3o]/40okK102D0okK100<0003o0?nf`@3o]/403@3o]/4[ooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`0300000?oooooooooo
00?oooooD03o]/4Looooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool03Oooool00`000?ooooooooooo`0OoooooaP0okK100<0003o0?nf`@3o
]/409`3o]/400`000?l0okK10?nf`@0=0?nf`B_ooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00ooooomB0?nf`Aco
oooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0=ooooo`030000oooooooooooo01kooooo6@3o]/400`000?l0okK10?nf`@0W0?nf`@030000
o`3o]/40okK100h0okK1:_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool00`00003oooooooooo`02oooooe@0okK16oooool00`00003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00cooooo00<0
003oooooooooool07_oooolI0?nf`@030000o`3o]/40okK102T0okK100<0003o0?nf`@3o]/403P3o
]/4Yooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Yooooo`0400000?oooooooooooooooeH0okK16oooool00`00003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool07_oo
oolJ0?nf`@030000o`3o]/40okK102X0okK100<0003o0?nf`@3o]/403P3o]/4Yooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`0400000?oo
oooooooooooooeP0okK16_ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool07OoooolK0?nf`@030000o`3o
]/40okK102X0okK100<0003o0?nf`@3o]/403`3o]/4Xooooo`03o`00oooooooooooo00;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Wooooo`0400000?oooooooooooooooeX0okK1
6_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00[ooooo00<0003oooooooooool07OoooolK0?nf`@030000o`3o]/40okK102`0okK100<0
003o0?nf`@3o]/403P3o]/4Xooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Wooooo`0300000?oooooooooo05/0okK16_ooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00[ooooo00<0003o
ooooooooool07OoooolK0?nf`@030000o`3o]/40okK102`0okK100<0003o0?nf`@3o]/403`3o]/4W
ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0V
ooooo`0400000?oooooooooooooooe`0okK16_ooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00<0003oooooooooool07OoooolL
0?nf`@030000o`3o]/40okK102d0okK100<0003o0?nf`@3o]/403`3o]/4Vooooo`03o`00oooooooo
oooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo05h0okK16Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Wooooo00<0003oooooooooool07?oooolM0?nf`@030000o`3o]/40okK1
02d0okK100<0003o0?nf`@3o]/40403o]/4Vooooo`05o`00ooooooooooooooooool000004Oooool0
0ol0003oooooooooo`0Vooooo`0300000?ooool0okK105l0okK16Oooool00`00003oooooooooo`0>
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Sooooo00<0003ooooo
ooooool07?oooolM0?nf`@030000o`3o]/40okK102l0okK100<0003o0?nf`@3o]/40403o]/4Uoooo
o`05o`00ooooooooooooooooool000004Oooool00ol0003oooooooooo`0Vooooo`030000003o]/40
okK10600okK16?ooool00`00003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Sooooo00<0003oooooooooool06ooooolN0?nf`@030000o`3o]/40okK1
02l0okK100<0003o0?nf`@3o]/40403o]/4Uooooo`05o`00ooooooooooooooooool000004Oooool0
0ol0003oooooooooo`0Uooooo`030000003o]/40okK10640okK16Oooool00`00003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00<0003ooooo
ooooool07?oooolN0?nf`@030000o`3o]/40okK10300okK100<0003o0?nf`@3o]/40403o]/4Toooo
o`05o`00ooooooooooooooooool000004Oooool00ol0003oooooooooo`0Tooooo`0300000?ooool0
okK106<0okK16?ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Oooooo00<0003oooooooooool06ooooolO0?nf`@030000o`3o]/40okK1
0300okK100<0003o0?nf`@3o]/404@3o]/4Tooooo`04o`00ooooooooooooo`00017ooooo00?o0000
ooooooooool09?ooool00`000000okK10?nf`@1T0?nf`AOooooo00<00000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`030000oooooooooooo
01[ooooo803o]/400`000?l0okK10?nf`@0`0?nf`@030000o`3o]/40okK10140okK19?ooool01?l0
0?ooooooooooool0000Aooooo`03o`000?oooooooooo02Cooooo00<000000?nf`@3o]/40I03o]/4G
ooooo`0300000?oooooooooo00gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool01_ooool00`000?ooooooooooo`0Kooooob00okK100<0003o0?nf`@3o]/40<@3o]/400`00
0?l0okK10?nf`@0A0?nf`B?ooooo00Co003ooooooooooooo00004Oooool00ol0003oooooooooo`0S
ooooo`030000003o]/40okK106H0okK15oooool00`00003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo00<0003oooooooooool06_oooolQ0?nf
`@030000o`3o]/40okK10340okK100<0003o0?nf`@3o]/404@3o]/4Sooooo`04o`00oooooooooooo
o`00017ooooo00?o0000ooooooooool08oooool00`000000okK10?nf`@1V0?nf`AOooooo00<00000
ooooooooool03?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06oooo
o`030000oooooooooooo01[ooooo8@3o]/400`000?l0okK10?nf`@0a0?nf`@030000o`3o]/40okK1
0180okK18_ooool01?l00?ooooooooooool0000Aooooo`03o`000?oooooooooo02?ooooo00<00000
0?nf`@3o]/40I`3o]/4Fooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0Jooooob40okK100<0003o0?nf
`@3o]/40<P3o]/43000001<0okK18Oooool01?l00?ooooooooooool0000Aooooo`03o`000?oooooo
oooo02;ooooo00?o00000?nf`@3o]/40J@3o]/4Fooooo`0300000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0Ioooo
ob80okK100<0003o0?nf`@3o]/40<@3o]/4500000180okK18Oooool01?l00?ooooooooooool0000A
ooooo`03o`000?oooooooooo027ooooo00<0okK10000003o]/40JP3o]/4Gooooo`0300000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`00
0?ooooooooooo`0Iooooob80okK100<0003o0?nf`@3o]/40<@3o]/45000001<0okK18?ooool01?l0
0?ooooooooooool0000Aooooo`03o`000?oooooooooo027ooooo00<0okK10000003o]/40J`3o]/4F
ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool01Oooool00`000?ooooooooooo`0Hooooob<0okK100<0003o0?nf`@3o]/40<@3o]/450000
01<0okK18?ooool01?l00?ooooooooooool0000Aooooo`03o`000?oooooooooo023ooooo0P3o]/40
0`000000okK10?nf`@1Z0?nf`AKooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000oooooooooooo01Sooooo8`3o]/400`00
0?l0okK10?nf`@0b0?nf`@<000005@3o]/4Oooooo`04o`00ooooooooooooo`00017ooooo00?o0000
ooooooooool08?ooool00`3o]/4000000?nf`@1]0?nf`AGooooo00<00000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000oooooooooooo
01Sooooo9@3o]/400`000?l0okK10?nf`@0c0?nf`@030000o`3o]/40okK101@0okK17_ooool01?l0
0?ooooooooooool0000Aooooo`03o`000?oooooooooo01oooooo0P3o]/400`000000okK10?nf`@14
0?nf`A8000005`3o]/4Eooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0GooooobH0okK100<0003o0?nf
`@3o]/40<`3o]/400`000?l0okK10?nf`@0D0?nf`Akooooo00Co003ooooooooooooo00004Oooool0
0ol0003oooooooooo`0Nooooo`<0okK100<000000?nf`@3o]/40@03o]/4400000180okK11000000C
0?nf`AGooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`04ooooo`030000oooooooooooo01Oooooo9P3o]/400`000?l0okK10?nf`@0c0?nf
`@030000o`3o]/40okK101D0okK17Oooool01?l00?ooooooooooool0000Aooooo`03o`000?oooooo
oooo01kooooo0`3o]/400`000000okK10?nf`@0m0?nf`@<000006P3o]/4300000140okK15Oooool0
0`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00Cooooo00<0003oooooooooool05_oooolW0?nf`@030000o`3o]/40okK103<0okK100<0003o0?nf
`@3o]/405@3o]/4Mooooo`04o`00ooooooooooooo`00017ooooo00?o0000ooooooooool07Oooool4
0?nf`@030000003o]/40okK103/0okK100?o00000000003o]/407`3o]/400`000000okK10?nf`@0>
0?nf`AGooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`04ooooo`030000oooooooooooo01Kooooo9`3o]/400`000?l0okK10?nf`@0=0?nf
`@L0oooo803o]/400`000?l0okK10?nf`@0D0?nf`Agooooo00Co003ooooooooooooo00004Oooool0
0ol0003oooooooooo`0Mooooo`@0okK100<000000?nf`@3o]/40<03o]/470?ooo`80okK10`00000R
0?nf`@03o`0000000000000000d0okK15Oooool00`00003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0003oooooooooool05_oooolW0?nf
`@030000o`3o]/40okK100T0okK13`3ooolL0?nf`@030000o`3o]/40okK101D0okK17?ooool01?l0
0?ooooooooooool0000Aooooo`03o`000?oooooooooo01gooooo103o]/400`000000okK10?nf`@0/
0?nf`@X0oooo0`0000020?ooobH0okK10P00000<0?nf`ACooooo00<00000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000oooooooooooo
01Gooooo:03o]/400`000?l0okK10?nf`@070?nf`A<0oooo6P3o]/400`000?l0okK10?nf`@0E0?nf
`Acooooo00Co003ooooooooooooo00004Oooool00ol0003oooooooooo`0Looooo`D0okK100<00000
0?nf`@3o]/40:P3o]/4;0?ooo`030000003oool0oooo00D0oooo9P3o]/400`000000okK10?nf`@09
0?nf`AGooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`04ooooo`030000oooooooooooo01Gooooo:03o]/400`000?l0okK10?nf`@050?nf
`AL0oooo603o]/400`000?l0okK10?nf`@0E0?nf`Acooooo00Co003ooooooooooooo00004Oooool0
0ol0003oooooooooo`0Looooo`D0okK100<000000?nf`@3o]/40:03o]/4;0?ooo`0300000?l00000
oooo00T0oooo9@3o]/400`00003o0000000000080?nf`AGooooo00<00000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000oooooooooooo
01Gooooo8P3o]/43000000@0okK100<0003o0?nf`@3o]/400`3o]/4J0?oooaH0okK100<0003o0?nf
`@3o]/405P3o]/4Kooooo`04o`00ooooooooooooo`00017ooooo00?o0000ooooooooool07?ooool5
0?nf`@030000003o]/40okK102L0okK12`3oool00`000000oooo0?ooo`0<0?ooobH0okK100<00000
0?nf`@3o]/401P3o]/4Dooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool00oooool00`000?ooooooooooo`0Eooooob80okK11@0000030?nf
`@030000o`3o]/40okK10080okK1703ooolE0?nf`@030000o`3o]/40okK101H0okK16_ooool01Ol0
0?oooooooooooooooooo0000017ooooo00?o0000ooooooooool06oooool60?nf`@030000003o]/40
okK102H0okK12`3oool00`000000oooo0?ooo`0>0?ooobH0okK100<000000?nf`@3o]/401@3o]/4E
ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool00oooool00`000?ooooooooooo`0Eooooob80okK11@0000030?nf`@040000o`3o]/40okK1
0?nf`Ah0oooo503o]/400`000?l0okK10?nf`@0F0?nf`A[ooooo00Go003oooooooooooooooooo`00
000Aooooo`03o`000?oooooooooo01_ooooo1P3o]/400`000000okK10?nf`@0U0?nf`@X0oooo00<0
0000o`00003oool04@3ooolV0?nf`@030000003o]/40okK100@0okK15Oooool00`00003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo00<0003o
ooooooooool05OoooolR0?nf`@D000000`3o]/400`000?l0okK10?nf`@0P0?oooa<0okK100<0003o
0?nf`@3o]/405P3o]/4Jooooo`05o`00ooooooooooooooooool000004Oooool00ol0003ooooooooo
o`0Kooooo`H0okK100<000000?nf`@3o]/40903o]/4:0?ooo`030000003oool0oooo01<0oooo9P3o
]/400`000000okK10?nf`@030?nf`AGooooo00<00000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`03ooooo`030000oooooooooooo01Gooooo8`3o]/43
000000@0okK100<0003o0?nf`@3o]/40803ooolC0?nf`@030000o`3o]/40okK101H0okK16_ooool0
1Ol00?oooooooooooooooooo0000017ooooo00?o0000ooooooooool06oooool60?nf`@030000003o
]/40okK102@0okK12@3oool00`000000oooo0?ooo`0D0?ooobL0okK100<000000?nf`@3o]/400P3o
]/4Eooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool00oooool00`000?ooooooooooo`0Eooooob/0okK100<0003o0?ooo`3oool0803ooolB
0?nf`@030000o`3o]/40okK101H0okK16Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06oooool60?nf`@030000003o]/40okK10280okK12P3oool0
0ol00000oooo0?ooo`0F0?ooo`H0okK12000000I0?nf`@040000003o]/40okK10?nf`AKooooo00<0
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04
ooooo`030000oooooooooooo01Cooooo:P3o]/400`3oool0003o0?ooo`0R0?oooa40okK100<0003o
0?nf`@3o]/405`3o]/4Hooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Kooooo`H0okK100<000000?nf`@3o]/408@3o]/4:0?ooo`030000003oool0
oooo01P0oooo00D0okK100000?l0003o0000000000080?nf`@03o`0000000000000000@000004`3o
]/401?l00000okK10?nf`@3o]/4Eooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0Cooooob/0okK10P3o
ool00`000?l0oooo0?ooo`0P0?oooa40okK100<0003o0?nf`@3o]/405`3o]/4Gooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`L0okK100<0
00000?nf`@3o]/408@3o]/490?ooo`030000003oool0oooo01@0oooo1P00000C0?nf`@8000004P3o
]/400`000000okK10?nf`@0Eooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0CooooobX0okK10`3oool0
0`000?l0oooo0?ooo`0Q0?oooa00okK100<0003o0?nf`@3o]/405`3o]/4Gooooo`03o`00oooooooo
oooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`L0okK100<00000
0?nf`@3o]/40803o]/480?ooo`8000005@3oool2000000H0oooo5@3o]/4200000140okK100<00000
0?nf`Oooool05Oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Cooooo00<0003oooooooooool04ooooolZ0?nf`@@0oooo00<0003o0?oo
o`3oool0803oool@0?nf`@030000o`3o]/40okK101L0okK15_ooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool70?nf`@030000003o]/40okK1
0200okK11`3oool00`000000oooo0?ooo`0B0?ooo`0300000?l00000000000P0oooo5`3o]/400ol0
000000000000000?0?nf`@0300000?oooooooooo01Cooooo00<00000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000oooooooooooo01?o
oooo:@3o]/450?ooo`030000o`3oool0oooo0240oooo3P3o]/400`000?l0okK10?nf`@0H0?nf`AKo
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo1`3o]/400`000000okK10?nf`@0O0?nf`@L0oooo00<000000?ooo`3oool04@3oool2000000`0
oooo6@3o]/400`000000okK10?nf`@0<0?nf`@0300000?oooooooooo01Cooooo00<00000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000
oooooooooooo01?ooooo:@3o]/450?ooo`030000o`3oool0oooo0240oooo3P3o]/400`000?l0okK1
0?nf`@0H0?nf`AGooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01[ooooo1`3o]/400`000000okK10?nf`@0O0?nf`@H0oooo00<000000?ooo`3oool0
403oool2000000h0oooo6P3o]/42000000d0okK100<00000ooooooooool04oooool00`00003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0
003oooooooooool04ooooolY0?nf`@H0oooo00<0003o0?ooo`3oool0803oool>0?nf`@030000o`3o
]/40okK101P0okK15Oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06_ooool70?nf`@030000003o]/40okK101l0okK11P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00h0oooo703o]/400`000000okK10?nf`@0:0?nf`@03ooooo`00
003ooooo01Cooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`04ooooo`030000oooooooooooo01?ooooo:@3o]/460?ooo`030000o`3oool0
oooo0200oooo3P3o]/400`000?l0okK10?nf`@0H0?nf`AGooooo00?o003oooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo1`3o]/400`000000okK10?nf`@0O
0?nf`@D0oooo00<000000?ooo`3oool03P3oool00`00003o00000?ooo`0@0?ooo`H0okK11@00000B
0?nf`@8000002P3o]/42ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`030000oooooooooooo
01?ooooo:03o]/470?ooo`030000o`3oool0oooo0240oooo3@3o]/400`000?l0okK10?nf`@0H0?nf
`ACooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01[ooooo1`3o]/400`000000okK10?nf`@0N0?nf`@D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0@0?ooo`L000001@3o]/4300000140okK100<000000?nf`@3o]/401`3o]/42oooo
o`0300000?oooooooooo01;ooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`05ooooo`030000oooooooooooo01;ooooo:03o]/470?ooo`03
0000o`3oool0oooo0240oooo303o]/400`000?l0okK10?nf`@0I0?nf`ACooooo00?o003ooooooooo
ool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo1`3o]/400`000000
okK10?nf`@0N0?nf`@@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`<0
00000P3oool=0?nf`@@000003P3o]/400`000000okK10?nf`@060?nf`@?ooooo00<00000oooooooo
ool04Oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00Gooooo00<0003oooooooooool04OoooolY0?nf`@P0oooo00<0003o0?ooo`3oool0
803oool<0?nf`@030000o`3o]/40okK101T0okK15?ooool00ol00?ooooooooooo`06ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06Oooool80?nf`@030000003o]/40okK101h0okK1
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0`0000050?oooa40okK1
0P00000=0?nf`@03o`00003o]/40okK100D0okK10oooool00`00003oooooooooo`0Aooooo`030000
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Ooo
ool00`000?ooooooooooo`0AooooobT0okK12@3oool00`000?l0oooo0?ooo`0O0?ooo``0okK100<0
003o0?nf`@3o]/406@3o]/4Cooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Iooooo`P0okK100<000000?nf`@3o]/407P3o]/430?ooo`030000003o
ool0oooo00`0oooo00?o00000000003oool02P3oool4000000P0oooo4`3o]/44000000T0okK100<0
00000?nf`@3o]/401@3o]/44ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000oooooooo
oooo017ooooo:@3o]/490?ooo`030000o`3oool0oooo01l0oooo303o]/400`000?l0okK10?nf`@0I
0?nf`A;ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Wooooo203o]/400`000000okK10?nf`@0N0?nf`@80oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo5`3o]/400`000000okK10?nf`@07
0?nf`@030000003o]/40okK100@0okK11Oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`00
0?ooooooooooo`0AooooobT0okK12P3oool00`000?l0oooo0?ooo`0N0?ooo`@0okK11ol00?l00`00
0?oo003oo`00o`04o`00oaH0okK14_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06Oooool90?nf`@030000003o]/40okK101d0okK100<0oooo0000
003oool03@3oool00`000000oooo0?ooo`090?ooo`8000003@3ooolH0?nf`@030000003o]/40okK1
00L0okK100<000000?nf`@3o]/400`3o]/46ooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`03
0000oooooooooooo017ooooo:03o]/4;0?ooo`030000o`3oool0oooo01d0oooo1?l00?l70?nf`@03
o`00o`3o]/40okK100@0okK10_l00?lD0?nf`A7ooooo00?o003oooooooooool02Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo203o]/400`000000okK10?nf`@0M0?nf`@03
0000003oool0oooo00/0oooo00?o00000000003oool02@3oool2000000d0oooo3`00000<0?nf`@03
0000003o]/40okK100L0okK100<000000?nf`@3o]/400P3o]/46ooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`06ooooo`030000oooooooooooo017ooooo:03o]/4<0?ooo`030000o`3oool0oooo01X0oooo
0_l00?l;0?nf`@030000o`3o]/40okK100H0okK10ol00?lA0?nf`A3ooooo00?o003oooooooooool0
2_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo203o]/400`000000okK1
0?nf`@0M0?nf`@030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool2000000`0oooo
0`0000020?ooo`d0okK1100000090?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40
0P3o]/46ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo017ooooo:@3o
]/4;0?ooo`030000o`3oool0oooo01P0oooo0_l00?l00`3oool0okK10?nf`@0:0?nf`@030000o`3o
]/40okK100T0okK100?o003o0?nf`@3o]/403P3o]/4?ooooo`03o`00oooooooooooo00_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`P0okK100<000000?nf`@3o]/40703o
]/400`000000okK10?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool3000000@0oooo4P3o]/42000000P0okK100<000000?nf`@3o]/401P3o]/4010000000okK10?nf
`@3o]/47ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`030000oooooooooooo013ooooo:@3o
]/4<0?ooo`030000o`3oool0oooo01D0oooo0_l00?l30?ooo`/0okK100<0003o0?nf`@3o]/402`3o
]/400ol00?l0okK10?nf`@0=0?nf`@kooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo203o]/400`000000okK10?nf`@0K0?nf`@030000003o
]/40okK100/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`8000001`3o
oolD0?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401P3o]/400`000000okK10?nf
`@07ooooo`0300000?oooooooooo00oooooo00D00000ooooooooooooooooo`00000:ooooo`002Ooo
ool00ol0003oooooooooo`07ooooo`030000oooooooooooo013ooooo:@3o]/4=0?ooo`030000o`3o
ool0oooo01<0oooo00?o003o0?ooo`3oool00`3oool;0?nf`@030000o`3o]/40okK100`0okK100?o
003o0?nf`@3o]/40303o]/4=ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`P0okK100<000000?nf`@3o]/406P3o]/401?l00000okK10?nf
`@3o]/4:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000T0oooo
5@3o]/400ol0000000000?nf`@060?nf`@8000001`3o]/400ol00000okK1ooooo`07ooooo`030000
0?oooooooooo00kooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003ooooo
ooooo`07ooooo`030000oooooooooooo013ooooo:@3o]/4>0?ooo`030000o`3oool0oooo0140oooo
00?o003o0?ooo`3oool0103oool;0?nf`@030000o`3o]/40okK100d0okK100?o003o0?nf`@3o]/40
2`3o]/4=ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Jooooo`P0okK100<000000?nf`@3o]/406P3o]/4010000000okK10?nf`@3o]/490?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`<0
okK12000000<0?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`00003o
ooooooooo`06ooooo`0300000?oooooooooo00kooooo00D00000ooooooooooooooooo`00000:oooo
o`002Oooool00ol0003oooooooooo`08ooooo`030000oooooooooooo00oooooo:P3o]/4>0?ooo`03
0000o`3oool0oooo0100oooo00?o003o0?ooo`3oool00`3oool;0?nf`@030000o`3o]/40okK100l0
okK100?o003o0?nf`@3o]/402P3o]/4;ooooo`;o003o4?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01[ooooo203o]/400`000000okK10?nf`@0I0?nf`@030000003o]/40okK100<0
okK11`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`L0
0000203o]/43000000X0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03
00000?oooooooooo00Oooooo00<00000ooooooooool03Oooool01@00003ooooooooooooooooo0000
00[ooooo0009ooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool03ooooolZ0?nf`@l0
oooo00?o003o0?ooo`3oool03`3oool00ol00?l0oooo0?ooo`030?ooo`/0okK100<0003o0?nf`@3o
]/40403o]/400ol00?l0okK10?nf`@090?nf`@[ooooo00?o003oooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo203o]/400`000000okK10?nf`@0H0?nf`@03
0000003o]/40okK100@0okK11P3oool00`000000oooo0?ooo`060?ooo`03o`0000000000oooo00H0
oooo0P0000090?ooo`040000003oool0oooo0?ooo`l0okK100<00000o`0000000000203o]/400ol0
000000000?nf`@050?nf`@030000003o]/40okK100D0okK100<00000ooooooooool01_ooool00`00
003oooooooooo`0=ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000oooo
ooooool02Oooool00`000?ooooooooooo`0>ooooob/0okK13`3oool00`000?l0oooo0?ooo`0=0?oo
o`03o`00o`3oool0oooo00<0oooo2`3o]/400`000?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK1
00P0okK12Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool80?nf`@030000003o]/40okK101P0okK100<000000?nf`@3o]/401@3o]/440?oo
o`03o`00003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00ol00000oooo0?ooo`060?oo
o`80000000Co00000?ooo`3oool0oooo4`3o]/400`000000okK10?nf`@060?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/401@3o]/400`00003oooooooooo`06ooooo`0300000?oooooo
oooo00gooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0:
ooooo`030000oooooooooooo00kooooo;03o]/4>0?ooo`030000o`3oool0oooo00/0oooo00?o003o
0?ooo`3oool0103oool;0?nf`@030000o`3o]/40okK101<0okK100?o003o0?nf`@3o]/401`3o]/48
ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0K
ooooo`L0okK100<000000?nf`@3o]/405`3o]/400`000000okK10?nf`@080?nf`@80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P000006
0?oooa@0okK10P0000070?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/40
0oooool00000ooooo`06ooooo`0300000?oooooooooo00gooooo00D00000ooooooooooooooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`0:ooooo`030000oooooooooooo00kooooo;03o]/4?
0?ooo`030000o`3oool0oooo00X0oooo00?o003o0?ooo`3oool00`3oool<0?nf`@030000o`3o]/40
okK101<0okK100?o003o0?nf`@3o]/401P3o]/49ooooo`03o`00oooooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Kooooo`L0okK100<000000?nf`@3o]/405P3o]/40
0ol00000okK10?nf`@090?nf`@030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo1P3o]/47000000X0okK100<00000
0?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK10_ooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00cooooo00D00000ooooooooooooooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo00gooooo;@3o]/4?
0?ooo`80003o2@3oool00ol00?l0oooo0?ooo`030?ooo`/0okK100<0003oo`00o`3o]/405@3o]/40
0ol00?l0okK10?nf`@060?nf`@Oooooo0_l00?lEooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06oooool70?nf`@030000003o]/40okK101H0okK100<000000?nf`@3o]/402@3o]/40
0`000000oooo0?ooo`060?ooo`03o`00003oool0oooo00@0oooo00?o00000000003oool0103oool0
0`00003o0000000000070?ooo`@000000_l000000`000000okK10?nf`@050?nf`@03o`0000000000
000000P0okK100?o00000000003o]/401@3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40
okK10080okK10oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00cooooo00D00000
ooooooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0;ooooo`030000oooooooo
oooo00gooooo;P3o]/4@0?ooo`80003o1P3oool00ol00?l0oooo0?ooo`030?ooo``0okK100<0003o
0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@060?nf`@Kooooo00?o003oooooooooool05Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo1`3o]/400`000000okK10?nf`@0F
0?nf`@030000003o]/40okK100P0okK100?o00000?nf`@3o]/401P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000okK10?nf`@0?
0?nf`@800000203o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100@00000
0?nf`@3o]/40okK10oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00cooooo00D0
0000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0<ooooo`030000oooo
oooooooo00cooooo;`3o]/4A0?ooo`030000o`3oool0oooo00<0oooo00?o003o0?ooo`3oool00P3o
ool<0?nf`@030000o`3o]/40okK101L0okK100?o003o0?nf`@3o]/401@3o]/44ooooo`;o003o6?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo1`3o]/400`000000okK10?nf
`@0E0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/400P3o]/440?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`800000503o
]/43000000H0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@040000003o
]/40okK10?nf`@?ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0<ooooo`040000
0?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo00cooooo00<0003oooooooooool0
3Oooool_0?nf`A40oooo0P000?l20?ooo`04o`00o`3oool0oooo0?ooo`h0okK100<0003o0?nf`@3o
]/40603o]/400ol00?l0okK10?nf`@040?nf`@;ooooo0_l00?lJooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07?ooool60?nf`@030000003o]/40okK101@0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@040?nf`@80oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`8000001`3oool2000001T0okK100?o00000?nf`@3o]/40103o]/400ol00000
okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401?ooool00`00003o
ooooooooo`05ooooo`0300000?oooooooooo00cooooo00@00000oooooooooooo00002_ooool000Wo
oooo00?o0000ooooooooool03Oooool00`000?ooooooooooo`0<oooooc40okK14@3oool20000o`80
oooo3`3o]/400`000?l0okK10?nf`@0J0?nf`@03o`00o`3o]/40okK10080okK10_ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool60?nf`@03
0000003o]/40okK101@0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
00000?l00000okK100/0okK11000000;0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/7ooooo00Cooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0<ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03
o`000?oooooooooo00gooooo00<0003oooooooooool03?oooolc0?nf`A00oooo00?o003o0000o`3o
]/403`3o]/400`000?l0okK10?nf`@0J0?nf`@03o`00o`3o]/40okK10080okK10_l00?lMooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool60?nf`@030000003o]/40okK101<0
okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o]/40okK100D0
okK11`0000040?nf`@@00000203o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400`3o]/400`00003oooooooooo`03ooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool03?ooool01000003oooooooooool0000:ooooo`002Oooool00ol0003o
ooooooooo`0>ooooo`030000oooooooooooo00cooooo=03o]/4=0?ooo`030?nf`Ol00?l0okK10080
003o3@3o]/400`000?l0okK10?nf`@0K0?nf`@03o`00o`3o]/7o003o00;o003o7oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01gooooo1@3o]/400`000000okK10?nf`@0C0?nf`@03
o`00003o]/40okK100L0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@030?nf`@03
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool0103oool00`3o]/4000000?nf`@060?nf`@03
0000003o]/40okK100d0okK10`0000060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/400`3o]/400ol00000okK10?nf`@020?nf`@0300000?oooooooooo00Cooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0;ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03
o`000?oooooooooo00oooooo00<0003oooooooooool02ooooolh0?nf`@D0oooo103o]/400ol00?l0
okK10?nf`@020?nf`@80003o2P3o]/400`000?l0okK10?nf`@0L0?nf`@;o003o0P3o]/4Pooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool50?nf`@030000003o]/40okK10180
okK100<000000?nf`@3o]/40203o]/400ol00000okK10?nf`@050?nf`@030000003o]/40okK100<0
okK100?o00000000003o]/400P3o]/420?ooo`03o`00003oool0oooo00<0okK100<00000o`00003o
]/401@3o]/42000001<0okK100?o00000?nf`@3o]/40103o]/400ol0000000000?nf`@030?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400oooool00000ooooo`04ooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool02oooool01000003oooooooooool0000:oooo
o`002Oooool00ol0003oooooooooo`0@ooooo`030000oooooooooooo00[ooooo@@3o]/400ol00?l0
okK10?nf`@040?nf`@<0003o1`3o]/400`000?l0okK10?nf`@0J0?nf`@;o003o00@0okK1o`00o`3o
]/40okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo1@3o]/400`00
0000okK10?nf`@0B0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40103o]/400ol0
0000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@040?nf`@8000005P3o]/42000000D0okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK10080okK100?ooooo00000?ooool01?ooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo00_ooooo00@00000oooooooooooo00002_ooool0
00Wooooo00?o0000ooooooooool04Oooool00`000?ooooooooooo`0:oooood00okK100?o003o0?nf
`@3o]/401`3o]/420000o`@0okK100<0003o0?nf`@3o]/40603o]/43o`00o`<0okK100?o003o0?nf
`@3o]/408?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo103o]/400`00
0000okK10?nf`@0A0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/401@3o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@030?nf`@8000006P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK1
0080okK100<000000?nf`@3o]/400`3o]/4010000000okK10?nf`@3o]/42ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0;ooooo`0400000?oooooo
ooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool02Ooooom0
0?nf`@03o`00o`3o]/40okK100T0okK110000?l70?nf`@<00000303o]/45o`00o`H0okK100?o003o
0?nf`Oooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo103o]/40
0`000000okK10?nf`@0A0?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/40
0ol00000okK10?nf`@030?nf`@030000003o]/40okK100L0okK13?l000080?nf`@03o`00003o]/40
okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100?ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo00_ooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool04oooool0
0`000?ooooooooooo`09ooooocl0okK100?o003o0?nf`@3o]/402`3o]/400`000?l0okK10000o`02
0000o`?o003o1@0000060?nf`@Go003o2`3o]/400ol00?l0okK1ooooo`0Pooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07oooool30?nf`@030000003o]/40okK10140okK100<00000
0?nf`@3o]/401`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/401@3o]/42o`0000`0okK100?o00000?nf`@3o]/401@3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@03
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0;
ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01Cooooo00<0003o
ooooooooool02Ooooole0?nf`@_o003o2`3o]/400`000?l0okK1o`00o`03o`00o`030?nf`@000?l0
003o00D000001_l00?l@0?nf`@03o`00oooooooooooo023ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Pooooo`80okK100<000000?nf`@3o]/404@3o]/400`000000okK10?nf`@06
0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@05
0?nf`@03o`00003o]/40okK100d0okK10_l000050?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/7ooooo00?ooooo00<00000
ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00_ooooo00@00000
oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool05Oooool00`000?ooooooooooo`08
oooooc00okK11Ol00?l90?nf`@03o`00o`3o]/7o003o00?o003o0`3o]/46o`00o`L0okK11@000002
0?nf`@;o003o4P3o]/400ol00?ooooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool08?ooool20?nf`@030000003o]/40okK10100okK100<000000?nf`@3o]/401`3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/42
o`000180okK100?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/400P3o]/400`00003oooooooooo`02ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`09ooooo`0500000?oooooo
ooooooooool000002_ooool000Wooooo00?o0000ooooooooool05Oooool00`000?ooooooooooo`09
ooooobh0okK100?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@030?nf`@05o`00o`3o]/7o
003o0?nf`@000?l0303o]/43000000D0okK10_l00?l@0?nf`@03o`00oooooooooooo023ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`030?nf`@000000okK10140okK100<0
00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK100<0okK100<0
00000?nf`@3o]/400`3o]/42o`0001D0okK100?o00000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@03o`0000000000okK10080okK100<000000?nf`@3o]/400P3o]/400`00003ooooooooo
o`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`09ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool05_oo
ool20000o`Wooooo;03o]/42o`00o`l0okK100?o003o0?nf`@3o]/400`3o]/43o`00o`030000o`3o
]/40okK101D0okK100?o003o0?nf`@3o]/40303o]/400ooooooo003oooooo`0Qooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08Oooool00`3o]/4000000?nf`@0A0?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@050000003o
]/40okK10?nf`Ol000001@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00?o00000?nf`@3o]/405P3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00D000000?nf`@3o]/40okK1000000030?nf`@03ooooo`00003ooooo00?ooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Wooooo00D00000oooooooo
ooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0Hooooo`030000oooooooooooo00Ko
oooo:`3o]/400ol00?l0okK10?nf`@0@0?nf`@05o`00o`3o]/40okK10?nf`Ol00?l00P3o]/400`00
0?oo003oo`00o`0G0?nf`@03o`00o`3o]/40okK100/0okK100?o003oooooooooool08Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00<0okK10000003o]/40403o]/400ol0
0000okK10?nf`@060?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@030?nf`@03o`00003o]/40okK100L0okK12?l000080?nf`@03o`00003o]/40okK1
00<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool02Oooool01@00003ooooooooooooooooo000000[ooooo0009oooo
o`03o`000?oooooooooo01Wooooo00<0003oooooooooool01_oooolY0?nf`@03o`00o`3o]/40okK1
0140okK100Co003o0?nf`@3o]/7o003o0P3o]/401Ol00?l0okK10?nf`@3o]/7o003o01L0okK10_l0
0?l;0?nf`@03o`00oooooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Rooooo`030000003o]/40okK100l0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf
`@060?nf`@;o0000203o]/400ol00000okK10?nf`@060?nf`@03o`00003o]/40okK100<0okK100D0
00000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100;ooooo00<00000ooooooooool0
0_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
2Oooool01@00003ooooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo01[ooooo
00<0003oooooooooool01_oooolV0?nf`@;o003o503o]/400ol00?l0okK1o`00o`020?nf`@030000
o`3o]/40okK100<0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@070?nf`@03oooo
ool00?oooooo02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`030000
003o]/40okK100l0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@03o`00
003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@050?nf`@03o`00
003o]/40okK100T0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@030?nf`@050000
003o]/40okK10?nf`@000000103o]/400`000000okK1ooooo`02ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Wo
oooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0Kooooo`03
o`00o`000?oooooo00Gooooo9P3o]/400ol00?l0okK10?nf`@0C0?nf`@05o`00o`3o]/7o003o0?nf
`@000?l01P3o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK100H0okK10_ooool00ol0
0?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool00`00
0000okK10?nf`@0?0?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/401@3o]/400ol0
0000okK10?nf`@0:0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/400`3o]/401@00
0000okK10?nf`@3o]/40000000@0okK100<00000ooooooooool00_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`09
ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool07Oooool2
0000o`Gooooo903o]/400ol00?l0okK10?nf`@0E0?nf`@;o003o00<0003o0?nf`@3o]/401P3o]/40
0ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK100D0okK100?oooooo`00ooooool08oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00<00000ooooo`3o]/403P3o]/40
0`000000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@020?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/40303o]/40
0ol00000okK10?nf`@050?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/40
1@000000okK10?nf`@3o]/40000000Cooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02Oooool01@00003ooooooooo
oooooooo000000[ooooo0009ooooo`03o`000?oooooooooo01oooooo00<0003oooooooooool00_oo
oolS0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0000o`3o]/402@3o]/400ol00?l0okK10?nf
`@0F0?nf`@03o`00o`3o]/40okK100<0okK10_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08_ooool00`00003ooooo0?nf`@0>0?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK100<0okK100<000000?nf`@3o]/400P3o]/401P000000okK10?nf`@3o]/7o0000000000@0
okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@0>0?nf`@03o`00003o]/40okK100@0
okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf
`@0000001?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`09ooooo`0500000?ooooooooooooooool000002_ooool0
00Wooooo00?o0000ooooooooool08?ooool00`000?ooooooooooo`02ooooob40okK100?o003o0?nf
`@3o]/405@3o]/400`000?oo003oo`00o`0<0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf
`@3o]/400P3o]/42ooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Rooooo`0300000?oooooooooo00h0okK100<000000?nf`@3o]/401P3o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400ol00000okK10?nf`@05
0?nf`@03o`00003o]/40okK100h0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@02
0?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK100000004ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00Wooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003ooooooooo
o`0Qooooo`03o`00o`000?oooooo00;ooooo7`3o]/400ol00?l0okK10?nf`@0C0?nf`@80003o0_l0
0?l20?nf`@03o`00o`3o]/40okK100X0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf
`@02ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Rooooo`0400000?ooooooooooooooo`d0okK100<000000?nf`@3o]/401P3o]/400`000000okK1
0?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400ol00000okK1
0?nf`@040?nf`@03o`00003o]/40okK100l0okK100?o00000?nf`@3o]/40103o]/400ol00000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/7ooooo00000004ooooo`03
00000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`05ooooo`03
00000?oooooooooo00Wooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003o
ooooooooo`0Sooooo`040000oooooooooooooooooah0okK100?o003o0?nf`@3o]/404@3o]/420000
o`<0okK100Co003o0?nf`@3o]/7o003o3@3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/7o
oooo00;ooooo00?o003oooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool00_ooool<0?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000D0okK100?o00000?nf`@3o]/40103o
]/400ol00000okK10?nf`@0A0?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400P3o
]/401P000000okK10?nf`@3o]/4000000?nf`@;ooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool09?ooool20000o`;ooooo7@3o]/400ol00?l0okK10?nf`@0@0?nf`@030000
o`3o]/40okK10080okK100?o003o0?nf`@3o]/400P3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00
o`3o]/40okK101H0okK100Co003ooooooooooooo003o9_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02;ooooo00<00000ooooooooool00oooool;0?nf`@030000003o]/40okK100D0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0
okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@0B0?nf`@03o`00003o]/40okK100@0
okK100?o00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000?ooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool09_ooool30000oa/0okK100?o003o0?nf`@3o
]/403P3o]/430000o`@0okK100?o003o0?nf`@3o]/40103o]/400ol00?l0okK10?nf`@0:0?nf`@03
o`00o`3o]/40okK101@0okK100Coooooo`00oooooooo003o9oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02;ooooo00<00000ooooooooool00oooool;0?nf`@030000003o]/40okK1
00D0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
0080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
0080okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@0B0?nf`@03o`00003o]/40okK1
00@0okK100?o00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000?ooooo00<00000
ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:Oooool50000oaD0okK100?o003o0?nf
`@3o]/403@3o]/400ol00?l0003o0?nf`@050?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf
`@3o]/402P3o]/400ol00?l0okK10?nf`@0C0?nf`@;ooooo00?o003oooooooooool09_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00<00000ooooooooool00oooool90?nf
`@030000003o]/40okK100H0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40
000000D0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@0C0?nf`@03o`00003o]/40
okK100<0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@0500000?oooooo
ooooooooo`0000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool01?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:_ooool40?nf`@80003o4`3o]/40
0ol00?l0okK10?nf`@0;0?nf`@<0003o1`3o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o]/40
okK100X0okK100?o003o0?nf`@3o]/404P3o]/42ooooo`;o003o:?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02?ooooo00<00000ooooooooool01?ooool80?nf`@030000003o]/40
okK100H0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000D0okK100?o
00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@0C0?nf`@03o`00003o]/40okK100<0okK100?o
00000?nf`@3o]/400P3o]/401_l00000okK10?nf`@3o]/7ooooo000000?ooooo00D00000oooooooo
oooooooo00000004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0:oooool50?nf`@80003o4@3o]/400ol00?l0okK10?nf`@060?nf`@D0
003o2P3o]/400ol00?l0okK10?nf`@070?nf`@;o003o2P3o]/400ol00?l0okK10?nf`@0A0?nf`@;o
oooo00?o003oooooool00?l0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?o
oooo00<00000ooooooooool01Oooool70?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100D000000?nf`@3o
]/40okK1o`0000040?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/400`3o]/400ol0
0000okK10?nf`@0C0?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@02ooooo`0500000?ooooooooooooooo`0000000oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0;?ooool60?nf`@T0003o1`3o]/400ol00?l0okK10?nf`@020?nf`@D0003o3P3o]/400ol0
0?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/403`3o]/42oooo
o`05o`00ooooooooooooooooool00?l09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02?ooooo00<00000ooooooooool01_ooool60?nf`@030000003o]/40okK100H0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100D00000
0?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@0C0?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o
]/400`000000okK1ooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool00`00003ooooo
ooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0;Oooool>0?nf`@L0003o00?o003o0000o`000?l00P000?lC0?nf`@03o`00o`3o
]/40okK100/0okK100?o003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@0=0?nf`@?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool08oooool00`00003oooooooooo`07ooooo`D0okK100<000000?nf`@3o]/401P3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10180okK100?o00000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@020?nf`@0300000?oooooooooo00;ooooo00D00000oooooooooooooooo
00000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0^oooooa@0okK100?o003o0?nf`@3o]/405@3o
]/400ol00?l0okK10?nf`@0<0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/40303o
]/42ooooo`;o003o1Oooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool08oooool00`00003oooooooooo`08ooooo`@0okK100<000000?nf`@3o]/401P3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10180okK100?o00000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@020?nf`@0300000?oooooooooo00;ooooo00D00000oooooooooooooooo
00000004ooooo`0500000?ooooooooooooooo`0000001Oooool00`00003oooooooooo`04ooooo`03
00000?oooooooooo00Wooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0`oooooa80okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK1
0?nf`@0=0?nf`@;o003o1P3o]/400ol00?l0okK10?nf`@0;0?nf`@?o003o1oooool00ol00?oooooo
ooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool00`00003ooooo
ooooo`0:ooooo`80okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@03o`00
003o]/40okK10140okK100?o00000?nf`@3o]/40103o]/401_l00000okK10?nf`@3o]/7ooooo0000
00Cooooo00D00000oooooooooooooooo00000004ooooo`0500000?ooooooooooooooo`0000001Ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0aoooooa40okK100?o003o
0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0?0?nf`@?o003o0P3o]/43000000X0okK10_l00?l:
ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`0300000?oooooooooo00[ooooo00<0okK10000003o]/401`3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o
]/40000000D0okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o
]/40okK100l0okK100?o00000?nf`@3o]/40103o]/401_l00000okK10?nf`@3o]/7ooooo000000Co
oooo00D00000oooooooooooooooo00000004ooooo`0500000?ooooooooooooooo`0000001Oooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0booooo`l0okK100?o003o0?nf
`@3o]/405@3o]/43000001<0okK100?o003o0000000000000`0000060?nf`@?o003o3Oooool00ol0
0?ooooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00`00
003oooooooooo`0;ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400ol0
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/401@3o]/42o`00
00d0okK10_l000060?nf`@04o`00003o]/40okK10?nf`@;ooooo00D00000oooooooooooooooo0000
0004ooooo`0500000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool02Oooool00`00003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03?ooooo3P3o]/400ol00?l0okK10?nf
`@0D0?nf`@D000004`3o]/45000000Ko003o0P3o]/4>ooooo`03o`00oooooooooooo02Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`0300000?oooooooooo00_ooooo00<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK100T0okK100?o
00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@02ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool00_ooool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool0
0oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0eooooo``0okK100?o
003o0?nf`@3o]/40503o]/45000001<0okK11@0000060?nf`A3ooooo00?o003oooooooooool09?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00<00000ooooooooool02ooo
ool00`00003oooooooooo`060?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK100L0okK10ol000060?nf`@;o0000203o
]/400ol00000okK1ooooo`02ooooo`0300000?oooooooooo00?ooooo00D00000oooooooooooooooo
00000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0fooooo`/0okK100?o003o0?nf`@3o]/40503o
]/45000001@0okK10`0000060?nf`A7ooooo00?o003oooooooooool09?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`050?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@03o`00003o]/40okK100X0okK11_l0000:0?nf`@03o`000?oooooooooo00;ooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D0
0000oooooooooooooooo00000005ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0
2Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo03Sooooo2@3o]/400ol00?l0okK10?nf`@0E0?nf`@<000005P3o]/400ol00?l0okK10?nf
`@030?nf`A?ooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Gooooo00<00000ooooooooool02oooool00`00003oooooooooo`02ooooo`<0okK100?o
00000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK10_l0
000H0?nf`@;o00001Oooool00`00003oooooooooo`02ooooo`05o`000?ooooooooooooooo`000000
1?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0>_ooool80?nf`@03o`00o`3o]/40okK101H0okK100?o
003o0?nf`@3o]/40503o]/401?l00?l0okK10?nf`@3o]/4Dooooo`03o`00oooooooooooo02Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool01?ooool00`3o]/4000000?nf`@050?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/400`3o]/401Ol00000okK10?nf`@3o]/40000000D0okK100?o00000?nf`@3o
]/401@3o]/400ol00000okK10?nf`@0D0?nf`@03o`000?oooooooooo00Cooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03_ooooo1`3o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK101@0okK1
00?o003o0?nf`@3o]/405Oooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool09_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Cooooo
00<0okK10000003o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100D0okK1
00?o00000?nf`@3o]/404P3o]/400ol0003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0nooooo`@0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00oooo
oooooooo01Gooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`0300000?oo
ool0okK100@0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@03o`00003o
]/40okK100h0okK10ol00005ooooo`0300000?l0003ooooo00?ooooo00<00000ooooooooool00_oo
ool00`00003o0000ooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`11ooooo`030?nf`Ol00?l0
okK101L0okK100?o003o0?nf`@3o]/404P3o]/400ooooooo003oooooo`0Fooooo`03o`00oooooooo
oooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`0300000?oooooo
oooo00_ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`02ooooo`80okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100?o0000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@?o00002P3o]/43o`0000Oooooo00<00000
ooooooooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00<00000
ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo04?ooooo00?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0>0?nf
`@Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool09_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool01?ooool00`000000okK10?nf`@030?nf`@030000003o]/40okK1
00<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00L0okK12_l00009ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`13ooooo`04o`00oooooooooooooooo
oaD0okK100?o003o0?nf`@3o]/402`3o]/47ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool00P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@0;0?nf`@gooooo00?o0000ooooooooool01?ooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04?o
oooo00?o003oooooooooool01?oooolB0?nf`@03o`00o`3o]/40okK100P0okK12Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Wooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool01Oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00?ooooo00?o00000?nf`@3o]/400`3o]/400`000000
okK10?nf`@030?nf`@030000003o]/40okK100@0okK10P0000080?nf`@kooooo0P000005ooooo`80
00001?ooool00`00003o0000ooooo`03ooooo`0300000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`13ooooo`03o`00
oooooooooooo00Oooooo3`3o]/400ol00?l0okK10?nf`@050?nf`@cooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
9oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00<0okK100?o00000000003o]/40
103o]/400ol0000000000?nf`@050?nf`@<000000P3o]/4>ooooo`<000001Oooool2000000Gooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A?ooool00ol00?oooooooooo
o`0?ooooo`@0okK10oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`04ooooo`0400000?ooooooooooooooo`<0okK1
00<00000ooooooooool01_ooool3000000[ooooo0`000007ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0AOooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`03ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`08ooooo`X000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00<0
0000o`000?ooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<0
0000ooooooooool02Oooool00`00003o0000ooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0:Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Sooooo00<00000ooooooooool02oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo00Gooooo00?o000000000?ooool06?ooool2000000Gooooo0P000005
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Xooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool01_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool01?ooool2000000Oooooo0P00000Dooooo`<000001_ooool00`00003oooooooooo`04oooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Yooooo`0300000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`06ooooo`<000003oooool2000000Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00_ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`0Gooooo`;o003o
2Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Yooooo`03o`000000003ooooo00cooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
1Oooool2000000Wooooo1`000002ooooo`H000002?ooool2000000Gooooo0P000006ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B?oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_oo
ool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000000003ooooo00Kooooo0P00000>ooooo`8000002ooo
ool3000000Kooooo00<00000ooooooooool01Oooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Wooooo0ol00?lHooooo`04o`00oooooooo
ooooooooo`?o003o5Oooool2o`00oc3ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0[ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`05ooooo`0300000?oooooooooo00Gooooo0P000007ooooo`<000005oooool00`00003ooooooooo
o`05ooooo`8000001_ooool2000000Oooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`0:ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0C?ooool00ol00?ooooooooooo`0Fooooo`?o003o5oooool00ol00?ooooooooooo`0`
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00Oooooo00@00000o`000000000000003oooool4000000Oooooo00?o
0000ooooooooool01Oooool00`00003oooooooooo`05ooooo`0300000?l0003ooooo00Kooooo00<0
0000ooooooooool02Oooool00ol000000000ooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool05_ooool3o`00oaGooooo00?o003o
ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo00<00000
ooooooooool03?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Gooooo00<00000
ooooooooool01Oooool00ol000000000ooooo`0;ooooo`<000002_ooool2000000Wooooo0P000007
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0C_ooool2o`00oaCooooo0_l00?l3ooooo`03o`00oooooooooooo00oooooo0ol00?ldoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00`00003oooooooooo`0<oooo
o`0300000?oooooooooo00Oooooo00<00000ooooooooool01Oooool2000000Oooooo00<00000oooo
ooooool03?ooool:000000Wooooo0P000007ooooo`8000001oooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo00Wooooo00<00000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1@ooooo`?o003o3oooool2o`00o`Kooooo1?l00?l8ooooo`Go
003o=oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool03?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool01Oooool3000001cooooo0P000008ooooo`0300000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0Doooool4o`00o`Oooooo1?l00?l<ooooo`So003o
??ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo00<00000ooooooooool0
3?ooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0P000008ooooo`@00000
5?ooool300000003o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool04?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1Gooooo`Oo003oE?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02kooooo00<00000ooooooooool03Oooool00`00003ooooooooo
o`07ooooo`0300000?oooooooooo00Oooooo0P00000:ooooo`@000003Oooool3000000_ooooo0P00
0008ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0_ooooo`0300000?oooooooooo00gooooo00?o0000
ooooooooool01oooool2000000Wooooo0P00000<ooooo`d000002oooool3000000Sooooo0P000008
ooooo`8000003?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo01oooooo0P000009ooooo`8000002Oooool00`00003oooooooooo`0;oooo
o`0300000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo00<00000oooooooo
ool03Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00?o000000000000
00007?ooool2000000Wooooo0P00000;ooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo00Wooooo0P00000;ooooo`@000005?ooool4000000Wooooo0P00000;ooooo`800000
3Oooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`0300000?oo
oooooooo00gooooo0P00000;ooooo`0300000?oooooooooo00cooooo1000000=ooooo`<000003?oo
ool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool05Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`0300000?oooooo
oooo00Wooooo00@00000o`000000000000003_ooool=000000gooooo0P00000<ooooo`0300000?oo
oooooooo00cooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool0
0`00003oooooooooo`0>ooooo`0300000?oooooooooo00cooooo0P00000Sooooo`<000003?ooool0
0`00003o0000ooooo`0=ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03Cooooo00<00000ooooooooool03oooool2000000kooooo00<00000ooooooooool07Oooool30000
00kooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Hooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool03?ooool3000001_o
oooo00<00000ooooooooool03_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Kooooo0P00000Aooooo`8000003oooool00`00003o0000
00000005000000gooooo1P00000?ooooo`0300000?l0003ooooo00kooooo0P00000Kooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0hooooo`0300000?oooooooooo013ooooo0P00000Eooooo`d000004_oo
ool30000013ooooo00<00000ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>Oooool0
0`00003oooooooooo`0Aooooo`800000<?ooool2000001;ooooo00<00000ooooooooool07?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0>_ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo
02cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Mooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooookKo00004Ooooonfo`0000[ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.42308 .13429 m
.44231 .13433 L
.45817 .13462 L
.46154 .13471 L
.48077 .13541 L
.5 .13638 L
.51923 .13776 L
.53846 .13968 L
.55769 .14224 L
.57692 .14547 L
.59615 .14923 L
.61538 .15326 L
.61815 .15385 L
.63462 .15858 L
.65385 .16454 L
.67308 .17064 L
.68082 .17308 L
.69231 .17753 L
.71154 .18556 L
.72663 .19231 L
.73077 .19449 L
.75 .20575 L
.75884 .21154 L
.76923 .21949 L
.78216 .23077 L
.78846 .23707 L
.79973 .25 L
.80769 .26053 L
.81325 .26923 L
.82382 .28846 L
.82692 .29511 L
.83161 .30769 L
.83751 .32692 L
.84201 .34615 L
.84541 .36538 L
.84615 .3704 L
.84774 .38462 L
.84962 .40385 L
.85129 .42308 L
.85276 .44231 L
.85394 .46154 L
.85474 .48077 L
.85505 .5 L
.85485 .51923 L
.85417 .53846 L
.85305 .55769 L
.85156 .57692 L
.84969 .59615 L
.84741 .61538 L
.84615 .6245 L
.84418 .63462 L
.83961 .65385 L
.83384 .67308 L
.82694 .69231 L
.82692 .69236 L
.81739 .71154 L
.80769 .72828 L
.806 .73077 L
.79136 .75 L
.78846 .75337 L
.77275 .76923 L
.76923 .77228 L
.75 .78695 L
.74775 .78846 L
.73077 .79807 L
.71154 .8073 L
.71063 .80769 L
.69231 .8143 L
.67308 .82089 L
.65532 .82692 L
.65385 .82734 L
.63462 .8333 L
.61538 .84023 L
.60024 .84615 L
.59615 .84755 L
.57692 .85469 L
.55769 .86209 L
.54862 .86538 L
.53846 .8684 L
.51923 .87342 L
.5 .87704 L
.48077 .87893 L
.46154 .87901 L
.44231 .8773 L
.42308 .87388 L
.40385 .86892 L
.39236 .86538 L
.38462 .86233 L
.36538 .85367 L
.35035 .84615 L
.34615 .8437 L
.32692 .8316 L
.31982 .82692 L
.30769 .81792 L
.29447 .80769 L
.28846 .80267 L
.27209 .78846 L
.26923 .78584 L
.25168 .76923 L
.25 .76758 L
.23271 .75 L
.23077 .74798 L
.21501 .73077 L
.21154 .72687 L
.19875 .71154 L
.19231 .70346 L
.18424 .69231 L
.17308 .67566 L
.17158 .67308 L
.16124 .65385 L
.15385 .63778 L
.15267 .63462 L
.1463 .61538 L
.14133 .59615 L
.13785 .57692 L
.13583 .55769 L
.13516 .53846 L
.13572 .51923 L
.13738 .5 L
.14 .48077 L
.14343 .46154 L
.14745 .44231 L
.15177 .42308 L
.15385 .41381 L
.15679 .40385 L
.16295 .38462 L
.1694 .36538 L
.17308 .3542 L
.1764 .34615 L
.1848 .32692 L
.19231 .30964 L
.1933 .30769 L
.20348 .28846 L
.21154 .2733 L
.21397 .26923 L
.22597 .25 L
.23077 .24247 L
.2391 .23077 L
.25 .21638 L
.25403 .21154 L
.26923 .19488 L
.27182 .19231 L
.28846 .17761 L
.29426 .17308 L
.30769 .16404 L
.32587 .15385 L
.32692 .15337 L
.34615 .14578 L
.36538 .1403 L
.38462 .1368 L
.40385 .13493 L
.40967 .13462 L
F
0 g
.42308 .13429 m
.44231 .13433 L
.45817 .13462 L
.46154 .13471 L
.48077 .13541 L
.5 .13638 L
.51923 .13776 L
.53846 .13968 L
.55769 .14224 L
.57692 .14547 L
.59615 .14923 L
.61538 .15326 L
.61815 .15385 L
.63462 .15858 L
.65385 .16454 L
.67308 .17064 L
.68082 .17308 L
.69231 .17753 L
.71154 .18556 L
.72663 .19231 L
.73077 .19449 L
.75 .20575 L
.75884 .21154 L
.76923 .21949 L
.78216 .23077 L
.78846 .23707 L
.79973 .25 L
.80769 .26053 L
.81325 .26923 L
.82382 .28846 L
.82692 .29511 L
.83161 .30769 L
.83751 .32692 L
.84201 .34615 L
.84541 .36538 L
.84615 .3704 L
.84774 .38462 L
.84962 .40385 L
.85129 .42308 L
.85276 .44231 L
.85394 .46154 L
.85474 .48077 L
.85505 .5 L
.85485 .51923 L
.85417 .53846 L
.85305 .55769 L
.85156 .57692 L
.84969 .59615 L
.84741 .61538 L
.84615 .6245 L
Mistroke
.84418 .63462 L
.83961 .65385 L
.83384 .67308 L
.82694 .69231 L
.82692 .69236 L
.81739 .71154 L
.80769 .72828 L
.806 .73077 L
.79136 .75 L
.78846 .75337 L
.77275 .76923 L
.76923 .77228 L
.75 .78695 L
.74775 .78846 L
.73077 .79807 L
.71154 .8073 L
.71063 .80769 L
.69231 .8143 L
.67308 .82089 L
.65532 .82692 L
.65385 .82734 L
.63462 .8333 L
.61538 .84023 L
.60024 .84615 L
.59615 .84755 L
.57692 .85469 L
.55769 .86209 L
.54862 .86538 L
.53846 .8684 L
.51923 .87342 L
.5 .87704 L
.48077 .87893 L
.46154 .87901 L
.44231 .8773 L
.42308 .87388 L
.40385 .86892 L
.39236 .86538 L
.38462 .86233 L
.36538 .85367 L
.35035 .84615 L
.34615 .8437 L
.32692 .8316 L
.31982 .82692 L
.30769 .81792 L
.29447 .80769 L
.28846 .80267 L
.27209 .78846 L
.26923 .78584 L
.25168 .76923 L
.25 .76758 L
Mistroke
.23271 .75 L
.23077 .74798 L
.21501 .73077 L
.21154 .72687 L
.19875 .71154 L
.19231 .70346 L
.18424 .69231 L
.17308 .67566 L
.17158 .67308 L
.16124 .65385 L
.15385 .63778 L
.15267 .63462 L
.1463 .61538 L
.14133 .59615 L
.13785 .57692 L
.13583 .55769 L
.13516 .53846 L
.13572 .51923 L
.13738 .5 L
.14 .48077 L
.14343 .46154 L
.14745 .44231 L
.15177 .42308 L
.15385 .41381 L
.15679 .40385 L
.16295 .38462 L
.1694 .36538 L
.17308 .3542 L
.1764 .34615 L
.1848 .32692 L
.19231 .30964 L
.1933 .30769 L
.20348 .28846 L
.21154 .2733 L
.21397 .26923 L
.22597 .25 L
.23077 .24247 L
.2391 .23077 L
.25 .21638 L
.25403 .21154 L
.26923 .19488 L
.27182 .19231 L
.28846 .17761 L
.29426 .17308 L
.30769 .16404 L
.32587 .15385 L
.32692 .15337 L
.34615 .14578 L
.36538 .1403 L
.38462 .1368 L
Mistroke
.40385 .13493 L
.40967 .13462 L
.42308 .13429 L
Mfstroke
.2 g
.38462 .17231 m
.40385 .16932 L
.42308 .16731 L
.44231 .16593 L
.46154 .16496 L
.48077 .1644 L
.5 .16435 L
.51923 .16495 L
.53846 .16632 L
.55769 .16851 L
.57692 .17151 L
.58557 .17308 L
.59615 .17554 L
.61538 .1807 L
.63462 .1866 L
.65179 .19231 L
.65385 .19308 L
.67308 .2008 L
.69231 .20924 L
.69725 .21154 L
.71154 .21908 L
.73077 .23068 L
.7309 .23077 L
.75 .24529 L
.75532 .25 L
.76923 .26435 L
.77328 .26923 L
.78672 .28846 L
.78846 .2914 L
.79668 .30769 L
.80432 .32692 L
.80769 .3374 L
.81004 .34615 L
.81447 .36538 L
.81818 .38462 L
.82142 .40385 L
.82426 .42308 L
.82666 .44231 L
.82692 .44463 L
.82832 .46154 L
.82939 .48077 L
.82983 .5 L
.82963 .51923 L
.8288 .53846 L
.82743 .55769 L
.82692 .56345 L
.82534 .57692 L
.82259 .59615 L
.8192 .61538 L
.81501 .63462 L
.80982 .65385 L
.80769 .66066 L
.80297 .67308 L
.79404 .69231 L
.78846 .70246 L
.78259 .71154 L
.76923 .72894 L
.76761 .73077 L
.75 .74787 L
.74745 .75 L
.73077 .76205 L
.71897 .76923 L
.71154 .7731 L
.69231 .78204 L
.67662 .78846 L
.67308 .78974 L
.65385 .79652 L
.63462 .80324 L
.62187 .80769 L
.61538 .80978 L
.59615 .81622 L
.57692 .82286 L
.56504 .82692 L
.55769 .82921 L
.53846 .83502 L
.51923 .84011 L
.5 .84394 L
.48077 .84615 L
.48069 .84615 L
.46154 .84652 L
.45361 .84615 L
.44231 .84504 L
.42308 .8416 L
.40385 .83624 L
.38462 .82909 L
.37949 .82692 L
.36538 .8199 L
.34615 .80887 L
.34424 .80769 L
.32692 .79577 L
.31712 .78846 L
.30769 .78084 L
.2942 .76923 L
.28846 .76398 L
.274 .75 L
.26923 .74516 L
.25577 .73077 L
.25 .72435 L
.23908 .71154 L
.23077 .70138 L
.22381 .69231 L
.21154 .67533 L
.21004 .67308 L
.19817 .65385 L
.19231 .64312 L
.18824 .63462 L
.18029 .61538 L
.17415 .59615 L
.17308 .59219 L
.16993 .57692 L
.16727 .55769 L
.16598 .53846 L
.16592 .51923 L
.16692 .5 L
.16881 .48077 L
.17145 .46154 L
.17308 .45134 L
.17489 .44231 L
.1793 .42308 L
.18444 .40385 L
.19019 .38462 L
.19231 .37791 L
.19701 .36538 L
.20496 .34615 L
.21154 .33125 L
.2137 .32692 L
.22393 .30769 L
.23077 .2956 L
.2352 .28846 L
.24797 .26923 L
.25 .26632 L
.26249 .25 L
.26923 .24188 L
.27933 .23077 L
.28846 .22173 L
.3 .21154 L
.30769 .20559 L
.32692 .19301 L
.32816 .19231 L
.34615 .18372 L
.36538 .17696 L
.38072 .17308 L
F
0 g
.38462 .17231 m
.40385 .16932 L
.42308 .16731 L
.44231 .16593 L
.46154 .16496 L
.48077 .1644 L
.5 .16435 L
.51923 .16495 L
.53846 .16632 L
.55769 .16851 L
.57692 .17151 L
.58557 .17308 L
.59615 .17554 L
.61538 .1807 L
.63462 .1866 L
.65179 .19231 L
.65385 .19308 L
.67308 .2008 L
.69231 .20924 L
.69725 .21154 L
.71154 .21908 L
.73077 .23068 L
.7309 .23077 L
.75 .24529 L
.75532 .25 L
.76923 .26435 L
.77328 .26923 L
.78672 .28846 L
.78846 .2914 L
.79668 .30769 L
.80432 .32692 L
.80769 .3374 L
.81004 .34615 L
.81447 .36538 L
.81818 .38462 L
.82142 .40385 L
.82426 .42308 L
.82666 .44231 L
.82692 .44463 L
.82832 .46154 L
.82939 .48077 L
.82983 .5 L
.82963 .51923 L
.8288 .53846 L
.82743 .55769 L
.82692 .56345 L
.82534 .57692 L
.82259 .59615 L
.8192 .61538 L
.81501 .63462 L
Mistroke
.80982 .65385 L
.80769 .66066 L
.80297 .67308 L
.79404 .69231 L
.78846 .70246 L
.78259 .71154 L
.76923 .72894 L
.76761 .73077 L
.75 .74787 L
.74745 .75 L
.73077 .76205 L
.71897 .76923 L
.71154 .7731 L
.69231 .78204 L
.67662 .78846 L
.67308 .78974 L
.65385 .79652 L
.63462 .80324 L
.62187 .80769 L
.61538 .80978 L
.59615 .81622 L
.57692 .82286 L
.56504 .82692 L
.55769 .82921 L
.53846 .83502 L
.51923 .84011 L
.5 .84394 L
.48077 .84615 L
.48069 .84615 L
.46154 .84652 L
.45361 .84615 L
.44231 .84504 L
.42308 .8416 L
.40385 .83624 L
.38462 .82909 L
.37949 .82692 L
.36538 .8199 L
.34615 .80887 L
.34424 .80769 L
.32692 .79577 L
.31712 .78846 L
.30769 .78084 L
.2942 .76923 L
.28846 .76398 L
.274 .75 L
.26923 .74516 L
.25577 .73077 L
.25 .72435 L
.23908 .71154 L
.23077 .70138 L
Mistroke
.22381 .69231 L
.21154 .67533 L
.21004 .67308 L
.19817 .65385 L
.19231 .64312 L
.18824 .63462 L
.18029 .61538 L
.17415 .59615 L
.17308 .59219 L
.16993 .57692 L
.16727 .55769 L
.16598 .53846 L
.16592 .51923 L
.16692 .5 L
.16881 .48077 L
.17145 .46154 L
.17308 .45134 L
.17489 .44231 L
.1793 .42308 L
.18444 .40385 L
.19019 .38462 L
.19231 .37791 L
.19701 .36538 L
.20496 .34615 L
.21154 .33125 L
.2137 .32692 L
.22393 .30769 L
.23077 .2956 L
.2352 .28846 L
.24797 .26923 L
.25 .26632 L
.26249 .25 L
.26923 .24188 L
.27933 .23077 L
.28846 .22173 L
.3 .21154 L
.30769 .20559 L
.32692 .19301 L
.32816 .19231 L
.34615 .18372 L
.36538 .17696 L
.38072 .17308 L
.38462 .17231 L
Mfstroke
.3 g
.40385 .19205 m
.42308 .1889 L
.44231 .18632 L
.46154 .18422 L
.48077 .18269 L
.5 .18188 L
.51923 .18195 L
.53846 .18302 L
.55769 .18514 L
.57692 .18831 L
.59545 .19231 L
.59615 .19249 L
.61538 .19802 L
.63462 .20455 L
.65284 .21154 L
.65385 .21196 L
.67308 .22066 L
.69231 .23047 L
.69286 .23077 L
.71154 .24211 L
.72281 .25 L
.73077 .25628 L
.74485 .26923 L
.75 .27473 L
.76102 .28846 L
.76923 .30096 L
.773 .30769 L
.78199 .32692 L
.78846 .34464 L
.78894 .34615 L
.79441 .36538 L
.79906 .38462 L
.80314 .40385 L
.80671 .42308 L
.80769 .42896 L
.80956 .44231 L
.81171 .46154 L
.81312 .48077 L
.81372 .5 L
.81349 .51923 L
.81248 .53846 L
.81074 .55769 L
.80836 .57692 L
.80769 .5816 L
.80518 .59615 L
.80121 .61538 L
.79633 .63462 L
.79024 .65385 L
.78846 .65872 L
.78229 .67308 L
.77191 .69231 L
.76923 .69655 L
.75811 .71154 L
.75 .72063 L
.73937 .73077 L
.73077 .73777 L
.71276 .75 L
.71154 .75072 L
.69231 .76087 L
.67363 .76923 L
.67308 .76945 L
.65385 .77687 L
.63462 .78385 L
.6214 .78846 L
.61538 .79043 L
.59615 .7967 L
.57692 .80286 L
.56131 .80769 L
.55769 .80874 L
.53846 .81412 L
.51923 .8189 L
.5 .82262 L
.48077 .82488 L
.46154 .82538 L
.44231 .82393 L
.42308 .82046 L
.40385 .81495 L
.38512 .80769 L
.38462 .80746 L
.36538 .79776 L
.34975 .78846 L
.34615 .78609 L
.32692 .77225 L
.32306 .76923 L
.30769 .75622 L
.30088 .75 L
.28846 .73787 L
.28166 .73077 L
.26923 .71703 L
.26457 .71154 L
.25 .69348 L
.24911 .69231 L
.23518 .67308 L
.23077 .66657 L
.22277 .65385 L
.21201 .63462 L
.21154 .6337 L
.20321 .61538 L
.19625 .59615 L
.19231 .58217 L
.19113 .57692 L
.18773 .55769 L
.18579 .53846 L
.18512 .51923 L
.18557 .5 L
.18698 .48077 L
.18927 .46154 L
.19231 .4425 L
.19235 .44231 L
.1965 .42308 L
.2016 .40385 L
.20761 .38462 L
.21154 .3733 L
.21469 .36538 L
.22317 .34615 L
.23077 .33068 L
.23281 .32692 L
.24411 .30769 L
.25 .2985 L
.257 .28846 L
.26923 .27245 L
.27189 .26923 L
.28846 .25101 L
.28947 .25 L
.30769 .23362 L
.31127 .23077 L
.32692 .21992 L
.3418 .21154 L
.34615 .20946 L
.36538 .20179 L
.38462 .19618 L
.40248 .19231 L
F
0 g
.40385 .19205 m
.42308 .1889 L
.44231 .18632 L
.46154 .18422 L
.48077 .18269 L
.5 .18188 L
.51923 .18195 L
.53846 .18302 L
.55769 .18514 L
.57692 .18831 L
.59545 .19231 L
.59615 .19249 L
.61538 .19802 L
.63462 .20455 L
.65284 .21154 L
.65385 .21196 L
.67308 .22066 L
.69231 .23047 L
.69286 .23077 L
.71154 .24211 L
.72281 .25 L
.73077 .25628 L
.74485 .26923 L
.75 .27473 L
.76102 .28846 L
.76923 .30096 L
.773 .30769 L
.78199 .32692 L
.78846 .34464 L
.78894 .34615 L
.79441 .36538 L
.79906 .38462 L
.80314 .40385 L
.80671 .42308 L
.80769 .42896 L
.80956 .44231 L
.81171 .46154 L
.81312 .48077 L
.81372 .5 L
.81349 .51923 L
.81248 .53846 L
.81074 .55769 L
.80836 .57692 L
.80769 .5816 L
.80518 .59615 L
.80121 .61538 L
.79633 .63462 L
.79024 .65385 L
.78846 .65872 L
.78229 .67308 L
Mistroke
.77191 .69231 L
.76923 .69655 L
.75811 .71154 L
.75 .72063 L
.73937 .73077 L
.73077 .73777 L
.71276 .75 L
.71154 .75072 L
.69231 .76087 L
.67363 .76923 L
.67308 .76945 L
.65385 .77687 L
.63462 .78385 L
.6214 .78846 L
.61538 .79043 L
.59615 .7967 L
.57692 .80286 L
.56131 .80769 L
.55769 .80874 L
.53846 .81412 L
.51923 .8189 L
.5 .82262 L
.48077 .82488 L
.46154 .82538 L
.44231 .82393 L
.42308 .82046 L
.40385 .81495 L
.38512 .80769 L
.38462 .80746 L
.36538 .79776 L
.34975 .78846 L
.34615 .78609 L
.32692 .77225 L
.32306 .76923 L
.30769 .75622 L
.30088 .75 L
.28846 .73787 L
.28166 .73077 L
.26923 .71703 L
.26457 .71154 L
.25 .69348 L
.24911 .69231 L
.23518 .67308 L
.23077 .66657 L
.22277 .65385 L
.21201 .63462 L
.21154 .6337 L
.20321 .61538 L
.19625 .59615 L
.19231 .58217 L
Mistroke
.19113 .57692 L
.18773 .55769 L
.18579 .53846 L
.18512 .51923 L
.18557 .5 L
.18698 .48077 L
.18927 .46154 L
.19231 .4425 L
.19235 .44231 L
.1965 .42308 L
.2016 .40385 L
.20761 .38462 L
.21154 .3733 L
.21469 .36538 L
.22317 .34615 L
.23077 .33068 L
.23281 .32692 L
.24411 .30769 L
.25 .2985 L
.257 .28846 L
.26923 .27245 L
.27189 .26923 L
.28846 .25101 L
.28947 .25 L
.30769 .23362 L
.31127 .23077 L
.32692 .21992 L
.3418 .21154 L
.34615 .20946 L
.36538 .20179 L
.38462 .19618 L
.40248 .19231 L
.40385 .19205 L
Mfstroke
.4 g
.42308 .20723 m
.44231 .20333 L
.46154 .20002 L
.48077 .19747 L
.5 .1959 L
.51923 .19544 L
.53846 .1962 L
.55769 .19822 L
.57692 .20154 L
.59615 .20611 L
.61438 .21154 L
.61538 .21188 L
.63462 .21907 L
.65385 .22747 L
.66075 .23077 L
.67308 .23721 L
.69231 .24859 L
.69449 .25 L
.71154 .26225 L
.71991 .26923 L
.73077 .27957 L
.73874 .28846 L
.75 .30353 L
.75266 .30769 L
.76308 .32692 L
.76923 .34115 L
.77115 .34615 L
.77771 .36538 L
.78333 .38462 L
.78827 .40385 L
.78846 .40464 L
.79247 .42308 L
.79596 .44231 L
.79863 .46154 L
.80037 .48077 L
.80112 .5 L
.80089 .51923 L
.7997 .53846 L
.79764 .55769 L
.79478 .57692 L
.79115 .59615 L
.78846 .60832 L
.78668 .61538 L
.78108 .63462 L
.77404 .65385 L
.76923 .66472 L
.76496 .67308 L
.75286 .69231 L
.75 .69613 L
.73637 .71154 L
.73077 .71682 L
.71303 .73077 L
.71154 .73178 L
.69231 .74325 L
.67883 .75 L
.67308 .75262 L
.65385 .76069 L
.63462 .76799 L
.63116 .76923 L
.61538 .77464 L
.59615 .78089 L
.57692 .78673 L
.57095 .78846 L
.55769 .79214 L
.53846 .79718 L
.51923 .80166 L
.5 .80522 L
.48077 .80747 L
.4774 .80769 L
.46154 .80802 L
.45348 .80769 L
.44231 .80665 L
.42308 .80317 L
.40385 .79752 L
.38462 .78974 L
.38186 .78846 L
.36538 .77971 L
.34867 .76923 L
.34615 .76749 L
.32692 .75286 L
.32349 .75 L
.30769 .73566 L
.30274 .73077 L
.28846 .71554 L
.28498 .71154 L
.26937 .69231 L
.26923 .69212 L
.25546 .67308 L
.25 .66496 L
.24298 .65385 L
.23192 .63462 L
.23077 .63245 L
.2225 .61538 L
.2148 .59615 L
.21154 .5863 L
.20891 .57692 L
.20471 .55769 L
.20202 .53846 L
.20068 .51923 L
.20051 .5 L
.20142 .48077 L
.20333 .46154 L
.20621 .44231 L
.21007 .42308 L
.21154 .41673 L
.21508 .40385 L
.22135 .38462 L
.22883 .36538 L
.23077 .36086 L
.23785 .34615 L
.24849 .32692 L
.25 .32442 L
.26107 .30769 L
.26923 .29672 L
.27589 .28846 L
.28846 .27454 L
.29368 .26923 L
.30769 .25664 L
.31601 .25 L
.32692 .24243 L
.34615 .23143 L
.3475 .23077 L
.36538 .22312 L
.38462 .21674 L
.40385 .21163 L
.40422 .21154 L
F
0 g
.42308 .20723 m
.44231 .20333 L
.46154 .20002 L
.48077 .19747 L
.5 .1959 L
.51923 .19544 L
.53846 .1962 L
.55769 .19822 L
.57692 .20154 L
.59615 .20611 L
.61438 .21154 L
.61538 .21188 L
.63462 .21907 L
.65385 .22747 L
.66075 .23077 L
.67308 .23721 L
.69231 .24859 L
.69449 .25 L
.71154 .26225 L
.71991 .26923 L
.73077 .27957 L
.73874 .28846 L
.75 .30353 L
.75266 .30769 L
.76308 .32692 L
.76923 .34115 L
.77115 .34615 L
.77771 .36538 L
.78333 .38462 L
.78827 .40385 L
.78846 .40464 L
.79247 .42308 L
.79596 .44231 L
.79863 .46154 L
.80037 .48077 L
.80112 .5 L
.80089 .51923 L
.7997 .53846 L
.79764 .55769 L
.79478 .57692 L
.79115 .59615 L
.78846 .60832 L
.78668 .61538 L
.78108 .63462 L
.77404 .65385 L
.76923 .66472 L
.76496 .67308 L
.75286 .69231 L
.75 .69613 L
.73637 .71154 L
Mistroke
.73077 .71682 L
.71303 .73077 L
.71154 .73178 L
.69231 .74325 L
.67883 .75 L
.67308 .75262 L
.65385 .76069 L
.63462 .76799 L
.63116 .76923 L
.61538 .77464 L
.59615 .78089 L
.57692 .78673 L
.57095 .78846 L
.55769 .79214 L
.53846 .79718 L
.51923 .80166 L
.5 .80522 L
.48077 .80747 L
.4774 .80769 L
.46154 .80802 L
.45348 .80769 L
.44231 .80665 L
.42308 .80317 L
.40385 .79752 L
.38462 .78974 L
.38186 .78846 L
.36538 .77971 L
.34867 .76923 L
.34615 .76749 L
.32692 .75286 L
.32349 .75 L
.30769 .73566 L
.30274 .73077 L
.28846 .71554 L
.28498 .71154 L
.26937 .69231 L
.26923 .69212 L
.25546 .67308 L
.25 .66496 L
.24298 .65385 L
.23192 .63462 L
.23077 .63245 L
.2225 .61538 L
.2148 .59615 L
.21154 .5863 L
.20891 .57692 L
.20471 .55769 L
.20202 .53846 L
.20068 .51923 L
.20051 .5 L
Mistroke
.20142 .48077 L
.20333 .46154 L
.20621 .44231 L
.21007 .42308 L
.21154 .41673 L
.21508 .40385 L
.22135 .38462 L
.22883 .36538 L
.23077 .36086 L
.23785 .34615 L
.24849 .32692 L
.25 .32442 L
.26107 .30769 L
.26923 .29672 L
.27589 .28846 L
.28846 .27454 L
.29368 .26923 L
.30769 .25664 L
.31601 .25 L
.32692 .24243 L
.34615 .23143 L
.3475 .23077 L
.36538 .22312 L
.38462 .21674 L
.40385 .21163 L
.40422 .21154 L
.42308 .20723 L
Mfstroke
.5 g
.48077 .21087 m
.5 .20843 L
.51923 .20741 L
.53846 .20782 L
.55769 .20969 L
.57018 .21154 L
.57692 .21303 L
.59615 .21791 L
.61538 .22428 L
.63156 .23077 L
.63462 .23212 L
.65385 .24156 L
.66864 .25 L
.67308 .25271 L
.69231 .26605 L
.69637 .26923 L
.71154 .2825 L
.71737 .28846 L
.73077 .30446 L
.7331 .30769 L
.745 .32692 L
.75 .33682 L
.7543 .34615 L
.76206 .36538 L
.76875 .38462 L
.76923 .38611 L
.77469 .40385 L
.77983 .42308 L
.78405 .44231 L
.78722 .46154 L
.78846 .47035 L
.78925 .48077 L
.79014 .5 L
.78991 .51923 L
.78861 .53846 L
.78846 .5402 L
.78626 .55769 L
.78295 .57692 L
.77872 .59615 L
.77353 .61538 L
.76923 .62883 L
.76718 .63462 L
.75912 .65385 L
.75 .67079 L
.7486 .67308 L
.73437 .69231 L
.73077 .6963 L
.71435 .71154 L
.71154 .71374 L
.69231 .7267 L
.68511 .73077 L
.67308 .73697 L
.65385 .74568 L
.64316 .75 L
.63462 .75329 L
.61538 .7602 L
.59615 .76638 L
.58641 .76923 L
.57692 .7719 L
.55769 .77697 L
.53846 .78159 L
.51923 .78568 L
.50363 .78846 L
.5 .789 L
.48077 .79127 L
.46154 .79195 L
.44231 .7907 L
.42552 .78846 L
.42308 .7873 L
.40385 .78165 L
.38462 .77368 L
.37565 .76923 L
.36538 .76338 L
.34615 .75058 L
.34536 .75 L
.32692 .73504 L
.32221 .73077 L
.30769 .7163 L
.30335 .71154 L
.28846 .69368 L
.28741 .69231 L
.27358 .67308 L
.26923 .66652 L
.26134 .65385 L
.25039 .63462 L
.25 .63389 L
.24067 .61538 L
.23238 .59615 L
.23077 .5919 L
.22564 .57692 L
.22049 .55769 L
.2169 .53846 L
.21473 .51923 L
.21383 .5 L
.21411 .48077 L
.21554 .46154 L
.21812 .44231 L
.22189 .42308 L
.22691 .40385 L
.23077 .39159 L
.2333 .38462 L
.2413 .36538 L
.25 .34801 L
.25102 .34615 L
.26284 .32692 L
.26923 .31791 L
.27714 .30769 L
.28846 .29499 L
.29478 .28846 L
.30769 .27704 L
.31757 .26923 L
.32692 .26302 L
.34615 .25223 L
.35089 .25 L
.36538 .24393 L
.38462 .23713 L
.40385 .23107 L
.40484 .23077 L
.42308 .22505 L
.44231 .21939 L
.46154 .21458 L
.4767 .21154 L
F
0 g
.48077 .21087 m
.5 .20843 L
.51923 .20741 L
.53846 .20782 L
.55769 .20969 L
.57018 .21154 L
.57692 .21303 L
.59615 .21791 L
.61538 .22428 L
.63156 .23077 L
.63462 .23212 L
.65385 .24156 L
.66864 .25 L
.67308 .25271 L
.69231 .26605 L
.69637 .26923 L
.71154 .2825 L
.71737 .28846 L
.73077 .30446 L
.7331 .30769 L
.745 .32692 L
.75 .33682 L
.7543 .34615 L
.76206 .36538 L
.76875 .38462 L
.76923 .38611 L
.77469 .40385 L
.77983 .42308 L
.78405 .44231 L
.78722 .46154 L
.78846 .47035 L
.78925 .48077 L
.79014 .5 L
.78991 .51923 L
.78861 .53846 L
.78846 .5402 L
.78626 .55769 L
.78295 .57692 L
.77872 .59615 L
.77353 .61538 L
.76923 .62883 L
.76718 .63462 L
.75912 .65385 L
.75 .67079 L
.7486 .67308 L
.73437 .69231 L
.73077 .6963 L
.71435 .71154 L
.71154 .71374 L
.69231 .7267 L
Mistroke
.68511 .73077 L
.67308 .73697 L
.65385 .74568 L
.64316 .75 L
.63462 .75329 L
.61538 .7602 L
.59615 .76638 L
.58641 .76923 L
.57692 .7719 L
.55769 .77697 L
.53846 .78159 L
.51923 .78568 L
.50363 .78846 L
.5 .789 L
.48077 .79127 L
.46154 .79195 L
.44231 .7907 L
.42552 .78846 L
.42308 .7873 L
.40385 .78165 L
.38462 .77368 L
.37565 .76923 L
.36538 .76338 L
.34615 .75058 L
.34536 .75 L
.32692 .73504 L
.32221 .73077 L
.30769 .7163 L
.30335 .71154 L
.28846 .69368 L
.28741 .69231 L
.27358 .67308 L
.26923 .66652 L
.26134 .65385 L
.25039 .63462 L
.25 .63389 L
.24067 .61538 L
.23238 .59615 L
.23077 .5919 L
.22564 .57692 L
.22049 .55769 L
.2169 .53846 L
.21473 .51923 L
.21383 .5 L
.21411 .48077 L
.21554 .46154 L
.21812 .44231 L
.22189 .42308 L
.22691 .40385 L
.23077 .39159 L
Mistroke
.2333 .38462 L
.2413 .36538 L
.25 .34801 L
.25102 .34615 L
.26284 .32692 L
.26923 .31791 L
.27714 .30769 L
.28846 .29499 L
.29478 .28846 L
.30769 .27704 L
.31757 .26923 L
.32692 .26302 L
.34615 .25223 L
.35089 .25 L
.36538 .24393 L
.38462 .23713 L
.40385 .23107 L
.40484 .23077 L
.42308 .22505 L
.44231 .21939 L
.46154 .21458 L
.4767 .21154 L
.48077 .21087 L
Mfstroke
.6 g
.46154 .22951 m
.48077 .22391 L
.5 .22031 L
.51923 .21856 L
.53846 .21858 L
.55769 .22034 L
.57692 .22382 L
.59615 .22902 L
.60155 .23077 L
.61538 .23594 L
.63462 .24479 L
.64428 .25 L
.65385 .25553 L
.67308 .26884 L
.67358 .26923 L
.69231 .28505 L
.69574 .28846 L
.71154 .30618 L
.7127 .30769 L
.72587 .32692 L
.73077 .3355 L
.73655 .34615 L
.74585 .36538 L
.75 .37527 L
.75396 .38462 L
.76142 .40385 L
.76762 .42308 L
.76923 .42881 L
.77267 .44231 L
.77646 .46154 L
.77889 .48077 L
.77997 .5 L
.77974 .51923 L
.77824 .53846 L
.77555 .55769 L
.77174 .57692 L
.76923 .58734 L
.76689 .59615 L
.76089 .61538 L
.75339 .63462 L
.75 .64202 L
.74409 .65385 L
.73152 .67308 L
.73077 .67405 L
.71428 .69231 L
.71154 .69479 L
.69231 .70953 L
.68919 .71154 L
.67308 .72095 L
.65385 .73022 L
.65255 .73077 L
.63462 .73845 L
.61538 .74566 L
.60122 .75 L
.59615 .75155 L
.57692 .75699 L
.55769 .76169 L
.53846 .76574 L
.51923 .76892 L
.51692 .76923 L
.5 .77209 L
.48077 .77454 L
.46154 .77553 L
.44231 .77459 L
.42308 .77142 L
.4134 .76923 L
.40385 .76598 L
.38462 .758 L
.36954 .75 L
.36538 .74742 L
.34615 .73396 L
.34215 .73077 L
.32692 .71714 L
.3214 .71154 L
.30769 .69598 L
.3048 .69231 L
.29104 .67308 L
.28846 .66917 L
.27931 .65385 L
.26923 .63504 L
.26901 .63462 L
.2595 .61538 L
.25091 .59615 L
.25 .59384 L
.24312 .57692 L
.23662 .55769 L
.2319 .53846 L
.23077 .53272 L
.22858 .51923 L
.22666 .5 L
.22615 .48077 L
.22699 .46154 L
.22918 .44231 L
.23077 .43203 L
.23273 .42308 L
.2378 .40385 L
.24451 .38462 L
.25 .37171 L
.25302 .36538 L
.26375 .34615 L
.26923 .33782 L
.27707 .32692 L
.28846 .31381 L
.29407 .30769 L
.30769 .29597 L
.31715 .28846 L
.32692 .28278 L
.34615 .27333 L
.35694 .26923 L
.36538 .26663 L
.38462 .26079 L
.40385 .25313 L
.41379 .25 L
.42308 .24536 L
.44231 .23624 L
.45799 .23077 L
F
0 g
.46154 .22951 m
.48077 .22391 L
.5 .22031 L
.51923 .21856 L
.53846 .21858 L
.55769 .22034 L
.57692 .22382 L
.59615 .22902 L
.60155 .23077 L
.61538 .23594 L
.63462 .24479 L
.64428 .25 L
.65385 .25553 L
.67308 .26884 L
.67358 .26923 L
.69231 .28505 L
.69574 .28846 L
.71154 .30618 L
.7127 .30769 L
.72587 .32692 L
.73077 .3355 L
.73655 .34615 L
.74585 .36538 L
.75 .37527 L
.75396 .38462 L
.76142 .40385 L
.76762 .42308 L
.76923 .42881 L
.77267 .44231 L
.77646 .46154 L
.77889 .48077 L
.77997 .5 L
.77974 .51923 L
.77824 .53846 L
.77555 .55769 L
.77174 .57692 L
.76923 .58734 L
.76689 .59615 L
.76089 .61538 L
.75339 .63462 L
.75 .64202 L
.74409 .65385 L
.73152 .67308 L
.73077 .67405 L
.71428 .69231 L
.71154 .69479 L
.69231 .70953 L
.68919 .71154 L
.67308 .72095 L
.65385 .73022 L
Mistroke
.65255 .73077 L
.63462 .73845 L
.61538 .74566 L
.60122 .75 L
.59615 .75155 L
.57692 .75699 L
.55769 .76169 L
.53846 .76574 L
.51923 .76892 L
.51692 .76923 L
.5 .77209 L
.48077 .77454 L
.46154 .77553 L
.44231 .77459 L
.42308 .77142 L
.4134 .76923 L
.40385 .76598 L
.38462 .758 L
.36954 .75 L
.36538 .74742 L
.34615 .73396 L
.34215 .73077 L
.32692 .71714 L
.3214 .71154 L
.30769 .69598 L
.3048 .69231 L
.29104 .67308 L
.28846 .66917 L
.27931 .65385 L
.26923 .63504 L
.26901 .63462 L
.2595 .61538 L
.25091 .59615 L
.25 .59384 L
.24312 .57692 L
.23662 .55769 L
.2319 .53846 L
.23077 .53272 L
.22858 .51923 L
.22666 .5 L
.22615 .48077 L
.22699 .46154 L
.22918 .44231 L
.23077 .43203 L
.23273 .42308 L
.2378 .40385 L
.24451 .38462 L
.25 .37171 L
.25302 .36538 L
.26375 .34615 L
Mistroke
.26923 .33782 L
.27707 .32692 L
.28846 .31381 L
.29407 .30769 L
.30769 .29597 L
.31715 .28846 L
.32692 .28278 L
.34615 .27333 L
.35694 .26923 L
.36538 .26663 L
.38462 .26079 L
.40385 .25313 L
.41379 .25 L
.42308 .24536 L
.44231 .23624 L
.45799 .23077 L
.46154 .22951 L
Mfstroke
.7 g
.51923 .22977 m
.53846 .22923 L
.55743 .23077 L
.55769 .2308 L
.57692 .2343 L
.59615 .23993 L
.61538 .24785 L
.61982 .25 L
.63462 .25778 L
.65123 .26923 L
.65385 .27081 L
.67308 .2881 L
.67342 .28846 L
.69001 .30769 L
.69231 .31034 L
.70308 .32692 L
.71154 .34134 L
.71455 .34615 L
.72724 .36538 L
.73077 .37413 L
.73727 .38462 L
.74735 .40385 L
.75 .41142 L
.75492 .42308 L
.7614 .44231 L
.76593 .46154 L
.76876 .48077 L
.76923 .48571 L
.77007 .5 L
.76984 .51923 L
.76923 .52807 L
.76817 .53846 L
.76513 .55769 L
.76068 .57692 L
.75475 .59615 L
.75 .60889 L
.74768 .61538 L
.73868 .63462 L
.73077 .64769 L
.72735 .65385 L
.71154 .67253 L
.71114 .67308 L
.69231 .68953 L
.68866 .69231 L
.67308 .70239 L
.65486 .71154 L
.65385 .71205 L
.63462 .72188 L
.61538 .72791 L
.60754 .73077 L
.59615 .73446 L
.57692 .74096 L
.55769 .74181 L
.53846 .74418 L
.51923 .74639 L
.5 .74931 L
.49612 .75 L
.48077 .75348 L
.46154 .75612 L
.44231 .75621 L
.42308 .75384 L
.40749 .75 L
.40385 .74901 L
.38462 .74143 L
.36583 .73077 L
.36538 .73045 L
.34615 .71609 L
.34105 .71154 L
.32692 .69697 L
.32309 .69231 L
.30929 .67308 L
.30769 .67106 L
.2984 .65385 L
.28971 .63462 L
.28846 .63142 L
.28187 .61538 L
.27183 .59615 L
.26923 .58436 L
.26504 .57692 L
.25388 .55769 L
.25 .54105 L
.24903 .53846 L
.2432 .51923 L
.23969 .5 L
.23809 .48077 L
.23818 .46154 L
.23991 .44231 L
.24331 .42308 L
.24846 .40385 L
.25 .39905 L
.25543 .38462 L
.26481 .36538 L
.26923 .35786 L
.27674 .34615 L
.28846 .33202 L
.29243 .32692 L
.30769 .31424 L
.31348 .30769 L
.32692 .30245 L
.34615 .29599 L
.36538 .29522 L
.38387 .30769 L
.38462 .31136 L
.38493 .32692 L
.38462 .33061 L
.38269 .34615 L
.37981 .36538 L
.37652 .38462 L
.37257 .40385 L
.36764 .42308 L
.36538 .43077 L
.36162 .44231 L
.35432 .46154 L
.34615 .4804 L
.346 .48077 L
.33775 .5 L
.32979 .51923 L
.32692 .5275 L
.32518 .53846 L
.32516 .55769 L
.32692 .57479 L
.32809 .57692 L
.34537 .59615 L
.34615 .59848 L
.36538 .61377 L
.36763 .61538 L
.38462 .6284 L
.39244 .63462 L
.40385 .64428 L
.41441 .65385 L
.42308 .66151 L
.43537 .67308 L
.44231 .67798 L
.46001 .69231 L
.46154 .69324 L
.48077 .70275 L
.5 .70667 L
.51923 .70498 L
.53846 .69894 L
.55411 .69231 L
.55769 .69021 L
.57692 .67764 L
.59395 .67308 L
.59615 .67179 L
.61538 .65879 L
.62357 .65385 L
.63462 .6425 L
.6404 .63462 L
.6492 .61538 L
.653 .59615 L
.65381 .57692 L
.65317 .55769 L
.65223 .53846 L
.65177 .51923 L
.65222 .5 L
.65373 .48077 L
.65385 .47965 L
.65605 .46154 L
.6588 .44231 L
.66112 .42308 L
.66134 .40385 L
.65624 .38462 L
.65385 .37976 L
.63496 .36538 L
.63462 .36522 L
.61538 .35902 L
.59615 .35527 L
.57692 .35217 L
.55769 .34868 L
.54608 .34615 L
.53846 .34424 L
.51923 .33839 L
.5 .33072 L
.49201 .32692 L
.48077 .32207 L
.46154 .31082 L
.45963 .30769 L
.44231 .29666 L
.43533 .28846 L
.43752 .26923 L
.44231 .26251 L
.45697 .25 L
.46154 .24672 L
.48077 .23741 L
.5 .23242 L
.51049 .23077 L
F
0 g
.51923 .22977 m
.53846 .22923 L
.55743 .23077 L
.55769 .2308 L
.57692 .2343 L
.59615 .23993 L
.61538 .24785 L
.61982 .25 L
.63462 .25778 L
.65123 .26923 L
.65385 .27081 L
.67308 .2881 L
.67342 .28846 L
.69001 .30769 L
.69231 .31034 L
.70308 .32692 L
.71154 .34134 L
.71455 .34615 L
.72724 .36538 L
.73077 .37413 L
.73727 .38462 L
.74735 .40385 L
.75 .41142 L
.75492 .42308 L
.7614 .44231 L
.76593 .46154 L
.76876 .48077 L
.76923 .48571 L
.77007 .5 L
.76984 .51923 L
.76923 .52807 L
.76817 .53846 L
.76513 .55769 L
.76068 .57692 L
.75475 .59615 L
.75 .60889 L
.74768 .61538 L
.73868 .63462 L
.73077 .64769 L
.72735 .65385 L
.71154 .67253 L
.71114 .67308 L
.69231 .68953 L
.68866 .69231 L
.67308 .70239 L
.65486 .71154 L
.65385 .71205 L
.63462 .72188 L
.61538 .72791 L
.60754 .73077 L
Mistroke
.59615 .73446 L
.57692 .74096 L
.55769 .74181 L
.53846 .74418 L
.51923 .74639 L
.5 .74931 L
.49612 .75 L
.48077 .75348 L
.46154 .75612 L
.44231 .75621 L
.42308 .75384 L
.40749 .75 L
.40385 .74901 L
.38462 .74143 L
.36583 .73077 L
.36538 .73045 L
.34615 .71609 L
.34105 .71154 L
.32692 .69697 L
.32309 .69231 L
.30929 .67308 L
.30769 .67106 L
.2984 .65385 L
.28971 .63462 L
.28846 .63142 L
.28187 .61538 L
.27183 .59615 L
.26923 .58436 L
.26504 .57692 L
.25388 .55769 L
.25 .54105 L
.24903 .53846 L
.2432 .51923 L
.23969 .5 L
.23809 .48077 L
.23818 .46154 L
.23991 .44231 L
.24331 .42308 L
.24846 .40385 L
.25 .39905 L
.25543 .38462 L
.26481 .36538 L
.26923 .35786 L
.27674 .34615 L
.28846 .33202 L
.29243 .32692 L
.30769 .31424 L
.31348 .30769 L
.32692 .30245 L
.34615 .29599 L
Mistroke
.36538 .29522 L
.38387 .30769 L
.38462 .31136 L
.38493 .32692 L
.38462 .33061 L
.38269 .34615 L
.37981 .36538 L
.37652 .38462 L
.37257 .40385 L
.36764 .42308 L
.36538 .43077 L
.36162 .44231 L
.35432 .46154 L
.34615 .4804 L
.346 .48077 L
.33775 .5 L
.32979 .51923 L
.32692 .5275 L
.32518 .53846 L
.32516 .55769 L
.32692 .57479 L
.32809 .57692 L
.34537 .59615 L
.34615 .59848 L
.36538 .61377 L
.36763 .61538 L
.38462 .6284 L
.39244 .63462 L
.40385 .64428 L
.41441 .65385 L
.42308 .66151 L
.43537 .67308 L
.44231 .67798 L
.46001 .69231 L
.46154 .69324 L
.48077 .70275 L
.5 .70667 L
.51923 .70498 L
.53846 .69894 L
.55411 .69231 L
.55769 .69021 L
.57692 .67764 L
.59395 .67308 L
.59615 .67179 L
.61538 .65879 L
.62357 .65385 L
.63462 .6425 L
.6404 .63462 L
.6492 .61538 L
.653 .59615 L
Mistroke
.65381 .57692 L
.65317 .55769 L
.65223 .53846 L
.65177 .51923 L
.65222 .5 L
.65373 .48077 L
.65385 .47965 L
.65605 .46154 L
.6588 .44231 L
.66112 .42308 L
.66134 .40385 L
.65624 .38462 L
.65385 .37976 L
.63496 .36538 L
.63462 .36522 L
.61538 .35902 L
.59615 .35527 L
.57692 .35217 L
.55769 .34868 L
.54608 .34615 L
.53846 .34424 L
.51923 .33839 L
.5 .33072 L
.49201 .32692 L
.48077 .32207 L
.46154 .31082 L
.45963 .30769 L
.44231 .29666 L
.43533 .28846 L
.43752 .26923 L
.44231 .26251 L
.45697 .25 L
.46154 .24672 L
.48077 .23741 L
.5 .23242 L
.51049 .23077 L
.51923 .22977 L
Mfstroke
.8 g
.32692 .3229 m
.34615 .32217 L
.35438 .32692 L
.3646 .34615 L
.36527 .36538 L
.36423 .38462 L
.36141 .40385 L
.35685 .42308 L
.35046 .44231 L
.34615 .45306 L
.34278 .46154 L
.33319 .48077 L
.32692 .49138 L
.32461 .5 L
.3107 .51923 L
.30769 .52165 L
.29102 .53846 L
.28846 .53916 L
.28178 .53846 L
.26923 .52863 L
.26315 .51923 L
.25285 .5 L
.25099 .48077 L
.25015 .46154 L
.25102 .44231 L
.25397 .42308 L
.25919 .40385 L
.26699 .38462 L
.26923 .38003 L
.27705 .36538 L
.28846 .35069 L
.29022 .34615 L
.30769 .33271 L
.31729 .32692 L
F
0 g
.32692 .3229 m
.34615 .32217 L
.35438 .32692 L
.3646 .34615 L
.36527 .36538 L
.36423 .38462 L
.36141 .40385 L
.35685 .42308 L
.35046 .44231 L
.34615 .45306 L
.34278 .46154 L
.33319 .48077 L
.32692 .49138 L
.32461 .5 L
.3107 .51923 L
.30769 .52165 L
.29102 .53846 L
.28846 .53916 L
.28178 .53846 L
.26923 .52863 L
.26315 .51923 L
.25285 .5 L
.25099 .48077 L
.25015 .46154 L
.25102 .44231 L
.25397 .42308 L
.25919 .40385 L
.26699 .38462 L
.26923 .38003 L
.27705 .36538 L
.28846 .35069 L
.29022 .34615 L
.30769 .33271 L
.31729 .32692 L
.32692 .3229 L
s
.9 g
.32692 .34587 m
.33023 .34615 L
.34615 .35832 L
.34847 .36538 L
.35072 .38462 L
.34896 .40385 L
.34615 .41712 L
.34521 .42308 L
.33901 .44231 L
.32876 .46154 L
.32692 .46443 L
.31581 .48077 L
.30769 .48993 L
.28846 .49991 L
.26923 .4828 L
.26823 .48077 L
.26327 .46154 L
.2631 .44231 L
.26594 .42308 L
.26923 .40822 L
.27063 .40385 L
.27912 .38462 L
.28846 .37149 L
.29363 .36538 L
.30769 .35263 L
.32386 .34615 L
F
0 g
.32692 .34587 m
.33023 .34615 L
.34615 .35832 L
.34847 .36538 L
.35072 .38462 L
.34896 .40385 L
.34615 .41712 L
.34521 .42308 L
.33901 .44231 L
.32876 .46154 L
.32692 .46443 L
.31581 .48077 L
.30769 .48993 L
.28846 .49991 L
.26923 .4828 L
.26823 .48077 L
.26327 .46154 L
.2631 .44231 L
.26594 .42308 L
.26923 .40822 L
.27063 .40385 L
.27912 .38462 L
.28846 .37149 L
.29363 .36538 L
.30769 .35263 L
.32386 .34615 L
.32692 .34587 L
s
1 g
.30769 .3773 m
.32692 .37629 L
.3304 .38462 L
.33281 .40385 L
.33013 .42308 L
.32692 .43338 L
.32114 .44231 L
.30769 .46005 L
.30495 .46154 L
.28846 .46242 L
.2876 .46154 L
.28035 .44231 L
.2814 .42308 L
.28684 .40385 L
.28846 .40072 L
.29974 .38462 L
F
0 g
.30769 .3773 m
.32692 .37629 L
.3304 .38462 L
.33281 .40385 L
.33013 .42308 L
.32692 .43338 L
.32114 .44231 L
.30769 .46005 L
.30495 .46154 L
.28846 .46242 L
.2876 .46154 L
.28035 .44231 L
.2814 .42308 L
.28684 .40385 L
.28846 .40072 L
.29974 .38462 L
.30769 .3773 L
s
.8 g
.32692 .62648 m
.34615 .62707 L
.36082 .63462 L
.36538 .63593 L
.38462 .65011 L
.38935 .65385 L
.40385 .66659 L
.4093 .67308 L
.42308 .6895 L
.42532 .69231 L
.43703 .71154 L
.42308 .72731 L
.40385 .72669 L
.38462 .72192 L
.36826 .71154 L
.36538 .70958 L
.34615 .69277 L
.34575 .69231 L
.33006 .67308 L
.32692 .66418 L
.32238 .65385 L
.3212 .63462 L
F
0 g
.32692 .62648 m
.34615 .62707 L
.36082 .63462 L
.36538 .63593 L
.38462 .65011 L
.38935 .65385 L
.40385 .66659 L
.4093 .67308 L
.42308 .6895 L
.42532 .69231 L
.43703 .71154 L
.42308 .72731 L
.40385 .72669 L
.38462 .72192 L
.36826 .71154 L
.36538 .70958 L
.34615 .69277 L
.34575 .69231 L
.33006 .67308 L
.32692 .66418 L
.32238 .65385 L
.3212 .63462 L
.32692 .62648 L
s
.5 g
.42308 .32544 m
.44231 .3242 L
.45585 .32692 L
.46154 .32873 L
.48077 .33583 L
.5 .34303 L
.50908 .34615 L
.51923 .34948 L
.53846 .35495 L
.55769 .35945 L
.57692 .36343 L
.58611 .36538 L
.59615 .36775 L
.61538 .37415 L
.63176 .38462 L
.63462 .3871 L
.64399 .40385 L
.64725 .42308 L
.6469 .44231 L
.64524 .46154 L
.64348 .48077 L
.64227 .5 L
.64182 .51923 L
.642 .53846 L
.64233 .55769 L
.64191 .57692 L
.63942 .59615 L
.63462 .61224 L
.63299 .61538 L
.61956 .63462 L
.61538 .63866 L
.59615 .65276 L
.59433 .65385 L
.57692 .66264 L
.55769 .67123 L
.55339 .67308 L
.53846 .6776 L
.51923 .68237 L
.5 .68368 L
.48077 .68029 L
.46263 .67308 L
.46154 .67212 L
.44231 .65878 L
.43601 .65385 L
.42308 .64269 L
.41378 .63462 L
.40385 .62602 L
.39138 .61538 L
.38462 .60971 L
.36944 .59615 L
.36538 .59238 L
.35265 .57692 L
.34615 .56496 L
.34384 .55769 L
.34201 .53846 L
.34491 .51923 L
.34615 .51253 L
.35081 .5 L
.35811 .48077 L
.36538 .46186 L
.36551 .46154 L
.37239 .44231 L
.37845 .42308 L
.38378 .40385 L
.38462 .40069 L
.38872 .38462 L
.39415 .36538 L
.40182 .34615 L
.40385 .3428 L
.41881 .32692 L
F
0 g
.42308 .32544 m
.44231 .3242 L
.45585 .32692 L
.46154 .32873 L
.48077 .33583 L
.5 .34303 L
.50908 .34615 L
.51923 .34948 L
.53846 .35495 L
.55769 .35945 L
.57692 .36343 L
.58611 .36538 L
.59615 .36775 L
.61538 .37415 L
.63176 .38462 L
.63462 .3871 L
.64399 .40385 L
.64725 .42308 L
.6469 .44231 L
.64524 .46154 L
.64348 .48077 L
.64227 .5 L
.64182 .51923 L
.642 .53846 L
.64233 .55769 L
.64191 .57692 L
.63942 .59615 L
.63462 .61224 L
.63299 .61538 L
.61956 .63462 L
.61538 .63866 L
.59615 .65276 L
.59433 .65385 L
.57692 .66264 L
.55769 .67123 L
.55339 .67308 L
.53846 .6776 L
.51923 .68237 L
.5 .68368 L
.48077 .68029 L
.46263 .67308 L
.46154 .67212 L
.44231 .65878 L
.43601 .65385 L
.42308 .64269 L
.41378 .63462 L
.40385 .62602 L
.39138 .61538 L
.38462 .60971 L
.36944 .59615 L
Mistroke
.36538 .59238 L
.35265 .57692 L
.34615 .56496 L
.34384 .55769 L
.34201 .53846 L
.34491 .51923 L
.34615 .51253 L
.35081 .5 L
.35811 .48077 L
.36538 .46186 L
.36551 .46154 L
.37239 .44231 L
.37845 .42308 L
.38378 .40385 L
.38462 .40069 L
.38872 .38462 L
.39415 .36538 L
.40182 .34615 L
.40385 .3428 L
.41881 .32692 L
.42308 .32544 L
Mfstroke
.4 g
.44231 .34343 m
.46154 .34451 L
.46938 .34615 L
.48077 .34919 L
.5 .35504 L
.51923 .36081 L
.53616 .36538 L
.53846 .36596 L
.55769 .37051 L
.57692 .37515 L
.59615 .38122 L
.60381 .38462 L
.61538 .39151 L
.62611 .40385 L
.63312 .42308 L
.63462 .43847 L
.6347 .44231 L
.63462 .45005 L
.63413 .46154 L
.63298 .48077 L
.63204 .5 L
.6316 .51923 L
.63153 .53846 L
.63131 .55769 L
.62992 .57692 L
.62574 .59615 L
.61625 .61538 L
.61538 .61664 L
.59728 .63462 L
.59615 .63544 L
.57692 .64701 L
.56218 .65385 L
.55769 .65559 L
.53846 .66216 L
.51923 .66638 L
.5 .66713 L
.48077 .66332 L
.46154 .6545 L
.46038 .65385 L
.44231 .64112 L
.43419 .63462 L
.42308 .62514 L
.41187 .61538 L
.40385 .60834 L
.39054 .59615 L
.38462 .59051 L
.37275 .57692 L
.36538 .56698 L
.36177 .55769 L
.35776 .53846 L
.35903 .51923 L
.36368 .5 L
.36538 .49404 L
.37003 .48077 L
.37691 .46154 L
.38356 .44231 L
.38462 .43914 L
.38964 .42308 L
.39553 .40385 L
.40205 .38462 L
.40385 .38009 L
.41036 .36538 L
.42308 .351 L
.4314 .34615 L
F
0 g
.44231 .34343 m
.46154 .34451 L
.46938 .34615 L
.48077 .34919 L
.5 .35504 L
.51923 .36081 L
.53616 .36538 L
.53846 .36596 L
.55769 .37051 L
.57692 .37515 L
.59615 .38122 L
.60381 .38462 L
.61538 .39151 L
.62611 .40385 L
.63312 .42308 L
.63462 .43847 L
.6347 .44231 L
.63462 .45005 L
.63413 .46154 L
.63298 .48077 L
.63204 .5 L
.6316 .51923 L
.63153 .53846 L
.63131 .55769 L
.62992 .57692 L
.62574 .59615 L
.61625 .61538 L
.61538 .61664 L
.59728 .63462 L
.59615 .63544 L
.57692 .64701 L
.56218 .65385 L
.55769 .65559 L
.53846 .66216 L
.51923 .66638 L
.5 .66713 L
.48077 .66332 L
.46154 .6545 L
.46038 .65385 L
.44231 .64112 L
.43419 .63462 L
.42308 .62514 L
.41187 .61538 L
.40385 .60834 L
.39054 .59615 L
.38462 .59051 L
.37275 .57692 L
.36538 .56698 L
.36177 .55769 L
.35776 .53846 L
Mistroke
.35903 .51923 L
.36368 .5 L
.36538 .49404 L
.37003 .48077 L
.37691 .46154 L
.38356 .44231 L
.38462 .43914 L
.38964 .42308 L
.39553 .40385 L
.40205 .38462 L
.40385 .38009 L
.41036 .36538 L
.42308 .351 L
.4314 .34615 L
.44231 .34343 L
Mfstroke
.3 g
.44231 .36278 m
.46154 .36037 L
.48077 .3631 L
.49292 .36538 L
.5 .36776 L
.51923 .37284 L
.53846 .37781 L
.55769 .38278 L
.56432 .38462 L
.57692 .38837 L
.59615 .39704 L
.60498 .40385 L
.61538 .41736 L
.6175 .42308 L
.62153 .44231 L
.62218 .46154 L
.62163 .48077 L
.62093 .5 L
.62048 .51923 L
.62015 .53846 L
.61932 .55769 L
.61676 .57692 L
.61538 .58345 L
.6106 .59615 L
.59711 .61538 L
.59615 .61635 L
.57692 .63088 L
.57018 .63462 L
.55769 .64032 L
.53846 .64701 L
.51923 .65089 L
.5 .65112 L
.48077 .64668 L
.46154 .6371 L
.45754 .63462 L
.44231 .62327 L
.43274 .61538 L
.42308 .60698 L
.4112 .59615 L
.40385 .58919 L
.39256 .57692 L
.38462 .56706 L
.3797 .55769 L
.37374 .53846 L
.3735 .51923 L
.37707 .5 L
.38276 .48077 L
.38462 .475 L
.38912 .46154 L
.3956 .44231 L
.40211 .42308 L
.40385 .41809 L
.40882 .40385 L
.41782 .38462 L
.42308 .37719 L
.43655 .36538 L
F
0 g
.44231 .36278 m
.46154 .36037 L
.48077 .3631 L
.49292 .36538 L
.5 .36776 L
.51923 .37284 L
.53846 .37781 L
.55769 .38278 L
.56432 .38462 L
.57692 .38837 L
.59615 .39704 L
.60498 .40385 L
.61538 .41736 L
.6175 .42308 L
.62153 .44231 L
.62218 .46154 L
.62163 .48077 L
.62093 .5 L
.62048 .51923 L
.62015 .53846 L
.61932 .55769 L
.61676 .57692 L
.61538 .58345 L
.6106 .59615 L
.59711 .61538 L
.59615 .61635 L
.57692 .63088 L
.57018 .63462 L
.55769 .64032 L
.53846 .64701 L
.51923 .65089 L
.5 .65112 L
.48077 .64668 L
.46154 .6371 L
.45754 .63462 L
.44231 .62327 L
.43274 .61538 L
.42308 .60698 L
.4112 .59615 L
.40385 .58919 L
.39256 .57692 L
.38462 .56706 L
.3797 .55769 L
.37374 .53846 L
.3735 .51923 L
.37707 .5 L
.38276 .48077 L
.38462 .475 L
.38912 .46154 L
.3956 .44231 L
Mistroke
.40211 .42308 L
.40385 .41809 L
.40882 .40385 L
.41782 .38462 L
.42308 .37719 L
.43655 .36538 L
.44231 .36278 L
Mfstroke
.2 g
.46154 .37823 m
.48077 .37868 L
.5 .38222 L
.51081 .38462 L
.51923 .38673 L
.53846 .39154 L
.55769 .39712 L
.57457 .40385 L
.57692 .4049 L
.59615 .42014 L
.59812 .42308 L
.60599 .44231 L
.60831 .46154 L
.60856 .48077 L
.6082 .5 L
.60775 .51923 L
.6071 .53846 L
.60551 .55769 L
.6014 .57692 L
.59615 .58998 L
.59214 .59615 L
.57692 .61194 L
.57211 .61538 L
.55769 .62341 L
.53846 .63056 L
.51923 .6342 L
.5 .63385 L
.48077 .62858 L
.46154 .61798 L
.45768 .61538 L
.44231 .60336 L
.43399 .59615 L
.42308 .58606 L
.41427 .57692 L
.40385 .56464 L
.39955 .55769 L
.39151 .53846 L
.38967 .51923 L
.39212 .5 L
.3971 .48077 L
.40329 .46154 L
.40385 .45989 L
.40964 .44231 L
.41681 .42308 L
.42308 .40947 L
.42562 .40385 L
.44231 .3852 L
.44321 .38462 L
F
0 g
.46154 .37823 m
.48077 .37868 L
.5 .38222 L
.51081 .38462 L
.51923 .38673 L
.53846 .39154 L
.55769 .39712 L
.57457 .40385 L
.57692 .4049 L
.59615 .42014 L
.59812 .42308 L
.60599 .44231 L
.60831 .46154 L
.60856 .48077 L
.6082 .5 L
.60775 .51923 L
.6071 .53846 L
.60551 .55769 L
.6014 .57692 L
.59615 .58998 L
.59214 .59615 L
.57692 .61194 L
.57211 .61538 L
.55769 .62341 L
.53846 .63056 L
.51923 .6342 L
.5 .63385 L
.48077 .62858 L
.46154 .61798 L
.45768 .61538 L
.44231 .60336 L
.43399 .59615 L
.42308 .58606 L
.41427 .57692 L
.40385 .56464 L
.39955 .55769 L
.39151 .53846 L
.38967 .51923 L
.39212 .5 L
.3971 .48077 L
.40329 .46154 L
.40385 .45989 L
.40964 .44231 L
.41681 .42308 L
.42308 .40947 L
.42562 .40385 L
.44231 .3852 L
.44321 .38462 L
.46154 .37823 L
s
.1 g
.46154 .40167 m
.48077 .39853 L
.5 .40046 L
.51827 .40385 L
.51923 .40449 L
.53846 .40941 L
.55769 .41674 L
.56831 .42308 L
.57692 .42989 L
.5847 .44231 L
.59017 .46154 L
.5917 .48077 L
.59183 .5 L
.5914 .51923 L
.5903 .53846 L
.5875 .55769 L
.58052 .57692 L
.57692 .58316 L
.565 .59615 L
.55769 .60127 L
.53846 .61021 L
.51923 .61388 L
.5 .61282 L
.48077 .60623 L
.46402 .59615 L
.46154 .59411 L
.44231 .57766 L
.44155 .57692 L
.42441 .55769 L
.42308 .55645 L
.41375 .53846 L
.40984 .51923 L
.41096 .5 L
.41521 .48077 L
.42129 .46154 L
.42308 .45648 L
.42806 .44231 L
.43759 .42308 L
.44231 .4166 L
.45689 .40385 L
F
0 g
.46154 .40167 m
.48077 .39853 L
.5 .40046 L
.51827 .40385 L
.51923 .40449 L
.53846 .40941 L
.55769 .41674 L
.56831 .42308 L
.57692 .42989 L
.5847 .44231 L
.59017 .46154 L
.5917 .48077 L
.59183 .5 L
.5914 .51923 L
.5903 .53846 L
.5875 .55769 L
.58052 .57692 L
.57692 .58316 L
.565 .59615 L
.55769 .60127 L
.53846 .61021 L
.51923 .61388 L
.5 .61282 L
.48077 .60623 L
.46402 .59615 L
.46154 .59411 L
.44231 .57766 L
.44155 .57692 L
.42441 .55769 L
.42308 .55645 L
.41375 .53846 L
.40984 .51923 L
.41096 .5 L
.41521 .48077 L
.42129 .46154 L
.42308 .45648 L
.42806 .44231 L
.43759 .42308 L
.44231 .4166 L
.45689 .40385 L
.46154 .40167 L
s
.48077 .43167 m
.5 .42983 L
.51923 .43318 L
.53846 .44144 L
.53994 .44231 L
.55769 .46135 L
.55778 .46154 L
.56382 .48077 L
.56541 .5 L
.56493 .51923 L
.56225 .53846 L
.55769 .55389 L
.55641 .55769 L
.53846 .57538 L
.53486 .57692 L
.51923 .58138 L
.5 .57926 L
.49371 .57692 L
.48077 .57039 L
.46486 .55769 L
.46154 .55437 L
.44951 .53846 L
.44238 .51923 L
.44231 .51884 L
.4413 .5 L
.44231 .49217 L
.44435 .48077 L
.45068 .46154 L
.46154 .44494 L
.46419 .44231 L
F
.48077 .43167 m
.5 .42983 L
.51923 .43318 L
.53846 .44144 L
.53994 .44231 L
.55769 .46135 L
.55778 .46154 L
.56382 .48077 L
.56541 .5 L
.56493 .51923 L
.56225 .53846 L
.55769 .55389 L
.55641 .55769 L
.53846 .57538 L
.53486 .57692 L
.51923 .58138 L
.5 .57926 L
.49371 .57692 L
.48077 .57039 L
.46486 .55769 L
.46154 .55437 L
.44951 .53846 L
.44238 .51923 L
.44231 .51884 L
.4413 .5 L
.44231 .49217 L
.44435 .48077 L
.45068 .46154 L
.46154 .44494 L
.46419 .44231 L
.48077 .43167 L
s
.8 g
.5 .24605 m
.51923 .24128 L
.53846 .23999 L
.55769 .24137 L
.57692 .24526 L
.59204 .25 L
.59615 .25142 L
.61538 .26036 L
.62851 .26923 L
.63462 .27112 L
.65026 .28846 L
.65385 .29276 L
.6638 .30769 L
.67013 .32692 L
.65385 .34468 L
.63462 .34529 L
.61538 .34406 L
.59615 .34281 L
.57692 .34095 L
.55769 .33792 L
.53846 .33319 L
.52083 .32692 L
.51923 .32643 L
.5 .31787 L
.48642 .30769 L
.48077 .30291 L
.4696 .28846 L
.46953 .26923 L
.48077 .25638 L
.49105 .25 L
F
0 g
.5 .24605 m
.51923 .24128 L
.53846 .23999 L
.55769 .24137 L
.57692 .24526 L
.59204 .25 L
.59615 .25142 L
.61538 .26036 L
.62851 .26923 L
.63462 .27112 L
.65026 .28846 L
.65385 .29276 L
.6638 .30769 L
.67013 .32692 L
.65385 .34468 L
.63462 .34529 L
.61538 .34406 L
.59615 .34281 L
.57692 .34095 L
.55769 .33792 L
.53846 .33319 L
.52083 .32692 L
.51923 .32643 L
.5 .31787 L
.48642 .30769 L
.48077 .30291 L
.4696 .28846 L
.46953 .26923 L
.48077 .25638 L
.49105 .25 L
.5 .24605 L
s
.9 g
.5 .26686 m
.51923 .2562 L
.53846 .25297 L
.55769 .25203 L
.57692 .25624 L
.59615 .26494 L
.60307 .26923 L
.61538 .27822 L
.6255 .28846 L
.63313 .30769 L
.61538 .32481 L
.60551 .32692 L
.59615 .32798 L
.57692 .32787 L
.56774 .32692 L
.55769 .32648 L
.53846 .32238 L
.51923 .31271 L
.51257 .30769 L
.5 .29616 L
.49527 .28846 L
.49785 .26923 L
F
0 g
.5 .26686 m
.51923 .2562 L
.53846 .25297 L
.55769 .25203 L
.57692 .25624 L
.59615 .26494 L
.60307 .26923 L
.61538 .27822 L
.6255 .28846 L
.63313 .30769 L
.61538 .32481 L
.60551 .32692 L
.59615 .32798 L
.57692 .32787 L
.56774 .32692 L
.55769 .32648 L
.53846 .32238 L
.51923 .31271 L
.51257 .30769 L
.5 .29616 L
.49527 .28846 L
.49785 .26923 L
.5 .26686 L
s
1 g
.53846 .27143 m
.55769 .27014 L
.57692 .27548 L
.59407 .28846 L
.58726 .30769 L
.57692 .30993 L
.55769 .30949 L
.55299 .30769 L
.53846 .30169 L
.5232 .28846 L
F
0 g
.53846 .27143 m
.55769 .27014 L
.57692 .27548 L
.59407 .28846 L
.58726 .30769 L
.57692 .30993 L
.55769 .30949 L
.55299 .30769 L
.53846 .30169 L
.5232 .28846 L
.53846 .27143 L
s
.8 g
.69231 .38937 m
.71154 .39032 L
.72632 .40385 L
.73077 .40934 L
.74168 .42308 L
.74927 .44231 L
.75 .44619 L
.75476 .46154 L
.75853 .48077 L
.7602 .5 L
.75997 .51923 L
.75794 .53846 L
.75407 .55769 L
.75 .572 L
.74888 .57692 L
.74209 .59615 L
.73124 .61538 L
.73077 .6161 L
.7217 .63462 L
.71154 .64276 L
.70006 .65385 L
.69231 .65995 L
.67308 .67013 L
.65938 .65385 L
.66232 .63462 L
.66692 .61538 L
.66741 .59615 L
.66608 .57692 L
.66413 .55769 L
.66245 .53846 L
.66166 .51923 L
.66212 .5 L
.66402 .48077 L
.66736 .46154 L
.67205 .44231 L
.67308 .43911 L
.6776 .42308 L
.68415 .40385 L
F
0 g
.69231 .38937 m
.71154 .39032 L
.72632 .40385 L
.73077 .40934 L
.74168 .42308 L
.74927 .44231 L
.75 .44619 L
.75476 .46154 L
.75853 .48077 L
.7602 .5 L
.75997 .51923 L
.75794 .53846 L
.75407 .55769 L
.75 .572 L
.74888 .57692 L
.74209 .59615 L
.73124 .61538 L
.73077 .6161 L
.7217 .63462 L
.71154 .64276 L
.70006 .65385 L
.69231 .65995 L
.67308 .67013 L
.65938 .65385 L
.66232 .63462 L
.66692 .61538 L
.66741 .59615 L
.66608 .57692 L
.66413 .55769 L
.66245 .53846 L
.66166 .51923 L
.66212 .5 L
.66402 .48077 L
.66736 .46154 L
.67205 .44231 L
.67308 .43911 L
.6776 .42308 L
.68415 .40385 L
.69231 .38937 L
s
.9 g
.69231 .43724 m
.71154 .42627 L
.73077 .44066 L
.7324 .44231 L
.7444 .46154 L
.74838 .48077 L
.74951 .5 L
.74937 .51923 L
.74778 .53846 L
.74336 .55769 L
.73398 .57692 L
.73077 .58167 L
.72058 .59615 L
.71154 .60442 L
.69231 .60192 L
.68889 .59615 L
.68196 .57692 L
.67742 .55769 L
.67339 .53846 L
.67308 .52144 L
.673 .51923 L
.67308 .5075 L
.67322 .5 L
.67434 .48077 L
.67766 .46154 L
.68727 .44231 L
F
0 g
.69231 .43724 m
.71154 .42627 L
.73077 .44066 L
.7324 .44231 L
.7444 .46154 L
.74838 .48077 L
.74951 .5 L
.74937 .51923 L
.74778 .53846 L
.74336 .55769 L
.73398 .57692 L
.73077 .58167 L
.72058 .59615 L
.71154 .60442 L
.69231 .60192 L
.68889 .59615 L
.68196 .57692 L
.67742 .55769 L
.67339 .53846 L
.67308 .52144 L
.673 .51923 L
.67308 .5075 L
.67322 .5 L
.67434 .48077 L
.67766 .46154 L
.68727 .44231 L
.69231 .43724 L
s
1 g
.71154 .45927 m
.71791 .46154 L
.73077 .47982 L
.73119 .48077 L
.73686 .5 L
.73657 .51923 L
.73102 .53846 L
.73077 .53909 L
.72108 .55769 L
.71154 .56504 L
.69759 .55769 L
.69231 .5483 L
.68803 .53846 L
.68416 .51923 L
.68504 .5 L
.69128 .48077 L
.69231 .47868 L
.70454 .46154 L
F
0 g
.71154 .45927 m
.71791 .46154 L
.73077 .47982 L
.73119 .48077 L
.73686 .5 L
.73657 .51923 L
.73102 .53846 L
.73077 .53909 L
.72108 .55769 L
.71154 .56504 L
.69759 .55769 L
.69231 .5483 L
.68803 .53846 L
.68416 .51923 L
.68504 .5 L
.69128 .48077 L
.69231 .47868 L
.70454 .46154 L
.71154 .45927 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.663 .741 .908 r
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56654 Mtetra
.5035 .56654 .50935 .57245 .51999 .56925 .51417 .56333 Mtetra
.51417 .56333 .51999 .56925 .53068 .56605 .52489 .5601 Mtetra
.52489 .5601 .53068 .56605 .54141 .56283 .53564 .55687 Mtetra
.663 .742 .908 r
.53564 .55687 .54141 .56283 .55218 .55961 .54644 .55363 Mtetra
.663 .742 .909 r
.54644 .55363 .55218 .55961 .56299 .55638 .55728 .55039 Mtetra
.662 .742 .91 r
.55728 .55039 .56299 .55638 .57385 .55314 .56816 .54716 Mtetra
.661 .743 .91 r
.56816 .54716 .57385 .55314 .58474 .54989 .57909 .54392 Mtetra
.661 .744 .912 r
.57909 .54392 .58474 .54989 .59569 .54664 .59006 .54069 Mtetra
.66 .745 .913 r
.59006 .54069 .59569 .54664 .60667 .54339 .60108 .53747 Mtetra
.659 .747 .915 r
.60108 .53747 .60667 .54339 .6177 .54013 .61214 .53425 Mtetra
.659 .749 .917 r
.61214 .53425 .6177 .54013 .62877 .53686 .62324 .53103 Mtetra
.659 .751 .918 r
.62324 .53103 .62877 .53686 .63989 .53358 .63439 .52778 Mtetra
.66 .753 .919 r
.63439 .52778 .63989 .53358 .65105 .53028 .64559 .52449 Mtetra
.661 .755 .92 r
.64559 .52449 .65105 .53028 .66226 .52695 .65682 .52116 Mtetra
.662 .756 .92 r
.65682 .52116 .66226 .52695 .6735 .52359 .66811 .51777 Mtetra
.664 .757 .919 r
.66811 .51777 .6735 .52359 .6848 .52019 .67943 .51432 Mtetra
.665 .756 .918 r
.67943 .51432 .6848 .52019 .69614 .51676 .6908 .51082 Mtetra
.666 .755 .916 r
.6908 .51082 .69614 .51676 .70752 .51331 .70221 .50727 Mtetra
.667 .753 .915 r
.70221 .50727 .70752 .51331 .71895 .50983 .71367 .50371 Mtetra
.667 .751 .913 r
.71367 .50371 .71895 .50983 .73042 .50633 .72517 .50013 Mtetra
.666 .749 .912 r
.72517 .50013 .73042 .50633 .74194 .50283 .73672 .49655 Mtetra
.666 .747 .911 r
.73672 .49655 .74194 .50283 .7535 .49932 .74832 .49298 Mtetra
.665 .745 .91 r
.74832 .49298 .7535 .49932 .76512 .49581 .75996 .48942 Mtetra
.665 .744 .91 r
.75996 .48942 .76512 .49581 .77678 .4923 .77166 .48586 Mtetra
.664 .744 .909 r
.77166 .48586 .77678 .4923 .78849 .48877 .7834 .4823 Mtetra
.664 .743 .909 r
.7834 .4823 .78849 .48877 .80024 .48523 .79519 .47873 Mtetra
.79519 .47873 .80024 .48523 .81205 .48168 .80703 .47514 Mtetra
.80703 .47514 .81205 .48168 .8239 .47811 .81892 .47154 Mtetra
.81892 .47154 .8239 .47811 .8358 .47453 .83085 .46793 Mtetra
.664 .742 .908 r
.83085 .46793 .8358 .47453 .84776 .47094 .84284 .4643 Mtetra
.84284 .4643 .84776 .47094 .85976 .46733 .85487 .46066 Mtetra
.85487 .46066 .85976 .46733 .87181 .46371 .86696 .45701 Mtetra
.86696 .45701 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.664 .741 .908 r
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44967 Mtetra
.89128 .44967 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.663 .741 .908 r
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56382 Mtetra
.48695 .56382 .49287 .56975 .5035 .56654 .49761 .5606 Mtetra
.49761 .5606 .5035 .56654 .51417 .56333 .50831 .55737 Mtetra
.50831 .55737 .51417 .56333 .52489 .5601 .51905 .55413 Mtetra
.663 .742 .909 r
.51905 .55413 .52489 .5601 .53564 .55687 .52983 .55089 Mtetra
.662 .742 .909 r
.52983 .55089 .53564 .55687 .54644 .55363 .54066 .54765 Mtetra
.661 .743 .91 r
.54066 .54765 .54644 .55363 .55728 .55039 .55153 .54443 Mtetra
.66 .743 .912 r
.55153 .54443 .55728 .55039 .56816 .54716 .56244 .54122 Mtetra
.658 .745 .914 r
.56244 .54122 .56816 .54716 .57909 .54392 .5734 .53804 Mtetra
.657 .747 .917 r
.5734 .53804 .57909 .54392 .59006 .54069 .5844 .53489 Mtetra
.655 .75 .92 r
.5844 .53489 .59006 .54069 .60108 .53747 .59545 .53177 Mtetra
.654 .754 .923 r
.59545 .53177 .60108 .53747 .61214 .53425 .60654 .52865 Mtetra
.653 .758 .927 r
.60654 .52865 .61214 .53425 .62324 .53103 .61768 .52553 Mtetra
.654 .763 .93 r
.61768 .52553 .62324 .53103 .63439 .52778 .62887 .52236 Mtetra
.656 .767 .932 r
.62887 .52236 .63439 .52778 .64559 .52449 .6401 .51911 Mtetra
.658 .771 .932 r
.6401 .51911 .64559 .52449 .65682 .52116 .65137 .51578 Mtetra
.662 .772 .931 r
.65137 .51578 .65682 .52116 .66811 .51777 .66268 .51233 Mtetra
.665 .772 .929 r
.66268 .51233 .66811 .51777 .67943 .51432 .67404 .50878 Mtetra
.668 .771 .927 r
.67404 .50878 .67943 .51432 .6908 .51082 .68544 .50515 Mtetra
.67 .767 .923 r
.68544 .50515 .6908 .51082 .70221 .50727 .69688 .50146 Mtetra
.671 .763 .92 r
.69688 .50146 .70221 .50727 .71367 .50371 .70836 .49774 Mtetra
.67 .759 .917 r
.70836 .49774 .71367 .50371 .72517 .50013 .71989 .49403 Mtetra
.669 .755 .914 r
.71989 .49403 .72517 .50013 .73672 .49655 .73147 .49034 Mtetra
.668 .751 .913 r
.73147 .49034 .73672 .49655 .74832 .49298 .7431 .48668 Mtetra
.666 .748 .912 r
.7431 .48668 .74832 .49298 .75996 .48942 .75477 .48305 Mtetra
.665 .747 .911 r
.75477 .48305 .75996 .48942 .77166 .48586 .7665 .47944 Mtetra
.665 .746 .911 r
.7665 .47944 .77166 .48586 .7834 .4823 .77827 .47583 Mtetra
.664 .745 .91 r
.77827 .47583 .7834 .4823 .79519 .47873 .7901 .47222 Mtetra
.7901 .47222 .79519 .47873 .80703 .47514 .80197 .46859 Mtetra
.665 .744 .909 r
.80197 .46859 .80703 .47514 .81892 .47154 .81389 .46495 Mtetra
.81389 .46495 .81892 .47154 .83085 .46793 .82586 .46129 Mtetra
.664 .743 .909 r
.82586 .46129 .83085 .46793 .84284 .4643 .83788 .45762 Mtetra
.664 .743 .908 r
.83788 .45762 .84284 .4643 .85487 .46066 .84995 .45394 Mtetra
.664 .742 .908 r
.84995 .45394 .85487 .46066 .86696 .45701 .86207 .45025 Mtetra
.86207 .45025 .86696 .45701 .87909 .45334 .87425 .44656 Mtetra
.87425 .44656 .87909 .45334 .89128 .44967 .88647 .44285 Mtetra
.664 .741 .908 r
.88647 .44285 .89128 .44967 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.663 .741 .908 r
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .5611 Mtetra
.47035 .5611 .47634 .56704 .48695 .56382 .48099 .55786 Mtetra
.48099 .55786 .48695 .56382 .49761 .5606 .49168 .55462 Mtetra
.663 .742 .908 r
.49168 .55462 .49761 .5606 .50831 .55737 .5024 .55137 Mtetra
.662 .742 .909 r
.5024 .55137 .50831 .55737 .51905 .55413 .51317 .54813 Mtetra
.661 .742 .91 r
.51317 .54813 .51905 .55413 .52983 .55089 .52398 .5449 Mtetra
.66 .743 .911 r
.52398 .5449 .52983 .55089 .54066 .54765 .53484 .5417 Mtetra
.658 .744 .914 r
.53484 .5417 .54066 .54765 .55153 .54443 .54574 .53854 Mtetra
.655 .746 .917 r
.54574 .53854 .55153 .54443 .56244 .54122 .55668 .53543 Mtetra
.652 .75 .921 r
.55668 .53543 .56244 .54122 .5734 .53804 .56767 .5324 Mtetra
.648 .754 .927 r
.56767 .5324 .5734 .53804 .5844 .53489 .5787 .52943 Mtetra
.644 .761 .933 r
.5787 .52943 .5844 .53489 .59545 .53177 .58979 .52652 Mtetra
.641 .768 .94 r
.58979 .52652 .59545 .53177 .60654 .52865 .60092 .52362 Mtetra
.64 .777 .946 r
.60092 .52362 .60654 .52865 .61768 .52553 .6121 .5207 Mtetra
.641 .787 .951 r
.6121 .5207 .61768 .52553 .62887 .52236 .62332 .51768 Mtetra
.645 .795 .954 r
.62332 .51768 .62887 .52236 .6401 .51911 .63459 .51452 Mtetra
.652 .801 .954 r
.63459 .51452 .6401 .51911 .65137 .51578 .6459 .51117 Mtetra
.66 .803 .952 r
.6459 .51117 .65137 .51578 .66268 .51233 .65725 .50762 Mtetra
.667 .802 .947 r
.65725 .50762 .66268 .51233 .67404 .50878 .66864 .50388 Mtetra
.673 .798 .941 r
.66864 .50388 .67404 .50878 .68544 .50515 .68006 .50001 Mtetra
.677 .79 .935 r
.68006 .50001 .68544 .50515 .69688 .50146 .69152 .49606 Mtetra
.677 .782 .929 r
.69152 .49606 .69688 .50146 .70836 .49774 .70303 .49209 Mtetra
.676 .773 .924 r
.70303 .49209 .70836 .49774 .71989 .49403 .71459 .48815 Mtetra
.674 .765 .919 r
.71459 .48815 .71989 .49403 .73147 .49034 .72619 .48428 Mtetra
.671 .759 .917 r
.72619 .48428 .73147 .49034 .7431 .48668 .73785 .48048 Mtetra
.669 .754 .915 r
.73785 .48048 .7431 .48668 .75477 .48305 .74955 .47675 Mtetra
.667 .751 .913 r
.74955 .47675 .75477 .48305 .7665 .47944 .76131 .47306 Mtetra
.666 .749 .913 r
.76131 .47306 .7665 .47944 .77827 .47583 .77312 .4694 Mtetra
.665 .748 .912 r
.77312 .4694 .77827 .47583 .7901 .47222 .78497 .46573 Mtetra
.665 .747 .911 r
.78497 .46573 .7901 .47222 .80197 .46859 .79688 .46205 Mtetra
.79688 .46205 .80197 .46859 .81389 .46495 .80883 .45836 Mtetra
.665 .746 .91 r
.80883 .45836 .81389 .46495 .82586 .46129 .82084 .45464 Mtetra
.665 .745 .909 r
.82084 .45464 .82586 .46129 .83788 .45762 .83289 .45092 Mtetra
.665 .744 .909 r
.83289 .45092 .83788 .45762 .84995 .45394 .845 .44719 Mtetra
.665 .743 .908 r
.845 .44719 .84995 .45394 .86207 .45025 .85715 .44346 Mtetra
.664 .742 .908 r
.85715 .44346 .86207 .45025 .87425 .44656 .86936 .43972 Mtetra
.86936 .43972 .87425 .44656 .88647 .44285 .88162 .43598 Mtetra
.88162 .43598 .88647 .44285 .89874 .43913 .89393 .43223 Mtetra
.664 .741 .908 r
.89393 .43223 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55836 Mtetra
.45369 .55836 .45975 .56432 .47035 .5611 .46432 .55512 Mtetra
.46432 .55512 .47035 .5611 .48099 .55786 .47499 .55187 Mtetra
.663 .742 .909 r
.47499 .55187 .48099 .55786 .49168 .55462 .4857 .54861 Mtetra
.662 .742 .909 r
.4857 .54861 .49168 .55462 .5024 .55137 .49646 .54537 Mtetra
.661 .742 .91 r
.49646 .54537 .5024 .55137 .51317 .54813 .50725 .54214 Mtetra
.659 .743 .912 r
.50725 .54214 .51317 .54813 .52398 .5449 .51809 .53896 Mtetra
.656 .745 .915 r
.51809 .53896 .52398 .5449 .53484 .5417 .52897 .53585 Mtetra
.651 .747 .92 r
.52897 .53585 .53484 .5417 .54574 .53854 .5399 .53284 Mtetra
.645 .752 .927 r
.5399 .53284 .54574 .53854 .55668 .53543 .55088 .52997 Mtetra
.637 .758 .936 r
.55088 .52997 .55668 .53543 .56767 .5324 .5619 .52723 Mtetra
.628 .767 .946 r
.5619 .52723 .56767 .5324 .5787 .52943 .57297 .52464 Mtetra
.618 .78 .958 r
.57297 .52464 .5787 .52943 .58979 .52652 .5841 .52213 Mtetra
.61 .794 .97 r
.5841 .52213 .58979 .52652 .60092 .52362 .59527 .51966 Mtetra
.604 .811 .979 r
.59527 .51966 .60092 .52362 .6121 .5207 .6065 .5171 Mtetra
.605 .828 .985 r
.6065 .5171 .6121 .5207 .62332 .51768 .61777 .51434 Mtetra
.613 .842 .987 r
.61777 .51434 .62332 .51768 .63459 .51452 .62908 .5113 Mtetra
.628 .853 .985 r
.62908 .5113 .63459 .51452 .6459 .51117 .64043 .50791 Mtetra
.647 .858 .98 r
.64043 .50791 .6459 .51117 .65725 .50762 .65182 .50416 Mtetra
.665 .855 .972 r
.65182 .50416 .65725 .50762 .66864 .50388 .66323 .5001 Mtetra
.679 .846 .963 r
.66323 .5001 .66864 .50388 .68006 .50001 .67468 .49582 Mtetra
.687 .832 .953 r
.67468 .49582 .68006 .50001 .69152 .49606 .68617 .49143 Mtetra
.689 .816 .943 r
.68617 .49143 .69152 .49606 .70303 .49209 .6977 .48704 Mtetra
.687 .8 .935 r
.6977 .48704 .70303 .49209 .71459 .48815 .70927 .48273 Mtetra
.682 .786 .929 r
.70927 .48273 .71459 .48815 .72619 .48428 .72089 .47855 Mtetra
.677 .775 .924 r
.72089 .47855 .72619 .48428 .73785 .48048 .73257 .47453 Mtetra
.673 .766 .921 r
.73257 .47453 .73785 .48048 .74955 .47675 .74431 .47063 Mtetra
.669 .76 .919 r
.74431 .47063 .74955 .47675 .76131 .47306 .75609 .46684 Mtetra
.667 .757 .917 r
.75609 .46684 .76131 .47306 .77312 .4694 .76793 .46308 Mtetra
.667 .754 .916 r
.76793 .46308 .77312 .4694 .78497 .46573 .77982 .45934 Mtetra
.667 .753 .915 r
.77982 .45934 .78497 .46573 .79688 .46205 .79176 .45558 Mtetra
.667 .751 .913 r
.79176 .45558 .79688 .46205 .80883 .45836 .80375 .4518 Mtetra
.667 .749 .912 r
.80375 .4518 .80883 .45836 .82084 .45464 .81578 .44801 Mtetra
.667 .747 .911 r
.81578 .44801 .82084 .45464 .83289 .45092 .82787 .44421 Mtetra
.666 .746 .91 r
.82787 .44421 .83289 .45092 .845 .44719 .84 .44041 Mtetra
.665 .744 .909 r
.84 .44041 .845 .44719 .85715 .44346 .85219 .43662 Mtetra
.665 .743 .908 r
.85219 .43662 .85715 .44346 .86936 .43972 .86444 .43284 Mtetra
.664 .742 .908 r
.86444 .43284 .86936 .43972 .88162 .43598 .87673 .42906 Mtetra
.87673 .42906 .88162 .43598 .89393 .43223 .88908 .42527 Mtetra
.664 .741 .908 r
.88908 .42527 .89393 .43223 .9063 .42846 .90149 .42148 Mtetra
.90149 .42148 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.663 .741 .908 r
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .56531 Mtetra
.40539 .56531 .4116 .57122 .42206 .56802 .41588 .56209 Mtetra
.41588 .56209 .42206 .56802 .43256 .56481 .42641 .55886 Mtetra
.42641 .55886 .43256 .56481 .44311 .56159 .43698 .55562 Mtetra
.43698 .55562 .44311 .56159 .45369 .55836 .44759 .55236 Mtetra
.663 .742 .908 r
.44759 .55236 .45369 .55836 .46432 .55512 .45825 .54911 Mtetra
.663 .742 .909 r
.45825 .54911 .46432 .55512 .47499 .55187 .46894 .54585 Mtetra
.662 .742 .909 r
.46894 .54585 .47499 .55187 .4857 .54861 .47968 .54259 Mtetra
.66 .742 .911 r
.47968 .54259 .4857 .54861 .49646 .54537 .49046 .53937 Mtetra
.658 .743 .913 r
.49046 .53937 .49646 .54537 .50725 .54214 .50129 .53621 Mtetra
.653 .745 .917 r
.50129 .53621 .50725 .54214 .51809 .53896 .51215 .53315 Mtetra
.647 .748 .923 r
.51215 .53315 .51809 .53896 .52897 .53585 .52306 .53025 Mtetra
.636 .753 .932 r
.52306 .53025 .52897 .53585 .5399 .53284 .53402 .52756 Mtetra
.622 .761 .945 r
.53402 .52756 .5399 .53284 .55088 .52997 .54503 .52512 Mtetra
.603 .772 .961 r
.54503 .52512 .55088 .52997 .5619 .52723 .55609 .52295 Mtetra
.577 .788 .979 r
.55609 .52295 .5619 .52723 .57297 .52464 .56721 .52102 Mtetra
.545 .805 .994 r
.56721 .52102 .57297 .52464 .5841 .52213 .57838 .51924 Mtetra
.51 .823 1 r
.57838 .51924 .5841 .52213 .59527 .51966 .58961 .51746 Mtetra
.48 .839 .994 r
.58961 .51746 .59527 .51966 .6065 .5171 .6009 .5155 Mtetra
.467 .854 .979 r
.6009 .5155 .6065 .5171 .61777 .51434 .61222 .51316 Mtetra
.479 .873 .967 r
.61222 .51316 .61777 .51434 .62908 .5113 .62359 .5103 Mtetra
.518 .895 .963 r
.62359 .5103 .62908 .5113 .64043 .50791 .63499 .50682 Mtetra
.573 .915 .968 r
.63499 .50682 .64043 .50791 .65182 .50416 .64641 .50273 Mtetra
.627 .924 .974 r
.64641 .50273 .65182 .50416 .66323 .5001 .65786 .49815 Mtetra
.668 .918 .976 r
.65786 .49815 .66323 .5001 .67468 .49582 .66933 .49322 Mtetra
.693 .9 .971 r
.66933 .49322 .67468 .49582 .68617 .49143 .68083 .48814 Mtetra
.702 .875 .963 r
.68083 .48814 .68617 .49143 .6977 .48704 .69237 .48309 Mtetra
.701 .849 .953 r
.69237 .48309 .6977 .48704 .70927 .48273 .70396 .47819 Mtetra
.695 .825 .945 r
.70396 .47819 .70927 .48273 .72089 .47855 .7156 .47353 Mtetra
.687 .805 .938 r
.7156 .47353 .72089 .47855 .73257 .47453 .72729 .46913 Mtetra
.68 .79 .933 r
.72729 .46913 .73257 .47453 .74431 .47063 .73905 .46496 Mtetra
.674 .779 .929 r
.73905 .46496 .74431 .47063 .75609 .46684 .75086 .46096 Mtetra
.671 .772 .926 r
.75086 .46096 .75609 .46684 .76793 .46308 .76273 .45705 Mtetra
.67 .767 .923 r
.76273 .45705 .76793 .46308 .77982 .45934 .77465 .45317 Mtetra
.67 .763 .92 r
.77465 .45317 .77982 .45934 .79176 .45558 .78662 .44928 Mtetra
.67 .76 .918 r
.78662 .44928 .79176 .45558 .80375 .4518 .79863 .44537 Mtetra
.67 .756 .915 r
.79863 .44537 .80375 .4518 .81578 .44801 .8107 .44144 Mtetra
.669 .752 .913 r
.8107 .44144 .81578 .44801 .82787 .44421 .82281 .43752 Mtetra
.668 .749 .911 r
.82281 .43752 .82787 .44421 .84 .44041 .83498 .43363 Mtetra
.667 .746 .91 r
.83498 .43363 .84 .44041 .85219 .43662 .8472 .42976 Mtetra
.666 .744 .909 r
.8472 .42976 .85219 .43662 .86444 .43284 .85948 .42592 Mtetra
.665 .743 .908 r
.85948 .42592 .86444 .43284 .87673 .42906 .87181 .42209 Mtetra
.664 .742 .908 r
.87181 .42209 .87673 .42906 .88908 .42527 .8842 .41827 Mtetra
.8842 .41827 .88908 .42527 .90149 .42148 .89664 .41444 Mtetra
.664 .741 .908 r
.89664 .41444 .90149 .42148 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.663 .741 .908 r
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .56531 .39914 .55935 Mtetra
.39914 .55935 .40539 .56531 .41588 .56209 .40966 .55611 Mtetra
.40966 .55611 .41588 .56209 .42641 .55886 .42021 .55286 Mtetra
.42021 .55286 .42641 .55886 .43698 .55562 .43081 .5496 Mtetra
.663 .742 .909 r
.43081 .5496 .43698 .55562 .44759 .55236 .44145 .54634 Mtetra
.662 .742 .909 r
.44145 .54634 .44759 .55236 .45825 .54911 .45213 .54307 Mtetra
.662 .742 .91 r
.45213 .54307 .45825 .54911 .46894 .54585 .46285 .53982 Mtetra
.66 .743 .911 r
.46285 .53982 .46894 .54585 .47968 .54259 .47362 .5366 Mtetra
.657 .743 .914 r
.47362 .5366 .47968 .54259 .49046 .53937 .48442 .53345 Mtetra
.651 .745 .918 r
.48442 .53345 .49046 .53937 .50129 .53621 .49527 .53043 Mtetra
.642 .748 .926 r
.49527 .53043 .50129 .53621 .51215 .53315 .50617 .52762 Mtetra
.628 .754 .938 r
.50617 .52762 .51215 .53315 .52306 .53025 .51711 .52511 Mtetra
.605 .762 .954 r
.51711 .52511 .52306 .53025 .53402 .52756 .5281 .52299 Mtetra
.569 .773 .975 r
.5281 .52299 .53402 .52756 .54503 .52512 .53914 .52132 Mtetra
.512 .785 .994 r
.53914 .52132 .54503 .52512 .55609 .52295 .55025 .5201 Mtetra
.424 .787 .995 r
.55025 .5201 .55609 .52295 .56721 .52102 .56141 .51927 Mtetra
.302 .762 .949 r
.56141 .51927 .56721 .52102 .57838 .51924 .57265 .51863 Mtetra
.169 .702 .842 r
.57265 .51863 .57838 .51924 .58961 .51746 .58394 .51794 Mtetra
.073 .634 .712 r
.58394 .51794 .58961 .51746 .6009 .5155 .5953 .51688 Mtetra
0 0 0 r
.5953 .51688 .6009 .5155 .61222 .51316 .6067 .51514 Mtetra
.6067 .51514 .61222 .51316 .62359 .5103 .61813 .51251 Mtetra
.61813 .51251 .62359 .5103 .63499 .50682 .62958 .50888 Mtetra
.273 .76 .67 r
.62958 .50888 .63499 .50682 .64641 .50273 .64105 .50431 Mtetra
.415 .856 .765 r
.64105 .50431 .64641 .50273 .65786 .49815 .65253 .49898 Mtetra
.544 .928 .856 r
.65253 .49898 .65786 .49815 .66933 .49322 .66403 .49314 Mtetra
.636 .959 .919 r
.66403 .49314 .66933 .49322 .68083 .48814 .67554 .48707 Mtetra
.687 .954 .952 r
.67554 .48707 .68083 .48814 .69237 .48309 .68709 .48106 Mtetra
.707 .928 .964 r
.68709 .48106 .69237 .48309 .70396 .47819 .69869 .47528 Mtetra
.708 .896 .965 r
.69869 .47528 .70396 .47819 .7156 .47353 .71033 .46986 Mtetra
.7 .864 .96 r
.71033 .46986 .7156 .47353 .72729 .46913 .72204 .46485 Mtetra
.69 .838 .954 r
.72204 .46485 .72729 .46913 .73905 .46496 .73381 .4602 Mtetra
.682 .818 .948 r
.73381 .4602 .73905 .46496 .75086 .46096 .74564 .45583 Mtetra
.678 .803 .942 r
.74564 .45583 .75086 .46096 .76273 .45705 .75753 .45162 Mtetra
.676 .792 .936 r
.75753 .45162 .76273 .45705 .77465 .45317 .76947 .44747 Mtetra
.676 .783 .931 r
.76947 .44747 .77465 .45317 .78662 .44928 .78146 .44333 Mtetra
.676 .776 .925 r
.78146 .44333 .78662 .44928 .79863 .44537 .7935 .43918 Mtetra
.676 .768 .92 r
.7935 .43918 .79863 .44537 .8107 .44144 .80559 .43504 Mtetra
.674 .761 .916 r
.80559 .43504 .8107 .44144 .82281 .43752 .81773 .43093 Mtetra
.672 .755 .913 r
.81773 .43093 .82281 .43752 .83498 .43363 .82992 .42688 Mtetra
.67 .75 .911 r
.82992 .42688 .83498 .43363 .8472 .42976 .84217 .4229 Mtetra
.667 .746 .909 r
.84217 .4229 .8472 .42976 .85948 .42592 .85448 .41898 Mtetra
.666 .744 .909 r
.85448 .41898 .85948 .42592 .87181 .42209 .86685 .41509 Mtetra
.665 .743 .908 r
.86685 .41509 .87181 .42209 .8842 .41827 .87927 .41121 Mtetra
.664 .742 .908 r
.87927 .41121 .8842 .41827 .89664 .41444 .89175 .40735 Mtetra
.89175 .40735 .89664 .41444 .90913 .4106 .90428 .40347 Mtetra
.664 .741 .908 r
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39959 Mtetra
.91687 .39959 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.663 .741 .908 r
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .55661 Mtetra
.38235 .55661 .38867 .56258 .39914 .55935 .39285 .55336 Mtetra
.39285 .55336 .39914 .55935 .40966 .55611 .40339 .5501 Mtetra
.40339 .5501 .40966 .55611 .42021 .55286 .41397 .54683 Mtetra
.663 .742 .909 r
.41397 .54683 .42021 .55286 .43081 .5496 .4246 .54356 Mtetra
.662 .742 .909 r
.4246 .54356 .43081 .5496 .44145 .54634 .43526 .54029 Mtetra
.661 .742 .91 r
.43526 .54029 .44145 .54634 .45213 .54307 .44597 .53703 Mtetra
.659 .743 .912 r
.44597 .53703 .45213 .54307 .46285 .53982 .45672 .53381 Mtetra
.656 .744 .914 r
.45672 .53381 .46285 .53982 .47362 .5366 .46751 .53067 Mtetra
.65 .746 .92 r
.46751 .53067 .47362 .5366 .48442 .53345 .47834 .52768 Mtetra
.639 .749 .928 r
.47834 .52768 .48442 .53345 .49527 .53043 .48921 .52495 Mtetra
.62 .754 .942 r
.48921 .52495 .49527 .53043 .50617 .52762 .50013 .52259 Mtetra
.587 .761 .962 r
.50013 .52259 .50617 .52762 .51711 .52511 .5111 .52076 Mtetra
.529 .769 .985 r
.5111 .52076 .51711 .52511 .5281 .52299 .52212 .51959 Mtetra
.424 .765 .996 r
.52212 .51959 .5281 .52299 .53914 .52132 .53321 .51915 Mtetra
.238 .711 .94 r
.53321 .51915 .53914 .52132 .55025 .5201 .54436 .51942 Mtetra
0 .561 .745 r
.54436 .51942 .55025 .5201 .56141 .51927 .55558 .52021 Mtetra
.228 0 0 r
.55558 .52021 .56141 .51927 .57265 .51863 .56689 .52124 Mtetra
.334 0 0 r
.56689 .52124 .57265 .51863 .58394 .51794 .57826 .52205 Mtetra
.363 0 0 r
.57826 .52205 .58394 .51794 .5953 .51688 .5897 .52219 Mtetra
.344 0 0 r
.5897 .52219 .5953 .51688 .6067 .51514 .60119 .52123 Mtetra
.292 0 0 r
.60119 .52123 .6067 .51514 .61813 .51251 .61271 .51889 Mtetra
.212 0 0 r
.61271 .51889 .61813 .51251 .62958 .50888 .62423 .51507 Mtetra
.105 0 0 r
.62423 .51507 .62958 .50888 .64105 .50431 .63576 .5099 Mtetra
0 0 0 r
.63576 .5099 .64105 .50431 .65253 .49898 .64729 .50365 Mtetra
.64729 .50365 .65253 .49898 .66403 .49314 .65881 .49668 Mtetra
.65881 .49668 .66403 .49314 .67554 .48707 .67035 .48938 Mtetra
.494 .886 .719 r
.67035 .48938 .67554 .48707 .68709 .48106 .68191 .4821 Mtetra
.599 .951 .84 r
.68191 .4821 .68709 .48106 .69869 .47528 .6935 .47511 Mtetra
.659 .966 .916 r
.6935 .47511 .69869 .47528 .71033 .46986 .70515 .46859 Mtetra
.685 .95 .956 r
.70515 .46859 .71033 .46986 .72204 .46485 .71686 .46261 Mtetra
.69 .921 .97 r
.71686 .46261 .72204 .46485 .73381 .4602 .72864 .45714 Mtetra
.689 .89 .971 r
.72864 .45714 .73381 .4602 .74564 .45583 .74047 .45209 Mtetra
.687 .863 .966 r
.74047 .45209 .74564 .45583 .75753 .45162 .75237 .44731 Mtetra
.687 .841 .957 r
.75237 .44731 .75753 .45162 .76947 .44747 .76432 .44266 Mtetra
.688 .822 .947 r
.76432 .44266 .76947 .44747 .78146 .44333 .77632 .43805 Mtetra
.688 .806 .938 r
.77632 .43805 .78146 .44333 .7935 .43918 .78837 .43348 Mtetra
.687 .791 .929 r
.78837 .43348 .7935 .43918 .80559 .43504 .80047 .42895 Mtetra
.683 .777 .922 r
.80047 .42895 .80559 .43504 .81773 .43093 .81262 .42453 Mtetra
.679 .766 .917 r
.81262 .42453 .81773 .43093 .82992 .42688 .82484 .42023 Mtetra
.674 .757 .913 r
.82484 .42023 .82992 .42688 .84217 .4229 .83711 .41607 Mtetra
.67 .75 .911 r
.83711 .41607 .84217 .4229 .85448 .41898 .84945 .41202 Mtetra
.667 .746 .909 r
.84945 .41202 .85448 .41898 .86685 .41509 .86185 .40804 Mtetra
.665 .744 .908 r
.86185 .40804 .86685 .41509 .87927 .41121 .87431 .40411 Mtetra
.664 .742 .908 r
.87431 .40411 .87927 .41121 .89175 .40735 .88682 .4002 Mtetra
.88682 .4002 .89175 .40735 .90428 .40347 .89939 .39629 Mtetra
.664 .741 .908 r
.89939 .39629 .90428 .40347 .91687 .39959 .91202 .39237 Mtetra
.91202 .39237 .91687 .39959 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.663 .741 .908 r
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .55661 .37599 .55059 Mtetra
.37599 .55059 .38235 .55661 .39285 .55336 .38651 .54732 Mtetra
.38651 .54732 .39285 .55336 .40339 .5501 .39708 .54405 Mtetra
.663 .742 .909 r
.39708 .54405 .40339 .5501 .41397 .54683 .40768 .54077 Mtetra
.662 .742 .909 r
.40768 .54077 .41397 .54683 .4246 .54356 .41833 .5375 Mtetra
.661 .742 .91 r
.41833 .5375 .4246 .54356 .43526 .54029 .42902 .53424 Mtetra
.659 .743 .912 r
.42902 .53424 .43526 .54029 .44597 .53703 .43976 .53102 Mtetra
.655 .744 .915 r
.43976 .53102 .44597 .53703 .45672 .53381 .45053 .52789 Mtetra
.649 .746 .921 r
.45053 .52789 .45672 .53381 .46751 .53067 .46134 .52492 Mtetra
.636 .749 .93 r
.46134 .52492 .46751 .53067 .47834 .52768 .4722 .52222 Mtetra
.614 .753 .945 r
.4722 .52222 .47834 .52768 .48921 .52495 .4831 .51998 Mtetra
.572 .759 .967 r
.4831 .51998 .48921 .52495 .50013 .52259 .49404 .51838 Mtetra
.491 .76 .99 r
.49404 .51838 .50013 .52259 .5111 .52076 .50503 .51765 Mtetra
.327 .728 .981 r
.50503 .51765 .5111 .52076 .52212 .51959 .51609 .51794 Mtetra
.028 .582 .825 r
.51609 .51794 .52212 .51959 .53321 .51915 .52721 .51931 Mtetra
.295 0 0 r
.52721 .51931 .53321 .51915 .54436 .51942 .53842 .52166 Mtetra
.471 0 0 r
.53842 .52166 .54436 .51942 .55558 .52021 .54971 .52467 Mtetra
.531 .036 .025 r
.54971 .52467 .55558 .52021 .56689 .52124 .5611 .52783 Mtetra
.538 .086 .126 r
.5611 .52783 .56689 .52124 .57826 .52205 .57257 .5305 Mtetra
.517 .094 .176 r
.57257 .5305 .57826 .52205 .5897 .52219 .58411 .53205 Mtetra
.478 .074 .194 r
.58411 .53205 .5897 .52219 .60119 .52123 .5957 .53195 Mtetra
.426 .033 .189 r
.5957 .53195 .60119 .52123 .61271 .51889 .60731 .52991 Mtetra
.361 0 .165 r
.60731 .52991 .61271 .51889 .62423 .51507 .61893 .5259 Mtetra
.285 0 .124 r
.61893 .5259 .62423 .51507 .63576 .5099 .63053 .52012 Mtetra
.2 0 .066 r
.63053 .52012 .63576 .5099 .64729 .50365 .64212 .51296 Mtetra
.107 0 0 r
.64212 .51296 .64729 .50365 .65881 .49668 .6537 .50485 Mtetra
.008 0 0 r
.6537 .50485 .65881 .49668 .67035 .48938 .66527 .49623 Mtetra
0 0 0 r
.66527 .49623 .67035 .48938 .68191 .4821 .67686 .48752 Mtetra
.67686 .48752 .68191 .4821 .6935 .47511 .68847 .47905 Mtetra
.68847 .47905 .6935 .47511 .70515 .46859 .70011 .47104 Mtetra
.463 .864 .688 r
.70011 .47104 .70515 .46859 .71686 .46261 .71182 .46366 Mtetra
.561 .934 .826 r
.71182 .46366 .71686 .46261 .72864 .45714 .72358 .45692 Mtetra
.628 .957 .915 r
.72358 .45692 .72864 .45714 .74047 .45209 .73541 .45073 Mtetra
.668 .947 .958 r
.73541 .45073 .74047 .45209 .75237 .44731 .7473 .44493 Mtetra
.691 .921 .97 r
.7473 .44493 .75237 .44731 .76432 .44266 .75924 .43937 Mtetra
.703 .89 .965 r
.75924 .43937 .76432 .44266 .77632 .43805 .77123 .43393 Mtetra
.708 .858 .954 r
.77123 .43393 .77632 .43805 .78837 .43348 .78327 .4286 Mtetra
.705 .829 .941 r
.78327 .4286 .78837 .43348 .80047 .42895 .79536 .42343 Mtetra
.699 .804 .93 r
.79536 .42343 .80047 .42895 .81262 .42453 .80751 .41847 Mtetra
.691 .783 .922 r
.80751 .41847 .81262 .42453 .82484 .42023 .81973 .41377 Mtetra
.682 .768 .916 r
.81973 .41377 .82484 .42023 .83711 .41607 .83203 .40932 Mtetra
.675 .757 .912 r
.83203 .40932 .83711 .41607 .84945 .41202 .84439 .40507 Mtetra
.67 .749 .91 r
.84439 .40507 .84945 .41202 .86185 .40804 .85682 .40098 Mtetra
.667 .745 .909 r
.85682 .40098 .86185 .40804 .87431 .40411 .86931 .39697 Mtetra
.665 .743 .908 r
.86931 .39697 .87431 .40411 .88682 .4002 .88186 .39301 Mtetra
.664 .742 .908 r
.88186 .39301 .88682 .4002 .89939 .39629 .89447 .38906 Mtetra
.89447 .38906 .89939 .39629 .91202 .39237 .90713 .3851 Mtetra
.664 .741 .908 r
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37716 Mtetra
.663 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54782 Mtetra
.35907 .54782 .3655 .55385 .37599 .55059 .36958 .54453 Mtetra
.36958 .54453 .37599 .55059 .38651 .54732 .38013 .54125 Mtetra
.662 .741 .909 r
.38013 .54125 .38651 .54732 .39708 .54405 .39072 .53796 Mtetra
.662 .742 .909 r
.39072 .53796 .39708 .54405 .40768 .54077 .40135 .53468 Mtetra
.66 .742 .91 r
.40135 .53468 .40768 .54077 .41833 .5375 .41202 .53143 Mtetra
.658 .743 .912 r
.41202 .53143 .41833 .5375 .42902 .53424 .42274 .52822 Mtetra
.655 .744 .916 r
.42274 .52822 .42902 .53424 .43976 .53102 .43349 .52509 Mtetra
.648 .746 .921 r
.43349 .52509 .43976 .53102 .45053 .52789 .44429 .52214 Mtetra
.635 .749 .931 r
.44429 .52214 .45053 .52789 .46134 .52492 .45513 .51947 Mtetra
.61 .753 .947 r
.45513 .51947 .46134 .52492 .4722 .52222 .466 .51729 Mtetra
.562 .758 .97 r
.466 .51729 .4722 .52222 .4831 .51998 .47692 .51584 Mtetra
.461 .751 .992 r
.47692 .51584 .4831 .51998 .49404 .51838 .48788 .51541 Mtetra
.242 .686 .957 r
.48788 .51541 .49404 .51838 .50503 .51765 .4989 .51629 Mtetra
0 .449 .698 r
.4989 .51629 .50503 .51765 .51609 .51794 .50998 .51865 Mtetra
.461 0 0 r
.50998 .51865 .51609 .51794 .52721 .51931 .52114 .52248 Mtetra
.59 .08 .008 r
.52114 .52248 .52721 .51931 .53842 .52166 .53241 .52751 Mtetra
.624 .173 .161 r
.53241 .52751 .53842 .52166 .54971 .52467 .54378 .5332 Mtetra
.621 .209 .241 r
.54378 .5332 .54971 .52467 .5611 .52783 .55526 .53879 Mtetra
.6 .213 .281 r
.55526 .53879 .5611 .52783 .57257 .5305 .56683 .54341 Mtetra
.567 .196 .299 r
.56683 .54341 .57257 .5305 .58411 .53205 .57848 .54629 Mtetra
.524 .165 .3 r
.57848 .54629 .58411 .53205 .5957 .53195 .59018 .54691 Mtetra
.473 .121 .288 r
.59018 .54691 .5957 .53195 .60731 .52991 .60191 .54507 Mtetra
.416 .07 .268 r
.60191 .54507 .60731 .52991 .61893 .5259 .61363 .54087 Mtetra
.357 .015 .24 r
.61363 .54087 .61893 .5259 .63053 .52012 .62533 .53466 Mtetra
.299 0 .21 r
.62533 .53466 .63053 .52012 .64212 .51296 .63702 .52687 Mtetra
.246 0 .177 r
.63702 .52687 .64212 .51296 .6537 .50485 .64868 .51796 Mtetra
.195 0 .139 r
.64868 .51796 .6537 .50485 .66527 .49623 .66033 .50832 Mtetra
.144 0 .095 r
.66033 .50832 .66527 .49623 .67686 .48752 .67197 .49832 Mtetra
.088 0 .035 r
.67197 .49832 .67686 .48752 .68847 .47905 .68361 .4883 Mtetra
.021 0 0 r
.68361 .4883 .68847 .47905 .70011 .47104 .69527 .47858 Mtetra
0 0 0 r
.69527 .47858 .70011 .47104 .71182 .46366 .70696 .46938 Mtetra
.70696 .46938 .71182 .46366 .72358 .45692 .71871 .46084 Mtetra
.71871 .46084 .72358 .45692 .73541 .45073 .73051 .45293 Mtetra
.475 .874 .705 r
.73051 .45293 .73541 .45073 .7473 .44493 .74237 .44552 Mtetra
.611 .956 .857 r
.74237 .44552 .7473 .44493 .75924 .43937 .75427 .43846 Mtetra
.694 .967 .934 r
.75427 .43846 .75924 .43937 .77123 .43393 .76623 .43164 Mtetra
.729 .936 .955 r
.76623 .43164 .77123 .43393 .78327 .4286 .77823 .42507 Mtetra
.734 .891 .951 r
.77823 .42507 .78327 .4286 .79536 .42343 .79028 .41882 Mtetra
.725 .847 .94 r
.79028 .41882 .79536 .42343 .80751 .41847 .80241 .41299 Mtetra
.71 .812 .928 r
.80241 .41299 .80751 .41847 .81973 .41377 .81462 .40763 Mtetra
.695 .785 .92 r
.81462 .40763 .81973 .41377 .83203 .40932 .82692 .40273 Mtetra
.683 .767 .914 r
.82692 .40273 .83203 .40932 .84439 .40507 .83929 .39819 Mtetra
.675 .755 .911 r
.83929 .39819 .84439 .40507 .85682 .40098 .85175 .39392 Mtetra
.669 .748 .909 r
.85175 .39392 .85682 .40098 .86931 .39697 .86427 .3898 Mtetra
.666 .744 .909 r
.86427 .3898 .86931 .39697 .88186 .39301 .87686 .38577 Mtetra
.665 .743 .908 r
.87686 .38577 .88186 .39301 .89447 .38906 .88951 .38177 Mtetra
.664 .742 .908 r
.88951 .38177 .89447 .38906 .90713 .3851 .90221 .37778 Mtetra
.664 .741 .908 r
.90221 .37778 .90713 .3851 .91985 .38114 .91497 .37378 Mtetra
.91497 .37378 .91985 .38114 .93263 .37716 .92778 .36976 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54782 .35258 .54174 Mtetra
.35258 .54174 .35907 .54782 .36958 .54453 .36312 .53844 Mtetra
.663 .741 .909 r
.36312 .53844 .36958 .54453 .38013 .54125 .37369 .53514 Mtetra
.662 .742 .909 r
.37369 .53514 .38013 .54125 .39072 .53796 .38431 .53185 Mtetra
.66 .742 .91 r
.38431 .53185 .39072 .53796 .40135 .53468 .39497 .52859 Mtetra
.658 .743 .912 r
.39497 .52859 .40135 .53468 .41202 .53143 .40566 .52538 Mtetra
.654 .744 .916 r
.40566 .52538 .41202 .53143 .42274 .52822 .4164 .52227 Mtetra
.647 .746 .922 r
.4164 .52227 .42274 .52822 .43349 .52509 .42718 .51933 Mtetra
.633 .749 .932 r
.42718 .51933 .43349 .52509 .44429 .52214 .438 .51668 Mtetra
.608 .753 .948 r
.438 .51668 .44429 .52214 .45513 .51947 .44885 .51452 Mtetra
.556 .756 .971 r
.44885 .51452 .45513 .51947 .466 .51729 .45974 .51314 Mtetra
.444 .745 .992 r
.45974 .51314 .466 .51729 .47692 .51584 .47067 .5129 Mtetra
.187 .655 .937 r
.47067 .5129 .47692 .51584 .48788 .51541 .48164 .51416 Mtetra
.246 0 0 r
.48164 .51416 .48788 .51541 .4989 .51629 .49267 .51726 Mtetra
.549 0 0 r
.49267 .51726 .4989 .51629 .50998 .51865 .50378 .52232 Mtetra
.652 .17 .095 r
.50378 .52232 .50998 .51865 .52114 .52248 .51499 .52917 Mtetra
.675 .25 .228 r
.51499 .52917 .52114 .52248 .53241 .52751 .52631 .53731 Mtetra
.669 .279 .298 r
.52631 .53731 .53241 .52751 .54378 .5332 .53776 .54585 Mtetra
.649 .281 .333 r
.53776 .54585 .54378 .5332 .55526 .53879 .54933 .55373 Mtetra
.62 .266 .348 r
.54933 .55373 .55526 .53879 .56683 .54341 .56102 .55992 Mtetra
.581 .236 .349 r
.56102 .55992 .56683 .54341 .57848 .54629 .57278 .56361 Mtetra
.535 .195 .339 r
.57278 .56361 .57848 .54629 .59018 .54691 .58459 .56443 Mtetra
.483 .147 .321 r
.58459 .56443 .59018 .54691 .60191 .54507 .59643 .56244 Mtetra
.43 .097 .299 r
.59643 .56244 .60191 .54507 .61363 .54087 .60826 .55802 Mtetra
.381 .052 .277 r
.60826 .55802 .61363 .54087 .62533 .53466 .62009 .55168 Mtetra
.341 .016 .26 r
.62009 .55168 .62533 .53466 .63702 .52687 .6319 .54388 Mtetra
.309 0 .249 r
.6319 .54388 .63702 .52687 .64868 .51796 .64369 .53493 Mtetra
.282 0 .239 r
.64369 .53493 .64868 .51796 .66033 .50832 .65546 .52504 Mtetra
.255 0 .226 r
.65546 .52504 .66033 .50832 .67197 .49832 .6672 .51438 Mtetra
.225 0 .206 r
.6672 .51438 .67197 .49832 .68361 .4883 .67892 .5032 Mtetra
.19 0 .174 r
.67892 .5032 .68361 .4883 .69527 .47858 .69062 .49184 Mtetra
.145 0 .125 r
.69062 .49184 .69527 .47858 .70696 .46938 .70233 .48067 Mtetra
.086 0 .051 r
.70233 .48067 .70696 .46938 .71871 .46084 .71407 .46994 Mtetra
0 0 0 r
.71407 .46994 .71871 .46084 .73051 .45293 .72583 .45977 Mtetra
.72583 .45977 .73051 .45293 .74237 .44552 .73764 .45011 Mtetra
.73764 .45011 .74237 .44552 .75427 .43846 .74948 .44085 Mtetra
.555 .908 .699 r
.74948 .44085 .75427 .43846 .76623 .43164 .76136 .43195 Mtetra
.707 .985 .866 r
.76136 .43195 .76623 .43164 .77823 .42507 .77328 .42346 Mtetra
.762 .965 .93 r
.77328 .42346 .77823 .42507 .79028 .41882 .78527 .41555 Mtetra
.761 .909 .94 r
.78527 .41555 .79028 .41882 .80241 .41299 .79735 .40838 Mtetra
.74 .854 .934 r
.79735 .40838 .80241 .41299 .81462 .40763 .80952 .40202 Mtetra
.716 .812 .924 r
.80952 .40202 .81462 .40763 .82692 .40273 .8218 .39641 Mtetra
.696 .782 .917 r
.8218 .39641 .82692 .40273 .83929 .39819 .83418 .39143 Mtetra
.682 .763 .913 r
.83418 .39143 .83929 .39819 .85175 .39392 .84665 .38688 Mtetra
.673 .752 .91 r
.84665 .38688 .85175 .39392 .86427 .3898 .8592 .38261 Mtetra
.668 .746 .909 r
.8592 .38261 .86427 .3898 .87686 .38577 .87182 .37849 Mtetra
.665 .743 .908 r
.87182 .37849 .87686 .38577 .88951 .38177 .8845 .37443 Mtetra
.664 .742 .908 r
.8845 .37443 .88951 .38177 .90221 .37778 .89724 .37039 Mtetra
.89724 .37039 .90221 .37778 .91497 .37378 .91004 .36636 Mtetra
.664 .741 .908 r
.91004 .36636 .91497 .37378 .92778 .36976 .9229 .36231 Mtetra
.663 .741 .908 r
.33554 .53893 .34209 .54503 .35258 .54174 .34605 .53561 Mtetra
.34605 .53561 .35258 .54174 .36312 .53844 .35661 .5323 Mtetra
.662 .741 .909 r
.35661 .5323 .36312 .53844 .37369 .53514 .36721 .52899 Mtetra
.66 .742 .91 r
.36721 .52899 .37369 .53514 .38431 .53185 .37785 .52572 Mtetra
.658 .742 .912 r
.37785 .52572 .38431 .53185 .39497 .52859 .38853 .5225 Mtetra
.653 .743 .916 r
.38853 .5225 .39497 .52859 .40566 .52538 .39925 .51939 Mtetra
.646 .745 .922 r
.39925 .51939 .40566 .52538 .4164 .52227 .41001 .51646 Mtetra
.632 .748 .931 r
.41001 .51646 .4164 .52227 .42718 .51933 .42081 .51383 Mtetra
.607 .752 .947 r
.42081 .51383 .42718 .51933 .438 .51668 .43164 .51168 Mtetra
.555 .755 .971 r
.43164 .51168 .438 .51668 .44885 .51452 .4425 .51032 Mtetra
.441 .742 .992 r
.4425 .51032 .44885 .51452 .45974 .51314 .45339 .51013 Mtetra
.17 .642 .931 r
.45339 .51013 .45974 .51314 .47067 .5129 .46432 .51156 Mtetra
.289 0 0 r
.46432 .51156 .47067 .5129 .48164 .51416 .4753 .51508 Mtetra
.591 .04 0 r
.4753 .51508 .48164 .51416 .49267 .51726 .48634 .52098 Mtetra
.687 .219 .134 r
.48634 .52098 .49267 .51726 .50378 .52232 .49747 .52926 Mtetra
.708 .295 .261 r
.49747 .52926 .50378 .52232 .51499 .52917 .50872 .5395 Mtetra
.703 .324 .327 r
.50872 .5395 .51499 .52917 .52631 .53731 .5201 .55078 Mtetra
.685 .326 .36 r
.5201 .55078 .52631 .53731 .53776 .54585 .53163 .56185 Mtetra
.657 .311 .374 r
.53163 .56185 .53776 .54585 .54933 .55373 .5433 .57134 Mtetra
.621 .281 .373 r
.5433 .57134 .54933 .55373 .56102 .55992 .55509 .57809 Mtetra
.575 .238 .36 r
.55509 .57809 .56102 .55992 .57278 .56361 .56696 .58147 Mtetra
.52 .182 .335 r
.56696 .58147 .57278 .56361 .58459 .56443 .57887 .58149 Mtetra
.46 .12 .302 r
.57887 .58149 .58459 .56443 .59643 .56244 .5908 .57868 Mtetra
.405 .063 .269 r
.5908 .57868 .59643 .56244 .60826 .55802 .60274 .57385 Mtetra
.365 .024 .247 r
.60274 .57385 .60826 .55802 .62009 .55168 .61469 .56771 Mtetra
.343 .006 .242 r
.61469 .56771 .62009 .55168 .6319 .54388 .62665 .56066 Mtetra
.332 .004 .249 r
.62665 .56066 .6319 .54388 .64369 .53493 .6386 .55277 Mtetra
.322 .004 .261 r
.6386 .55277 .64369 .53493 .65546 .52504 .65054 .54383 Mtetra
.306 0 .268 r
.65054 .54383 .65546 .52504 .6672 .51438 .66245 .53367 Mtetra
.284 0 .267 r
.66245 .53367 .6672 .51438 .67892 .5032 .6743 .52229 Mtetra
.258 0 .257 r
.6743 .52229 .67892 .5032 .69062 .49184 .6861 .50999 Mtetra
.226 0 .235 r
.6861 .50999 .69062 .49184 .70233 .48067 .69787 .49719 Mtetra
.187 0 .199 r
.69787 .49719 .70233 .48067 .71407 .46994 .70962 .48433 Mtetra
.13 0 .142 r
.70962 .48433 .71407 .46994 .72583 .45977 .72137 .47168 Mtetra
.041 0 .05 r
.72137 .47168 .72583 .45977 .73764 .45011 .73312 .4593 Mtetra
0 0 0 r
.73312 .4593 .73764 .45011 .74948 .44085 .74488 .44721 Mtetra
.74488 .44721 .74948 .44085 .76136 .43195 .75666 .43548 Mtetra
.576 .886 .604 r
.75666 .43548 .76136 .43195 .77328 .42346 .76847 .42433 Mtetra
.751 .993 .818 r
.76847 .42433 .77328 .42346 .78527 .41555 .78035 .41406 Mtetra
.799 .972 .908 r
.78035 .41406 .78527 .41555 .79735 .40838 .79233 .40495 Mtetra
.78 .908 .929 r
.79233 .40495 .79735 .40838 .80952 .40202 .80444 .39712 Mtetra
.746 .848 .926 r
.80444 .39712 .80952 .40202 .8218 .39641 .81667 .39049 Mtetra
.715 .804 .92 r
.81667 .39049 .8218 .39641 .83418 .39143 .82904 .38485 Mtetra
.693 .775 .914 r
.82904 .38485 .83418 .39143 .84665 .38688 .84152 .37991 Mtetra
.679 .758 .911 r
.84152 .37991 .84665 .38688 .8592 .38261 .85409 .37542 Mtetra
.671 .749 .909 r
.85409 .37542 .8592 .38261 .87182 .37849 .86674 .37117 Mtetra
.667 .745 .909 r
.86674 .37117 .87182 .37849 .8845 .37443 .87946 .36704 Mtetra
.665 .743 .908 r
.87946 .36704 .8845 .37443 .89724 .37039 .89224 .36296 Mtetra
.664 .742 .908 r
.89224 .36296 .89724 .37039 .91004 .36636 .90508 .35888 Mtetra
.664 .741 .908 r
.90508 .35888 .91004 .36636 .9229 .36231 .91798 .3548 Mtetra
.663 .741 .908 r
.32893 .53278 .33554 .53893 .34605 .53561 .33947 .52945 Mtetra
.662 .741 .909 r
.33947 .52945 .34605 .53561 .35661 .5323 .35006 .52612 Mtetra
.661 .741 .91 r
.35006 .52612 .35661 .5323 .36721 .52899 .36068 .52282 Mtetra
.658 .742 .911 r
.36068 .52282 .36721 .52899 .37785 .52572 .37135 .51958 Mtetra
.654 .742 .915 r
.37135 .51958 .37785 .52572 .38853 .5225 .38205 .51645 Mtetra
.646 .744 .92 r
.38205 .51645 .38853 .5225 .39925 .51939 .39279 .5135 Mtetra
.632 .746 .93 r
.39279 .5135 .39925 .51939 .41001 .51646 .40356 .51086 Mtetra
.607 .75 .946 r
.40356 .51086 .41001 .51646 .42081 .51383 .41437 .50872 Mtetra
.558 .752 .968 r
.41437 .50872 .42081 .51383 .43164 .51168 .4252 .50734 Mtetra
.448 .74 .99 r
.4252 .50734 .43164 .51168 .4425 .51032 .43607 .50711 Mtetra
.186 .647 .94 r
.43607 .50711 .4425 .51032 .45339 .51013 .44695 .50854 Mtetra
.28 0 0 r
.44695 .50854 .45339 .51013 .46432 .51156 .45787 .51216 Mtetra
.603 .05 0 r
.45787 .51216 .46432 .51156 .4753 .51508 .46884 .51843 Mtetra
.707 .24 .14 r
.46884 .51843 .4753 .51508 .48634 .52098 .47988 .52758 Mtetra
.731 .321 .271 r
.47988 .52758 .48634 .52098 .49747 .52926 .49103 .53935 Mtetra
.729 .353 .338 r
.49103 .53935 .49747 .52926 .50872 .5395 .50231 .55291 Mtetra
.714 .358 .372 r
.50231 .55291 .50872 .5395 .5201 .55078 .51376 .56688 Mtetra
.689 .344 .386 r
.51376 .56688 .5201 .55078 .53163 .56185 .52537 .57955 Mtetra
.654 .314 .385 r
.52537 .57955 .53163 .56185 .5433 .57134 .53714 .5893 Mtetra
.606 .266 .367 r
.53714 .5893 .5433 .57134 .55509 .57809 .54902 .59503 Mtetra
.541 .195 .33 r
.54902 .59503 .55509 .57809 .56696 .58147 .56096 .59649 Mtetra
.457 .099 .269 r
.56096 .59649 .56696 .58147 .57887 .58149 .57295 .59432 Mtetra
.359 0 .184 r
.57295 .59432 .57887 .58149 .5908 .57868 .58495 .58972 Mtetra
.275 0 .1 r
.58495 .58972 .5908 .57868 .60274 .57385 .59697 .58403 Mtetra
.244 0 .06 r
.59697 .58403 .60274 .57385 .61469 .56771 .60903 .57821 Mtetra
.266 0 .082 r
.60903 .57821 .61469 .56771 .62665 .56066 .62113 .57258 Mtetra
.301 0 .139 r
.62113 .57258 .62665 .56066 .6386 .55277 .63327 .56682 Mtetra
.32 0 .195 r
.63327 .56682 .6386 .55277 .65054 .54383 .64541 .56021 Mtetra
.317 0 .234 r
.64541 .56021 .65054 .54383 .66245 .53367 .65753 .55205 Mtetra
.299 0 .256 r
.65753 .55205 .66245 .53367 .6743 .52229 .66958 .54197 Mtetra
.275 0 .264 r
.66958 .54197 .6743 .52229 .6861 .50999 .68155 .53006 Mtetra
.247 0 .261 r
.68155 .53006 .6861 .50999 .69787 .49719 .69345 .51674 Mtetra
.215 0 .245 r
.69345 .51674 .69787 .49719 .70962 .48433 .70528 .50253 Mtetra
.17 0 .214 r
.70528 .50253 .70962 .48433 .72137 .47168 .71705 .4878 Mtetra
.102 0 .16 r
.71705 .4878 .72137 .47168 .73312 .4593 .72878 .47276 Mtetra
0 0 .067 r
.72878 .47276 .73312 .4593 .74488 .44721 .74047 .45756 Mtetra
0 0 0 r
.74047 .45756 .74488 .44721 .75666 .43548 .75213 .44247 Mtetra
.75213 .44247 .75666 .43548 .76847 .42433 .7638 .42796 Mtetra
.681 .924 .612 r
.7638 .42796 .76847 .42433 .78035 .41406 .77553 .41461 Mtetra
.815 1 .815 r
.77553 .41461 .78035 .41406 .79233 .40495 .78738 .40292 Mtetra
.825 .959 .899 r
.78738 .40292 .79233 .40495 .80444 .39712 .79938 .3931 Mtetra
.785 .889 .92 r
.79938 .3931 .80444 .39712 .81667 .39049 .81156 .38507 Mtetra
.742 .831 .919 r
.81156 .38507 .81667 .39049 .82904 .38485 .82389 .37853 Mtetra
.709 .791 .915 r
.82389 .37853 .82904 .38485 .84152 .37991 .83636 .37305 Mtetra
.687 .767 .912 r
.83636 .37305 .84152 .37991 .85409 .37542 .84895 .36825 Mtetra
.675 .753 .91 r
.84895 .36825 .85409 .37542 .86674 .37117 .86163 .36383 Mtetra
.669 .747 .909 r
.86163 .36383 .86674 .37117 .87946 .36704 .87438 .35961 Mtetra
.666 .743 .908 r
.87438 .35961 .87946 .36704 .89224 .36296 .8872 .35546 Mtetra
.664 .742 .908 r
.8872 .35546 .89224 .36296 .90508 .35888 .90008 .35134 Mtetra
.90008 .35134 .90508 .35888 .91798 .3548 .91302 .34722 Mtetra
.663 .741 .908 r
.32228 .52659 .32893 .53278 .33947 .52945 .33285 .52324 Mtetra
.662 .741 .909 r
.33285 .52324 .33947 .52945 .35006 .52612 .34346 .51991 Mtetra
.659 .741 .91 r
.34346 .51991 .35006 .52612 .36068 .52282 .3541 .51663 Mtetra
.655 .742 .913 r
.3541 .51663 .36068 .52282 .37135 .51958 .36479 .51345 Mtetra
.648 .742 .918 r
.36479 .51345 .37135 .51958 .38205 .51645 .37551 .51045 Mtetra
.634 .744 .927 r
.37551 .51045 .38205 .51645 .39279 .5135 .38627 .50776 Mtetra
.61 .746 .942 r
.38627 .50776 .39279 .5135 .40356 .51086 .39705 .50557 Mtetra
.563 .748 .964 r
.39705 .50557 .40356 .51086 .41437 .50872 .40786 .50414 Mtetra
.464 .738 .987 r
.40786 .50414 .41437 .50872 .4252 .50734 .41869 .50383 Mtetra
.228 .661 .956 r
.41869 .50383 .4252 .50734 .43607 .50711 .42954 .50513 Mtetra
.227 0 0 r
.42954 .50513 .43607 .50711 .44695 .50854 .4404 .50861 Mtetra
.589 .025 0 r
.4404 .50861 .44695 .50854 .45787 .51216 .4513 .51483 Mtetra
.713 .238 .119 r
.4513 .51483 .45787 .51216 .46884 .51843 .46225 .52421 Mtetra
.746 .331 .263 r
.46225 .52421 .46884 .51843 .47988 .52758 .47329 .53674 Mtetra
.749 .37 .336 r
.47329 .53674 .47988 .52758 .49103 .53935 .48445 .5518 Mtetra
.738 .38 .373 r
.48445 .5518 .49103 .53935 .50231 .55291 .49577 .56807 Mtetra
.718 .371 .389 r
.49577 .56807 .50231 .55291 .51376 .56688 .50728 .58365 Mtetra
.686 .343 .388 r
.50728 .58365 .51376 .56688 .52537 .57955 .51898 .59641 Mtetra
.638 .291 .368 r
.51898 .59641 .52537 .57955 .53714 .5893 .53083 .60463 Mtetra
.561 .202 .316 r
.53083 .60463 .53714 .5893 .54902 .59503 .54278 .60744 Mtetra
.426 .041 .203 r
.54278 .60744 .54902 .59503 .56096 .59649 .55479 .60522 Mtetra
.171 0 0 r
.55479 .60522 .56096 .59649 .57295 .59432 .56682 .59939 Mtetra
0 0 0 r
.56682 .59939 .57295 .59432 .58495 .58972 .57885 .59194 Mtetra
.514 .905 .766 r
.57885 .59194 .58495 .58972 .59697 .58403 .59092 .58477 Mtetra
.526 .92 .868 r
.59092 .58477 .59697 .58403 .60903 .57821 .60304 .57908 Mtetra
.347 .824 .809 r
.60304 .57908 .60903 .57821 .62113 .57258 .61526 .57508 Mtetra
0 0 0 r
.61526 .57508 .62113 .57258 .63327 .56682 .62755 .57207 Mtetra
.166 0 0 r
.62755 .57207 .63327 .56682 .64541 .56021 .63989 .56881 Mtetra
.242 0 .002 r
.63989 .56881 .64541 .56021 .65753 .55205 .65223 .56405 Mtetra
.251 0 .116 r
.65223 .56405 .65753 .55205 .66958 .54197 .66453 .55695 Mtetra
.238 0 .177 r
.66453 .55695 .66958 .54197 .68155 .53006 .67674 .54726 Mtetra
.218 0 .208 r
.67674 .54726 .68155 .53006 .69345 .51674 .68884 .53524 Mtetra
.193 0 .219 r
.68884 .53524 .69345 .51674 .70528 .50253 .70084 .5213 Mtetra
.156 0 .211 r
.70084 .5213 .70528 .50253 .71705 .4878 .71272 .50579 Mtetra
.095 0 .18 r
.71272 .50579 .71705 .4878 .72878 .47276 .7245 .48892 Mtetra
0 0 .116 r
.7245 .48892 .72878 .47276 .74047 .45756 .73615 .47096 Mtetra
0 0 .003 r
.73615 .47096 .74047 .45756 .75213 .44247 .74771 .45242 Mtetra
0 0 0 r
.74771 .45242 .75213 .44247 .7638 .42796 .75924 .43416 Mtetra
.624 .832 .434 r
.75924 .43416 .7638 .42796 .77553 .41461 .77081 .41718 Mtetra
.81 .977 .685 r
.77081 .41718 .77553 .41461 .78738 .40292 .78249 .40232 Mtetra
.863 .988 .838 r
.78249 .40232 .78738 .40292 .79938 .3931 .79436 .39001 Mtetra
.828 .927 .898 r
.79436 .39001 .79938 .3931 .81156 .38507 .80644 .3802 Mtetra
.774 .859 .913 r
.80644 .3802 .81156 .38507 .82389 .37853 .81872 .37248 Mtetra
.728 .808 .914 r
.81872 .37248 .82389 .37853 .83636 .37305 .83118 .3663 Mtetra
.698 .776 .912 r
.83118 .3663 .83636 .37305 .84895 .36825 .84377 .36111 Mtetra
.68 .758 .91 r
.84377 .36111 .84895 .36825 .86163 .36383 .85647 .35648 Mtetra
.671 .749 .909 r
.85647 .35648 .86163 .36383 .87438 .35961 .86926 .35213 Mtetra
.667 .744 .908 r
.86926 .35213 .87438 .35961 .8872 .35546 .88211 .34792 Mtetra
.665 .743 .908 r
.88211 .34792 .8872 .35546 .90008 .35134 .89503 .34375 Mtetra
.664 .742 .908 r
.89503 .34375 .90008 .35134 .91302 .34722 .90801 .33959 Mtetra
.662 .741 .909 r
.31558 .52036 .32228 .52659 .33285 .52324 .32617 .517 Mtetra
.661 .741 .91 r
.32617 .517 .33285 .52324 .34346 .51991 .3368 .51367 Mtetra
.657 .741 .912 r
.3368 .51367 .34346 .51991 .3541 .51663 .34747 .51042 Mtetra
.651 .741 .916 r
.34747 .51042 .3541 .51663 .36479 .51345 .35818 .50733 Mtetra
.639 .742 .923 r
.35818 .50733 .36479 .51345 .37551 .51045 .36892 .50453 Mtetra
.616 .743 .936 r
.36892 .50453 .37551 .51045 .38627 .50776 .37968 .50222 Mtetra
.574 .743 .957 r
.37968 .50222 .38627 .50776 .39705 .50557 .39047 .50065 Mtetra
.487 .736 .982 r
.39047 .50065 .39705 .50557 .40786 .50414 .40127 .50019 Mtetra
.286 .679 .973 r
.40127 .50019 .40786 .50414 .41869 .50383 .41208 .50128 Mtetra
0 .436 .751 r
.41208 .50128 .41869 .50383 .42954 .50513 .4229 .50448 Mtetra
.547 0 0 r
.4229 .50448 .42954 .50513 .4404 .50861 .43373 .51037 Mtetra
.708 .214 .07 r
.43373 .51037 .4404 .50861 .4513 .51483 .4446 .51945 Mtetra
.753 .326 .237 r
.4446 .51945 .4513 .51483 .46225 .52421 .45553 .53194 Mtetra
.763 .376 .321 r
.45553 .53194 .46225 .52421 .47329 .53674 .46656 .54752 Mtetra
.758 .394 .364 r
.46656 .54752 .47329 .53674 .48445 .5518 .47773 .56511 Mtetra
.744 .391 .383 r
.47773 .56511 .48445 .5518 .49577 .56807 .4891 .58288 Mtetra
.719 .368 .383 r
.4891 .58288 .49577 .56807 .50728 .58365 .50068 .59844 Mtetra
.675 .319 .361 r
.50068 .59844 .50728 .58365 .51898 .59641 .51246 .60944 Mtetra
.594 .216 .296 r
.51246 .60944 .51898 .59641 .53083 .60463 .52439 .61422 Mtetra
.394 0 .11 r
.52439 .61422 .53083 .60463 .54278 .60744 .53641 .6124 Mtetra
0 0 0 r
.53641 .6124 .54278 .60744 .55479 .60522 .54845 .60511 Mtetra
.83 .98 .881 r
.54845 .60511 .55479 .60522 .56682 .59939 .56049 .59459 Mtetra
.834 .838 .849 r
.56049 .59459 .56682 .59939 .57885 .59194 .57252 .58355 Mtetra
.771 .74 .824 r
.57252 .58355 .57885 .59194 .59092 .58477 .58459 .57433 Mtetra
.702 .678 .824 r
.58459 .57433 .59092 .58477 .60304 .57908 .59673 .56828 Mtetra
.628 .641 .844 r
.59673 .56828 .60304 .57908 .61526 .57508 .609 .56554 Mtetra
.553 .634 .886 r
.609 .56554 .61526 .57508 .62755 .57207 .62139 .56514 Mtetra
.482 .677 .951 r
.62139 .56514 .62755 .57207 .63989 .56881 .63388 .56546 Mtetra
.394 .77 .992 r
.63388 .56546 .63989 .56881 .65223 .56405 .64643 .56483 Mtetra
.216 .739 .759 r
.64643 .56483 .65223 .56405 .66453 .55695 .65896 .562 Mtetra
0 0 0 r
.65896 .562 .66453 .55695 .67674 .54726 .67144 .55636 Mtetra
.059 0 0 r
.67144 .55636 .67674 .54726 .68884 .53524 .68382 .54779 Mtetra
.09 0 .061 r
.68382 .54779 .68884 .53524 .70084 .5213 .69608 .5364 Mtetra
.079 0 .117 r
.69608 .5364 .70084 .5213 .71272 .50579 .70818 .52219 Mtetra
.027 0 .123 r
.70818 .52219 .71272 .50579 .7245 .48892 .7201 .50518 Mtetra
0 0 .086 r
.7201 .50518 .7245 .48892 .73615 .47096 .7318 .48557 Mtetra
0 0 0 r
.7318 .48557 .73615 .47096 .74771 .45242 .74332 .46412 Mtetra
.74332 .46412 .74771 .45242 .75924 .43416 .75473 .44218 Mtetra
.636 .795 .353 r
.75473 .44218 .75924 .43416 .77081 .41718 .76613 .42133 Mtetra
.818 .942 .583 r
.76613 .42133 .77081 .41718 .78249 .40232 .77764 .40292 Mtetra
.893 .989 .764 r
.77764 .40292 .78249 .40232 .79436 .39001 .78936 .38773 Mtetra
.87 .95 .862 r
.78936 .38773 .79436 .39001 .80644 .3802 .80133 .37582 Mtetra
.809 .883 .899 r
.80133 .37582 .80644 .3802 .81872 .37248 .81354 .3667 Mtetra
.752 .825 .909 r
.81354 .3667 .81872 .37248 .83118 .3663 .82597 .35967 Mtetra
.711 .786 .91 r
.82597 .35967 .83118 .3663 .84377 .36111 .83856 .35399 Mtetra
.687 .763 .91 r
.83856 .35399 .84377 .36111 .85647 .35648 .85128 .3491 Mtetra
.674 .751 .909 r
.85128 .3491 .85647 .35648 .86926 .35213 .8641 .34462 Mtetra
.668 .746 .908 r
.8641 .34462 .86926 .35213 .88211 .34792 .87699 .34032 Mtetra
.665 .743 .908 r
.87699 .34032 .88211 .34792 .89503 .34375 .88995 .3361 Mtetra
.664 .742 .908 r
.88995 .3361 .89503 .34375 .90801 .33959 .90297 .3319 Mtetra
.662 .741 .909 r
.30882 .51408 .31558 .52036 .32617 .517 .31944 .51071 Mtetra
.659 .741 .91 r
.31944 .51071 .32617 .517 .3368 .51367 .3301 .50739 Mtetra
.654 .741 .913 r
.3301 .50739 .3368 .51367 .34747 .51042 .34079 .50419 Mtetra
.645 .741 .919 r
.34079 .50419 .34747 .51042 .35818 .50733 .35152 .50124 Mtetra
.626 .741 .929 r
.35152 .50124 .35818 .50733 .36892 .50453 .36227 .49871 Mtetra
.59 .74 .947 r
.36227 .49871 .36892 .50453 .37968 .50222 .37303 .4969 Mtetra
.518 .733 .972 r
.37303 .4969 .37968 .50222 .39047 .50065 .38381 .49615 Mtetra
.356 .695 .982 r
.38381 .49615 .39047 .50065 .40127 .50019 .39459 .49692 Mtetra
0 .518 .851 r
.39459 .49692 .40127 .50019 .41208 .50128 .40536 .49973 Mtetra
.467 0 0 r
.40536 .49973 .41208 .50128 .4229 .50448 .41614 .50513 Mtetra
.688 .169 0 r
.41614 .50513 .4229 .50448 .43373 .51037 .42694 .51363 Mtetra
.754 .308 .192 r
.42694 .51363 .43373 .51037 .4446 .51945 .43777 .52552 Mtetra
.771 .371 .294 r
.43777 .52552 .4446 .51945 .45553 .53194 .44867 .54072 Mtetra
.773 .397 .345 r
.44867 .54072 .45553 .53194 .46656 .54752 .4597 .55849 Mtetra
.765 .402 .368 r
.4597 .55849 .46656 .54752 .47773 .56511 .47091 .57727 Mtetra
.748 .387 .37 r
.47091 .57727 .47773 .56511 .4891 .58288 .48233 .59479 Mtetra
.715 .344 .345 r
.48233 .59479 .4891 .58288 .50068 .59844 .49399 .6084 Mtetra
.642 .24 .266 r
.49399 .6084 .50068 .59844 .51246 .60944 .50585 .61576 Mtetra
.391 0 0 r
.50585 .61576 .51246 .60944 .52439 .61422 .51785 .61558 Mtetra
.631 .963 .859 r
.51785 .61558 .52439 .61422 .53641 .6124 .52992 .60813 Mtetra
.86 .846 .829 r
.52992 .60813 .53641 .6124 .54845 .60511 .54199 .59527 Mtetra
.822 .723 .755 r
.54199 .59527 .54845 .60511 .56049 .59459 .55402 .57991 Mtetra
.775 .652 .726 r
.55402 .57991 .56049 .59459 .57252 .58355 .56603 .5652 Mtetra
.722 .598 .717 r
.56603 .5652 .57252 .58355 .58459 .57433 .57806 .5537 Mtetra
.664 .551 .717 r
.57806 .5537 .58459 .57433 .59673 .56828 .59018 .54678 Mtetra
.602 .51 .723 r
.59018 .54678 .59673 .56828 .609 .56554 .60244 .54452 Mtetra
.545 .479 .732 r
.60244 .54452 .609 .56554 .62139 .56514 .61485 .54586 Mtetra
.504 .468 .75 r
.61485 .54586 .62139 .56514 .63388 .56546 .62742 .54907 Mtetra
.487 .487 .782 r
.62742 .54907 .63388 .56546 .64643 .56483 .6401 .55233 Mtetra
.497 .548 .839 r
.6401 .55233 .64643 .56483 .65896 .562 .65283 .55422 Mtetra
.531 .676 .931 r
.65283 .55422 .65896 .562 .67144 .55636 .66556 .55381 Mtetra
.539 .869 .993 r
.66556 .55381 .67144 .55636 .68382 .54779 .67825 .55059 Mtetra
.335 .786 .638 r
.67825 .55059 .68382 .54779 .69608 .5364 .69084 .54407 Mtetra
0 0 0 r
.69084 .54407 .69608 .5364 .70818 .52219 .70325 .53363 Mtetra
.70325 .53363 .70818 .52219 .7201 .50518 .71542 .51868 Mtetra
.71542 .51868 .7201 .50518 .7318 .48557 .72728 .49916 Mtetra
.72728 .49916 .7318 .48557 .74332 .46412 .73884 .47595 Mtetra
.73884 .47595 .74332 .46412 .75473 .44218 .75017 .45089 Mtetra
.713 .816 .356 r
.75017 .45089 .75473 .44218 .76613 .42133 .76143 .4263 Mtetra
.855 .926 .539 r
.76143 .4263 .76613 .42133 .77764 .40292 .77278 .40425 Mtetra
.921 .975 .705 r
.77278 .40425 .77764 .40292 .78936 .38773 .78434 .38598 Mtetra
.904 .955 .82 r
.78434 .38598 .78936 .38773 .80133 .37582 .79619 .37176 Mtetra
.842 .897 .878 r
.79619 .37176 .80133 .37582 .81354 .3667 .80833 .3611 Mtetra
.776 .839 .9 r
.80833 .3611 .81354 .3667 .82597 .35967 .82072 .3531 Mtetra
.726 .795 .907 r
.82072 .3531 .82597 .35967 .83856 .35399 .83331 .34688 Mtetra
.695 .768 .908 r
.83331 .34688 .83856 .35399 .85128 .3491 .84605 .34169 Mtetra
.678 .754 .908 r
.84605 .34169 .85128 .3491 .8641 .34462 .8589 .33705 Mtetra
.67 .747 .908 r
.8589 .33705 .8641 .34462 .87699 .34032 .87182 .33267 Mtetra
.666 .744 .908 r
.87182 .33267 .87699 .34032 .88995 .3361 .88482 .32839 Mtetra
.665 .742 .908 r
.88482 .32839 .88995 .3361 .90297 .3319 .89788 .32414 Mtetra
.661 .741 .909 r
.30202 .50776 .30882 .51408 .31944 .51071 .31267 .50438 Mtetra
.658 .741 .911 r
.31267 .50438 .31944 .51071 .3301 .50739 .32335 .50107 Mtetra
.651 .74 .915 r
.32335 .50107 .3301 .50739 .34079 .50419 .33406 .49795 Mtetra
.637 .74 .923 r
.33406 .49795 .34079 .50419 .35152 .50124 .3448 .49517 Mtetra
.609 .738 .937 r
.3448 .49517 .35152 .50124 .36227 .49871 .35556 .49299 Mtetra
.553 .732 .959 r
.35556 .49299 .36227 .49871 .37303 .4969 .36632 .4918 Mtetra
.432 .708 .981 r
.36632 .4918 .37303 .4969 .38381 .49615 .37707 .49205 Mtetra
.153 .597 .932 r
.37707 .49205 .38381 .49615 .39459 .49692 .38782 .4943 Mtetra
.325 0 0 r
.38782 .4943 .39459 .49692 .40536 .49973 .39855 .49907 Mtetra
.646 .094 0 r
.39855 .49907 .40536 .49973 .41614 .50513 .40927 .50685 Mtetra
.748 .275 .123 r
.40927 .50685 .41614 .50513 .42694 .51363 .42001 .51793 Mtetra
.776 .356 .252 r
.42001 .51793 .42694 .51363 .43777 .52552 .43081 .53227 Mtetra
.782 .392 .316 r
.43081 .53227 .43777 .52552 .44867 .54072 .4417 .54935 Mtetra
.779 .404 .345 r
.4417 .54935 .44867 .54072 .4597 .55849 .45276 .56795 Mtetra
.77 .396 .348 r
.45276 .56795 .4597 .55849 .47091 .57727 .46401 .58613 Mtetra
.749 .362 .319 r
.46401 .58613 .47091 .57727 .48233 .59479 .47552 .6014 Mtetra
.693 .262 .22 r
.47552 .6014 .48233 .59479 .49399 .6084 .48726 .61115 Mtetra
.415 0 0 r
.48726 .61115 .49399 .6084 .50585 .61576 .4992 .61342 Mtetra
.707 .915 .966 r
.4992 .61342 .50585 .61576 .51785 .61558 .51127 .60754 Mtetra
.82 .754 .789 r
.51127 .60754 .51785 .61558 .52992 .60813 .52337 .59445 Mtetra
.805 .673 .717 r
.52337 .59445 .52992 .60813 .54199 .59527 .53545 .57661 Mtetra
.779 .625 .689 r
.53545 .57661 .54199 .59527 .55402 .57991 .54747 .55726 Mtetra
.746 .588 .679 r
.54747 .55726 .55402 .57991 .56603 .5652 .55945 .53963 Mtetra
.704 .551 .678 r
.55945 .53963 .56603 .5652 .57806 .5537 .57144 .52617 Mtetra
.653 .512 .68 r
.57144 .52617 .57806 .5537 .59018 .54678 .58351 .51814 Mtetra
.596 .473 .682 r
.58351 .51814 .59018 .54678 .60244 .54452 .59571 .51557 Mtetra
.544 .438 .684 r
.59571 .51557 .60244 .54452 .61485 .54586 .60809 .51746 Mtetra
.503 .414 .688 r
.60809 .51746 .61485 .54586 .62742 .54907 .62064 .52225 Mtetra
.479 .406 .696 r
.62064 .52225 .62742 .54907 .6401 .55233 .63336 .52834 Mtetra
.468 .414 .714 r
.63336 .52834 .6401 .55233 .65283 .55422 .64621 .53441 Mtetra
.465 .442 .748 r
.64621 .53441 .65283 .55422 .66556 .55381 .65915 .53948 Mtetra
.473 .507 .813 r
.65915 .53948 .66556 .55381 .67825 .55059 .67213 .54265 Mtetra
.508 .664 .932 r
.67213 .54265 .67825 .55059 .69084 .54407 .68507 .54273 Mtetra
.554 .912 .962 r
.68507 .54273 .69084 .54407 .70325 .53363 .69786 .53819 Mtetra
.463 .817 .542 r
.69786 .53819 .70325 .53363 .71542 .51868 .71037 .52751 Mtetra
0 0 0 r
.71037 .52751 .71542 .51868 .72728 .49916 .72248 .51 Mtetra
.72248 .51 .72728 .49916 .73884 .47595 .73416 .48643 Mtetra
.693 .784 .306 r
.73416 .48643 .73884 .47595 .75017 .45089 .74549 .45915 Mtetra
.816 .859 .408 r
.74549 .45915 .75017 .45089 .76143 .4263 .75665 .43127 Mtetra
.908 .923 .537 r
.75665 .43127 .76143 .4263 .77278 .40425 .76786 .40573 Mtetra
.949 .955 .67 r
.76786 .40573 .77278 .40425 .78434 .38598 .77928 .38438 Mtetra
.93 .945 .781 r
.77928 .38438 .78434 .38598 .79619 .37176 .79101 .3678 Mtetra
.869 .9 .852 r
.79101 .3678 .79619 .37176 .80833 .3611 .80308 .35552 Mtetra
.798 .845 .887 r
.80308 .35552 .80833 .3611 .82072 .3531 .81544 .34653 Mtetra
.74 .801 .901 r
.81544 .34653 .82072 .3531 .83331 .34688 .82802 .33973 Mtetra
.703 .772 .906 r
.82802 .33973 .83331 .34688 .84605 .34169 .84078 .33423 Mtetra
.682 .756 .907 r
.84078 .33423 .84605 .34169 .8589 .33705 .85365 .32943 Mtetra
.672 .748 .908 r
.85365 .32943 .8589 .33705 .87182 .33267 .86662 .32495 Mtetra
.667 .744 .908 r
.86662 .32495 .87182 .33267 .88482 .32839 .87965 .32061 Mtetra
.665 .742 .908 r
.87965 .32061 .88482 .32839 .89788 .32414 .89276 .31632 Mtetra
.66 .741 .91 r
.29517 .50139 .30202 .50776 .31267 .50438 .30584 .498 Mtetra
.656 .74 .912 r
.30584 .498 .31267 .50438 .32335 .50107 .31654 .49473 Mtetra
.647 .74 .917 r
.31654 .49473 .32335 .50107 .33406 .49795 .32727 .49169 Mtetra
.627 .738 .927 r
.32727 .49169 .33406 .49795 .3448 .49517 .33802 .48911 Mtetra
.588 .733 .944 r
.33802 .48911 .3448 .49517 .35556 .49299 .34878 .48734 Mtetra
.504 .718 .968 r
.34878 .48734 .35556 .49299 .36632 .4918 .35953 .48687 Mtetra
.313 .658 .972 r
.35953 .48687 .36632 .4918 .37707 .49205 .37026 .48827 Mtetra
0 .432 .803 r
.37026 .48827 .37707 .49205 .38782 .4943 .38096 .49215 Mtetra
.548 0 0 r
.38096 .49215 .38782 .4943 .39855 .49907 .39162 .49903 Mtetra
.731 .222 .014 r
.39162 .49903 .39855 .49907 .40927 .50685 .40229 .50921 Mtetra
.779 .334 .192 r
.40229 .50921 .40927 .50685 .42001 .51793 .41298 .52264 Mtetra
.79 .381 .277 r
.41298 .52264 .42001 .51793 .43081 .53227 .42375 .5388 Mtetra
.789 .398 .316 r
.42375 .5388 .43081 .53227 .4417 .54935 .43466 .55661 Mtetra
.782 .395 .321 r
.43466 .55661 .4417 .54935 .45276 .56795 .44576 .57443 Mtetra
.769 .365 .288 r
.44576 .57443 .45276 .56795 .46401 .58613 .4571 .59008 Mtetra
.727 .271 .167 r
.4571 .59008 .46401 .58613 .47552 .6014 .4687 .60118 Mtetra
.425 0 0 r
.4687 .60118 .47552 .6014 .48726 .61115 .48054 .60558 Mtetra
.646 .788 .95 r
.48054 .60558 .48726 .61115 .4992 .61342 .49257 .60201 Mtetra
.771 .687 .771 r
.49257 .60201 .4992 .61342 .51127 .60754 .50469 .59057 Mtetra
.78 .637 .702 r
.50469 .59057 .51127 .60754 .52337 .59445 .51682 .57282 Mtetra
.773 .608 .674 r
.51682 .57282 .52337 .59445 .53545 .57661 .52891 .55148 Mtetra
.758 .585 .663 r
.52891 .55148 .53545 .57661 .54747 .55726 .54091 .52974 Mtetra
.733 .563 .661 r
.54091 .52974 .54747 .55726 .55945 .53963 .55287 .51053 Mtetra
.698 .536 .664 r
.55287 .51053 .55945 .53963 .57144 .52617 .56481 .49595 Mtetra
.653 .504 .668 r
.56481 .49595 .57144 .52617 .58351 .51814 .57682 .487 Mtetra
.601 .467 .671 r
.57682 .487 .58351 .51814 .59571 .51557 .58896 .48363 Mtetra
.55 .431 .671 r
.58896 .48363 .59571 .51557 .60809 .51746 .60126 .48505 Mtetra
.507 .402 .669 r
.60126 .48505 .60809 .51746 .62064 .52225 .61375 .49009 Mtetra
.474 .381 .67 r
.61375 .49009 .62064 .52225 .63336 .52834 .62644 .49763 Mtetra
.446 .368 .675 r
.62644 .49763 .63336 .52834 .64621 .53441 .63932 .50676 Mtetra
.417 .362 .689 r
.63932 .50676 .64621 .53441 .65915 .53948 .65239 .51666 Mtetra
.386 .37 .719 r
.65239 .51666 .65915 .53948 .67213 .54265 .6656 .52623 Mtetra
.365 .417 .782 r
.6656 .52623 .67213 .54265 .68507 .54273 .67888 .53364 Mtetra
.408 .582 .911 r
.67888 .53364 .68507 .54273 .69786 .53819 .69207 .53628 Mtetra
.6 .916 .976 r
.69207 .53628 .69786 .53819 .71037 .52751 .70496 .53144 Mtetra
.703 .94 .639 r
.70496 .53144 .71037 .52751 .72248 .51 .71738 .51747 Mtetra
.758 .872 .448 r
.71738 .51747 .72248 .51 .73416 .48643 .72925 .49483 Mtetra
.833 .868 .422 r
.72925 .49483 .73416 .48643 .74549 .45915 .74064 .46622 Mtetra
.902 .89 .468 r
.74064 .46622 .74549 .45915 .75665 .43127 .75175 .43561 Mtetra
.951 .916 .551 r
.75175 .43561 .75665 .43127 .76786 .40573 .76284 .40687 Mtetra
.97 .933 .651 r
.76284 .40687 .76786 .40573 .77928 .38438 .77414 .38258 Mtetra
.948 .926 .75 r
.77414 .38258 .77928 .38438 .79101 .3678 .78577 .3637 Mtetra
.889 .893 .827 r
.78577 .3637 .79101 .3678 .80308 .35552 .79777 .34984 Mtetra
.816 .846 .872 r
.79777 .34984 .80308 .35552 .81544 .34653 .8101 .33986 Mtetra
.753 .803 .893 r
.8101 .33986 .81544 .34653 .82802 .33973 .82269 .3325 Mtetra
.71 .774 .902 r
.82269 .3325 .82802 .33973 .84078 .33423 .83546 .3267 Mtetra
.685 .757 .906 r
.83546 .3267 .84078 .33423 .85365 .32943 .84836 .32174 Mtetra
.673 .748 .907 r
.84836 .32174 .85365 .32943 .86662 .32495 .86136 .31717 Mtetra
.668 .744 .908 r
.86136 .31717 .86662 .32495 .87965 .32061 .87444 .31277 Mtetra
.665 .742 .908 r
.87444 .31277 .87965 .32061 .89276 .31632 .88759 .30843 Mtetra
.66 .741 .91 r
.28826 .49498 .29517 .50139 .30584 .498 .29896 .49159 Mtetra
.654 .74 .913 r
.29896 .49159 .30584 .498 .31654 .49473 .30968 .48834 Mtetra
.642 .739 .919 r
.30968 .48834 .31654 .49473 .32727 .49169 .32043 .48539 Mtetra
.617 .735 .931 r
.32043 .48539 .32727 .49169 .33802 .48911 .3312 .48304 Mtetra
.563 .726 .95 r
.3312 .48304 .33802 .48911 .34878 .48734 .34195 .48172 Mtetra
.445 .696 .973 r
.34195 .48172 .34878 .48734 .35953 .48687 .35269 .48202 Mtetra
.166 .579 .935 r
.35269 .48202 .35953 .48687 .37026 .48827 .36337 .48463 Mtetra
0 .244 .628 r
.36337 .48463 .37026 .48827 .38096 .49215 .37401 .49022 Mtetra
.671 .12 0 r
.37401 .49022 .38096 .49215 .39162 .49903 .38461 .49923 Mtetra
.776 .297 .097 r
.38461 .49923 .39162 .49903 .40229 .50921 .39521 .51169 Mtetra
.799 .368 .223 r
.39521 .51169 .40229 .50921 .41298 .52264 .40585 .52708 Mtetra
.799 .393 .28 r
.40585 .52708 .41298 .52264 .42375 .5388 .41662 .54428 Mtetra
.792 .391 .294 r
.41662 .54428 .42375 .5388 .43466 .55661 .42757 .56164 Mtetra
.778 .362 .263 r
.42757 .56164 .43466 .55661 .44576 .57443 .43876 .57712 Mtetra
.739 .269 .134 r
.43876 .57712 .44576 .57443 .4571 .59008 .45021 .58858 Mtetra
.435 0 0 r
.45021 .58858 .4571 .59008 .4687 .60118 .46194 .59407 Mtetra
.584 .717 .935 r
.46194 .59407 .4687 .60118 .48054 .60558 .47389 .59228 Mtetra
.732 .649 .766 r
.47389 .59228 .48054 .60558 .49257 .60201 .48598 .58289 Mtetra
.755 .611 .698 r
.48598 .58289 .49257 .60201 .50469 .59057 .49815 .56676 Mtetra
.759 .591 .669 r
.49815 .56676 .50469 .59057 .51682 .57282 .5103 .54588 Mtetra
.756 .579 .656 r
.5103 .54588 .51682 .57282 .52891 .55148 .52238 .52291 Mtetra
.746 .567 .653 r
.52238 .52291 .52891 .55148 .54091 .52974 .53438 .50063 Mtetra
.727 .554 .657 r
.53438 .50063 .54091 .52974 .55287 .51053 .54631 .4814 Mtetra
.699 .536 .663 r
.54631 .4814 .55287 .51053 .56481 .49595 .55824 .46676 Mtetra
.659 .51 .671 r
.55824 .46676 .56481 .49595 .57682 .487 .5702 .45738 Mtetra
.61 .478 .675 r
.5702 .45738 .57682 .487 .58896 .48363 .58227 .45319 Mtetra
.56 .442 .676 r
.58227 .45319 .58896 .48363 .60126 .48505 .59449 .45361 Mtetra
.512 .407 .673 r
.59449 .45361 .60126 .48505 .61375 .49009 .60689 .458 Mtetra
.467 .376 .669 r
.60689 .458 .61375 .49009 .62644 .49763 .61951 .46583 Mtetra
.42 .346 .668 r
.61951 .46583 .62644 .49763 .63932 .50676 .63238 .47679 Mtetra
.363 .316 .671 r
.63238 .47679 .63932 .50676 .65239 .51666 .64551 .49047 Mtetra
.292 .288 .682 r
.64551 .49047 .65239 .51666 .6656 .52623 .6589 .50573 Mtetra
.216 .278 .713 r
.6589 .50573 .6656 .52623 .67888 .53364 .67246 .52021 Mtetra
.184 .349 .796 r
.67246 .52021 .67888 .53364 .69207 .53628 .68601 .53026 Mtetra
.356 .657 .97 r
.68601 .53026 .69207 .53628 .70496 .53144 .69928 .53188 Mtetra
.732 .991 .863 r
.69928 .53188 .70496 .53144 .71738 .51747 .71204 .52226 Mtetra
.858 .947 .589 r
.71204 .52226 .71738 .51747 .72925 .49483 .72413 .50132 Mtetra
.912 .906 .503 r
.72413 .50132 .72925 .49483 .74064 .46622 .73561 .472 Mtetra
.952 .897 .51 r
.73561 .472 .74064 .46622 .75175 .43561 .74671 .43909 Mtetra
.977 .903 .562 r
.74671 .43909 .75175 .43561 .76284 .40687 .75772 .40743 Mtetra
.982 .91 .639 r
.75772 .40743 .76284 .40687 .77414 .38258 .76891 .38038 Mtetra
.958 .905 .726 r
.76891 .38038 .77414 .38258 .78577 .3637 .78046 .35932 Mtetra
.902 .881 .804 r
.78046 .35932 .78577 .3637 .79777 .34984 .7924 .34394 Mtetra
.83 .842 .857 r
.7924 .34394 .79777 .34984 .8101 .33986 .80471 .33303 Mtetra
.763 .803 .885 r
.80471 .33303 .8101 .33986 .82269 .3325 .8173 .32515 Mtetra
.716 .774 .898 r
.8173 .32515 .82269 .3325 .83546 .3267 .83009 .31907 Mtetra
.689 .757 .904 r
.83009 .31907 .83546 .3267 .84836 .32174 .84303 .31396 Mtetra
.674 .748 .906 r
.84303 .31396 .84836 .32174 .86136 .31717 .85607 .30931 Mtetra
.668 .744 .907 r
.85607 .30931 .86136 .31717 .87444 .31277 .86919 .30486 Mtetra
.665 .742 .908 r
.86919 .30486 .87444 .31277 .88759 .30843 .88237 .30048 Mtetra
.659 .741 .91 r
.28131 .48852 .28826 .49498 .29896 .49159 .29202 .48512 Mtetra
.652 .74 .914 r
.29202 .48512 .29896 .49159 .30968 .48834 .30277 .4819 Mtetra
.637 .737 .921 r
.30277 .4819 .30968 .48834 .32043 .48539 .31354 .47905 Mtetra
.606 .732 .934 r
.31354 .47905 .32043 .48539 .3312 .48304 .32431 .47692 Mtetra
.537 .716 .955 r
.32431 .47692 .3312 .48304 .34195 .48172 .33507 .47604 Mtetra
.38 .665 .97 r
.33507 .47604 .34195 .48172 .35269 .48202 .34578 .4771 Mtetra
.018 .482 .875 r
.34578 .4771 .35269 .48202 .36337 .48463 .35643 .48092 Mtetra
.485 0 0 r
.35643 .48092 .36337 .48463 .37401 .49022 .367 .48818 Mtetra
.738 .215 0 r
.367 .48818 .37401 .49022 .38461 .49923 .37753 .49923 Mtetra
.805 .343 .137 r
.37753 .49923 .38461 .49923 .39521 .51169 .38805 .51375 Mtetra
.815 .389 .232 r
.38805 .51375 .39521 .51169 .40585 .52708 .39866 .5307 Mtetra
.808 .395 .266 r
.39866 .5307 .40585 .52708 .41662 .54428 .40943 .54827 Mtetra
.79 .369 .25 r
.40943 .54827 .41662 .54428 .42757 .56164 .42045 .56422 Mtetra
.749 .284 .145 r
.42045 .56422 .42757 .56164 .43876 .57712 .43175 .57623 Mtetra
.521 0 0 r
.43175 .57623 .43876 .57712 .45021 .58858 .44336 .58241 Mtetra
.521 .724 .966 r
.44336 .58241 .45021 .58858 .46194 .59407 .45523 .58158 Mtetra
.721 .654 .783 r
.45523 .58158 .46194 .59407 .47389 .59228 .46729 .57348 Mtetra
.746 .608 .705 r
.46729 .57348 .47389 .59228 .48598 .58289 .47946 .55885 Mtetra
.751 .586 .671 r
.47946 .55885 .48598 .58289 .49815 .56676 .49166 .53924 Mtetra
.751 .574 .656 r
.49166 .53924 .49815 .56676 .5103 .54588 .50381 .51682 Mtetra
.747 .567 .651 r
.50381 .51682 .5103 .54588 .52238 .52291 .51589 .49391 Mtetra
.739 .562 .654 r
.51589 .49391 .52238 .52291 .53438 .50063 .52788 .47266 Mtetra
.724 .555 .661 r
.52788 .47266 .53438 .50063 .54631 .4814 .53981 .4547 Mtetra
.701 .545 .672 r
.53981 .4547 .54631 .4814 .55824 .46676 .55172 .44096 Mtetra
.667 .527 .684 r
.55172 .44096 .55824 .46676 .5702 .45738 .56367 .43179 Mtetra
.623 .5 .692 r
.56367 .43179 .5702 .45738 .58227 .45319 .57569 .42705 Mtetra
.571 .465 .695 r
.57569 .42705 .58227 .45319 .59449 .45361 .58785 .42645 Mtetra
.516 .426 .692 r
.58785 .42645 .59449 .45361 .60689 .458 .60017 .42983 Mtetra
.455 .382 .686 r
.60017 .42983 .60689 .458 .61951 .46583 .61272 .43732 Mtetra
.379 .331 .678 r
.61272 .43732 .61951 .46583 .63238 .47679 .62554 .44924 Mtetra
.277 .269 .669 r
.62554 .44924 .63238 .47679 .64551 .49047 .6387 .46566 Mtetra
.143 .195 .658 r
.6387 .46566 .64551 .49047 .6589 .50573 .6522 .48559 Mtetra
0 .128 .648 r
.6522 .48559 .6589 .50573 .67246 .52021 .66598 .50628 Mtetra
0 .126 .673 r
.66598 .50628 .67246 .52021 .68601 .53026 .67984 .52319 Mtetra
0 .363 .829 r
.67984 .52319 .68601 .53026 .69928 .53188 .69347 .53101 Mtetra
.558 .924 .939 r
.69347 .53101 .69928 .53188 .71204 .52226 .70654 .52575 Mtetra
.874 .971 .656 r
.70654 .52575 .71204 .52226 .72413 .50132 .71885 .50666 Mtetra
.944 .915 .542 r
.71885 .50666 .72413 .50132 .73561 .472 .73044 .47682 Mtetra
.975 .892 .53 r
.73044 .47682 .73561 .472 .74671 .43909 .74153 .4418 Mtetra
.989 .887 .565 r
.74153 .4418 .74671 .43909 .75772 .40743 .75248 .40739 Mtetra
.988 .889 .628 r
.75248 .40739 .75772 .40743 .76891 .38038 .76359 .37771 Mtetra
.963 .886 .707 r
.76359 .37771 .76891 .38038 .78046 .35932 .77506 .35458 Mtetra
.911 .869 .784 r
.77506 .35458 .78046 .35932 .7924 .34394 .78696 .33778 Mtetra
.84 .837 .843 r
.78696 .33778 .7924 .34394 .80471 .33303 .79926 .32601 Mtetra
.772 .801 .877 r
.79926 .32601 .80471 .33303 .8173 .32515 .81186 .31765 Mtetra
.721 .773 .894 r
.81186 .31765 .8173 .32515 .83009 .31907 .82468 .31133 Mtetra
.691 .756 .902 r
.82468 .31133 .83009 .31907 .84303 .31396 .83765 .3061 Mtetra
.675 .748 .905 r
.83765 .3061 .84303 .31396 .85607 .30931 .85073 .30138 Mtetra
.668 .744 .907 r
.85073 .30138 .85607 .30931 .86919 .30486 .86389 .29688 Mtetra
.665 .742 .907 r
.86389 .29688 .86919 .30486 .88237 .30048 .87712 .29246 Mtetra
.658 .74 .911 r
.2743 .482 .28131 .48852 .29202 .48512 .28504 .47861 Mtetra
.65 .739 .914 r
.28504 .47861 .29202 .48512 .30277 .4819 .29581 .47541 Mtetra
.633 .736 .922 r
.29581 .47541 .30277 .4819 .31354 .47905 .3066 .47264 Mtetra
.596 .728 .936 r
.3066 .47264 .31354 .47905 .32431 .47692 .31738 .4707 Mtetra
.513 .705 .958 r
.31738 .4707 .32431 .47692 .33507 .47604 .32813 .47021 Mtetra
.319 .631 .962 r
.32813 .47021 .33507 .47604 .34578 .4771 .33882 .47197 Mtetra
0 .388 .81 r
.33882 .47197 .34578 .4771 .35643 .48092 .34943 .47688 Mtetra
.58 .02 0 r
.34943 .47688 .35643 .48092 .367 .48818 .35994 .48568 Mtetra
.778 .275 0 r
.35994 .48568 .367 .48818 .37753 .49923 .37039 .49858 Mtetra
.827 .375 .152 r
.37039 .49858 .37753 .49923 .38805 .51375 .38084 .51495 Mtetra
.831 .405 .226 r
.38084 .51495 .38805 .51375 .39866 .5307 .39141 .53317 Mtetra
.815 .393 .24 r
.39141 .53317 .39866 .5307 .40943 .54827 .4022 .55074 Mtetra
.779 .331 .184 r
.4022 .55074 .40943 .54827 .42045 .56422 .4133 .56483 Mtetra
.653 .116 0 r
.4133 .56483 .42045 .56422 .43175 .57623 .42474 .57294 Mtetra
.257 .699 .96 r
.42474 .57294 .43175 .57623 .44336 .58241 .43652 .57356 Mtetra
.732 .72 .84 r
.43652 .57356 .44336 .58241 .45523 .58158 .44855 .56642 Mtetra
.765 .644 .728 r
.44855 .56642 .45523 .58158 .46729 .57348 .46073 .55246 Mtetra
.764 .605 .682 r
.46073 .55246 .46729 .57348 .47946 .55885 .47298 .53342 Mtetra
.758 .585 .662 r
.47298 .53342 .47946 .55885 .49166 .53924 .4852 .51144 Mtetra
.751 .573 .654 r
.4852 .51144 .49166 .53924 .50381 .51682 .49736 .48866 Mtetra
.745 .568 .655 r
.49736 .48866 .50381 .51682 .51589 .49391 .50942 .46692 Mtetra
.736 .566 .661 r
.50942 .46692 .51589 .49391 .52788 .47266 .5214 .44764 Mtetra
.724 .565 .673 r
.5214 .44764 .52788 .47266 .53981 .4547 .53333 .4317 Mtetra
.705 .561 .689 r
.53333 .4317 .53981 .4547 .55172 .44096 .54525 .41949 Mtetra
.676 .552 .707 r
.54525 .41949 .55172 .44096 .56367 .43179 .5572 .41102 Mtetra
.636 .533 .721 r
.5572 .41102 .56367 .43179 .57569 .42705 .56921 .40614 Mtetra
.584 .501 .728 r
.56921 .40614 .57569 .42705 .58785 .42645 .58133 .4048 Mtetra
.518 .457 .727 r
.58133 .4048 .58785 .42645 .60017 .42983 .5936 .40727 Mtetra
.43 .396 .72 r
.5936 .40727 .60017 .42983 .61272 .43732 .60609 .41427 Mtetra
.304 .312 .703 r
.60609 .41427 .61272 .43732 .62554 .44924 .61888 .4267 Mtetra
.122 .195 .667 r
.61888 .4267 .62554 .44924 .6387 .46566 .63204 .44513 Mtetra
0 .048 .598 r
.63204 .44513 .6387 .46566 .6522 .48559 .64563 .46876 Mtetra
0 0 .502 r
.64563 .46876 .6522 .48559 .66598 .50628 .65958 .49462 Mtetra
0 0 .435 r
.65958 .49462 .66598 .50628 .67984 .52319 .67368 .51738 Mtetra
.489 0 0 r
.67368 .51738 .67984 .52319 .69347 .53101 .6876 .53059 Mtetra
.187 .718 .825 r
.6876 .53059 .69347 .53101 .70654 .52575 .70094 .52912 Mtetra
.846 .976 .672 r
.70094 .52912 .70654 .52575 .71885 .50666 .71346 .51155 Mtetra
.956 .915 .554 r
.71346 .51155 .71885 .50666 .73044 .47682 .72514 .48106 Mtetra
.985 .883 .537 r
.72514 .48106 .73044 .47682 .74153 .4418 .73624 .44391 Mtetra
.994 .872 .563 r
.73624 .44391 .74153 .4418 .75248 .40739 .74714 .40681 Mtetra
.99 .871 .617 r
.74714 .40681 .75248 .40739 .76359 .37771 .75818 .37461 Mtetra
.966 .87 .69 r
.75818 .37461 .76359 .37771 .77506 .35458 .76959 .34951 Mtetra
.918 .858 .767 r
.76959 .34951 .77506 .35458 .78696 .33778 .78146 .33138 Mtetra
.849 .832 .83 r
.78146 .33138 .78696 .33778 .79926 .32601 .79375 .31881 Mtetra
.778 .8 .87 r
.79375 .31881 .79926 .32601 .81186 .31765 .80636 .31002 Mtetra
.725 .773 .891 r
.80636 .31002 .81186 .31765 .82468 .31133 .81921 .30349 Mtetra
.693 .756 .9 r
.81921 .30349 .82468 .31133 .83765 .3061 .83222 .29815 Mtetra
.676 .747 .905 r
.83222 .29815 .83765 .3061 .85073 .30138 .84534 .29337 Mtetra
.669 .744 .906 r
.84534 .29337 .85073 .30138 .86389 .29688 .85854 .28882 Mtetra
.665 .742 .907 r
.85854 .28882 .86389 .29688 .87712 .29246 .87181 .28437 Mtetra
.657 .74 .911 r
.26724 .47544 .2743 .482 .28504 .47861 .278 .47203 Mtetra
.649 .738 .915 r
.278 .47203 .28504 .47861 .29581 .47541 .28879 .46885 Mtetra
.63 .734 .923 r
.28879 .46885 .29581 .47541 .3066 .47264 .2996 .46613 Mtetra
.588 .724 .937 r
.2996 .46613 .3066 .47264 .31738 .4707 .3104 .46434 Mtetra
.495 .695 .958 r
.3104 .46434 .31738 .4707 .32813 .47021 .32115 .46415 Mtetra
.274 .6 .951 r
.32115 .46415 .32813 .47021 .33882 .47197 .33183 .46647 Mtetra
0 .317 .761 r
.33183 .46647 .33882 .47197 .34943 .47688 .34239 .47229 Mtetra
.631 .086 0 r
.34239 .47229 .34943 .47688 .35994 .48568 .35284 .48239 Mtetra
.804 .313 0 r
.35284 .48239 .35994 .48568 .37039 .49858 .36321 .49693 Mtetra
.846 .4 .152 r
.36321 .49693 .37039 .49858 .38084 .51495 .3736 .51499 Mtetra
.846 .418 .213 r
.3736 .51499 .38084 .51495 .39141 .53317 .38412 .53442 Mtetra
.823 .39 .21 r
.38412 .53442 .39141 .53317 .4022 .55074 .39491 .55205 Mtetra
.76 .283 .11 r
.39491 .55205 .4022 .55074 .4133 .56483 .40609 .56448 Mtetra
.438 0 0 r
.40609 .56448 .4133 .56483 .42474 .57294 .41768 .56904 Mtetra
.667 .853 .971 r
.41768 .56904 .42474 .57294 .43652 .57356 .42963 .56458 Mtetra
.807 .735 .784 r
.42963 .56458 .43652 .57356 .44855 .56642 .44183 .55178 Mtetra
.805 .665 .708 r
.44183 .55178 .44855 .56642 .46073 .55246 .45415 .53269 Mtetra
.791 .626 .676 r
.45415 .53269 .46073 .55246 .47298 .53342 .46648 .51001 Mtetra
.776 .602 .663 r
.46648 .51001 .47298 .53342 .4852 .51144 .47874 .48635 Mtetra
.763 .588 .661 r
.47874 .48635 .4852 .51144 .49736 .48866 .4909 .46374 Mtetra
.751 .581 .665 r
.4909 .46374 .49736 .48866 .50942 .46692 .50296 .44355 Mtetra
.74 .58 .677 r
.50296 .44355 .50942 .46692 .5214 .44764 .51494 .42647 Mtetra
.727 .583 .694 r
.51494 .42647 .5214 .44764 .53333 .4317 .52688 .41271 Mtetra
.709 .586 .715 r
.52688 .41271 .53333 .4317 .54525 .41949 .53881 .40219 Mtetra
.684 .585 .739 r
.53881 .40219 .54525 .41949 .5572 .41102 .55077 .39465 Mtetra
.647 .575 .759 r
.55077 .39465 .5572 .41102 .56921 .40614 .56278 .38995 Mtetra
.594 .548 .773 r
.56278 .38995 .56921 .40614 .58133 .4048 .57489 .38823 Mtetra
.513 .498 .778 r
.57489 .38823 .58133 .4048 .5936 .40727 .58714 .39011 Mtetra
.382 .414 .769 r
.58714 .39011 .5936 .40727 .60609 .41427 .59961 .39676 Mtetra
.169 .274 .73 r
.59961 .39676 .60609 .41427 .61888 .4267 .61237 .40959 Mtetra
0 .064 .62 r
.61237 .40959 .61888 .4267 .63204 .44513 .62554 .42957 Mtetra
0 0 .435 r
.62554 .42957 .63204 .44513 .64563 .46876 .63919 .45612 Mtetra
.688 .306 0 r
.63919 .45612 .64563 .46876 .65958 .49462 .65326 .4861 Mtetra
.775 .338 0 r
.65326 .4861 .65958 .49462 .67368 .51738 .66756 .51359 Mtetra
.727 .213 0 r
.66756 .51359 .67368 .51738 .6876 .53059 .6817 .53117 Mtetra
.185 0 0 r
.6817 .53117 .6876 .53059 .70094 .52912 .69527 .53266 Mtetra
.811 .972 .67 r
.69527 .53266 .70094 .52912 .71346 .51155 .70795 .51609 Mtetra
.966 .913 .562 r
.70795 .51609 .71346 .51155 .72514 .48106 .71972 .48468 Mtetra
.992 .873 .541 r
.71972 .48468 .72514 .48106 .73624 .44391 .73083 .44536 Mtetra
.997 .858 .562 r
.73083 .44536 .73624 .44391 .74714 .40681 .74169 .40565 Mtetra
.99 .856 .609 r
.74169 .40565 .74714 .40681 .75818 .37461 .75267 .37106 Mtetra
.968 .856 .676 r
.75267 .37106 .75818 .37461 .76959 .34951 .76405 .34411 Mtetra
.922 .849 .753 r
.76405 .34411 .76959 .34951 .78146 .33138 .77589 .32474 Mtetra
.855 .828 .819 r
.77589 .32474 .78146 .33138 .79375 .31881 .78818 .31144 Mtetra
.784 .798 .864 r
.78818 .31144 .79375 .31881 .80636 .31002 .80081 .30227 Mtetra
.728 .772 .888 r
.80081 .30227 .80636 .31002 .81921 .30349 .8137 .29554 Mtetra
.694 .756 .899 r
.8137 .29554 .81921 .30349 .83222 .29815 .82674 .29011 Mtetra
.676 .747 .904 r
.82674 .29011 .83222 .29815 .84534 .29337 .8399 .28528 Mtetra
.669 .743 .906 r
.8399 .28528 .84534 .29337 .85854 .28882 .85315 .2807 Mtetra
.665 .742 .907 r
.85315 .2807 .85854 .28882 .87181 .28437 .86647 .27621 Mtetra
.657 .74 .911 r
.26012 .46883 .26724 .47544 .278 .47203 .27091 .4654 Mtetra
.648 .738 .915 r
.27091 .4654 .278 .47203 .28879 .46885 .28173 .46221 Mtetra
.628 .733 .923 r
.28173 .46221 .28879 .46885 .2996 .46613 .29256 .45951 Mtetra
.584 .72 .937 r
.29256 .45951 .2996 .46613 .3104 .46434 .30337 .45779 Mtetra
.485 .686 .956 r
.30337 .45779 .3104 .46434 .32115 .46415 .31413 .45778 Mtetra
.252 .578 .943 r
.31413 .45778 .32115 .46415 .33183 .46647 .3248 .46047 Mtetra
0 .276 .739 r
.3248 .46047 .33183 .46647 .34239 .47229 .33533 .46695 Mtetra
.652 .121 0 r
.33533 .46695 .34239 .47229 .35284 .48239 .34573 .4781 Mtetra
.82 .339 0 r
.34573 .4781 .35284 .48239 .36321 .49693 .35602 .49405 Mtetra
.862 .42 .143 r
.35602 .49405 .36321 .49693 .3736 .51499 .36632 .51372 Mtetra
.862 .434 .199 r
.36632 .51372 .3736 .51499 .38412 .53442 .37678 .53453 Mtetra
.834 .395 .188 r
.37678 .53453 .38412 .53442 .39491 .55205 .38756 .55273 Mtetra
.745 .25 .059 r
.38756 .55273 .39491 .55205 .40609 .56448 .39879 .56433 Mtetra
.22 0 0 r
.39879 .56433 .40609 .56448 .41768 .56904 .4105 .56635 Mtetra
.795 .905 .918 r
.4105 .56635 .41768 .56904 .42963 .56458 .42262 .55792 Mtetra
.868 .779 .762 r
.42262 .55792 .42963 .56458 .44183 .55178 .435 .54046 Mtetra
.854 .709 .702 r
.435 .54046 .44183 .55178 .45415 .53269 .44747 .51704 Mtetra
.832 .667 .678 r
.44747 .51704 .45415 .53269 .46648 .51001 .4599 .49122 Mtetra
.81 .64 .671 r
.4599 .49122 .46648 .51001 .47874 .48635 .47222 .46605 Mtetra
.788 .621 .674 r
.47222 .46605 .47874 .48635 .4909 .46374 .4844 .44352 Mtetra
.769 .611 .683 r
.4844 .44352 .4909 .46374 .50296 .44355 .49646 .42456 Mtetra
.751 .609 .7 r
.49646 .42456 .50296 .44355 .51494 .42647 .50845 .40929 Mtetra
.734 .612 .722 r
.50845 .40929 .51494 .42647 .52688 .41271 .52041 .39739 Mtetra
.715 .619 .749 r
.52041 .39739 .52688 .41271 .53881 .40219 .53236 .38834 Mtetra
.69 .624 .777 r
.53236 .38834 .53881 .40219 .55077 .39465 .54434 .38172 Mtetra
.654 .62 .803 r
.54434 .38172 .55077 .39465 .56278 .38995 .55638 .37736 Mtetra
.597 .598 .823 r
.55638 .37736 .56278 .38995 .57489 .38823 .5685 .37553 Mtetra
.496 .544 .835 r
.5685 .37553 .57489 .38823 .58714 .39011 .58075 .37712 Mtetra
.304 .428 .822 r
.58075 .37712 .58714 .39011 .59961 .39676 .5932 .38364 Mtetra
0 .202 .723 r
.5932 .38364 .59961 .39676 .61237 .40959 .60596 .39685 Mtetra
0 0 .481 r
.60596 .39685 .61237 .40959 .62554 .42957 .61914 .41805 Mtetra
.723 .324 0 r
.61914 .41805 .62554 .42957 .63919 .45612 .63282 .44683 Mtetra
.833 .418 0 r
.63282 .44683 .63919 .45612 .65326 .4861 .64698 .47997 Mtetra
.858 .421 0 r
.64698 .47997 .65326 .4861 .66756 .51359 .66142 .51108 Mtetra
.801 .31 0 r
.66142 .51108 .66756 .51359 .6817 .53117 .67574 .53195 Mtetra
.355 0 0 r
.67574 .53195 .6817 .53117 .69527 .53266 .68948 .53561 Mtetra
.824 .984 .704 r
.68948 .53561 .69527 .53266 .70795 .51609 .7023 .51956 Mtetra
.98 .906 .581 r
.7023 .51956 .70795 .51609 .71972 .48468 .71414 .48711 Mtetra
.997 .86 .551 r
.71414 .48711 .71972 .48468 .73083 .44536 .72528 .44573 Mtetra
.997 .843 .564 r
.72528 .44573 .73083 .44536 .74169 .40565 .73611 .40364 Mtetra
.989 .84 .604 r
.73611 .40364 .74169 .40565 .75267 .37106 .74707 .36691 Mtetra
.967 .842 .666 r
.74707 .36691 .75267 .37106 .76405 .34411 .75842 .33832 Mtetra
.925 .839 .741 r
.75842 .33832 .76405 .34411 .77589 .32474 .77026 .31786 Mtetra
.86 .823 .81 r
.77026 .31786 .77589 .32474 .78818 .31144 .78255 .30392 Mtetra
.789 .797 .859 r
.78255 .30392 .78818 .31144 .80081 .30227 .79522 .2944 Mtetra
.731 .772 .885 r
.79522 .2944 .80081 .30227 .8137 .29554 .80813 .28751 Mtetra
.695 .755 .898 r
.80813 .28751 .8137 .29554 .82674 .29011 .82122 .282 Mtetra
.677 .747 .904 r
.82122 .282 .82674 .29011 .8399 .28528 .83442 .27712 Mtetra
.669 .743 .906 r
.83442 .27712 .8399 .28528 .85315 .2807 .84771 .2725 Mtetra
.665 .742 .907 r
.84771 .2725 .85315 .2807 .86647 .27621 .86108 .26797 Mtetra
.657 .74 .911 r
.25295 .46215 .26012 .46883 .27091 .4654 .26377 .4587 Mtetra
.648 .737 .914 r
.26377 .4587 .27091 .4654 .28173 .46221 .27461 .45548 Mtetra
.628 .732 .922 r
.27461 .45548 .28173 .46221 .29256 .45951 .28546 .45277 Mtetra
.584 .718 .935 r
.28546 .45277 .29256 .45951 .30337 .45779 .2963 .45104 Mtetra
.484 .68 .952 r
.2963 .45104 .30337 .45779 .31413 .45778 .30707 .45107 Mtetra
.252 .567 .938 r
.30707 .45107 .31413 .45778 .3248 .46047 .31774 .45392 Mtetra
0 .264 .74 r
.31774 .45392 .3248 .46047 .33533 .46695 .32826 .46078 Mtetra
.65 .134 0 r
.32826 .46078 .33533 .46695 .34573 .4781 .33861 .47266 Mtetra
.827 .354 0 r
.33861 .47266 .34573 .4781 .35602 .49405 .34883 .4898 Mtetra
.875 .438 .129 r
.34883 .4898 .35602 .49405 .36632 .51372 .35904 .51105 Mtetra
.878 .453 .188 r
.35904 .51105 .36632 .51372 .37678 .53453 .3694 .53359 Mtetra
.849 .411 .179 r
.3694 .53359 .37678 .53453 .38756 .55273 .38013 .55317 Mtetra
.751 .257 .057 r
.38013 .55317 .38756 .55273 .39879 .56433 .39136 .56517 Mtetra
.19 0 0 r
.39136 .56517 .39879 .56433 .4105 .56635 .40316 .56616 Mtetra
.842 .967 .883 r
.40316 .56616 .4105 .56635 .42262 .55792 .41542 .55524 Mtetra
.924 .845 .748 r
.41542 .55524 .42262 .55792 .435 .54046 .42798 .53432 Mtetra
.911 .773 .697 r
.42798 .53432 .435 .54046 .44747 .51704 .44062 .50729 Mtetra
.887 .729 .681 r
.44062 .50729 .44747 .51704 .4599 .49122 .45318 .47853 Mtetra
.859 .698 .681 r
.45318 .47853 .4599 .49122 .47222 .46605 .46559 .45156 Mtetra
.83 .675 .69 r
.46559 .45156 .47222 .46605 .4844 .44352 .47782 .4285 Mtetra
.802 .66 .707 r
.47782 .4285 .4844 .44352 .49646 .42456 .48992 .41001 Mtetra
.774 .653 .729 r
.48992 .41001 .49646 .42456 .50845 .40929 .50193 .3958 Mtetra
.748 .654 .757 r
.50193 .3958 .50845 .40929 .52041 .39739 .51391 .38511 Mtetra
.722 .659 .787 r
.51391 .38511 .52041 .39739 .53236 .38834 .52589 .3771 Mtetra
.693 .665 .817 r
.52589 .3771 .53236 .38834 .54434 .38172 .53789 .37118 Mtetra
.656 .663 .845 r
.53789 .37118 .54434 .38172 .55638 .37736 .54996 .36714 Mtetra
.593 .643 .869 r
.54996 .36714 .55638 .37736 .5685 .37553 .5621 .36535 Mtetra
.469 .583 .886 r
.5621 .36535 .5685 .37553 .58075 .37712 .57436 .36684 Mtetra
.205 .429 .857 r
.57436 .36684 .58075 .37712 .5932 .38364 .58682 .37334 Mtetra
0 .112 .662 r
.58682 .37334 .5932 .38364 .60596 .39685 .59958 .38686 Mtetra
.643 .221 0 r
.59958 .38686 .60596 .39685 .61914 .41805 .61276 .40892 Mtetra
.818 .396 0 r
.61276 .40892 .61914 .41805 .63282 .44683 .62647 .43925 Mtetra
.875 .458 .026 r
.62647 .43925 .63282 .44683 .64698 .47997 .64068 .47457 Mtetra
.879 .45 .055 r
.64068 .47457 .64698 .47997 .66142 .51108 .6552 .50818 Mtetra
.821 .342 0 r
.6552 .50818 .66142 .51108 .67574 .53195 .66963 .53134 Mtetra
.365 0 0 r
.66963 .53134 .67574 .53195 .68948 .53561 .6835 .53646 Mtetra
.885 .991 .782 r
.6835 .53646 .68948 .53561 .7023 .51956 .69643 .52066 Mtetra
.99 .886 .612 r
.69643 .52066 .7023 .51956 .71414 .48711 .70836 .48732 Mtetra
.996 .84 .569 r
.70836 .48732 .71414 .48711 .72528 .44573 .71954 .44429 Mtetra
.993 .824 .572 r
.71954 .44429 .72528 .44573 .73611 .40364 .73039 .40032 Mtetra
.983 .822 .604 r
.73039 .40032 .73611 .40364 .74707 .36691 .74135 .36189 Mtetra
.963 .826 .66 r
.74135 .36189 .74707 .36691 .75842 .33832 .7527 .33201 Mtetra
.924 .828 .732 r
.7527 .33201 .75842 .33832 .77026 .31786 .76455 .31069 Mtetra
.863 .817 .802 r
.76455 .31069 .77026 .31786 .78255 .30392 .77687 .29623 Mtetra
.792 .795 .854 r
.77687 .29623 .78255 .30392 .79522 .2944 .78957 .28643 Mtetra
.733 .771 .883 r
.78957 .28643 .79522 .2944 .80813 .28751 .80252 .2794 Mtetra
.696 .755 .897 r
.80252 .2794 .80813 .28751 .82122 .282 .81565 .27381 Mtetra
.677 .747 .904 r
.81565 .27381 .82122 .282 .83442 .27712 .8289 .26889 Mtetra
.669 .743 .906 r
.8289 .26889 .83442 .27712 .84771 .2725 .84223 .26423 Mtetra
.665 .742 .907 r
.84223 .26423 .84771 .2725 .86108 .26797 .85564 .25967 Mtetra
.657 .74 .911 r
.24573 .45542 .25295 .46215 .26377 .4587 .25657 .45194 Mtetra
.649 .737 .914 r
.25657 .45194 .26377 .4587 .27461 .45548 .26744 .44867 Mtetra
.63 .731 .921 r
.26744 .44867 .27461 .45548 .28546 .45277 .27832 .44589 Mtetra
.587 .717 .933 r
.27832 .44589 .28546 .45277 .2963 .45104 .28918 .44408 Mtetra
.492 .679 .948 r
.28918 .44408 .2963 .45104 .30707 .45107 .29998 .44402 Mtetra
.272 .568 .936 r
.29998 .44402 .30707 .45107 .31774 .45392 .31066 .44681 Mtetra
0 .276 .76 r
.31066 .44681 .31774 .45392 .32826 .46078 .32117 .45377 Mtetra
.628 .126 0 r
.32117 .45377 .32826 .46078 .33861 .47266 .33149 .46606 Mtetra
.827 .361 0 r
.33149 .46606 .33861 .47266 .34883 .4898 .34164 .4841 Mtetra
.885 .453 .114 r
.34164 .4841 .34883 .4898 .35904 .51105 .35175 .50689 Mtetra
.892 .473 .18 r
.35175 .50689 .35904 .51105 .3694 .53359 .36199 .53152 Mtetra
.868 .438 .183 r
.36199 .53152 .3694 .53359 .38013 .55317 .37261 .55335 Mtetra
.78 .3 .091 r
.37261 .55335 .38013 .55317 .39136 .56517 .3838 .56713 Mtetra
.322 0 0 r
.3838 .56713 .39136 .56517 .40316 .56616 .39562 .56878 Mtetra
.804 1 .821 r
.39562 .56878 .40316 .56616 .41542 .55524 .40799 .557 Mtetra
.96 .912 .722 r
.40799 .557 .41542 .55524 .42798 .53432 .42072 .53388 Mtetra
.961 .842 .68 r
.42072 .53388 .42798 .53432 .44062 .50729 .43355 .5039 Mtetra
.943 .8 .673 r
.43355 .5039 .44062 .50729 .45318 .47853 .44628 .47219 Mtetra
.917 .77 .683 r
.44628 .47219 .45318 .47853 .46559 .45156 .45882 .44292 Mtetra
.885 .746 .703 r
.45882 .44292 .46559 .45156 .47782 .4285 .47114 .41848 Mtetra
.848 .727 .729 r
.47114 .41848 .47782 .4285 .48992 .41001 .4833 .3995 Mtetra
.809 .714 .76 r
.4833 .3995 .48992 .41001 .50193 .3958 .49535 .38543 Mtetra
.769 .706 .793 r
.49535 .38543 .50193 .3958 .51391 .38511 .50736 .3752 Mtetra
.732 .704 .824 r
.50736 .3752 .51391 .38511 .52589 .3771 .51937 .36771 Mtetra
.696 .703 .853 r
.51937 .36771 .52589 .3771 .53789 .37118 .53141 .3622 Mtetra
.654 .698 .879 r
.53141 .3622 .53789 .37118 .54996 .36714 .54351 .35838 Mtetra
.585 .676 .903 r
.54351 .35838 .54996 .36714 .5621 .36535 .55567 .35664 Mtetra
.441 .61 .92 r
.55567 .35664 .5621 .36535 .57436 .36684 .56796 .3581 Mtetra
.121 .421 .866 r
.56796 .3581 .57436 .36684 .58682 .37334 .58043 .36457 Mtetra
0 .05 .595 r
.58043 .36457 .58682 .37334 .59958 .38686 .59319 .37821 Mtetra
.715 .27 0 r
.59319 .37821 .59958 .38686 .61276 .40892 .60636 .40065 Mtetra
.843 .418 0 r
.60636 .40065 .61276 .40892 .62647 .43925 .62006 .43173 Mtetra
.882 .467 .043 r
.62006 .43173 .62647 .43925 .64068 .47457 .63428 .46817 Mtetra
.878 .454 .043 r
.63428 .46817 .64068 .47457 .6552 .50818 .64882 .50314 Mtetra
.807 .335 0 r
.64882 .50314 .6552 .50818 .66963 .53134 .66331 .52759 Mtetra
0 .357 .74 r
.66331 .52759 .66963 .53134 .6835 .53646 .67726 .53358 Mtetra
.902 .922 .822 r
.67726 .53358 .6835 .53646 .69643 .52066 .69029 .518 Mtetra
.978 .844 .64 r
.69029 .518 .69643 .52066 .70836 .48732 .70232 .48419 Mtetra
.984 .811 .588 r
.70232 .48419 .70836 .48732 .71954 .44429 .71357 .44023 Mtetra
.982 .8 .584 r
.71357 .44023 .71954 .44429 .73039 .40032 .72449 .39516 Mtetra
.974 .802 .609 r
.72449 .39516 .73039 .40032 .74135 .36189 .7355 .3557 Mtetra
.956 .809 .658 r
.7355 .3557 .74135 .36189 .7527 .33201 .74689 .32501 Mtetra
.92 .814 .726 r
.74689 .32501 .7527 .33201 .76455 .31069 .75878 .30314 Mtetra
.862 .809 .796 r
.75878 .30314 .76455 .31069 .77687 .29623 .77113 .28834 Mtetra
.793 .791 .85 r
.77113 .28834 .77687 .29623 .78957 .28643 .78386 .27835 Mtetra
.734 .771 .882 r
.78386 .27835 .78957 .28643 .80252 .2794 .79686 .27121 Mtetra
.697 .755 .897 r
.79686 .27121 .80252 .2794 .81565 .27381 .81003 .26556 Mtetra
.677 .747 .904 r
.81003 .26556 .81565 .27381 .8289 .26889 .82332 .26059 Mtetra
.669 .743 .906 r
.82332 .26059 .8289 .26889 .84223 .26423 .8367 .2559 Mtetra
.665 .742 .907 r
.8367 .2559 .84223 .26423 .85564 .25967 .85015 .2513 Mtetra
.658 .74 .91 r
.23845 .44864 .24573 .45542 .25657 .45194 .24932 .44511 Mtetra
.65 .737 .913 r
.24932 .44511 .25657 .45194 .26744 .44867 .26022 .44178 Mtetra
.633 .731 .919 r
.26022 .44178 .26744 .44867 .27832 .44589 .27113 .4389 Mtetra
.594 .717 .93 r
.27113 .4389 .27832 .44589 .28918 .44408 .28202 .43694 Mtetra
.507 .68 .944 r
.28202 .43694 .28918 .44408 .29998 .44402 .29285 .43666 Mtetra
.306 .578 .937 r
.29285 .43666 .29998 .44402 .31066 .44681 .30356 .4392 Mtetra
0 .306 .79 r
.30356 .4392 .31066 .44681 .32117 .45377 .31408 .44597 Mtetra
.588 .101 0 r
.31408 .44597 .32117 .45377 .33149 .46606 .32438 .45832 Mtetra
.818 .36 0 r
.32438 .45832 .33149 .46606 .34164 .4841 .33448 .47695 Mtetra
.89 .465 .096 r
.33448 .47695 .34164 .4841 .35175 .50689 .34448 .50111 Mtetra
.905 .494 .173 r
.34448 .50111 .35175 .50689 .36199 .53152 .35458 .528 Mtetra
.888 .469 .188 r
.35458 .528 .36199 .53152 .37261 .55335 .36504 .55276 Mtetra
.819 .358 .129 r
.36504 .55276 .37261 .55335 .3838 .56713 .37611 .56955 Mtetra
.488 0 0 r
.37611 .56955 .3838 .56713 .39562 .56878 .38789 .57344 Mtetra
.652 .947 .712 r
.38789 .57344 .39562 .56878 .40799 .557 .40033 .56244 Mtetra
.956 .95 .678 r
.40033 .56244 .40799 .557 .42072 .53388 .4132 .53838 Mtetra
.984 .89 .645 r
.4132 .53838 .42072 .53388 .43355 .5039 .42623 .50611 Mtetra
.98 .856 .646 r
.42623 .50611 .43355 .5039 .44628 .47219 .43917 .47149 Mtetra
.964 .833 .666 r
.43917 .47149 .44628 .47219 .45882 .44292 .45188 .4394 Mtetra
.937 .815 .699 r
.45188 .4394 .45882 .44292 .47114 .41848 .46434 .41274 Mtetra
.899 .798 .74 r
.46434 .41274 .47114 .41848 .4833 .3995 .47659 .39234 Mtetra
.85 .78 .783 r
.47659 .39234 .4833 .3995 .49535 .38543 .48871 .37756 Mtetra
.796 .763 .822 r
.48871 .37756 .49535 .38543 .50736 .3752 .50076 .36712 Mtetra
.745 .749 .855 r
.50076 .36712 .50736 .3752 .51937 .36771 .51281 .35968 Mtetra
.699 .738 .881 r
.51281 .35968 .51937 .36771 .53141 .3622 .52489 .35429 Mtetra
.65 .727 .905 r
.52489 .35429 .53141 .3622 .54351 .35838 .53701 .35058 Mtetra
.575 .702 .928 r
.53701 .35058 .54351 .35838 .55567 .35664 .54921 .34888 Mtetra
.417 .629 .941 r
.54921 .34888 .55567 .35664 .56796 .3581 .56152 .35028 Mtetra
.068 .417 .865 r
.56152 .35028 .56796 .3581 .58043 .36457 .574 .35661 Mtetra
0 .026 .559 r
.574 .35661 .58043 .36457 .59319 .37821 .58676 .37005 Mtetra
.731 .278 0 r
.58676 .37005 .59319 .37821 .60636 .40065 .59991 .3923 Mtetra
.841 .415 0 r
.59991 .3923 .60636 .40065 .62006 .43173 .61358 .42323 Mtetra
.872 .46 .016 r
.61358 .42323 .62006 .43173 .63428 .46817 .62775 .45965 Mtetra
.856 .438 0 r
.62775 .45965 .63428 .46817 .64882 .50314 .64227 .49474 Mtetra
.73 .28 0 r
.64227 .49474 .64882 .50314 .66331 .52759 .65676 .51948 Mtetra
.111 .451 .883 r
.65676 .51948 .66331 .52759 .67726 .53358 .67075 .52583 Mtetra
.856 .803 .798 r
.67075 .52583 .67726 .53358 .69029 .518 .68386 .51056 Mtetra
.945 .787 .655 r
.68386 .51056 .69029 .518 .70232 .48419 .69599 .47691 Mtetra
.962 .775 .605 r
.69599 .47691 .70232 .48419 .71357 .44023 .70737 .43295 Mtetra
.965 .773 .596 r
.70737 .43295 .71357 .44023 .72449 .39516 .7184 .38774 Mtetra
.96 .779 .616 r
.7184 .38774 .72449 .39516 .7355 .3557 .7295 .34808 Mtetra
.944 .79 .66 r
.7295 .34808 .7355 .3557 .74689 .32501 .74097 .31719 Mtetra
.912 .8 .723 r
.74097 .31719 .74689 .32501 .75878 .30314 .75292 .29514 Mtetra
.858 .8 .792 r
.75292 .29514 .75878 .30314 .77113 .28834 .76533 .28021 Mtetra
.793 .787 .847 r
.76533 .28021 .77113 .28834 .78386 .27835 .77811 .27013 Mtetra
.735 .769 .881 r
.77811 .27013 .78386 .27835 .79686 .27121 .79115 .26293 Mtetra
.697 .755 .897 r
.79115 .26293 .79686 .27121 .81003 .26556 .80437 .25723 Mtetra
.677 .747 .904 r
.80437 .25723 .81003 .26556 .82332 .26059 .8177 .25223 Mtetra
.669 .743 .906 r
.8177 .25223 .82332 .26059 .8367 .2559 .83113 .24749 Mtetra
.665 .742 .907 r
.83113 .24749 .8367 .2559 .85015 .2513 .84462 .24286 Mtetra
.659 .74 .91 r
.23111 .4418 .23845 .44864 .24932 .44511 .24201 .43822 Mtetra
.652 .737 .912 r
.24201 .43822 .24932 .44511 .26022 .44178 .25294 .43481 Mtetra
.636 .732 .917 r
.25294 .43481 .26022 .44178 .27113 .4389 .26388 .43181 Mtetra
.602 .718 .926 r
.26388 .43181 .27113 .4389 .28202 .43694 .27481 .42964 Mtetra
.525 .684 .939 r
.27481 .42964 .28202 .43694 .29285 .43666 .28568 .42904 Mtetra
.348 .593 .937 r
.28568 .42904 .29285 .43666 .30356 .4392 .29643 .43117 Mtetra
0 .349 .823 r
.29643 .43117 .30356 .4392 .31408 .44597 .30698 .43749 Mtetra
0 0 .47 r
.30698 .43749 .31408 .44597 .32438 .45832 .31729 .44955 Mtetra
.798 .346 0 r
.31729 .44955 .32438 .45832 .33448 .47695 .32734 .46835 Mtetra
.889 .47 .071 r
.32734 .46835 .33448 .47695 .34448 .50111 .33724 .49351 Mtetra
.913 .51 .159 r
.33724 .49351 .34448 .50111 .35458 .528 .34719 .52252 Mtetra
.906 .498 .185 r
.34719 .52252 .35458 .528 .36504 .55276 .35746 .55049 Mtetra
.857 .413 .147 r
.35746 .55049 .36504 .55276 .37611 .56955 .36835 .5711 Mtetra
.626 .09 0 r
.36835 .5711 .37611 .56955 .38789 .57344 .38003 .57849 Mtetra
.455 .843 .627 r
.38003 .57849 .38789 .57344 .40033 .56244 .39248 .56971 Mtetra
.927 .959 .644 r
.39248 .56971 .40033 .56244 .4132 .53838 .40547 .54599 Mtetra
.983 .908 .61 r
.40547 .54599 .4132 .53838 .42623 .50611 .41869 .51225 Mtetra
.991 .881 .61 r
.41869 .51225 .42623 .50611 .43917 .47149 .43186 .47495 Mtetra
.986 .867 .634 r
.43186 .47495 .43917 .47149 .45188 .4394 .44478 .43978 Mtetra
.97 .86 .675 r
.44478 .43978 .45188 .4394 .46434 .41274 .4574 .41034 Mtetra
.938 .851 .73 r
.4574 .41034 .46434 .41274 .47659 .39234 .46978 .38782 Mtetra
.889 .837 .788 r
.46978 .38782 .47659 .39234 .48871 .37756 .48198 .37168 Mtetra
.827 .816 .839 r
.48198 .37168 .48871 .37756 .50076 .36712 .49409 .36051 Mtetra
.762 .793 .878 r
.49409 .36051 .50076 .36712 .51281 .35968 .50619 .3528 Mtetra
.704 .774 .906 r
.50619 .3528 .51281 .35968 .52489 .35429 .51831 .34738 Mtetra
.646 .756 .929 r
.51831 .34738 .52489 .35429 .53701 .35058 .53047 .34372 Mtetra
.562 .728 .952 r
.53047 .34372 .53701 .35058 .54921 .34888 .5427 .34205 Mtetra
.388 .647 .96 r
.5427 .34205 .54921 .34888 .56152 .35028 .55504 .34336 Mtetra
.019 .416 .86 r
.55504 .34336 .56152 .35028 .574 .35661 .56753 .34941 Mtetra
0 .021 .539 r
.56753 .34941 .574 .35661 .58676 .37005 .58028 .36231 Mtetra
.73 .269 0 r
.58028 .36231 .58676 .37005 .59991 .3923 .59341 .38373 Mtetra
.828 .4 0 r
.59341 .38373 .59991 .3923 .61358 .42323 .60701 .41358 Mtetra
.849 .439 0 r
.60701 .41358 .61358 .42323 .62775 .45965 .62111 .44877 Mtetra
.806 .4 0 r
.62111 .44877 .62775 .45965 .64227 .49474 .63554 .48275 Mtetra
0 0 .399 r
.63554 .48275 .64227 .49474 .65676 .51948 .64998 .50675 Mtetra
.305 .457 .848 r
.64998 .50675 .65676 .51948 .67075 .52583 .66396 .51292 Mtetra
.8 .704 .759 r
.66396 .51292 .67075 .52583 .68386 .51056 .67714 .49806 Mtetra
.903 .732 .659 r
.67714 .49806 .68386 .51056 .69599 .47691 .68939 .46524 Mtetra
.933 .738 .616 r
.68939 .46524 .69599 .47691 .70737 .43295 .70092 .42225 Mtetra
.943 .746 .607 r
.70092 .42225 .70737 .43295 .7184 .38774 .71211 .37792 Mtetra
.942 .757 .623 r
.71211 .37792 .7184 .38774 .7295 .34808 .72336 .33894 Mtetra
.93 .772 .663 r
.72336 .33894 .7295 .34808 .74097 .31719 .73494 .30848 Mtetra
.902 .786 .723 r
.73494 .30848 .74097 .31719 .75292 .29514 .74698 .28667 Mtetra
.852 .79 .79 r
.74698 .28667 .75292 .29514 .76533 .28021 .75946 .27184 Mtetra
.79 .782 .846 r
.75946 .27184 .76533 .28021 .77811 .27013 .7723 .26179 Mtetra
.734 .767 .88 r
.7723 .26179 .77811 .27013 .79115 .26293 .78539 .25457 Mtetra
.697 .754 .896 r
.78539 .25457 .79115 .26293 .80437 .25723 .79865 .24884 Mtetra
.677 .747 .904 r
.79865 .24884 .80437 .25723 .8177 .25223 .81203 .24379 Mtetra
.669 .744 .906 r
.81203 .24379 .8177 .25223 .83113 .24749 .8255 .23902 Mtetra
.665 .742 .907 r
.8255 .23902 .83113 .24749 .84462 .24286 .83904 .23434 Mtetra
.659 .74 .909 r
.22372 .4349 .23111 .4418 .24201 .43822 .23465 .43126 Mtetra
.654 .738 .911 r
.23465 .43126 .24201 .43822 .25294 .43481 .24561 .42778 Mtetra
.641 .733 .915 r
.24561 .42778 .25294 .43481 .26388 .43181 .25659 .42463 Mtetra
.611 .72 .923 r
.25659 .42463 .26388 .43181 .27481 .42964 .26756 .42223 Mtetra
.545 .69 .934 r
.26756 .42223 .27481 .42964 .28568 .42904 .27847 .42125 Mtetra
.393 .612 .937 r
.27847 .42125 .28568 .42904 .29643 .43117 .28927 .42283 Mtetra
.057 .4 .856 r
.28927 .42283 .29643 .43117 .30698 .43749 .29986 .42847 Mtetra
0 .006 .545 r
.29986 .42847 .30698 .43749 .31729 .44955 .31019 .43987 Mtetra
.763 .318 0 r
.31019 .43987 .31729 .44955 .32734 .46835 .32024 .45834 Mtetra
.879 .466 .035 r
.32024 .45834 .32734 .46835 .33724 .49351 .33006 .48391 Mtetra
.915 .52 .134 r
.33006 .48391 .33724 .49351 .34719 .52252 .33986 .51451 Mtetra
.917 .52 .167 r
.33986 .51451 .34719 .52252 .35746 .55049 .34994 .54544 Mtetra
.886 .458 .136 r
.34994 .54544 .35746 .55049 .36835 .5711 .36062 .57007 Mtetra
.729 .207 0 r
.36062 .57007 .36835 .5711 .38003 .57849 .37213 .58173 Mtetra
.301 .776 .67 r
.37213 .58173 .38003 .57849 .39248 .56971 .38452 .57634 Mtetra
.919 .968 .666 r
.38452 .57634 .39248 .56971 .40547 .54599 .39758 .55424 Mtetra
.981 .911 .603 r
.39758 .55424 .40547 .54599 .41869 .51225 .41098 .52007 Mtetra
.992 .884 .591 r
.41098 .52007 .41869 .51225 .43186 .47495 .42436 .4807 Mtetra
.991 .875 .609 r
.42436 .4807 .43186 .47495 .44478 .43978 .43751 .44264 Mtetra
.983 .876 .648 r
.43751 .44264 .44478 .43978 .4574 .41034 .45034 .41025 Mtetra
.961 .878 .707 r
.45034 .41025 .4574 .41034 .46978 .38782 .46286 .3853 Mtetra
.919 .876 .777 r
.46286 .3853 .46978 .38782 .48198 .37168 .47516 .36748 Mtetra
.855 .862 .845 r
.47516 .36748 .48198 .37168 .49409 .36051 .48735 .35536 Mtetra
.779 .84 .898 r
.48735 .35536 .49409 .36051 .50619 .3528 .4995 .34726 Mtetra
.705 .818 .935 r
.4995 .34726 .50619 .3528 .51831 .34738 .51166 .34181 Mtetra
.631 .798 .963 r
.51166 .34181 .51831 .34738 .53047 .34372 .52387 .33829 Mtetra
.526 .765 .984 r
.52387 .33829 .53047 .34372 .5427 .34205 .53614 .33673 Mtetra
.318 .667 .975 r
.53614 .33673 .5427 .34205 .55504 .34336 .54851 .338 Mtetra
0 .399 .823 r
.54851 .338 .55504 .34336 .56753 .34941 .56102 .34366 Mtetra
.512 0 0 r
.56102 .34366 .56753 .34941 .58028 .36231 .57377 .35571 Mtetra
.737 .259 0 r
.57377 .35571 .58028 .36231 .59341 .38373 .58687 .37568 Mtetra
.817 .379 0 r
.58687 .37568 .59341 .38373 .60701 .41358 .60039 .40352 Mtetra
.822 .409 0 r
.60039 .40352 .60701 .41358 .62111 .44877 .61438 .43634 Mtetra
.736 .342 0 r
.61438 .43634 .62111 .44877 .63554 .48275 .62869 .46796 Mtetra
0 0 .536 r
.62869 .46796 .63554 .48275 .64998 .50675 .64302 .49016 Mtetra
.4 .453 .799 r
.64302 .49016 .64998 .50675 .66396 .51292 .65697 .49556 Mtetra
.76 .641 .73 r
.65697 .49556 .66396 .51292 .67714 .49806 .67018 .48111 Mtetra
.866 .687 .658 r
.67018 .48111 .67714 .49806 .68939 .46524 .68257 .44964 Mtetra
.905 .706 .624 r
.68257 .44964 .68939 .46524 .70092 .42225 .69427 .40846 Mtetra
.921 .721 .617 r
.69427 .40846 .70092 .42225 .71211 .37792 .70566 .36593 Mtetra
.924 .737 .632 r
.70566 .36593 .71211 .37792 .72336 .33894 .71708 .3284 Mtetra
.915 .755 .669 r
.71708 .3284 .72336 .33894 .73494 .30848 .72882 .29895 Mtetra
.89 .773 .726 r
.72882 .29895 .73494 .30848 .74698 .28667 .74097 .27776 Mtetra
.844 .781 .791 r
.74097 .27776 .74698 .28667 .75946 .27184 .75354 .26324 Mtetra
.785 .777 .846 r
.75354 .26324 .75946 .27184 .7723 .26179 .76644 .25332 Mtetra
.732 .765 .88 r
.76644 .25332 .7723 .26179 .78539 .25457 .77958 .24613 Mtetra
.696 .754 .896 r
.77958 .24613 .78539 .25457 .79865 .24884 .79289 .24038 Mtetra
.677 .747 .904 r
.79289 .24038 .79865 .24884 .81203 .24379 .80632 .2353 Mtetra
.669 .744 .907 r
.80632 .2353 .81203 .24379 .8255 .23902 .81983 .23048 Mtetra
.665 .742 .908 r
.81983 .23048 .8255 .23902 .83904 .23434 .83342 .22576 Mtetra
.66 .74 .909 r
.21627 .42794 .22372 .4349 .23465 .43126 .22723 .42426 Mtetra
.656 .738 .91 r
.22723 .42426 .23465 .43126 .24561 .42778 .23822 .42069 Mtetra
.645 .734 .913 r
.23822 .42069 .24561 .42778 .25659 .42463 .24923 .4174 Mtetra
.62 .723 .92 r
.24923 .4174 .25659 .42463 .26756 .42223 .26024 .41474 Mtetra
.565 .697 .93 r
.26024 .41474 .26756 .42223 .27847 .42125 .27121 .41335 Mtetra
.438 .632 .936 r
.27121 .41335 .27847 .42125 .28927 .42283 .28206 .41429 Mtetra
.151 .455 .884 r
.28206 .41429 .28927 .42283 .29986 .42847 .29272 .41906 Mtetra
0 .089 .629 r
.29272 .41906 .29986 .42847 .31019 .43987 .3031 .42945 Mtetra
.706 .269 0 r
.3031 .42945 .31019 .43987 .32024 .45834 .31317 .44702 Mtetra
.856 .448 0 r
.31317 .44702 .32024 .45834 .33006 .48391 .32296 .47225 Mtetra
.906 .518 .093 r
.32296 .47225 .33006 .48391 .33986 .51451 .33265 .50355 Mtetra
.917 .53 .129 r
.33265 .50355 .33986 .51451 .34994 .54544 .34255 .53664 Mtetra
.897 .485 .094 r
.34255 .53664 .34994 .54544 .36062 .57007 .353 .56487 Mtetra
.78 .282 0 r
.353 .56487 .36062 .57007 .37213 .58173 .36431 .58097 Mtetra
.215 .733 .863 r
.36431 .58097 .37213 .58173 .38452 .57634 .37658 .57976 Mtetra
.931 .969 .748 r
.37658 .57976 .38452 .57634 .39758 .55424 .38964 .56047 Mtetra
.985 .903 .631 r
.38964 .56047 .39758 .55424 .41098 .52007 .40316 .52714 Mtetra
.993 .876 .598 r
.40316 .52714 .41098 .52007 .42436 .4807 .41674 .48676 Mtetra
.993 .869 .602 r
.41674 .48676 .42436 .4807 .43751 .44264 .43011 .44652 Mtetra
.987 .875 .631 r
.43011 .44652 .43751 .44264 .45034 .41025 .44314 .41159 Mtetra
.972 .887 .685 r
.44314 .41159 .45034 .41025 .46286 .3853 .45582 .3844 Mtetra
.939 .901 .761 r
.45582 .3844 .46286 .3853 .47516 .36748 .46824 .36499 Mtetra
.878 .908 .846 r
.46824 .36499 .47516 .36748 .48735 .35536 .48052 .35203 Mtetra
.789 .901 .921 r
.48052 .35203 .48735 .35536 .4995 .34726 .49273 .34371 Mtetra
.683 .883 .972 r
.49273 .34371 .4995 .34726 .51166 .34181 .50494 .33847 Mtetra
.56 .854 .997 r
.50494 .33847 .51166 .34181 .52387 .33829 .5172 .33535 Mtetra
.386 .789 .984 r
.5172 .33535 .52387 .33829 .53614 .33673 .52952 .33416 Mtetra
.097 .619 .881 r
.52952 .33416 .53614 .33673 .54851 .338 .54193 .33552 Mtetra
.297 0 0 r
.54193 .33552 .54851 .338 .56102 .34366 .55448 .34079 Mtetra
.609 .048 0 r
.55448 .34079 .56102 .34366 .57377 .35571 .56724 .35172 Mtetra
.764 .261 0 r
.56724 .35172 .57377 .35571 .58687 .37568 .5803 .3697 Mtetra
.822 .362 0 r
.5803 .3697 .58687 .37568 .60039 .40352 .59375 .39468 Mtetra
.811 .38 0 r
.59375 .39468 .60039 .40352 .61438 .43634 .60761 .424 Mtetra
.677 .282 0 r
.60761 .424 .61438 .43634 .62869 .46796 .62177 .45206 Mtetra
0 .064 .626 r
.62177 .45206 .62869 .46796 .64302 .49016 .63596 .47138 Mtetra
.459 .463 .775 r
.63596 .47138 .64302 .49016 .65697 .49556 .64984 .4753 Mtetra
.739 .609 .713 r
.64984 .4753 .65697 .49556 .67018 .48111 .66308 .46102 Mtetra
.838 .658 .658 r
.66308 .46102 .67018 .48111 .68257 .44964 .67558 .43115 Mtetra
.881 .683 .63 r
.67558 .43115 .68257 .44964 .69427 .40846 .68748 .39233 Mtetra
.9 .702 .625 r
.68748 .39233 .69427 .40846 .70566 .36593 .69908 .35224 Mtetra
.907 .721 .64 r
.69908 .35224 .70566 .36593 .71708 .3284 .71071 .31676 Mtetra
.901 .743 .676 r
.71071 .31676 .71708 .3284 .72882 .29895 .72261 .28878 Mtetra
.878 .762 .731 r
.72261 .28878 .72882 .29895 .74097 .27776 .73489 .2685 Mtetra
.835 .774 .794 r
.73489 .2685 .74097 .27776 .75354 .26324 .74755 .25447 Mtetra
.78 .773 .847 r
.74755 .25447 .75354 .26324 .76644 .25332 .76052 .24475 Mtetra
.729 .763 .88 r
.76052 .24475 .76644 .25332 .77958 .24613 .77372 .23762 Mtetra
.695 .754 .897 r
.77372 .23762 .77958 .24613 .79289 .24038 .78708 .23186 Mtetra
.677 .747 .904 r
.78708 .23186 .79289 .24038 .80632 .2353 .80055 .22673 Mtetra
.669 .744 .907 r
.80055 .22673 .80632 .2353 .81983 .23048 .81411 .22187 Mtetra
.666 .743 .908 r
.81411 .22187 .81983 .23048 .83342 .22576 .82774 .2171 Mtetra
.661 .74 .909 r
.20877 .42094 .21627 .42794 .22723 .42426 .21975 .4172 Mtetra
.658 .739 .91 r
.21975 .4172 .22723 .42426 .23822 .42069 .23077 .41355 Mtetra
.649 .735 .912 r
.23077 .41355 .23822 .42069 .24923 .4174 .24182 .41012 Mtetra
.629 .726 .917 r
.24182 .41012 .24923 .4174 .26024 .41474 .25287 .40722 Mtetra
.584 .705 .926 r
.25287 .40722 .26024 .41474 .27121 .41335 .26389 .40541 Mtetra
.48 .651 .934 r
.26389 .40541 .27121 .41335 .28206 .41429 .27481 .40566 Mtetra
.243 .509 .905 r
.27481 .40566 .28206 .41429 .29272 .41906 .28555 .40942 Mtetra
0 .188 .715 r
.28555 .40942 .29272 .41906 .3031 .42945 .29601 .41849 Mtetra
.616 .192 0 r
.29601 .41849 .3031 .42945 .31317 .44702 .30613 .4346 Mtetra
.813 .41 0 r
.30613 .4346 .31317 .44702 .32296 .47225 .31594 .45862 Mtetra
.881 .501 .031 r
.31594 .45862 .32296 .47225 .33265 .50355 .32558 .48952 Mtetra
.898 .524 .068 r
.32558 .48952 .33265 .50355 .34255 .53664 .33534 .52358 Mtetra
.876 .487 .02 r
.33534 .52358 .34255 .53664 .353 .56487 .34559 .55443 Mtetra
.741 .3 0 r
.34559 .55443 .353 .56487 .36431 .58097 .35668 .57452 Mtetra
.173 .556 .931 r
.35668 .57452 .36431 .58097 .37658 .57976 .36876 .5778 Mtetra
.897 .899 .82 r
.36876 .5778 .37658 .57976 .38964 .56047 .38175 .56234 Mtetra
.973 .871 .674 r
.38175 .56234 .38964 .56047 .40316 .52714 .39532 .53127 Mtetra
.987 .856 .621 r
.39532 .53127 .40316 .52714 .41674 .48676 .40905 .49137 Mtetra
.99 .855 .611 r
.40905 .49137 .41674 .48676 .43011 .44652 .42261 .45022 Mtetra
.987 .867 .628 r
.42261 .45022 .43011 .44652 .44314 .41159 .43582 .41373 Mtetra
.977 .89 .672 r
.43582 .41373 .44314 .41159 .45582 .3844 .44866 .38502 Mtetra
.95 .924 .746 r
.44866 .38502 .45582 .3844 .46824 .36499 .4612 .36459 Mtetra
.885 .96 .843 r
.4612 .36459 .46824 .36499 .48052 .35203 .47356 .35129 Mtetra
.747 .971 .928 r
.47356 .35129 .48052 .35203 .49273 .34371 .48584 .34326 Mtetra
.513 .906 .931 r
.48584 .34326 .49273 .34371 .50494 .33847 .49811 .33874 Mtetra
.22 .743 .804 r
.49811 .33874 .50494 .33847 .5172 .33535 .51043 .33651 Mtetra
.062 0 0 r
.51043 .33651 .5172 .33535 .52952 .33416 .52281 .33611 Mtetra
.304 0 0 r
.52281 .33611 .52952 .33416 .54193 .33552 .53529 .33785 Mtetra
.505 0 0 r
.53529 .33785 .54193 .33552 .55448 .34079 .5479 .34278 Mtetra
.66 .13 0 r
.5479 .34278 .55448 .34079 .56724 .35172 .56069 .35238 Mtetra
.766 .266 .021 r
.56069 .35238 .56724 .35172 .5803 .3697 .57374 .36785 Mtetra
.823 .345 .022 r
.57374 .36785 .5803 .3697 .59375 .39468 .58713 .38912 Mtetra
.819 .354 0 r
.58713 .38912 .59375 .39468 .60761 .424 .60086 .41388 Mtetra
.658 .228 0 r
.60086 .41388 .60761 .424 .62177 .45206 .61486 .4372 Mtetra
0 .169 .701 r
.61486 .4372 .62177 .45206 .63596 .47138 .62889 .45253 Mtetra
.513 .495 .773 r
.62889 .45253 .63596 .47138 .64984 .4753 .64267 .45409 Mtetra
.736 .601 .707 r
.64267 .45409 .64984 .4753 .66308 .46102 .6559 .4395 Mtetra
.823 .643 .659 r
.6559 .4395 .66308 .46102 .67558 .43115 .66851 .41112 Mtetra
.864 .668 .636 r
.66851 .41112 .67558 .43115 .68748 .39233 .68059 .37485 Mtetra
.885 .689 .633 r
.68059 .37485 .68748 .39233 .69908 .35224 .69241 .33753 Mtetra
.893 .711 .649 r
.69241 .33753 .69908 .35224 .71071 .31676 .70425 .30444 Mtetra
.888 .734 .685 r
.70425 .30444 .71071 .31676 .72261 .28878 .71633 .2782 Mtetra
.866 .755 .738 r
.71633 .2782 .72261 .28878 .73489 .2685 .72875 .25901 Mtetra
.826 .769 .799 r
.72875 .25901 .73489 .2685 .74755 .25447 .74151 .24556 Mtetra
.774 .77 .849 r
.74151 .24556 .74755 .25447 .76052 .24475 .75456 .2361 Mtetra
.726 .762 .881 r
.75456 .2361 .76052 .24475 .77372 .23762 .76781 .22904 Mtetra
.694 .754 .897 r
.76781 .22904 .77372 .23762 .78708 .23186 .78122 .22327 Mtetra
.677 .748 .904 r
.78122 .22327 .78708 .23186 .80055 .22673 .79474 .2181 Mtetra
.669 .744 .907 r
.79474 .2181 .80055 .22673 .81411 .22187 .80834 .21319 Mtetra
.666 .743 .908 r
.80834 .21319 .81411 .22187 .82774 .2171 .82202 .20837 Mtetra
.662 .74 .908 r
.2012 .41388 .20877 .42094 .21975 .4172 .21221 .41009 Mtetra
.659 .739 .909 r
.21221 .41009 .21975 .4172 .23077 .41355 .22327 .40637 Mtetra
.652 .736 .911 r
.22327 .40637 .23077 .41355 .24182 .41012 .23435 .40281 Mtetra
.637 .729 .915 r
.23435 .40281 .24182 .41012 .25287 .40722 .24545 .39968 Mtetra
.6 .712 .922 r
.24545 .39968 .25287 .40722 .26389 .40541 .25652 .39746 Mtetra
.517 .669 .931 r
.25652 .39746 .26389 .40541 .27481 .40566 .26751 .39701 Mtetra
.33 .558 .919 r
.26751 .39701 .27481 .40566 .28555 .40942 .27833 .39967 Mtetra
0 .295 .793 r
.27833 .39967 .28555 .40942 .29601 .41849 .28889 .40718 Mtetra
0 0 .483 r
.28889 .40718 .29601 .41849 .30613 .4346 .29911 .42137 Mtetra
.738 .344 0 r
.29911 .42137 .30613 .4346 .31594 .45862 .30899 .44337 Mtetra
.832 .462 0 r
.30899 .44337 .31594 .45862 .32558 .48952 .31865 .4727 Mtetra
.851 .495 0 r
.31865 .4727 .32558 .48952 .33534 .52358 .32834 .50631 Mtetra
.81 .456 0 r
.32834 .50631 .33534 .52358 .34559 .55443 .33844 .53841 Mtetra
0 0 .328 r
.33844 .53841 .34559 .55443 .35668 .57452 .34931 .56156 Mtetra
.16 .365 .817 r
.34931 .56156 .35668 .57452 .36876 .5778 .36118 .56917 Mtetra
.79 .754 .82 r
.36118 .56917 .36876 .5778 .38175 .56234 .37403 .55825 Mtetra
.929 .809 .705 r
.37403 .55825 .38175 .56234 .39532 .53127 .38755 .53086 Mtetra
.967 .822 .648 r
.38755 .53086 .39532 .53127 .40905 .49137 .40134 .49318 Mtetra
.98 .835 .628 r
.40134 .49318 .40905 .49137 .42261 .45022 .41503 .45286 Mtetra
.984 .857 .635 r
.41503 .45286 .42261 .45022 .43582 .41373 .42839 .41633 Mtetra
.978 .894 .669 r
.42839 .41633 .43582 .41373 .44866 .38502 .44136 .38735 Mtetra
.948 .952 .733 r
.44136 .38735 .44866 .38502 .4612 .36459 .45401 .36696 Mtetra
.823 1 .804 r
.45401 .36696 .4612 .36459 .47356 .35129 .46645 .35424 Mtetra
.442 .862 .721 r
.46645 .35424 .47356 .35129 .48584 .34326 .4788 .34734 Mtetra
.037 0 0 r
.4788 .34734 .48584 .34326 .49811 .33874 .49114 .34432 Mtetra
.298 0 0 r
.49114 .34432 .49811 .33874 .51043 .33651 .50353 .34369 Mtetra
.419 0 0 r
.50353 .34369 .51043 .33651 .52281 .33611 .516 .34461 Mtetra
.491 .027 .08 r
.516 .34461 .52281 .33611 .53529 .33785 .52856 .34705 Mtetra
.557 .107 .138 r
.52856 .34705 .53529 .33785 .5479 .34278 .54126 .3517 Mtetra
.629 .183 .173 r
.54126 .3517 .5479 .34278 .56069 .35238 .55411 .35972 Mtetra
.704 .254 .18 r
.55411 .35972 .56069 .35238 .57374 .36785 .56718 .3721 Mtetra
.77 .306 .145 r
.56718 .3721 .57374 .36785 .58713 .38912 .58052 .38881 Mtetra
.8 .311 .028 r
.58052 .38881 .58713 .38912 .60086 .41388 .59415 .40793 Mtetra
.67 .166 0 r
.59415 .40793 .60086 .41388 .61486 .4372 .60799 .42532 Mtetra
.043 .308 .796 r
.60799 .42532 .61486 .4372 .62889 .45253 .62186 .43551 Mtetra
.581 .554 .789 r
.62186 .43551 .62889 .45253 .64267 .45409 .63552 .43374 Mtetra
.75 .614 .708 r
.63552 .43374 .64267 .45409 .6559 .4395 .64873 .41814 Mtetra
.819 .642 .663 r
.64873 .41814 .6559 .4395 .66851 .41112 .66142 .39083 Mtetra
.855 .663 .643 r
.66142 .39083 .66851 .41112 .68059 .37485 .67367 .35695 Mtetra
.874 .684 .642 r
.67367 .35695 .68059 .37485 .69241 .33753 .6857 .32241 Mtetra
.881 .706 .659 r
.6857 .32241 .69241 .33753 .70425 .30444 .69775 .2918 Mtetra
.877 .729 .695 r
.69775 .2918 .70425 .30444 .71633 .2782 .71 .26741 Mtetra
.856 .752 .747 r
.71 .26741 .71633 .2782 .72875 .25901 .72256 .24938 Mtetra
.817 .766 .805 r
.72256 .24938 .72875 .25901 .74151 .24556 .73542 .23656 Mtetra
.768 .768 .853 r
.73542 .23656 .74151 .24556 .75456 .2361 .74854 .22738 Mtetra
.723 .761 .883 r
.74854 .22738 .75456 .2361 .76781 .22904 .76185 .2204 Mtetra
.694 .754 .898 r
.76185 .2204 .76781 .22904 .78122 .22327 .77531 .21461 Mtetra
.677 .748 .904 r
.77531 .21461 .78122 .22327 .79474 .2181 .78887 .2094 Mtetra
.669 .745 .907 r
.78887 .2094 .79474 .2181 .80834 .21319 .80252 .20444 Mtetra
.666 .743 .908 r
.80252 .20444 .80834 .21319 .82202 .20837 .81624 .19957 Mtetra
.662 .741 .908 r
.19357 .40677 .2012 .41388 .21221 .41009 .20462 .40293 Mtetra
.66 .74 .909 r
.20462 .40293 .21221 .41009 .22327 .40637 .2157 .39914 Mtetra
.655 .737 .91 r
.2157 .39914 .22327 .40637 .23435 .40281 .22682 .39548 Mtetra
.643 .732 .913 r
.22682 .39548 .23435 .40281 .24545 .39968 .23795 .39214 Mtetra
.615 .718 .919 r
.23795 .39214 .24545 .39968 .25652 .39746 .24908 .38954 Mtetra
.55 .685 .928 r
.24908 .38954 .25652 .39746 .26751 .39701 .26014 .38841 Mtetra
.406 .601 .926 r
.26014 .38841 .26751 .39701 .27833 .39967 .27105 .38995 Mtetra
.108 .398 .852 r
.27105 .38995 .27833 .39967 .28889 .40718 .28173 .39577 Mtetra
0 .054 .614 r
.28173 .39577 .28889 .40718 .29911 .42137 .29209 .40767 Mtetra
0 0 .331 r
.29209 .40767 .29911 .42137 .30899 .44337 .3021 .42699 Mtetra
.748 .393 0 r
.3021 .42699 .30899 .44337 .31865 .4727 .31184 .45371 Mtetra
.77 .438 0 r
.31184 .45371 .31865 .4727 .32834 .50631 .32154 .48549 Mtetra
.699 .392 0 r
.32154 .48549 .32834 .50631 .33844 .53841 .33155 .51733 Mtetra
0 0 .415 r
.33155 .51733 .33844 .53841 .34931 .56156 .34224 .54228 Mtetra
.162 .264 .722 r
.34224 .54228 .34931 .56156 .36118 .56917 .35389 .55363 Mtetra
.669 .609 .779 r
.35389 .55363 .36118 .56917 .37403 .55825 .36652 .54759 Mtetra
.859 .728 .718 r
.36652 .54759 .37403 .55825 .38755 .53086 .37991 .5251 Mtetra
.929 .776 .671 r
.37991 .5251 .38755 .53086 .40134 .49318 .39366 .49145 Mtetra
.96 .81 .65 r
.39366 .49145 .40134 .49318 .41503 .45286 .40739 .45396 Mtetra
.976 .85 .651 r
.40739 .45396 .41503 .45286 .42839 .41633 .42083 .4193 Mtetra
.975 .908 .677 r
.42083 .4193 .42839 .41633 .44136 .38735 .4339 .39174 Mtetra
.908 .98 .711 r
.4339 .39174 .44136 .38735 .45401 .36696 .44663 .37283 Mtetra
.513 .853 .582 r
.44663 .37283 .45401 .36696 .46645 .35424 .45914 .36193 Mtetra
.118 0 0 r
.45914 .36193 .46645 .35424 .4788 .34734 .47155 .35726 Mtetra
.399 0 .066 r
.47155 .35726 .4788 .34734 .49114 .34432 .48396 .35669 Mtetra
.493 .076 .177 r
.48396 .35669 .49114 .34432 .50353 .34369 .49643 .3584 Mtetra
.525 .13 .233 r
.49643 .3584 .50353 .34369 .516 .34461 .50901 .36117 Mtetra
.539 .157 .264 r
.50901 .36117 .516 .34461 .52856 .34705 .5217 .36456 Mtetra
.555 .178 .281 r
.5217 .36456 .52856 .34705 .54126 .3517 .53451 .36885 Mtetra
.581 .201 .286 r
.53451 .36885 .54126 .3517 .55411 .35972 .54746 .37486 Mtetra
.621 .227 .276 r
.54746 .37486 .55411 .35972 .56718 .3721 .56059 .38344 Mtetra
.668 .247 .236 r
.56059 .38344 .56718 .3721 .58052 .38881 .57392 .39465 Mtetra
.703 .23 .124 r
.57392 .39465 .58052 .38881 .59415 .40793 .58747 .40703 Mtetra
.613 .044 0 r
.58747 .40703 .59415 .40793 .60799 .42532 .60118 .41736 Mtetra
.233 .543 .927 r
.60118 .41736 .60799 .42532 .62186 .43551 .61489 .42134 Mtetra
.672 .638 .807 r
.61489 .42134 .62186 .43551 .63552 .43374 .62842 .41529 Mtetra
.778 .642 .711 r
.62842 .41529 .63552 .43374 .64873 .41814 .6416 .3979 Mtetra
.825 .651 .667 r
.6416 .3979 .64873 .41814 .66142 .39083 .65434 .3711 Mtetra
.851 .665 .65 r
.65434 .3711 .66142 .39083 .67367 .35695 .66674 .33924 Mtetra
.867 .683 .652 r
.66674 .33924 .67367 .35695 .6857 .32241 .67895 .30728 Mtetra
.872 .704 .67 r
.67895 .30728 .6857 .32241 .69775 .2918 .6912 .27907 Mtetra
.866 .727 .707 r
.6912 .27907 .69775 .2918 .71 .26741 .70363 .2565 Mtetra
.845 .749 .757 r
.70363 .2565 .71 .26741 .72256 .24938 .71632 .23965 Mtetra
.808 .763 .812 r
.71632 .23965 .72256 .24938 .73542 .23656 .72928 .22747 Mtetra
.761 .765 .856 r
.72928 .22747 .73542 .23656 .74854 .22738 .74247 .21857 Mtetra
.72 .76 .884 r
.74247 .21857 .74854 .22738 .76185 .2204 .75584 .21167 Mtetra
.693 .753 .898 r
.75584 .21167 .76185 .2204 .77531 .21461 .76934 .20588 Mtetra
.677 .748 .904 r
.76934 .20588 .77531 .21461 .78887 .2094 .78295 .20062 Mtetra
.67 .745 .907 r
.78295 .20062 .78887 .2094 .80252 .20444 .79665 .19561 Mtetra
.666 .743 .907 r
.79665 .19561 .80252 .20444 .81624 .19957 .81042 .19069 Mtetra
.663 .741 .908 r
.18589 .3996 .19357 .40677 .20462 .40293 .19696 .39572 Mtetra
.661 .74 .908 r
.19696 .39572 .20462 .40293 .2157 .39914 .20807 .39187 Mtetra
.658 .738 .909 r
.20807 .39187 .2157 .39914 .22682 .39548 .21922 .38811 Mtetra
.648 .734 .912 r
.21922 .38811 .22682 .39548 .23795 .39214 .2304 .3846 Mtetra
.627 .723 .916 r
.2304 .3846 .23795 .39214 .24908 .38954 .24158 .38165 Mtetra
.578 .698 .924 r
.24158 .38165 .24908 .38954 .26014 .38841 .25271 .3799 Mtetra
.469 .636 .927 r
.25271 .3799 .26014 .38841 .27105 .38995 .26372 .38035 Mtetra
.244 .487 .89 r
.26372 .38035 .27105 .38995 .28173 .39577 .27453 .38446 Mtetra
0 .203 .731 r
.27453 .38446 .28173 .39577 .29209 .40767 .28504 .3939 Mtetra
0 0 .479 r
.28504 .3939 .29209 .40767 .3021 .42699 .29522 .41011 Mtetra
0 0 .298 r
.29522 .41011 .3021 .42699 .31184 .45371 .30511 .43342 Mtetra
0 0 .241 r
.30511 .43342 .31184 .45371 .32154 .48549 .3149 .46221 Mtetra
0 0 .3 r
.3149 .46221 .32154 .48549 .33155 .51733 .32489 .49238 Mtetra
0 0 .472 r
.32489 .49238 .33155 .51733 .34224 .54228 .33546 .51777 Mtetra
.166 .216 .669 r
.33546 .51777 .34224 .54228 .35389 .55363 .34689 .53197 Mtetra
.568 .498 .737 r
.34689 .53197 .35389 .55363 .36652 .54759 .35927 .53074 Mtetra
.778 .646 .717 r
.35927 .53074 .36652 .54759 .37991 .5251 .37244 .51401 Mtetra
.878 .725 .689 r
.37244 .51401 .37991 .5251 .39366 .49145 .38605 .48598 Mtetra
.931 .783 .674 r
.38605 .48598 .39366 .49145 .40739 .45396 .39971 .4533 Mtetra
.963 .846 .678 r
.39971 .4533 .40739 .45396 .42083 .4193 .41315 .42254 Mtetra
.964 .935 .699 r
.41315 .42254 .42083 .4193 .4339 .39174 .42625 .39828 Mtetra
.746 .948 .631 r
.42625 .39828 .4339 .39174 .44663 .37283 .43902 .38246 Mtetra
.002 0 0 r
.43902 .38246 .44663 .37283 .45914 .36193 .45157 .37474 Mtetra
.404 0 .135 r
.45157 .37474 .45914 .36193 .47155 .35726 .46404 .37339 Mtetra
.526 .14 .252 r
.46404 .37339 .47155 .35726 .48396 .35669 .47652 .37613 Mtetra
.56 .194 .303 r
.47652 .37613 .48396 .35669 .49643 .3584 .48909 .38079 Mtetra
.562 .209 .328 r
.48909 .38079 .49643 .3584 .50901 .36117 .50179 .38571 Mtetra
.552 .208 .339 r
.50179 .38571 .50901 .36117 .5217 .36456 .51463 .39 Mtetra
.543 .202 .34 r
.51463 .39 .5217 .36456 .53451 .36885 .5276 .39355 Mtetra
.539 .195 .333 r
.5276 .39355 .53451 .36885 .54746 .37486 .54069 .3969 Mtetra
.546 .189 .314 r
.54069 .3969 .54746 .37486 .56059 .38344 .55391 .40081 Mtetra
.557 .173 .27 r
.55391 .40081 .56059 .38344 .57392 .39465 .56727 .40553 Mtetra
.549 .109 .155 r
.56727 .40553 .57392 .39465 .58747 .40703 .58078 .41021 Mtetra
.369 0 0 r
.58078 .41021 .58747 .40703 .60118 .41736 .59437 .41258 Mtetra
.557 .824 .996 r
.59437 .41258 .60118 .41736 .61489 .42134 .60795 .40957 Mtetra
.768 .714 .802 r
.60795 .40957 .61489 .42134 .62842 .41529 .62136 .39856 Mtetra
.809 .67 .709 r
.62136 .39856 .62842 .41529 .6416 .3979 .63449 .3788 Mtetra
.833 .662 .67 r
.63449 .3788 .6416 .3979 .65434 .3711 .64728 .35203 Mtetra
.85 .669 .657 r
.64728 .35203 .65434 .3711 .66674 .33924 .6598 .32183 Mtetra
.86 .683 .661 r
.6598 .32183 .66674 .33924 .67895 .30728 .67219 .29223 Mtetra
.863 .702 .681 r
.67219 .29223 .67895 .30728 .6912 .27907 .68461 .26629 Mtetra
.855 .725 .718 r
.68461 .26629 .6912 .27907 .70363 .2565 .6972 .24548 Mtetra
.834 .746 .767 r
.6972 .24548 .70363 .2565 .71632 .23965 .71002 .22978 Mtetra
.797 .759 .818 r
.71002 .22978 .71632 .23965 .72928 .22747 .72308 .21825 Mtetra
.754 .762 .859 r
.72308 .21825 .72928 .22747 .74247 .21857 .73634 .20964 Mtetra
.717 .758 .885 r
.73634 .20964 .74247 .21857 .75584 .21167 .74977 .20284 Mtetra
.691 .752 .898 r
.74977 .20284 .75584 .21167 .76934 .20588 .76333 .19705 Mtetra
.677 .747 .904 r
.76333 .19705 .76934 .20588 .78295 .20062 .77698 .19175 Mtetra
.67 .744 .906 r
.77698 .19175 .78295 .20062 .79665 .19561 .79072 .18669 Mtetra
.666 .743 .907 r
.79072 .18669 .79665 .19561 .81042 .19069 .80454 .18172 Mtetra
.663 .741 .908 r
.17814 .39238 .18589 .3996 .19696 .39572 .18924 .38846 Mtetra
.662 .741 .908 r
.18924 .38846 .19696 .39572 .20807 .39187 .20038 .38456 Mtetra
.659 .739 .909 r
.20038 .38456 .20807 .39187 .21922 .38811 .21157 .38072 Mtetra
.653 .736 .911 r
.21157 .38072 .21922 .38811 .2304 .3846 .22278 .37705 Mtetra
.637 .728 .914 r
.22278 .37705 .2304 .3846 .24158 .38165 .23401 .37382 Mtetra
.6 .709 .92 r
.23401 .37382 .24158 .38165 .25271 .3799 .2452 .37151 Mtetra
.521 .663 .926 r
.2452 .37151 .25271 .3799 .26372 .38035 .25631 .37096 Mtetra
.357 .557 .91 r
.25631 .37096 .26372 .38035 .27453 .38446 .26725 .37342 Mtetra
.071 .342 .817 r
.26725 .37342 .27453 .38446 .28504 .3939 .27793 .38041 Mtetra
0 .056 .622 r
.27793 .38041 .28504 .3939 .29522 .41011 .28831 .39332 Mtetra
0 0 .441 r
.28831 .39332 .29522 .41011 .30511 .43342 .2984 .41277 Mtetra
0 0 .364 r
.2984 .41277 .30511 .43342 .3149 .46221 .30834 .43777 Mtetra
0 0 .396 r
.30834 .43777 .3149 .46221 .32489 .49238 .3184 .46513 Mtetra
0 0 .512 r
.3184 .46513 .32489 .49238 .33546 .51777 .3289 .48971 Mtetra
.169 .192 .641 r
.3289 .48971 .33546 .51777 .34689 .53197 .34014 .50571 Mtetra
.489 .419 .704 r
.34014 .50571 .34689 .53197 .35927 .53074 .35226 .50883 Mtetra
.695 .571 .711 r
.35226 .50883 .35927 .53074 .37244 .51401 .36515 .49821 Mtetra
.815 .669 .702 r
.36515 .49821 .37244 .51401 .38605 .48598 .37852 .47692 Mtetra
.889 .75 .702 r
.37852 .47692 .38605 .48598 .39971 .4533 .39202 .45068 Mtetra
.941 .844 .719 r
.39202 .45068 .39971 .4533 .41315 .42254 .40536 .42562 Mtetra
.93 .97 .743 r
.40536 .42562 .41315 .42254 .42625 .39828 .41842 .40633 Mtetra
0 0 0 r
.41842 .40633 .42625 .39828 .43902 .38246 .43118 .39502 Mtetra
.32 0 .079 r
.43118 .39502 .43902 .38246 .45157 .37474 .44375 .39158 Mtetra
.525 .142 .256 r
.44375 .39158 .45157 .37474 .46404 .37339 .45625 .39433 Mtetra
.583 .223 .323 r
.45625 .39433 .46404 .37339 .47652 .37613 .4688 .40081 Mtetra
.592 .246 .352 r
.4688 .40081 .47652 .37613 .48909 .38079 .48148 .40852 Mtetra
.579 .242 .363 r
.48148 .40852 .48909 .38079 .50179 .38571 .49433 .41539 Mtetra
.554 .224 .364 r
.49433 .41539 .50179 .38571 .51463 .39 .50733 .42008 Mtetra
.524 .197 .356 r
.50733 .42008 .51463 .39 .5276 .39355 .52048 .42218 Mtetra
.494 .165 .338 r
.52048 .42218 .5276 .39355 .54069 .3969 .53373 .42202 Mtetra
.465 .125 .305 r
.53373 .42202 .54069 .3969 .55391 .40081 .54708 .4204 Mtetra
.425 .059 .238 r
.54708 .4204 .55391 .40081 .56727 .40553 .5605 .41789 Mtetra
.317 0 .068 r
.5605 .41789 .56727 .40553 .58078 .41021 .57399 .4143 Mtetra
0 0 0 r
.57399 .4143 .58078 .41021 .59437 .41258 .5875 .40838 Mtetra
.811 .905 .906 r
.5875 .40838 .59437 .41258 .60795 .40957 .60097 .39821 Mtetra
.828 .739 .766 r
.60097 .39821 .60795 .40957 .62136 .39856 .61429 .38216 Mtetra
.828 .681 .699 r
.61429 .38216 .62136 .39856 .63449 .3788 .62738 .35995 Mtetra
.836 .665 .67 r
.62738 .35995 .63449 .3788 .64728 .35203 .64021 .33308 Mtetra
.844 .667 .662 r
.64021 .33308 .64728 .35203 .6598 .32183 .65284 .30441 Mtetra
.851 .68 .67 r
.65284 .30441 .6598 .32183 .67219 .29223 .66539 .27703 Mtetra
.851 .698 .692 r
.66539 .27703 .67219 .29223 .68461 .26629 .67798 .25329 Mtetra
.842 .72 .729 r
.67798 .25329 .68461 .26629 .6972 .24548 .69072 .23422 Mtetra
.82 .74 .776 r
.69072 .23422 .6972 .24548 .71002 .22978 .70367 .2197 Mtetra
.785 .753 .824 r
.70367 .2197 .71002 .22978 .72308 .21825 .71682 .20884 Mtetra
.746 .757 .861 r
.71682 .20884 .72308 .21825 .73634 .20964 .73016 .20056 Mtetra
.712 .754 .885 r
.73016 .20056 .73634 .20964 .74977 .20284 .74365 .19388 Mtetra
.69 .75 .897 r
.74365 .19388 .74977 .20284 .76333 .19705 .75725 .1881 Mtetra
.676 .746 .903 r
.75725 .1881 .76333 .19705 .77698 .19175 .77096 .18279 Mtetra
.67 .744 .906 r
.77096 .18279 .77698 .19175 .79072 .18669 .78474 .17769 Mtetra
.666 .743 .907 r
.78474 .17769 .79072 .18669 .80454 .18172 .79861 .17267 Mtetra
.663 .741 .908 r
.17033 .3851 .17814 .39238 .18924 .38846 .18146 .38115 Mtetra
.18146 .38115 .18924 .38846 .20038 .38456 .19263 .3772 Mtetra
.661 .74 .909 r
.19263 .3772 .20038 .38456 .21157 .38072 .20384 .37329 Mtetra
.656 .738 .91 r
.20384 .37329 .21157 .38072 .22278 .37705 .2151 .3695 Mtetra
.644 .732 .912 r
.2151 .3695 .22278 .37705 .23401 .37382 .22637 .36602 Mtetra
.618 .718 .917 r
.22637 .36602 .23401 .37382 .2452 .37151 .23763 .36324 Mtetra
.561 .685 .923 r
.23763 .36324 .2452 .37151 .25631 .37096 .24883 .36182 Mtetra
.444 .61 .918 r
.24883 .36182 .25631 .37096 .26725 .37342 .25989 .3628 Mtetra
.234 .456 .87 r
.25989 .3628 .26725 .37342 .27793 .38041 .27075 .36747 Mtetra
0 .22 .739 r
.27075 .36747 .27793 .38041 .28831 .39332 .28134 .37715 Mtetra
0 .001 .577 r
.28134 .37715 .28831 .39332 .2984 .41277 .29165 .39263 Mtetra
0 0 .482 r
.29165 .39263 .2984 .41277 .30834 .43777 .3018 .41341 Mtetra
0 0 .48 r
.3018 .41341 .30834 .43777 .3184 .46513 .31198 .43721 Mtetra
0 .005 .546 r
.31198 .43721 .3184 .46513 .3289 .48971 .32248 .45994 Mtetra
.17 .182 .629 r
.32248 .45994 .3289 .48971 .34014 .50571 .33358 .47666 Mtetra
.425 .361 .682 r
.33358 .47666 .34014 .50571 .35226 .50883 .34544 .48334 Mtetra
.614 .502 .703 r
.34544 .48334 .35226 .50883 .36515 .49821 .35801 .47861 Mtetra
.74 .609 .713 r
.35801 .47861 .36515 .49821 .37852 .47692 .37108 .46449 Mtetra
.828 .706 .73 r
.37108 .46449 .37852 .47692 .39202 .45068 .38433 .44561 Mtetra
.894 .829 .775 r
.38433 .44561 .39202 .45068 .40536 .42562 .39751 .42737 Mtetra
.849 .996 .829 r
.39751 .42737 .40536 .42562 .41842 .40633 .41046 .41413 Mtetra
.006 0 0 r
.41046 .41413 .41842 .40633 .43118 .39502 .42317 .40812 Mtetra
.477 .06 .169 r
.42317 .40812 .43118 .39502 .44375 .39158 .43572 .40939 Mtetra
.592 .213 .294 r
.43572 .40939 .44375 .39158 .45625 .39433 .44825 .41627 Mtetra
.62 .262 .341 r
.44825 .41627 .45625 .39433 .4688 .40081 .46086 .42617 Mtetra
.614 .268 .359 r
.46086 .42617 .4688 .40081 .48148 .40852 .47365 .4363 Mtetra
.588 .249 .362 r
.47365 .4363 .48148 .40852 .49433 .41539 .48664 .44425 Mtetra
.545 .211 .353 r
.48664 .44425 .49433 .41539 .50733 .42008 .49982 .44839 Mtetra
.489 .157 .33 r
.49982 .44839 .50733 .42008 .52048 .42218 .51314 .44808 Mtetra
.417 .083 .288 r
.51314 .44808 .52048 .42218 .53373 .42202 .52657 .44364 Mtetra
.319 0 .213 r
.52657 .44364 .53373 .42202 .54708 .4204 .54004 .43599 Mtetra
.146 0 .054 r
.54004 .43599 .54708 .4204 .5605 .41789 .55354 .42615 Mtetra
0 0 0 r
.55354 .42615 .5605 .41789 .57399 .4143 .56703 .41459 Mtetra
.85 .994 .836 r
.56703 .41459 .57399 .4143 .5875 .40838 .5805 .40099 Mtetra
.872 .817 .792 r
.5805 .40099 .5875 .40838 .60097 .39821 .59389 .38443 Mtetra
.838 .71 .722 r
.59389 .38443 .60097 .39821 .61429 .38216 .60714 .36409 Mtetra
.827 .667 .685 r
.60714 .36409 .61429 .38216 .62738 .35995 .62022 .34 Mtetra
.827 .655 .668 r
.62022 .34 .62738 .35995 .64021 .33308 .6331 .31341 Mtetra
.832 .658 .667 r
.6331 .31341 .64021 .33308 .65284 .30441 .64585 .28645 Mtetra
.835 .67 .678 r
.64585 .28645 .65284 .30441 .66539 .27703 .65854 .2614 Mtetra
.834 .689 .703 r
.65854 .2614 .66539 .27703 .67798 .25329 .67129 .2399 Mtetra
.824 .711 .74 r
.67129 .2399 .67798 .25329 .69072 .23422 .68418 .22262 Mtetra
.803 .731 .785 r
.68418 .22262 .69072 .23422 .70367 .2197 .69725 .20932 Mtetra
.771 .744 .829 r
.69725 .20932 .70367 .2197 .71682 .20884 .7105 .19919 Mtetra
.736 .75 .863 r
.7105 .19919 .71682 .20884 .73016 .20056 .72391 .19128 Mtetra
.707 .749 .885 r
.72391 .19128 .73016 .20056 .74365 .19388 .73746 .18477 Mtetra
.687 .747 .897 r
.73746 .18477 .74365 .19388 .75725 .1881 .75112 .17904 Mtetra
.675 .744 .903 r
.75112 .17904 .75725 .1881 .77096 .18279 .76488 .17372 Mtetra
.669 .743 .906 r
.76488 .17372 .77096 .18279 .78474 .17769 .77871 .16859 Mtetra
.666 .742 .907 r
.77871 .16859 .78474 .17769 .79861 .17267 .79262 .16354 Mtetra
.663 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38115 .17361 .37378 Mtetra
.17361 .37378 .18146 .38115 .19263 .3772 .18481 .36979 Mtetra
.662 .74 .908 r
.18481 .36979 .19263 .3772 .20384 .37329 .19606 .36582 Mtetra
.658 .739 .909 r
.19606 .36582 .20384 .37329 .2151 .3695 .20735 .36193 Mtetra
.65 .735 .911 r
.20735 .36193 .2151 .3695 .22637 .36602 .21866 .35825 Mtetra
.631 .724 .915 r
.21866 .35825 .22637 .36602 .23763 .36324 .22998 .35509 Mtetra
.591 .701 .919 r
.22998 .35509 .23763 .36324 .24883 .36182 .24126 .35294 Mtetra
.509 .649 .92 r
.24126 .35294 .24883 .36182 .25989 .3628 .25244 .35263 Mtetra
.36 .542 .898 r
.25244 .35263 .25989 .3628 .27075 .36747 .26347 .35525 Mtetra
.142 .362 .819 r
.26347 .35525 .27075 .36747 .28134 .37715 .27426 .36197 Mtetra
0 .159 .692 r
.27426 .36197 .28134 .37715 .29165 .39263 .28482 .37363 Mtetra
0 .025 .589 r
.28482 .37363 .29165 .39263 .3018 .41341 .29519 .39015 Mtetra
0 0 .555 r
.29519 .39015 .3018 .41341 .31198 .43721 .30554 .41 Mtetra
0 .06 .58 r
.30554 .41 .31198 .43721 .32248 .45994 .3161 .43013 Mtetra
.173 .183 .629 r
.3161 .43013 .32248 .45994 .33358 .47666 .32712 .44656 Mtetra
.373 .32 .67 r
.32712 .44656 .33358 .47666 .34544 .48334 .33876 .45576 Mtetra
.536 .442 .695 r
.33876 .45576 .34544 .48334 .35801 .47861 .35102 .45609 Mtetra
.655 .544 .717 r
.35102 .45609 .35801 .47861 .37108 .46449 .36376 .44873 Mtetra
.741 .642 .75 r
.36376 .44873 .37108 .46449 .38433 .44561 .37672 .43718 Mtetra
.799 .768 .825 r
.37672 .43718 .38433 .44561 .39751 .42737 .38967 .42594 Mtetra
.708 .951 .954 r
.38967 .42594 .39751 .42737 .41046 .41413 .40247 .41883 Mtetra
.224 0 0 r
.40247 .41883 .41046 .41413 .42317 .40812 .4151 .41796 Mtetra
.569 .122 .149 r
.4151 .41796 .42317 .40812 .43572 .40939 .42762 .42337 Mtetra
.644 .243 .269 r
.42762 .42337 .43572 .40939 .44825 .41627 .44016 .43344 Mtetra
.656 .275 .31 r
.44016 .43344 .44825 .41627 .46086 .42617 .45283 .4455 Mtetra
.638 .265 .32 r
.45283 .4455 .46086 .42617 .47365 .4363 .46571 .45663 Mtetra
.593 .222 .308 r
.46571 .45663 .47365 .4363 .48664 .44425 .47883 .46426 Mtetra
.514 .141 .271 r
.47883 .46426 .48664 .44425 .49982 .44839 .49217 .46663 Mtetra
.382 .005 .192 r
.49217 .46663 .49982 .44839 .51314 .44808 .50565 .4631 Mtetra
.151 0 .034 r
.50565 .4631 .51314 .44808 .52657 .44364 .51922 .45408 Mtetra
0 0 0 r
.51922 .45408 .52657 .44364 .54004 .43599 .53281 .44075 Mtetra
.776 .969 .677 r
.53281 .44075 .54004 .43599 .55354 .42615 .54637 .4245 Mtetra
.924 .934 .792 r
.54637 .4245 .55354 .42615 .56703 .41459 .55988 .40639 Mtetra
.885 .798 .758 r
.55988 .40639 .56703 .41459 .5805 .40099 .57332 .38684 Mtetra
.84 .707 .716 r
.57332 .38684 .5805 .40099 .59389 .38443 .58667 .36568 Mtetra
.816 .658 .687 r
.58667 .36568 .59389 .38443 .60714 .36409 .5999 .34263 Mtetra
.808 .637 .671 r
.5999 .34263 .60714 .36409 .62022 .34 .61298 .31789 Mtetra
.808 .634 .666 r
.61298 .31789 .62022 .34 .6331 .31341 .62594 .29239 Mtetra
.812 .641 .67 r
.62594 .29239 .6331 .31341 .64585 .28645 .6388 .26764 Mtetra
.815 .656 .686 r
.6388 .26764 .64585 .28645 .65854 .2614 .65165 .24516 Mtetra
.813 .676 .713 r
.65165 .24516 .65854 .2614 .67129 .2399 .66455 .22606 Mtetra
.803 .699 .75 r
.66455 .22606 .67129 .2399 .68418 .22262 .67758 .21066 Mtetra
.783 .72 .793 r
.67758 .21066 .68418 .22262 .69725 .20932 .69077 .19864 Mtetra
.755 .735 .834 r
.69077 .19864 .69725 .20932 .7105 .19919 .70411 .1893 Mtetra
.725 .742 .865 r
.70411 .1893 .7105 .19919 .72391 .19128 .7176 .18182 Mtetra
.7 .744 .885 r
.7176 .18182 .72391 .19128 .73746 .18477 .73122 .17551 Mtetra
.683 .744 .897 r
.73122 .17551 .73746 .18477 .75112 .17904 .74494 .16985 Mtetra
.674 .743 .903 r
.74494 .16985 .75112 .17904 .76488 .17372 .75874 .16454 Mtetra
.668 .742 .905 r
.75874 .16454 .76488 .17372 .77871 .16859 .77263 .15939 Mtetra
.666 .742 .907 r
.77263 .15939 .77871 .16859 .79262 .16354 .78658 .15431 Mtetra
.663 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37378 .16571 .36636 Mtetra
.16571 .36636 .17361 .37378 .18481 .36979 .17694 .36233 Mtetra
.662 .741 .908 r
.17694 .36233 .18481 .36979 .19606 .36582 .18821 .3583 Mtetra
.66 .74 .909 r
.18821 .3583 .19606 .36582 .20735 .36193 .19953 .35433 Mtetra
.654 .737 .91 r
.19953 .35433 .20735 .36193 .21866 .35825 .21088 .3505 Mtetra
.641 .73 .913 r
.21088 .3505 .21866 .35825 .22998 .35509 .22225 .34703 Mtetra
.613 .713 .916 r
.22225 .34703 .22998 .35509 .24126 .35294 .23361 .3443 Mtetra
.556 .677 .919 r
.23361 .3443 .24126 .35294 .25244 .35263 .2449 .34294 Mtetra
.453 .604 .91 r
.2449 .34294 .25244 .35263 .26347 .35525 .25607 .34382 Mtetra
.292 .474 .867 r
.25607 .34382 .26347 .35525 .27426 .36197 .26707 .34795 Mtetra
.109 .304 .779 r
.26707 .34795 .27426 .36197 .28482 .37363 .27785 .35616 Mtetra
0 .161 .682 r
.27785 .35616 .28482 .37363 .29519 .39015 .28847 .36863 Mtetra
0 .099 .626 r
.28847 .36863 .29519 .39015 .30554 .41 .29902 .38447 Mtetra
.044 .119 .618 r
.29902 .38447 .30554 .41 .3161 .43013 .30969 .40153 Mtetra
.183 .196 .639 r
.30969 .40153 .3161 .43013 .32712 .44656 .32068 .41677 Mtetra
.336 .296 .665 r
.32068 .41677 .32712 .44656 .33876 .45576 .33216 .42726 Mtetra
.469 .393 .688 r
.33216 .42726 .33876 .45576 .35102 .45609 .34416 .43136 Mtetra
.57 .479 .713 r
.34416 .43136 .35102 .45609 .36376 .44873 .35659 .42955 Mtetra
.638 .559 .75 r
.35659 .42955 .36376 .44873 .37672 .43718 .36926 .42432 Mtetra
.663 .648 .825 r
.36926 .42432 .37672 .43718 .38967 .42594 .38197 .41916 Mtetra
.549 .749 .97 r
.38197 .41916 .38967 .42594 .40247 .41883 .39461 .41722 Mtetra
.188 0 0 r
.39461 .41722 .40247 .41883 .4151 .41796 .40715 .42026 Mtetra
.616 .079 0 r
.40715 .42026 .4151 .41796 .42762 .42337 .41964 .42829 Mtetra
.696 .217 .108 r
.41964 .42829 .42762 .42337 .44016 .43344 .4322 .43973 Mtetra
.703 .24 .15 r
.4322 .43973 .44016 .43344 .45283 .4455 .44492 .45201 Mtetra
.666 .193 .12 r
.44492 .45201 .45283 .4455 .46571 .45663 .45788 .46226 Mtetra
.554 .043 0 r
.45788 .46226 .46571 .45663 .47883 .46426 .4711 .46801 Mtetra
.209 0 0 r
.4711 .46801 .47883 .46426 .49217 .46663 .48454 .46763 Mtetra
.55 .931 .863 r
.48454 .46763 .49217 .46663 .50565 .4631 .49813 .46062 Mtetra
.862 .939 .87 r
.49813 .46062 .50565 .4631 .51922 .45408 .5118 .44759 Mtetra
.886 .831 .788 r
.5118 .44759 .51922 .45408 .53281 .44075 .52546 .42993 Mtetra
.864 .753 .738 r
.52546 .42993 .53281 .44075 .54637 .4245 .53906 .40929 Mtetra
.836 .695 .707 r
.53906 .40929 .54637 .4245 .55988 .40639 .55258 .38712 Mtetra
.81 .653 .687 r
.55258 .38712 .55988 .40639 .57332 .38684 .56601 .36424 Mtetra
.792 .624 .673 r
.56601 .36424 .57332 .38684 .58667 .36568 .57934 .34095 Mtetra
.782 .608 .665 r
.57934 .34095 .58667 .36568 .5999 .34263 .59256 .31728 Mtetra
.779 .604 .662 r
.59256 .31728 .5999 .34263 .61298 .31789 .60569 .29344 Mtetra
.782 .609 .665 r
.60569 .29344 .61298 .31789 .62594 .29239 .61873 .27005 Mtetra
.787 .621 .675 r
.61873 .27005 .62594 .29239 .6388 .26764 .63171 .24807 Mtetra
.79 .64 .695 r
.63171 .24807 .6388 .26764 .65165 .24516 .6447 .22847 Mtetra
.789 .663 .724 r
.6447 .22847 .65165 .24516 .66455 .22606 .65776 .21188 Mtetra
.78 .687 .761 r
.65776 .21188 .66455 .22606 .67758 .21066 .67093 .19843 Mtetra
.762 .709 .802 r
.67093 .19843 .67758 .21066 .69077 .19864 .68423 .18775 Mtetra
.738 .726 .84 r
.68423 .18775 .69077 .19864 .70411 .1893 .69767 .17923 Mtetra
.713 .735 .868 r
.69767 .17923 .70411 .1893 .7176 .18182 .71124 .17221 Mtetra
.693 .74 .887 r
.71124 .17221 .7176 .18182 .73122 .17551 .72492 .16612 Mtetra
.679 .741 .897 r
.72492 .16612 .73122 .17551 .74494 .16985 .73869 .16056 Mtetra
.672 .741 .903 r
.73869 .16056 .74494 .16985 .75874 .16454 .75255 .15527 Mtetra
.667 .741 .905 r
.75255 .15527 .75874 .16454 .77263 .15939 .76648 .15011 Mtetra
.665 .741 .907 r
.76648 .15011 .77263 .15939 .78658 .15431 .78049 .145 Mtetra
.663 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36636 .15773 .35888 Mtetra
.15773 .35888 .16571 .36636 .17694 .36233 .16899 .35481 Mtetra
.16899 .35481 .17694 .36233 .18821 .3583 .1803 .35074 Mtetra
.661 .74 .909 r
.1803 .35074 .18821 .3583 .19953 .35433 .19165 .34669 Mtetra
.657 .738 .909 r
.19165 .34669 .19953 .35433 .21088 .3505 .20304 .34275 Mtetra
.648 .733 .911 r
.20304 .34275 .21088 .3505 .22225 .34703 .21445 .33904 Mtetra
.629 .722 .914 r
.21445 .33904 .22225 .34703 .23361 .3443 .22587 .33586 Mtetra
.59 .697 .917 r
.22587 .33586 .23361 .3443 .2449 .34294 .23726 .33367 Mtetra
.519 .647 .914 r
.23726 .33367 .2449 .34294 .25607 .34382 .24856 .33314 Mtetra
.405 .556 .892 r
.24856 .33314 .25607 .34382 .26707 .34795 .25973 .33511 Mtetra
.26 .425 .837 r
.25973 .33511 .26707 .34795 .27785 .35616 .27074 .34034 Mtetra
.135 .29 .758 r
.27074 .34034 .27785 .35616 .28847 .36863 .28159 .34917 Mtetra
.084 .204 .692 r
.28159 .34917 .28847 .36863 .29902 .38447 .29235 .36116 Mtetra
.116 .187 .661 r
.29235 .36116 .29902 .38447 .30969 .40153 .30317 .37491 Mtetra
.207 .224 .658 r
.30317 .37491 .30969 .40153 .32068 .41677 .3142 .38821 Mtetra
.318 .29 .669 r
.3142 .38821 .32068 .41677 .33216 .42726 .3256 .39875 Mtetra
.422 .361 .684 r
.3256 .39875 .33216 .42726 .34416 .43136 .33741 .40501 Mtetra
.502 .427 .703 r
.33741 .40501 .34416 .43136 .35659 .42955 .34958 .407 Mtetra
.55 .482 .732 r
.34958 .407 .35659 .42955 .36926 .42432 .362 .40632 Mtetra
.554 .525 .778 r
.362 .40632 .36926 .42432 .38197 .41916 .37452 .40548 Mtetra
.471 .542 .848 r
.37452 .40548 .38197 .41916 .39461 .41722 .38702 .40689 Mtetra
.206 .467 .884 r
.38702 .40689 .39461 .41722 .40715 .42026 .39949 .41192 Mtetra
0 .252 .746 r
.39949 .41192 .40715 .42026 .41964 .42829 .41197 .42048 Mtetra
0 .112 .614 r
.41197 .42048 .41964 .42829 .4322 .43973 .42455 .43113 Mtetra
0 .159 .67 r
.42455 .43113 .4322 .43973 .44492 .45201 .43732 .44156 Mtetra
.035 .358 .831 r
.43732 .44156 .44492 .45201 .45788 .46226 .45034 .44923 Mtetra
.409 .529 .867 r
.45034 .44923 .45788 .46226 .4711 .46801 .46361 .45199 Mtetra
.612 .589 .803 r
.46361 .45199 .4711 .46801 .48454 .46763 .47709 .44852 Mtetra
.701 .602 .743 r
.47709 .44852 .48454 .46763 .49813 .46062 .49072 .43859 Mtetra
.741 .602 .703 r
.49072 .43859 .49813 .46062 .5118 .44759 .50441 .42297 Mtetra
.757 .597 .679 r
.50441 .42297 .5118 .44759 .52546 .42993 .51808 .40314 Mtetra
.762 .59 .664 r
.51808 .40314 .52546 .42993 .53906 .40929 .53168 .3808 Mtetra
.759 .581 .656 r
.53168 .3808 .53906 .40929 .55258 .38712 .54519 .35748 Mtetra
.754 .574 .652 r
.54519 .35748 .55258 .38712 .56601 .36424 .55861 .33415 Mtetra
.749 .569 .651 r
.55861 .33415 .56601 .36424 .57934 .34095 .57194 .31129 Mtetra
.748 .569 .653 r
.57194 .31129 .57934 .34095 .59256 .31728 .58519 .28903 Mtetra
.75 .575 .658 r
.58519 .28903 .59256 .31728 .60569 .29344 .59837 .26751 Mtetra
.756 .587 .668 r
.59837 .26751 .60569 .29344 .61873 .27005 .6115 .24709 Mtetra
.762 .605 .683 r
.6115 .24709 .61873 .27005 .63171 .24807 .62461 .22832 Mtetra
.766 .627 .707 r
.62461 .22832 .63171 .24807 .6447 .22847 .63774 .21175 Mtetra
.765 .652 .738 r
.63774 .21175 .6447 .22847 .65776 .21188 .65094 .1977 Mtetra
.757 .679 .775 r
.65094 .1977 .65776 .21188 .67093 .19843 .66423 .18616 Mtetra
.742 .703 .814 r
.66423 .18616 .67093 .19843 .68423 .18775 .67765 .17678 Mtetra
.722 .72 .848 r
.67765 .17678 .68423 .18775 .69767 .17923 .69118 .16907 Mtetra
.702 .731 .873 r
.69118 .16907 .69767 .17923 .71124 .17221 .70482 .1625 Mtetra
.686 .736 .889 r
.70482 .1625 .71124 .17221 .72492 .16612 .71856 .15664 Mtetra
.676 .739 .898 r
.71856 .15664 .72492 .16612 .73869 .16056 .73239 .15118 Mtetra
.67 .74 .903 r
.73239 .15118 .73869 .16056 .75255 .15527 .7463 .14592 Mtetra
.666 .741 .906 r
.7463 .14592 .75255 .15527 .76648 .15011 .76029 .14074 Mtetra
.665 .741 .907 r
.76029 .14074 .76648 .15011 .78049 .145 .77434 .1356 Mtetra
.663 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35888 .1497 .35133 Mtetra
.1497 .35133 .15773 .35888 .16899 .35481 .16098 .34723 Mtetra
.16098 .34723 .16899 .35481 .1803 .35074 .17232 .34312 Mtetra
.662 .741 .908 r
.17232 .34312 .1803 .35074 .19165 .34669 .1837 .33902 Mtetra
.659 .739 .909 r
.1837 .33902 .19165 .34669 .20304 .34275 .19513 .33498 Mtetra
.653 .736 .91 r
.19513 .33498 .20304 .34275 .21445 .33904 .20658 .3311 Mtetra
.64 .728 .912 r
.20658 .3311 .21445 .33904 .22587 .33586 .21806 .32757 Mtetra
.614 .711 .915 r
.21806 .32757 .22587 .33586 .23726 .33367 .22952 .32474 Mtetra
.566 .677 .915 r
.22952 .32474 .23726 .33367 .24856 .33314 .24094 .32312 Mtetra
.487 .615 .904 r
.24094 .32312 .24856 .33314 .25973 .33511 .25226 .32335 Mtetra
.379 .519 .872 r
.25226 .32335 .25973 .33511 .27074 .34034 .26346 .3261 Mtetra
.269 .404 .815 r
.26346 .3261 .27074 .34034 .28159 .34917 .27453 .33177 Mtetra
.201 .31 .752 r
.27453 .33177 .28159 .34917 .29235 .36116 .28552 .34024 Mtetra
.198 .265 .708 r
.28552 .34024 .29235 .36116 .30317 .37491 .29651 .35064 Mtetra
.248 .269 .687 r
.29651 .35064 .30317 .37491 .3142 .38821 .30764 .36145 Mtetra
.325 .305 .682 r
.30764 .36145 .3142 .38821 .3256 .39875 .31902 .37092 Mtetra
.403 .352 .686 r
.31902 .37092 .3256 .39875 .33741 .40501 .33073 .37772 Mtetra
.466 .397 .696 r
.33073 .37772 .33741 .40501 .34958 .407 .34275 .38157 Mtetra
.503 .433 .71 r
.34275 .38157 .34958 .407 .362 .40632 .35499 .38336 Mtetra
.507 .453 .731 r
.35499 .38336 .362 .40632 .37452 .40548 .36737 .38475 Mtetra
.47 .45 .753 r
.36737 .38475 .37452 .40548 .38702 .40689 .37978 .38744 Mtetra
.396 .418 .766 r
.37978 .38744 .38702 .40689 .39949 .41192 .39222 .39241 Mtetra
.324 .373 .759 r
.39222 .39241 .39949 .41192 .41197 .42048 .40472 .39953 Mtetra
.312 .352 .742 r
.40472 .39953 .41197 .42048 .42455 .43113 .41733 .40759 Mtetra
.372 .368 .725 r
.41733 .40759 .42455 .43113 .43732 .44156 .43014 .41471 Mtetra
.462 .404 .706 r
.43014 .41471 .43732 .44156 .45034 .44923 .44318 .41883 Mtetra
.544 .44 .686 r
.44318 .41883 .45034 .44923 .46361 .45199 .45645 .41831 Mtetra
.606 .468 .667 r
.45645 .41831 .46361 .45199 .47709 .44852 .46992 .41222 Mtetra
.65 .489 .653 r
.46992 .41222 .47709 .44852 .49072 .43859 .48351 .40058 Mtetra
.679 .504 .643 r
.48351 .40058 .49072 .43859 .50441 .42297 .49715 .38422 Mtetra
.697 .514 .637 r
.49715 .38422 .50441 .42297 .51808 .40314 .51077 .36453 Mtetra
.708 .521 .634 r
.51077 .36453 .51808 .40314 .53168 .3808 .52432 .34306 Mtetra
.713 .526 .635 r
.52432 .34306 .53168 .3808 .54519 .35748 .5378 .32117 Mtetra
.715 .53 .638 r
.5378 .32117 .54519 .35748 .55861 .33415 .5512 .29978 Mtetra
.717 .536 .644 r
.5512 .29978 .55861 .33415 .57194 .31129 .56454 .27933 Mtetra
.72 .544 .651 r
.56454 .27933 .57194 .31129 .58519 .28903 .57782 .25993 Mtetra
.725 .557 .662 r
.57782 .25993 .58519 .28903 .59837 .26751 .59106 .24166 Mtetra
.732 .574 .677 r
.59106 .24166 .59837 .26751 .6115 .24709 .60428 .22466 Mtetra
.739 .595 .697 r
.60428 .22466 .6115 .24709 .62461 .22832 .61751 .20921 Mtetra
.743 .621 .723 r
.61751 .20921 .62461 .22832 .63774 .21175 .63077 .19558 Mtetra
.743 .649 .756 r
.63077 .19558 .63774 .21175 .65094 .1977 .64409 .1839 Mtetra
.736 .677 .793 r
.64409 .1839 .65094 .1977 .66423 .18616 .6575 .17411 Mtetra
.723 .7 .828 r
.6575 .17411 .66423 .18616 .67765 .17678 .67102 .16591 Mtetra
.707 .718 .858 r
.67102 .16591 .67765 .17678 .69118 .16907 .68463 .15892 Mtetra
.691 .729 .879 r
.68463 .15892 .69118 .16907 .70482 .1625 .69835 .15276 Mtetra
.68 .735 .892 r
.69835 .15276 .70482 .1625 .71856 .15664 .71215 .1471 Mtetra
.672 .738 .9 r
.71215 .1471 .71856 .15664 .73239 .15118 .72603 .14172 Mtetra
.668 .74 .904 r
.72603 .14172 .73239 .15118 .7463 .14592 .74 .13648 Mtetra
.666 .741 .906 r
.74 .13648 .7463 .14592 .76029 .14074 .75403 .13129 Mtetra
.664 .741 .907 r
.75403 .13129 .76029 .14074 .77434 .1356 .76814 .12612 Mtetra
.663 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34723 .15291 .33959 Mtetra
.15291 .33959 .16098 .34723 .17232 .34312 .16427 .33544 Mtetra
.662 .741 .908 r
.16427 .33544 .17232 .34312 .1837 .33902 .17569 .33129 Mtetra
.661 .74 .909 r
.17569 .33129 .1837 .33902 .19513 .33498 .18714 .32717 Mtetra
.657 .738 .909 r
.18714 .32717 .19513 .33498 .20658 .3311 .19864 .32316 Mtetra
.648 .733 .911 r
.19864 .32316 .20658 .3311 .21806 .32757 .21017 .31938 Mtetra
.63 .721 .913 r
.21017 .31938 .21806 .32757 .22952 .32474 .2217 .31608 Mtetra
.598 .698 .913 r
.2217 .31608 .22952 .32474 .24094 .32312 .23321 .31362 Mtetra
.545 .656 .909 r
.23321 .31362 .24094 .32312 .25226 .32335 .24466 .31249 Mtetra
.468 .588 .891 r
.24466 .31249 .25226 .32335 .26346 .3261 .25603 .31324 Mtetra
.381 .498 .853 r
.25603 .31324 .26346 .3261 .27453 .33177 .2673 .31627 Mtetra
.312 .41 .802 r
.2673 .31627 .27453 .33177 .28552 .34024 .2785 .32161 Mtetra
.286 .35 .754 r
.2785 .32161 .28552 .34024 .29651 .35064 .28969 .3288 Mtetra
.306 .329 .721 r
.28969 .3288 .29651 .35064 .30764 .36145 .30095 .33682 Mtetra
.355 .339 .703 r
.30095 .33682 .30764 .36145 .31902 .37092 .3124 .34439 Mtetra
.411 .364 .695 r
.3124 .34439 .31902 .37092 .33073 .37772 .32409 .35039 Mtetra
.46 .393 .694 r
.32409 .35039 .33073 .37772 .34275 .38157 .33603 .35439 Mtetra
.493 .415 .697 r
.33603 .35439 .34275 .38157 .35499 .38336 .34819 .35676 Mtetra
.504 .427 .702 r
.34819 .35676 .35499 .38336 .36737 .38475 .36049 .3585 Mtetra
.494 .423 .706 r
.36049 .3585 .36737 .38475 .37978 .38744 .37288 .36073 Mtetra
.472 .407 .703 r
.37288 .36073 .37978 .38744 .39222 .39241 .38533 .3641 Mtetra
.457 .389 .692 r
.38533 .3641 .39222 .39241 .40472 .39953 .39786 .36852 Mtetra
.462 .38 .678 r
.39786 .36852 .40472 .39953 .41733 .40759 .41052 .37308 Mtetra
.489 .385 .663 r
.41052 .37308 .41733 .40759 .43014 .41471 .42335 .37638 Mtetra
.527 .4 .65 r
.42335 .37638 .43014 .41471 .44318 .41883 .43638 .37696 Mtetra
.566 .418 .639 r
.43638 .37696 .44318 .41883 .45645 .41831 .44961 .37366 Mtetra
.601 .436 .631 r
.44961 .37366 .45645 .41831 .46992 .41222 .46301 .36594 Mtetra
.629 .453 .626 r
.46301 .36594 .46992 .41222 .48351 .40058 .4765 .35398 Mtetra
.65 .467 .623 r
.4765 .35398 .48351 .40058 .49715 .38422 .49004 .33855 Mtetra
.666 .479 .623 r
.49004 .33855 .49715 .38422 .51077 .36453 .50356 .32081 Mtetra
.677 .49 .625 r
.50356 .32081 .51077 .36453 .52432 .34306 .51705 .30201 Mtetra
.684 .499 .63 r
.51705 .30201 .52432 .34306 .5378 .32117 .53047 .28323 Mtetra
.689 .509 .638 r
.53047 .28323 .5378 .32117 .5512 .29978 .54385 .26516 Mtetra
.694 .52 .647 r
.54385 .26516 .5512 .29978 .56454 .27933 .55719 .24816 Mtetra
.699 .533 .66 r
.55719 .24816 .56454 .27933 .57782 .25993 .5705 .23228 Mtetra
.705 .55 .675 r
.5705 .23228 .57782 .25993 .59106 .24166 .5838 .21751 Mtetra
.712 .571 .694 r
.5838 .21751 .59106 .24166 .60428 .22466 .5971 .20387 Mtetra
.719 .596 .718 r
.5971 .20387 .60428 .22466 .61751 .20921 .61043 .19147 Mtetra
.724 .624 .746 r
.61043 .19147 .61751 .20921 .63077 .19558 .6238 .18043 Mtetra
.723 .653 .779 r
.6238 .18043 .63077 .19558 .64409 .1839 .63724 .17079 Mtetra
.717 .681 .813 r
.63724 .17079 .64409 .1839 .6575 .17411 .65075 .16247 Mtetra
.707 .703 .844 r
.65075 .16247 .6575 .17411 .67102 .16591 .66435 .15525 Mtetra
.694 .719 .869 r
.66435 .15525 .67102 .16591 .68463 .15892 .67804 .14886 Mtetra
.683 .729 .886 r
.67804 .14886 .68463 .15892 .69835 .15276 .69182 .14303 Mtetra
.674 .735 .896 r
.69182 .14303 .69835 .15276 .71215 .1471 .70568 .13753 Mtetra
.669 .738 .902 r
.70568 .13753 .71215 .1471 .72603 .14172 .71962 .13221 Mtetra
.666 .74 .905 r
.71962 .13221 .72603 .14172 .74 .13648 .73364 .12697 Mtetra
.665 .741 .907 r
.73364 .12697 .74 .13648 .75403 .13129 .74772 .12177 Mtetra
.664 .741 .907 r
.74772 .12177 .75403 .13129 .76814 .12612 .76188 .11656 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.663 .741 .908 r
.13343 .33606 .1416 .34373 .15291 .33959 .14477 .33189 Mtetra
.14477 .33189 .15291 .33959 .16427 .33544 .15616 .3277 Mtetra
.15616 .3277 .16427 .33544 .17569 .33129 .16761 .32351 Mtetra
.662 .74 .908 r
.16761 .32351 .17569 .33129 .18714 .32717 .1791 .31933 Mtetra
.659 .739 .909 r
.1791 .31933 .18714 .32717 .19864 .32316 .19063 .31521 Mtetra
.653 .736 .91 r
.19063 .31521 .19864 .32316 .21017 .31938 .2022 .31124 Mtetra
.642 .728 .911 r
.2022 .31124 .21017 .31938 .2217 .31608 .21379 .30759 Mtetra
.62 .713 .912 r
.21379 .30759 .2217 .31608 .23321 .31362 .22538 .3045 Mtetra
.585 .684 .91 r
.22538 .3045 .23321 .31362 .24466 .31249 .23694 .30235 Mtetra
.533 .638 .9 r
.23694 .30235 .24466 .31249 .25603 .31324 .24846 .30153 Mtetra
.469 .571 .876 r
.24846 .30153 .25603 .31324 .2673 .31627 .25991 .30241 Mtetra
.409 .497 .838 r
.25991 .30241 .2673 .31627 .2785 .32161 .2713 .3051 Mtetra
.375 .434 .794 r
.2713 .3051 .2785 .32161 .28969 .3288 .28268 .30937 Mtetra
.375 .397 .756 r
.28268 .30937 .28969 .3288 .30095 .33682 .29411 .31456 Mtetra
.401 .387 .729 r
.29411 .31456 .30095 .33682 .3124 .34439 .30566 .31976 Mtetra
.439 .394 .712 r
.30566 .31976 .3124 .34439 .32409 .35039 .3174 .3241 Mtetra
.476 .409 .702 r
.3174 .3241 .32409 .35039 .33603 .35439 .32936 .32705 Mtetra
.505 .422 .696 r
.32936 .32705 .33603 .35439 .34819 .35676 .3415 .32867 Mtetra
.519 .428 .692 r
.3415 .32867 .34819 .35676 .36049 .3585 .35379 .3295 Mtetra
.522 .426 .687 r
.35379 .3295 .36049 .3585 .37288 .36073 .36619 .33023 Mtetra
.517 .416 .68 r
.36619 .33023 .37288 .36073 .38533 .3641 .37867 .3313 Mtetra
.514 .405 .669 r
.37867 .3313 .38533 .3641 .39786 .36852 .39125 .33266 Mtetra
.519 .399 .656 r
.39125 .33266 .39786 .36852 .41052 .37308 .40394 .33375 Mtetra
.533 .399 .644 r
.40394 .33375 .41052 .37308 .42335 .37638 .41678 .33363 Mtetra
.554 .406 .635 r
.41678 .33363 .42335 .37638 .43638 .37696 .42979 .33137 Mtetra
.578 .417 .627 r
.42979 .33137 .43638 .37696 .44961 .37366 .44295 .32624 Mtetra
.6 .43 .623 r
.44295 .32624 .44961 .37366 .46301 .36594 .45624 .31798 Mtetra
.62 .443 .621 r
.45624 .31798 .46301 .36594 .4765 .35398 .46962 .30681 Mtetra
.636 .455 .621 r
.46962 .30681 .4765 .35398 .49004 .33855 .48303 .29336 Mtetra
.649 .467 .624 r
.48303 .29336 .49004 .33855 .50356 .32081 .49645 .2785 Mtetra
.659 .479 .63 r
.49645 .2785 .50356 .32081 .51705 .30201 .50985 .26314 Mtetra
.667 .491 .638 r
.50985 .26314 .51705 .30201 .53047 .28323 .52322 .24804 Mtetra
.673 .504 .649 r
.52322 .24804 .53047 .28323 .54385 .26516 .53657 .23367 Mtetra
.678 .519 .662 r
.53657 .23367 .54385 .26516 .55719 .24816 .5499 .22024 Mtetra
.684 .536 .679 r
.5499 .22024 .55719 .24816 .5705 .23228 .56324 .20776 Mtetra
.691 .556 .698 r
.56324 .20776 .5705 .23228 .5838 .21751 .5766 .19616 Mtetra
.698 .581 .72 r
.5766 .19616 .5838 .21751 .5971 .20387 .58997 .18541 Mtetra
.704 .608 .746 r
.58997 .18541 .5971 .20387 .61043 .19147 .60338 .17552 Mtetra
.708 .637 .775 r
.60338 .17552 .61043 .19147 .6238 .18043 .61685 .16656 Mtetra
.707 .665 .806 r
.61685 .16656 .6238 .18043 .63724 .17079 .63037 .15852 Mtetra
.702 .69 .836 r
.63037 .15852 .63724 .17079 .65075 .16247 .64397 .15133 Mtetra
.693 .71 .861 r
.64397 .15133 .65075 .16247 .66435 .15525 .65765 .14486 Mtetra
.684 .723 .88 r
.65765 .14486 .66435 .15525 .67804 .14886 .67141 .13891 Mtetra
.676 .732 .892 r
.67141 .13891 .67804 .14886 .69182 .14303 .68525 .13331 Mtetra
.67 .736 .9 r
.68525 .13331 .69182 .14303 .70568 .13753 .69916 .12792 Mtetra
.667 .739 .904 r
.69916 .12792 .70568 .13753 .71962 .13221 .71315 .12263 Mtetra
.665 .74 .906 r
.71315 .12263 .71962 .13221 .73364 .12697 .72722 .11739 Mtetra
.664 .741 .907 r
.72722 .11739 .73364 .12697 .74772 .12177 .74135 .11216 Mtetra
.74135 .11216 .74772 .12177 .76188 .11656 .75556 .10691 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.663 .741 .908 r
.12519 .32833 .13343 .33606 .14477 .33189 .13656 .32412 Mtetra
.13656 .32412 .14477 .33189 .15616 .3277 .14799 .3199 Mtetra
.14799 .3199 .15616 .3277 .16761 .32351 .15946 .31566 Mtetra
.662 .741 .908 r
.15946 .31566 .16761 .32351 .1791 .31933 .17098 .31143 Mtetra
.661 .74 .909 r
.17098 .31143 .1791 .31933 .19063 .31521 .18255 .30723 Mtetra
.657 .737 .909 r
.18255 .30723 .19063 .31521 .2022 .31124 .19415 .30312 Mtetra
.649 .733 .91 r
.19415 .30312 .2022 .31124 .21379 .30759 .2058 .29921 Mtetra
.636 .722 .91 r
.2058 .29921 .21379 .30759 .22538 .3045 .21745 .29567 Mtetra
.613 .704 .909 r
.21745 .29567 .22538 .3045 .23694 .30235 .22911 .29274 Mtetra
.578 .672 .903 r
.22911 .29274 .23694 .30235 .24846 .30153 .24075 .29074 Mtetra
.534 .625 .888 r
.24075 .29074 .24846 .30153 .25991 .30241 .25235 .28992 Mtetra
.489 .567 .862 r
.25235 .28992 .25991 .30241 .2713 .3051 .26391 .29045 Mtetra
.455 .511 .826 r
.26391 .29045 .2713 .3051 .28268 .30937 .27548 .2922 Mtetra
.444 .468 .79 r
.27548 .2922 .28268 .30937 .29411 .31456 .28707 .29479 Mtetra
.454 .444 .758 r
.28707 .29479 .29411 .31456 .30566 .31976 .29877 .29756 Mtetra
.478 .437 .734 r
.29877 .29756 .30566 .31976 .3174 .3241 .3106 .29985 Mtetra
.504 .439 .717 r
.3106 .29985 .3174 .3241 .32936 .32705 .32261 .30117 Mtetra
.527 .444 .705 r
.32261 .30117 .32936 .32705 .3415 .32867 .33479 .30139 Mtetra
.542 .447 .696 r
.33479 .30139 .3415 .32867 .35379 .3295 .34711 .30077 Mtetra
.548 .444 .688 r
.34711 .30077 .35379 .3295 .36619 .33023 .35954 .2997 Mtetra
.549 .437 .678 r
.35954 .2997 .36619 .33023 .37867 .3313 .37207 .2985 Mtetra
.549 .428 .668 r
.37207 .2985 .37867 .3313 .39125 .33266 .38469 .2972 Mtetra
.552 .422 .657 r
.38469 .2972 .39125 .33266 .40394 .33375 .39741 .29549 Mtetra
.56 .42 .647 r
.39741 .29549 .40394 .33375 .41678 .33363 .41025 .29285 Mtetra
.573 .422 .639 r
.41025 .29285 .41678 .33363 .42979 .33137 .42321 .28873 Mtetra
.588 .429 .633 r
.42321 .28873 .42979 .33137 .44295 .32624 .4363 .28272 Mtetra
.603 .438 .631 r
.4363 .28272 .44295 .32624 .45624 .31798 .44949 .27473 Mtetra
.617 .448 .63 r
.44949 .27473 .45624 .31798 .46962 .30681 .46274 .26494 Mtetra
.63 .46 .633 r
.46274 .26494 .46962 .30681 .48303 .29336 .47604 .25381 Mtetra
.641 .472 .639 r
.47604 .25381 .48303 .29336 .49645 .2785 .48936 .24194 Mtetra
.65 .485 .647 r
.48936 .24194 .49645 .2785 .50985 .26314 .50268 .22992 Mtetra
.657 .499 .658 r
.50268 .22992 .50985 .26314 .52322 .24804 .516 .21823 Mtetra
.663 .515 .673 r
.516 .21823 .52322 .24804 .53657 .23367 .52933 .20715 Mtetra
.669 .533 .69 r
.52933 .20715 .53657 .23367 .5499 .22024 .54267 .19677 Mtetra
.675 .553 .709 r
.54267 .19677 .5499 .22024 .56324 .20776 .55604 .18708 Mtetra
.681 .577 .731 r
.55604 .18708 .56324 .20776 .5766 .19616 .56943 .17798 Mtetra
.688 .602 .755 r
.56943 .17798 .5766 .19616 .58997 .18541 .58287 .16943 Mtetra
.693 .63 .781 r
.58287 .16943 .58997 .18541 .60338 .17552 .59635 .16142 Mtetra
.695 .657 .808 r
.59635 .16142 .60338 .17552 .61685 .16656 .60989 .15396 Mtetra
.694 .682 .834 r
.60989 .15396 .61685 .16656 .63037 .15852 .62349 .14706 Mtetra
.689 .702 .857 r
.62349 .14706 .63037 .15852 .64397 .15133 .63716 .14067 Mtetra
.683 .718 .876 r
.63716 .14067 .64397 .15133 .65765 .14486 .6509 .13471 Mtetra
.676 .728 .889 r
.6509 .13471 .65765 .14486 .67141 .13891 .66472 .12906 Mtetra
.671 .734 .897 r
.66472 .12906 .67141 .13891 .68525 .13331 .67862 .12361 Mtetra
.668 .738 .902 r
.67862 .12361 .68525 .13331 .69916 .12792 .69259 .11828 Mtetra
.666 .739 .905 r
.69259 .11828 .69916 .12792 .71315 .12263 .70663 .113 Mtetra
.664 .74 .907 r
.70663 .113 .71315 .12263 .72722 .11739 .72074 .10773 Mtetra
.664 .741 .907 r
.72074 .10773 .72722 .11739 .74135 .11216 .73493 .10246 Mtetra
.664 .741 .908 r
.73493 .10246 .74135 .11216 .75556 .10691 .74919 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.663 .741 .908 r
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .3163 Mtetra
.12829 .3163 .13656 .32412 .14799 .3199 .13974 .31203 Mtetra
.13974 .31203 .14799 .3199 .15946 .31566 .15124 .30776 Mtetra
.15124 .30776 .15946 .31566 .17098 .31143 .16279 .30348 Mtetra
.662 .74 .908 r
.16279 .30348 .17098 .31143 .18255 .30723 .17439 .29921 Mtetra
.659 .739 .909 r
.17439 .29921 .18255 .30723 .19415 .30312 .18604 .29499 Mtetra
.655 .736 .909 r
.18604 .29499 .19415 .30312 .2058 .29921 .19773 .29089 Mtetra
.646 .729 .909 r
.19773 .29089 .2058 .29921 .21745 .29567 .20944 .28701 Mtetra
.632 .717 .908 r
.20944 .28701 .21745 .29567 .22911 .29274 .22117 .28353 Mtetra
.61 .696 .905 r
.22117 .28353 .22911 .29274 .24075 .29074 .23291 .28065 Mtetra
.581 .664 .895 r
.23291 .28065 .24075 .29074 .25235 .28992 .24464 .27856 Mtetra
.549 .622 .877 r
.24464 .27856 .25235 .28992 .26391 .29045 .25635 .27739 Mtetra
.521 .575 .85 r
.25635 .27739 .26391 .29045 .27548 .2922 .26808 .27712 Mtetra
.506 .534 .819 r
.26808 .27712 .27548 .2922 .28707 .29479 .27984 .27749 Mtetra
.507 .504 .788 r
.27984 .27749 .28707 .29479 .29877 .29756 .29167 .27808 Mtetra
.519 .487 .761 r
.29167 .27808 .29877 .29756 .3106 .29985 .30362 .27838 Mtetra
.537 .48 .74 r
.30362 .27838 .3106 .29985 .32261 .30117 .31571 .27799 Mtetra
.554 .478 .725 r
.31571 .27799 .32261 .30117 .33479 .30139 .32794 .27672 Mtetra
.567 .477 .712 r
.32794 .27672 .33479 .30139 .34711 .30077 .34031 .27464 Mtetra
.574 .473 .702 r
.34031 .27464 .34711 .30077 .35954 .2997 .35279 .272 Mtetra
.576 .467 .692 r
.35279 .272 .35954 .2997 .37207 .2985 .36535 .26903 Mtetra
.577 .459 .683 r
.36535 .26903 .37207 .2985 .38469 .2972 .378 .26581 Mtetra
.578 .453 .673 r
.378 .26581 .38469 .2972 .39741 .29549 .39074 .26223 Mtetra
.583 .449 .664 r
.39074 .26223 .39741 .29549 .41025 .29285 .40357 .25804 Mtetra
.59 .449 .658 r
.40357 .25804 .41025 .29285 .42321 .28873 .4165 .25295 Mtetra
.6 .453 .654 r
.4165 .25295 .42321 .28873 .4363 .28272 .42952 .24676 Mtetra
.61 .459 .652 r
.42952 .24676 .4363 .28272 .44949 .27473 .44262 .23943 Mtetra
.621 .469 .654 r
.44262 .23943 .44949 .27473 .46274 .26494 .45579 .23113 Mtetra
.631 .48 .659 r
.45579 .23113 .46274 .26494 .47604 .25381 .469 .22212 Mtetra
.64 .493 .667 r
.469 .22212 .47604 .25381 .48936 .24194 .48224 .21279 Mtetra
.648 .508 .678 r
.48224 .21279 .48936 .24194 .50268 .22992 .4955 .20348 Mtetra
.655 .524 .693 r
.4955 .20348 .50268 .22992 .516 .21823 .50879 .19445 Mtetra
.66 .543 .71 r
.50879 .19445 .516 .21823 .52933 .20715 .52211 .18586 Mtetra
.665 .563 .73 r
.52211 .18586 .52933 .20715 .54267 .19677 .53546 .17775 Mtetra
.671 .585 .751 r
.53546 .17775 .54267 .19677 .55604 .18708 .54885 .17005 Mtetra
.676 .609 .773 r
.54885 .17005 .55604 .18708 .56943 .17798 .56229 .1627 Mtetra
.681 .633 .795 r
.56229 .1627 .56943 .17798 .58287 .16943 .57577 .15565 Mtetra
.684 .657 .818 r
.57577 .15565 .58287 .16943 .59635 .16142 .58931 .14889 Mtetra
.685 .68 .839 r
.58931 .14889 .59635 .16142 .60989 .15396 .60291 .14243 Mtetra
.683 .699 .859 r
.60291 .14243 .60989 .15396 .62349 .14706 .61658 .13627 Mtetra
.679 .714 .875 r
.61658 .13627 .62349 .14706 .63716 .14067 .63031 .13039 Mtetra
.675 .725 .887 r
.63031 .13039 .63716 .14067 .6509 .13471 .64411 .12474 Mtetra
.671 .732 .896 r
.64411 .12474 .6509 .13471 .66472 .12906 .65799 .11927 Mtetra
.668 .737 .901 r
.65799 .11927 .66472 .12906 .67862 .12361 .67193 .1139 Mtetra
.666 .739 .905 r
.67193 .1139 .67862 .12361 .69259 .11828 .68595 .10859 Mtetra
.665 .74 .906 r
.68595 .10859 .69259 .11828 .70663 .113 .70005 .1033 Mtetra
.664 .741 .907 r
.70005 .1033 .70663 .113 .72074 .10773 .71421 .098 Mtetra
.664 .741 .908 r
.71421 .098 .72074 .10773 .73493 .10246 .72844 .09269 Mtetra
.72844 .09269 .73493 .10246 .74919 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31269 Mtetra
.10852 .31269 .11689 .32054 .12829 .3163 .11995 .3084 Mtetra
.663 .741 .908 r
.11995 .3084 .12829 .3163 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30776 .14296 .29979 Mtetra
.14296 .29979 .15124 .30776 .16279 .30348 .15454 .29546 Mtetra
.662 .741 .908 r
.15454 .29546 .16279 .30348 .17439 .29921 .16617 .29114 Mtetra
.661 .74 .908 r
.16617 .29114 .17439 .29921 .18604 .29499 .17785 .28683 Mtetra
.658 .738 .908 r
.17785 .28683 .18604 .29499 .19773 .29089 .18958 .28259 Mtetra
.653 .733 .908 r
.18958 .28259 .19773 .29089 .20944 .28701 .20134 .27848 Mtetra
.644 .726 .908 r
.20134 .27848 .20944 .28701 .22117 .28353 .21314 .2746 Mtetra
.631 .712 .905 r
.21314 .2746 .22117 .28353 .23291 .28065 .22496 .27109 Mtetra
.613 .691 .899 r
.22496 .27109 .23291 .28065 .24464 .27856 .23679 .26808 Mtetra
.591 .662 .887 r
.23679 .26808 .24464 .27856 .25635 .27739 .24863 .26567 Mtetra
.571 .627 .868 r
.24863 .26567 .25635 .27739 .26808 .27712 .26049 .26386 Mtetra
.557 .591 .844 r
.26049 .26386 .26808 .27712 .27984 .27749 .27239 .2625 Mtetra
.553 .562 .817 r
.27239 .2625 .27984 .27749 .29167 .27808 .28435 .26132 Mtetra
.559 .541 .791 r
.28435 .26132 .29167 .27808 .30362 .27838 .29641 .25995 Mtetra
.569 .528 .77 r
.29641 .25995 .30362 .27838 .31571 .27799 .30858 .25809 Mtetra
.581 .521 .752 r
.30858 .25809 .31571 .27799 .32794 .27672 .32088 .25555 Mtetra
.592 .517 .739 r
.32088 .25555 .32794 .27672 .34031 .27464 .33329 .25233 Mtetra
.598 .512 .729 r
.33329 .25233 .34031 .27464 .35279 .272 .34581 .24858 Mtetra
.601 .507 .719 r
.34581 .24858 .35279 .272 .36535 .26903 .35841 .24445 Mtetra
.602 .5 .711 r
.35841 .24445 .36535 .26903 .378 .26581 .37108 .24008 Mtetra
.603 .494 .703 r
.37108 .24008 .378 .26581 .39074 .26223 .38383 .23545 Mtetra
.604 .49 .696 r
.38383 .23545 .39074 .26223 .40357 .25804 .39666 .23049 Mtetra
.609 .489 .691 r
.39666 .23049 .40357 .25804 .4165 .25295 .40956 .22505 Mtetra
.615 .491 .689 r
.40956 .22505 .4165 .25295 .42952 .24676 .42254 .21904 Mtetra
.622 .497 .689 r
.42254 .21904 .42952 .24676 .44262 .23943 .43558 .21247 Mtetra
.63 .506 .693 r
.43558 .21247 .44262 .23943 .45579 .23113 .44868 .20542 Mtetra
.638 .518 .7 r
.44868 .20542 .45579 .23113 .469 .22212 .46184 .19805 Mtetra
.645 .532 .711 r
.46184 .19805 .469 .22212 .48224 .21279 .47503 .19057 Mtetra
.652 .548 .724 r
.47503 .19057 .48224 .21279 .4955 .20348 .48827 .18316 Mtetra
.657 .566 .741 r
.48827 .18316 .4955 .20348 .50879 .19445 .50155 .17595 Mtetra
.661 .585 .759 r
.50155 .17595 .50879 .19445 .52211 .18586 .51487 .16903 Mtetra
.665 .606 .778 r
.51487 .16903 .52211 .18586 .53546 .17775 .52823 .16237 Mtetra
.669 .626 .798 r
.52823 .16237 .53546 .17775 .54885 .17005 .54165 .15593 Mtetra
.672 .647 .816 r
.54165 .15593 .54885 .17005 .56229 .1627 .55513 .14967 Mtetra
.675 .667 .834 r
.55513 .14967 .56229 .1627 .57577 .15565 .56866 .14353 Mtetra
.677 .685 .85 r
.56866 .14353 .57577 .15565 .58931 .14889 .58225 .13753 Mtetra
.677 .701 .865 r
.58225 .13753 .58931 .14889 .60291 .14243 .5959 .13166 Mtetra
.675 .714 .878 r
.5959 .13166 .60291 .14243 .61658 .13627 .60962 .12594 Mtetra
.673 .724 .888 r
.60962 .12594 .61658 .13627 .63031 .13039 .62341 .12035 Mtetra
.67 .731 .896 r
.62341 .12035 .63031 .13039 .64411 .12474 .63727 .11488 Mtetra
.668 .736 .901 r
.63727 .11488 .64411 .12474 .65799 .11927 .65119 .1095 Mtetra
.666 .738 .904 r
.65119 .1095 .65799 .11927 .67193 .1139 .66519 .10416 Mtetra
.665 .74 .906 r
.66519 .10416 .67193 .1139 .68595 .10859 .67926 .09884 Mtetra
.664 .741 .907 r
.67926 .09884 .68595 .10859 .70005 .1033 .6934 .09351 Mtetra
.6934 .09351 .70005 .1033 .71421 .098 .70762 .08818 Mtetra
.664 .741 .908 r
.70762 .08818 .71421 .098 .72844 .09269 .7219 .08282 Mtetra
.7219 .08282 .72844 .09269 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31269 .10008 .30476 Mtetra
.10008 .30476 .10852 .31269 .11995 .3084 .11153 .30045 Mtetra
.663 .741 .908 r
.11153 .30045 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29979 .1346 .29176 Mtetra
.1346 .29176 .14296 .29979 .15454 .29546 .14621 .28739 Mtetra
.14621 .28739 .15454 .29546 .16617 .29114 .15788 .28301 Mtetra
.662 .74 .908 r
.15788 .28301 .16617 .29114 .17785 .28683 .16959 .27864 Mtetra
.66 .739 .908 r
.16959 .27864 .17785 .28683 .18958 .28259 .18136 .27429 Mtetra
.657 .736 .908 r
.18136 .27429 .18958 .28259 .20134 .27848 .19317 .27001 Mtetra
.652 .732 .907 r
.19317 .27001 .20134 .27848 .21314 .2746 .20502 .26586 Mtetra
.644 .723 .906 r
.20502 .26586 .21314 .2746 .22496 .27109 .2169 .26192 Mtetra
.633 .709 .901 r
.2169 .26192 .22496 .27109 .23679 .26808 .22881 .25827 Mtetra
.62 .69 .894 r
.22881 .25827 .23679 .26808 .24863 .26567 .24075 .25499 Mtetra
.607 .666 .881 r
.24075 .25499 .24863 .26567 .26049 .26386 .25272 .25208 Mtetra
.596 .639 .864 r
.25272 .25208 .26049 .26386 .27239 .2625 .26473 .24947 Mtetra
.591 .614 .843 r
.26473 .24947 .27239 .2625 .28435 .26132 .27681 .24697 Mtetra
.593 .593 .822 r
.27681 .24697 .28435 .26132 .29641 .25995 .28896 .24435 Mtetra
.599 .579 .802 r
.28896 .24435 .29641 .25995 .30858 .25809 .30121 .24139 Mtetra
.607 .57 .786 r
.30121 .24139 .30858 .25809 .32088 .25555 .31357 .23794 Mtetra
.615 .564 .774 r
.31357 .23794 .32088 .25555 .33329 .25233 .32602 .23396 Mtetra
.621 .56 .764 r
.32602 .23396 .33329 .25233 .34581 .24858 .33857 .22954 Mtetra
.624 .555 .757 r
.33857 .22954 .34581 .24858 .35841 .24445 .3512 .2248 Mtetra
.625 .551 .75 r
.3512 .2248 .35841 .24445 .37108 .24008 .36389 .21987 Mtetra
.626 .546 .745 r
.36389 .21987 .37108 .24008 .38383 .23545 .37665 .21478 Mtetra
.626 .543 .741 r
.37665 .21478 .38383 .23545 .39666 .23049 .38948 .20953 Mtetra
.628 .543 .738 r
.38948 .20953 .39666 .23049 .40956 .22505 .40237 .20407 Mtetra
.632 .545 .738 r
.40237 .20407 .40956 .22505 .42254 .21904 .41532 .19837 Mtetra
.637 .55 .74 r
.41532 .19837 .42254 .21904 .43558 .21247 .42834 .19242 Mtetra
.643 .559 .746 r
.42834 .19242 .43558 .21247 .44868 .20542 .44141 .18627 Mtetra
.648 .571 .754 r
.44141 .18627 .44868 .20542 .46184 .19805 .45454 .17999 Mtetra
.653 .585 .766 r
.45454 .17999 .46184 .19805 .47503 .19057 .46772 .17369 Mtetra
.658 .601 .779 r
.46772 .17369 .47503 .19057 .48827 .18316 .48096 .16746 Mtetra
.661 .618 .795 r
.48096 .16746 .48827 .18316 .50155 .17595 .49424 .16135 Mtetra
.664 .635 .811 r
.49424 .16135 .50155 .17595 .51487 .16903 .50758 .15539 Mtetra
.666 .651 .826 r
.50758 .15539 .51487 .16903 .52823 .16237 .52097 .14957 Mtetra
.667 .667 .84 r
.52097 .14957 .52823 .16237 .54165 .15593 .53442 .14384 Mtetra
.669 .682 .853 r
.53442 .14384 .54165 .15593 .55513 .14967 .54793 .13816 Mtetra
.67 .695 .864 r
.54793 .13816 .55513 .14967 .56866 .14353 .56151 .13253 Mtetra
.671 .707 .875 r
.56151 .13253 .56866 .14353 .58225 .13753 .57515 .12693 Mtetra
.671 .717 .883 r
.57515 .12693 .58225 .13753 .5959 .13166 .58885 .12138 Mtetra
.67 .725 .891 r
.58885 .12138 .5959 .13166 .60962 .12594 .60262 .11589 Mtetra
.669 .731 .897 r
.60262 .11589 .60962 .12594 .62341 .12035 .61646 .11045 Mtetra
.667 .735 .901 r
.61646 .11045 .62341 .12035 .63727 .11488 .63036 .10506 Mtetra
.666 .738 .904 r
.63036 .10506 .63727 .11488 .65119 .1095 .64434 .0997 Mtetra
.665 .74 .906 r
.64434 .0997 .65119 .1095 .66519 .10416 .65839 .09436 Mtetra
.664 .741 .907 r
.65839 .09436 .66519 .10416 .67926 .09884 .67251 .08901 Mtetra
.67251 .08901 .67926 .09884 .6934 .09351 .6867 .08365 Mtetra
.664 .741 .908 r
.6867 .08365 .6934 .09351 .70762 .08818 .70096 .07827 Mtetra
.70096 .07827 .70762 .08818 .7219 .08282 .71529 .07287 Mtetra
.71529 .07287 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30045 .10305 .29242 Mtetra
.10305 .29242 .11153 .30045 .12304 .29611 .11459 .28805 Mtetra
.663 .741 .908 r
.11459 .28805 .12304 .29611 .1346 .29176 .12618 .28365 Mtetra
.12618 .28365 .1346 .29176 .14621 .28739 .13782 .27925 Mtetra
.13782 .27925 .14621 .28739 .15788 .28301 .14952 .27482 Mtetra
.14952 .27482 .15788 .28301 .16959 .27864 .16126 .27039 Mtetra
.662 .74 .908 r
.16126 .27039 .16959 .27864 .18136 .27429 .17306 .26597 Mtetra
.66 .738 .908 r
.17306 .26597 .18136 .27429 .19317 .27001 .18491 .26157 Mtetra
.657 .735 .907 r
.18491 .26157 .19317 .27001 .20502 .26586 .1968 .25723 Mtetra
.653 .73 .906 r
.1968 .25723 .20502 .26586 .2169 .26192 .20874 .25301 Mtetra
.647 .722 .903 r
.20874 .25301 .2169 .26192 .22881 .25827 .22072 .24894 Mtetra
.639 .71 .899 r
.22072 .24894 .22881 .25827 .24075 .25499 .23274 .24508 Mtetra
.63 .694 .891 r
.23274 .24508 .24075 .25499 .25272 .25208 .24479 .24144 Mtetra
.623 .676 .879 r
.24479 .24144 .25272 .25208 .26473 .24947 .2569 .23797 Mtetra
.619 .657 .865 r
.2569 .23797 .26473 .24947 .27681 .24697 .26906 .23457 Mtetra
.619 .64 .849 r
.26906 .23457 .27681 .24697 .28896 .24435 .28129 .23109 Mtetra
.622 .627 .834 r
.28129 .23109 .28896 .24435 .30121 .24139 .29361 .22738 Mtetra
.628 .618 .821 r
.29361 .22738 .30121 .24139 .31357 .23794 .30601 .22333 Mtetra
.634 .613 .811 r
.30601 .22333 .31357 .23794 .32602 .23396 .31851 .21891 Mtetra
.64 .61 .804 r
.31851 .21891 .32602 .23396 .33857 .22954 .33108 .21416 Mtetra
.643 .607 .799 r
.33108 .21416 .33857 .22954 .3512 .2248 .34373 .20917 Mtetra
.644 .605 .795 r
.34373 .20917 .3512 .2248 .36389 .21987 .35644 .20404 Mtetra
.645 .604 .793 r
.35644 .20404 .36389 .21987 .37665 .21478 .36922 .19882 Mtetra
.645 .603 .792 r
.36922 .19882 .37665 .21478 .38948 .20953 .38205 .19354 Mtetra
.646 .603 .792 r
.38205 .19354 .38948 .20953 .40237 .20407 .39495 .18819 Mtetra
.648 .606 .793 r
.39495 .18819 .40237 .20407 .41532 .19837 .4079 .18276 Mtetra
.651 .612 .797 r
.4079 .18276 .41532 .19837 .42834 .19242 .42092 .17723 Mtetra
.654 .62 .803 r
.42092 .17723 .42834 .19242 .44141 .18627 .43399 .17164 Mtetra
.657 .63 .811 r
.43399 .17164 .44141 .18627 .45454 .17999 .44712 .166 Mtetra
.66 .642 .821 r
.44712 .166 .45454 .17999 .46772 .17369 .46031 .16037 Mtetra
.662 .654 .832 r
.46031 .16037 .46772 .17369 .48096 .16746 .47356 .15477 Mtetra
.664 .667 .843 r
.47356 .15477 .48096 .16746 .49424 .16135 .48686 .14924 Mtetra
.664 .679 .854 r
.48686 .14924 .49424 .16135 .50758 .15539 .50022 .14377 Mtetra
.665 .69 .863 r
.50022 .14377 .50758 .15539 .52097 .14957 .51365 .13836 Mtetra
.666 .699 .872 r
.51365 .13836 .52097 .14957 .53442 .14384 .52714 .13296 Mtetra
.666 .708 .879 r
.52714 .13296 .53442 .14384 .54793 .13816 .54069 .12757 Mtetra
.667 .716 .885 r
.54069 .12757 .54793 .13816 .56151 .13253 .55431 .12217 Mtetra
.668 .722 .89 r
.55431 .12217 .56151 .13253 .57515 .12693 .56799 .11677 Mtetra
.667 .728 .895 r
.56799 .11677 .57515 .12693 .58885 .12138 .58174 .11136 Mtetra
.667 .732 .899 r
.58174 .11136 .58885 .12138 .60262 .11589 .59556 .10597 Mtetra
.666 .736 .902 r
.59556 .10597 .60262 .11589 .61646 .11045 .60945 .10059 Mtetra
.665 .738 .904 r
.60945 .10059 .61646 .11045 .63036 .10506 .6234 .09523 Mtetra
.665 .74 .906 r
.6234 .09523 .63036 .10506 .64434 .0997 .63743 .08986 Mtetra
.664 .74 .907 r
.63743 .08986 .64434 .0997 .65839 .09436 .65152 .08449 Mtetra
.664 .741 .907 r
.65152 .08449 .65839 .09436 .67251 .08901 .66569 .07911 Mtetra
.664 .741 .908 r
.66569 .07911 .67251 .08901 .6867 .08365 .67993 .0737 Mtetra
.67993 .0737 .6867 .08365 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07287 .70863 .06282 Mtetra
.70863 .06282 .71529 .07287 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28805 .10606 .27992 Mtetra
.10606 .27992 .11459 .28805 .12618 .28365 .11768 .27549 Mtetra
.663 .741 .908 r
.11768 .27549 .12618 .28365 .13782 .27925 .12935 .27104 Mtetra
.12935 .27104 .13782 .27925 .14952 .27482 .14108 .26657 Mtetra
.14108 .26657 .14952 .27482 .16126 .27039 .15286 .26209 Mtetra
.663 .74 .908 r
.15286 .26209 .16126 .27039 .17306 .26597 .16469 .2576 Mtetra
.662 .74 .908 r
.16469 .2576 .17306 .26597 .18491 .26157 .17658 .25312 Mtetra
.66 .738 .907 r
.17658 .25312 .18491 .26157 .1968 .25723 .18851 .24866 Mtetra
.658 .735 .907 r
.18851 .24866 .1968 .25723 .20874 .25301 .2005 .24425 Mtetra
.654 .73 .905 r
.2005 .24425 .20874 .25301 .22072 .24894 .21253 .23991 Mtetra
.65 .723 .902 r
.21253 .23991 .22072 .24894 .23274 .24508 .2246 .23569 Mtetra
.645 .713 .897 r
.2246 .23569 .23274 .24508 .24479 .24144 .23673 .23157 Mtetra
.641 .702 .89 r
.23673 .23157 .24479 .24144 .2569 .23797 .2489 .22756 Mtetra
.638 .689 .881 r
.2489 .22756 .2569 .23797 .26906 .23457 .26113 .22357 Mtetra
.637 .677 .871 r
.26113 .22357 .26906 .23457 .28129 .23109 .27343 .21954 Mtetra
.639 .667 .861 r
.27343 .21954 .28129 .23109 .29361 .22738 .2858 .21536 Mtetra
.643 .66 .852 r
.2858 .21536 .29361 .22738 .30601 .22333 .29825 .21095 Mtetra
.648 .657 .845 r
.29825 .21095 .30601 .22333 .31851 .21891 .31078 .20629 Mtetra
.652 .655 .84 r
.31078 .20629 .31851 .21891 .33108 .21416 .32338 .20141 Mtetra
.655 .655 .837 r
.32338 .20141 .33108 .21416 .34373 .20917 .33605 .19636 Mtetra
.657 .655 .836 r
.33605 .19636 .34373 .20917 .35644 .20404 .34879 .1912 Mtetra
.658 .656 .837 r
.34879 .1912 .35644 .20404 .36922 .19882 .36158 .186 Mtetra
.658 .657 .838 r
.36158 .186 .36922 .19882 .38205 .19354 .37443 .18079 Mtetra
.658 .659 .839 r
.37443 .18079 .38205 .19354 .39495 .18819 .38734 .17555 Mtetra
.659 .662 .842 r
.38734 .17555 .39495 .18819 .4079 .18276 .40031 .1703 Mtetra
.66 .667 .846 r
.40031 .1703 .4079 .18276 .42092 .17723 .41334 .16502 Mtetra
.661 .673 .85 r
.41334 .16502 .42092 .17723 .43399 .17164 .42643 .15972 Mtetra
.662 .68 .856 r
.42643 .15972 .43399 .17164 .44712 .166 .43959 .15441 Mtetra
.663 .687 .862 r
.43959 .15441 .44712 .166 .46031 .16037 .4528 .1491 Mtetra
.664 .695 .869 r
.4528 .1491 .46031 .16037 .47356 .15477 .46607 .1438 Mtetra
.664 .703 .876 r
.46607 .1438 .47356 .15477 .48686 .14924 .47941 .13852 Mtetra
.664 .709 .881 r
.47941 .13852 .48686 .14924 .50022 .14377 .49281 .13326 Mtetra
.664 .715 .886 r
.49281 .13326 .50022 .14377 .51365 .13836 .50627 .12801 Mtetra
.664 .72 .89 r
.50627 .12801 .51365 .13836 .52714 .13296 .5198 .12274 Mtetra
.665 .724 .894 r
.5198 .12274 .52714 .13296 .54069 .12757 .53339 .11746 Mtetra
.665 .728 .896 r
.53339 .11746 .54069 .12757 .55431 .12217 .54705 .11214 Mtetra
.665 .731 .899 r
.54705 .11214 .55431 .12217 .56799 .11677 .56078 .10681 Mtetra
.665 .734 .901 r
.56078 .10681 .56799 .11677 .58174 .11136 .57458 .10146 Mtetra
.665 .737 .903 r
.57458 .10146 .58174 .11136 .59556 .10597 .58844 .09609 Mtetra
.665 .738 .905 r
.58844 .09609 .59556 .10597 .60945 .10059 .60237 .09072 Mtetra
.665 .74 .906 r
.60237 .09072 .60945 .10059 .6234 .09523 .61638 .08534 Mtetra
.664 .74 .907 r
.61638 .08534 .6234 .09523 .63743 .08986 .63045 .07995 Mtetra
.664 .741 .907 r
.63045 .07995 .63743 .08986 .65152 .08449 .6446 .07454 Mtetra
.664 .741 .908 r
.6446 .07454 .65152 .08449 .66569 .07911 .65881 .06911 Mtetra
.65881 .06911 .66569 .07911 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05268 Mtetra
.7019 .05268 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27549 .10911 .26725 Mtetra
.663 .741 .908 r
.10911 .26725 .11768 .27549 .12935 .27104 .12082 .26276 Mtetra
.12082 .26276 .12935 .27104 .14108 .26657 .13257 .25825 Mtetra
.13257 .25825 .14108 .26657 .15286 .26209 .14438 .25373 Mtetra
.14438 .25373 .15286 .26209 .16469 .2576 .15625 .24919 Mtetra
.663 .74 .908 r
.15625 .24919 .16469 .2576 .17658 .25312 .16817 .24464 Mtetra
.662 .74 .908 r
.16817 .24464 .17658 .25312 .18851 .24866 .18014 .24009 Mtetra
.661 .738 .907 r
.18014 .24009 .18851 .24866 .2005 .24425 .19216 .23556 Mtetra
.659 .735 .906 r
.19216 .23556 .2005 .24425 .21253 .23991 .20424 .23106 Mtetra
.656 .731 .905 r
.20424 .23106 .21253 .23991 .2246 .23569 .21636 .2266 Mtetra
.654 .726 .902 r
.21636 .2266 .2246 .23569 .23673 .23157 .22854 .2222 Mtetra
.651 .719 .898 r
.22854 .2222 .23673 .23157 .2489 .22756 .24077 .21784 Mtetra
.649 .711 .893 r
.24077 .21784 .2489 .22756 .26113 .22357 .25306 .2135 Mtetra
.649 .703 .886 r
.25306 .2135 .26113 .22357 .27343 .21954 .26541 .20912 Mtetra
.65 .697 .88 r
.26541 .20912 .27343 .21954 .2858 .21536 .27783 .20464 Mtetra
.653 .692 .874 r
.27783 .20464 .2858 .21536 .29825 .21095 .29032 .20003 Mtetra
.656 .69 .87 r
.29032 .20003 .29825 .21095 .31078 .20629 .30288 .19525 Mtetra
.659 .69 .867 r
.30288 .19525 .31078 .20629 .32338 .20141 .31551 .19032 Mtetra
.662 .691 .867 r
.31551 .19032 .32338 .20141 .33605 .19636 .32821 .18528 Mtetra
.663 .692 .867 r
.32821 .18528 .33605 .19636 .34879 .1912 .34097 .18017 Mtetra
.664 .694 .868 r
.34097 .18017 .34879 .1912 .36158 .186 .35378 .17502 Mtetra
.664 .696 .87 r
.35378 .17502 .36158 .186 .37443 .18079 .36666 .16987 Mtetra
.663 .699 .873 r
.36666 .16987 .37443 .18079 .38734 .17555 .3796 .16472 Mtetra
.663 .701 .875 r
.3796 .16472 .38734 .17555 .40031 .1703 .39259 .15956 Mtetra
.663 .704 .878 r
.39259 .15956 .40031 .1703 .41334 .16502 .40565 .1544 Mtetra
.664 .708 .881 r
.40565 .1544 .41334 .16502 .42643 .15972 .41877 .14923 Mtetra
.664 .712 .884 r
.41877 .14923 .42643 .15972 .43959 .15441 .43195 .14405 Mtetra
.664 .716 .887 r
.43195 .14405 .43959 .15441 .4528 .1491 .4452 .13886 Mtetra
.664 .72 .891 r
.4452 .13886 .4528 .1491 .46607 .1438 .45851 .13367 Mtetra
.664 .724 .894 r
.45851 .13367 .46607 .1438 .47941 .13852 .47188 .12847 Mtetra
.664 .727 .896 r
.47188 .12847 .47941 .13852 .49281 .13326 .48532 .12327 Mtetra
.663 .729 .898 r
.48532 .12327 .49281 .13326 .50627 .12801 .49882 .11805 Mtetra
.664 .731 .9 r
.49882 .11805 .50627 .12801 .5198 .12274 .51239 .11281 Mtetra
.664 .733 .901 r
.51239 .11281 .5198 .12274 .53339 .11746 .52603 .10755 Mtetra
.664 .735 .902 r
.52603 .10755 .53339 .11746 .54705 .11214 .53973 .10225 Mtetra
.664 .736 .903 r
.53973 .10225 .54705 .11214 .56078 .10681 .5535 .09692 Mtetra
.664 .738 .905 r
.5535 .09692 .56078 .10681 .57458 .10146 .56734 .09156 Mtetra
.664 .739 .905 r
.56734 .09156 .57458 .10146 .58844 .09609 .58126 .08619 Mtetra
.664 .74 .906 r
.58126 .08619 .58844 .09609 .60237 .09072 .59524 .0808 Mtetra
.664 .74 .907 r
.59524 .0808 .60237 .09072 .61638 .08534 .60929 .07539 Mtetra
.664 .741 .907 r
.60929 .07539 .61638 .08534 .63045 .07995 .62341 .06996 Mtetra
.664 .741 .908 r
.62341 .06996 .63045 .07995 .6446 .07454 .6376 .0645 Mtetra
.6376 .0645 .6446 .07454 .65881 .06911 .65187 .05903 Mtetra
.65187 .05903 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05268 .6951 .04244 Mtetra
.6951 .04244 .7019 .05268 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25895 Mtetra
.10047 .25895 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.663 .741 .908 r
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25373 .13583 .2453 Mtetra
.13583 .2453 .14438 .25373 .15625 .24919 .14773 .24072 Mtetra
.14773 .24072 .15625 .24919 .16817 .24464 .15968 .23612 Mtetra
.663 .74 .908 r
.15968 .23612 .16817 .24464 .18014 .24009 .17169 .2315 Mtetra
.662 .74 .907 r
.17169 .2315 .18014 .24009 .19216 .23556 .18375 .22689 Mtetra
.661 .738 .907 r
.18375 .22689 .19216 .23556 .20424 .23106 .19586 .22227 Mtetra
.66 .736 .906 r
.19586 .22227 .20424 .23106 .21636 .2266 .20803 .21768 Mtetra
.658 .733 .905 r
.20803 .21768 .21636 .2266 .22854 .2222 .22026 .2131 Mtetra
.657 .729 .903 r
.22026 .2131 .22854 .2222 .24077 .21784 .23253 .20853 Mtetra
.656 .725 .9 r
.23253 .20853 .24077 .21784 .25306 .2135 .24487 .20396 Mtetra
.656 .72 .896 r
.24487 .20396 .25306 .2135 .26541 .20912 .25727 .19937 Mtetra
.656 .716 .893 r
.25727 .19937 .26541 .20912 .27783 .20464 .26973 .19472 Mtetra
.658 .714 .889 r
.26973 .19472 .27783 .20464 .29032 .20003 .28226 .18997 Mtetra
.66 .713 .887 r
.28226 .18997 .29032 .20003 .30288 .19525 .29485 .18513 Mtetra
.662 .713 .886 r
.29485 .18513 .30288 .19525 .31551 .19032 .30751 .18018 Mtetra
.664 .714 .885 r
.30751 .18018 .31551 .19032 .32821 .18528 .32023 .17516 Mtetra
.665 .716 .886 r
.32023 .17516 .32821 .18528 .34097 .18017 .33302 .17009 Mtetra
.665 .718 .888 r
.33302 .17009 .34097 .18017 .35378 .17502 .34587 .16498 Mtetra
.665 .72 .89 r
.34587 .16498 .35378 .17502 .36666 .16987 .35878 .15987 Mtetra
.665 .722 .891 r
.35878 .15987 .36666 .16987 .3796 .16472 .37174 .15476 Mtetra
.664 .723 .893 r
.37174 .15476 .3796 .16472 .39259 .15956 .38477 .14964 Mtetra
.664 .725 .895 r
.38477 .14964 .39259 .15956 .40565 .1544 .39786 .14451 Mtetra
.664 .727 .896 r
.39786 .14451 .40565 .1544 .41877 .14923 .41102 .13938 Mtetra
.664 .729 .898 r
.41102 .13938 .41877 .14923 .43195 .14405 .42424 .13423 Mtetra
.664 .731 .9 r
.42424 .13423 .43195 .14405 .4452 .13886 .43752 .12906 Mtetra
.664 .733 .901 r
.43752 .12906 .4452 .13886 .45851 .13367 .45086 .12389 Mtetra
.663 .734 .902 r
.45086 .12389 .45851 .13367 .47188 .12847 .46428 .11869 Mtetra
.663 .735 .903 r
.46428 .11869 .47188 .12847 .48532 .12327 .47775 .11348 Mtetra
.663 .736 .904 r
.47775 .11348 .48532 .12327 .49882 .11805 .4913 .10824 Mtetra
.663 .737 .904 r
.4913 .10824 .49882 .11805 .51239 .11281 .50491 .10298 Mtetra
.664 .738 .905 r
.50491 .10298 .51239 .11281 .52603 .10755 .51859 .09769 Mtetra
.51859 .09769 .52603 .10755 .53973 .10225 .53234 .09237 Mtetra
.664 .739 .906 r
.53234 .09237 .53973 .10225 .5535 .09692 .54616 .08701 Mtetra
.664 .74 .906 r
.54616 .08701 .5535 .09692 .56734 .09156 .56005 .08163 Mtetra
.664 .74 .907 r
.56005 .08163 .56734 .09156 .58126 .08619 .574 .07623 Mtetra
.664 .741 .907 r
.574 .07623 .58126 .08619 .59524 .0808 .58803 .0708 Mtetra
.58803 .0708 .59524 .0808 .60929 .07539 .60213 .06535 Mtetra
.664 .741 .908 r
.60213 .06535 .60929 .07539 .62341 .06996 .6163 .05987 Mtetra
.6163 .05987 .62341 .06996 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05903 .64486 .04885 Mtetra
.64486 .04885 .65187 .05903 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25895 .09176 .25057 Mtetra
.09176 .25057 .10047 .25895 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .23681 Mtetra
.663 .741 .908 r
.12721 .23681 .13583 .2453 .14773 .24072 .13914 .23218 Mtetra
.13914 .23218 .14773 .24072 .15968 .23612 .15112 .22753 Mtetra
.15112 .22753 .15968 .23612 .17169 .2315 .16316 .22286 Mtetra
.663 .74 .908 r
.16316 .22286 .17169 .2315 .18375 .22689 .17526 .21819 Mtetra
.662 .74 .907 r
.17526 .21819 .18375 .22689 .19586 .22227 .18741 .2135 Mtetra
.662 .739 .907 r
.18741 .2135 .19586 .22227 .20803 .21768 .19962 .20881 Mtetra
.661 .737 .906 r
.19962 .20881 .20803 .21768 .22026 .2131 .21188 .20411 Mtetra
.66 .735 .905 r
.21188 .20411 .22026 .2131 .23253 .20853 .2242 .19942 Mtetra
.66 .733 .904 r
.2242 .19942 .23253 .20853 .24487 .20396 .23658 .19471 Mtetra
.659 .73 .902 r
.23658 .19471 .24487 .20396 .25727 .19937 .24902 .18998 Mtetra
.66 .728 .9 r
.24902 .18998 .25727 .19937 .26973 .19472 .26152 .18521 Mtetra
.661 .727 .898 r
.26152 .18521 .26973 .19472 .28226 .18997 .27408 .18038 Mtetra
.662 .726 .897 r
.27408 .18038 .28226 .18997 .29485 .18513 .28671 .17549 Mtetra
.663 .726 .896 r
.28671 .17549 .29485 .18513 .30751 .18018 .2994 .17052 Mtetra
.664 .727 .896 r
.2994 .17052 .30751 .18018 .32023 .17516 .31216 .16551 Mtetra
.665 .729 .897 r
.31216 .16551 .32023 .17516 .33302 .17009 .32497 .16045 Mtetra
.665 .73 .898 r
.32497 .16045 .33302 .17009 .34587 .16498 .33785 .15536 Mtetra
.665 .732 .899 r
.33785 .15536 .34587 .16498 .35878 .15987 .35079 .15026 Mtetra
.665 .733 .901 r
.35079 .15026 .35878 .15987 .37174 .15476 .3638 .14515 Mtetra
.664 .734 .902 r
.3638 .14515 .37174 .15476 .38477 .14964 .37686 .14003 Mtetra
.664 .735 .903 r
.37686 .14003 .38477 .14964 .39786 .14451 .38999 .1349 Mtetra
.664 .736 .903 r
.38999 .1349 .39786 .14451 .41102 .13938 .40318 .12975 Mtetra
.664 .737 .904 r
.40318 .12975 .41102 .13938 .42424 .13423 .41644 .12459 Mtetra
.664 .737 .905 r
.41644 .12459 .42424 .13423 .43752 .12906 .42976 .1194 Mtetra
.663 .738 .905 r
.42976 .1194 .43752 .12906 .45086 .12389 .44315 .1142 Mtetra
.663 .738 .906 r
.44315 .1142 .45086 .12389 .46428 .11869 .4566 .10897 Mtetra
.663 .739 .906 r
.4566 .10897 .46428 .11869 .47775 .11348 .47012 .10372 Mtetra
.47012 .10372 .47775 .11348 .4913 .10824 .48371 .09845 Mtetra
.48371 .09845 .4913 .10824 .50491 .10298 .49737 .09315 Mtetra
.664 .74 .907 r
.49737 .09315 .50491 .10298 .51859 .09769 .51109 .08781 Mtetra
.51109 .08781 .51859 .09769 .53234 .09237 .52489 .08245 Mtetra
.52489 .08245 .53234 .09237 .54616 .08701 .53875 .07706 Mtetra
.53875 .07706 .54616 .08701 .56005 .08163 .55268 .07164 Mtetra
.664 .741 .907 r
.55268 .07164 .56005 .08163 .574 .07623 .56669 .06619 Mtetra
.56669 .06619 .574 .07623 .58803 .0708 .58076 .06072 Mtetra
.664 .741 .908 r
.58076 .06072 .58803 .0708 .60213 .06535 .59491 .05523 Mtetra
.59491 .05523 .60213 .06535 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .23681 .11851 .22824 Mtetra
.11851 .22824 .12721 .23681 .13914 .23218 .13047 .22357 Mtetra
.663 .741 .908 r
.13047 .22357 .13914 .23218 .15112 .22753 .14249 .21888 Mtetra
.14249 .21888 .15112 .22753 .16316 .22286 .15456 .21416 Mtetra
.15456 .21416 .16316 .22286 .17526 .21819 .16669 .20943 Mtetra
.16669 .20943 .17526 .21819 .18741 .2135 .17887 .20469 Mtetra
.663 .74 .907 r
.17887 .20469 .18741 .2135 .19962 .20881 .19112 .19993 Mtetra
.662 .739 .907 r
.19112 .19993 .19962 .20881 .21188 .20411 .20342 .19516 Mtetra
.662 .738 .907 r
.20342 .19516 .21188 .20411 .2242 .19942 .21578 .19037 Mtetra
.662 .737 .906 r
.21578 .19037 .2242 .19942 .23658 .19471 .22819 .18557 Mtetra
.661 .736 .905 r
.22819 .18557 .23658 .19471 .24902 .18998 .24067 .18075 Mtetra
.662 .735 .904 r
.24067 .18075 .24902 .18998 .26152 .18521 .25321 .17589 Mtetra
.662 .734 .903 r
.25321 .17589 .26152 .18521 .27408 .18038 .26581 .171 Mtetra
.663 .733 .902 r
.26581 .171 .27408 .18038 .28671 .17549 .27847 .16606 Mtetra
.663 .734 .902 r
.27847 .16606 .28671 .17549 .2994 .17052 .2912 .16107 Mtetra
.664 .734 .902 r
.2912 .16107 .2994 .17052 .31216 .16551 .30399 .15604 Mtetra
.664 .735 .903 r
.30399 .15604 .31216 .16551 .32497 .16045 .31684 .15098 Mtetra
.664 .736 .903 r
.31684 .15098 .32497 .16045 .33785 .15536 .32975 .14589 Mtetra
.664 .737 .904 r
.32975 .14589 .33785 .15536 .35079 .15026 .34273 .14078 Mtetra
.664 .738 .905 r
.34273 .14078 .35079 .15026 .3638 .14515 .35577 .13565 Mtetra
.35577 .13565 .3638 .14515 .37686 .14003 .36887 .13051 Mtetra
.664 .739 .906 r
.36887 .13051 .37686 .14003 .38999 .1349 .38204 .12535 Mtetra
.38204 .12535 .38999 .1349 .40318 .12975 .39527 .12017 Mtetra
.664 .74 .907 r
.39527 .12017 .40318 .12975 .41644 .12459 .40857 .11497 Mtetra
.40857 .11497 .41644 .12459 .42976 .1194 .42193 .10974 Mtetra
.663 .74 .907 r
.42193 .10974 .42976 .1194 .44315 .1142 .43536 .1045 Mtetra
.43536 .1045 .44315 .1142 .4566 .10897 .44886 .09923 Mtetra
.44886 .09923 .4566 .10897 .47012 .10372 .46242 .09393 Mtetra
.46242 .09393 .47012 .10372 .48371 .09845 .47605 .08861 Mtetra
.47605 .08861 .48371 .09845 .49737 .09315 .48975 .08326 Mtetra
.664 .741 .907 r
.48975 .08326 .49737 .09315 .51109 .08781 .50352 .07788 Mtetra
.50352 .07788 .51109 .08781 .52489 .08245 .51736 .07247 Mtetra
.51736 .07247 .52489 .08245 .53875 .07706 .53127 .06703 Mtetra
.664 .741 .908 r
.53127 .06703 .53875 .07706 .55268 .07164 .54525 .06157 Mtetra
.54525 .06157 .55268 .07164 .56669 .06619 .5593 .05607 Mtetra
.5593 .05607 .56669 .06619 .58076 .06072 .57342 .05056 Mtetra
.57342 .05056 .58076 .06072 .59491 .05523 .58762 .04501 Mtetra
.58762 .04501 .59491 .05523 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.7064 .39316 m
.7322 .39477 L
.73614 .3968 L
.758 .41907 L
.76039 .4226 L
.77236 .4484 L
.77794 .4742 L
.7799 .5 L
.77904 .5258 L
.7751 .5516 L
.76669 .5774 L
.758 .59345 L
.75124 .6032 L
.7322 .62038 L
.7064 .62466 L
.6806 .6083 L
.67549 .6032 L
.66072 .5774 L
.6552 .5516 L
.6548 .54834 L
.65188 .5258 L
.65173 .5 L
.6548 .47489 L
.65488 .4742 L
.65999 .4484 L
.67203 .4226 L
.6806 .41212 L
.69816 .3968 L
.7064 .39316 L
s
.2936 .31574 m
.3194 .30366 L
.3452 .30687 L
.3595 .3194 L
.371 .34318 L
.37146 .3452 L
.37519 .371 L
.37383 .3968 L
.371 .41272 L
.369 .4226 L
.3606 .4484 L
.34677 .4742 L
.3452 .47662 L
.32856 .5 L
.3194 .50734 L
.2936 .52273 L
.2678 .52376 L
.242 .50109 L
.24139 .5 L
.23249 .4742 L
.23092 .4484 L
.23375 .4226 L
.2404 .3968 L
.242 .39175 L
.24969 .371 L
.26541 .3452 L
.2678 .34208 L
.28742 .3194 L
.2936 .31574 L
s
.4742 .22951 m
.5 .22021 L
.5258 .2175 L
.5516 .21807 L
.5774 .22204 L
.6032 .23033 L
.62533 .242 L
.629 .24267 L
.6548 .2673 L
.65508 .2678 L
.66684 .2936 L
.66162 .3194 L
.6548 .32798 L
.629 .34403 L
.62573 .3452 L
.6032 .35077 L
.5774 .35212 L
.5516 .34936 L
.53029 .3452 L
.5258 .34334 L
.5 .33327 L
.47967 .3194 L
.4742 .31477 L
.4563 .2936 L
.4498 .2678 L
.46131 .242 L
.4742 .22951 L
s
.5774 .65181 m
.6032 .64541 L
.629 .64381 L
.6548 .64839 L
.66952 .6548 L
.6806 .66547 L
.68867 .6806 L
.68685 .7064 L
.6806 .71902 L
.67086 .7322 L
.6548 .74872 L
.63755 .758 L
.629 .76246 L
.6032 .77277 L
.5774 .77797 L
.5516 .77868 L
.5258 .7739 L
.50549 .758 L
.5 .74885 L
.49609 .7322 L
.5 .71358 L
.50329 .7064 L
.5251 .6806 L
.5258 .67994 L
.5516 .66147 L
.56828 .6548 L
.5774 .65181 L
s
.2936 .59888 m
.3194 .58923 L
.3452 .5911 L
.371 .60023 L
.37781 .6032 L
.3968 .61539 L
.4132 .629 L
.4226 .6385 L
.43518 .6548 L
.4484 .6782 L
.44924 .6806 L
.45687 .7064 L
.4562 .7322 L
.4484 .74894 L
.43977 .758 L
.4226 .76694 L
.3968 .76846 L
.371 .76186 L
.3593 .758 L
.3452 .74916 L
.32278 .7322 L
.3194 .72899 L
.29952 .7064 L
.2936 .69964 L
.2844 .6806 L
.27597 .6548 L
.27532 .629 L
.28832 .6032 L
.2936 .59888 L
s
0 g
.03 w
.71539 .50841 Mdot
.30326 .41409 Mdot
.55845 .28475 Mdot
.59292 .71117 Mdot
.36623 .67901 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.71569 .45847 m
.72218 .46078 L
.73529 .47943 L
.73573 .48039 L
.7415 .5 L
.74121 .51961 L
.73555 .53922 L
.73529 .53986 L
.72541 .55882 L
.71569 .56632 L
.70147 .55882 L
.69608 .54925 L
.69171 .53922 L
.68777 .51961 L
.68867 .5 L
.69503 .48039 L
.69608 .47826 L
.70856 .46078 L
.71569 .45847 L
s
.30392 .37489 m
.32353 .37386 L
.32707 .38235 L
.32953 .40196 L
.3268 .42157 L
.32353 .43207 L
.31764 .44118 L
.30392 .45927 L
.30113 .46078 L
.28431 .46168 L
.28344 .46078 L
.27605 .44118 L
.27711 .42157 L
.28266 .40196 L
.28431 .39877 L
.29581 .38235 L
.30392 .37489 L
s
.53922 .26694 m
.55882 .26563 L
.57843 .27108 L
.59592 .28431 L
.58897 .30392 L
.57843 .3062 L
.55882 .30576 L
.55403 .30392 L
.53922 .2978 L
.52365 .28431 L
.53922 .26694 L
s
.69608 .43601 m
.71569 .42483 L
.73529 .4395 L
.73695 .44118 L
.74919 .46078 L
.75326 .48039 L
.7544 .5 L
.75426 .51961 L
.75264 .53922 L
.74813 .55882 L
.73857 .57843 L
.73529 .58328 L
.7249 .59804 L
.71569 .60647 L
.69608 .60392 L
.6926 .59804 L
.68553 .57843 L
.68089 .55882 L
.67679 .53922 L
.67647 .52186 L
.67639 .51961 L
.67647 .50765 L
.67661 .5 L
.67776 .48039 L
.68114 .46078 L
.69094 .44118 L
.69608 .43601 L
s
.32353 .34285 m
.3269 .34314 L
.34314 .35554 L
.3455 .36275 L
.34779 .38235 L
.346 .40196 L
.34314 .4155 L
.34218 .42157 L
.33586 .44118 L
.3254 .46078 L
.32353 .46374 L
.3122 .48039 L
.30392 .48974 L
.28431 .49991 L
.26471 .48247 L
.26369 .48039 L
.25863 .46078 L
.25846 .44118 L
.26135 .42157 L
.26471 .40642 L
.26613 .40196 L
.27479 .38235 L
.28431 .36897 L
.28958 .36275 L
.30392 .34974 L
.3204 .34314 L
.32353 .34285 L
s
.5 .26229 m
.51961 .25142 L
.53922 .24813 L
.55882 .24717 L
.57843 .25146 L
.59804 .26033 L
.60509 .26471 L
.61765 .27387 L
.62796 .28431 L
.63574 .30392 L
.61765 .32137 L
.60757 .32353 L
.59804 .32461 L
.57843 .3245 L
.56906 .32353 L
.55882 .32308 L
.53922 .3189 L
.51961 .30903 L
.51281 .30392 L
.5 .29216 L
.49518 .28431 L
.49781 .26471 L
.5 .26229 L
s
.32353 .62896 m
.34314 .62956 L
.35809 .63725 L
.36275 .6386 L
.38235 .65305 L
.38718 .65686 L
.40196 .66986 L
.40752 .67647 L
.42157 .69321 L
.42385 .69608 L
.43579 .71569 L
.42157 .73177 L
.40196 .73114 L
.38235 .72628 L
.36567 .71569 L
.36275 .71369 L
.34314 .69655 L
.34272 .69608 L
.32673 .67647 L
.32353 .6674 L
.3189 .65686 L
.3177 .63725 L
.32353 .62896 L
s
.69608 .3872 m
.71569 .38817 L
.73075 .40196 L
.73529 .40757 L
.74642 .42157 L
.75416 .44118 L
.7549 .44513 L
.75975 .46078 L
.7636 .48039 L
.7653 .5 L
.76507 .51961 L
.763 .53922 L
.75906 .55882 L
.7549 .57341 L
.75376 .57843 L
.74684 .59804 L
.73577 .61765 L
.73529 .61838 L
.72605 .63725 L
.71569 .64556 L
.70399 .65686 L
.69608 .66308 L
.67647 .67347 L
.66251 .65686 L
.66551 .63725 L
.67019 .61765 L
.67069 .59804 L
.66933 .57843 L
.66734 .55882 L
.66563 .53922 L
.66483 .51961 L
.6653 .5 L
.66723 .48039 L
.67064 .46078 L
.67542 .44118 L
.67647 .43792 L
.68109 .42157 L
.68776 .40196 L
.69608 .3872 L
s
.32353 .31942 m
.34314 .31869 L
.35153 .32353 L
.36194 .34314 L
.36263 .36275 L
.36157 .38235 L
.3587 .40196 L
.35404 .42157 L
.34753 .44118 L
.34314 .45214 L
.3397 .46078 L
.32992 .48039 L
.32353 .49121 L
.32117 .5 L
.30699 .51961 L
.30392 .52207 L
.28693 .53922 L
.28431 .53993 L
.27751 .53922 L
.26471 .5292 L
.2585 .51961 L
.248 .5 L
.24611 .48039 L
.24525 .46078 L
.24614 .44118 L
.24914 .42157 L
.25447 .40196 L
.26242 .38235 L
.26471 .37768 L
.27268 .36275 L
.28431 .34776 L
.2861 .34314 L
.30392 .32943 L
.3137 .32353 L
.32353 .31942 L
s
.5 .24107 m
.51961 .23621 L
.53922 .23489 L
.55882 .23629 L
.57843 .24027 L
.59384 .2451 L
.59804 .24655 L
.61765 .25566 L
.63103 .26471 L
.63725 .26663 L
.65321 .28431 L
.65686 .2887 L
.66701 .30392 L
.67347 .32353 L
.65686 .34163 L
.63725 .34226 L
.61765 .34101 L
.59804 .33973 L
.57843 .33783 L
.55882 .33474 L
.53922 .32991 L
.52124 .32353 L
.51961 .32303 L
.5 .31429 L
.48616 .30392 L
.48039 .29904 L
.46901 .28431 L
.46894 .26471 L
.48039 .2516 L
.49087 .2451 L
.5 .24107 L
s
.51961 .22447 m
.53922 .22392 L
.55856 .22549 L
.55882 .22552 L
.57843 .22909 L
.59804 .23483 L
.61765 .2429 L
.62217 .2451 L
.63725 .25303 L
.65419 .26471 L
.65686 .26632 L
.67647 .28394 L
.67682 .28431 L
.69373 .30392 L
.69608 .30662 L
.70706 .32353 L
.71569 .33823 L
.71876 .34314 L
.7317 .36275 L
.73529 .37166 L
.74192 .38235 L
.7522 .40196 L
.7549 .40969 L
.75992 .42157 L
.76652 .44118 L
.77115 .46078 L
.77403 .48039 L
.77451 .48543 L
.77536 .5 L
.77513 .51961 L
.77451 .52862 L
.77343 .53922 L
.77033 .55882 L
.76579 .57843 L
.75975 .59804 L
.7549 .61102 L
.75254 .61765 L
.74336 .63725 L
.73529 .65059 L
.73181 .65686 L
.71569 .67592 L
.71528 .67647 L
.69608 .69325 L
.69236 .69608 L
.67647 .70635 L
.65789 .71569 L
.65686 .7162 L
.63725 .72623 L
.61765 .73238 L
.60965 .73529 L
Mistroke
.59804 .73906 L
.57843 .74568 L
.55882 .74656 L
.53922 .74896 L
.51961 .75122 L
.5 .7542 L
.49605 .7549 L
.48039 .75845 L
.46078 .76115 L
.44118 .76123 L
.42157 .75881 L
.40567 .7549 L
.40196 .75389 L
.38235 .74616 L
.3632 .73529 L
.36275 .73496 L
.34314 .72033 L
.33793 .71569 L
.32353 .70083 L
.31962 .69608 L
.30555 .67647 L
.30392 .67441 L
.29445 .65686 L
.28559 .63725 L
.28431 .63399 L
.27759 .61765 L
.26736 .59804 L
.26471 .58602 L
.26044 .57843 L
.24905 .55882 L
.2451 .54185 L
.24411 .53922 L
.23817 .51961 L
.23458 .5 L
.23295 .48039 L
.23305 .46078 L
.23481 .44118 L
.23828 .42157 L
.24353 .40196 L
.2451 .39708 L
.25063 .38235 L
.2602 .36275 L
.26471 .35507 L
.27236 .34314 L
.28431 .32873 L
.28836 .32353 L
.30392 .3106 L
.30982 .30392 L
.32353 .29858 L
.34314 .29199 L
Mistroke
.36275 .29121 L
.38159 .30392 L
.38235 .30766 L
.38267 .32353 L
.38235 .32729 L
.38039 .34314 L
.37745 .36275 L
.3741 .38235 L
.37007 .40196 L
.36504 .42157 L
.36275 .42941 L
.3589 .44118 L
.35146 .46078 L
.34314 .48001 L
.34298 .48039 L
.33456 .5 L
.32645 .51961 L
.32353 .52804 L
.32175 .53922 L
.32173 .55882 L
.32353 .57626 L
.32472 .57843 L
.34234 .59804 L
.34314 .60041 L
.36275 .61601 L
.36503 .61765 L
.38235 .63092 L
.39033 .63725 L
.40196 .64711 L
.41273 .65686 L
.42157 .66467 L
.43411 .67647 L
.44118 .68147 L
.45923 .69608 L
.46078 .69703 L
.48039 .70673 L
.5 .71072 L
.51961 .709 L
.53922 .70284 L
.55517 .69608 L
.55882 .69394 L
.57843 .68113 L
.5958 .67647 L
.59804 .67515 L
.61765 .66191 L
.62599 .65686 L
.63725 .64529 L
.64315 .63725 L
.65213 .61765 L
.656 .59804 L
Mistroke
.65682 .57843 L
.65617 .55882 L
.65522 .53922 L
.65474 .51961 L
.65521 .5 L
.65675 .48039 L
.65686 .47925 L
.65911 .46078 L
.66192 .44118 L
.66427 .42157 L
.6645 .40196 L
.65931 .38235 L
.65686 .3774 L
.63761 .36275 L
.63725 .36258 L
.61765 .35626 L
.59804 .35244 L
.57843 .34927 L
.55882 .34572 L
.54699 .34314 L
.53922 .34119 L
.51961 .33522 L
.5 .3274 L
.49186 .32353 L
.48039 .31858 L
.46078 .30711 L
.45884 .30392 L
.44118 .29267 L
.43407 .28431 L
.43629 .26471 L
.44118 .25785 L
.45613 .2451 L
.46078 .24175 L
.48039 .23226 L
.5 .22718 L
.51069 .22549 L
.51961 .22447 L
Mfstroke
.42157 .32202 m
.44118 .32075 L
.45498 .32353 L
.46078 .32537 L
.48039 .33261 L
.5 .33995 L
.50925 .34314 L
.51961 .34653 L
.53922 .3521 L
.55882 .35669 L
.57843 .36075 L
.58779 .36275 L
.59804 .36516 L
.61765 .37168 L
.63434 .38235 L
.63725 .38489 L
.64681 .40196 L
.65013 .42157 L
.64978 .44118 L
.64808 .46078 L
.6463 .48039 L
.64506 .5 L
.6446 .51961 L
.64478 .53922 L
.64512 .55882 L
.64469 .57843 L
.64215 .59804 L
.63725 .61444 L
.63559 .61765 L
.6219 .63725 L
.61765 .64137 L
.59804 .65575 L
.59618 .65686 L
.57843 .66582 L
.55882 .67459 L
.55444 .67647 L
.53922 .68108 L
.51961 .68594 L
.5 .68728 L
.48039 .68383 L
.4619 .67647 L
.46078 .67549 L
.44118 .66189 L
.43476 .65686 L
.42157 .64549 L
.41209 .63725 L
.40196 .62849 L
.38925 .61765 L
.38235 .61186 L
.36688 .59804 L
Mistroke
.36275 .59419 L
.34977 .57843 L
.34314 .56623 L
.34078 .55882 L
.33891 .53922 L
.34186 .51961 L
.34314 .51277 L
.34788 .5 L
.35532 .48039 L
.36275 .46111 L
.36287 .46078 L
.36988 .44118 L
.37607 .42157 L
.3815 .40196 L
.38235 .39874 L
.38654 .38235 L
.39207 .36275 L
.39989 .34314 L
.40196 .33972 L
.41722 .32353 L
.42157 .32202 L
Mfstroke
.46078 .22421 m
.48039 .2185 L
.5 .21482 L
.51961 .21304 L
.53922 .21307 L
.55882 .21486 L
.57843 .21841 L
.59804 .22371 L
.60354 .22549 L
.61765 .23076 L
.63725 .23978 L
.64711 .2451 L
.65686 .25073 L
.67647 .26431 L
.67698 .26471 L
.69608 .28083 L
.69958 .28431 L
.71569 .30238 L
.71687 .30392 L
.7303 .32353 L
.73529 .33227 L
.74119 .34314 L
.75067 .36275 L
.7549 .37283 L
.75894 .38235 L
.76654 .40196 L
.77287 .42157 L
.77451 .42741 L
.77802 .44118 L
.78188 .46078 L
.78435 .48039 L
.78546 .5 L
.78522 .51961 L
.7837 .53922 L
.78096 .55882 L
.77707 .57843 L
.77451 .58905 L
.77212 .59804 L
.766 .61765 L
.75836 .63725 L
.7549 .64481 L
.74887 .65686 L
.73606 .67647 L
.73529 .67746 L
.71848 .69608 L
.71569 .69861 L
.69608 .71364 L
.6929 .71569 L
.67647 .72528 L
.65686 .73474 L
Mistroke
.65554 .73529 L
.63725 .74313 L
.61765 .75048 L
.60321 .7549 L
.59804 .75648 L
.57843 .76203 L
.55882 .76682 L
.53922 .77095 L
.51961 .77419 L
.51725 .77451 L
.5 .77742 L
.48039 .77992 L
.46078 .78093 L
.44118 .77997 L
.42157 .77675 L
.4117 .77451 L
.40196 .7712 L
.38235 .76306 L
.36698 .7549 L
.36275 .75227 L
.34314 .73854 L
.33906 .73529 L
.32353 .7214 L
.31789 .71569 L
.30392 .69982 L
.30098 .69608 L
.28695 .67647 L
.28431 .67248 L
.27498 .65686 L
.26471 .63769 L
.26449 .63725 L
.25478 .61765 L
.24602 .59804 L
.2451 .59568 L
.23808 .57843 L
.23146 .55882 L
.22664 .53922 L
.22549 .53337 L
.22325 .51961 L
.2213 .5 L
.22078 .48039 L
.22164 .46078 L
.22387 .44118 L
.22549 .4307 L
.22749 .42157 L
.23266 .40196 L
.2395 .38235 L
.2451 .36919 L
.24817 .36275 L
.25912 .34314 L
Mistroke
.26471 .33464 L
.2727 .32353 L
.28431 .31016 L
.29003 .30392 L
.30392 .29197 L
.31356 .28431 L
.32353 .27852 L
.34314 .26888 L
.35413 .26471 L
.36275 .26205 L
.38235 .2561 L
.40196 .24829 L
.4121 .2451 L
.42157 .24036 L
.44118 .23107 L
.45716 .22549 L
.46078 .22421 L
Mfstroke
.44118 .34036 m
.46078 .34146 L
.46878 .34314 L
.48039 .34623 L
.5 .3522 L
.51961 .35808 L
.53687 .36275 L
.53922 .36333 L
.55882 .36797 L
.57843 .37271 L
.59804 .37889 L
.60585 .38235 L
.61765 .38939 L
.62859 .40196 L
.63573 .42157 L
.63725 .43726 L
.63734 .44118 L
.63725 .44907 L
.63676 .46078 L
.63559 .48039 L
.63463 .5 L
.63418 .51961 L
.63411 .53922 L
.63388 .55882 L
.63246 .57843 L
.6282 .59804 L
.61853 .61765 L
.61765 .61892 L
.59919 .63725 L
.59804 .63809 L
.57843 .64989 L
.5634 .65686 L
.55882 .65864 L
.53922 .66534 L
.51961 .66965 L
.5 .67041 L
.48039 .66653 L
.46078 .65753 L
.4596 .65686 L
.44118 .64389 L
.4329 .63725 L
.42157 .62759 L
.41015 .61765 L
.40196 .61046 L
.3884 .59804 L
.38235 .59229 L
.37025 .57843 L
.36275 .56829 L
.35906 .55882 L
.35497 .53922 L
Mistroke
.35627 .51961 L
.36101 .5 L
.36275 .49393 L
.36748 .48039 L
.37449 .46078 L
.38128 .44118 L
.38235 .43794 L
.38748 .42157 L
.39348 .40196 L
.40013 .38235 L
.40196 .37774 L
.4086 .36275 L
.42157 .34808 L
.43005 .34314 L
.44118 .34036 L
Mfstroke
.48039 .2052 m
.5 .20272 L
.51961 .20167 L
.53922 .20209 L
.55882 .204 L
.57156 .20588 L
.57843 .20741 L
.59804 .21238 L
.61765 .21887 L
.63414 .22549 L
.63725 .22687 L
.65686 .2365 L
.67195 .2451 L
.67647 .24786 L
.69608 .26146 L
.70022 .26471 L
.71569 .27824 L
.72163 .28431 L
.73529 .30062 L
.73767 .30392 L
.7498 .32353 L
.7549 .33362 L
.75929 .34314 L
.7672 .36275 L
.77402 .38235 L
.77451 .38387 L
.78008 .40196 L
.78532 .42157 L
.78962 .44118 L
.79285 .46078 L
.79412 .46977 L
.79492 .48039 L
.79583 .5 L
.7956 .51961 L
.79427 .53922 L
.79412 .54098 L
.79187 .55882 L
.7885 .57843 L
.78419 .59804 L
.7789 .61765 L
.77451 .63136 L
.77242 .63725 L
.7642 .65686 L
.7549 .67413 L
.75347 .67647 L
.73896 .69608 L
.73529 .70015 L
.71855 .71569 L
.71569 .71793 L
.69608 .73114 L
Mistroke
.68874 .73529 L
.67647 .74162 L
.65686 .7505 L
.64597 .7549 L
.63725 .75826 L
.61765 .7653 L
.59804 .77161 L
.58811 .77451 L
.57843 .77723 L
.55882 .7824 L
.53922 .78711 L
.51961 .79128 L
.5037 .79412 L
.5 .79466 L
.48039 .79698 L
.46078 .79768 L
.44118 .7964 L
.42406 .79412 L
.42157 .79294 L
.40196 .78718 L
.38235 .77905 L
.37321 .77451 L
.36275 .76855 L
.34314 .75549 L
.34233 .7549 L
.32353 .73965 L
.31873 .73529 L
.30392 .72054 L
.29949 .71569 L
.28431 .69747 L
.28324 .69608 L
.26914 .67647 L
.26471 .66978 L
.25666 .65686 L
.2455 .63725 L
.2451 .63651 L
.23559 .61765 L
.22713 .59804 L
.22549 .5937 L
.22026 .57843 L
.21501 .55882 L
.21135 .53922 L
.20914 .51961 L
.20822 .5 L
.20851 .48039 L
.20996 .46078 L
.21259 .44118 L
.21644 .42157 L
.22156 .40196 L
.22549 .38946 L
Mistroke
.22807 .38235 L
.23623 .36275 L
.2451 .34503 L
.24614 .34314 L
.25819 .32353 L
.26471 .31434 L
.27277 .30392 L
.28431 .29097 L
.29075 .28431 L
.30392 .27267 L
.314 .26471 L
.32353 .25837 L
.34314 .24738 L
.34796 .2451 L
.36275 .23891 L
.38235 .23197 L
.40196 .2258 L
.40298 .22549 L
.42157 .21966 L
.44118 .21389 L
.46078 .20898 L
.47624 .20588 L
.48039 .2052 L
Mfstroke
.44118 .36009 m
.46078 .35763 L
.48039 .36041 L
.49278 .36275 L
.5 .36517 L
.51961 .37034 L
.53922 .37541 L
.55882 .38048 L
.56558 .38235 L
.57843 .38618 L
.59804 .39502 L
.60704 .40196 L
.61765 .41574 L
.6198 .42157 L
.62391 .44118 L
.62457 .46078 L
.62402 .48039 L
.62331 .5 L
.62284 .51961 L
.6225 .53922 L
.62166 .55882 L
.61905 .57843 L
.61765 .58508 L
.61277 .59804 L
.59901 .61765 L
.59804 .61864 L
.57843 .63345 L
.57155 .63725 L
.55882 .64307 L
.53922 .6499 L
.51961 .65385 L
.5 .65408 L
.48039 .64956 L
.46078 .63979 L
.45671 .63725 L
.44118 .62569 L
.43142 .61765 L
.42157 .60908 L
.40946 .59804 L
.40196 .59093 L
.39045 .57843 L
.38235 .56838 L
.37734 .55882 L
.37127 .53922 L
.37102 .51961 L
.37466 .5 L
.38046 .48039 L
.38235 .47451 L
.38695 .46078 L
.39355 .44118 L
Mistroke
.40019 .42157 L
.40196 .41649 L
.40703 .40196 L
.41621 .38235 L
.42157 .37478 L
.4353 .36275 L
.44118 .36009 L
Mfstroke
.42157 .20149 m
.44118 .19751 L
.46078 .19413 L
.48039 .19154 L
.5 .18994 L
.51961 .18947 L
.53922 .19024 L
.55882 .19231 L
.57843 .19569 L
.59804 .20035 L
.61662 .20588 L
.61765 .20623 L
.63725 .21356 L
.65686 .22212 L
.6639 .22549 L
.67647 .23205 L
.69608 .24366 L
.69831 .2451 L
.71569 .25758 L
.72423 .26471 L
.73529 .27525 L
.74343 .28431 L
.7549 .29968 L
.75761 .30392 L
.76824 .32353 L
.77451 .33803 L
.77647 .34314 L
.78315 .36275 L
.78889 .38235 L
.79392 .40196 L
.79412 .40277 L
.79821 .42157 L
.80177 .44118 L
.80448 .46078 L
.80626 .48039 L
.80703 .5 L
.80679 .51961 L
.80558 .53922 L
.80348 .55882 L
.80055 .57843 L
.79686 .59804 L
.79412 .61044 L
.7923 .61765 L
.78659 .63725 L
.77942 .65686 L
.77451 .66795 L
.77016 .67647 L
.75782 .69608 L
.7549 .69997 L
.741 .71569 L
Mistroke
.73529 .72107 L
.7172 .73529 L
.71569 .73632 L
.69608 .74802 L
.68234 .7549 L
.67647 .75757 L
.65686 .7658 L
.63725 .77324 L
.63373 .77451 L
.61765 .78003 L
.59804 .78639 L
.57843 .79235 L
.57234 .79412 L
.55882 .79787 L
.53922 .803 L
.51961 .80757 L
.5 .81121 L
.48039 .81349 L
.47696 .81373 L
.46078 .81406 L
.45257 .81373 L
.44118 .81266 L
.42157 .80911 L
.40196 .80336 L
.38235 .79542 L
.37954 .79412 L
.36275 .7852 L
.3457 .77451 L
.34314 .77273 L
.32353 .75782 L
.32003 .7549 L
.30392 .74028 L
.29888 .73529 L
.28431 .71977 L
.28076 .71569 L
.26485 .69608 L
.26471 .69589 L
.25067 .67647 L
.2451 .66819 L
.23794 .65686 L
.22666 .63725 L
.22549 .63505 L
.21706 .61765 L
.20921 .59804 L
.20588 .58799 L
.2032 .57843 L
.19892 .55882 L
.19618 .53922 L
.19481 .51961 L
.19464 .5 L
Mistroke
.19556 .48039 L
.19751 .46078 L
.20045 .44118 L
.20438 .42157 L
.20588 .4151 L
.20949 .40196 L
.21588 .38235 L
.22351 .36275 L
.22549 .35813 L
.23271 .34314 L
.24356 .32353 L
.2451 .32098 L
.25639 .30392 L
.26471 .29273 L
.27149 .28431 L
.28431 .27012 L
.28964 .26471 L
.30392 .25187 L
.31241 .2451 L
.32353 .23738 L
.34314 .22617 L
.34451 .22549 L
.36275 .21769 L
.38235 .21118 L
.40196 .20598 L
.40234 .20588 L
.42157 .20149 L
Mfstroke
.46078 .37584 m
.48039 .3763 L
.5 .37991 L
.51102 .38235 L
.51961 .38451 L
.53922 .38941 L
.55882 .3951 L
.57603 .40196 L
.57843 .40304 L
.59804 .41858 L
.60004 .42157 L
.60807 .44118 L
.61043 .46078 L
.61069 .48039 L
.61032 .5 L
.60986 .51961 L
.6092 .53922 L
.60758 .55882 L
.60338 .57843 L
.59804 .59174 L
.59395 .59804 L
.57843 .61414 L
.57352 .61765 L
.55882 .62583 L
.53922 .63312 L
.51961 .63683 L
.5 .63647 L
.48039 .6311 L
.46078 .6203 L
.45685 .61765 L
.44118 .60539 L
.4327 .59804 L
.42157 .58775 L
.41259 .57843 L
.40196 .56591 L
.39758 .55882 L
.38938 .53922 L
.38751 .51961 L
.39 .5 L
.39508 .48039 L
.4014 .46078 L
.40196 .4591 L
.40787 .44118 L
.41518 .42157 L
.42157 .4077 L
.42416 .40196 L
.44118 .38295 L
.4421 .38235 L
.46078 .37584 L
s
.40196 .18602 m
.42157 .1828 L
.44118 .18017 L
.46078 .17803 L
.48039 .17647 L
.5 .17564 L
.51961 .17572 L
.53922 .1768 L
.55882 .17896 L
.57843 .1822 L
.59732 .18627 L
.59804 .18646 L
.61765 .1921 L
.63725 .19876 L
.65584 .20588 L
.65686 .20632 L
.67647 .21519 L
.69608 .22519 L
.69664 .22549 L
.71569 .23705 L
.72718 .2451 L
.73529 .2515 L
.74965 .26471 L
.7549 .27031 L
.76613 .28431 L
.77451 .29706 L
.77835 .30392 L
.78752 .32353 L
.79412 .34159 L
.79461 .34314 L
.80018 .36275 L
.80493 .38235 L
.80909 .40196 L
.81272 .42157 L
.81373 .42756 L
.81563 .44118 L
.81782 .46078 L
.81926 .48039 L
.81987 .5 L
.81964 .51961 L
.81861 .53922 L
.81684 .55882 L
.81441 .57843 L
.81373 .5832 L
.81117 .59804 L
.80712 .61765 L
.80214 .63725 L
.79593 .65686 L
.79412 .66184 L
.78782 .67647 L
Mistroke
.77724 .69608 L
.77451 .7004 L
.76317 .71569 L
.7549 .72496 L
.74406 .73529 L
.73529 .74243 L
.71693 .7549 L
.71569 .75563 L
.69608 .76599 L
.67704 .77451 L
.67647 .77474 L
.65686 .7823 L
.63725 .78942 L
.62378 .79412 L
.61765 .79613 L
.59804 .80252 L
.57843 .8088 L
.56252 .81373 L
.55882 .81479 L
.53922 .82028 L
.51961 .82516 L
.5 .82895 L
.48039 .83125 L
.46078 .83176 L
.44118 .83028 L
.42157 .82675 L
.40196 .82112 L
.38286 .81373 L
.38235 .81349 L
.36275 .8036 L
.3468 .79412 L
.34314 .7917 L
.32353 .77759 L
.31959 .77451 L
.30392 .76124 L
.29698 .7549 L
.28431 .74253 L
.27738 .73529 L
.26471 .72128 L
.25995 .71569 L
.2451 .69727 L
.24419 .69608 L
.22998 .67647 L
.22549 .66984 L
.21733 .65686 L
.20636 .63725 L
.20588 .63632 L
.19739 .61765 L
.19029 .59804 L
.18627 .58378 L
Mistroke
.18507 .57843 L
.18161 .55882 L
.17962 .53922 L
.17894 .51961 L
.1794 .5 L
.18085 .48039 L
.18318 .46078 L
.18627 .44137 L
.18631 .44118 L
.19055 .42157 L
.19575 .40196 L
.20187 .38235 L
.20588 .37082 L
.2091 .36275 L
.21774 .34314 L
.22549 .32736 L
.22757 .32353 L
.23909 .30392 L
.2451 .29455 L
.25223 .28431 L
.26471 .26799 L
.26741 .26471 L
.28431 .24613 L
.28534 .2451 L
.30392 .22839 L
.30757 .22549 L
.32353 .21443 L
.3387 .20588 L
.34314 .20377 L
.36275 .19594 L
.38235 .19023 L
.40057 .18627 L
.40196 .18602 L
Mfstroke
.46078 .39974 m
.48039 .39654 L
.5 .39851 L
.51862 .40196 L
.51961 .40262 L
.53922 .40763 L
.55882 .41511 L
.56965 .42157 L
.57843 .42851 L
.58636 .44118 L
.59194 .46078 L
.5935 .48039 L
.59363 .5 L
.59319 .51961 L
.59207 .53922 L
.58921 .55882 L
.58209 .57843 L
.57843 .58479 L
.56627 .59804 L
.55882 .60325 L
.53922 .61237 L
.51961 .61612 L
.5 .61503 L
.48039 .60831 L
.46332 .59804 L
.46078 .59596 L
.44118 .57919 L
.4404 .57843 L
.42293 .55882 L
.42157 .55756 L
.41206 .53922 L
.40807 .51961 L
.40921 .5 L
.41354 .48039 L
.41975 .46078 L
.42157 .45563 L
.42665 .44118 L
.43637 .42157 L
.44118 .41497 L
.45604 .40196 L
.46078 .39974 L
s
.38235 .16589 m
.40196 .16283 L
.42157 .16079 L
.44118 .15937 L
.46078 .15839 L
.48039 .15782 L
.5 .15776 L
.51961 .15838 L
.53922 .15978 L
.55882 .16201 L
.57843 .16507 L
.58725 .16667 L
.59804 .16918 L
.61765 .17444 L
.63725 .18045 L
.65477 .18627 L
.65686 .18707 L
.67647 .19493 L
.69608 .20354 L
.70112 .20588 L
.71569 .21357 L
.73529 .2254 L
.73543 .22549 L
.7549 .2403 L
.76032 .2451 L
.77451 .25972 L
.77864 .26471 L
.79234 .28431 L
.79412 .28731 L
.8025 .30392 L
.81028 .32353 L
.81373 .33421 L
.81612 .34314 L
.82063 .36275 L
.82442 .38235 L
.82772 .40196 L
.83062 .42157 L
.83306 .44118 L
.83333 .44354 L
.83475 .46078 L
.83584 .48039 L
.8363 .5 L
.83609 .51961 L
.83525 .53922 L
.83385 .55882 L
.83333 .56469 L
.83172 .57843 L
.82892 .59804 L
.82546 .61765 L
.82119 .63725 L
Mistroke
.8159 .65686 L
.81373 .66381 L
.80891 .67647 L
.79981 .69608 L
.79412 .70643 L
.78813 .71569 L
.77451 .73343 L
.77285 .73529 L
.7549 .75273 L
.75231 .7549 L
.73529 .76719 L
.72326 .77451 L
.71569 .77846 L
.69608 .78757 L
.68009 .79412 L
.67647 .79542 L
.65686 .80233 L
.63725 .80919 L
.62426 .81373 L
.61765 .81585 L
.59804 .82242 L
.57843 .82919 L
.56632 .83333 L
.55882 .83566 L
.53922 .84159 L
.51961 .84678 L
.5 .85068 L
.48039 .85294 L
.48031 .85294 L
.46078 .85332 L
.4527 .85294 L
.44118 .85181 L
.42157 .8483 L
.40196 .84283 L
.38235 .83555 L
.37713 .83333 L
.36275 .82617 L
.34314 .81493 L
.34118 .81373 L
.32353 .80157 L
.31353 .79412 L
.30392 .78634 L
.29016 .77451 L
.28431 .76915 L
.26957 .7549 L
.26471 .74996 L
.25098 .73529 L
.2451 .72875 L
.23396 .71569 L
.22549 .70533 L
Mistroke
.21839 .69608 L
.20588 .67877 L
.20436 .67647 L
.19225 .65686 L
.18627 .64593 L
.18213 .63725 L
.17403 .61765 L
.16776 .59804 L
.16667 .594 L
.16346 .57843 L
.16075 .55882 L
.15943 .53922 L
.15937 .51961 L
.16039 .5 L
.16232 .48039 L
.16501 .46078 L
.16667 .45039 L
.16852 .44118 L
.17301 .42157 L
.17825 .40196 L
.18412 .38235 L
.18627 .37552 L
.19107 .36275 L
.19917 .34314 L
.20588 .32794 L
.20808 .32353 L
.21852 .30392 L
.22549 .29159 L
.23001 .28431 L
.24302 .26471 L
.2451 .26174 L
.25783 .2451 L
.26471 .23682 L
.27501 .22549 L
.28431 .21627 L
.29608 .20588 L
.30392 .19981 L
.32353 .18699 L
.32479 .18627 L
.34314 .17752 L
.36275 .17062 L
.37838 .16667 L
.38235 .16589 L
Mfstroke
.48039 .43033 m
.5 .42845 L
.51961 .43187 L
.53922 .4403 L
.54072 .44118 L
.55882 .46059 L
.55891 .46078 L
.56507 .48039 L
.5667 .5 L
.5662 .51961 L
.56347 .53922 L
.55882 .55495 L
.55751 .55882 L
.53922 .57685 L
.53555 .57843 L
.51961 .58298 L
.5 .58081 L
.49359 .57843 L
.48039 .57177 L
.46417 .55882 L
.46078 .55544 L
.44852 .53922 L
.44125 .51961 L
.44118 .51921 L
.44014 .5 L
.44118 .49202 L
.44326 .48039 L
.44971 .46078 L
.46078 .44386 L
.46348 .44118 L
.48039 .43033 L
s
.42157 .12712 m
.44118 .12716 L
.45735 .12745 L
.46078 .12755 L
.48039 .12826 L
.5 .12925 L
.51961 .13065 L
.53922 .13261 L
.55882 .13523 L
.57843 .13851 L
.59804 .14235 L
.61765 .14646 L
.62046 .14706 L
.63725 .15189 L
.65686 .15796 L
.67647 .16418 L
.68437 .16667 L
.69608 .17121 L
.71569 .17939 L
.73107 .18627 L
.73529 .1885 L
.7549 .19998 L
.76392 .20588 L
.77451 .21399 L
.78769 .22549 L
.79412 .23191 L
.8056 .2451 L
.81373 .25583 L
.81939 .26471 L
.83017 .28431 L
.83333 .29109 L
.83811 .30392 L
.84413 .32353 L
.84872 .34314 L
.85218 .36275 L
.85294 .36786 L
.85456 .38235 L
.85647 .40196 L
.85818 .42157 L
.85967 .44118 L
.86088 .46078 L
.86169 .48039 L
.86201 .5 L
.86181 .51961 L
.86112 .53922 L
.85998 .55882 L
.85845 .57843 L
.85655 .59804 L
.85422 .61765 L
.85294 .62694 L
Mistroke
.85093 .63725 L
.84627 .65686 L
.84038 .67647 L
.83335 .69608 L
.83333 .69613 L
.82361 .71569 L
.81373 .73275 L
.812 .73529 L
.79707 .7549 L
.79412 .75833 L
.77809 .77451 L
.77451 .77762 L
.7549 .79257 L
.7526 .79412 L
.73529 .80392 L
.71569 .81332 L
.71476 .81373 L
.69608 .82046 L
.67647 .82718 L
.65836 .83333 L
.65686 .83376 L
.63725 .83983 L
.61765 .84691 L
.6022 .85294 L
.59804 .85436 L
.57843 .86164 L
.55882 .86919 L
.54957 .87255 L
.53922 .87562 L
.51961 .88075 L
.5 .88443 L
.48039 .88636 L
.46078 .88645 L
.44118 .8847 L
.42157 .88121 L
.40196 .87615 L
.39025 .87255 L
.38235 .86943 L
.36275 .86061 L
.34742 .85294 L
.34314 .85044 L
.32353 .8381 L
.31629 .83333 L
.30392 .82416 L
.29044 .81373 L
.28431 .8086 L
.26762 .79412 L
.26471 .79145 L
.24682 .77451 L
.2451 .77283 L
Mistroke
.22747 .7549 L
.22549 .75284 L
.20942 .73529 L
.20588 .73132 L
.19284 .71569 L
.18627 .70745 L
.17805 .69608 L
.16667 .6791 L
.16514 .67647 L
.1546 .65686 L
.14706 .64048 L
.14586 .63725 L
.13936 .61765 L
.1343 .59804 L
.13075 .57843 L
.12869 .55882 L
.128 .53922 L
.12858 .51961 L
.13027 .5 L
.13295 .48039 L
.13644 .46078 L
.14054 .44118 L
.14494 .42157 L
.14706 .41212 L
.15006 .40196 L
.15634 .38235 L
.16292 .36275 L
.16667 .35134 L
.17006 .34314 L
.17861 .32353 L
.18627 .30591 L
.18728 .30392 L
.19766 .28431 L
.20588 .26885 L
.20836 .26471 L
.2206 .2451 L
.22549 .23742 L
.23399 .22549 L
.2451 .21082 L
.2492 .20588 L
.26471 .18889 L
.26734 .18627 L
.28431 .17129 L
.29022 .16667 L
.30392 .15745 L
.32246 .14706 L
.32353 .14657 L
.34314 .13884 L
.36275 .13325 L
.38235 .12968 L
Mistroke
.40196 .12777 L
.4079 .12745 L
.42157 .12712 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`00
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`00
0010ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0O_oo
ool2o`0000?ooooo2OnY_NP01?l0003oZKgXooooool0000oooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0Noooool3o`0000;ooooo3?nY_NP01Ol0003oZKgX
oooooooooooo000003kooooo0009ooooo`0400000?ooooooooooooooodl0000000?o000000000000
0000F`000004ooooo`0300000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY
_NSoooooo`00000nooooo`002Oooool01000003ooooooooooooooom500000003o`00000I6AT06ATI
00/06ATIFP000004ooooo`0300000?oooooooooo07Kooooo0ol00002oooooa7oZKgX00Ko0000ojVm
j?nY_NSoZKgXooooool0000mooooo`002Oooool01000003ooooooooooooooom0000002006ATIC@00
0004ooooo`0300000?oooooooooo07Cooooo0_l00002oooooaCoZKgX00?o0000ojVmj?nY_NP00_nY
_NP00ol0003oooooooooo`0kooooo`002Oooool01000003ooooooooooooooolj000002d06ATIAP00
0004ooooo`0300000?oooooooooo077ooooo0ol00002oooooaKoZKgX00?o0000ojVmj?nY_NP00onY
_NP00ol0003oooooooooo`0jooooo`002Oooool01000003ooooooooooooooolh000003<06ATI00?o
0000000000000000?`000004ooooo`0300000?oooooooooo06kooooo0ol00002oooooaWoZKgX00?o
0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0jooooo`002Oooool01000003ooooooooooooo
oolf000003T06ATI?P000004ooooo`0300000?oooooooooo06cooooo0_l00003oooooacoZKgX00?o
0000ojVmj?nY_NP00onY_NP00ol0003oooooooooo`0iooooo`002Oooool01000003ooooooooooooo
oole000001806ATI6@00000B01TI6C/000001?ooool00`00003oooooooooo`1Yooooo`?o00000_oo
oolOojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?ooool0>Oooool000Wooooo00@00000
oooooooooooooooo<`00000=01TI6@0300000?l0003o000000@000006@0c<c<8000000d06ATI00<0
0000o`0000000000=@000004ooooo`0300000?oooooooooo06Oooooo0_l00003ooooob7oZKgX00?o
0000ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0hooooo`002Oooool01000003ooooooooooooo
ool`00000003o`00000I6AT06ATI00X06ATI0`00000X03<c<`<000003P0I6ATd000000Cooooo00<0
0000ooooooooool0I?ooool3o`0000;ooooo9?nY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0
003ooooo03Sooooo0009ooooo`0400000?oooooooooooooooc0000002P0I6AT300000140<c<c4P00
000;03<c<`<000003@0I6ATb000000Cooooo00<00000ooooooooool0H_ooool2o`0000?ooooo3?nY
_NP2ojVmi`GoZKgX00?oZKgWojVmj?nY_NP04?nY_NP00ol0003oZKgXojVmj005ojVmj003ooooool0
003ooooo03Oooooo0009ooooo`0400000?ooooooooooooooobl000002@0I6AT2000000d0<c<c1`00
000B04a<C0L000001`0c<c<4000000/06ATI<0000004ooooo`0300000?oooooooooo05oooooo0ol0
0002ooooo`goZKgX1OnY_NL00onY_NSoZKgWojVmi`03ojVmi`;oZKgX0_nZ_NL00onY_NSoZ[gWojZm
i`0:ojVmj003o`000?nY_NSoZKgX00KoZKgX00?oooooo`000?ooool0=_ooool000Wooooo00@00000
oooooooooooooooo;P00000801TI6@800000300c<c<00`00003o00000000000A04a<C0D000002P1<
C4`4000000L0<c<c0`00000:01TI6@03o`0000000000000002/000001?ooool00`00003ooooooooo
o`1Mooooo`;o00000oooool6ojVmj003ojVmionY_NSoZKgX00?oZKgX0_nY_>L5ojVmi`;oZKcW1?nY
_NL2ojZli`;oZ[gW00?oZ[cWojZmionZ_NL00_nZ_NL00onY_NSoZ[gWojVmj006ojVmj003o`000?nY
_NSoZKgX00OoZKgX00?o0000ooooooooool0=Oooool000Wooooo00@00000oooooooooooooooo;@00
000801TI6@030000000c<c<0<c<c00P0<c<c1000000:04a<C0X000001@1VIVH7000000L0C4a<0`00
000703<c<`<000002P0I6AT[000000Cooooo00<00000ooooooooool0F_ooool3o`0000;ooooo1onY
_NP4ojVmi`;oZKgX1OnY_>L00onY_NOoZKcWojVli`02ojVli`03ojZki_nZ_>OoZ[cW00?oZ[cW0_nZ
_>H3ojZli`;oZ[gW00CoZ[cWojZmionZ_NOoZ[gW0_nY_NP01OnZ_NOoZKgXojVmj?nY_NSo000000[o
ZKgX00?o0000ooooooooool0=?ooool000Wooooo00@00000oooooooooooooooo;000000701TI6@80
0000200c<c<3000000/0C4a<0`00000F06IVIPL000000`1<C4`4000000H0<c<c00<0000001TI6@0I
6AT02@0I6AT00ol0000000000000000V000000Cooooo00<00000ooooooooool0Eoooool3o`0000?o
oooo1_nY_NP6ojVmi`OoZKcW0_nY_>H00onY_>OoZ[_VojZkiP03ojZkiP;oZ[cW00?oZ[_VojZli_nZ
_>H00_nZ_>H00onZ_>OoZ[cVojZli`03ojZli`03ojZmionZ_>OoZ[cW00?oZ[gW0_nY_NP00ol0003o
ZKgXojVmj008ojVmj003ooooool0003ooooo03Cooooo0009ooooo`0400000?ooooooooooooooob/0
00001`0I6AT00`000000<c<c03<c<`0403<c<`0400000?l000000000000000L0C4a<1`00000606IV
IP0300000?l0003o000000l0000000?o000006IVIP1VIVH01@1VIVH2000000D0C4a<0P00000503<c
<`03o`0000000000000000T06ATI:0000004ooooo`0300000?oooooooooo05Gooooo0_l00003oooo
o`OoZKgX00?oZKcWojVmionY_NL00onY_NL6ojVli`?oZK_V00?oZKcVojZjiOnZ^nH01?nZ^nH2ojZj
i@?oZ[_V0_nZ_>H01?n[^nGoZ[cVojZli_nZ_>H2ojZli`03oj^li_nZ_>OoZ[cW00;oZ[cW1?nZ_NL0
0ol0003oZ[gWojVmj009ojVmj003o`000?oooooooooo03?ooooo0009ooooo`0400000?oooooooooo
ooooobT0000000?o000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0
C4a<00D0C4a<1000000:06IVIP<000004`1oOgl3000000H0IVIV0P00000504a<C08000001P0c<c<0
0`0000006ATI01TI6@0701TI6BL000001?ooool00`00003oooooooooo`1Booooo`?o00000oooool6
ojVmj0GoZKcW00?oZKgWojVlionY_>L00_nY_>L2ojVji@GoZK_V00CoZ[WTojZjiOnZ^^GoZ[[U0_nZ
^nH00on[^>?oZ[[UojZji@02ojZji@03ojZki_n[^NCoZk_U00?oZk_U00?oZ[cVoj^kiOn[^nD00on[
_>H2ojZli`;oZkcV0onZ_NL00ol0003oZ[gWojZmi`02ojVmj003ojZmionY_NSoZKgX00CoZKgX00?o
ooooo`000?ooool0<oooool000Wooooo00@00000oooooooooooooooo:P00000601TI6@030000000c
<c<0<c<c00<0<c<c0P00000504a<C0<000002`1VIVH3000000L0Ogmo3`00000307moO`@00000101V
IVH3000000@0C4a<0P00000503<c<`800000200I6ATV000000Cooooo00<00000ooooooooool0D?oo
ool2o`0000Cooooo00?oZKgWojVmj?nY_NP00onY_NP6ojVli`;oZK_V0_nY_>L5ojVji@03ojVki_nY
^>?oZ[WT00?oZ[WT00?oZ[[UojZgh_nZ]n800on[^><2ojZji@04oj^gh_n[^NCoZkWToj^ii0;oZk_U
00?o[;WSoj^kiOn[^nD00_n[^nD00on[_>KoZk_Uoj^ki@02oj^liP05oj^kiOn[_>KoZkcVoj^li_l0
00001_nZ_NL00onY_NSoZ[gXojVmj003ojVmj003o`000?oooooooooo03;ooooo0009ooooo`040000
0?ooooooooooooooobT000001`0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH0201VIVH4000000L0Ogmo0`00000?09VIV@<00000101oOgl3000000@0
IVIV0P00000404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6ATU000000Co
oooo00<00000ooooooooool0COooool3o`0000?ooooo1OnY_NL00onY_NSoZKcWojVli`02ojVli`Ko
ZK_V0_nY^N@5ojVji@04ojVgh_nY^>?oZKSSojVhh`;oZ[WT00?oZ[GQojZgh_nZ]n800_nZ]n800on[
^>?oZkCOoj^ghP03oj^ghP03oj^ii?n/]^3o[;KP00?o[;WS0_n[^nD2ojbih`03oj^kiOn]^^?oZk_U
00?oZk_U0_n[_>H00ol0003oZ[gWojZmi`04ojZmi`?oZ[gX0onY_NP00ooooooo0000ooooo`0boooo
o`002Oooool01000003ooooooooooooooolX000000L06ATI00@0000003<c<`0c<c<0<c<c0P000005
04a<C0800000201VIVH3000000L0Ogmo00@00000o`000?l0000000000`2IVITA0000000309VIV@00
003o0000008000000`1oOgl00ol0000000000000000306IVIP8000000`1<C4`2000000D0<c<c0P00
000701TI6B@000001?ooool00`00003oooooooooo`1;ooooo`;o00001?ooool2ojVli`CoZKgW1?nY
_>L00onY^^GoZK_VojVkiP03ojVkiP03ojVhi?nY^NCoZKWT00;oZKWT00?oZK[UojVehOnY]N400onY
]n800onY^>?oZ[;OojZbg`03ojZeh@;oZ[OR00CoZk7Moj^dgon[]=ooZkCO0_n[]n800on]/mgo[;KP
ojbfh002ojbfh003ojbihon]]]oo[;WS00;o[;WS00Co[[OPojfjhon]^^?o[K[S0_n[^nD01on]^nCo
ZkcVoj^li_l0003oZkcVojZmion[_>H01?nZ_NL00onZ_NSoZ[gWojZmi`03ojVmj003ooooool0003o
oooo037ooooo0009ooooo`0400000?ooooooooooooooobP000001P0I6AT01@000000<c<c03<c<`0c
<c<0000000D0C4a<0P00000606IVIP@000001`1oOgl3000000@0VIVI0`00000A0;>c/`8000000`2I
VIT3000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH2000000<0C4a<0P00000503<c<`8000001`0I
6ATR000000Cooooo00<00000ooooooooool0B?ooool3o`0000?ooooo1?nY_>L2ojVkiPCoZKcW1OnY
^^D2ojVkiP04ojVghonY^>CoZKSTojVhi0;oZKWT00?oZK?PojVehOnY]N400_nY]N400onY]n;oZ[3L
ojZbg`03ojZbg`03ojZehOn[[][oZk7M00?oZk7M00?oZkCOojf_fOn][mT00on]/md2ojbfh005ojjb
fon]]]oo[KKOojffgon/^N<00on^]n000on]^^?o[kWQojnih@03ojfki003oj^li_l0003o[;cU00?o
ZkcV0_nZ_NL00on[_NOoZ[gWojZmi`02ojZmi`04ojVmj?nZ_NSoZ[gXo`0003;ooooo0009ooooo`04
00000?ooooooooooooooobL000001P0I6AT01@000000<c<c03<c<`0c<c<0000000@0C4a<0P000005
06IVIP<00000201oOgl3000000H0VIVI00<000000;>c/`2c/k<0102c/k<?o`0000040;>c/`000000
0000000000<0VIVI0`000000101oOgl0000000000000000306IVIP030000001<C4`0C4a<0080C4a<
0P00000503<c<`03o`00000I6AT06ATI00D06ATI8@000004ooooo`0300000?oooooooooo04Gooooo
0ol00004ooooo`CoZKcW00?oZ[_VojVki_nY^nH00_nY^nH00onY_>OoZKWUojVji@04ojVji@;oZKKR
0onY]n<00onY^>CoZK7NojVagP03ojVch0;oZKGQ00CoZJgJojZ`g?nZ/=coZ[3L0_nZ/]l01?nZZ]Oo
ZjkJoj^^f_n[[]X2oj^ag@03ojbZeOn][mWo[JoI00;o[JoI00?o[K?Mojn^e_n^/]/00on^/]/01_n]
]]oo/;?Kok2cfon`/m_o[[OPok6eg0Co[kWQ00Co[K_Tojjjh_n/_>Go00000_n/_>D01?n[_>Ko[;cV
ojbli_n/_>H2oj^mi`CoZ[gW0_nZ_NP00ooooooo0000ooooo`0`ooooo`002Oooool01000003ooooo
oooooooooolU00000003o`00000I6AT06ATI00@06ATI00Go000003<c<`0c<c<0<c<c0000000404a<
C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01`1oOgl2000000L0VIVI00?o00000000
002c/k<00P2c/k<4o`0000l0c<c<00Go00000;>c/`2c/k<0/k>co`000002000000<0VIVI00Go0000
07moO`1oOgl0Ogmoo`00000306IVIP03o`0000000000C4a<00<0C4a<00?o000003<c<`0c<c<00`0c
<c<00`0000006ATI01TI6@0501TI6B0000001?ooool00`00003oooooooooo`13ooooo`;o00000_oo
ool6ojVli`GoZ[_V0_nY^nH01?nY^NCoZKWUojViiOnY^ND2ojVji@03ojVehOnY]^;oZKKR00;oZKKR
00?oZKOSojV_g?nY/Mh00onY/Mh00onY/n3oZJ[GojV]fP03ojV]fP03ojZ`g?nZY]?oZZKC00?oZZ[G
00?oZjkJojbUd?n/Z]D00on/Z]D2ojf_f@04ojnXdOn_[]Ko[jkFojn^eP;o[[;K00Go/JkEok2cfon`
/m_o/;?Kok>`eP03ok6eg0;o[kWQ00Ko/KSNojjjh_n^^^;o[[[Ro`000?n/_>D2ojjli0;o[;cV00Co
[KgUoj^mion[_NOoZkgW0onZ_NL3ojZmj003ooooool0003ooooo02oooooo0009ooooo`0400000?oo
ooooooooooooobH000001@0I6AT00`000000<c<c03<c<`0203<c<`03o`00001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00P1VIVH00`00003o000007moO`0707moO`800000202IVIT00`000000/k>c
0;>c/`020;>c/`03o`00003<c<`0c<c<00<0c<c<3Ol000020<c<c0?o00000`2c/k<010000000VIVI
09VIV@2IVIT200000080Ogmo0P00000306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c
<c<00P0c<c<00`0000006ATI01TI6@0501TI6B0000001?ooool00`00003oooooooooo`10ooooo`?o
00000_ooool00onY^nKoZKcWojVli`03ojVli`;oZ[[U1?nZ^nH2ojZhi0?oZKWT00?oZKWUojVdh?nY
]>000onY]N42ojVfhP04ojV^fonY[mcoZJoLojV_g0;oZK7N00CoZJODojVZeonYZ]OoZJ[G0_nY[MX0
0onYX/ooZZKCojZVd`02ojZVd`03ojZZeon[X<co[:G@00;o[:G@0on/Z]D4ojnXd@03ojn^e_naZ<ko
/JS>00?o/JkE00Co/;?Kok>`e_nc/=Ko/k3F0_na]M`4ok6hgP03ojjjh_n`^^7o000000?o[[cT1?n]
_ND00on[_NOo[;gWojZmi`03ojZmi`;oZ[gX00?oooooo`000?ooool0;oooool000Wooooo00@00000
oooooooooooooooo9@00000501TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0C4a<
0P00000306IVIP8000001P1oOgl4000000T0VIVI00<000000;>c/`2c/k<00`2c/k<01?l00000c<c<
0<c<c03<c<`2o`0000d0i^KV0_l000030<c<c0;o00000P2c/k<2000000<0VIVI00D0000007moO`1o
Ogl0Ogmo0000000306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`00
00006ATI01TI6@0501TI6Al000001?ooool00`00003oooooooooo`0nooooo`;o00000oooool4ojVk
iP;oZKcW1OnZ^^D00onZ^nKoZ[SSojZhi003ojZhi003ojVii?nY/mooZKCP00?oZKCP00?oZKGQojV/
fOnY[=T00onY[]/00onY[mcoZ:CBojVWe003ojVWe003ojVZeonYW/_oZJ;?00?oZJ;?0_nZY]<01?nZ
VlOoZj3<oj^Pc?n[X<`3ojbUd003ojbZeOn^X/_o[Z;;00;o[jSA00?o/J77ok6Xc_naZ<h00_naZ<h0
0ona[]Go]:[>ok>`eP03ok>`eP03ok6eg?nd/mSo];?H00;o/KSN00Ko];OKok2jhOn`^^7o0000ok2j
hOn^_>@2ojnlh`?o[KgU0on/_NL2ojZmi`06oj^mionZ_NSoZ[gXojZmj?oooooo0000;oooool000Wo
oooo00@00000oooooooooooooooo9@00000401TI6@030000000c<c<0<c<c0080<c<c00D0000004a<
C01<C4`0C4a<0000000406IVIP030000001oOgl0Ogmo00@0Ogmo0P00000<09VIV@030000002c/k<0
/k>c00<0/k>c00Go00000<c<c03<c<`0c<c<o`00000A0>KViP03o`00003<c<`0c<c<0080c<c<00Go
00000;>c/`2c/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moOol000000`1VIVH00ol00000
C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I6ATO000000Co
oooo00<00000ooooooooool0>oooool3o`0000;ooooo1_nY^nH2ojVji@GoZ[[U00CoZ[OSojZhhonZ
^>?oZ[SS0_nZ^>@01?nY/]ooZK?OojVcgonY/ml2ojVdh003ojRZf?nY[=WoZJcI00;oZJcI00?oZJkK
ojRQconXY=800_nXY=83ojVWe0?oZIk;0onYX/l01?nZY]?oZY_7ojZKaonZVlL2oj^Pc0;o[:G@00Go
[I_5ojjRbon^X/_o[Z;;ojnXd@03ok6Qa`;o/JS>00Co]J?6okBZc_ndZ/ko]:[>0_nc/=H01Ong[]3o
];?HokBcf?nd/mSo^K?C00?o];OK00Ko/;[Qo`000?nc^moo/k_Oojnlhona_N<4ojfmi@03ojbmion/
_^OoZkgW00?oZkgW0onZ_NP00ooooooo0000ooooo`0]ooooo`002Oooool01000003ooooooooooooo
oolT000000D06ATI00Go000003<c<`0c<c<0<c<c0000000304a<C0060000001VIVH0IVIV06IVIP00
003o00001@1oOgl00`00003o000009VIV@0<09VIV@03o`00002c/k<0/k>c00<0/k>c00?o00000<c<
c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViPOo00001@3Vi^H2o`0000<0c<c<0_l000020;>c
/`8000000P2IVIT010000000Ogmo07moO`1oOgl200000080IVIV00<0000004a<C01<C4`00P1<C4`0
0ol00000<c<c03<c<`0203<c<`030000000I6AT06ATI00@06ATI7P000004ooooo`0300000?oooooo
oooo03Wooooo0_l00003ooooo`;oZK_W1?nY^nH2ojVii@?oZK[U00?oZ[[UojZgh_nZ]n800onZ]n<0
0onZ^>?oZK;NojVbgP03ojVbg`03ojVcgonXZMOoZ:WG00?oZ:[H0_nY[=T01?nWW/goZ:7?ojRQconX
XLl3ojRTdP03ojVWe?nXVLOoZ9W700?oZIk;00?oZJ;?ojVE`_nZVlL00onZVlL00on[X<coZiG0ojfK
a@03ojfKa@03ojjRbon`V/7o/J7700?o/J7700Co/JS>okFSa_neXlKo]J?60_ndZ/h01OniYlOo]jk@
okN^d?ng[]3o];?H00?o^K?C00Ko];OKokRhfOnc^moo0000ok>kgonf_=h3ok6mh`;o[KgU00Co[[kU
ojbnion/_^Oo[;kW0_n[_NL2oj^ni`04ojZmj?nZ_^SoZ[kXo`0002kooooo0009ooooo`0400000?oo
ooooooooooooob80000000?o000001TI6@0I6AT0100I6AT01@000000<c<c03<c<`0c<c<000000080
C4a<00?o000006IVIP1VIVH00P00000407moO`<000003`2IVIT00`000000/k>c0;>c/`030;>c/`03
o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`040?ooo`;o
00001@3Vi^H00ol00000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/`0000000P2IVIT00`00
0000Ogmo07moO`0207moO`040000001VIVH0IVIV000000@0C4a<00D0000003<c<`0c<c<0<c<c0000
000601TI6Ah000001?ooool00`00003oooooooooo`0fooooo`?o00000oooool00onY_>OoZK_WojVk
i`02ojVki`03ojVki_nY^NGoZKWU00?oZKWU00?oZK[UojVfh_nZ]n800onZ]n800onZ]n?oZK7NojVb
gP03ojVbgP03ojVbgonXZ=KoZ:WG00?oZ:WG00?oZ:[HojJLc?nWW/d00onWW/d2ojRQc`;oZ:CB00Co
YiG4ojRIaonXVLOoZ9W70_nYW//01?nXT;goZIG2ojVE`_nYUL82ojZKa`04ojZ@^_n[UL3oZiG0oj^E
`0?o[I_50on`V/43ok6Qa`Co]J?600Ko]:[>okVWaoniYlOo^JO7okN^d?nl[L/3okVcd`05okfcd?nh
^=Wo^;SIokRhfOl000000onf_=h00ona_N?o/kkRojjni@03ojjni@?o[;kW0on[_^L4ojZnj003o`00
0?oooooooooo02_ooooo0009ooooo`0400000?ooooooooooooooob<000001@0I6AT01@000000<c<c
03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000`1oOgl300000180VIVI00<000000;>c
/`2c/k<00`2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?oo
o`3oool01`3oool00ol00000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00Go00000;>c
/`2c/k<0/k>c0000000209VIV@030000001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P000003
04a<C0050000000c<c<0<c<c03<c<`0000001P0I6ATM000000Cooooo00<00000ooooooooool0<ooo
ool3o`0000Cooooo1?nY_>L2ojVki`;oZK[U1?nY^ND4ojVfhP;oZ[OR00CoZK7MojVag_nY/MkoZK7N
0_nY/]h4ojRXeP;oZ:WG00CoYI_;ojJLc?nVW<coYYc<0onWW/d00onXXLooYI;1ojNEa003ojNEa0;o
Z9W71?nXT;d2ojVE`P03ojZKaonZT;[oZY2j00CoZiG000?o[I_5ojjC^on`V/400on`V/400onaXLOo
]9^nokBK_P02okFSaP03okVO__niYlOo^JO700;o^JO70onl[L/01oni/m?o_K?@okfcd?nm/m3o^;SI
okbieol000000_nf_=h01?ni_Mgo/kkRok>nh_nc_^82ojjni@;o[koU00?o[;kWojfnion]_^L00on[
_^L3ojZnj003o`000?oooooooooo02_ooooo0009ooooo`0400000?ooooooooooooooob8000001@0I
6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000`1oOgl00`000000
VIVI09VIV@0C09VIV@030000002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`00P3<c<`00ol00000
i^KV0>KViP020>KViP03o`00003oool0oooo00T0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000
c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/`0000000P2IVIT00ol00000000007moO`0207mo
O`050000001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c03<c<`0c<c?o000000H06ATI00?o
00000000000000006@000004ooooo`0300000?oooooooooo037ooooo0_l00004ooooo`CoZKcW1OnX
^^H00onY^^GoZ;KSojRfh`03ojRfh`?oZKKR0_nY/=d3ojVag@03ojVag_nXYmKoZ:OF00CoZ:SF00?o
YI[:ojFKbonUVl/00_nUVl/3ojJLc003ojNNcOnTSkkoYI;100;oYI;10onWUL@00onXVLOoYXbiojJ<
^@03ojR@_@03ojVE`_nXRkGoZY2j00?oZY2j0_n[UL001?n/SKGo[Y>kojjC^on^Tk/2ok2J`@05ok:D
^?ndVkko]9^nokBK__neXlH00oniWkh2okVWa`;o_ZK10_nl[L/3okfcd005ol>ecOnl^MOo_;WGokbi
eol000000oni_Md01_nc_^;o];oRokBoh_nd_n;o[koUok2oi@Co[KkW0_n[_^L4ojZnj003o`000?oo
oooooooo02[ooooo0009ooooo`0400000?ooooooooooooooob8000001@0I6AT010000000<c<c03<c
<`00000304a<C0030000001VIVKo000000@0Ogmo00<0000009VIV@2IVIT01@2IVIT2000000`0VIVI
00<000000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV0080i^KV
00?o00000?ooo`3oool02@3oool00ol00000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<
00Go00000;>c/`2c/k<0/k>c0000000409VIV@040000001oOgl0Ogmo000000<0IVIV00D0000004a<
C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00@06ATI6`000004ooooo`0300000?oooooo
oooo02kooooo0ol00002ooooo`03ojVmj?nY_>SoZKcX00;oZKcX00?oZKcWojRkionX^^H01?nX^^H0
0onW]nCoZ;KSojRfh`03ojRfh`04ojN`g_nX/=goZ;3MojR`g@?oZK3M00?oZK7MojRWe_nXYmH00onX
YmH00onXZ=KoYI[:ojFJbP02ojFJbP?oYI_;0_nVW<`01?nSS;goY8nnojB?__nTSkh3ojFB`@03ojNE
a?nUR;KoYXbi00;oYXbi0onXT;d3ojR;]@?oZY2j00?oZiG0ojb=]On/SKD00on^Tk/01?n`V/7o/YBh
ok:D^?nbU;P2okBK_PCo^Inn00Go^JO7okjV`OnnY/7o_ZK1okb]b`02ol6]aP09okfcd?o3]Lgo`kG=
ol>ecOnl^MOo`KcEo`000?o1_=Go^KgM00;o_;oL0_nd_n801?nf`N;o/;oUok2oiOn`_nD2ojfni`;o
[KoW0_n[_^L4ojZnj003o`000?oooooooooo02Wooooo0009ooooo`0400000?ooooooooooooooob40
00001@0I6AT010000000<c<c03<c<`00000304a<C0040000001VIVH0IVIV00000080Ogmo0P000004
09VIV@@000000P2c/k<00`000000VIVI09VIV@0:09VIV@800000102c/k<01?l00000c<c<0<c<c03<
c<`2o`0000@0i^KV00?o00000?ooo`3oool0203oool00ol00000i^KV0>KViP040>KViP05o`00003<
c<`0c<c<0<c<c?l00000102c/k<00`000000VIVI09VIV@0209VIV@040000001oOgl0Ogmo000000<0
IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`030000000I6AT06ATI00@06ATI6`000004oooo
o`0300000?oooooooooo02cooooo0_l00003ooooo`CoZKgX0_nY_>P01?nX_>OoZ;_WojRkionX^nL2
ojRjiP04ojNhiOnW]nCoYkOTojNgi0;oZ;KS00CoYk7OojN`g_nW/=koYk3N0onX/=d00onY/=goYjOF
ojRWeP04ojRWeP03ojFJbonUV/[oYI[:00CoYI[:00?oYI_;oj6;_?nSS;d00_nSS;d3ojB?_P;oYI;1
00?oXhBcojF8]_nUR;H01?nVS;T00onXT;goYhJaojR;]@02ojR;]@?oZY2j1?n/SKD2ojjC^`Co/YBh
00?o]9^nokRH]onhV;L00oniWkh3okjV`@05ol>V_?o1[LKo`Jg6ol6]a_o7[l800oo3]Ld2ol6le@03
o`000?o5_]Co_;oL00;o_;oL1?nf`N800on`_nGo/<3Uok30i@03ojfoi`?oZkkX0onZ_^P00ol0003o
ooooooooo`0Yooooo`002Oooool01000003ooooooooooooooolQ000000D06ATI00@0000003<c<`0c
<c<000000P1<C4`010000000IVIV06IVIP00000207moO`040000002IVIT0VIVI09VIV@<000001`2c
/k<00`000000VIVI09VIV@0;09VIV@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`00P3<
c<`00ol00000i^KV0>KViP020>KViP?o00001P3oool00ol00000i^KV0>KViP050>KViP03o`00003<
c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@04o`00001o
Ogl0Ogmoo`0000<0IVIV00Co000004a<C01<C4co0000100c<c<00`0000006ATI01TI6@0301TI6A/0
00001?ooool00`00003oooooooooo`0Yooooo`?o00000_ooool6ojVmj0;oZKcW0onX_>L00onX^nOo
YkWVojNiiP03ojNhi@03ojNgi?nV/^7oY[;Q00?oYk7O00?oYk3NojFXf?nVYmL00_nVYmL3ojNWeP03
ojRWe_nTV/_oYI[;00?oYI[;1?nUV/X00onPRkcoXH^loj6;_004oj><_@;oY8nn0onSQ;<3ojF8]P;o
YXbi00CoYH:]ojN6/OnWQ[7oYhJa0onXRkD00onZT;[oZhR`ojb=]@03ojb=]@03ojjC^on`S[;o/8jb
00?o/YBh1?nhV;L01?niWkko_YjiokjN^OnnY/43ol>V_005ol6]a_o7[l;oajo2olN_`_o3]Ld00_o8
^</01Oo1_=Go0000olFne?o5_]Co_;oL00;o_/7L0_nf`N82okO2hP03ok30iOna`>Go[KoW00?o[KoW
0_n[_^P4ojZnj003o`000?oooooooooo02Sooooo0009ooooo`0400000?ooooooooooooooob000000
1@0I6AT010000000<c<c03<c<`00000204a<C0040000001VIVH0IVIV00000080Ogmo00D0000009VI
V@2IVIT0VIVI0000000;0;>c/`03o`0000000000VIVI00/0VIVI00<00000o`00000000000P2c/k<0
0ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00@0i^KV1ol000070>KViP;o0000103<c<`0
0ol00000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl010000000IVIV06IV
IP00000304a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATK000000Cooooo00<00000oooooooo
ool09oooool2o`0000?ooooo2?nY_NP3ojVli`03ojRlionX^^OoZ;[W00?oYkWV00?oYkSUojJch_nV
/^400onV/^400onW/MooY:SJojFXf002ojFXf0?oYZOG00?oYjOFojBKc?nTV//00_nTV//3ojFJb`03
ojFJb_nPRkgoX8^l00;oX8^l0onQRk`3oj><_@03ojB?__nQPK7oXhBc00?oXhBc0_nUR;H00onVS;Wo
YH:]ojF2[@03ojN6/@;oZ8^e00CoZH>/oj^8/?n[R;3oZhR`0_n/SKD00on_RJgo/8jbok2>/P02ok2>
/P03ok:D^?nfT[7o^9Rg00?o^9Rg0onnW[T4ol>V_0Coajo20oo8^</01?o5_]Co0000olFne?o8`=83
okk1g0?o]l;R00Co^<;Rok70iOna`>Go/L3U0on]_nL3oj^nj0CoZ[kX00?o0000ooooooooool09ooo
ool000Wooooo00@00000oooooooooooooooo8000000501TI6@040000000c<c<0<c<c00000080C4a<
00H0000006IVIP1VIVH0000007moOol0000209VIV@0300000?l00000/k>c00`0/k>c00<0000009VI
V@2IVIT03@2IVIT010000000/k>c0;>c/ol000040<c<c0?o0000403Vi^H00ol00000c<c<0<c<c004
0<c<c003o`00002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`040000001V
IVH0IVIV000000<0C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6A/000001?ooool00`00003o
ooooooooo`0Tooooo`?o00000oooool;ojVmj003ojVlionX^nOoZ;_W00?oZ;[W00?oYkWVojJfi?nV
/n800_nV/n82ojJbh@04oj>Zg?nTZ=[oY:SJojBXfP?oYJSH00?oYZOGoj>LcOnTVl`00_nTVl`3ojBJ
b`03ojFJbonPRkkoX8^m00;oX8^m0onPRk`2oj6;_0;oXhbm00CoWgn`oj61/OnQPK7oXH6a0onSQ;<0
0onUR;KoXgjZojF2[@03ojF2[@;oYhJa00?oZ8^eojV3[?nYPj`00on[R;000on/SKGo[hV]ojn9[@04
ok2>/P?o]Y:a0_nhV;L2okfH/P;o_Yji00Goa:2dol>V_?o3Y[co`jJlolVY^@02olN_`P;ocK:o00Co
b;S;olfkb?o=^lSo00000oo8`=801?nn`Mco`L?Kol73fong`^83okS2hP03ok70iOna`NGo[KoW00?o
[KoW0on[_^P3ojZnj003o`000?oooooooooo02Oooooo0009ooooo`0400000?oooooooooooooooal0
00001@0I6AT010000000<c<c03<c<`00000204a<C0060000001VIVH0IVIV0000001oOgl000000P2I
VIT010000000/k>c0;>c/`2c/k<6o`0000H0/k>c00<0000009VIV@2IVIT03P2IVIT2000000040;>c
/ol0003o0000o`0000@0c<c<0ol0000<0>KViP03o`00003<c<`0c<c<00H0c<c<00?o00000;>c/`2c
/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`0
1@000000<c<c03<c<`0c<c<0000000D06ATI6P000004ooooo`0300000?oooooooooo02;ooooo0_l0
0004ooooo`WoZKgX0_nY_>P3ojRli`03ojRkionW^NKoYkWV00?oY[SU0_nV]^@00onV/n;oXjgNoj>]
gP03oj>Zg0;oY:SJ0_nUZ=P01?nRW<ooXic=oj>LcOnSW<d3ojBKc004ojBJbonOSKooX8^noj2;_P?o
X8^m0onPRk`00onQRkcoWGf`oimo/002oimo/0?oXH6a0_nSQ;<01?nQNZSoXgjZoj=nZ_nSOZX3ojF2
[@;oYhJa1?nYPj`2oj^8/0Co[hV]0_n`S[801OndS:co]Y:aokJB/OnfT[7o^9Rg00?o_IRb00Go_Yji
olBP]?o4X;Coa:2dol>V_002olVY^@04olN_`_o=/[oocK:oolfb_`?ocK_800?o0000olS0d_o8`=80
0_o<`]400oo1`m_o`/?Kol;3f`02okS2hP04okW2h_na`NGo/L7Uok71i@Co[KoW0_n[_^P4ojZnj003
o`000?oooooooooo02Kooooo0009ooooo`0400000?oooooooooooooooal00000100I6AT010000000
<c<c03<c<`00000204a<C0060000001VIVH0IVIVo`00001oOgl000000P2IVIT01@000000/k>c0;>c
/`2c/k?o000000H0c<c<00?o00000;>c/`2c/k<00`2c/k<00ol00000VIVI09VIV@0309VIV@;o0000
1P00000509VIV@040000002c/k<0/k>c0;>c/`Co00000`3<c<`<o`0000T0c<c<00?o00000;>c/`2c
/k<00`2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00@0000006IVIP1VIVH000000P1<C4`0
1@000000<c<c03<c<`0c<c<0000000D06ATI6P000004ooooo`0300000?oooooooooo01oooooo0ol0
00000oooooooZKgXojVmj00<ojVmj0?oZKcX00?oZ;cWojNkionW^nL00onW^NH00onV^>GoY;?Soj>`
h@02oj>`h@?oXjgN00?oXj[LoinPeOnPW]800_nPW]83oj:Lc`;oXic=0_nTVl`00onOS/7oWhfooin=
_`03oj2;_P?oX8^m00?oX8^loi]m/?nMOK000_nMOK03oimo/0;oXH6a00?oXhBcoj5jZ?nQNZP00onS
OZX3ojF2[@03ojN6/OnXOjSoZ7nX00?oZH>/00?oZhR`ojf4ZOn]Q:T00on_RJd01?n`S[;o]8b/okB<
[?ndS:`2okJB/@Co_IRb1?o4X;@3olVY^@CocK:o00God[Jmolfkb?oA_LKo0000olS0dP03olc2d@?o
`/?K00Coa<CJokW2h_ni`^;o^L;R0ona`ND3ojfoi`?oZkkX0_nZ_^P00onZ_NSoooooo`00000Woooo
o`002Oooool01000003ooooooooooooooolO000000<06ATI00Go000003<c<`0c<c<0<c<co`000002
04a<C0080000001VIVH0IVIV0000001oOgl0000009VIVOl000030;>c/`03o`00003<c<`0c<c<00D0
c<c<00?o00000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00H0
Ogmo0`00000309VIV@03o`0000000000000000@0/k>c0ol0000D0<c<c003o`00002c/k<0/k>c00@0
/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`040000001VIVH0IVIV00000080C4a<00D00000
03<c<`0c<c<0<c<c0000000501TI6AX000001?ooool00`00003oooooooooo`0Looooo`?o00000_oo
oolAojVmj003ojVlj?nX_>OoYk_W00?oYk_W00?oYkWVojFfiOnT/n<00_nT/n<3oj>`h@03oj>]g_nN
XmWoWj3E00;oWj3E0onPW]801?nRW<ooWI36oij?`onNSl<4oin>`@;oWhfo0_nPRkh2oj2;_@03oiYm
/_nKOK3oVgf`00?oWGf`0onOOk000onQPK7oWWRWoj5jZ002oj5jZ0?oXgjZ0onUPZd3ojQoZ0?oZH>/
0on]Q:T3ojn9[@Co]8b/0_nfT[401?nkTZgo_IRbokfH/_nmV;84olBP]004olZS/Oo9ZKWobJViom2]
]P;ocK:o0_oB][d2om6maP04o`000?oE_/CoeKk4olc2d@;oc/??00Go`/?KolC4f_o4a=[oa<CJokW2
hP02okW3h@;o/L7U1?n]_nL3oj^nj0?oZ[gX00?o0000ooooooooool09Oooool000Wooooo00@00000
oooooooooooooooo7P00000401TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP03
0000001oOgl000000080VIVI00@000000;>c/`2c/k?o00002@3<c<`00ol00000/k>c0;>c/`020;>c
/`050000002IVIT0VIVI09VIV@000000301oOgl3000000<0VIVI100000030;>c/`Co00003`3<c<`0
0ol00000/k>c0;>c/`060;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl010000000IVIV06IV
IP00000204a<C0050000000c<c<0<c<c03<c<`000000100I6ATJ000000Cooooo00<00000oooooooo
ool06_ooool2o`0000?ooooo4_nY_NP2ojVlj0;oZ;cW0_nW^nL2ojJiiP;oYKKU00?oY;?Soin]hOnO
[N400_nNZ=d3oijSf@?oWj3E00CoX9kBoi^AbOnMT<KoWI360onNSl<3oin>`@;oWhfo00?oX8^noiYn
/onJOK800_nJOK83oi]m/0;oWGf`0onOOk03oiihY`?oXGZX0onSOZX00onUPZgoYWbUojQoZ002ojQo
Z0?oZH>/0on]Q:T3ojn9[@05ok:8Z?ndS:co]8b/okB<[?nfT[400_nkTZd2okfH/P;o`iZ^0_o4X;@2
olZS/@04olVY^Oo@[KKod:ffolfb_`?od[Jm00?oekRjom6ma_l000000_oE_/@3olk3c`?oa<CJ0_o6
aMT00oni`n7o^/?Qok71i@02ok71i@Co[KoW00?oZkkXoj^nionZ_NP00onZ_NP00ol0003ooooooooo
o`0Tooooo`002Oooool01000003ooooooooooooooolN000000<06ATI00D0000003<c<`0c<c<0<c<c
0000000204a<C0030000001VIVH000000080Ogmo00<0000009VIV@0000000P2c/k<00ol00000c<c<
0<c<c0080<c<c005o`00002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0307moO`D0
000000?o000007moO`1oOgl00`1oOgl2000000D0VIVI0P0000050;>c/`[o00000`3<c<`2o`0000X0
/k>c00Co000009VIV@2IVIT000000`1oOgl010000000IVIV06IVI_l0000304a<C004o`00000c<c<0
<c<c000000D06ATI6@000004ooooo`0300000?oooooooooo01Oooooo0ol00003oooooaCoZKgX00?o
ZKcXojRlj?nX_>P00onW^^L00onV^NKoXkGVoj>eiP02oj6ai0?oWjgQ0_nNZ=d00onNXmWoUiOBoiVD
c@02oiVDc@?oVi790_nMT<H3oij?``04oin>`OnIPKSoVWnfoiYo]P?oVWjc0onJOK82oi]m/0?oWGf`
00?oWgn`oiaeY_nNN:L00_nNN:L3oj5jZ0;oXgjZ00?oY7RSojIlYOnVO:D01?nXOjP00onYPjco[86V
ojf4Z@03ojf4Z@03ojn9[OnbR:So/XRX00?o]8b/1?nkTZd01?nmV;;o`iZ^ol>J[_o4X;@3olZS/@?o
d:ff00?oeK2com:f_OoB][d00_oG^;X2o`0000;oeKk400Gof;o1olk3cooAa<kodLC>olC4fP02olK5
f@05olO5f?nj`n7o^/?Qok[3hOna`ND00onb`ND2ojfoi`?oZkkW0onZ_NP00ooooooo0000ooooo`0T
ooooo`002Oooool01000003ooooooooooooooolM000000@06ATI00@0000003<c<`0c<c<000000P1<
C4`00`000000IVIV0000000207moO`030000002IVIT000000080/k>c00?o00000<c<c03<c<`00P3<
c<`4o`0000@0c<c<00Co00000;>c/`2c/k<000000`2IVIT00ol00000Ogmo07moO`0207moO`030000
001VIVH0IVIV00@0IVIV1@00000207moO`D000000P2IVIT5000000X0/k>c0ol0000<0;>c/`050000
002IVIT0VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP00000304a<C0040000000c<c<0<c<c
000000D06ATI6@000004ooooo`0300000?oooooooooo01Kooooo0_l00003oooooaGoZKgX1OnX_>P0
0onW^^OoYKSWoj>eiP03oj>eiP;oXK7T00CoWjgQoiRSgOnGWMOoUigG0onGUm83oiVDc@;oVi790_nM
T<H2oij?``03oiV3^_nIPKSoVH6h00;oVWnf0onJO[<3oiYm/P;oVgf`0_nMOK000onILjOoW7FVoiae
YP03oiihY`?oXGZX00?oXgjZojAhXonTN:<00onVO:D3ojQoZ0?o[86V0on]Q:T3ok:8Z0?o]8b/1?nk
TZd3ol>J[PCobZ>a00?od:N_om2]]_o@[KH00_oE/;<3o`000003omFna?l0003oeKk400;of;o10ooA
a<h00ooCa<coa/GIolO5f002olO5f003ok[3hOnk`n7o^l?Q00?o//7U0on]_nL3oj^ni`?oZ[gX00?o
0000ooooooooool08oooool000Wooooo00@00000oooooooooooooooo6`0000000ol000006ATI01TI
6@0301TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl01@000000VIVI
0000002c/k?o00000080c<c<0ol000040>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01@00
0000VIVI09VIV@2IVIT000000080Ogmo00<00000o`00001VIVH02`1VIVH3000000@0Ogmo0`000004
09VIV@L000004`2c/k<010000000VIVI09VIV@00000207moO`040000001VIVH0IVIV000000<0C4a<
00@0000003<c<`0c<c<000001@0I6ATI000000Cooooo00<00000ooooooooool05_ooool00ol0003o
ZKgXojVmj00GojVmj0CoZ;cX00CoYk[WojFhionU^>OoYKSW0_nS]NH00onN/>CoVj[Qoi^Zh@03oiRS
g@;oUigG0onGUm82oiVDc@04oi^AbOnDQL3oUhBmoiN4_@?oVH>j0onIPKP2oiYo]P;oVWjc0onJOK80
0onKOK3oUg:XoiUcY`02oiUcY`?oW7FV0onNN:L2oj5jZ0?oY7RS0onVO:D2ojQoZ004ojYmXon/PJKo
[86Vojb1YP;o[HBY00?o/HFUok:8Z?nbR:P00_nbR:P00ondS:co^HjYokV>Z@03ok^B[@?o`iZ^00?o
bIj/olZS/Oo:Xk400_o@Yjl01?o@[KKo0000o`000?l00003omNh^P04omZi]ooE_/Co0000omRo`@;o
fl2o00?odLC>om?4c?oCa<`00oo7aMP2olS6f003ok_3hOnka>7o//7U00?o//7U0on]_nL2oj^ni`Co
Z[gX00?o0000ooooooooool08_ooool000Wooooo00@00000oooooooooooooooo7000000401TI6@04
0000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl01@000000VIVI0000002c/k?o
00000080c<c<00?o00000>KViP3Vi^H01P3Vi^H01?l00000c<c<0<c<c?l000020;>c/`040000002I
VIT0VIVI00000080Ogmo00<0000006IVIP1VIVH0101VIVH5000000H0IVIV1000000307moO`@00000
1`2IVIT300000140/k>c00@0000009VIV@2IVIT000000P1oOgl010000000IVIV06IVIP00000304a<
C0040000000c<c<0<c<c000000D06ATI60000004ooooo`0300000?oooooooooo01Kooooo00?o0000
ojVmj?nY_NP05_nY_NP5ojRlj0;oYk[W00?oYKSWoj:ei_nR]NH00onN/>@2oi^Zh@;oV:?M00?oUigG
ohf?dOn?R/X00_n?R/X2oi67a@;oU8G00onGQ;d3oiV3^P;oVH6h0_nJOkH3oiYn/`03oiYm/_nELZWo
Ug:X00;oUg:X0_nILjL3oiaeYP?oWWRW00?oXGZXoj5eX_nTN:<00onTN:<2ojIlY@03ojQoZ?nZOJ?o
ZWfS00?o[86V00?o[HBYok65YOnaQJD01?nbR:P3okV>Z@;o^i:]0_o1UZ/00oo3VZkobIj/olVN[002
olZS/@?o00000ooE/;<01ooI/[7oekRjomZi]ooJ^KOogKZdomRo`Ol000000_oK`;l3om?4c005omG6
boo7aMSob<KHolS6f?o:b=P00onka>44ok;1i@;o[KoW0on[_^L3ojZmj003o`000?oooooooooo02;o
oooo0009ooooo`0400000?oooooooooooooooa`00000100I6AT01P000000<c<c03<c<`000000C4a<
o`000080IVIV00L0000007moO`000000VIVIo`00002c/k?o00000080c<c<00?o00000>KViP3Vi^H0
1`3Vi^H01?l00000c<c<0<c<c?l000020;>c/`030000002IVIT000000080Ogmo00<0000006IVIP1V
IVH00P1VIVH2o`0000030000001<C4`0C4a<00<0C4a<0P0000000ol00000IVIV06IVIP0506IVIP<0
0000101oOgl4000000H0VIVI0P00000@0;>c/`040000002IVIT0VIVI00000080Ogmo00@0000006IV
IP1VIVH000000P1<C4`010000000<c<c03<c<`00000501TI6@03o`0000000000000001D000001?oo
ool00`00003oooooooooo`0Fooooo`03o`000?nY_NSoZKgX01KoZKgX1?nX_>P2ojJkj0?oY;WW0_nR
]NH00onN/>CoUjWSoi:PgP02oi:PgP;oSYOH0_n=Sm43ohn:bP;oTHO50_nDQL02oiN4_@?oVH>j0_nI
PKP00onJOkKoTgF^oi=c[002oi=c[0;oUG:Y0onGLZP3oiUcY`;oW7FV0_nNN:L00onMLZ7oXGFRoj5e
XP04ojAhX`;oYWbU1?nZOJ<2ojb1YPCo/HFU0onbR:P3okV>Z@06ok^B[Oo1UZ_o`IJ[ol6FZoo3VZko
bIj/0ol00002om2W[`03omF[[OoE/;?oeK2c00;ofK:a0ooJ^KL01ooM^[Coh;Zaom_0_ol0003ofl2o
omg1_?oCa<`00_oEa//00ooHal[ob<KHol[8f002ol[8f003ok_4hOnla>7o_<CQ00?o//7U0on]_nL3
oj^ni`?oZ[gX00?o0000ooooooooool08Oooool000Wooooo00@00000oooooooooooooooo70000004
01TI6@060000000c<c<0<c<c0000001<C4`000000P1VIVH02@00003o000009VIV@2IVIT000000;>c
/ol00000c<c<o`00000:0>KViP04o`00003<c<`0c<c<o`000080/k>c00<0000009VIV@0000000P1o
Ogl01@000000IVIV06IVIP1VIVH0000000/0C4a<0`00000706IVIP@00000101oOgl3000000D0VIVI
00<000000;>c/`2c/k<03@2c/k<010000000VIVI09VIV@00000207moO`040000001VIVH0IVIV0000
0080C4a<00@0000003<c<`0c<c<000001@0I6ATH000000Cooooo00<00000ooooooooool05Oooool0
1?l0003ooooooooooooooolGojVmj0;oZ;cX1?nV^nP01?nT^NOoXKKWoib`i_nL/>H3oiNYh`?oTZ3N
0_n>UmP2ohf?d@;oSh[:0_nAQlD2oiB5`0?oUhBm00CoVH>joi9i/onCMk7oTgNa0onCMJh2oi=c[0;o
UG:Y0onGLZP3oiUcY`;oW7FV00?oWWRWoiebXOnMLZ400onQMJ83ojAhX`;oYWbU1?nZOJ<2ojb1YP04
ok22XonaQJGo/HFUok65Y@;o/XRX0_nhRjH2okV>Z@?o`IJ[0ol00002olVN[0;od:N_0_oEZjd01_oE
/;?ofK:aomVb/OoI/[7og;>^omZi]`;ogKZd0_oP^[401Ol0003ogL6lomg1_?oP`k_oeLK;00;of<O:
0oo:b=P2ol_9f003okc4hOnkaN7o//7U00?o//7U0on]_nL2oj^ni`CoZ[gX00?o0000ooooooooool0
8?ooool000Wooooo00@00000oooooooooooooooo7000000301TI6@040000000c<c<0<c<c00000080
C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c/ol000000P3<c<`01?l00000i^KV0>KV
iP3Vi^H4o`0000<0i^KV00Co00000<c<c03<c<co00000P2c/k<01@000000VIVI0000001oOgl00000
00<0IVIV00<0000004a<C01<C4`00`1<C4`4o`0000H0C4a<1`00000406IVIP<00000101oOgl20000
00@0VIVI00<000000;>c/`2c/k<0302c/k<01`000000VIVI09VIV@2IVIT0000007moO`0000000P1V
IVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00<06ATI60000004ooooo`030000
0?oooooooooo01Gooooo00Co0000oooooooooooooooo5_nY_NP2ojRmj0;oZ;cX0_nV^nP2ojBij0;o
XKKW0_nL/>H00onGZN?oS9oPohFCf@02ohFCf@;oPHSA0_n1PLT2ohAl`P;oRGZm0_n=N[T3oi5j]P;o
TWVc0_nCMk43oi=e[P;oTg>/0onELZT3oiMbZ0;oVG>W00?oW7FVoiY`XOnMLZ400_nMLZ43oj5eXP?o
Y7RS00?oYWbUojQjXOnXNZ400onZOJ<00on/PJKo/8:Sok22X`03ok65Y@04ok:8Z?nhRjKo^8^VokR;
YP;o^HjY0ol000000oo1UZ_obIj/olVN[002olVN[004olnTZoo@YjooeJ^]omF[[@?ofK:a0_oL/jh0
0ooJ^KOogKZdon2j/@02on2j/@04omg1_?l0003ogL6lon33^`?of<O:00?of/[:ol[8f?o;bMP00_o;
bMP3ok_5h@Co//7U0_n]_nL3oj^ni`?oZ[gX00?o0000ooooooooool08?ooool000Wooooo00@00000
oooooooooooooooo6`00000401TI6@060000000c<c<0<c<c0000001<C4`000000P1VIVH200000080
VIVI00D000000;>c/ol00000c<c<o`0000030>KViP05o`00003oool0oooo0?ooool000000`3Vi^H0
2?l00000c<c<0<c<c?l00000/k>c0000002IVIT000000P1oOgl01@000000IVIV06IVIP1VIVH00000
00<0C4a<0_l0000403<c<`Go0000201<C4`00`00003o000006IVIP0406IVIP0300000?l00000Ogmo
00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`0;0;>c/`050000002IVIT0VIVI
09VIV@0000000P1oOgl010000000IVIV06IVIP00000204a<C0040000000c<c<0<c<c000000@06ATI
60000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00_oooolEojVmj003ojRm
j?nX_>SoZ;cX00?oYk_X00?oY;WXoj6gj?nL/^L00_nL/^L2oiBYi@;oS9oP0on5TmT2oh68d@03oh61
bOn4O<;oQ7c200;oRGZm0on=N[T2oi5j]P?oTWVc0_nCMk42oi=e[P?oTg>/0_nELZT3oiMbZ004oiUc
YonFKJ;oVW2QoiY`X@?oWG:Q0onQMJ82ojAhX`04ojIgWonXNZ7oZ7ZQojQjX@?oZWfS0on`PZ<3ok65
Y@?o^8^V0ol000000onoTjSo`IJ[ol6FZ`02olRKZP;obIj/0_o?Y:/01?o@YjooeJ^]omF[[OoI[Z/2
omVb/@;og;>^0_oM^[@3on2j/@06on>k[ooM`Kco0000on33^ooSaKWof<O:0_oJb/X2om_<bP04ol_9
f?o;b]Wobl[Iok_5h@;o^lGR0_nb`ND01?na`NGo[KoWojfoion]_nL3oj^ni`?oZ[gX00?o0000oooo
ooooool07oooool000Wooooo00@00000oooooooooooooooo6`00000301TI6@0?0000000c<c<0<c<c
03<c<`000000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000080c<c<00Co0000
0>KViP3Vi^Ko00001@3oool01?l00000i^KV0>KVi_l000020<c<c005o`00002c/k<0000009VIV@00
00000P1oOgl01?l00000IVIV06IVIP00000304a<C003o`00000c<c<0<c<c00T0<c<c1Ol0000504a<
C0@000000`1VIVH2000000<0Ogmo00?o00000000002IVIT00P2IVIT00ol00000/k>c0;>c/`0;0;>c
/`040000002IVIT0VIVI00000080Ogmo00@0000006IVIP1VIVH000000P1<C4`010000000<c<c03<c
<`00000401TI6AP000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo
5OnY_NP2ojRlj003ojNkj?nU^^SoXKOX00;oXKOX0onL/^L2oiBYi@;oS9oP0_n5TmT2oh68d@;oPH79
0_n4O<82ohUj_@;oSGZi0onAN[H2oi9i/`;oTgNa0onCMJh2oi=c[0;oUG:Y0_nGLZP00onBK:?oUVfR
oiI]XP03oiY`X@?oWG:Q0_nQMJ800onTN:?oYWNOojIgW`03ojQjX@?oZWfS1?n`PZ<2ok65Y@?o0000
00?o^8^VoknCZ?noTjP00_noTjP01?o1UZ_ob9^ZolRKZ_o9WZ`3olnTZ`;oeJ^]0ooI[Z/01OoI/[7o
g;>^ombc[_oO]:_ogKZd00;oh;Za0_oS^jl2on33^`03o`000?oSaKWof/[:00;of/[:0_oKc<X3ol_:
f@03ol[;f_nkaN;o^lGR00Co/L7U0on]_nL2oj^ni`CoZ[gX00?o0000ooooooooool07_ooool000Wo
oooo00@00000oooooooooooooooo6`00000301TI6@0?0000000c<c<0<c<c03<c<`000000C4a<0000
001VIVKo000007moO`000000VIVI0000002c/k?o00000080c<c<00Co00000>KViP3Vi^Ko00001@3o
ool01?l00000i^KV0>KVi_l000020<c<c005o`00002c/k<0000009VIV@0000000P1oOgl010000000
IVIV06IVIP00000204a<C003o`00000c<c<0<c<c00l0<c<c0ol0000604a<C08000000`1VIVH01@00
0000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00`2c/k<5o`0000<0/k>c00@00000
09VIV@2IVIT000000P1oOgl010000000IVIV06IVIP00000204a<C0040000000c<c<0<c<c000000@0
6ATI60000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool01OoooolCojVmj004
ojRmj?nW_>SoYkcXojNlj0;oYK[X00?oXKOXoibdj?nL]>P00_nC[>L2ohROh`;oOI7L0_mdP]<2og5g
bP;oM7720_n4O<82ohUj_@;oSGZi0onAN[H2oi9i/`;oTgNa0onCMJh2oi=c[003oiEbZOn?JjGoTVbS
00;oTVbS0_nFKJ83oiY`X@?oWG:Q0_nQMJ83ojIgW`CoZ7ZQ00?oZWfSojmoXOn`PZ<00on`PZ<2o`00
0004okN9Y?nhRjKo^8^VokR;YPCo_i>X0oo8VjX4olnTZ`03omBXZ_oEZjgofJj[00;ofJj[0_oL/jh2
omndZ`;oh;Za0ooS^jl01_oV_Zgoh<>ko`000?oSaKWoi/Viom[:bP;oflc:0_oLcl/00oo;b]Wob/_J
ol[;fP03ok_5hP;o/L7U0_na`NH2ojfoi`?oZkkW0onZ_NP00ol0003oooooooooo`0Nooooo`002Ooo
ool01000003ooooooooooooooolJ000000<06ATI00L0000003<c<`0c<c<0<c<c0000001<C4`00000
0080IVIV0P000000102IVIT000000;>c/ol000020<c<c004o`00003Vi^H0i^KVo`0000H0oooo00So
00000>KViP3Vi^Ko00000<c<c?l00000/k>c00000080VIVI00<0000007moO`0000000P1VIVH01000
0000C4a<04a<C?l0000703<c<`Co00002P0c<c<4o`0000@0C4a<00Go000006IVIP1VIVH0IVIV0000
000307moO`050000002IVIT0VIVI09VIV@000000102c/k<00ol00000c<c<0<c<c0020<c<c005o`00
002c/k<0/k>c0;>c/`0000000P2IVIT010000000Ogmo07moO`00000206IVIP030000001<C4`00000
00<0<c<c00<0000001TI6@0I6AT00P0I6ATG000000Cooooo00<00000ooooooooool05Oooool00ol0
003oooooooooo`06oooooa7oZKgX0onX_NP00onW_>SoY[_XojJkj003oj:hj0;oW;CX0_nC[>L2ohRO
h`;oOI7L0_mdP]<00omaMl[oM772ogAa`P02ogY_^`;oPG2g0on=N[T2oi5j]P04oi9i/on<LK3oS6n]
oha_[@?oS6f[0_n=K:P2ohm[Y@?oTVbS0_nFKJ83oiY`X@?oWG:Q0_nQMJ84ojIgW`?oZ7ZQ00?oZWfS
ojmoXOn_Oj400ol00003okN9Y0;o^8^V00?o_i6WoknCZ?noTjP00_noTjP3olRKZP03oljRZ_o?Y:_o
cjB[00;oe:RZ00KoeJ^]omV^ZooI[Z_ofJj[omb^ZOoL/jh2omndZ`04on6dZ?oP^[7ohk^_on>k[`;o
i[j]0_oSaKT01?l0003oi/VionW<^OoKc<X2omc?b`;og=7=00Cob/_JolW<foo9c=_o^lGR0_njaN<3
ok71iP?o[KoW00?oZkkWoj^nj?n[_^P00onZ_NP00ol0003oooooooooo`0Mooooo`002Oooool01000
003ooooooooooooooolI000000@06ATI0140000003<c<`0c<c<0<c<c0000001<C4`0000006IVIP00
0000Ogmo0000002IVIWo00000;>c/ol00000c<c<o`0000020>KViP03o`00003oool0oooo00D0oooo
00oo00000>KViP3Vi^Ko00000<c<c?l00000/k>c0000002IVIWo00000000001oOgl0000006IVIP00
00000P1<C4`00ol00000<c<c03<c<`0203<c<`Co0000100I6AT7o`0000L0<c<c0_l0000304a<C005
0000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c00?o0000
0<c<c03<c<`0103<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00<0000007moO`0000000P1V
IVH00`000000C4a<0000000303<c<`030000000I6AT06ATI00806ATI5`000004ooooo`0300000?oo
oooooooo01Cooooo00?o0000ooooooooool02?oooolAojVmj004ojRmj?nX_>SoZ;cXojRlj0;oY[_X
00CoX[SXoijfjOnE[nSoUJoX0_n8XnH2ogRBh0;oJ7oF0_mOKl/2og5gbP03ogAa`_mjKk_oNVnk00;o
PG2g0on6LK@2ohYb/P;oS76`0on<Kjd2oha]Z`;oSFbX0_n?JjD3oi9/X`?oUVfR0_nJL:43oiebX@03
oj5eX_nRM9koXWBN00?oYWNO0onXNZ43o`0000?o/8:S0ongRJ@01?nhRjKo_i6WoknAYonoTJL2oknC
Z0;oaiZY00?ob9^ZoljRZ_o>XZX00_o?Y:/2omBXZP?ofJj[0_oL[ZT01OoL/jkogkB[on6dZ?oQ]:So
i;JV00;ohk^_0_oV_Zd01ooZ`J_ohlFionK9^Ol0003ojLbion_@^OoLcl/00ooLdLd01OoLd/oobLcK
olS<gOo8c=go^/GS00;o^LGT0ona`NH00on]_nOo[;oWojboi`02oj^nj0CoZ[gX00?o0000oooooooo
ool07?ooool000Wooooo00@00000oooooooooooooooo6@00000401TI6@0A0000000c<c<0<c<c03<c
<`000000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l000000P3Vi^H0
0ol00000oooo0?ooo`050?ooo`0:o`00003Vi^H0i^KVo`00003<c<co00000;>c/`000000VIVI0000
0080Ogmo00<0000006IVIP0000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000l06ATI0ol00006
03<c<`04o`00001<C4`0C4a<000000<0IVIV00@0000007moO`1oOgl000000`2IVIT01@000000/k>c
0;>c/`2c/k?o000000L0c<c<00Wo00000;>c/`2c/k<0/k>c0000002IVIT0000007moO`0000000P1V
IVH00`000000C4a<0000000303<c<`030000000I6AT06ATI00806ATI5`000004ooooo`0300000?oo
oooooooo01Cooooo00?o0000ooooooooool02_ooool@ojVmj0;oZ;cX00CoYkcXojBjjOnT^^WoY;[Y
0_nN]^T2oiF_j0;oR:?V0_mhT^02ofQoeP03oem_bomOIL7oGfG100;oM7720_mjKk/2oh5`]`;oQW6d
0_n:L[82ohaa/0?oS6n]0_n<KJ/2ohe/Z0?oSf^U0onBK:<2oiI]XP?oVW2Q0_nMLZ43oj9dWP?oYWNO
0ol00003ojmoX@;o/8:S00Co]hNSokN9Y?ngRJCo]hVT1?noTJL01OnoTjSoaiZYolNJZOo7VZWob9^Z
00?ocZ:Z00GocjB[omBXZ_oDZ:[of:ZYomV^Z`03omb^Z@;ogkB[0_oQ]:P2onBfYP04on>k[ooV_Zgo
j/6[on[1Z`;oi/Vi00?ojLbio`000?o[d;T00ooLdLd2omcBc`?ob<cM0oniaN@4ok31iP;o[;oW0on[
_^P3ojZmj003o`000?oooooooooo01cooooo0009ooooo`0400000?oooooooooooooooaT00000100I
6AT010000000<c<c03<c<`0c<c<200000080IVIV00T0000007moO`000000VIVI0000002c/k?o0000
0<c<c?l000000P3Vi^H00ol00000oooo0?ooo`050?ooo`0:o`00003Vi^H0i^KVo`00003<c<co0000
0;>c/`000000VIVI00000080Ogmo0P00000304a<C004o`00000c<c<0<c<co`0001<06ATI0_l00005
03<c<`04o`00001<C4`0C4a<000000<0IVIV00<0000007moO`0000000`2IVIT01@000000/k>c0;>c
/`2c/k?o000000L0c<c<00Wo00000;>c/`2c/k<0/k>c0000002IVIT0000007moO`0000000P1VIVH0
0`000000C4a<0000000303<c<`030000000I6AT06ATI00806ATI5`000004ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool?ojVmj0;oZ;gX0onW_>P00onT^^WoXKSYoj6hj@02
oiVbj@;oRjOX0_mgU^@01?mQOm[oCfS=odmXcOmOKl/2oemU`@;oIV>j0_mjKk/2oh5`]`?oQW6d0_n:
L[82ohaa/0;oS6n]0on<KJ/2ohe/Z0;oSf^U0onBK:<2oiI]XP?oVW2Q00?oWG:QoiiaW_nRM9h00_nR
M9h3o`000003ojQjXOn]OIoo[GfO00?o[gnQ00Co/8:SokN7XongQj?o]hNS0_ngRJ@01OnoTJKo_i6W
oknAYonoTJOo_i>X00?oaiZY00Cob9^ZoljRZ_o>XZ[ocZ:Z0_oDZ:X2omRZZ@07omV^ZooL[ZWog:jY
omb^ZOoM[ZKogkB[on6dZ003onBfYP;oi[j]0_oZ`J/01oo^aJWoi/VionW<^Ol0003ojm2ioncC^ooL
dLd00_oLd/l2om[Cd@04olS<gOo7c=koalcNokW5i0;o^<GT0_n``NH2ok31i`;o[;oW0on[_^P3ojZm
j003o`000?oooooooooo01_ooooo0009ooooo`0400000?oooooooooooooooaT00000100I6AT04000
0000<c<c03<c<`000000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l0
00020>KViP03o`00003oool0oooo00H0oooo00ko00000>KViP3Vi^Ko00000<c<c?l00000/k>c0000
002IVIT0000007moO`000000IVIV00000080C4a<00Go000003<c<`0c<c<0<c<co`00000E01TI6@03
o`00000c<c<0<c<c00<0<c<c00Co000004a<C01<C4co00000P1VIVH010000000Ogmo07moO`000002
09VIV@040000002c/k<0/k>co`0000T0c<c<00_o00000;>c/`2c/k<0/k>c0000002IVIT0000007mo
O`000000IVIV0000000204a<C0040000000c<c<0<c<c000000@06ATI5`000004ooooo`0300000?oo
oooooooo01Cooooo00?o0000ooooooooool02oooool?ojVmj0;oZ;gX00?oYkcXojFkjOnU^nT00onQ
^>T2oiVbj@;oRjOX0_mgU^@01OmQOm[oCfS=odUI`OmOKl_oGfG100;oIV>j0_m`I;H3oh5`]`;oQW6d
0_n:L[82ohaa/0?oS6n]0_n<KJ/2ohe/Z0;oSf^U0onBK:<2oiI]XP;oVW2Q00?oVFjOoiiaW_nNLIh0
0ol00003ojIgW`Co[GfO0_n_Oj44okN7X`03okN9Y?noTJKo_i6V00?o_i6W1?o7VZT4oljRZP04om>W
ZooDZ:[of:ZYomRZZ@?og:jY0_oM[ZH2on6dZ0?oi;JV00?oj;RSonJn[OoZ`J/00_o^aJT01ooabZSo
jLbion_@^Ol0003ok=>koncF_OoLd/l00_oJdm42omWDe004olO<g_o5cN3oaLgPokS5i0;o]lKU0_n`
`NL01_n_`NOo[;oXojboj?n/_nSoZkkXojZnj0?oZ[gX00?oooooo`000?ooool06oooool000Wooooo
00@00000oooooooooooooooo6@00000401TI6@0@0000000c<c<0<c<c0000001<C4`0000006IVIP00
0000Ogmo0000002IVIT000000;>c/ol00000c<c<o`000080i^KV00?o00000?ooo`3oool01P3oool0
4?l00000i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIV@000000Ogmo0000001VIVKo000004a<
C?l0000303<c<`03o`00000I6AT06ATI01D06ATI00?o000003<c<`0c<c<00P0c<c<01Ol00000C4a<
04a<C01<C4`000000080IVIV00<0000007moO`0000000P2IVIT010000000/k>c0;>c/ol000040<c<
c0;o0000103<c<`02_l00000/k>c0;>c/`000000VIVIo`00001oOgl0000006IVIP00000204a<C004
o`00000c<c<0<c<c000000@06ATI5`000004ooooo`0300000?oooooooooo01Cooooo00?o0000oooo
ooooool03Oooool=ojVmj0?oZ;cX00?oYK_Yoj>jjOnS^^T00onM]^X2oi2]jP03ogbMiomQQ=ooHHCO
00;oA6O@00CoCfS=odUI`OmOIL7oGfG10_mVHkX01?m`I;KoNFRcogUX/omiJ;<2oh5//P;oRW:b0_n<
LK03oha_[@;oS6f[0_n=K:P2ohm[Y@?oTVbS00CoUVfRoi=ZX?nIKYooVFjO0ol00004oj9dWP;oYWNO
1?n]OIl2ojmoX@Co]hNS00?o]hVToknAY_noTJH00onoTJL01?o8Vj[oaiZYolNJZOo7VZT3oljRZP;o
djN[00Coe:RZomRZZOoHZZWofJ^X0_oL[ZT2omf^YP04omn_Y?oQ]:Soi;JVonBfYP;oj;RS0_oZ`J/2
onk5Z@08oo7:Z?odcjSojm2ioncC^ol0003ok=JmoncI`?oJdm42omWDe0;oemKG00GoaLgPol?=h_o3
cN;o]lKUokG6iP03ojo1i`Co[;oX0_nZ_^P3ojZmj003o`000?oooooooooo01[ooooo0009ooooo`04
00000?oooooooooooooooaT00000100I6AT040000000<c<c03<c<`000000C4a<0000001VIVH00000
07moOol00000VIVI0000002c/k?o00000<c<c?l000020>KViP03o`00003oool0oooo00D0oooo00So
00000>KViP3Vi^H0i^KVo`00003<c<co000000000080VIVI00L0000007moO`000000IVIV0000001<
C4co000000<0<c<c00?o000001TI6@0I6AT0100I6AT:000000P06ATI00Go000003<c<`0c<c<0<c<c
o`00000304a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT010000000/k>c0;>c/ol00002
0<c<c0;o00000P3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c00L0000009VIV@000000Ogmo
0000001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6ATG000000Cooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`0=ooooo`koZKgX00CoZ;cXojNlj?nW_>SoYkcX0_nS^^T0
1?nM]^[oUk;ZohBUjOn4YNT2ofN>i0;oHHCO00?oA6O@oc=?`?m9FL400_m>E;P2ofIS^P;oL6Bf0_mi
J;<2oh5//P;oQ6fa0_n5KJl3ohAZ[P;oPfN[0_n4IZL00on?JjGoR6JToheWXP02oheWXP05oi=ZX?l0
003o0000o`000?nIKYl00onNLIh3oj9dWP03ojIgWonZNYoo[GfO00?o[GfO00?o[gnQokJ6X_nfQZ80
0ongQj<01OngRJCo_i6VoknAY_noTJKo_i6W00;ob9^Z0_o7VZT2oljSZ`04oljRZ_oCYj_odjN[om>W
Z`;of:ZY0ooIZjP01?oL[ZWogJjVomf^Y_oO[j@3onBfYP;oj;RS00?ok;bQon[1Zoo^aJT00_oabZP0
2?odcjSom]>XoncC^ol0003ok=JmoncI`?o[flCofMCD0_oGe]L01?oDem_o`lgRol?=h_o3cN83okG6
iP03ojo1ion^`NSo[/7X00;o[;oX00SoZkoXojZnj?nZ_^SoZ[kXojZmj?nY_NSoooooo`0001_ooooo
0009ooooo`0400000?oooooooooooooooaP00000100I6AT01P000000<c<c03<c<`000000C4a<0000
0080IVIV00H0000007moO`00000000000;>c/ol000020<c<c004o`00003Vi^H0i^KVo`0000L0oooo
013o00000>KViP3Vi^Ko00000<c<c?l00000/k>c0000002IVIT0000007moO`000000IVIV0000001<
C4co00000`0c<c<00ol000006ATI01TI6@0401TI6@`00000200I6AT01Ol00000<c<c03<c<`0c<c?o
00000080C4a<00P0000006IVIP1VIVKo000007moO`000000VIVI00000080/k>c00Co00000<c<c03<
c<co00001@3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c0P00000207moO`050000001VIVH0
000004a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6AL000001?ooool00`00003ooooooooo
o`0Cooooo`03o`000?oooooooooo00oooooo3?nY_NP3ojRmj003ojNlj?nU^nWoXKSY00;oXKSY0_nG
/^X2ohBUj@03ofN>i?m2K=Ko@VcF00;oA6O@00?o<do0odUI`Om>E;P00omJE[<01Om`I;KoNFRcogUX
/omiJ;?oPFbb00;oQ6fa0_n5KJl3ohAZ[P;oPfN[0_n4IZL2ohQVY005oheWX_l0003o0000o`000?nC
JZ000onIKYl3oiiaWP?oXWBN0_nZNYl4ojemW`03ojmoXOnfQZ;o]XJR00?o]hNS1?noTJH01OnoTJOo
b9^ZolRKZ_o8Vj[oaiZY00;ocZ>[00CocZ:Zom>WZooCYj_odjN[0_oHZZT3omV[Z0;ogJjV0_oO[j@2
onBfYP?oj;RS00Cok;bQonk5ZOo^aJWolLZX0_odcjP02?ofdjSommNZoncF_Ol0003ok=W0on_Ka?oY
g/SoemKG0ooDem/01?o3cN;o`<gTol3=i?nea^H2ok?5i`03ojk1j?n]`NSo[L7X00?oZkoX0onZ_^P2
ojVmj003o`000?oooooooooo01Wooooo0009ooooo`0400000?oooooooooooooooaP00000100I6AT0
1P000000<c<c03<c<`000000C4a<00000080IVIV00H0000007moO`00000000000;>c/ol000020<c<
c004o`00003Vi^H0i^KVo`0000H0oooo017o00000>KViP3Vi^Ko00000<c<c?l00000/k>c0000002I
VIT0000007moOol00000000006IVIP000000C4a<o`00000203<c<`03o`00000I6AT06ATI00@06ATI
3@0000000ol00000000001TI6@0601TI6@07o`00000c<c<0<c<c03<c<ol00000C4a<0000000206IV
IP05o`00001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<o`0000070>KViP0?o`00003<c<`0
c<c<0<c<c?l00000/k>c0000002IVIT0000007moO`000000IVIV0000001<C4`000000080<c<c00?o
00000000000I6AT00P0I6ATG000000Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0Aooooo`_oZKgX00?oZ;gXojRlj?nU^nT00_nU^nT00onQ^>WoW;KZoibfjP02ohj]j`;oLi[X00Ko
BWWMod9/e_lRB/;o8T[2oc=?`?lb@kD2odiD^0;oFUJc00CoJEfaogUX/omiJ;?oNFRc0_n1K;82ohA]
/@;oQFf_0_n4JZh2oh=WZ`;oQ6JW00?oR6JTo`000?l000000_n=Ij82oi=ZX0CoVFjO0_nNLIh2oj9d
WP04ojIgWonZNYooZWZOojYjW`?o[GfO0onfQZ83okN7X`Co_i6V1?o8VjX3oljSZ`?odjN[0_oFZZ/0
1?oHZZWofJ^XomV[Z?oIZjP2omf^YP;ogjnT00Coh[2RonBfY_oX^:?oj;RS0_o/_:401?oa`Iook/FY
oo7:Z?odcjP2ooKCZ007ooOGZ_ogfjgok=W0o`000?o[flCojMk8onKQc@02omCGf`;od=SO00Co`<gT
okg=i_nmcNKo/lGW0_naa>P00on]`NSo[<3Xoj^nj003oj^nj0;oZ[kX0onY_NP00ol0003ooooooooo
o`0Hooooo`002Oooool01000003ooooooooooooooolH000000@06ATI00H0000003<c<`0c<c<00000
04a<C000000206IVIP060000001oOgl000000000002c/k?o00000P3<c<`01?l00000i^KV0>KVi_l0
00060?ooo`0<o`00003Vi^H0i^KVo`00003<c<co00000;>c/`000000VIVI0000001oOgl000000P1V
IVH00`000000C4a<o`00000203<c<`03o`00000I6AT06ATI00@06ATI00?o00000000000000003000
000701TI6@07o`00000c<c<0<c<c03<c<ol00000C4a<0000000206IVIP050000001oOgl0000009VI
V@0000000P2c/k<00ol00000c<c<o`0000070>KViP0?o`00003<c<`0c<c<0<c<c?l00000/k>c0000
002IVIT0000007moO`000000IVIV0000001<C4`0000000<0<c<c00@0000001TI6@0I6AT06ATI5`00
0004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool;ojVmj0;oZ;cX00Co
YK_YojBjjOnT^^WoY;[Y0_nL]^X2ohj]j`;oLi[X00Oo6dg7od9/e_lRB/;o5CBaoc=?`?lb@kGoCUBh
00;oFUJc0_mYGK42ogUX/`;oPFbb0_n4KK42ohE][`?oQ6Z^00CoPfN[o`000?l0003o00000_n8IZ@2
oheWXP?oTfZP0onIKYl2oiiaWP03oj9dW_nVMiooYWNO00?oZWZO0on]OIl4okJ6XP03okN7Xoo1TZKo
`I:V00?o_i6V1?o8VjX3oljSZ`03om>Z[ooCYj_odjN[00;oeZZ[0ooIZjP2omVZYP05omf^Y_oO[jCo
gjnTon:`X_oT]ZH00_oX^:<2onblX@05oo71WooeaigolLZXooC?Z?ofdjP00_ogejX01oogfjgommj`
on_Ka?l0003ojMk8onKQcOoSi=<00_o@f=l2olcHh`05okg=i_nibnSo^L_Xok74j?n_`nP00on/`>P2
oj^nj0CoZ[kX0onY_NP00ol0003oooooooooo`0Gooooo`002Oooool01000003ooooooooooooooolH
000000<06ATI00L0000003<c<`0c<c<0<c<c0000001<C4`000000080IVIV00H0000007moO`000000
00000;>c/ol000020<c<c004o`00003Vi^H0i^KVo`0000D0oooo017o00000>KViP3Vi^H0i^KVo`00
003<c<co00000;>c/`000000VIVI0000001oOgl0000006IVIP000000C4a<o`00000303<c<`03o`00
000I6AT06ATI00@06ATI4000000601TI6@07o`00000c<c<0<c<c03<c<ol00000C4a<0000000206IV
IP050000001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<o`0000080>KViP0>o`00003<c<`0
c<c<o`00002c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C000000303<c<`040000000I
6AT06ATI01TI6AL000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
2OnY_NP2ojRmj0?oYkcX00CoY;[Yoj6ij_nG/n_oUk?[0_n2Y^/2oeb:i@03obALdOlKCLOo8T[200;o
5CBa00?o<T>eocm4[omJE[<00_mJE[<00omYGK7oMFBaogET/@02ogiZ/P;oQ6fa0_n5KJl01On4JZko
0000o`000?l0003oPfN[00;oQ6JW0_n8IZ@3oheWXP;oTfZP0onIKYl2oiiaWP?oYWNO0onZNYl2ojem
W`03okF5X_nfQZ;o]XJR00;o]XJR00?o]hNSol6BY_o1TZH00_noTJH2olZO[0;ob9^Z0_o@Z:l01Oo>
Xj_odjZ_om>Z[ooCZZoodjN[00;oeZZ[0ooIZjP2omVZYP;ogjnT0_oR/:801?oV/iooj;RSonRhXoo/
_:42oo71W`05ooG7WOodcjSom<nXooKCZ?ogejX00_ogfjd00oogg[3om^:do`000002onKQc@05on?T
dooNi][oc=SSolcHhoo6e^H00_nibnP2okK9j0;o[l?X00?o[<3Xoj^oj?n[_nP00onZ_^P5ojVmj003
o`000?oooooooooo01Oooooo0009ooooo`0400000?oooooooooooooooaL00000100I6AT010000000
<c<c03<c<`00000204a<C0090000001VIVH0000007moO`000000VIVI0000002c/k?o00000080c<c<
00Go00000>KViP3Vi^H0i^KVo`0000030?ooo`05o`00003Vi^H0i^KV0>KVi_l000000P3<c<`01_l0
0000000009VIV@000000Ogmo00000080IVIV00<0000004a<C?l000000`0c<c<00ol000006ATI01TI
6@0301TI6A<000001@0I6AT01?l00000<c<c03<c<ol0000204a<C00;0000001VIVH0000007moO`00
0000VIVI0000002c/k?o00000<c<c?l00000103Vi^H2o`0000@0i^KV00Go00000<c<c03<c<co0000
0;>c/`020000000407moO`000000IVIV00000080C4a<00@0000003<c<`0c<c<000000`0I6ATG0000
00Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`SoZKgX0onX_NP00onW
_>SoY[cYojJlj@02oj6ijP;oUk?[0_n2Y^/2oeb:i@05obALdOl0:Jko8T[2oaDd/Olb@kD00_loA:l2
oeYF/`03ofUM/OmeI;7oMFBa00;oOVZb0_n1KK<3o`0000;oN6Rc0_n3Ij/2ohAVY`;oR6JT0on=Ij82
oi=ZX0?oVFjO00?oWW6Noj5cX?nVMil00onVMil2ojYjW`04ojemWoneQJ;o]HFRokF5XP?o]XJR0oo1
TZH01OnoTJKobYn/olZO[?o:Wjcob9^Z00?od:R_00CocZ>[om>Z[ooCZZoodjZ_0ooFZZ/00ooEZJ_o
fJ^XomVZYP02omVZYP;ogjnT0_oR/:82onJcW`;ok;bQ0_oa`Il01_oeaigonLfKooKCZ?ofdjSommNZ
ooOK[@;ommj`00?om^:dooGW^Ol000000_oSi=<00ooNi][oenGPolKFiP02ol3Cj0;o]/WX00Co//KY
ojk2j?n^`^So[/;X0_n[_nP3ojZnj0KoZKgX00?o0000ooooooooool05_ooool000Wooooo00@00000
oooooooooooooooo5`00000401TI6@040000000c<c<0<c<c00000080C4a<00T0000006IVIP000000
Ogmo0000002IVIT000000;>c/ol000000P3<c<`01?l00000i^KV0>KViP3Vi^H4o`0000<0i^KV0_l0
00002P3<c<co00000;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C004o`00000c<c<0
<c<co`0000D06ATI5000000501TI6@04o`00000c<c<0<c<co`000080C4a<00/0000006IVIP000000
Ogmo0000002IVIT000000;>c/ol00000c<c<o`0000030>KViP04o`00003oool0ooooo`0000@0i^KV
00Co00000<c<c?l00000/k>c0P000000101oOgoo000006IVIP00000204a<C0040000000c<c<0<c<c
000000<06ATI5`000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool8
ojVmj0?oZ;gX00?oY[cYojBkjOnN]nX00_nN]nX2ohn_k00:og6LjolkM=ko>gCNobALdOl0:;7o02V^
oaDd/OlM;jWo<T>eocm4[`;oDdj^0_mYGK42ogET/@?o00000omnK;@2ogQX/`;oM6>a0_n4IZL3ohQV
Y0;oSFNR0_nCJZ02oiU^W`03oiU_XOnQLj3oXG>P00CoYWNO0_nZNYl4okF5XP?o]XJR0oo1TZH4olZO
[0Cod:R_1?oCZZl2omJZZ`;oeJV[00KofJ^XomVZY_oIZZKofJZVomZYY?oO[j@2on:`XP;oi[>O0_o/
_:401Ooa`IoomLNMooG7WOoicI_onm:J00;ommNZ00Somm^]ooON/?ofh[Com^:dooGW^OobkKoo0000
omkVfP;oenGP0oo0dnP4ok;6j@03ojk2j?n/`>So[<3X00;oZkoX0onZ_^P6ojVmj003o`000?oooooo
oooo01Gooooo0009ooooo`0400000?oooooooooooooooaL00000100I6AT010000000<c<c03<c<`00
000204a<C0090000001VIVH0000007moO`000000VIVI0000002c/k?o00000080c<c<00?o00000>KV
iP3Vi^H0203Vi^H03?l00000c<c<0<c<c?l00000/k>c0000002IVIT0000007moO`000000IVIV0000
0080C4a<00Co000003<c<`0c<c?o00001@0I6ATD000000D06ATI00Co000003<c<`0c<c?o00000P1<
C4`02`000000IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co000000<0i^KV00Co0000
0?ooo`3ooooo0000103Vi^H01?l00000c<c<o`00002c/k<200000080Ogmo0P00000204a<C0040000
000c<c<0<c<c000000<06ATI5`000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooooooo
ool05oooool8ojVmj003ojRmj?nW_>SoYkcX00;oY;_Y00?oW[OZoiVejonI]N/00_n5ZNd01OmKS^So
>gCNo`0h_Ol0>;go02Ra00;o5CBa00Go7BnYocm4[omCCZkoDdj^ofMJ[`03o`0000;oOVZb0_n1KK<2
ogi/]0;oN6Rc0_mdHk42ogIQ[@?oR6JT0_n=Ij82oi=ZX003oiU^WonIKj7oVFnQ00;oXG>P1?nVMil2
ojYjW`Co]HFR0_nfQZ82ol:DY`;o`I:V00CocjN_olZO[?o:WjcobYn/1?o@Z:l00ooF]KSodjZ_om>Z
[`02om>^/P03omJZZooEZJ_oeJV[00?ofJZV0_oJZJ@2on:`XP?oi[>O00CojkRMoo71Wooa`IoomLNM
0_oicI/01_okdY[ooMNJoogKVoogfjgommj`ooKR]0;omNNi00Col^foonkaaol0003oenGP0_o?h^H0
0oo0dnSo^/kYok[>j@02ok;6j@;o[lCY00?o[<3Xoj^oj?nZ_^P00onZ_^P7ojVmj003o`000?oooooo
oooo01Gooooo0009ooooo`0400000?oooooooooooooooaH000001@0I6AT010000000<c<c03<c<`00
000204a<C0090000001VIVH0000007moO`000000VIVI0000002c/k?o000000<0c<c<00?o00000>KV
iP3Vi^H01P3Vi^H02_l00000c<c<0<c<c?l00000/k>c0000002IVIT0000007moO`00000206IVIP03
0000001<C4co00000080<c<c00?o000001TI6@0I6AT00`0I6ATF000000@06ATI013o000003<c<`0c
<c?o000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co00000`3Vi^H0
0ol00000oooo0?ooo`020?ooo`0Ao`00003Vi^H0i^KV0>KVi_l00000c<c<o`00002c/k<0000009VI
V@000000Ogmo0000001VIVH0000004a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6AH00000
1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo2?nY_NP00onW_>SoYkcY
ojNlj@03oj>jj@;oVKG[0_n5ZNd02?mKS^So4UOAo`0h_Ol0:;7o01VPoaDd/OlM;jWo=3VX0ol00000
0omWFZooMfFbogMU/P02ogiZ/P;oPFfc0_mnK;@3ogQX/`03ogAS/OmfHJgoMV6]00?oOF:Y0_n6IZH2
oi1[X`?oVFnQ0onQLj03ojIgW`03ojYjWonbPj?o/X>S00?o]HFR00Go]XJRol:DYoo2U:Oo`YBWol6B
YP02olnW[`;obYn/0_oG];L2om2X[`;oe[Fh00GodjZ_om>^/_oC[[;odjjbomJZZ`02omFYZ`03om>V
Z_oIZZKofJZV00;ofZVT0_oR/:83onJcW`04on^hWOoa`IoolL6OooG7W@;onLfK00Oonm:JoogGV_om
fi_ooMjMoocSX?ofh[ComNNi00;ol^fo00Cok_77o`000?oNlmcocn;V0_o6fnT00onjc^Wo]L[ZokG:
jP02ojo4j@04ojg2jOn[_nSoZkoXoj^oj0?oZ[kX2?nY_NP00ol0003oooooooooo`0Dooooo`002Ooo
ool01000003ooooooooooooooolF000000D06ATI00@0000003<c<`0c<c<000000P1<C4`02@000000
IVIV0000001oOgl0000009VIV@000000/k>co`0000030<c<c003o`00003Vi^H0i^KV00D0i^KV00Co
00000<c<c03<c<co00000P2c/k<01`000000VIVI0000001oOgl0000006IVI_l000000P1<C4`01?l0
0000<c<c03<c<ol0000401TI6AL00000100I6AT04?l00000<c<c03<c<ol00000C4a<0000001VIVH0
000007moO`000000VIVI0000002c/k?o00000<c<c?l000020>KViP03o`00003oool0oooo00@0oooo
013o00000>KViP3Vi^Ko00000<c<c?l00000/k>co`00002IVIT0000007moO`000000IVIV0000001<
C4`000000P0c<c<00`0000006ATI01TI6@0201TI6AH000001?ooool00`00003oooooooooo`0Boooo
o`03o`000?oooooooooo01Wooooo1_nY_NP3ojRmj0;oYkcY00?oXk[Yoj2ij_nC/^`00_nC/^`01_mh
X^go?WcSocilholBEm7o03Rmo`0X/@?o000000Co=3VXoe=>[_mCCZkoIeZ_0_mgIK82oh1^]@;oPG>k
0omnK;@2ogQX/`;oM6>a0_mfHJd2ogeRZ@;oQVJV0_n@Jj<3oiU_X@?oXG>P0onVMil00onZNYoo/X>S
ok:3X`03okF5XPCo`YBW00Go`I:VolnW[oo?YjoocjN_olZO[002omNd]`04om2X[ooF]KSoe[FhomJe
^0Codjjb0_oEZJ/2om>VZP;ofJZV0_oJZJ@01?oMZj;oh[2RonJcWooV/il2on^hW@05oo6nVooeaigo
mLNMooW=VookdYX00_omeiX03?omfi_ooMjMoocSX?okj:?on>jVoo;]_oo^lLOoioCAomkcg?l0003o
dngUolKKj@;o_MC[00Go]L[Zok76jOnaa^Wo[L;Yojc0j004oj^nj0;oZ[kX2OnY_NP00ol0003ooooo
ooooo`0Cooooo`002Oooool01000003ooooooooooooooolF000000D06ATI00@0000003<c<`0c<c<0
00000P1<C4`02@000000IVIV0000001oOgl0000009VIV@000000/k>co`0000040<c<c003o`00003V
i^H0i^KV00@0i^KV00Co00000<c<c03<c<co00000P2c/k<01`000000VIVI0000001oOgl0000006IV
IP0000000P1<C4`01?l00000<c<c03<c<ol0000401TI6AL00000100I6AT04?l00000<c<c03<c<ol0
0000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l000020>KViP03o`00
003oool0oooo00@0oooo013o00000>KViP3Vi^Ko00000<c<c?l00000/k>c0000002IVIT0000007mo
O`000000IVIV0000001<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6AH000001?ooool00`00
003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo1_nY_NP00onX_NSoZ;cXojFkj@02ojFk
j@;oX;WZ00KoTk;/ohb_kOmWVNgoIiW]ocilhol0<k/2o`000006o`0IX?lM;jWo7BnYoc@iZ?mABZ_o
Ddj^0_mWFZl01OmgIK;oP6jeoh1^]On0K[GoPG>k00?oN7?00_mUJl@2ogAS/@;oMV6]0_mmHZT2ohIV
YP?oT6^S0onIKj42oj5cX0?oYWNO0onbPj<3okF5XP04ol>GZOo2U:Oo`YBWol:DY`CocjN_0ooG];L0
1OoOdL[oe[FhomJe^?oF]KSodkg400;odjjb0_o?ZkD01?oEZJ_odjJZom>VZ_oCYZX3omZYY004omf[
X_oV/iooi[>OonJcW`;ojkRM00SolKjKooG7WOoeaigonLfKoo_BV_omei[ooM^KoogNW@;oo>>P00[o
nnRSooS^Y_obm:_ojoVdonCm`ooNlmcodngUo`000?o8hn_o_MC[0_ngcN/00onaa^Wo[/?Yojk3j@02
ojc0j0;oZkkX1?nZ_^P8ojVmj003o`000?oooooooooo01?ooooo0009ooooo`0400000?oooooooooo
oooooaH00000100I6AT01`000000<c<c03<c<`0c<c<0000004a<C00000000P1VIVH01@000000Ogmo
0000002IVIT000000080/k>c00?o00000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP03o`000080
c<c<00[o00000;>c/`2c/k<0000009VIV@000000Ogmo0000001VIVH000000P1<C4`01?l00000<c<c
03<c<ol0000501TI6AL00000100I6AT04_l00000<c<c03<c<ol00000C4a<0000001VIVH0000007mo
O`000000VIVI0000002c/k?o00000<c<c?l00000i^KVo`0000P0oooo00?o00000>KViP3Vi^H00_l0
00002P2c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C000000203<c<`030000000I6AT0
6ATI00806ATI5P000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool5
ojVmj0;oZ;cX00?oYK_YojBkjOnT^nT00_nM]n/2ohb_k@?o000000Ko03>ko`00Tol06J3o2ajNoad_
ZOld>JP2oe5:Z`;oIeZ_0_mgIK82oh1^]@;oPG>k0_mhLl02ofE[a0;oDUo20_mfHJd3ogeRZ@04ohIV
Y_n@Jj?oT6^Soi1[X`?oVFnQ0_nQLj02ojIgW`03ojf1Y?nbPj?o/X>S00;o/X>S00?o]HFRol>GZOo3
UjT00oo2U:L4olnW[`03on;<`_oG];OoekBg00;ogm7:00Coe[Fhom>ma?oC_LCodjjb0oo?ZkD01?oE
ZJ_odjJZom>VZ_oCYZX2omZYY0;ogJ^R0ooV/il01?o[^9golKjKoo6nVoogaIP2ooW=V`06oo_BV_om
ei[ooM^KoogNWOolhj3onnRS0_ohkZH00oobm:_ojoVdonCm``02om?eiP04olSSjol0003o_]W]okO=
j`;o//SZ00?o[/?Yojc1jOn[_nP00_n[_nP3ojZnj0_oZKgX00?o0000ooooooooool04_ooool000Wo
oooo00@00000oooooooooooooooo5P00000401TI6@070000000c<c<0<c<c03<c<`000000C4a<0000
000206IVIP050000001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0030<c<c0;o0000
1@3<c<`00ol00000/k>c0000000209VIV@050000001oOgoo000006IVIP0000000P1<C4`01?l00000
<c<c03<c<ol0000501TI6@03o`0000000000000001@00000100I6AT04_l00000<c<c03<c<ol00000
C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l00000i^KVo`0000P0oooo
00?o00000>KViP3Vi^H00_l000002P2c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C000
000203<c<`030000000I6AT06ATI00806ATI5P000004ooooo`0300000?oooooooooo01;ooooo00?o
0000ooooooooool07?ooool4ojVmj005ojRmj?nW_>SoYkcXojNlj?nT^nT00_nS^^X3o`000009ohB[
k_mDS^_oE8k[o`0=WOl0<k_o001ko`0IX?l;7Yko=3VX00;oDDZ[0_m/G:l2ogMU/P;oP6je0on1Lk/2
ogQc`003ofE[a?mBGl;oDUo200;oCeZm00?oMV6]ogeRZOmmHZT00_n6IZH2oi1[X`?oVFnQ0_nQLj00
0onVMioo[H6Tojf1Y004ok:3X`03okF5X_o3UjWo`iNY00;o`YBW0_oF/K@2olnW[`;oh/c200CoekBg
omoAb_oOdL[ocnOW0ooC_L@4oln[]@CodjJZ0_oJZJ@2omf[XP04on6^XOoV/iooi[>Oon^hW@;olKjK
00?omlFHoo_<UOokdYX00_omeiX02?omfi_ooMjMoocSX?okj:?on>jVoo;dZoo[nKCoi?g30_oCmNH0
0oo7j>go_]W]o`000002okO?k003ok;8j_n^a>Wo[/CY00;o[<7Y00?oZkoXojZnj?nZ_^P00_nZ_^P;
ojVmj003o`000?oooooooooo01;ooooo0009ooooo`0400000?oooooooooooooooaH00000100I6AT0
1`000000<c<c03<c<`0c<c<0000004a<C00000000P1VIVH01@000000Ogmo0000002IVIT000000080
/k>c00?o00000<c<c03<c<`02P3<c<`00ol00000/k>c0000000209VIV@050000001oOgl0000006IV
IP0000000P1<C4`01?l00000<c<c03<c<ol0000501TI6AL00000100I6AT04_l00000<c<c03<c<ol0
0000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l00000i^KVo`0000P0
oooo00?o00000>KViP3Vi^H00_l000002P2c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<
C000000203<c<`030000000I6AT06ATI00806ATI5P000004ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool07Oooool3ojVmj0;oZ;gX00?oYkcXojJljOl000000_l000000onS^^[oVKK/
oiFdk@02ogZVk`;oE8k[00Co00fMo`00Tol008ko2ajN0_ld>JP00omABZ_oK5b_ofaL[`02oh1]/`?o
P6je00CoPG>kohf6aomhR]WoN8[I0_mUJl@2oe9O`P;oCeZm0_mmHZT2ohIVYP;oT6^S0onIKj42oj5c
X0Co[H6T0onbPj<4ol>GZ@04ol:DYooF/KCoe[6dolnW[`?oh/c200?ofOkFomoAb_o?inL00_o?inL0
0ooC_LCoa;K=olBfc@03oln[]@?odjJZ0_oAY:T00ooJZJCogJ^Romf[XP02on6^X@;ojkRM00SolKjK
ooO5V?ogaISonlbEookBT_ooei3ooM^KoogNW@;oo>>P00OonnRSooS^Y_oJkHWodO6Eom3od?o<n>So
anS]00;o_M[_00Ko]lo/o`000?nab>_o/LS[ojk4jOn/`NT3oj^oj0;oZ[kX3_nY_NP00ol0003ooooo
ooooo`0Aooooo`002Oooool01000003ooooooooooooooolF000000@06ATI00L0000003<c<`0c<c<0
<c<c0000001<C4`000000080IVIV00D0000007moO`000000VIVI000000030;>c/`03o`00003<c<`0
c<c<00P0c<c<00Ko00000;>c/`2c/k<0000009VIV@00000207moO`030000001VIVH000000080C4a<
00Co000003<c<`0c<c?o00001@0I6ATG000000@06ATI01;o000003<c<`0c<c?o000004a<C0000000
IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co00000>KVi_l000080?ooo`03o`00003V
i^H0i^KV00;o000000X0/k>c0000002IVIT0000007moO`000000IVIV0000001<C4`000000P0c<c<0
0`0000006ATI01TI6@0201TI6AH000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01oooooo0onY_NP3o`0000;oY[cY0onQ^NX2oiFdk@;oNZK_00Oo?X;Wo`0`]ol0073o001ko`/N
W_l^<Z?o=3VX00;oDDZ[00?oK5b_oh1]/on0KK<00on<Nk/3ohf6a`03ogR:fOldMn;o=7OR00;oDUo2
0_m?F[d2oemN^@;oQVJV0on@Jj<2oiU_X@03oj5cX?nVOJOoYWfW00?o[H6T0onbPj<4ol>GZ@?oe[6d
0_o/klX01ooRc<;ofOkFohAd^_n4M;[oKVFholoWion>d_h01?o4]/d01?o?ZkGoajBfolNT]_oCYZX3
om6TZ@;ogJ^R0ooQ[Z42on^hW@0?oo6nVoogaISomlFHoo_<UOondY;oomN@oooKSoongi3ooN>@oo[W
SoocjXgoj>b9om[]ROo@om3oc?SX00;o`^S`00Ko_M[_okG?kOnecngo/LS[o`000?n^a>X3ojc1j@03
oj^oj?nZ_^SoZ[kX00;oZ[kX3_nY_NP00ol0003oooooooooo`0@ooooo`002Oooool01000003ooooo
oooooooooolF000000@06ATI00L0000003<c<`0c<c<0<c<c0000001<C4`000000080IVIV00<00000
07moO`0000000P2IVIT010000000/k>c0;>c/ol000090<c<c004o`00002c/k<0/k>c00000080VIVI
00<0000007moO`0000000P1VIVH010000000C4a<04a<C?l0000203<c<`03o`00000I6AT06ATI00<0
6ATI5`00000401TI6@0Bo`00000c<c<0<c<co`00001<C4`0000006IVIP000000Ogmo0000002IVIT0
00000;>c/ol00000c<c<o`00003Vi^Ko0000203oool00ol00000i^KV0>KViP02o`00000:0;>c/`00
0000VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00<0000001TI6@0I6AT00P0I6ATF
000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`?o000000CoZKgX
ojRmj?nX_NSoZ;gX0_nV_>T00onQ^N[oW[W[oi2bkP02oi2bkP08og2QkolVM>;o9WCRo`0`]ol007_o
00nDo`/NW_l^<Z<2oe5:Z`;oK5b_0_n0KK<3ohak^`;oSHK70_mhR]T3ocAghP04o`10__m?F[goGeji
oemN^@;oMVNd0on@Jj<00onIKj7oVgNZojImY`02ojImY`?o[H6T0_nbPj<2ol6H[@?o`iNY00KogL2l
omJa]?oF/KCok>o:o`000?nRR;P2oiF0^P;oQ7Bj00?oKVFhohkBo_n>d_h00_o4]/d01On/XlkoajBf
olNT]_o7Y;KodjJZ00?odJBY0_oMZj83on6^X@04onNdWoo[^9golKjKooO5V0;onlbE00coo]:BoooG
T?oofhooo]n@oogST?ojihoolnZ=om[]ROn^k9co`?kAol?gk_o2j?02okWHl005okG?kOn`b>co/<S/
ojk4j_l000001?n[_nT5ojZnj0goZKgX00?o0000ooooooooool04?ooool000Wooooo00@00000oooo
oooooooooooo5P00000401TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP030000
001oOgl000000080VIVI00D000000;>c/`2c/k<0/k>co`0000070<c<c007o`00002c/k<0/k>c0;>c
/ol00000VIVIo`00000207moO`040000001VIVH0IVIV00000080C4a<00Co000003<c<`0c<c?o0000
1@0I6ATG000000@06ATI01;o000003<c<`0c<c?o000004a<C0000000IVIV0000001oOgl0000009VI
V@000000/k>co`00003<c<co00000>KVi_l000080?ooo`03o`00003Vi^H0i^KV00;o000000X0/k>c
0000002IVIT0000007moO`000000IVIV0000001<C4`000000P0c<c<00`0000006ATI01TI6@0201TI
6AH000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo0ol00002oooo
o`?oZKgX00?oZ;gXojNlj?nU^nT00_nU^nT2oijij`0:oi2bk_n;/>ooRk3_ofBLkolVM>;o01JQo`00
GOl008ko2ajNobhbX`;oET^Z0_m/G:l2oh1]/`?oS7^k00_oSHK7ojVUdonYYM?oZJGCohbon?neloCo
fOkDonkh__l079goCeZmoemN^@02ogIW]0?oRg2_0_nKMjX3ojImY`?o[H6T00Co/X>Sol6H[Oo1V:go
`IR]0_o3UjT2omg0_003omJa]?o/kl[o[Hfd00;oXXRh0_nEP;X2ohAd^P;oKVFh00Co>h_]ojbSc_n/
Xlko[:?>0oo7Y;H4om6TZ@03om:TZ?oMZj;ohJjQ00;ohJjQ00KoikBOoo6nVooa_Y_omlFHoo_<UOon
dY82oooGT008ookOT?omhi3on^N?oo?ZSOoXk8WoWmA_ol3ndOo3mnh2ok_Tl`04okWHl?nbcNko//g^
ok38k0;o[LCZ00Co0000ojc1jOn[_nWoZkoY1?nZ_^P@ojVmj003o`000?oooooooooo00oooooo0009
ooooo`0400000?oooooooooooooooaH00000100I6AT01`000000<c<c03<c<`0c<c<0000004a<C000
00000P1VIVH00`000000Ogmo0000000209VIV@050000002c/k<0/k>c0;>c/ol000001P3<c<`01Ol0
0000/k>c0;>c/`2c/k<000000080VIVI00@0000007moO`1oOgl000000P1VIVH010000000C4a<04a<
C?l0000203<c<`03o`00000I6AT06ATI00<06ATI5`00000401TI6@0Bo`00000c<c<0<c<co`00001<
C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/ol00000c<c<o`00003Vi^Ko0000203oool0
0ol00000i^KV0>KViP02o`00000:0;>c/`000000VIVI0000001oOgl0000006IVIP000000C4a<0000
0080<c<c00<0000001TI6@0I6AT00P0I6ATF000000Cooooo00<00000ooooooooool04Oooool00ol0
003oooooooooo`0Iooooo`?o00001_ooool00onY_NSoZ;gXojRmj002ojNlj004ojFkjOnT^n[oY;_Z
ojBkjP;oW;S/0_n;/>l2ofBLk`04o`00L?l007_o00nDobhbX`;oET^Z0_mhI;03oh1]/`03ohak^onS
SkooZJGC00;oZJGC0_o<a=<01OoTe<Kol=Rhoo3H^?off:go01bM00;oGeji00CoMVNdoh]`[on;L:oo
Rg2_0_nKMjX4ojImY`;o[H6T1?o1V:d01Oo3UjWogL2lomg0_?oM`;coa_R]00;o[Hfd00CoXXRhoimo
/OnBMk7oTWNa0on4KK400om^IKSo2dk;o`]>b`03ojbScP;oajBf00?o_ifeom6TZOoAY:T00_oBY:P3
on6^X@;oikBO00gok[bMooO5V?ogaISonlbEookBT_ooei3oom^?ookOT?omhi3on^N?oo?ZSOnfd5_o
]?cM00;o^^od00Co^nCcokCDl?nde?3o//g^0_n^a^`01On]a>[o[<7Yoj^ojOl0003oZkoY00KoZ[kX
4?nY_NP00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooooooooolF000000@06ATI
00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH000000080Ogmo00@0000009VIV@2I
VIT000000`2c/k<2o`0000<0c<c<00?o00000;>c/`2c/k<00P2c/k<010000000VIVI09VIV@000002
07moO`040000001VIVH0IVIV00000080C4a<00Go000003<c<`0c<c<0<c<co`00000501TI6AH00000
100I6AT04_l00000<c<c03<c<ol00000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o
00000<c<c?l00000i^KVo`0000L0oooo013o00000>KViP3Vi^Ko00000<c<c?l00000/k>co`00002I
VIT0000007moO`000000IVIV0000001<C4`000000P0c<c<0100000006ATI01TI6@0I6ATG000000Co
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`?o00002_ooool4ojRmj0;o
YkcY00?oY;_Zoj:kj_nJ]nd00_nJ]nd2ohJ_l004oeVGkol0FM;o001Mo`0?U0;o;S:S00?oET^ZogQT
/?mhI;000onAN[H3oj>?_`05ojVUdoo<a=?oc<CColc4dooTe<H00_o`f;P2ooWIYP04o`0XZomOG[Wo
MVNdogIW]0;oRg2_0onKMjX3ojImY`03ojf1Y?nmV[?o_IZc00?o`IR]0ooM`;`01?o6n:go]8n`ojf=
]?n]SK@2oimo/@?oTWNa0_n4KK42ogAQ[`;o2dk;0_n/Xlh00oo7Y;Ko_ifeoknM]@02om6TZ@;odZBX
0ooQ[Z42onNdW`0;onjlWOogaISomlFHoo_<UOondY;oomN@oooKSoongi3ooN>@oo[WSoo@ffP00_na
mnl01?njkoCo]M_dokGKm?nde?02ojo:k@03ojk6k?n/`^[o[<;Z00;o[<7Y00?oZkoYo`000?nZ_^P0
0_nZ_^PCojVmj003o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooooaH00000
100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP0000000P1oOgl01?l00000
VIVI09VIV@0000050;>c/`03o`00003<c<co000000D0/k>c00@0000009VIV@2IVIT000000P1oOgl0
10000000IVIV06IVIP00000204a<C005o`00000c<c<0<c<c03<c<ol000001@0I6ATF000000@06ATI
01;o000003<c<`0c<c?o000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`00003<
c<co00000>KVi_l000070?ooo`0@o`00003Vi^H0i^KVo`00003<c<co00000;>c/`000000VIVI0000
001oOgoo000006IVIP000000C4a<00000080<c<c00@0000001TI6@0I6AT06ATI5`000004ooooo`03
00000?oooooooooo017ooooo00?o0000ooooooooool05?ooool2o`0000oooooo0_nX_NP3ojJlj@;o
X[_Z00?oV[O]oiRgk_nH]nh00_n1[_401_m>Tnoo001Mo`0?U?l/;Z7o;S:SoeI;ZP?oN6B`0onAN[H2
oj>?_`04okfT_oo<a=?oc<CConCDaP;ol=Rh00Gom]R]ooWIY_okfj;oo=fPo`0XZ`02ogIW]0?oRg2_
0_nKMjX2ojImY`04ok>J__nmV[?o_IZcokfJ/`?o`IR]00?oh]C9omg0_?ndSk000_ndSk000on]SKCo
ZXJ_oimo/@02oimo/@;oTWNa0_n4KK42ogAQ[`04o`0[/ol;C/_oU8g9oiB=b@Co_ife00CodJBYom:T
Z?oBY:SoeZRX0_oQ[Z42onNdW`0<onjlWOofaY[onlbEoo_<UOondY;oomN@ookOT?omhi3on^N?onKS
Monfd5_o/OO_0_n`d_83ok3>l004ojo:kOn]a>_o[LC[ojc2jP;oZl3Y0_n[_nT00onZ_^So0000ojZn
j002ojZnj0ooZKgX0oooool00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooooooo
oolF000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH000000080Ogmo
00@0000009VIV@2IVIWo00001P2c/k<00ol00000/k>c0;>c/`040;>c/`040000002IVIT0VIVI0000
0080Ogmo00@0000006IVIP1VIVH000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000H06ATI5@00
000401TI6@0Bo`00000c<c<0<c<co`00001<C4`0000006IVIP000000Ogmo0000002IVIT000000;>c
/ol00000c<c<o`00003Vi^Ko00001`3oool04?l00000i^KV0>KVi_l00000c<c<o`00002c/k<00000
09VIV@000000Ogmo0000001VIVH0000004a<C000000203<c<`040000000I6AT06ATI01TI6AL00000
1?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol0000Booooo`;oZ;gX
0onV_>T2oj:kj`03oiRgk_nF]nkoU[O^00;oOJgb00CoAI7_o`00IOl03iCo;2jQ0_mFBjX2ogQT/0?o
TGZf00OoXhnookfT_onmY;oo_JBoolc4dooTe<Kol=Rh00;om]R]00KonMVVoo_KX_olgJ3oo=nQoogO
Vol8Fm@3oh]`[`;oVgNZ00?oYWfWok>J__ncV[h01?nmV[<00oo1V:goh]C9on;Db@02okV@[0;o]8n`
0onZQZl2oimo/@;oTWNa0on4KK401?mdHJooHEB]o`0[/ol;C//2oiB=b@;o_ife00?o_9Vdom:TZ?oB
Y:P00ooFZ:P2onNdW`;ok[bM00Wom/JJoo_?U_ondY;oomN@oooKSoolhXWonNB7oo?UP_o@ffP00_n_
eo@00on`d_;o[LS^ojg8kP03ojg6k005ojg4jon[`N[oZl7Zoj_0jOnZ_nT00onZ_^P00ol0003oZ[kX
ojVmj00>ojVmj0Gooooo00?o0000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo
5P00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV0000000207moO`04
0000002IVIT0VIVI000000d0/k>c00@0000009VIV@2IVIT000000P1oOgl010000000IVIV06IVIP00
000204a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I6ATC000000D06ATI013o
000003<c<`0c<c?o000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co
00000P3Vi^H00ol00000oooo0?ooo`040?ooo`0@o`00003Vi^H0i^KVo`00003<c<co00000;>c/`00
0000VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00@0000001TI6@0I6AT06ATI5`00
0004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0001Gooooo0onX
_NP3ojJlj@?oXK_[0_nF]nh2ogf]lP05o`00GOl03iCo;2jQoemAZomFBjX00_mhI;03oi5j]PCo_JBo
00CodkBjonCDa_o`f;Som]R]0_oifJH01Ookfj;ooMZLookNV_omgi_oo=fR00?oJ8OM00?oVgNZoibF
cOncV[h00oncV[h2okfJ/`;og?3N00Koh]C9okV@[?niT:co^I2/okB?/?ncRj`3ojZ6[`;oWgna0onB
Mk42ohA]/@;oM66_00Go[DP0o`0[/onDSLWoU8g9oknM]@02okbI]0;odZBX0ooFZ:P2onNdW`0<onjl
WOofaY[om/JJoo_?U_onei7oomb=oogOR_olhXWonNB7onKSMoo@ffSo[mOd0_n]b^l00on]b>koZl?[
oj_2j`02oj_2j`;oZl7Z1?nZ_nT3ojZnj003o`000?nZ_^SoZKgX00WoZKgX2_ooool00ol0003ooooo
ooooo`0=ooooo`002Oooool01000003ooooooooooooooolF000000@06ATI00D0000003<c<`0c<c<0
<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIT00000302c/k<0
10000000VIVI09VIV@00000207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`01Ol00000<c<c
03<c<`0c<c?o000000L06ATI4@0000000ol000006ATI01TI6@0201TI6@0?o`00000c<c<0<c<c03<c
<ol00000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000080c<c<00?o00000>KV
i_l000001@3oool03_l00000i^KV0>KVi_l00000c<c<o`00002c/k<0000009VIV@000000Ogmo0000
001VIVH000000P1<C4`010000000<c<c03<c<`00000301TI6AL000001?ooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`04ojRmj?nX_NWoZ;gYojRmj@;oY[cY
00?oXK_[oj2kk?nP^n`00_nE]nl01?mk[_?o001Mo`01Rol/;Z42oemAZ`?oN6B`00?oTGZfojN;]onW
RkL00_nmY;l2om>d^P05on>o/oo^b:cok/R/ooG?Y_ojeJ000_omfY`01?ongY[oo=fRoocMX_ofeJX2
ofR7g@?oW9K=0oncV[h01OnmV[?og?3Nomc`g_nmU:go_92Y00?o^I2/0oncRj`2ojZ6[`03oimo/OnL
NZcoSg6]00;oSg6]0_n3J:`2ogAQ[`04of5D[Ol0:k?oPgk5oh=na@Co_9Vd00OodZBXomJXZ?oFZ:So
eZRXomf_Z?oW]9ook[bM00;om/JJ00OonlnFookGTOoog8gooMn:ooWTQoociH;oi^=g00;o[Lga00?o
[L[_oj_4k?n[a>`00_n[`n/00on[`^_oZ/3Yoj[0j@02ojZoj@GoZ[kX0_nY_^P00ol0003oZKgXojVm
j005ojVmj0gooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5P00
000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`04
0000002IVIT0VIVI000000`0/k>c00@0000009VIV@2IVIT000000P1oOgl01@000000IVIV06IVIP1V
IVH000000080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0401TI6@03o`000000
0000000000l00000100I6AT03ol00000<c<c03<c<`0c<c?o000004a<C0000000IVIV0000001oOgl0
000009VIV@000000/k>co`0000020<c<c003o`00003Vi^H0i^KV00?o000000<0ooooo`00003Vi^H0
0P3Vi^H02ol00000c<c<o`00002c/k<0000009VIV@000000Ogmo0000001VIVH000000080C4a<00@0
000003<c<`0c<c?o00000`0I6ATG000000Cooooo00<00000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`?o00007_ooool3ojRmj@;oYKcY0onP^n`2oiFhk`05ogb_m?l006Go;2jQob`^XOmO
DJ/00on9LK43ojN;]`05okfT_ooC];[odkBjom>d^_oS_k<00_o^b:`01_oecjKon]FPoogJW?ongY[o
oMnKoocMXP;om]FZ00?oj/F^ofR7gOmXQmd00_nLU/d3ok>J_P03ohc^g?oLl=ko_IB]00;o_92Y0oni
T:`3ok>;[0;oZXJ_0onLNZ`2ohma[@;oPfR/0_mgH:/00omQE:go[DP0o`0[/`02oh=na@?o_9Vd0ooF
Z:P2omf_Z0;ok[bM00[om/JJoo_?U_okciKoo]NAoooLSOolhXWonNB7oo?UP_nab4ko[Lga0_n[aNd0
0on[a>coZ/7Zoj[1jP02oj[0jP03oj[0jOnZ_nWoZ[oY00CoZ[kX0onY_^P00onY_NSo0000ojVmj002
ojVmj17ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5P000004
01TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`040000
002IVIT0VIVI000000`0/k>c00L0000009VIV@2IVIT0VIVIo`00001oOgl0000000<0IVIV00D00000
04a<C01<C4`0C4a<o`00000403<c<`03o`00000I6AT06ATI00D06ATI3P00000601TI6@0?o`00000c
<c<0<c<c03<c<ol00000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000080c<c<
00?o00000>KViP3Vi^H00`3Vi^H00ol00000i^KV0>KViP020>KViP0;o`00003<c<co00000;>c/`00
0000VIVI0000001oOgl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000301TI6AL00000
1?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo0ol0000Rooooo`;oZ;gY
0onU_>X00onP^ncoXK_/oiJik`02oiJik`03o`00IOl00H_o;2jQ00;oGe6[0_n9LK43ojN;]`?odkBj
00?ohknconk8[?o^b:`00_oecjH01OojeJ3ooMZLookNV_omgi_oo=fR00;om]FZ00?oj/F^om^b[_oK
/Zh00onLU/d01OncV[koS>kLol2DZ_o0U:[o_IB]00;o_92Y0_niT:`2okV>Z@;o/h^/00?oZXJ_ojR2
ZonLNZ`00_nLNZ`2ohma[@;oPfR/0_mgH:/00om[F:_oHEB]o`0@X002oh=na@?o_9Vd0ooFZ:P2omf_
Z0;ok[bM00Som/JJoo_?U_onei7oomb=oogOR_olhXWonNB7omGNK0;o[<O]00CoZlG]oj[1j_nZ`N[o
Z/7Z1OnZ_nT4ojZnj0;oZKkX1?nY_NP00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo0009ooooo`0400000?oooooooooooooooaH000001@0I6AT01@000000<c<c03<c<`0c<c<00000
0080C4a<00@0000006IVIP1VIVH000000P1oOgl010000000VIVI09VIV@00000;0;>c/`050000002I
VIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00?o000003<c<`0c
<c<00P0c<c<00ol000006ATI01TI6@0501TI6@`000001P0I6AT01Ol00000<c<c03<c<`0c<c?o0000
0080C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c/ol000000P3<c<`00ol00000i^KV
0>KViP070>KViP0>o`00003<c<`0c<c<o`00002c/k<0000009VIV@000000Ogmo0000001VIVH00000
04a<C000000303<c<`040000000I6AT06ATI01TI6AL000001?ooool00`00003oooooooooo`0@oooo
o`03o`000?oooooooooo00?ooooo0ol0000Vooooo`;oZ;gY00[oYKcZojJlj_nV_>[oY[cZoj6kk?nF
^NooV;[_o`00C?l008?o:bjQ0_mODJ/3ohUa/@;oYh^g00Co_I^fom>d^_oS_k?ohknc0_o^b:`00ooe
cjKon]FPoogJW002ookNVP03oocMX_ojfjGon]^U00;oj/F^0_oK/Zh01?o?Xj_obIj/olVN[?o9WZ`3
ol2DZPCo_92Y00?o^I2/okV>ZOniSZT00_ncRj`3ojR2Z`;oW7Z/0on?LJd00on3J:coMf2[ogMPZ`02
of]HZ`05o`0@X?meM/KoMGK6ogEfa_nlVK@00_nmVkH01OoFZ:SogJnXomf_Z?oM[jSoik^X00;om/JJ
00SonlnFookGTOoog8gooMn:ooWTQoociH;o/LQ>ojc4j`;oZl;[00?oZ/7ZojZojOnZ_nT00onZ_nT2
ojVnj003ojZnj?nY_^SoZKkX00;oZKkX00?oZKgXooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooaH000001@0I6AT0
1@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl01@000000VIVI
09VIV@2IVIT0000000X0/k>c00<0000009VIV@2IVIT00P2IVIT010000000Ogmo07moOol0000306IV
IP05o`00001<C4`0C4a<04a<C?l00000100c<c<00ol000006ATI01TI6@0601TI6@T000001`0I6AT0
1Ol00000<c<c03<c<`0c<c?o00000080C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c
/ol000000P3<c<`00ol00000i^KV0>KViP070>KViP0>o`00003<c<co0000o`00002c/k<0000009VI
V@000000Ogmo0000001VIVH0000004a<C?l0000203<c<`030000000I6AT06ATI00806ATI5`000004
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo0ol0000[ooooo`;oZ;gY00?o
Y[cZojJmjOnV_NT00_nR_>`00onH^^oo001Uob/^X@02ofaL[P?oRG6a00CoYh^gokfK]_nmVkKod:^c
0_oS_k<02?o^b:comLnVooG?Y_ojeJ3ooMZLookNV_omgi_ooN6L0_ojfjD00ooac:coj/F^om^b[P02
olnSZ`;obIj/0_o3UZT2ol2DZPCo_92Y0oniSZT00oncRjco/XVYojR2Z`02ojR2Z`?oW7Z/0_n?LJd2
oh=X[004ogMPZom[F:_oJeR[oea@Z`?oMGK60onmVkH00ooFZ:SogJnXomf_Z002onNkZ0;om/JJ00So
nlnFookGTOoog8goo>:9oo7ZR_oEgVco[<C[oj_1jP?oZ/3Y00?oZ[oYojZnjOnZ_^T02?nY_^P8oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooo
oooooooo5P00000501TI6@050000000c<c<0<c<c03<c<ol000000P1<C4`010000000IVIV06IVIP00
000207moO`050000002IVIT0VIVI09VIV@0000002`2c/k<01@000000VIVI09VIV@2IVIT0000000<0
Ogmo00@0000006IVIP1VIVH00000101<C4`01?l00000<c<c03<c<`0c<c<2o`0000P06ATI00?o0000
0000000000000`00000901TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`02@000000IVIV0000
001oOgl0000009VIV@000000/k>co`0000020<c<c003o`00003Vi^H0i^KV00H0i^KV00Co00000<c<
c03<c<co00000P2c/k<02@000000VIVI0000001oOgl0000006IVIP000000C4a<0000000203<c<`03
0000000I6AT06ATI00806ATI5`000004ooooo`0300000?oooooooooo00oooooo1?l0000^ooooo`?o
Z;gY0onV_NT2oj>lj`03o`00IOl00H_o:bjQ00;oK5b^00?oRG6aoif0/onmVkH00_nmVkH2om2[/`;o
k/R/0_oecjH01OojeJ3ooMZLookPVOomhYOooN6L00;on]^U00?olLb/om^b[_oK/Zh00oo?Xj/01?o9
WZco`iJYol>FZOo0U:X2okjAY`;o_92Y00Co_HnWokV>ZOniSZWo^HjY0onbRJT2ojR2Z`?oW7Z/0_n?
LJd2oh=X[0;oMf2[0_m[F:/00ol04:3oMGK6ogEfaP03okfK]P?ogJnX0_oW^jP02?oabJOonlnFookG
TOoog8gooMn:ooCZSOoajX[oeMi/0on[`NX01?nZ`>WoZ[oYojZojOnZ_^T5ojVnj0cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolF
000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP000000
0P1oOgl01@000000VIVI09VIV@2IVIT0000000/0/k>c00D0000009VIV@2IVIT0VIVI0000000307mo
O`040000001VIVH0IVIV000000@0C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0C
01TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`02P000000IVIV06IVIP000000Ogmo0000002I
VIT000000;>c/ol000030<c<c003o`00003Vi^H0i^KV00D0i^KV00Co00000<c<c03<c<co00000P2c
/k<200000080Ogmo00D0000006IVIP000000C4a<0000000203<c<`030000000I6AT06ATI00806ATI
5`000004ooooo`0300000?oooooooooo00oooooo0_l0000aooooo`05ojRmjOnX_NSoZ;gXojJmjOnW
_NT00_nT_N/00ol004co0023ob/^X@02ofaL[P?oWH2c00Wo_I^fom2[/oo@Zk?od:^con2i/?o^b:co
mLnVoo[EX?omfY`00_onh9T00oomhYOon]^Uoo[KY@02oo7<[003on>j[_oK/Zkocj>[00;ocj>[0oo3
UZT01?o0U:[o_Y6WokjAYonlT:T3okf?Y`;o^HjY0onbRJT2ojR2Z`?oVGN[0_n<KZ/2oh5VZ`;oMf2[
0_m[F:/01?mLD:_oMGK6ogEfa_meM/H2okfK]P04ol:T^_oM[jSogJnXonNkZ0;olLVW00Kon]RSoogR
W?ojiiComnV?oo7ZR_oYih02oj_0j@CoZ[oY0_nZ_^P3ojVnj0oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolG000000@06ATI00<0
000003<c<`0c<c<00P0c<c<00`000000C4a<0000000306IVIP040000001oOgl0Ogmo000000<0VIVI
00<000000;>c/`2c/k<02P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00@0000006IVIP1V
IVH00000101<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI01406ATI00?o000003<c
<`0c<c<00P0c<c<01_l00000C4a<04a<C0000000IVIV00000080Ogmo00<0000009VIV@0000000P2c
/k<01?l00000c<c<0<c<c?l000060>KViP04o`00003<c<`0c<c<o`000080/k>c00L0000009VIV@00
0000Ogmo0000001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6ATG000000Cooooo00<0
0000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`?oZ;gX0_nW_NT01?nT_N_o/V@0o`00
Pol[;Z42ofaL[P?oWH2c00Go_I^fom2[/oo@Zk?od:^con2i/002ong6Z`06ooOBYOolfikoo^2IoogR
UoomhIcon]^U0_oac:`2on>j[PCocj>[0oo3UZT3okjAY`Co_HnW00?o^HjYokZ=Z?njSJP00_nbRJT0
0onXPZ_oYh6[ojN1Z`02oiUgZ`;oS6j[0_n1IZ/2ogUQZ`;oJeR[00GoG52[ofIcc?mVLlcoIW?<okfK
]P03ol:T^P;oik^X0_oabJL01oojf:?ooN:Loo[WU?odjXgolNZ:omGNK?n[`>T00_nZ_nT4ojZnj1Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooo
oooooooooolG000000D06ATI00Go000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV
o`000080Ogmo00Go000009VIV@2IVIT0VIVI0000000=0;>c/`060000002IVIT0VIVI09VIVOl00000
00000P1oOgl01Ol00000IVIV06IVI_l00000000000<0C4a<00?o000003<c<`0c<c<00P0c<c<2o`00
01006ATI00?o000003<c<`0c<c<00P0c<c<01?l00000C4a<04a<C000000206IVIP060000001oOgl0
Ogmo0000002IVIT000000P2c/k<01Ol00000c<c<0<c<c03<c<co000000@0i^KV00Go00000<c<c03<
c<`0c<c<o`0000020;>c/`070000002IVIT0000007moO`000000IVIV0000000204a<C0040000000c
<c<0<c<c000000@06ATI5`000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool0
;oooool4ojRmj0;oYkgY00?o001hob/aY?l[;Z400_m/G:h2oif0/`?od:^c0_oP^K02ong6Z`06ooOB
YOolfikoo^2IoogRUoomhIcon]^U0_oac:`2on>j[P03omBZ[Oo?Xj_ocj>[00;oaYZY0_o3UZT3okjA
Y`05oknAY_nmSjOo_HnWokf?YoniSZT00_njSJP2ok:9Z@?oYh6[0onIMj/00on<KZ_oPFJ[oh5VZ`02
ogUQZ`;oLUj/00CoJeR[o`00I_mVLlcoIW?<1?o2Y;X2onNkZ007oo79Yoojf:?ooN:Loo[WU?ogjHoo
m>Z=oo7ZRP03ojZojA[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
2Oooool01000003ooooooooooooooolG000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<
C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVI0000000>0;>c/`030000002I
VIT0VIVI0080VIVI00@0000007moO`1oOgl000000`1VIVH010000000C4a<04a<C01<C4`2o`0000@0
<c<c00?o000001TI6@0I6AT02P0I6AT3o`0000@0<c<c00Go000004a<C01<C4`0C4a<0000000206IV
IP060000001oOgl0Ogmo0000002IVIT000000P2c/k<01?l00000c<c<0<c<c03<c<`5o`0000@0c<c<
00[o00000;>c/`2c/k<0000009VIV@000000Ogmo0000001VIVH000000P1<C4`010000000<c<c03<c
<`00000401TI6AL000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo
00OoZ;gXojVmj?nX_NWoZ;gYo`00C?l008?o:c6T00;oK5b^00CoWH2cok6B]_naT[Kod:^c0_oP^K02
ong6Z`;omm:U00Coo^2IoogRUoomhYOon]^U0_ofejh01Ooac:cohkZ^omBZ[OoDZZgocj>[00?oaYZY
00Co`iJYol2BYoo0TZOo_Y6W0_noTJH3okf?Y`?o^XfX0_nbRJT3ojN1Z`?oVGN[0_n<KZ/01?n1IZ_o
NF6[ogUQZomiHJ/2og9N[004oea@Zol006KoIW?<ofIcc0;o`ZBj0_o<]<82oo79Y`07oo[HXoomhYco
n^NDooOYSooajX[ofo:FojZoj@0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool000Wooooo00@00000oooooooooooooooo6000000501TI6@050000000c<c<0<c<c03<c<`00
00000P1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VIV@0000003P2c/k<0
0`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo008000000P1VIVH00`000000C4a<04a<C002
04a<C003o`00000c<c<0<c<c0080<c<c0ol0000601TI6@?o00001P0c<c<01Ol00000C4a<04a<C01<
C4`000000080IVIV00H0000007moO`1oOgl0000009VIV@0000030;>c/`03o`00003<c<`0c<c<00T0
c<c<00So00000;>c/`2c/k?o000009VIV@000000Ogmo00000080IVIV00?o000004a<C00000000P0c
<c<00`0000006ATI01TI6@0201TI6AP000001?ooool00`00003oooooooooo`0Dooooo`;o0000<Ooo
ool2ojVmj004ojRmjOnbI03o0023ob/aY0;oOF^d0onaT[H00oo@Zk?oh;V`on2i/002ong6Z`06ooOB
YOolfikoo^2IoogRUoomhIconn>U0_ofejh2on>j[P;oe:Z]1?o6VZT01?o3UZWo`9:Wol2BYonnTJL2
oknAYP?o_HnW0onjSJP3ok:9Z@?oYh6[0_nIMj/2oha^Z`;oPFJ[0_miHJ/2og9N[005ofYL/?mLD:_o
CWCIodidfOo2Y;X00oo<]<82oo79Y`05oo[HXoomhYcon^NDooCZSOoOn:L07oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooaP00000
1@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00D0000006IVIP1VIVH0IVIV0000000207mo
O`050000002IVIT0VIVI09VIV@0000003P2c/k<00ol00000000009VIV@0209VIV@05o`00001oOgl0
Ogmo07moO`0000000P1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c00@0<c<c1_l0
000703<c<`;o00000`1<C4`01?l00000IVIV06IVI_l0000307moO`030000002IVIT0000000<0/k>c
00?o00000<c<c03<c<`0203<c<`01?l00000/k>c0;>c/`00000209VIV@050000001oOgl0000006IV
IP0000000P1<C4`010000000<c<c03<c<`00000401TI6AP000001?ooool00`00003oooooooooo`0F
ooooo`03o`000?oooooooooo02oooooo0_nY_NP00onX_NSo001hob/aY002oge[]0?o/I:f00CoajFg
on2i/?oP^K3okLJ[0_ogdZD01?olfikoo^2Ioo_YV_okj9`3ooKG[P05onW5/_oS^Zkoe:Z]omBZ[Oo:
X:d00oo6VZT3ol2BY`05okjAYonoTJKo_i6VoknAY_nmSjL00_nnTJL2okZ=Z0?o/XVY0onWPJ/01?nI
Mj_oV7V^oh]`[on;L:l2oh5VZ`;oNF6[0_mbGZ`2ofYL/003odY9[_m>M=Woc;C200;oc;C20_oKcL`0
1_ojf:?ooN:Loo[WU?o?n:_of?V/om_bUR3ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`002Oooool01000003ooooooooooooooolH000000D06ATI00D0000003<c<`0c<c<0
<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT0
00000100/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`040000001VIVH0IVIV000000@0C4a<
0_l0000@03<c<`03o`00001<C4`0C4a<0080C4a<0P00000206IVIP070000001oOgl0Ogmo07moO`00
0000VIVI000000030;>c/`03o`00003<c<`0c<c<00P0c<c<00Co00000;>c/`2c/k<000000P2IVIT0
1@000000Ogmo0000001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6ATH000000Cooooo
00<00000ooooooooool05oooool00ol0003oooooooooo`0_ooooo`;oZKgX00?o001hobXgZol[<J@0
0_mmJk@2ok6B]P;oajFg0_o]aZ/2ooOBY@04ookPVOokjI[onnVJoo_SY@;om]N^0_oYaK82omBZ[@;o
bZ2]0oo6VZT3ol2BY`Co_i6V00Go_HnWokjAYonnTJOo^XfXok^@Z@03ok:9Z@;oYh6[00?oYh>^oiQi
[_nHNJh00_n;L:l2oh1Y/0?oNF6[0_mbGZ`01OmZG;3oHUjhoaach_lLLn;oc;C200?oflg<00Goi^cB
on;mb?oBnkCocoR[omohY`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?oo
ool000Wooooo00@00000oooooooooooooooo6000000501TI6@050000000c<c<0<c<c03<c<`000000
0`1<C4`010000000IVIV06IVIP00000307moO`050000002IVIT0VIVI09VIV@0000001P2c/k<5o`00
00D0/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV00800000101<C4`0
0ol00000<c<c03<c<`0:03<c<`?o00000`1<C4`2000000<0IVIV00D0000007moO`1oOgl0Ogmo0000
000209VIV@050000002c/k<0/k>c0;>c/ol000002P3<c<`02?l00000/k>c0;>c/`000000VIVI0000
001oOgl000000P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00806ATI6000
0004ooooo`0300000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool01?nY_NSo001ZobXg
ZolZ=j/2oge[]00=ok6B]_o7YKOoajFgolNU]ooK^[OokLJ[ooOBYOolfikoo>NQoo_YV_okj9conn>U
ooKG[P03onW5/P04omZe/ooDZZgobZ2]olZP[@;oaYZY0_o2UJT2ol2BY`Co_i6V0onnTJL00onjSJSo
^i2Yok^@Z@02ok:9Z@?oYh>^0_nHNJh2oh]`[`;oP6V`0omjIk82og9N[003ofYL/?mRG[SoHUjh00;o
77?R0ooKcL`01OoVk=;oh_g8olohZonkoMco/o2S02;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolI000000D06ATI00D0000003<c
<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVI
000000060;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00`2c/k<01Ol00000VIVI
09VIV@2IVIT0000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0?o00001P0c<c<3o`00
00D0C4a<00?o000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00D00000
0;>c/`2c/k<0/k>co`00000:0<c<c004o`00002c/k<0/k>c00000080VIVI00D0000007moOol00000
IVIV0000000204a<C0040000000c<c<0<c<c000000D06ATI60000004ooooo`0300000?oooooooooo
01Wooooo0_l0000`ooooo`03ojVmj?l007So:SN[00;oTGnl1?o7YKL01?oK^[OokLndong?]?oigZ`2
oo_YVP03oo_XW?ofejkom]N^00;ojLFb0_oJ]K<4olZP[@03olJJZOo2UJWo`YFY00?o`9:W0onoTJH3
okjAY`?o^i2Y0_nbRJT01?ndSJgoYh>^ojN3[_nWPjh2oiQi[P;oRg2_0_n0JK02ogYW/P;oMfVf0_mZ
G;02of9N^0;oGF[800Goflg<onK/d_oRoLSoFjShoiWZn@0Uooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo6@00000501TI6@050000
000c<c<0<c<c03<c<`0000000`1<C4`01?l00000IVIV06IVIP00000307moO`040000002IVIT0VIVI
o`0000D0/k>c00?o00000<c<c03<c<`0103<c<`3o`0000<0/k>c00@0000009VIV@2IVIT0VIVI0P00
000207moO`070000001VIVH0IVIV06IVIP00003o00000000000404a<C0Ko00001P1<C4`2000000<0
IVIV0P00000307moO`05o`00002IVIT0VIVI09VIV@0000000`2c/k<00ol00000c<c<0<c<c0070<c<
c0;o00000P2c/k<00`000000VIVIo`00000207moO`030000001VIVH000000080C4a<00@0000003<c
<`0c<c<000001@0I6ATH000000Cooooo00<00000ooooooooool06oooool00ol0003oooooooooo`0^
ooooo`03o`00J_lZ=j_oTGnl00;oTGnl0_o7YKL2om^j]`;okLnd00GonMj/oo_YV_okj9conn>UooGY
^002oncH_`03onW5/_oJ]K?of[Fc00CobZ2]0oo2UJT3ol2BY`;o_i6V0_o1U:L2okjAY`?o^i2Y00?o
/XVYokB=[OndSJd00onWPjh2oiQi[P;oRg2_0_n0JK02ogYW/P;oMfVf0_mgLKl3of9N^0;oGF[800?o
J9CYohgYm_n=jOH09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`0400000?oooooooooooooooaT000001P0I6AT01?l00000<c<c03<c<`00000304a<C0040000
001VIVH0IVIV000000<0Ogmo00@0000009VIV@2IVIT000001@2c/k<00ol00000c<c<0<c<c0070<c<
c005o`00002c/k<0/k>c0;>c/`000000102IVIT01@000000Ogmo07moOol00000000000@0IVIV00<0
000004a<C01<C4`02P1<C4`3000000<0IVIV0P00000307moO`8000000`2IVIT00ol00000/k>c0;>c
/`020;>c/`03o`00003<c<`0c<c<00H0c<c<00Go00000;>c/`2c/k<0/k>c0000000209VIV@060000
001oOgl0Ogmo0000001VIVH000000P1<C4`010000000<c<c03<c<`00000501TI6AP000001?ooool0
0`00003oooooooooo`0Looooo`03o`000?oooooooooo02gooooo00?o001ZobU3^?lZ=j/00_nAOk`0
0oo7YKOofkZgom^j]`02ong?]006ooWN[?olij7onnVJongeY?odljgomNVh0_o/f;l2omZe/`;ocZZe
0_o:X:d01?o3VZko`YFYol:EZOo2UJT3ol2BY`05oknAY_o1U:Oo`IBWol6DYonnTJL00_o2UJT2ok^@
Z@?o]8f]0onWPjh2oiQi[P;oRg2_0on0JK02ogYW/P;oMfVf00CoMg6oogV1d?miPM3oNH7@0on2ZNh0
0on=jOKoooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
00Wooooo00@00000oooooooooooooooo6P00000501TI6@050000000c<c<0<c<c03<c<`0000000`1<
C4`010000000IVIV06IVIP00000307moO`040000002IVIT0VIVI000000@0/k>c00?o00000<c<c03<
c<`0203<c<`01?l00000/k>c0;>c/`2c/k<2000000<0VIVI00D0000007moO`1oOgl0Ogmo00000004
06IVIP<000001P1<C4`3000000@0IVIV0P00000407moO`030000002IVIT0VIVI0080VIVI00<00000
0;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0060<c<c005o`00002c/k<0/k>c0;>c/ol000000`2I
VIT01@000000Ogmo0000001VIVH000000080C4a<00@0000003<c<`0c<c<000001@0I6ATI000000Co
oooo00<00000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`;o:D>h00?oTGnloj^Kaon[
VlL00_oK^[L2ong?]005ooWN[?okjI[okOFTongeY?oejKP00_o/f;l2omk7``04omZe/oo>Z[GocZZe
olZP[@?o`iZ^0_o2UJT3ol2BY`Co`IBW00?o_Y6Wol:EZOo2UJT00_nkT:T4okB=[@04ojN3[_nYSKOo
VX:ioiZ2^@;oRgZk0on1Mkl2ogalb0;oMfVf0_mgLKl3ogV1d003oh:Yk_oooooooooo02Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooo
oolJ000000H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV000000<0
Ogmo00@0000009VIV@2IVIT000000`2c/k<00ol00000c<c<0<c<c0090<c<c003o`00002c/k<0/k>c
0080/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`0300000?l00000000000@0IVIV1P000006
06IVIP03o`00001oOgl0Ogmo0080Ogmo0P00000309VIV@8000001@2c/k<00ol00000c<c<0<c<c004
0<c<c0;o0000102c/k<01P000000VIVI09VIV@000000Ogmo00000080IVIV00@0000004a<C01<C4co
00000P0c<c<00`0000006ATI01TI6@0301TI6AT000001?ooool00`00003oooooooooo`0Nooooo`;o
0000;Oooool00ol006[o:D>hoj^Ka`03oj^Ka`09om^j]oo]ckConMj/ooWN[?o[mj[okOFTooCc[Ooe
jKSok=Ro00?og/O30oo>Z[D4ol>J[P03ol:EZOo0UZ_o`9J[00;o`9:W00Co`YN[ol6DYoo1U:Oo`IBW
0oo2UJT00onkT:Wo_YJ]okjF[@02okB=[@03okRI]onYSKOoZHfg00?oVX:i0_n;N[/3oh5g_`03ogal
b?moS=KoOhcF00?oQjg^00?oRMknooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooaX000001P0I6AT01@000000<c<c
03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH000000`1oOgl010000000VIVI09VIV@000003
0;>c/`03o`00003<c<`0c<c<00X0c<c<00?o00000;>c/`2c/k<00P2c/k<01P000000VIVI09VIV@2I
VIWo0000000000@0Ogmo00<0000006IVIP1VIVH02P1VIVH3000000<0Ogmo0P00000409VIV@030000
002c/k<0/k>c00H0/k>c00Co00000<c<c03<c<`0c<c<0_l000060;>c/`060000002IVIT0VIVI0000
001oOgl000000P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00<06ATI6@00
0004ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool0:oooool2obU3^0;oZi_70_o:
`M401oo]ckConMj/oocWXOo]mJCoY_:folgod_oGmn800_o;in/00ooNal?oc[c8oljlb002oljZ]@04
ol>T^_o3VZko`iZ^ol>J[P?o`9J[00?o`9:Wol:GZoo2Uj/00oo1U:L3ol:EZ@?o_YJ]00?o]8f]okRI
]onhVKL00onYSKL2oiZ2^@;oRgZk0on1Mkl2ogalb0;oOhcF00?oQjg^ooooooooool0;oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooo
oa/000001P0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH000000`1o
Ogl010000000VIVI09VIV@0000030;>c/`03o`00003<c<`0c<c<00X0c<c<00?o00000;>c/`2c/k<0
0P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo0`00000606IVIP<00000
101oOgl2000000D0VIVI00<000000;>c/`2c/k<0202c/k<00ol00000c<c<o`0000070;>c/`060000
002IVIT0VIVI0000001oOgl000000P1VIVH01@000000C4a<04a<C01<C4`000000080<c<c00<00000
01TI6@0I6AT00`0I6ATI000000Cooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0[
ooooo`03obQMdOn[VlOob/7A00;ob/7A0_oUi]401?o[mj[oY_:folgod_oGmn82ol_Wj`05oj[Jn?o>
_<Soc[c8oljlb?o>Z[D00_o3Y;X3ol>J[P?o`9J[00?o`9:Wol:GZoo2Uj/00_o1U:L2olFK[0;o`YFY
0onnUZd4okRI]`;oZHfg00?oVX:ioj2Tf?n=X^800_n=X^83og^]l`03ofC5oOoooooooooo03?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooo
oooooolK000000H06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000306IVIP04
0000001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c/k?o00003@3<c<`00ol00000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0101oOgl6000000D0Ogmo00?o0000
0000002IVIT01@2IVIT00`000000/k>c0;>c/`0:0;>c/`03o`00002c/k<0/k>c00D0/k>c00@00000
09VIV@2IVIT000000P1oOgl01?l00000IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`00
0000100I6ATJ000000Cooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`0[ooooo`06
obQMdOo:`M7ob/7Aol[1dOoUi]7ok_Ro1_nY_NP2oj[Jn003oljlb?nk^=Oo`jBj00?o`jBj00?o`iZ^
okjK]?nnVk@00_o0UZ/4ol:GZ`04ol6DYoo5VjcoaI^/ol:EZ@;oain`0_nnUZd01_o6Y[Wo^9VgokRI
]onhVKOoZHfgok>]dP?oX:CH0on=X^800omk[O?oooooooooo`0eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo7000000601TI6@03
0000000c<c<0<c<c0080<c<c00Co000004a<C01<C4`000000`1VIVH01?l00000Ogmo07moOol00002
09VIV@05o`00002c/k<0/k>c0;>c/ol000003@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002I
VIT0VIVI0080VIVI0`00000<07moO`8000001@2IVIT00`00003o00000000000C0;>c/`8000000P2I
VIT010000000Ogmo07moO`00000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I
6AT00`0I6ATJ000000Cooooo00<00000ooooooooool08oooool00ol0003oooooooooo`0[ooooo`04
obb>k_o:`M7oiNKAodg6Z`WoZKgX00?oQ@00ok^heonk^=L00_o3Y;X01?nhYlSo_Y^dokjK]?nnVk@2
ol2FZ`Co`YN[0oo5Vj`3olNO/003okjF[Oo6Y[WoaZJi00?o^9Vg0onc[M800onPY=SoF=;?ooooo`0k
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooo
oooooooooooo7000000701TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`010000000IVIV06IV
IP00000207moO`050000002IVIT0VIVI09VIV@0000000`2c/k<00ol00000c<c<0<c<c00;0<c<c003
o`00002c/k<0/k>c0080/k>c0P00000509VIV@<000000P1oOgl7000000@0VIVI0`00000E0;>c/`05
0000002IVIT0VIVI09VIV@0000000`1oOgl010000000IVIV06IVIP00000204a<C0050000000c<c<0
<c<c03<c<`0000001@0I6ATJ000000Cooooo00<00000ooooooooool09?ooool2o`0002oooooo2_nY
_NP2ohFim`Co^:O80_nnVk@00oo0UZ_o`Ibbol6L/P02ol:GZ`04olNS/oo5VjcoaI^/olFK[0?oain`
1?o6Y[T01OnhVKOoaKgBolFmd_nc[M;oQ^_N03oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolM000000L06ATI00D0000003<c<`0c
<c<0<c<c0000000304a<C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVI0000
00030;>c/`03o`00003<c<`0c<c<00/0c<c<00?o00000;>c/`2c/k<00`2c/k<00`000000VIVI09VI
V@0509VIV@8000002P2IVIT00`000000/k>c0;>c/`0E0;>c/`050000002IVIT0VIVI09VIV@000000
0`1oOgl010000000IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATK0000
00Cooooo00<00000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`[oZKgX0_n5^OL3okRW
b003okjK]?nkY/Co`Ibb00;o`Ibb00Go`YN[olNS/oo7Xk?oaj>colFK[002olj/]`;oain`00?od[W1
olJV^Oo6Y[T00_oEe]T00oo5_M;oPnO4ooooo`10ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo7P00000701TI6@050000000c<c<0
<c<c03<c<`0000000`1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VIV@00
00000`2c/k<00ol00000c<c<0<c<c00;0<c<c003o`00002c/k<0/k>c00<0/k>c00?o000000000000
00003@2IVIT00`00003o00000000000F0;>c/`8000000`2IVIT01Ol00000Ogmo07moO`1oOgoo0000
0080IVIV00Go000004a<C01<C4`0C4a<o`00000303<c<`030000000I6AT06ATI00<06ATI6`000004
ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool8ojVmj0Cooooo00?o^:O8
oiFgkonkY/@00_nkY/@2ol6L/PCoaj>c00CoaI^/olj/]oo>[;Ooain`0_oB^L401?o6Y[WoeMKIomGF
fOoEe]U4ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool000Wooooo00@0
0000oooooooooooooooo7`00000601TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`010000000
IVIV06IVIP00000307moO`04o`00002IVIT0VIVIo`0000@0/k>c00?o00000<c<c03<c<`02P3<c<`0
0ol00000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00L0VIVI0`00000H0;>c/`030000002IVIT0
VIVI0080VIVI0P00000207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c03<c
<`0203<c<`030000000I6AT06ATI00<06ATI6`000004ooooo`0300000?oooooooooo02Sooooo00?o
0000ooooooooool0;Oooool3ojVmj0Wooooo0_nE]nl2ok^Va003ol6L/_o5[lGoaJo500?oaj>c0oo>
[;L3om:i`@;oe?[Q00?oeMKIooooooooool0A?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo0009ooooo`0400000?ooooooooooooooob0000001P0I6AT01@000000<c<c03<c
<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH000000P1oOgl01@000000VIVI09VIV@2IVIT00000
00@0/k>c00?o00000<c<c03<c<`02P3<c<`00ol00000/k>c0;>c/`060;>c/`<000001@2IVIT00`00
0000/k>c0;>c/`0G0;>c/`8000000`2IVIT2000000<0Ogmo00D0000006IVIP1VIVH0IVIV00000003
04a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATL000000Cooooo00<00000ooooooooool0:Ooo
ool2o`0002gooooo00?o0000ooooooooool02oooool00onkY/CoYLWcolF_a@03olF_a@04olNS/ooA
`LWodL79olj/]`;og=SD00?od[W1omCjhOoDn^40BOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo0009ooooo`0400000?ooooooooooooooob0000001P0I6AT00`000000<c<c
03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH010000000Ogmo07moO`00000309VI
V@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`02@3<c<`00ol00000/k>c0;>c/`090;>c
/`D00000602c/k<2000000@0VIVI00?o000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH0
000000<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0301TI6A`000001?ooool0
0`00003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03?ooool2
ojG9l`;oaJo50_ndj_L01?oA`LWoXOKKoj7ffooLf=A=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo8@00000601TI6@030000000c
<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP040000001oOgl0Ogmo000000<0
VIVI00<000000;>c/`2c/k<00P2c/k<2o`0000X0c<c<00?o00000;>c/`2c/k<08`2c/k<2000000D0
VIVI0P00000207moO`8000000`1VIVH01Ol00000C4a<04a<C01<C4co000000@0<c<c00<0000001TI
6@0I6AT00`0I6ATM000000Cooooo00<00000ooooooooool0;?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo013ooooo00?o]>[gooooooooool0DOooool01Ol0003ooooooooooooooooo
000000_ooooo0009ooooo`0400000?ooooooooooooooob8000001P0I6AT00`000000<c<c03<c<`02
03<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH01Ol00000Ogmo07moOol0000000000080VIVI
00?o00000000002c/k<00`2c/k<00ol00000c<c<0<c<c0070<c<c003o`00002c/k<0/k>c0280/k>c
00<0000009VIV@2IVIT00P2IVIT300000080Ogmo0P00000306IVIP8000000`1<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00@06ATI7@000004ooooo`0300000?oooooooooo02gooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_o
oooo0009ooooo`0400000?ooooooooooooooob<000001P0I6AT00`000000<c<c03<c<`0203<c<`05
0000001<C4`0C4a<04a<C00000000P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<00000
0;>c/`2c/k<00P2c/k<6o`000080c<c<00?o00000;>c/`2c/k<0802c/k<3000000<0VIVI0P000004
07moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`02
03<c<`030000000I6AT06ATI00@06ATI7P000004ooooo`0300000?oooooooooo02kooooo0_l0000X
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool000Wooooo00@00000oooo
oooooooooooo8`0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c0080<c<c00D00000
04a<C01<C4`0C4a<0000000206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT2000000P0/k>c
0_l0000O0;>c/`80000000?o00000000002IVIT00`2IVIT2000000@0Ogmo0P00000306IVIP800000
0`1<C4`2000000@0<c<c00<0000001TI6@0I6AT0100I6ATO000000Cooooo00<00000ooooooooool0
<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000
2oooool000Wooooo00@00000oooooooooooooooo9@00000601TI6@030000000c<c<0<c<c0080<c<c
00Go000004a<C01<C4`0C4a<o`00000206IVIP06o`0000000000Ogmo07moOol0000000000`2IVIT2
000002@0/k>c0`00000709VIV@030000001oOgl0Ogmo0080Ogmo0P00000306IVIP800000101<C4`0
0`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00D06ATI7`000004ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
000000[ooooo0009ooooo`0400000?ooooooooooooooobH000001P0I6AT01@000000<c<c03<c<`0c
<c<0000000@0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002IVIT0VIVI0080VIVI
0`00000J0;>c/`L000001`2IVIT3000000<0Ogmo0P00000406IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0501TI6B0000001?ooool00`00003ooooo
ooooo`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo
0009ooooo`0400000?ooooooooooooooobL000001P0I6AT01@000000<c<c03<c<`0c<c<0000000@0
C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<0402c/k<7000000/0VIVI0`00000407moO`8000001@1VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT01@0I6ATQ000000Cooooo00<00000oooo
ooooool0<oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0000[ooooo0009ooooo`04
00000?ooooooooooooooobH0000000?o000001TI6@0I6AT01@0I6AT01?l00000<c<c03<c<`0c<c<2
000000<0C4a<0P00000206IVIP8000000P1oOgl00ol0000000000000000409VIV@03o`0000000000
000000<000001P2c/k<6000000h0VIVI0`0000000ol00000Ogmo07moO`0207moO`80000000?o0000
06IVIP1VIVH00P1VIVH200000003o`00001<C4`0C4a<0080C4a<0P00000403<c<`8000001`0I6ATR
000000Cooooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06?ooooo1?l0000=ooooo`002Oooool01000003ooooooooooooooolX000000L06ATI00<00000
03<c<`0c<c<00P0c<c<2000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`800000202I
VIT600000140VIVI0`00000607moO`8000001@1VIVH2000000D0C4a<0P00000503<c<`030000000I
6AT06ATI00H06ATI8`000004ooooo`0300000?oooooooooo03Kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@00000oooooooooooooooo:@00
000701TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP800000
101oOgl00`000000VIVI09VIV@0H09VIV@@000001`1oOgl2000000D0IVIV0P00000504a<C0800000
1@0c<c<2000000P06ATI90000004ooooo`0300000?oooooooooo03Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@00000oooooooooooooooo
:P0000000ol000006ATI01TI6@0401TI6@03o`0000000000<c<c00<0<c<c00@0000004a<C01<C4`0
C4a<0P00000306IVIP8000000`1oOgl4000000l0VIVI1`00000607moO`D000000`1VIVH200000003
o`0000000000C4a<00<0C4a<0`00000603<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000
00008P000004ooooo`0300000?oooooooooo03Sooooo0_l0000Nooooo`03o`000?oooooooooo05So
oooo1?l0000Hooooo`002Oooool01000003oooooooooooooool/000000L06ATI00H0000003<c<`0c
<c<0<c<co`000000000404a<C0030000001VIVH0IVIV0080IVIV0`00000407moO`l000002`1oOgl2
000000D0IVIV0`00000604a<C08000001P0c<c<3000000P06ATI9`000004ooooo`0300000?oooooo
oooo03[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co00007?ooool0
00Wooooo00@00000oooooooooooooooo;@00000701TI6@030000000c<c<0<c<c0080<c<c0P000003
04a<C08000001@1VIVH3000001@0Ogmo1`00000306IVIP@000001`1<C4`2000000D0<c<c0`00000:
01TI6BP000001?ooool00`00003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0DOooool3o`00023ooooo0009ooooo`0400000?ooooooooooooooobh000001P0I6AT0
0`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH01@1VIVH2
000000l0Ogmo0`00000806IVIP03o`0000000000C4a<00L0C4a<0`00000603<c<`030000000I6AT0
6ATI00X06ATI00?o00000000000000009P000004ooooo`0300000?oooooooooo03cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co00008oooool000Wooooo00@00000oooo
oooooooooooo;@0000000ol00000000001TI6@0501TI6@800000100c<c<00ol00000000000000003
04a<C00400000?l000000000000000@0IVIV00?o00000000000000002`0000000ol00000000006IV
IP0506IVIPD000001P1<C4`200000003o`0000000000<c<c00D0<c<c0`00000;01TI6B/000001?oo
ool00`00003oooooooooo`0mooooo`;o00006Oooool00ol0003oooooooooo`19ooooo`Co00009ooo
ool000Wooooo00@00000oooooooooooooooo<000000701TI6@8000001@0c<c<2000000D0C4a<0`00
000D06IVIP<000001`1<C4`4000000L0<c<c0`00000;01TI6Bh000001?ooool00`00003ooooooooo
o`0oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo0009
ooooo`0400000?oooooooooooooooc400000200I6AT00`000000<c<c03<c<`0403<c<`8000001P1<
C4`4000000`0IVIV1000000704a<C0<00000200c<c<3000000d06ATI;`000004ooooo`0300000?oo
oooooooo043ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000;ooo
ool000Wooooo00@00000oooooooooooooooo<@0000000ol00000000001TI6@0601TI6@0300000?l0
0000000000D0<c<c0`00000704a<C0L0000000?o00000000000000000P00000704a<C0<0000000?o
000003<c<`0c<c<01@0c<c<200000003o`00000000006ATI00`06ATI<P000004ooooo`0300000?oo
oooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co0000<_oo
ool000Wooooo00@00000oooooooooooooooo=000000901TI6@030000000c<c<0<c<c00D0<c<c0`00
000D04a<C0<000002P0c<c<00`0000006ATI01TI6@0<01TI6CD000001?ooool00`00003ooooooooo
o`12ooooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool000Wooooo00@00000
oooooooooooooooo=@00000901TI6@800000200c<c<4000000`0C4a<1000000:03<c<`<00000300I
6ATh000000Cooooo00<00000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03Oooooo1?l0000jooooo`002Oooool01000003ooooooooooooooolf000000X06ATI00<0
000003<c<`0c<c<02@0c<c<<000000/0<c<c0`00000>01TI6CT000001?ooool00`00003ooooooooo
o`15ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo0009
ooooo`0400000?ooooooooooooooocL0000000?o00000000000I6AT01`0I6AT01000003o00000000
0000000J03<c<`<0000000?o000001TI6@0I6AT0300I6AT200000003o`0000000000000003L00000
1?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
<?ooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooocX000002`0I6AT3000001@0<c<c
0`00000>01TI6D0000001?ooool00`00003oooooooooo`17ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0;?ooool4o`0004Gooooo0009ooooo`0400000?oooooooooooooooc/00000
3@0I6AT4000000`0<c<c1000000>01TI6D<000001?ooool00`00003oooooooooo`18ooooo`;o0000
3Oooool00ol0003oooooooooo`0Xooooo`Co0000BOooool000Wooooo00@00000oooooooooooooooo
?P00000>01TI6@`000003`0I6AT200000003o`00000000000000044000001?ooool00`00003ooooo
ooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool4o`0004gooooo
0009ooooo`0400000?oooooooooooooood0000009@0I6AU8000000Cooooo00<00000ooooooooool0
Boooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001Aooooo`002Ooo
ool01000003ooooooooooooooom2000002406ATIBP000004ooooo`0300000?oooooooooo04cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool000Wooooo00@0
0000oooooooooooooooo@`00000M01TI6Dd000001?ooool00`00003oooooooooo`1=ooooo`;o0000
2?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000oooooooooooooooo
@`0000000ol00000000000000002000001@06ATID@000004ooooo`0300000?oooooooooo04oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wooooo00@0
0000ooooooooooooooooC000000<01TI6ED000001?ooool00`00003oooooooooo`1@ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000
Ioooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo05Cooooo
00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo0ol0001_ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0E_ooool2o`000003
ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo05Oooooo0_l0001fooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo]P00003Aoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00017ooooo]_l0000:ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0A?ooool200000003
o`0000000000000000h00000Foooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool7000001?ooooo
2`00001@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`<000009Oooool7000004Wooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Wooooo00<00000ooooooooool0;Oooool3000004Kooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03Kooooo00<00000o`0000000000<oooool4000004;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Gooooo00<00000ooooooooool0>?ooool3000003oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo0P00000Coooooad000003_ooool4000003_ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0C?oooolI0?nf`Dgooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0aooooo`8000003Oooool00`00003o0000o`000005000000Cooooo6@3o
]/401000003o000000000000000>ooooo`@00000=oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`19oooooal0okK1B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo033ooooo00<00000ooooooooool02_ooool3000000Wooooo7`3o]/401?ooool000000000
0000000?ooooo`800000=Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`16ooooobD0okK1Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00<0
0000ooooooooool02?ooool3000000Wooooo2@3o]/4C000000T0okK100?ooooo0000000000000P00
000=ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0@oooool[0?nf`DCooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool50?nf`@L000004`3o]/47
000000D0okK10_ooool3000000_ooooo0`00000aooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo043ooooo<@3o]/51ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;Oooool00`00003oooooooooo`07ooooo`8000001oooool40?nf`@80000000?o00000000
003o]/40403o]/45000000/0okK10`0000050?nf`@;ooooo00Co000000000000000000002_ooool0
0ol0000000000000000^ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
03gooooo=`3o]/4nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00`00
003oooooooooo`06ooooo`8000001_ooool40?nf`@<000002`3o]/4:000000D0okK11`0000070?nf
`@@00000103o]/43ooooo`8000002oooool2000002cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0>_oooolk0?nf`Cgooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0[ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool00oooool30?nf`@@0
00002P3o]/44000001H0okK11`0000040?nf`@<000000P3o]/44ooooo`8000002oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Wooooo
?@3o]/4looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00003ooooo
ooooo`05ooooo`0300000?l0003ooooo00Cooooo00@0okK1o`000000000000001`3o]/47000000L0
okK100<00000o`000?l000004@0000060?nf`@<00000103o]/43000000Gooooo00?o000000000?oo
ool02Oooool00`00003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03Oooooo@P3o]/4iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00?ooooo0P3o]/400`000000okK1
0?nf`@050?nf`@<000002`3o]/43000001@0okK10`0000060?nf`@030000003o]/40okK100@0okK1
00<000000?nf`@3o]/401?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo02Oooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=OoooolU0?nf`@Ko003o6`3o
]/4gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo00;ooooo0P3o]/42000000L0okK100<000000?nf`@3o]/40203o
]/44000000L0okK13`0000040?nf`@<00000103o]/43000000@0okK10P0000020?nf`@?ooooo0P00
0009ooooo`0300000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0=?oooolR0?nf`@Co003o1P3o]/47o`00oaD0okK1=_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Sooooo00<00000ooooooooool01Oooool01000003ooooooooooooo
ool20?nf`@030000003o]/40okK100@0okK10`0000080?nf`@<000001`3o]/44000000l0okK11000
00030?nf`@@000000`3o]/400`00003o00000?nf`@030?nf`@80000000<0okK1ooooooooool00_oo
ool2000000Sooooo00<00000ooooooooool09Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0cooooob40okK10_l00?lA0?nf`@?o003o4`3o]/4eooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09oooool00`00003oooooooooo`05ooooo`0700000?oooooo
ooooooooo`3o]/7o0000000000040?nf`@<000001`3o]/44000000L0okK100<00000o`0000000000
103o]/4?000000@0okK100Co000000000000000000000`3o]/42000000<0okK10P0000040?nf`@80
00001Oooool2000000Oooooo0P00000Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03;ooooo803o]/42o`00oaH0okK10_l00?lB0?nf`CCooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Wooooo`0300000?oooooooooo00Cooooo00H00000oooooooooooo
oooo0?nf`@0000050?nf`@030000003o]/40okK100D0okK10`0000080?nf`@<00000103o]/430000
00l0okK1100000040?nf`@8000000`3o]/42000000<0okK10P0000040?nf`@0300000?oooooooooo
00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo033ooooo8@3o]/400ol00?l0okK10?nf`@0H0?nf`@;o
003o4P3o]/4booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo0080okK100<000000?nf`@3o]/400P3o]/42000000D0
okK10`0000090?nf`@8000001@3o]/42000000H0okK13?l000040?nf`@<000000`3o]/400`000000
okK10?nf`@020?nf`@<000000P3o]/42000000<0okK10`000004ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0_ooooob40okK100?o003o0?nf`@3o]/406`3o]/42o`00oa40okK1<Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/42000000T0okK1
00<00000o`00000000001P3o]/400`000000okK10?nf`@030?nf`@?o0000303o]/44o`0000<0okK1
00@00000o`0000000000okK1100000030?nf`@05o`00003o]/40okK10?nf`@0000001@3o]/400`00
003oooooooooo`02ooooo`03o`000000003ooooo00Kooooo00<00000ooooooooool08?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0^ooooob80okK100?o003o0?nf`@3o
]/407@3o]/400ol00?l0okK10?nf`@0?0?nf`C3ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Uooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00P3o]/400ol00000
okK10?nf`@020?nf`@030000003o]/40okK10080okK100<00000o`00003o]/401`3o]/43000000P0
okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@050?nf`@So0000103o]/43o`0000<0
okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@02000000<0okK100<000000?nf`@3o
]/400P3o]/400`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool08?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0]ooooob80okK1
00?o003o0?nf`@3o]/407`3o]/400ol00?l0okK10?nf`@0?0?nf`Boooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Tooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
0P3o]/4010000000okK10?nf`@3o]/42000000@0okK100<000000?nf`@3o]/401@3o]/43000000X0
okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@?o0000203o]/44o`0000<0
okK10_l000020?nf`@8000000`3o]/4010000000okK10?nf`@3o]/4200000080okK100<000000?nf
`@3o]/400P3o]/42000000Cooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02cooooo8`3o]/400ol00?l0
okK10?nf`@0P0?nf`@03o`00o`3o]/40okK100l0okK1;_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`020?nf`@05
0000003o]/40okK10?nf`@000000103o]/42000000L0okK100<000000?nf`@3o]/402P3o]/400`00
0000okK10?nf`@030?nf`@03o`00003o]/40okK10080okK10_l0000?0?nf`@03o`00003o]/40okK1
0080okK100Go00000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK10080okK100?o0000
0?nf`@3o]/400P0000040?nf`@0300000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0`00003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02_ooooo903o]/400ol00?l0okK10?nf`@0Q0?nf`@03o`00o`3o]/40okK100l0okK1;Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00<00000ooooooooool00oooool01Ol0
003ooooo0?nf`@3o]/40000000<0okK100@000000?nf`@3o]/40okK10P0000050?nf`@@00000303o
]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/401@3o
]/46o`0000D0okK10_l000030?nf`@;o00000P3o]/401?l0000000000?nf`@3o]/42000000<0okK1
00D000000?nf`@3o]/40okK1000000040?nf`@03o`000?oooooooooo00;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02[ooooo903o]/400ol00?l0okK10?nf`@0R0?nf`@03o`00o`3o]/40okK100l0okK1
;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1?ooool01@000000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o]/40okK1000000050?nf
`@800000403o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK10080okK100?o00000?nf
`@3o]/401@3o]/400ol00000okK10?nf`@030?nf`@;o00001@3o]/401Ol00000okK10?nf`@3o]/7o
000000@0okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@000000
0`3o]/400oooool00000ooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Zooooob@0okK100?o
003o0?nf`@3o]/40403o]/43o`0000l0okK100?o003o0?nf`@3o]/40403o]/4/ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08_ooool00`00003oooooooooo`03ooooo`0300000?oo
ool0okK10080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10100okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@03o`00
003o]/40okK100@0okK100?o00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@030?nf`@05o`00
003o]/40okK10?nf`Ol00000103o]/401@000000okK10?nf`@3o]/40000000<0okK100D000000?nf
`@3o]/40okK1000000030?nf`@0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02Wooooo9P3o]/400ol00?l0okK10?nf`@0>0?nf`@Go00003`3o]/400ol00?l0okK10?nf`@0@0?nf
`B_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`0300000?oooooooooo
00Cooooo00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000000`3o
]/42000001<0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@03o`00003o
]/40okK100<0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@030?nf`@05o`00003o
]/40okK10?nf`Ol00000103o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100@000000?nf`@3o
]/400000103o]/401@00003oooooooooooooool0000000Kooooo00<00000ooooooooool07Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0XooooobL0okK100?o003o0?nf
`@3o]/403P3o]/45o`000100okK100?o003o0?nf`@3o]/40403o]/4Zooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool08Oooool00`00003oooooooooo`03ooooo`030000003o]/40okK1
008000000P3o]/400`000000okK10?nf`@0200000080okK10P00000E0?nf`@030000003o]/40okK1
00<0okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@;o00002`3o]/400ol0
0000okK10?nf`@030?nf`@04o`00003o]/40okK10?nf`@;o00000P3o]/400`000000okK10?nf`@02
0?nf`@050000003o]/40okK10?nf`@0000000P3o]/42000000<0okK100H00000oooooooooooooooo
o`0000000005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool09ooooolY0?nf`@03o`00o`3o]/40okK100d0okK11Ol0000A0?nf`@03o`00
o`3o]/40okK10100okK1:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo
00<00000ooooooooool00_ooool01?l00000okK10?nf`@0000030?nf`@04o`00003o]/40okK10000
00<0okK100<000000?nf`@3o]/400`3o]/47000000`0okK100?o00000000003o]/400`3o]/401?l0
0000okK10?nf`@3o]/42o`0000D0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@03
0?nf`@03o`00003o]/40okK10080okK100Go00000?nf`@3o]/40okK1000000030?nf`@050000003o
]/40okK10?nf`@000000103o]/4010000000okK10?nf`@000004ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0VooooobX0okK100?o003o0?nf`@3o]/403P3o]/43o`000180okK100?o003o0?nf`@3o]/40
403o]/4Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00`00003ooooo
ooooo`03ooooo`040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000`3o]/401000
0000okK10?nf`@3o]/43000000L0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@02
0?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/400`3o]/42o`0000L0okK100?o0000
0?nf`@3o]/401@3o]/400ol00000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`@0000000`3o
]/401@000000okK10?nf`@3o]/40000000@0okK100Co00000?nf`@3o]/7o00001?ooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool09_ooool@0?nf`@Go003o5P3o]/400ol00?l0okK10?nf`@0R0?nf`@03o`00
o`3o]/40okK10140okK1:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo
00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf`@040000003o]/40okK10000
0080okK10P0000020?nf`@8000002`3o]/400ol00000okK10?nf`@0;0?nf`@030000003o]/40okK1
0080okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@040?nf`@Co00000P3o]/42o`00
00L0okK100?o00000?nf`@3o]/400`3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100Go0000
0000003o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000000oooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool09Oooool>0?nf`@?o003o1@3o]/42o`00oaD0okK100?o003o0?nf`@3o]/40803o
]/400ol00?l0okK10?nf`@0C0?nf`BOooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Oooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/401P000000okK1
0?nf`@000000okK1000000<0okK100?o00000?nf`@3o]/402`3o]/400`000000okK10?nf`@0;0?nf
`@03o`0000000000okK100<0okK100?o00000?nf`@3o]/400P3o]/42o`0000P0okK10_l000080?nf
`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40
00000080okK100D000000?nf`@3o]/40okK1000000030?nf`@0500000?ooooooooooooooo`000000
1_ooool00`00003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo02Cooooo3P3o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK101<0okK100?o
003o0?nf`@3o]/407`3o]/400ol00?l0okK10?nf`@0C0?nf`BOooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Nooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/400000
0P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000h0okK100<000000?nf
`@3o]/403@3o]/42000000<0okK10_l000040?nf`@;o00003`3o]/400ol00000okK10?nf`@050?nf
`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@000003
0?nf`@040000003o]/40okK1000000Cooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Cooooo3@3o]/40
0ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK101<0okK10_l00?lN0?nf`@;o003o5P3o]/4V
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00`00003oooooooooo`03
ooooo`060000003o]/40okK10000003o]/4000000`3o]/400`000000okK1000000020?nf`@030000
003o]/40okK10080okK11_l000050?nf`@030000003o]/40okK100@0okK100?o0000000000000000
0`0000050?nf`@8000000`3o]/42o`0000@0okK10ol0000:0?nf`@;o00002@3o]/400ol00000okK1
0?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/4010000000okK10?nf`@0000030?nf
`@0500000?ooooooooooooooo`0000001_ooool00`00003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02?ooooo3P3o]/400ol00?l0okK10?nf`@0:0?nf
`@03o`00o`3o]/40okK101D0okK100?o003o0?nf`@3o]/406@3o]/42o`00oaP0okK19_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00<00000ooooooooool00_ooool01Ol0
000000000?nf`@3o]/4000000080okK100Ko00000?nf`@3o]/4000000?nf`@0000020?nf`@040000
003o]/40okK10?nf`@;o00001P3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100@0
okK100?o00000?nf`@3o]/400`3o]/401?l0000000000000000000030?nf`@0300000?l000000000
0080okK10ol000040?nf`@[o00002`3o]/400ol00000okK10?nf`@030?nf`@050000003o]/40okK1
0?nf`Ol000000`3o]/401?l00000okK10?nf`@0000020?nf`@0300000?oooooooooo00;ooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02?ooooo3@3o]/400ol00?l0okK10?nf`@0<0?nf`@03o`00o`3o]/40
okK101D0okK10_l00?lH0?nf`@03o`00o`3o]/40okK101T0okK19Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00<00000ooooooooool00_ooool01@000000okK10?nf`@3o
]/4000000080okK100P000000?nf`@3o]/4000000?nf`@000000okK1o`000080okK10_l000080?nf
`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@080?nf
`@<000000`3o]/42000000<0okK11?l0000D0?nf`@03o`00003o]/40okK100@0okK100<000000?nf
`@3o]/400P3o]/401`000000okK10?nf`@3o]/4000000?nf`@0000000P3o]/400`000000okK1oooo
o`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool06Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Rooooo`d0okK100?o003o0?nf`@3o]/403@3o]/40
0ol00?l0okK10?nf`@0G0?nf`@?o003o503o]/400ol00?l0okK10?nf`@0K0?nf`BCooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Looooo`0300000?oooooooooo00;ooooo00D00000
0?nf`@3o]/40okK1000000020?nf`@080000003o]/40okK10000003o]/4000000?nf`@0000020?nf
`@03o`00003o]/40okK100T0okK100Go00000?nf`@3o]/40okK1000000040?nf`@030000003o]/40
okK100`0okK100<000000?nf`@3o]/400P3o]/43000000@0okK11ol0000<0?nf`@03o`00003o]/40
okK100H0okK100Go00000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1o`000080okK1
00D000000?nf`Oooooooooooo`000005ooooo`0300000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool08Oooool=0?nf`@03o`00o`3o]/40okK100l0okK1
00?o003o0?nf`@3o]/406@3o]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK101`0okK1
9?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00<00000ooooooooool0
0_ooool010000000okK10?nf`@0000020?nf`@080000003o]/40okK10000003o]/7o00000?nf`@00
00020?nf`@03o`00003o]/40okK10080okK11?l000050?nf`@04o`00003o]/40okK100000080okK1
00?o00000000003o]/400P3o]/4:000000<0okK1100000030?nf`@80000000?o00000000003o]/40
1P3o]/4<o`0000X0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK10000
00<0okK100D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo01Wooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool<0?nf`@03o`00o`3o]/40okK1
0100okK100?o003o0?nf`@3o]/406P3o]/47o`00o`P0okK10ol00?lP0?nf`B?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Looooo`0300000?oooooooooo00;ooooo00@000000?nf
`@3o]/4000000P3o]/400`000000okK1o`0000020?nf`@050000003o]/4000000?nf`Ol000000`3o
]/42o`0000@0okK100?o00000?nf`@3o]/400P3o]/401?l00000okK10?nf`@0000020?nf`@050000
003o]/40okK10?nf`@0000002P3o]/43000000@0okK10`0000040?nf`@L000005P3o]/401@000000
okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/401@000000okK1oooooooo
ool0000000Cooooo00<00000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Pooooo`d0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0Q
0?nf`@So003o8`3o]/4Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool0
0`00003oooooooooo`02ooooo`070?nf`@000000okK10?nf`@000000okK1000000020?nf`@050000
003o]/4000000?nf`@0000000P3o]/401?l00000okK10?nf`Ol000070?nf`@05o`00003o]/40okK1
0?nf`Ol000000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK100/0okK10`00
00040?nf`@@000001`3o]/43000001@0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000
003o]/40okK100000080okK100D000000?nf`Ooooooooooo00000004ooooo`0300000?oooooooooo
01Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool<0?nf`@03
o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/40C@3o]/4Rooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06oooool00`00003oooooooooo`02ooooo`040000003o]/40okK10000
0080okK100<000000?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080okK100?o0000
0?nf`@3o]/401P3o]/401ol00000okK10?nf`@3o]/7o00000?nf`@0000000P3o]/401@000000okK1
0?nf`@3o]/40000000@0okK100?o00000000000000001P0000040?nf`@@00000103o]/4400000003
o`00003o]/40okK100<0okK11000000@0?nf`@050000003o]/40okK10?nf`@0000000P3o]/401000
0000okK10?nf`@0000030?nf`@040000003o]/7ooooo000000Gooooo00<00000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Oooooo``0okK100?o003o
0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@1=0?nf`B7ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Kooooo`0600000?ooooooooooooooo`3o]/4000000P3o]/4030000000okK1
0?nf`Ol00000okK10000003o]/4000000?nf`@000000okK1o`000080okK100?o00000?nf`@3o]/40
203o]/401_l00000okK10?nf`Ol00000okK100000080okK100@000000?nf`@3o]/4000000`3o]/40
0`00003o00000?nf`@080?nf`@04o`00000000000000000000@0okK100Co00000000000000000000
1@3o]/45000000@0okK10P00000?0?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/4010000000
okK10?nf`@0000020?nf`@040000003o]/40okK1000000Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo``0okK100?o003o0?nf
`@3o]/40503o]/400ol00?l0okK10?nf`@1=0?nf`B7ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Kooooo`0300000?oooooooooo0080okK100<000000?nf`Ol000000`3o]/401000
0000okK100000?l000020?nf`@050000003o]/7o00000?nf`Ol000002`3o]/401_l00000okK10?nf
`Ol00000okK100000080okK100@000000?nf`@3o]/4000000P3o]/400`000000okK10?nf`@0=0?nf
`@@00000103o]/43000000L0okK10`0000030?nf`@8000003P3o]/4010000000okK10?nf`@000002
0?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/4000001Oooool00`00003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo303o
]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK104h0okK18?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo00H00000oooooooooooooooo0?nf`@0000020?nf`@0<
0000003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/7o00000P3o]/401?l00000
okK10?nf`@3o]/45o`0000<0okK100?o00000?nf`Ol000000P3o]/400`000000okK1000000020?nf
`@040000003o]/40okK1000000D0okK12?l000070?nf`@@000000`3o]/44000000H0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@0;0?nf`@050000003o]/40okK10?nf`Ol000000P3o
]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000Cooooo00<00000oooooooo
ool06?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`d0okK1
00?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@1>0?nf`B3ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Iooooo`0600000?ooooooooooooooo`3o]/7o00000`3o]/402@00
0000okK10000003o]/4000000?nf`@000000okK1000000020?nf`@03o`00003o]/7o000000<0okK1
00?o00000?nf`@3o]/400P3o]/401ol00000okK10?nf`@3o]/7o00000?nf`Ol000000P3o]/401@00
0000okK10000003o]/7o00000080okK100?o00000?nf`@3o]/400P3o]/42o`0000P0okK11?l00007
0?nf`@04o`00000000000000000000<0okK10`0000040?nf`@05o`00003o]/40okK10?nf`Ol00000
3P3o]/4010000000okK10?nf`@0000020?nf`@04o`00003o]/40okK100000080okK100@000000?nf
`@3o]/4000001Oooool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01gooooo303o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK1
0100okK11`3ooolg0?nf`B3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ioooo
o`0600000?ooooooooooooooo`3o]/4000000`3o]/402@000000okK10000003o]/4000000?nf`@00
0000okK1000000020?nf`@03o`00003o]/7o00000080okK100?o00000?nf`@3o]/400`3o]/401ol0
0000okK10?nf`@3o]/7o00000?nf`Ol000000P3o]/401@000000okK10000003o]/4000000080okK1
00<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@040?nf`@L0oooo0ol000080?nf`@800000
103o]/401@000000okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/40103o]/44o`0000@0
okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40
okK1000000Gooooo00<00000ooooooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Mooooo``0okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0<
0?nf`@l0oooo7@3o]/44o`00oa<0okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Wooooo00H00000oooooooooooooooo0?nf`@0000020?nf`@070000003o]/40okK10000003o
]/4000000?nf`@0200000080okK100?o00000?nf`Ol000000P3o]/400ol00000okK10?nf`@040?nf
`@07o`00003o]/40okK10?nf`Ol00000okK1o`0000020?nf`@8000000P3o]/4010000000okK10?nf
`@0000030?nf`@04o`00003o]/40okK10?nf`@h0oooo1?l000060?nf`@030000003o]/40okK10080
okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@040?nf`@05o`00003o]/40okK1
0?nf`Ol00000103o]/401P000000okK10?nf`@000000okK100000080okK100@000000?nf`@3o]/40
00000P3o]/400`00003oooooooooo`03ooooo`0300000?oooooooooo01Oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool07?ooool=0?nf`@03o`00o`3o]/40okK101D0okK1
00?o003o0?nf`@3o]/402P3o]/4C0?oooaX0okK100?o003o0?nf`@3o]/400P3o]/43o`00oa00okK1
7oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00H00000oooooooooooo
oooo0?nf`@0000030?nf`@030000003o]/4000000080okK10P0000002@3o]/4000000?nf`@3o]/7o
00000?nf`Ol00000okK1o`0000080?nf`@0<o`00003o]/40okK1o`00003o]/7o00000?nf`@000000
okK10000003o]/4000000P3o]/401@000000okK10?nf`@3o]/7o00000080okK10P3oool:o`0000L0
oooo00@0okK1o`000?l0003o0000103o]/42000000<0okK100@000000?nf`@3o]/4000000`3o]/40
0`000000okK10?nf`@020?nf`@03o`00003o]/40okK100<0okK100Go00000?nf`@3o]/40okK10000
00020?nf`@040000003o]/40okK100000080okK100<000000?nf`@0000000`3o]/400`00003ooooo
ooooo`02ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool07?ooool=0?nf`@03o`00o`3o]/40okK100L0okK10ol0000;0?nf`@03o`00o`3o
]/40okK100P0okK15`3ooolG0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/403@3o
]/4Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool01P00003ooooooooo
ooooool0okK100000080okK100h000000?nf`@3o]/4000000?nf`@000000okK10000003o]/7o0000
0?nf`Ol00000okK1o`000080okK100?o00000?nf`@3o]/401P3o]/403?l00000okK10?nf`Ol00000
okK1o`00003o]/4000000?nf`Ol00000okK100000080okK100D000000?nf`@3o]/7o00000?nf`@03
0?ooo`;o00002@3oool4o`0000D0oooo0P3o]/42o`0000@0okK100D000000?nf`@3o]/40okK10000
00020?nf`@040000003o]/40okK1000000<0okK100?o00000?nf`@3o]/401@3o]/401Ol00000okK1
0?nf`@3o]/7o00000080okK100<000000?nf`@0000000P3o]/400`000000okK1000000030?nf`@03
00000?oooooooooo00;ooooo00<00000ooooooooool05oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Looooo``0okK100?o003o0?nf`@3o]/401`3o]/45o`0000T0okK1
00?o003o0?nf`@3o]/40203o]/4J0?oooa@0okK100?o003o0?nf`@3o]/40203o]/400ol00?l0okK1
0?nf`@0=0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`060000
0?ooooooooooooooo`3o]/4000000P3o]/403P000000okK10?nf`@000000okK10000003o]/400000
0?nf`@000000okK1o`00003o]/7o00000P3o]/400ol00000okK10?nf`@060?nf`@0<o`00003o]/40
okK1o`00003o]/7o00000?nf`@000000okK10000003o]/4000000P3o]/4010000000okK1o`00003o
]/430?ooo`03o`00003oool0oooo00d0oooo1?l000030?ooo`80okK100?o00000?nf`@3o]/400P3o
]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000<0okK100?o00000?nf`@3o
]/401P3o]/402Ol00000okK10?nf`@3o]/4000000?nf`@000000okK1000000020?nf`@030000003o
]/40000000<0okK100<00000ooooooooool00_ooool00`00003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo3@3o]/400ol00?l0okK10?nf`@07
0?nf`@Go00002@3o]/400ol00?l0okK10?nf`@070?nf`A`0oooo4P3o]/400ol00?l0okK10?nf`@0:
0?nf`@03o`00o`3o]/40okK100`0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Sooooo00D00000ooooooooool0okK1000000030?nf`@0;0000003o]/4000000?nf`@000000
okK10000003o]/4000000?nf`Ol000000P3o]/400ol00000okK1o`0000080?nf`@0<o`00003o]/40
okK1o`00003o]/7o00000?nf`@000000okK10000003o]/4000000P3o]/4010000000okK10?nf`Ol0
00030?ooo`03o`00003oool0oooo0180oooo0_l000020?ooo`80okK100?o00000?nf`@3o]/400P3o
]/401?l00000okK10?nf`@0000020?nf`@030000003o]/4000000080okK100?o00000?nf`@3o]/40
203o]/401?l00000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/401000
0000okK10?nf`@000004ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool06oooool=0?nf`@03o`00o`3o]/40okK100L0okK11Ol000090?nf
`@03o`00o`3o]/40okK100H0okK17P3ooolA0?nf`@03o`00o`3o]/40okK100/0okK100?o003o0?nf
`@3o]/402`3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool01_l0
003oooooooooooooool0okK1000000<0okK100d000000?nf`Ol00000okK10000003o]/4000000?nf
`@000000okK1o`00003o]/7o00000080okK100?o00000?nf`@3o]/401P3o]/403_l00000okK10?nf
`Ol00000okK1o`00003o]/4000000?nf`@000000okK10000003o]/7o00000P3o]/401Ol00000oooo
0?ooo`3ooooo000001L0oooo00?o00000?ooo`3oool00P3o]/42o`000080okK100@000000?nf`@3o
]/4000000P3o]/400`000000okK1000000020?nf`@03o`00003o]/40okK100T0okK100?o00000?nf
`@0000000P3o]/401Ol00000okK10000003o]/4000000080okK100Co00000?nf`@3o]/4000001?oo
ool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01_ooooo303o]/400ol00?l0okK10?nf`@090?nf`@?o00002P3o]/400ol00?l0okK10?nf`@05
0?nf`B00oooo3`3o]/400ol00?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK100X0okK17_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00H00000oooooooooooooooo0?nf
`@0000030?nf`@0=0000003o]/4000000?nf`@000000okK10000003o]/4000000?nf`Ol00000okK1
o`0000020?nf`@03o`00003o]/40okK100H0okK100ko00000?nf`@3o]/7o00000?nf`Ol00000okK1
0000003o]/4000000?nf`@000000okK100000080okK100Go00000?ooo`3oool0ooooo`00000H0?oo
o`03o`00003oool0oooo0080okK100Co00000?nf`@3o]/4000000P3o]/401P000000okK10?nf`@00
0000okK100000080okK100?o00000?nf`@3o]/400P3o]/43o`0000@0okK100?o00000?nf`@000000
0P3o]/401@000000okK10000003o]/4000000080okK100@000000?nf`@3o]/4000001?ooool00`00
003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_o
oooo303o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK100D0okK1803oool?0?nf`@03
o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/402P3o]/4Nooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05oooool01P00003oooooooooooooool0okK1000000<0okK100d00000
0?nf`@000000okK10000003o]/4000000?nf`@000000okK1o`00003o]/7o00000080okK100?o0000
0?nf`@3o]/401P3o]/402Ol00000okK10?nf`Ol00000okK1o`00003o]/4000000?nf`@0200000080
okK100@000000?nf`@3o]/7o00000P3oool00ol00000oooo0?ooo`050?ooo`[o00002@3oool01Ol0
0000oooo0?nf`@3o]/7o00000080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10000
003o]/7o000000@0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@0:o`00003o]/40okK10000
003o]/4000000?nf`@000000okK100000080okK100@000000?nf`@3o]/4000001?ooool00`00003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo
303o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK100@0okK18`3oool=0?nf`@03o`00
o`3o]/40okK100l0okK100?o003o0?nf`@3o]/402@3o]/4Nooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05oooool01P00003oooooooooooooool0okK100000080okK100<000000?nf
`@0000000P3o]/402@000000okK10000003o]/4000000?nf`Ol00000okK1o`0000020?nf`@03o`00
003o]/40okK100H0okK100Go00000?nf`Ol00000okK1o`0000020?nf`@80000000L0okK10000003o
]/4000000?nf`@3ooooo000000<0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`08
0?ooo`;o00001`3oool00ol00000oooo0?ooo`020?nf`@06o`00003o]/40okK10000003o]/7o0000
0P3o]/401@000000okK10000003o]/7o000000<0okK100?o00000?nf`@3o]/400`3o]/401ol00000
okK10?nf`@3o]/7o00000?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK100@0
00000?nf`@3o]/4000000oooool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01_ooooo303o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o
]/40okK100<0okK19@3oool;0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/402P3o
]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool01P00003ooooooooo
ooooool0okK100000080okK100<000000?nf`@0000000P3o]/402@000000okK10000003o]/400000
0?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/40okK100D0okK100ko00000?nf`@3o]/7o0000
0?nf`Ol00000okK10000003o]/4000000?nf`Ol00000okK100000080oooo00Co00000?ooo`3ooooo
00001@3oool2o`0000d0oooo00?o00000?ooo`3oool01@3oool01Ol00000oooo0?ooo`3o]/7o0000
0080okK100<000000?nf`Ol000000P3o]/401@000000okK10000003o]/7o00000080okK100?o0000
0?nf`@3o]/401@3o]/401?l00000okK10?nf`Ol000020?nf`@070000003o]/4000000?nf`@000000
okK1000000020?nf`@040000003o]/40okK1000000?ooooo00<00000ooooooooool05oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`d0okK100?o003o0?nf`@3o
]/40503o]/400ol00?l0okK10?nf`@040?nf`BD0oooo2P3o]/400ol00?l0okK10?nf`@0B0?nf`@03
o`00o`3o]/40okK100T0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oo
oooo00<00000ooooooooool00P3o]/401P000000okK10?nf`@000000okK100000080okK100T00000
0?nf`@000000okK10000003o]/7o00000?nf`Ol000000P3o]/400ol00000okK10?nf`@040?nf`@0?
o`00003o]/40okK10?nf`Ol00000okK1o`00003o]/4000000?nf`@000000okK10000003o]/400000
0080oooo00Co00000?ooo`3ooooo00001@3oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0
oooo00@0oooo00Go00000?ooo`3oool0okK1o`0000020?nf`@030000003o]/4000000080okK100D0
00000?nf`@000000okK1o`0000020?nf`@03o`00003o]/40okK100D0okK100go00000?nf`@3o]/40
okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000080okK100@000000?nf`@3o]/40
00000oooool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01[ooooo3@3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100<0okK1
9`3oool90?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/402@3o]/4Mooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05_ooool01P00003oooooooooooooool0okK10000
0080okK100`000000?nf`@3o]/4000000?nf`@000000okK10000003o]/4000000?nf`Ol000020?nf
`@05o`00003o]/40okK10?nf`Ol00000103o]/403ol00000okK10?nf`@3o]/7o00000?nf`Ol00000
okK10000003o]/4000000?nf`@000000okK1000000020?ooo`04o`00003oool0ooooo`0000D0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`040?ooo`04o`00003oool0ooooo`000080
okK100T000000?nf`@000000okK10000003o]/4000000?nf`Ol000000P3o]/400ol00000okK10?nf
`@070?nf`@0<o`00003o]/40okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000P3o
]/4010000000okK10?nf`@000004ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool06_ooool=0?nf`@03o`00o`3o]/40okK101<0okK100?o
003o0?nf`@3o]/40103o]/4W0?ooo`T0okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf
`@090?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`0600000?oo
ooooooooooooo`3o]/7o00000P3o]/4030000000okK10?nf`@000000okK10000003o]/4000000?nf
`@000000okK1o`000080okK100Ko00000?nf`@3o]/40okK1o`00003o]/43o`0000<0okK100co0000
0?nf`@3o]/7o00000?nf`@000000okK10000003o]/4000000?nf`@0000020?ooo`04o`00003oool0
ooooo`0000@0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`030?ooo`04o`00003o
ool0ooooo`000080okK100/000000?nf`@000000okK10000003o]/4000000?nf`Ol00000okK1o`00
00040?nf`@Co00000`3o]/402ol00000okK1o`00003o]/4000000?nf`@000000okK10000003o]/40
00000080okK100@000000?nf`@3o]/4000001?ooool00`00003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo3@3o]/400ol00?l0okK10?nf`@0C
0?nf`@03o`00o`3o]/40okK100<0okK1:@3oool70?nf`@03o`00o`3o]/40okK101@0okK100?o003o
0?nf`@3o]/40203o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool0
1P00003oooooooooooooool0okK100000080okK100`000000?nf`@3o]/4000000?nf`@000000okK1
0000003o]/4000000?nf`Ol000020?nf`@04o`00003o]/40okK10?nf`@;o00001P3o]/403?l00000
okK10?nf`Ol00000okK10000003o]/7o00000?nf`@000000okK100000080oooo00Co00000?ooo`3o
oooo0000103oool00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo00<0oooo00Co00000?oo
o`3ooooo00000P3o]/402`000000okK10000003o]/4000000?nf`@000000okK1o`00003o]/7o0000
00@0okK100Co00000?nf`@3o]/7o00000`3o]/402ol00000okK1o`00003o]/4000000?nf`@000000
okK10000003o]/4000000080okK100@000000?nf`@3o]/4000001?ooool00`00003oooooooooo`0F
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo3@3o]/400ol0
0?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100<0okK1:@3oool70?nf`@03o`00o`3o]/40okK1
01@0okK100?o003o0?nf`@3o]/40203o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool01P00003oooooooooooooool0okK100000080okK100`000000?nf`@3o]/400000
0?nf`@000000okK10000003o]/4000000?nf`Ol000020?nf`@03o`00003o]/40okK100T0okK100Go
00000?nf`Ol00000okK1000000020?nf`@040000003o]/400000000000<0oooo00Co00000?ooo`3o
oooo0000103oool00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo00<0oooo00Co00000?oo
o`3ooooo00000P3o]/402`000000okK10000003o]/4000000?nf`@000000okK1o`00003o]/7o0000
00<0okK100?o00000?nf`@3o]/400P3o]/402_l00000okK10?nf`Ol00000okK1o`00003o]/400000
0?nf`@0000020?nf`@8000000P3o]/4010000000okK10?nf`@000004ooooo`0300000?oooooooooo
01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool=0?nf`@03
o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/40103o]/4Y0?ooo`L0okK100?o003o0?nf`@3o
]/40503o]/400ol00?l0okK10?nf`@080?nf`Agooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Eooooo`0300000?oooooooooo00;ooooo00L000000?nf`@3o]/40okK10000003o]/40
00000080okK100D000000?nf`@000000okK1000000020?nf`@04o`00003o]/40okK1o`0000T0okK1
00co00000?nf`@3o]/7o00000?nf`@000000okK10000003o]/4000000?nf`@0000020?ooo`04o`00
003oool0ooooo`0000@0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?ooo`020?ooo`04
o`00003oool0ooooo`000080okK100/000000?nf`@000000okK10000003o]/4000000?nf`Ol00000
okK1o`0000030?nf`@03o`00003o]/40okK10080okK1017o00000?nf`@3o]/40okK1o`00003o]/7o
00000?nf`@000000okK10000003o]/4000000?nf`@000000okK1000000020?nf`@0300000?oooooo
oooo00;ooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Jooooo`d0okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@040?nf
`BT0oooo1`3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100P0okK17Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00<00000ooooooooool00_ooool01`00
0000okK10?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK1
00Co00000?nf`@3o]/7o0000203o]/402?l00000okK10?nf`Ol00000okK10000003o]/4000000P3o
]/400`000000okK1o`0000020?ooo`04o`00003oool0ooooo`0000@0oooo00?o00000?ooo`3oool0
4`3oool00ol00000oooo0?ooo`020?ooo`04o`00003oool0ooooo`000080okK100/000000?nf`@00
0000okK10000003o]/4000000?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/40okK100@0okK1
013o00000?nf`@3o]/7o00000?nf`Ol00000okK1o`00003o]/4000000?nf`@000000okK10000003o
]/4000000P3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo01Kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool>0?nf`@03o`00o`3o]/40okK10100
okK100?o003o0?nf`@3o]/40103o]/4[0?ooo`H0okK100?o003o0?nf`@3o]/40503o]/400ol00?l0
okK10?nf`@080?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03
00000?oooooooooo00;ooooo00L000000?nf`@3o]/40okK10000003o]/4000000080okK100D00000
0?nf`@000000okK1000000020?nf`@04o`00003o]/40okK1o`0000L0okK100Wo00000?nf`@3o]/40
okK1o`00003o]/4000000?nf`@0000000P3o]/400`000000okK1000000020?ooo`04o`00003oool0
ooooo`0000@0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?ooo`020?ooo`0Ao`00003o
ool0ooooo`00003oool0okK10000003o]/4000000?nf`@000000okK10000003o]/7o00000?nf`Ol0
00000P3o]/400ol00000okK10?nf`@040?nf`@0@o`00003o]/40okK1o`00003o]/7o00000?nf`@00
0000okK10000003o]/4000000?nf`@000000okK100000080okK100<00000ooooooooool00_ooool0
0`00003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01[ooooo3P3o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100D0okK1:`3oool60?nf
`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/40203o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05Oooool00`00003oooooooooo`02ooooo`070000003o]/40okK1
0?nf`@000000okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/401Ol00000okK1
0?nf`@3o]/7o000000@0okK10_l000030?nf`@08o`00003o]/40okK10000003o]/4000000?nf`@00
00020?nf`@040000003oool0ooooo`000080oooo00?o00000?ooo`3oool00P3oool00ol00000oooo
0?ooo`0C0?ooo`03o`00003oool0oooo0080oooo017o00000?ooo`3ooooo00000?ooo`3o]/400000
0?nf`@000000okK10000003o]/4000000?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/40okK1
00@0okK1013o00000?nf`@3o]/7o00000?nf`Ol00000okK10000003o]/4000000?nf`@000000okK1
0000003o]/4000000P3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06Oooool?0?nf`@03o`00o`3o]/40
okK100h0okK100?o003o0?nf`@3o]/401P3o]/4[0?ooo`H0okK100?o003o0?nf`@3o]/401`3o]/43
o`0000X0okK100?o003o0?nf`@3o]/40203o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05Oooool01P00003oooooooooooooool0okK1000000<0okK100<000000?nf`@000000
0P3o]/400`000000okK1000000020?nf`@030000003o]/7o000000@0okK100Co00000?nf`Ol0003o
00001@3o]/401Ol00000okK10000003o]/4000000080okK100<000000?nf`@0000000P3oool01?l0
0000oooo0?ooool000050?ooo`03o`00003oool0oooo01@0oooo00Go00000?ooo`3oool0ooooo`00
00020?ooo`0=o`00003oool0okK10000003o]/4000000?nf`@000000okK100000?l00000okK1o`00
00020?nf`@03o`00003o]/40okK100H0okK100oo00000?nf`Ol00000okK1o`00003o]/4000000?nf
`@000000okK10000003o]/4000000?nf`@0000000P3o]/400`00003oooooooooo`02ooooo`030000
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06Ooo
ool@0?nf`@;o003o3@3o]/400ol00?l0okK10?nf`@070?nf`B/0oooo1P3o]/400ol00?l0okK10?nf
`@060?nf`@Go00002@3o]/400ol00?l0okK10?nf`@080?nf`Agooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Eooooo`0600000?ooooooooooooooo`3o]/4000000`3o]/400`000000
okK1000000020?nf`@030000003o]/4000000080okK100<000000?nf`Ol000001@3o]/400ol00000
okK10?nf`@040?nf`@08o`00003o]/40okK10000003o]/4000000?nf`@0000020?nf`@040000003o
ool0ooooo`000080oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0D0?ooo`05o`00
003oool0oooo0?ooool000000P3oool03Ol00000oooo0?nf`@000000okK10000003o]/4000000?nf
`@00003o00000?nf`Ol000000P3o]/400ol00000okK10?nf`@060?nf`@0?o`00003o]/7o00000?nf
`Ol00000okK10000003o]/4000000?nf`@000000okK10000003o]/4000000080okK100<00000oooo
ooooool00_ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01Wooooo4P3o]/400ol00?l0okK10?nf`@080?nf`@;o003o2P3o]/4[0?ooo`H0
okK100?o003o0?nf`@3o]/401P3o]/45o`0000T0okK100?o003o0?nf`@3o]/40203o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool01P00003oooooooooooooool0okK1
000000<0okK100<000000?nf`@0000000P3o]/400`000000okK1000000020?nf`@030000003o]/7o
000000`0okK100So00000?nf`@3o]/4000000?nf`@000000okK100000080okK100@000000?ooo`3o
oooo00000P3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo01@0oooo00Go00000?oo
o`3oool0ooooo`0000020?ooo`0=o`00003oool0okK10000003o]/4000000?nf`@000000okK10000
0?l00000okK1o`0000020?nf`@03o`00003o]/40okK100H0okK100oo00000?nf`Ol00000okK1o`00
003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o]/400`00003ooooooooo
o`02ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool06OoooolC0?nf`@03o`00o`3o]/40okK100D0okK10_l00?l<0?nf`B/0oooo1P3o]/40
0ol00?l0okK10?nf`@060?nf`@Go00002@3o]/400ol00?l0okK10?nf`@080?nf`Agooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Dooooo`0300000?oooooooooo00;ooooo00D0okK1
0000003o]/40okK1000000020?nf`@060000003o]/40okK10000003o]/4000000P3o]/4010000000
okK10?nf`Ol0000:0?nf`@06o`00003o]/40okK10000003o]/4000000P3o]/401P000000okK10000
003o]/40ooooo`0000<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0C0?ooo`03
o`00003oool0oooo0080oooo00[o00000?ooo`3ooooo00000?ooo`3o]/4000000?nf`@000000okK1
0P0000001P3o]/7o00000?nf`Ol00000okK1o`0000T0okK100oo00000?nf`Ol00000okK1o`00003o
]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o]/400`00003oooooooooo`02
ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool06_oooolC0?nf`@03o`00o`3o]/40okK100<0okK100?o003o0?nf`@3o]/40303o]/4[0?oo
o`H0okK100?o003o0?nf`@3o]/401`3o]/43o`0000X0okK100?o003o0?nf`@3o]/40203o]/4Moooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00`00003oooooooooo`03oooo
o`040000003o]/40okK100000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@050000
003o]/40okK10?nf`Ol00000203o]/401?l00000okK10?nf`@0000020?nf`@09o`00003o]/40okK1
0000003o]/4000000?nf`@3ooooo000000<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo
0?ooo`0C0?ooo`03o`00003oool0oooo0080oooo00[o00000?ooo`3ooooo00000?ooo`3o]/400000
0?nf`@000000okK10P0000001P3o]/7o00000?nf`Ol00000okK1o`0000T0okK100oo00000?nf`Ol0
0000okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o]/400`00
003oooooooooo`02ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06_oooolD0?nf`@Go003o3`3o]/4[0?ooo`H0okK100?o003o0?nf`@3o
]/40503o]/400ol00?l0okK10?nf`@080?nf`Agooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Dooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/401P00
0000okK10?nf`@000000okK100000080okK100D000000?nf`@3o]/40okK1o`0000070?nf`@05o`00
003o]/40okK10?nf`@0000000P3o]/402@000000okK10?nf`@000000okK10000003o]/40ooooo`00
00030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?oo
o`020?ooo`0:o`00003oool0ooooo`00003oool0okK10000003o]/4000000?nf`@80000000H0okK1
o`00003o]/7o00000?nf`Ol000090?nf`@0?o`00003o]/7o00000?nf`Ol00000okK10000003o]/40
00000?nf`@000000okK10000003o]/4000000080okK100<00000ooooooooool00_ooool00`00003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo
:@3o]/4Y0?ooo`L0okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@080?nf`Agooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`0300000?oooooooooo00?ooooo
00@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/400000
00@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@040000003o]/40okK1
00000080okK100<000000?nf`@0000000P3o]/401Ol00000oooo0?ooo`3ooooo000000D0oooo00?o
00000?ooo`3oool04`3oool00ol00000oooo0?ooo`020?ooo`04o`00003oool0ooooo`000080okK1
00@000000?nf`@000000okK10P0000001P3o]/7o00000?nf`Ol00000okK1o`0000T0okK100oo0000
0?nf`Ol00000okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o
]/400`00003oooooooooo`02ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool06_oooolY0?nf`BT0oooo1`3o]/400ol00?l0okK10?nf`@0D
0?nf`@03o`00o`3o]/40okK100P0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Cooooo00<00000ooooooooool00oooool01@000000okK10?nf`@3o]/4000000080okK100<0
00000?nf`@0000000P3o]/4010000000okK10?nf`@0000040?nf`@05o`00003o]/40okK10?nf`Ol0
00001@3o]/400`000000okK1000000020?nf`@040000003o]/40okK100000080okK100?o00000?oo
o`3oool00P3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo0180oooo00?o00000?oo
o`3oool00P3oool01?l00000oooo0?ooool000020?nf`@0:0000003o]/4000000?nf`@000000okK1
00000?l00000okK1o`000080okK100?o00000?nf`@3o]/401@3o]/404?l00000okK10?nf`Ol00000
okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000020?nf`@0300000?oo
oooooooo00;ooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0JooooobT0okK1:@3oool70?nf`@03o`00o`3o]/40okK101<0okK100?o003o
0?nf`@3o]/402@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool0
0`00003oooooooooo`03ooooo`050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10000
00020?nf`@04o`00003o]/40okK1000000D0okK10ol000050?nf`@040000003o]/40okK100000080
okK100@000000?nf`@3o]/4000000P3o]/400ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo
00<0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`020?ooo`04o`00003oool0oooo
o`000080okK100X000000?nf`@000000okK10000003o]/400000o`00003o]/7o00000P3o]/400ol0
0000okK10?nf`@050?nf`@0@o`00003o]/40okK1o`00003o]/7o00000?nf`@000000okK10000003o
]/4000000?nf`@000000okK100000080okK100<00000ooooooooool00_ooool00`00003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo:@3o]/4Y
0?ooo`L0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@090?nf`Agooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Dooooo`0300000?oooooooooo00?ooooo00D00000
0?nf`@3o]/40okK1000000020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/400000
3@3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100?o00000?oo
o`3oool00P3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo0180oooo00?o00000?oo
o`3oool00P3oool01?l00000oooo0?ooool000020?nf`@0:0000003o]/4000000?nf`@000000okK1
00000?l00000okK1o`0000<0okK100?o00000?nf`@3o]/40103o]/404?l00000okK10?nf`Ol00000
okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000020?nf`@0300000?oo
oooooooo00;ooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0JooooobX0okK19`3oool90?nf`@03o`00o`3o]/40okK10180okK100?o003o
0?nf`@3o]/402@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool0
0`00003oooooooooo`03ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf
`@0000020?nf`@040000003o]/40okK1000000`0okK100D000000?nf`@3o]/40okK1000000020?nf
`@040000003o]/40okK100000080okK100?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool00`3oool01_l00000oooo0?ooool0
0000okK100000080okK100T000000?nf`@000000okK10000003o]/7o00000?nf`Ol000000P3o]/40
0ol00000okK10?nf`@030?nf`@0>o`00003o]/40okK1o`00003o]/7o00000?nf`@000000okK10000
003o]/4000000?nf`@0000020?nf`@040000003o]/40okK1000000Cooooo00<00000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobX0okK19`3o
ool90?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/402@3o]/4Mooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05?ooool00`00003oooooooooo`03ooooo`050000003o
]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK10000
00`0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100<0
ooooo`00003oool00P3oool2o`0000D0oooo0ol0000?0?ooo`03o`00003oool0oooo00<0oooo00Ko
00000?ooo`3ooooo00000?nf`@0000020?nf`@090000003o]/4000000?nf`@000000okK1o`00003o
]/7o000000<0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@0;o`00003o]/7o00000?nf`@00
0000okK10000003o]/4000000?nf`@0000000P3o]/4010000000okK10?nf`Ol00004ooooo`030000
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_oo
ool[0?nf`BD0oooo2P3o]/400ol00?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK100T0okK17Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool00ooo
ool01@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/4010000000
okK10?nf`@00000<0?nf`@050000003o]/40okK10?nf`Ol000000P3o]/4010000000okK10?nf`@00
00030?nf`@030?ooool00000oooo0080oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?oo
o`0;0?ooo`03o`00003oool0oooo00@0oooo00Ko00000?ooo`3o]/7o00000?nf`@0000020?nf`@09
0000003o]/4000000?nf`@000000okK1o`00003o]/7o000000@0okK100?o00000?nf`Ol00000103o
]/402ol00000okK1o`00003o]/4000000?nf`@000000okK10000003o]/4000000080okK100@00000
0?nf`@3o]/4000001?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01_ooooo;03o]/4S0?ooo`/0okK100?o003o0?nf`@3o]/40403o]/40
0ol00?l0okK10?nf`@0:0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0D
ooooo`0300000?oooooooooo00?ooooo00D000000?nf`@3o]/40okK1000000020?nf`@040000003o
]/40okK100000080okK100D000000?nf`@3o]/40okK10000000<0?nf`@040000003o]/40okK10000
00<0okK100@000000?nf`@3o]/4000000`3o]/400ol00000oooo0?ooo`020?ooo`03o`00003oool0
oooo00H0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`040?ooo`07o`00003oool0
oooo0?nf`Ol00000okK1000000020?nf`@090000003o]/4000000?nf`@000000okK1o`00003o]/7o
000000D0okK100?o00000?nf`@3o]/400`3o]/402ol00000okK1o`00003o]/4000000?nf`@000000
okK10000003o]/4000000080okK100@000000?nf`@3o]/4000001?ooool00`00003oooooooooo`0F
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo;03o]/4R0?oo
o``0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@090?nf`Akooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Eooooo`0300000?oooooooooo00?ooooo00D000000?nf
`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/400000
303o]/401Ol00000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1000000030?nf
`@03o`00003oool0oooo0080oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`070?oo
o`03o`00003oool0oooo00D0oooo00Co00000?ooo`3o]/7o00000P3o]/400`000000okK100000002
0?nf`@050000003o]/4000000?nf`Ol000000P3o]/400ol00000okK10?nf`@070?nf`@05o`00003o
]/40okK1o`00000000000P3o]/401`000000okK10000003o]/4000000?nf`@0000000P3o]/400`00
003oooooooooo`02ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06oooool]0?nf`B00oooo3@3o]/400ol00?l0okK10?nf`@0@0?nf`@03
o`00o`3o]/40okK100T0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00<00000ooooooooool00oooool01@000000okK10?nf`@3o]/4000000080okK100@000000?nf
`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000/0okK100D000000?nf`@3o]/40okK1
000000030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400ol00000oooo0?ooo`020?ooo`03
o`00003oool0oooo00H0oooo1?l000030?ooo`;o00001`3oool01Ol00000oooo0?nf`@3o]/7o0000
0080okK100?o00000?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080okK100?o0000
0?nf`@3o]/401`3o]/401Ol00000okK1o`00003o]/4000000080okK100L000000?nf`@000000okK1
0000003o]/7o00000080okK100<00000ooooooooool00_ooool00`00003oooooooooo`0Gooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo;P3o]/4N0?ooo`h0okK1
00?o003o0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@0:0?nf`Akooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Eooooo`0300000?oooooooooo00?ooooo00D000000?nf`@3o]/40
okK1o`0000020?nf`@04o`00003o]/40okK100000080okK100<000000?nf`@3o]/400P3o]/400ol0
0000okK10?nf`@090?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o
]/40000000<0okK100?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`090?ooo`?o0000203o
ool2o`0000<0okK100Ko00000?nf`@3o]/4000000?nf`@0000020?nf`@050000003o]/4000000?nf
`Ol000000P3o]/400ol00000okK10?nf`@060?nf`@06o`00003o]/40okK1o`00003o]/4000000P3o
]/401`000000okK10000003o]/4000000?nf`@0000000P3o]/400`00003oooooooooo`02ooooo`03
00000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6ooooolJ0?nf`@Wo003o303o]/4L0?oooa00okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK1
0?nf`@0;0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`030000
0?oooooooooo00?ooooo00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf
`@0000000P3o]/401@000000okK10?nf`@3o]/40000000`0okK100D000000?nf`@3o]/40okK10000
00030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400ol00000oooo0?ooo`020?ooo`03o`00
003oool0oooo0180oooo00?o00000?ooo`3o]/400P3o]/402Ol00000okK10?nf`@3o]/4000000?nf
`@000000okK1000000020?nf`@030000003o]/7o000000<0okK100?o00000?nf`@3o]/40103o]/40
1_l00000okK10?nf`Ol00000okK100000080okK100Go00000?nf`@000000okK1000000020?nf`@04
0000003o]/40okK1000000Cooooo00<00000ooooooooool05oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0LoooooaH0okK10ol00?l90?nf`@;o003o2`3o]/4I0?oooa80
okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0;0?nf`Akooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Eooooo`0300000?oooooooooo00?ooooo00<000000?nf`@3o
]/400P3o]/4010000000okK10?nf`@0000020?nf`@05o`00003o]/40okK100000?l000000P3o]/40
0`000000okK10?nf`@0;0?nf`@05o`00003o]/40okK10?nf`@0000000`3o]/401Ol0000000000?nf
`@3o]/7o000000<0okK100?o00000?ooo`3oool00P3oool3o`000100oooo00?o00000?nf`@3o]/40
0P3o]/401Ol00000okK10?nf`@3o]/4000000080okK100<000000?nf`@0000000P3o]/400`000000
okK1o`0000030?nf`@03o`00003o]/40okK100<0okK100Oo00000?nf`@3o]/40okK1o`00003o]/40
00000080okK100D000000?nf`@000000okK1000000020?nf`@040000003o]/40okK1000000Cooooo
00<00000ooooooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0LoooooaD0okK100?o003o0?nf`@3o]/40303o]/43o`00o`X0okK15@3ooolE0?nf`@03o`00o`3o
]/40okK100X0okK10_l00?l=0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Eooooo`0300000?oooooooooo00?ooooo00<000000?nf`@3o]/400P3o]/4010000000okK10?nf
`@0000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@0;0?nf`@80
00000`3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK1000000<0okK100?o00000?oo
o`3oool0103oool00ol00000oooo0?ooo`0;0?ooo`;o00001@3o]/401Ol00000okK10?nf`@3o]/40
00000080okK100<000000?nf`@0000000P3o]/400`000000okK1o`0000040?nf`@?o000000<0okK1
o`00003o]/400`3o]/400ol00000okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o
]/4010000000okK10?nf`@000004ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool07?oooolE0?nf`@03o`00o`3o]/40okK100l0okK10_l0
0?l:0?nf`A40oooo603o]/42o`00o`T0okK100?o003o0?nf`@3o]/403@3o]/4Oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05Oooool00`00003oooooooooo`04ooooo`050000003o
]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o
]/40okK10000000>0?nf`@8000000P3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK1
000000<0okK10_l000050?ooo`?o00002@3oool00ol00000okK10?nf`@040?nf`@05o`00003o]/40
okK10?nf`@0000000P3o]/400`000000okK1000000030?nf`@030000003o]/7o000000L0okK100?o
00000?nf`@3o]/400P3o]/401?l00000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@00
00000P3o]/4010000000okK10?nf`@000004ooooo`0300000?oooooooooo01Oooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool07OoooolC0?nf`@03o`00o`3o]/40okK10180
okK100?o003o0?nf`@3o]/402@3o]/4=0?oooa`0okK10_l00?l60?nf`@03o`00o`3o]/40okK100h0
okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00<00000oooooooo
ool00oooool00`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100D000000?nf
`@3o]/40okK1000000020?nf`@030000003o]/40okK100h0okK100Co00000?nf`@3o]/4000000`3o
]/401@000000okK10?nf`@3o]/40000000@0okK100?o00000?nf`@3oool01@3oool3o`0000<0oooo
0ol000060?nf`@05o`00003o]/40okK10?nf`@0000000`3o]/400`000000okK1o`0000020?nf`@04
0000003o]/40okK1o`0000`0okK100So00000?nf`@3o]/7o00000?nf`@000000okK100000080okK1
00<000000?nf`@0000000P3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo01Sooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07OoooolC0?nf`@03o`00o`3o
]/40okK101<0okK100?o003o0?nf`@3o]/40303o]/450?ooob80okK100?o003o0?nf`@3o]/400ol0
0?l@0?nf`B3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`0300000?oo
oooooooo00Cooooo00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@00
00000P3o]/401@000000okK10?nf`@3o]/40000000l0okK10P0000020?nf`@05o`0000000000okK1
0?nf`@0000000`3o]/42000000<0okK10_l000030?nf`@D0oooo0ol000070?nf`@;o00000`3o]/40
0`000000okK10?nf`@0200000080okK100@000000?nf`@3o]/4000000P3o]/400ol00000okK10?nf
`@090?nf`@04o`00003o]/40okK100000080okK100D000000?nf`@000000okK1000000020?nf`@04
0000003o]/40okK1000000Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Moooooa<0okK100?o003o0?nf`@3o]/40503o]/400ol00?l0
okK10?nf`@0c0?nf`@;o003o4`3o]/4Pooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool05_ooool00`00003oooooooooo`04ooooo`050000003o]/40okK10?nf`@0000000P3o]/401@00
0000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK10000000A0?nf`@050000003o
]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@020?nf`@8000000`3o]/42o`0000d0okK1
0ol000040?nf`@040000003o]/40okK1000000<0okK100D000000?nf`@3o]/40okK1000000020?nf
`@03o`00003o]/40okK100T0okK100Co00000?nf`@3o]/4000000P3o]/401@000000okK10000003o
]/4000000080okK100@000000?nf`@3o]/4000001?ooool00`00003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo4@3o]/400ol00?l0okK10?nf
`@0F0?nf`@03o`00o`3o]/40okK104L0okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Oooooo00<00000ooooooooool01?ooool01@000000okK10?nf`@3o]/4000000080okK1
00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000001`3o]/46o`00
00@0okK10P0000020?nf`@80000000<0okK1000000000000103o]/400`000000okK10?nf`@020?nf
`@?o00002@3o]/400ol00000okK10?nf`@040?nf`@040000003o]/40okK1000000<0okK100D00000
0?nf`@3o]/40okK1000000020?nf`@03o`00003o]/40okK100T0okK100Co00000?nf`@3o]/400000
0P3o]/401@000000okK1o`00003o]/4000000080okK100D000000?nf`@3o]/40okK100000004oooo
o`0300000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool07_oooolA0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/40AP3o]/4Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00`00003oooooooooo`04ooooo`05
0000003o]/40okK10?nf`@0000000`3o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40
okK100000?l000001@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100<0okK100D0
00000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
103o]/49o`0000<0okK1100000020?nf`@050000003o]/40okK10?nf`Ol000000`3o]/401@000000
okK10?nf`@3o]/7o000000X0okK100Co00000?nf`@3o]/4000000P3o]/401P000000okK10?nf`@00
0000okK100000080okK100D000000?nf`@3o]/7ooooo00000004ooooo`0300000?oooooooooo01So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07oooool@0?nf`@03o`00
o`3o]/40okK101L0okK10_l00?m60?nf`B7ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo00D000000?nf`@3o]/40okK1000000030?nf`@04
0000003o]/40okK1000000<0okK100D000000?nf`@3o]/40okK1000000050?nf`@03o`00003o]/40
okK100D0okK10_l000040?nf`@040000003o]/40okK1000000<0okK100H000000?nf`@3o]/40okK1
o`000000000?0?nf`@8000001@3o]/4010000000okK10?nf`@3o]/42000000<0okK100D000000?nf
`@3o]/40okK1o`0000090?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/401P000000okK10?nf
`@000000okK100000080okK100D000000?nf`@3o]/7ooooo00000004ooooo`0300000?oooooooooo
01Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool?0?nf`@03
o`00o`3o]/40okK101T0okK100?o003o0?nf`@3o]/406P3o]/4>o`00oaX0okK18_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00<00000ooooooooool01?ooool01@000000
okK10?nf`@3o]/40000000<0okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@00
00050?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf
`@0200000080okK10P0000030?nf`@800000303o]/400`000000okK10?nf`@040?nf`@050000003o
]/40okK10?nf`@000000103o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK100H0okK1
00Go00000?nf`@3o]/40okK1000000030?nf`@030000003o]/4000000080okK100D000000?nf`@3o
]/4000000?nf`@02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool06?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo`l0okK100?o003o0?nf`@3o
]/406P3o]/400ol00?l0okK10?nf`@0D0?nf`@Go003o3P3o]/400ol00?l0okK10?nf`@0F0?nf`B?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`0300000?oooooooooo00?o
oooo00D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000000P3o]/40
1@000000okK10?nf`@3o]/40000000@0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@020?nf`@`00000
1@3o]/42000000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00
003o]/40okK100D0okK100?o00000?nf`@3o]/400P3o]/401?l00000okK10?nf`@0000020?nf`@03
0000003o]/4000000080okK100D000000?nf`Ooooooooooo00000004ooooo`0300000?oooooooooo
01Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool>0?nf`@03
o`00o`3o]/40okK101X0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0B0?nf`@03
o`00o`3o]/40okK101D0okK18oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo00<00000ooooooooool01?ooool01@000000okK10?nf`@3o]/40000000<0okK100D000000?nf
`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000@0okK100?o00000?nf`@3o]/402@3o
]/42o`0000<0okK100Go00000?nf`@3o]/40okK1000000030?nf`@8000003`3o]/4200000003o`00
00000000okK10080okK10P0000040?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o]/40
103o]/400ol00000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o
]/4000000P3o]/401Ol00000okK1oooooooooooo000000Cooooo00<00000ooooooooool06Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Qooooo`l0okK100?o003o0?nf
`@3o]/406P3o]/400ol00?l0okK10?nf`@0@0?nf`@;o003o5P3o]/400ol00?l0okK10?nf`@0C0?nf
`BCooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`0300000?oooooooooo
00Cooooo00<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@0000030?nf`@040000003o]/40
okK100000080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@0;0?nf`@04o`00003o
]/40okK10?nf`@8000000P3o]/400ol0000000000?nf`@020?nf`@8000002@3o]/44000000@0okK1
0`0000040?nf`@0300000?l00000okK100H0okK100?o00000?nf`@3o]/400P3o]/42o`0000@0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100@00000oooo
ooooool000001Oooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo027ooooo3`3o]/400ol00?l0okK10?nf`@0;0?nf`@?o0000303o]/400ol0
0?l0okK10?nf`@0>0?nf`@;o003o603o]/400ol00?l0okK10?nf`@0C0?nf`BCooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Jooooo`0300000?oooooooooo00Cooooo00<000000?nf
`@3o]/400P3o]/4010000000okK10?nf`@0000030?nf`@040000003o]/40okK100000080okK100<0
00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@0;0?nf`@03o`00003o]/40okK10080okK100D0
00000?nf`@3o]/40okK1000000040?nf`@T000001P3o]/42000000D0okK10P00000:0?nf`@04o`00
003o]/7o0000o`0000D0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1
o`000080okK100D000000?nf`Ooooooooooo00000004ooooo`0300000?oooooooooo01[ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08_ooool>0?nf`@03o`00o`3o]/40
okK100X0okK11Ol0000;0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/406@3o]/40
0ol00?l0okK10?nf`@0B0?nf`BCooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0K
ooooo`0300000?oooooooooo00Cooooo00<000000?nf`@3o]/400P3o]/401?l00000okK10?nf`Ol0
00030?nf`@04o`00003o]/400000o`000080okK100D000000?nf`@3o]/40okK1o`00000>0?nf`@03
o`00003o]/40okK10080okK100Oo00000?nf`@3o]/40okK100000?l00000000000d0okK10P000000
0ol00000okK10?nf`@030?nf`@8000003@3o]/400ol00000okK10?nf`@040?nf`@050000003o]/40
okK10?nf`Ol000000P3o]/401000003o00000?nf`@0000020?nf`@050000003o]/40okK1ooooo`00
00001Oooool00`00003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02?ooooo3P3o]/400ol00?l0okK10?nf`@090?nf`@Go0000303o]/400ol00?l0okK1
0?nf`@0;0?nf`@03o`00o`3o]/40okK101/0okK100?o003o0?nf`@3o]/40403o]/4Uooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`00
003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@0000020?nf
`@050000003o]/40okK10?nf`Ol000003P3o]/400ol00000okK10?nf`@030?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/401`3o]/43000000D0okK10`00000E0?nf`@030000003o]/40
okK10080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@000000okK100;ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02?ooooo3P3o]/400ol00?l0okK10?nf`@090?nf`@Go0000303o
]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK101/0okK100?o003o0?nf`@3o]/403`3o
]/4Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00`00003ooooooooo
o`05ooooo`030000003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/4010000000okK1
0?nf`@0000020?nf`@050000003o]/40okK10?nf`Ol000003P3o]/400ol00000okK10?nf`@030?nf
`@030000003o]/40okK100<0okK12@0000070?nf`@030000003o]/40okK101D0okK100<000000?nf
`@3o]/400P3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000000ooo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool09?ooool=0?nf`@03o`00o`3o]/40okK100X0okK10ol0000>
0?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/40703o]/400ol00?l0okK10?nf`@0?
0?nf`BKooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`0300000?oooooo
oooo00Gooooo00D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1000000<0okK1
00@000000?nf`@3o]/4000000`3o]/400ol00000okK10?nf`@0<0?nf`@03o`00003o]/40okK100<0
okK100<000000?nf`@3o]/404@3o]/400`000000okK10?nf`@0E0?nf`@03o`00003o]/40okK10080
okK100D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10000003o]/400_ooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool09?ooool>0?nf`@03o`00o`3o]/40okK101X0okK100?o003o0?nf
`@3o]/40203o]/400ol00?l0okK10?nf`@0L0?nf`@03o`00o`3o]/40okK100l0okK19oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00<00000ooooooooool01?ooool00`3o
]/4000000?nf`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o
]/4000000080okK100@000000?nf`@3o]/40okK10_l0000=0?nf`@03o`00003o]/40okK100<0okK1
0P00000>0?nf`@0300000?l00000000001H0okK10P0000030?nf`@0300000?l00000okK10080okK1
00Co00000?nf`@3o]/7o00000`3o]/401Ol0003oooooooooooooool0000000Gooooo00<00000oooo
ooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Uooooo`d0
okK100?o003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@070?nf`@03o`00o`3o]/40okK100/0
okK10ol0000?0?nf`@03o`00o`3o]/40okK100l0okK19oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01kooooo00<00000ooooooooool01?ooool01@000000okK10?nf`@3o]/400000
00<0okK100@000000?nf`@3o]/4000000`3o]/401Ol00000okK10?nf`@3o]/7o000000@0okK100?o
00000?nf`@3o]/402P3o]/400ol00000okK10?nf`@050?nf`@8000002@3o]/43000001P0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@000000
0P3o]/400`000000okK1ooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
6oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Vooooo`d0okK100?o
003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK100/0okK11Ol0
000>0?nf`@03o`00o`3o]/40okK100h0okK1:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01oooooo00<00000ooooooooool01?ooool01@000000okK10?nf`@3o]/40000000<0okK1
00@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@0000050?nf`@03o`00003o]/40okK1
00X0okK100?o00000?nf`@3o]/401P3o]/4300000080okK11000000I0?nf`@800000103o]/400`00
0000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@00003ooooooooooooo
ool0000000Gooooo00<00000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Wooooo`d0okK100?o003o0?nf`@3o]/406@3o]/400ol00?l0okK10?nf`@04
0?nf`@03o`00o`3o]/40okK100`0okK11Ol0000>0?nf`@03o`00o`3o]/40okK100d0okK1:Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00<00000ooooooooool01?ooool0
0`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf
`@3o]/4000000080okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@090?nf`@03o`00
003o]/40okK100T0okK10P00000L0?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/40
0P3o]/401@000000okK10?nf`@3o]/40000000<0okK100<00000ooooooooool00_ooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0:?ooool=0?nf`@03o`00o`3o]/40okK101P0okK100?o003o0?nf`@3o]/40
103o]/400ol00?l0okK10?nf`@0<0?nf`@Go00003@3o]/400ol00?l0okK10?nf`@0=0?nf`B[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`0300000?oooooooooo00Cooooo
00<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/4000000080okK100D00000o`00003o
]/40okK1000000020?nf`@0300000?l0000000000080okK10ol000090?nf`@;o00009@3o]/430000
00@0okK10P0000020?nf`@80000000Go00000?nf`@3o]/400000o`0000030?nf`@03o`000?oooooo
oooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02Sooooo3P3o]/400ol00?l0okK10?nf`@0G0?nf
`@03o`00o`3o]/40okK100@0okK100?o003o0?nf`@3o]/403@3o]/43o`0000d0okK100?o003o0?nf
`@3o]/403@3o]/4[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00`00
003oooooooooo`04ooooo`030000003o]/40okK10080okK100Go00000?nf`@3o]/40okK100000003
0?nf`@040000003o]/40okK1o`0000@0okK100<000000?nf`@3o]/400P3o]/43o`0000D0okK100?o
00000?nf`@3o]/408P3o]/43000000@0okK10`0000030?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400P3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Y
ooooo`h0okK10_l00?lG0?nf`@03o`00o`3o]/40okK100@0okK100?o003o0?nf`@3o]/40703o]/40
0ol00?l0okK10?nf`@0>0?nf`B_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0R
ooooo`0300000?oooooooooo00Cooooo00<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o
]/40000000<0okK100@000000?nf`@3o]/400000103o]/400`000000okK10?nf`@040?nf`@Go0000
903o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/7ooooo00;ooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo02[ooooo3`3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100@0okK100?o
003o0?nf`@3o]/406`3o]/400ol00?l0okK10?nf`@0>0?nf`Bcooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o00000?nf`@3o]/400P3o
]/401@000000okK10?nf`@3o]/40000000<0okK100@000000?nf`@3o]/400000103o]/42000002T0
okK1100000040?nf`@<00000103o]/4200000080okK10P0000001?l00000okK10?nf`@3o]/420000
00050?nf`Oooooooooooooooo`0000001_ooool00`00003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02_ooooo3`3o]/400ol00?l0okK10?nf`@0B0?nf
`@03o`00o`3o]/40okK100D0okK100?o003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@0>0?nf
`Bgooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`0300000?oooooooooo
00Cooooo00<000000?nf`@3o]/400P3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100Go0000
0?nf`@3o]/7o0000000000040?nf`@030000003o]/40okK102@0okK10P0000050?nf`@<00000103o
]/43000000<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@03ooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0/ooooo`l0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@05
0?nf`@03o`00o`3o]/40okK101P0okK10_l00?l@0?nf`Bkooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Uooooo`0300000?oooooooooo00Cooooo00<000000?nf`@3o]/400P3o]/40
1@000000okK10?nf`@3o]/40000000<0okK100@000000?nf`@3o]/40okK10P0000030?nf`@<00000
703o]/47000000H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@800000
1@3o]/400`000000okK10?nf`@03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
8?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0]ooooo`l0okK10_l0
0?l@0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf
`@0>0?nf`C3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`0300000?oo
oooooooo00Cooooo00<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@800000403o]/400ol000000000
00000007000000/0okK10P0000050?nf`@800000103o]/400`000000okK10?nf`@040?nf`@030000
003o]/7ooooo00?ooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02kooooo403o]/42o`00o``0okK10_l0
0?l:0?nf`@;o003o5P3o]/400ol00?l0okK10?nf`@0>0?nf`C7ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o00000?nf`@3o]/400P3o
]/401P000000okK10?nf`@3o]/400000o`000080okK10P0000020?nf`@03o`0000000000000000@0
okK100?o00000000000000000`0000060?nf`@H00000403o]/4200000003o`0000000000okK10080
okK1100000030?nf`@80000000?o00000?nf`@3o]/400P3o]/4200000003o`00003o]/7ooooo00;o
oooo0P000007ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0<?ooool@0?nf`@Co003o1P3o]/42o`00o`h0okK100?o003o0?nf`@3o]/40
4@3o]/42o`00oa00okK1<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo
00<00000ooooooooool01Oooool00`000000okK10?nf`@020?nf`@03o`0000000000okK10080okK1
00@000000?nf`@3o]/40okK10P0000030?nf`@800000203o]/4600000180okK1100000040?nf`@<0
00001P3o]/400`000000okK10?nf`@040?nf`@040000003o]/40okK10?nf`@?ooooo00<00000oooo
ooooool01_ooool00`00003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo037ooooo4`3o]/46o`00oa40okK100?o003o0?nf`@3o]/403@3o]/43o`00oa40
okK1<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00<00000oooooooo
ool01Oooool2000000@0okK100D000000?nf`@3o]/40okK1000000040?nf`@8000000`3o]/420000
01L0okK11`0000060?nf`@8000001P3o]/43000000@0okK10`0000030?nf`@;ooooo0P000008oooo
o`0300000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0<_oooolZ0?nf`@Co003o203o]/43o`00oa<0okK1=?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Wooooo00<00000o`000?ooool01_ooool00`000000okK10?nf`@020?nf`@07
0000003o]/40okK10?nf`@00003o0000000000030?nf`@030000003o]/40okK10080okK10`00000@
0?nf`@@000002P3o]/400ol000000000000000050?nf`@<00000103o]/43000000D0okK100?ooooo
0000000000002Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo03?ooooo;@3o]/48o`00oaD0okK1=Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02_ooooo00<00000ooooooooool01Oooool00`000000okK10?nf`@020?nf
`@03o`0000000000okK100<0okK100D000000?nf`@3o]/40okK1o`000002000000@0okK100?o0000
0000000000003@00000;0?nf`@<00000103o]/44000000H0okK100<000000?nf`@3o]/401@3o]/42
000000Wooooo0P00000Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
03GoooooAP3o]/4gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00`00
003oooooooooo`05ooooo`030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/420000
00@0okK11000000D0?nf`@L00000103o]/43000000L0okK10`0000050?nf`@<000002_ooool00`00
003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Ko
ooooA03o]/4hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00`00003o
ooooooooo`05ooooo`030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000
okK10?nf`@050?nf`@030000003o]/40okK100h0okK10`0000090?nf`@03o`0000000000okK100H0
okK10`0000070?nf`@0300000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0hoooood00okK1>_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02gooooo00?o000000000?ooool01_ooool2000000@0okK1
00?o00000000000000000`3o]/43000000D0okK100?o00000000000000002`0000000ol000000000
0?nf`@060?nf`@D000001@3o]/4300000003o`00003o]/40okK100D0okK10P0000000ol0003ooooo
ooooo`09ooooo`800000;?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0joooooc`0okK1??ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00<0
0000ooooooooool01_ooool2000000D0okK10P0000040?nf`@@00000503o]/44000000L0okK10`00
00070?nf`@@000002oooool3000002kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0>ooooolj0?nf`Cgooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`
ooooo`8000002?ooool00`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK10`00000=
0?nf`@@00000203o]/43000000L0okK10`0000030?nf`@[ooooo0P00000aooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo03kooooo=@3o]/4oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<_ooool00`00003oooooooooo`06ooooo`80000000?ooooo0?nf
`@3o]/400P3o]/42000000P0okK1100000001Ol00000000000000000003o000000@00000203o]/42
00000003o`0000000000okK100P0okK100?o00000?nf`@3o]/400P3o]/4:ooooo`800000<oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`11ooooobl0okK1@_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00<00000ooooooooool01oooool20000
00;ooooo0`3o]/42000001L0okK11000000:0?nf`@<000000P3o]/4:ooooo`<00000=Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`14ooooobT0okK1AOooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`02ooooo`80okK10`00000@0?nf`@@000002`3o]/4300000080okK12oooool2000003So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0AooooolS0?nf`DSooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool01?ooool20?nf`A000000303o]/4300000080okK13?ooool2000003[ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B_oooolM0?nf`D_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`8000002Oooool01000003o00000000
00000005oooooaL0okK10P0000001?l0000000000?nf`@3o]/4;ooooo`@00000??ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1=oooooaL0okK1C_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Sooooo0P00000;ooooo`@000001?ooool@0?nf`@@00000
0`3o]/4;ooooo`<00000@?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1Fooooo`@0okK1F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00<0
0000ooooooooool03?ooool3000000[ooooo0`3o]/44000000oooooo0`000013ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0kooooo`0300000?l00000000000kooooo100000000ol00000000000000006
0000017ooooo00?o000000000?ooool0AOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool00`00
003oooooooooo`0Wooooo`800000B?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?oooool3000002;o
oooo1000001:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`12ooooo`8000007Oooool3000004kooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04Cooooo1@00000Dooooo`<0000000?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0BOooool3000000gooooo1000001Eooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1<ooooo`d00000FOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooooonfo`00017o
oooo]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0680272 0.0533118 0.000624815 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15986 -0.0125 -3 -9 ]
[.15986 -0.0125 3 0 ]
[.29592 -0.0125 -3 -9 ]
[.29592 -0.0125 3 0 ]
[.43197 -0.0125 -3 -9 ]
[.43197 -0.0125 3 0 ]
[.56803 -0.0125 -3 -9 ]
[.56803 -0.0125 3 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.84014 -0.0125 -6 -9 ]
[.84014 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05331 -6 -4.5 ]
[-0.0125 .05331 0 4.5 ]
[-0.0125 .17827 -18 -4.5 ]
[-0.0125 .17827 0 4.5 ]
[-0.0125 .30324 -18 -4.5 ]
[-0.0125 .30324 0 4.5 ]
[-0.0125 .4282 -18 -4.5 ]
[-0.0125 .4282 0 4.5 ]
[-0.0125 .55316 -18 -4.5 ]
[-0.0125 .55316 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.15986 0 m
.15986 .61803 L
s
.29592 0 m
.29592 .61803 L
s
.43197 0 m
.43197 .61803 L
s
.56803 0 m
.56803 .61803 L
s
.70408 0 m
.70408 .61803 L
s
.84014 0 m
.84014 .61803 L
s
0 .05331 m
1 .05331 L
s
0 .17827 m
1 .17827 L
s
0 .30324 m
1 .30324 L
s
0 .4282 m
1 .4282 L
s
0 .55316 m
1 .55316 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15986 0 m
.15986 .00625 L
s
[(2)] .15986 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(4)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(6)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(8)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(10)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(12)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(14)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05782 0 m
.05782 .00375 L
s
.09184 0 m
.09184 .00375 L
s
.12585 0 m
.12585 .00375 L
s
.19388 0 m
.19388 .00375 L
s
.22789 0 m
.22789 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.32993 0 m
.32993 .00375 L
s
.36395 0 m
.36395 .00375 L
s
.39796 0 m
.39796 .00375 L
s
.46599 0 m
.46599 .00375 L
s
.5 0 m
.5 .00375 L
s
.53401 0 m
.53401 .00375 L
s
.60204 0 m
.60204 .00375 L
s
.63605 0 m
.63605 .00375 L
s
.67007 0 m
.67007 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77211 0 m
.77211 .00375 L
s
.80612 0 m
.80612 .00375 L
s
.87415 0 m
.87415 .00375 L
s
.90816 0 m
.90816 .00375 L
s
.94218 0 m
.94218 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05331 m
.00625 .05331 L
s
[(0)] -0.0125 .05331 1 0 Mshowa
0 .17827 m
.00625 .17827 L
s
[(200)] -0.0125 .17827 1 0 Mshowa
0 .30324 m
.00625 .30324 L
s
[(400)] -0.0125 .30324 1 0 Mshowa
0 .4282 m
.00625 .4282 L
s
[(600)] -0.0125 .4282 1 0 Mshowa
0 .55316 m
.00625 .55316 L
s
[(800)] -0.0125 .55316 1 0 Mshowa
.125 Mabswid
0 .08455 m
.00375 .08455 L
s
0 .11579 m
.00375 .11579 L
s
0 .14703 m
.00375 .14703 L
s
0 .20952 m
.00375 .20952 L
s
0 .24076 m
.00375 .24076 L
s
0 .272 m
.00375 .272 L
s
0 .33448 m
.00375 .33448 L
s
0 .36572 m
.00375 .36572 L
s
0 .39696 m
.00375 .39696 L
s
0 .45944 m
.00375 .45944 L
s
0 .49068 m
.00375 .49068 L
s
0 .52192 m
.00375 .52192 L
s
0 .02207 m
.00375 .02207 L
s
0 .5844 m
.00375 .5844 L
s
0 .61564 m
.00375 .61564 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05782 .61428 m
.05782 .61803 L
s
.09184 .61428 m
.09184 .61803 L
s
.12585 .61428 m
.12585 .61803 L
s
.19388 .61428 m
.19388 .61803 L
s
.22789 .61428 m
.22789 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.32993 .61428 m
.32993 .61803 L
s
.36395 .61428 m
.36395 .61803 L
s
.39796 .61428 m
.39796 .61803 L
s
.46599 .61428 m
.46599 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53401 .61428 m
.53401 .61803 L
s
.60204 .61428 m
.60204 .61803 L
s
.63605 .61428 m
.63605 .61803 L
s
.67007 .61428 m
.67007 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77211 .61428 m
.77211 .61803 L
s
.80612 .61428 m
.80612 .61803 L
s
.87415 .61428 m
.87415 .61803 L
s
.90816 .61428 m
.90816 .61803 L
s
.94218 .61428 m
.94218 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05331 m
1 .05331 L
s
.99375 .17827 m
1 .17827 L
s
.99375 .30324 m
1 .30324 L
s
.99375 .4282 m
1 .4282 L
s
.99375 .55316 m
1 .55316 L
s
.125 Mabswid
.99625 .08455 m
1 .08455 L
s
.99625 .11579 m
1 .11579 L
s
.99625 .14703 m
1 .14703 L
s
.99625 .20952 m
1 .20952 L
s
.99625 .24076 m
1 .24076 L
s
.99625 .272 m
1 .272 L
s
.99625 .33448 m
1 .33448 L
s
.99625 .36572 m
1 .36572 L
s
.99625 .39696 m
1 .39696 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .49068 m
1 .49068 L
s
.99625 .52192 m
1 .52192 L
s
.99625 .02207 m
1 .02207 L
s
.99625 .5844 m
1 .5844 L
s
.99625 .61564 m
1 .61564 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09184 .44662 L
.15986 .47888 L
.22789 .50933 L
.29592 .53315 L
.36395 .54944 L
.43197 .56234 L
.5 .57378 L
.56803 .58361 L
.63605 .59155 L
.70408 .59729 L
.77211 .60066 L
.84014 .60225 L
.90816 .60296 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09184 .44662 Mdot
.15986 .47888 Mdot
.22789 .50933 Mdot
.29592 .53315 Mdot
.36395 .54944 Mdot
.43197 .56234 Mdot
.5 .57378 Mdot
.56803 .58361 Mdot
.63605 .59155 Mdot
.70408 .59729 Mdot
.77211 .60066 Mdot
.84014 .60225 Mdot
.90816 .60296 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`00023ooooo1Ol0000Qooooo`?o00008Oooool3o`00027ooooo0ol0000Noooo
o`?o00001?ooool2o`0001_ooooo0ol00002ooooo`Go00006_ooool3o`0000Cooooo0ol00003oooo
o`006Oooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool07oooool01Ol0003ooooooooooooooooo000001oooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`006Oooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo
01oooooo1Ol0000Pooooo`05o`000?ooooooooooooooool000007oooool01Ol0003ooooooooooooo
oooo000001kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06oooool01?l0003oooooooooooooool5o`0000?o
oooo000Iooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool07_ooool01?l0003o
ooooooooool0000Qooooo`Co00008Oooool3o`0001oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool001Wooooo00Co0000
oooooooooooo00007oooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004
ooooo`006Oooool01?l0003oooooooooool0000Oooooo`05o`000?ooooooooooooooool000008Ooo
ool2o`0002;ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000001gooooo
0_l00004ooooo`04o`000?ooooooooooo`0001[ooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000006_ooool2o`0000Gooooo0_l00004ooooo`006_ooool2o`00027ooooo0ol0000Sooooo`03
o`000?oooooooooo027ooooo0_l0000Qooooo`?o00007oooool00ol0003oooooooooo`03ooooo`;o
00007?ooool00ol0003oooooooooo`02ooooo`?o00007?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000Eooooo`0300000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`400000
0Oooool001Gooooo00<00000ooooooooool00_ooool3ool002;ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00ooo
ool10000007ooooo000Eooooo`0400000?ooooooooooooooo`Goo`008Oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000E
ooooo`0400000?ooooooooooooooo`Goo`008Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eooooo`0400000?oooooo
ooooooooo`Goo`008Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool09oooool10000007ooooo000Eooooo`0300000?l0003ooooo00;ooooo0ooo000R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0V
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo023o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oo
oooo0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo023ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo
0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo023ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo023ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001
ooooo`003_ooool2o`0000Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Poooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Woooo
o`4000000Oooool000gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`04oooo
o`0300000?oooooooooo023ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02Oooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`0300000?l00000001o00@0001o00<000000000O`0007l0oP0007l1o`00004000000Oooool000go
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo
01oooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02Oooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool09oooool10000007ooooo000=ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool000ko
oooo0_l00005ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007o
oooo000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo
000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000E
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eoooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eooooo`03
00000?l0003ooooo00Kooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool09_ooool1o`00004000000Oooool001Gooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`0Mooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000o`000?ooool01oooool0
0`00003oooooooooo`0Mooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Vooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo01gooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo01gooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`030000
0?oooooooooo01cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo01cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooo
oooo01cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo
01cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01co
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oo
oooo0@000001ooooo`005Oooool00`00003o0000ooooo`08ooooo`0300000?oooooooooo01cooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Kooooo
0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool06ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool06oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool1
0000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool06oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000
007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool06oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007o
oooo000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool06oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo
0005o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo01_ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02Oooooo0@000001ooooo`0000Goooooo`000?ooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`03
00000?oooooooooo01_ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`0:0000
O`030000000007l0001o0?P0001o0Ol000010000007ooooo0003ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000
ooooooooool02_ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool00005o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool02_ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool00005o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool00004
ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0:oooo
o`0300000?oooooooooo01[ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0:ooooo`03
00000?oooooooooo01[ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo01Wooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0;ooooo`0300000?oo
oooooooo01Wooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0;ooooo`0300000?oooooo
oooo01Wooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo02Oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0;ooooo`0300000?oooooooooo
01Wooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02Kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool06Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool09oooool10000007ooooo000Eooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0
6Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
9oooool10000007ooooo000Eooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06?oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06?ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool1
0000007ooooo000Eooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06?ooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000
007ooooo000Eooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06?ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007o
oooo000Eooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06?ooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo
000Eooooo`0300000?l0003ooooo00cooooo00<00000ooooooooool06?ooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09_ooool1o`00004000000Ooo
ool001Gooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0Hooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool0
01Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Go
oooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo
00<00000ooooooooool03Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<0
0000ooooooooool03Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000
ooooooooool03Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000o`000?oo
ool03_ooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Vooooo`7o00000@000001ooooo`005Oooool00`00003ooooo
ooooo`0>ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0>ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0>
ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0>oooo
o`0300000?oooooooooo01Kooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0>ooooo`03
00000?oooooooooo01Kooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`000_ooool3o`0000?ooooo0_l00004ooooo`;o0000
1Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Gooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007o
oooo0005o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo00001?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003o00000000O`0?0000O`030000000007l0001o0?<0001o0Ol000010000007ooooo0000
1?oooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Gooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`00
0_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo0003ooooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo01Gooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`030000
0?oooooooooo01Cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oo
oooooooo01Cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooo
oooo01Cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo
01Cooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02Oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0@ooooo`0300000?oooooooooo01Co
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Ko
oooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool0
5?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
9oooool10000007ooooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool04ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool04oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool1
0000007ooooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool04oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000
007ooooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool04oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007o
oooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool04oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo
000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool04oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000E
ooooo`0300000?l0003ooooo017ooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09_ooool1o`00004000000Oooool0
01Gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Go
oooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<0
0000ooooooooool04_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000
ooooooooool04_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000oooo
ooooool04_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000oooooooo
ool04oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool0
4oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000o`000?ooool04ooo
ool00`00003oooooooooo`0Aooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Vooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0C
ooooo`0300000?oooooooooo017ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Coooo
o`0300000?oooooooooo017ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Cooooo`03
00000?oooooooooo017ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Dooooo`030000
0?oooooooooo013ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02Oooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04?ooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo
00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04?ooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000
007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04?oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09ooo
ool10000007ooooo0004o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?l00000001o01@0001o00<000000000O`0007l0kP0007l1o`0000400000
0Oooool00003o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04?ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007o
oooo00000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo013ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001oooo
o`000_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Dooooo`?o
o`004?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool09oooool10000007ooooo000Eooooo`0300000?oooooooooo01?ooooo1Ooo000?ooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`400000
0Oooool001Gooooo00<00000ooooooooool04oooool5ool000oooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Cooooo`Goo`0000<00000ooooooooool03?ooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eoooo
o`0300000?oooooooooo01Cooooo0ooo0002ooooo`<000002oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eooooo`03
00000?l0003ooooo01cooooo0P000009ooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Vooooo`7o00000@000001ooooo`005Oooool00`00003ooooo
ooooo`0Nooooo`8000001oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool09oooool10000007ooooo000Eooooo`0300000?oooooooooo023ooooo0P00
0005ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007oooooooooo
o`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool08_ooool300000004oooooooo003o
o`00ool002;ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool09Oooool5ool0027ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool09Oooool5ool0
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Go
oooo00<00000ooooooooool09Oooool5ool0000300000?oooooooooo01kooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool0
9_ooool3ool000;ooooo0`00000Mooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
9oooool10000007ooooo000Eooooo`0300000?l0003ooooo02Oooooo00<0001oooooooooool01?oo
ool2000001_ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Vooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo00Kooooo0P00000I
ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eoooo
o`0300000?oooooooooo02Oooooo00<0001oooooooooool02?ooool2000001Oooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000oooooooo
ool09oooool00`0007ooooooooooo`0:ooooo`<000005?ooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Wooooo`030000
Oooooooooooo00gooooo00@00000ool00?oo003oo`004?ooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Wooooo`030000
Oooooooooooo00gooooo1Ooo000?ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
9oooool10000007ooooo000Eooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool03Ooo
ool5ool0008000003Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo00gooooo1Ooo0002
ooooo`8000002oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo00kooooo0ooo0005oooo
o`<000002?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001oooo
o`005Oooool00`00003o0000ooooo`0Wooooo`030000Oooooooooooo01Wooooo0`000005ooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool09_ooool1o`00004000000Oooool001Gooooo
00<00000ooooooooool09oooool00`0007ooooooooooo`0Looooo`8000000_ooool3ool002?ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool09oooool10000007ooooo000Eooooo`0300000?oooooooooo02Oooooo00<0
001oooooooooool07_ooool00`00003oo`00ool00003ool002;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool09ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool07oooool5
ool002;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool09oooool10000007ooooo000Eooooo`0300000?oooooooooo
02Oooooo00<0001oooooooooool07oooool5ool000D000007Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Woooo
o`4000000Oooool001Gooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Pooooo`?o
o`001_ooool4000000Gooooo0ooo000Aooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`00
00Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo02Oo
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`09ooooo`@000001Ooo000@ooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02Oooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0W
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool03Oooool5ool0000300000?oooooo
oooo00gooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool09oooool10000007ooooo00001Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?l00000001o05/0001o1Ooo00000`0007l0000000000005000009d0001o0Ol000010000007ooooo
00001?oooooo0000o`000?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool03_ooool3ool000Wooooo1P000003ool002?ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo02Oooooo0@000001ooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Wooooo`030000Oooooooooooo027ooooo00<0001oooooooooool07ooo
ool5ool0008000008?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool09oooool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Oo
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Oooooo`Goo`000_ooool6000001[o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02Oo
oooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`03
00000?oooooooooo02Oooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Oooooo`Go
o`002?ooool6000000?oo`004Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool09oooool10000007ooooo000Eooooo`0300000?oooooooooo02Oooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`?oo`003_ooool5ool000800000
3_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
9oooool10000007ooooo000Eooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo00cooooo1Ooo0002ooooo`H000001ooo
ool3ool002;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo02;ooooo00<0001oooooooooool03?ooool5ool000Sooooo1P000005ool0027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000o`00
0?ooool09oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool03Oooool3ool000oooooo1Ooo0003000000_ooooo0ooo000@ooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool09_ooool1o`00004000000Oooool001Gooooo00<00000oooooooo
ool09oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool07oooool5ool000?ooooo2@0000000oooooooo`00ool00003ool000oooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Wooooo`4000000Oooool001Gooooo00<00000ooooooooool0
9oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8?ooool3ool000gooooo00<00000ool00?oo00000ooo0003000000_ooooo0ooo000Rooooo`030000
Oooooooooooo02Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Wooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo00gooooo1Ooo0003ooooo`T0000000?oooooool00?oo00000ooo000>ooooo`?oo`003ooo
ool3ool000oooooo0ooo000?ooooo`?oo`001?ooool10000007ooooo000Eooooo`0300000?oooooo
oooo02Oooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool03_ooool3ool000gooooo00<00000ool00?oo00000ooo0007
000000Kooooo1Ooo000=ooooo`Goo`003Oooool5ool000gooooo1Ooo0003ooooo`4000000Oooool0
01Gooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Oooooo`Goo`001oooool60000
00Goo`003@000005ool000d000001Ooo000=000000Goo`000oooool10000007ooooo000Eooooo`03
00000?oooooooooo02Oooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08?ooool3ool000kooooo1Ooo000=ooooo`Go
o`003Oooool5ool000gooooo1Ooo0003ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
9oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo00kooooo0ooo000?ooooo`?oo`00
3oooool3ool000oooooo0ooo0004ooooo`4000000Oooool001Gooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`005Ooooooo
000000T000000Ol000010000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.53024, -161.075, \
0.0553562, 6.02695}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(full1\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #3: blue class, scalar covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 11;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes scalar covariances", "Subsubsection"],

Cell[BoxData[
    \(\(initScalar\  = \ EMInitializationScalar[data2, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data2, initScalar, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.28000000000002956`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.2 g
.01923 .69433 m
.03846 .70476 L
.05383 .71154 L
.05769 .71301 L
.07692 .71921 L
.09615 .72352 L
.11538 .72598 L
.13462 .72659 L
.15385 .72531 L
.17308 .72205 L
.19231 .71661 L
.20542 .71154 L
.21154 .70868 L
.23077 .69769 L
.2384 .69231 L
.25 .68269 L
.25969 .67308 L
.26923 .66175 L
.27491 .65385 L
.28612 .63462 L
.28846 .62979 L
.2943 .61538 L
.30002 .59615 L
.3036 .57692 L
.30525 .55769 L
.30511 .53846 L
.3033 .51923 L
.29999 .5 L
.29541 .48077 L
.29001 .46154 L
.28846 .4568 L
.28448 .44231 L
.2802 .42308 L
.27982 .40385 L
.28846 .3852 L
.28897 .38462 L
.30769 .36944 L
.3164 .36538 L
.32692 .35999 L
.34615 .35094 L
.35643 .34615 L
.36538 .34156 L
.38462 .33089 L
.39115 .32692 L
.40385 .31833 L
.41768 .30769 L
.42308 .30306 L
.43804 .28846 L
.44231 .28376 L
.45376 .26923 L
.46154 .25769 L
.46583 .25 L
.4748 .23077 L
.48077 .21263 L
.48099 .21154 L
.48411 .19231 L
.48461 .17308 L
.48245 .15385 L
.48077 .14435 L
.47734 .13462 L
.46911 .11538 L
.46154 .10139 L
.45809 .09615 L
.44369 .07692 L
.44231 .07524 L
.42574 .05769 L
.42308 .05511 L
.40389 .03846 L
.40385 .03842 L
.38462 .02405 L
.37746 .01923 L
.01923 .01923 L
F
0 g
.01923 .69433 m
.03846 .70476 L
.05383 .71154 L
.05769 .71301 L
.07692 .71921 L
.09615 .72352 L
.11538 .72598 L
.13462 .72659 L
.15385 .72531 L
.17308 .72205 L
.19231 .71661 L
.20542 .71154 L
.21154 .70868 L
.23077 .69769 L
.2384 .69231 L
.25 .68269 L
.25969 .67308 L
.26923 .66175 L
.27491 .65385 L
.28612 .63462 L
.28846 .62979 L
.2943 .61538 L
.30002 .59615 L
.3036 .57692 L
.30525 .55769 L
.30511 .53846 L
.3033 .51923 L
.29999 .5 L
.29541 .48077 L
.29001 .46154 L
.28846 .4568 L
.28448 .44231 L
.2802 .42308 L
.27982 .40385 L
.28846 .3852 L
.28897 .38462 L
.30769 .36944 L
.3164 .36538 L
.32692 .35999 L
.34615 .35094 L
.35643 .34615 L
.36538 .34156 L
.38462 .33089 L
.39115 .32692 L
.40385 .31833 L
.41768 .30769 L
.42308 .30306 L
.43804 .28846 L
.44231 .28376 L
.45376 .26923 L
Mistroke
.46154 .25769 L
.46583 .25 L
.4748 .23077 L
.48077 .21263 L
.48099 .21154 L
.48411 .19231 L
.48461 .17308 L
.48245 .15385 L
.48077 .14435 L
.47734 .13462 L
.46911 .11538 L
.46154 .10139 L
.45809 .09615 L
.44369 .07692 L
.44231 .07524 L
.42574 .05769 L
.42308 .05511 L
.40389 .03846 L
.40385 .03842 L
.38462 .02405 L
.37746 .01923 L
Mfstroke
.3 g
.01923 .63742 m
.03846 .65086 L
.04349 .65385 L
.05769 .66102 L
.07692 .6684 L
.09518 .67308 L
.09615 .67323 L
.11538 .67563 L
.13462 .67557 L
.1532 .67308 L
.15385 .67294 L
.17308 .66745 L
.19231 .65854 L
.2 .65385 L
.21154 .64515 L
.22256 .63462 L
.23077 .6248 L
.23718 .61538 L
.24696 .59615 L
.25 .58852 L
.25317 .57692 L
.25644 .55769 L
.25714 .53846 L
.25548 .51923 L
.2516 .5 L
.25 .4939 L
.24562 .48077 L
.23764 .46154 L
.23077 .44777 L
.22782 .44231 L
.21634 .42308 L
.21154 .41645 L
.20345 .40385 L
.19231 .39037 L
.18937 .38462 L
.17429 .36538 L
.1787 .34615 L
.19231 .34521 L
.21154 .34325 L
.23077 .34163 L
.25 .33963 L
.26923 .33706 L
.28846 .33375 L
.30769 .32949 L
.31746 .32692 L
.32692 .32389 L
.34615 .31662 L
.3648 .30769 L
.36538 .30737 L
.38462 .2953 L
.39361 .28846 L
.40385 .2794 L
.41351 .26923 L
.42308 .25712 L
.42775 .25 L
.43775 .23077 L
.44231 .2191 L
.44423 .21154 L
.44754 .19231 L
.44794 .17308 L
.44547 .15385 L
.44231 .14003 L
.44007 .13462 L
.43151 .11538 L
.42308 .101 L
.41971 .09615 L
.40419 .07692 L
.40385 .07655 L
.38462 .05786 L
.38442 .05769 L
.36538 .04256 L
.35965 .03846 L
.34615 .0295 L
.32872 .01923 L
.01923 .01923 L
F
0 g
.01923 .63742 m
.03846 .65086 L
.04349 .65385 L
.05769 .66102 L
.07692 .6684 L
.09518 .67308 L
.09615 .67323 L
.11538 .67563 L
.13462 .67557 L
.1532 .67308 L
.15385 .67294 L
.17308 .66745 L
.19231 .65854 L
.2 .65385 L
.21154 .64515 L
.22256 .63462 L
.23077 .6248 L
.23718 .61538 L
.24696 .59615 L
.25 .58852 L
.25317 .57692 L
.25644 .55769 L
.25714 .53846 L
.25548 .51923 L
.2516 .5 L
.25 .4939 L
.24562 .48077 L
.23764 .46154 L
.23077 .44777 L
.22782 .44231 L
.21634 .42308 L
.21154 .41645 L
.20345 .40385 L
.19231 .39037 L
.18937 .38462 L
.17429 .36538 L
.1787 .34615 L
.19231 .34521 L
.21154 .34325 L
.23077 .34163 L
.25 .33963 L
.26923 .33706 L
.28846 .33375 L
.30769 .32949 L
.31746 .32692 L
.32692 .32389 L
.34615 .31662 L
.3648 .30769 L
.36538 .30737 L
.38462 .2953 L
Mistroke
.39361 .28846 L
.40385 .2794 L
.41351 .26923 L
.42308 .25712 L
.42775 .25 L
.43775 .23077 L
.44231 .2191 L
.44423 .21154 L
.44754 .19231 L
.44794 .17308 L
.44547 .15385 L
.44231 .14003 L
.44007 .13462 L
.43151 .11538 L
.42308 .101 L
.41971 .09615 L
.40419 .07692 L
.40385 .07655 L
.38462 .05786 L
.38442 .05769 L
.36538 .04256 L
.35965 .03846 L
.34615 .0295 L
.32872 .01923 L
Mfstroke
.01923 .78127 m
.035 .78846 L
.03846 .78988 L
.05769 .79688 L
.07692 .80251 L
.09615 .80684 L
.10041 .80769 L
.11538 .80989 L
.13462 .81183 L
.15385 .8128 L
.17308 .81296 L
.19231 .8125 L
.21154 .81174 L
.23077 .81118 L
.25 .812 L
.26923 .81877 L
.27473 .82692 L
.27836 .84615 L
.27774 .86538 L
.27611 .88462 L
.2745 .90385 L
.27346 .92308 L
.27331 .94231 L
.27432 .96154 L
.27667 .98077 L
.01923 .98077 L
F
.01923 .78127 m
.035 .78846 L
.03846 .78988 L
.05769 .79688 L
.07692 .80251 L
.09615 .80684 L
.10041 .80769 L
.11538 .80989 L
.13462 .81183 L
.15385 .8128 L
.17308 .81296 L
.19231 .8125 L
.21154 .81174 L
.23077 .81118 L
.25 .812 L
.26923 .81877 L
.27473 .82692 L
.27836 .84615 L
.27774 .86538 L
.27611 .88462 L
.2745 .90385 L
.27346 .92308 L
.27331 .94231 L
.27432 .96154 L
.27667 .98077 L
s
.4 g
.01923 .57826 m
.03521 .59615 L
.03846 .59921 L
.05769 .6133 L
.06106 .61538 L
.07692 .62279 L
.09615 .62855 L
.11538 .63088 L
.13462 .62976 L
.15385 .62479 L
.17242 .61538 L
.17308 .6149 L
.19231 .59734 L
.19325 .59615 L
.20482 .57692 L
.21094 .55769 L
.21154 .55453 L
.21305 .53846 L
.21166 .51923 L
.21154 .51846 L
.20701 .5 L
.19896 .48077 L
.19231 .46907 L
.18709 .46154 L
.17308 .44527 L
.17003 .44231 L
.15385 .42956 L
.14312 .42308 L
.13462 .41934 L
.11538 .41349 L
.09615 .41142 L
.07692 .41288 L
.05769 .41803 L
.04582 .42308 L
.03846 .42762 L
.02124 .44231 L
.01923 .44392 L
F
0 g
.01923 .57826 m
.03521 .59615 L
.03846 .59921 L
.05769 .6133 L
.06106 .61538 L
.07692 .62279 L
.09615 .62855 L
.11538 .63088 L
.13462 .62976 L
.15385 .62479 L
.17242 .61538 L
.17308 .6149 L
.19231 .59734 L
.19325 .59615 L
.20482 .57692 L
.21094 .55769 L
.21154 .55453 L
.21305 .53846 L
.21166 .51923 L
.21154 .51846 L
.20701 .5 L
.19896 .48077 L
.19231 .46907 L
.18709 .46154 L
.17308 .44527 L
.17003 .44231 L
.15385 .42956 L
.14312 .42308 L
.13462 .41934 L
.11538 .41349 L
.09615 .41142 L
.07692 .41288 L
.05769 .41803 L
.04582 .42308 L
.03846 .42762 L
.02124 .44231 L
.01923 .44392 L
s
.2 g
.01923 .38534 m
.02069 .38462 L
.03846 .37514 L
.05769 .36742 L
.06325 .36538 L
.07692 .36167 L
.09615 .35754 L
.11538 .35507 L
.13462 .35109 L
.15385 .3496 L
.16356 .34615 L
.15385 .33874 L
.14386 .32692 L
.13462 .31575 L
.12808 .30769 L
.11538 .29182 L
.11277 .28846 L
.09815 .26923 L
.09615 .26635 L
.08452 .25 L
.07692 .23827 L
.07215 .23077 L
.06127 .21154 L
.05769 .20449 L
.05209 .19231 L
.04476 .17308 L
.03938 .15385 L
.03846 .15247 L
.0361 .13462 L
.03504 .11538 L
.03638 .09615 L
.03846 .08138 L
.04035 .07692 L
.04733 .05769 L
.05769 .03889 L
.05799 .03846 L
.07366 .01923 L
.01923 .01923 L
F
0 g
.01923 .38534 m
.02069 .38462 L
.03846 .37514 L
.05769 .36742 L
.06325 .36538 L
.07692 .36167 L
.09615 .35754 L
.11538 .35507 L
.13462 .35109 L
.15385 .3496 L
.16356 .34615 L
.15385 .33874 L
.14386 .32692 L
.13462 .31575 L
.12808 .30769 L
.11538 .29182 L
.11277 .28846 L
.09815 .26923 L
.09615 .26635 L
.08452 .25 L
.07692 .23827 L
.07215 .23077 L
.06127 .21154 L
.05769 .20449 L
.05209 .19231 L
.04476 .17308 L
.03938 .15385 L
.03846 .15247 L
.0361 .13462 L
.03504 .11538 L
.03638 .09615 L
.03846 .08138 L
.04035 .07692 L
.04733 .05769 L
.05769 .03889 L
.05799 .03846 L
.07366 .01923 L
s
.1 g
.01923 .32286 m
.03489 .30769 L
.03846 .30268 L
.04416 .28846 L
.04418 .26923 L
.03944 .25 L
.03846 .24629 L
.03272 .23077 L
.02558 .21154 L
.01923 .19315 L
F
0 g
.01923 .32286 m
.03489 .30769 L
.03846 .30268 L
.04416 .28846 L
.04418 .26923 L
.03944 .25 L
.03846 .24629 L
.03272 .23077 L
.02558 .21154 L
.01923 .19315 L
s
.1 g
.01923 .04644 m
.02302 .03846 L
.03454 .01923 L
.01923 .01923 L
F
0 g
.01923 .04644 m
.02302 .03846 L
.03454 .01923 L
s
.5 g
.07692 .46971 m
.09615 .46596 L
.11538 .46906 L
.13462 .47985 L
.13581 .48077 L
.15203 .5 L
.15385 .50407 L
.15892 .51923 L
.15918 .53846 L
.15385 .55342 L
.15196 .55769 L
.13462 .57274 L
.11915 .57692 L
.11538 .57733 L
.10427 .57692 L
.09615 .57542 L
.07692 .56664 L
.06598 .55769 L
.05769 .54815 L
.05343 .53846 L
.04821 .51923 L
.05002 .5 L
.05769 .48519 L
.05974 .48077 L
F
0 g
.07692 .46971 m
.09615 .46596 L
.11538 .46906 L
.13462 .47985 L
.13581 .48077 L
.15203 .5 L
.15385 .50407 L
.15892 .51923 L
.15918 .53846 L
.15385 .55342 L
.15196 .55769 L
.13462 .57274 L
.11915 .57692 L
.11538 .57733 L
.10427 .57692 L
.09615 .57542 L
.07692 .56664 L
.06598 .55769 L
.05769 .54815 L
.05343 .53846 L
.04821 .51923 L
.05002 .5 L
.05769 .48519 L
.05974 .48077 L
.07692 .46971 L
s
.4 g
.28411 .01923 m
.28846 .02109 L
.30769 .0302 L
.32278 .03846 L
.32692 .04092 L
.34615 .05355 L
.3518 .05769 L
.36538 .06871 L
.3743 .07692 L
.38462 .08768 L
.39166 .09615 L
.40385 .11383 L
.40474 .11538 L
.41401 .13462 L
.41989 .15385 L
.42252 .17308 L
.42192 .19231 L
.41796 .21154 L
.41031 .23077 L
.40385 .24216 L
.3982 .25 L
.38462 .26509 L
.38003 .26923 L
.36538 .28033 L
.35166 .28846 L
.34615 .29118 L
.32692 .29894 L
.30769 .30433 L
.28887 .30769 L
.28846 .30773 L
.26923 .30929 L
.25 .30918 L
.23299 .30769 L
.23077 .30738 L
.21154 .30355 L
.19231 .29748 L
.17308 .28913 L
.17169 .28846 L
.15385 .27752 L
.14225 .26923 L
.13462 .26284 L
.12078 .25 L
.11538 .24432 L
.10365 .23077 L
.09615 .22092 L
.0897 .21154 L
.07848 .19231 L
.07692 .1893 L
.06983 .17308 L
.06368 .15385 L
.06006 .13462 L
.05909 .11538 L
.06096 .09615 L
.06603 .07692 L
.07497 .05769 L
.07692 .05443 L
.08914 .03846 L
.09615 .03154 L
.112 .01923 L
F
0 g
.28411 .01923 m
.28846 .02109 L
.30769 .0302 L
.32278 .03846 L
.32692 .04092 L
.34615 .05355 L
.3518 .05769 L
.36538 .06871 L
.3743 .07692 L
.38462 .08768 L
.39166 .09615 L
.40385 .11383 L
.40474 .11538 L
.41401 .13462 L
.41989 .15385 L
.42252 .17308 L
.42192 .19231 L
.41796 .21154 L
.41031 .23077 L
.40385 .24216 L
.3982 .25 L
.38462 .26509 L
.38003 .26923 L
.36538 .28033 L
.35166 .28846 L
.34615 .29118 L
.32692 .29894 L
.30769 .30433 L
.28887 .30769 L
.28846 .30773 L
.26923 .30929 L
.25 .30918 L
.23299 .30769 L
.23077 .30738 L
.21154 .30355 L
.19231 .29748 L
.17308 .28913 L
.17169 .28846 L
.15385 .27752 L
.14225 .26923 L
.13462 .26284 L
.12078 .25 L
.11538 .24432 L
.10365 .23077 L
.09615 .22092 L
.0897 .21154 L
.07848 .19231 L
.07692 .1893 L
.06983 .17308 L
.06368 .15385 L
Mistroke
.06006 .13462 L
.05909 .11538 L
.06096 .09615 L
.06603 .07692 L
.07497 .05769 L
.07692 .05443 L
.08914 .03846 L
.09615 .03154 L
.112 .01923 L
Mfstroke
.5 g
.22196 .01923 m
.23077 .02076 L
.25 .0254 L
.26923 .03173 L
.2857 .03846 L
.28846 .03973 L
.30769 .04947 L
.32153 .05769 L
.32692 .06122 L
.34615 .07561 L
.34771 .07692 L
.36538 .09392 L
.36737 .09615 L
.38191 .11538 L
.38462 .11958 L
.3921 .13462 L
.39844 .15385 L
.40114 .17308 L
.40019 .19231 L
.39536 .21154 L
.38599 .23077 L
.38462 .23295 L
.37058 .25 L
.36538 .25486 L
.34615 .26859 L
.34506 .26923 L
.32692 .27777 L
.30769 .28375 L
.28846 .28717 L
.26923 .28837 L
.25 .28751 L
.23077 .28461 L
.21154 .27959 L
.19231 .27233 L
.18551 .26923 L
.17308 .26251 L
.15414 .25 L
.15385 .24978 L
.13462 .2334 L
.13191 .23077 L
.11538 .21218 L
.11488 .21154 L
.10172 .19231 L
.09615 .18238 L
.09184 .17308 L
.08502 .15385 L
.08118 .13462 L
.08044 .11538 L
.08308 .09615 L
.08969 .07692 L
.09615 .06495 L
.1015 .05769 L
.11538 .04338 L
.12173 .03846 L
.13462 .03072 L
.15385 .02293 L
.16795 .01923 L
F
0 g
.22196 .01923 m
.23077 .02076 L
.25 .0254 L
.26923 .03173 L
.2857 .03846 L
.28846 .03973 L
.30769 .04947 L
.32153 .05769 L
.32692 .06122 L
.34615 .07561 L
.34771 .07692 L
.36538 .09392 L
.36737 .09615 L
.38191 .11538 L
.38462 .11958 L
.3921 .13462 L
.39844 .15385 L
.40114 .17308 L
.40019 .19231 L
.39536 .21154 L
.38599 .23077 L
.38462 .23295 L
.37058 .25 L
.36538 .25486 L
.34615 .26859 L
.34506 .26923 L
.32692 .27777 L
.30769 .28375 L
.28846 .28717 L
.26923 .28837 L
.25 .28751 L
.23077 .28461 L
.21154 .27959 L
.19231 .27233 L
.18551 .26923 L
.17308 .26251 L
.15414 .25 L
.15385 .24978 L
.13462 .2334 L
.13191 .23077 L
.11538 .21218 L
.11488 .21154 L
.10172 .19231 L
.09615 .18238 L
.09184 .17308 L
.08502 .15385 L
.08118 .13462 L
.08044 .11538 L
.08308 .09615 L
.08969 .07692 L
Mistroke
.09615 .06495 L
.1015 .05769 L
.11538 .04338 L
.12173 .03846 L
.13462 .03072 L
.15385 .02293 L
.16795 .01923 L
Mfstroke
.6 g
.17308 .03742 m
.19231 .0349 L
.21154 .0351 L
.23077 .0376 L
.23572 .03846 L
.25 .04216 L
.26923 .04865 L
.28846 .05708 L
.28971 .05769 L
.30769 .06764 L
.32166 .07692 L
.32692 .08085 L
.34437 .09615 L
.34615 .09793 L
.36073 .11538 L
.36538 .12206 L
.37201 .13462 L
.37886 .15385 L
.38157 .17308 L
.38009 .19231 L
.37398 .21154 L
.36538 .22664 L
.36199 .23077 L
.34615 .2461 L
.34072 .25 L
.32692 .25778 L
.30769 .26497 L
.28846 .26891 L
.28583 .26923 L
.26923 .27018 L
.2515 .26923 L
.25 .26906 L
.23077 .26564 L
.21154 .25989 L
.19231 .25165 L
.18903 .25 L
.17308 .24057 L
.15952 .23077 L
.15385 .22606 L
.13884 .21154 L
.13462 .20681 L
.12354 .19231 L
.11538 .17907 L
.1124 .17308 L
.10493 .15385 L
.10097 .13462 L
.10065 .11538 L
.10442 .09615 L
.11334 .07692 L
.11538 .07375 L
.13014 .05769 L
.13462 .05417 L
.15385 .04335 L
.16783 .03846 L
F
0 g
.17308 .03742 m
.19231 .0349 L
.21154 .0351 L
.23077 .0376 L
.23572 .03846 L
.25 .04216 L
.26923 .04865 L
.28846 .05708 L
.28971 .05769 L
.30769 .06764 L
.32166 .07692 L
.32692 .08085 L
.34437 .09615 L
.34615 .09793 L
.36073 .11538 L
.36538 .12206 L
.37201 .13462 L
.37886 .15385 L
.38157 .17308 L
.38009 .19231 L
.37398 .21154 L
.36538 .22664 L
.36199 .23077 L
.34615 .2461 L
.34072 .25 L
.32692 .25778 L
.30769 .26497 L
.28846 .26891 L
.28583 .26923 L
.26923 .27018 L
.2515 .26923 L
.25 .26906 L
.23077 .26564 L
.21154 .25989 L
.19231 .25165 L
.18903 .25 L
.17308 .24057 L
.15952 .23077 L
.15385 .22606 L
.13884 .21154 L
.13462 .20681 L
.12354 .19231 L
.11538 .17907 L
.1124 .17308 L
.10493 .15385 L
.10097 .13462 L
.10065 .11538 L
.10442 .09615 L
.11334 .07692 L
.11538 .07375 L
Mistroke
.13014 .05769 L
.13462 .05417 L
.15385 .04335 L
.16783 .03846 L
.17308 .03742 L
Mfstroke
.7 g
.17308 .05651 m
.19231 .05249 L
.21154 .05186 L
.23077 .05395 L
.24844 .05769 L
.25 .05841 L
.26923 .06511 L
.28846 .07416 L
.29348 .07692 L
.30769 .08589 L
.32097 .09615 L
.32692 .10141 L
.3398 .11538 L
.34615 .1236 L
.35242 .13462 L
.35986 .15385 L
.3625 .17308 L
.36021 .19231 L
.3521 .21154 L
.34615 .22029 L
.3355 .23077 L
.32692 .23704 L
.30769 .24643 L
.29788 .25 L
.28846 .25138 L
.26923 .25305 L
.25 .25191 L
.23866 .25 L
.23077 .24815 L
.21154 .24173 L
.19231 .23243 L
.18941 .23077 L
.17308 .21975 L
.16319 .21154 L
.15385 .20246 L
.14518 .19231 L
.13462 .17687 L
.13258 .17308 L
.12443 .15385 L
.12046 .13462 L
.12086 .11538 L
.1264 .09615 L
.13462 .08193 L
.13932 .07692 L
.15385 .06514 L
.16926 .05769 L
F
0 g
.17308 .05651 m
.19231 .05249 L
.21154 .05186 L
.23077 .05395 L
.24844 .05769 L
.25 .05841 L
.26923 .06511 L
.28846 .07416 L
.29348 .07692 L
.30769 .08589 L
.32097 .09615 L
.32692 .10141 L
.3398 .11538 L
.34615 .1236 L
.35242 .13462 L
.35986 .15385 L
.3625 .17308 L
.36021 .19231 L
.3521 .21154 L
.34615 .22029 L
.3355 .23077 L
.32692 .23704 L
.30769 .24643 L
.29788 .25 L
.28846 .25138 L
.26923 .25305 L
.25 .25191 L
.23866 .25 L
.23077 .24815 L
.21154 .24173 L
.19231 .23243 L
.18941 .23077 L
.17308 .21975 L
.16319 .21154 L
.15385 .20246 L
.14518 .19231 L
.13462 .17687 L
.13258 .17308 L
.12443 .15385 L
.12046 .13462 L
.12086 .11538 L
.1264 .09615 L
.13462 .08193 L
.13932 .07692 L
.15385 .06514 L
.16926 .05769 L
.17308 .05651 L
s
.8 g
.19231 .07108 m
.21154 .06914 L
.23077 .07062 L
.25 .07497 L
.25657 .07692 L
.26923 .08198 L
.28846 .09201 L
.29492 .09615 L
.30769 .10575 L
.31771 .11538 L
.32692 .126 L
.33219 .13462 L
.34037 .15385 L
.3428 .17308 L
.33915 .19231 L
.32728 .21154 L
.32692 .21194 L
.30769 .22647 L
.29903 .23077 L
.28846 .23329 L
.26923 .23582 L
.25 .23486 L
.23077 .23078 L
.23073 .23077 L
.21154 .22363 L
.19231 .21285 L
.19036 .21154 L
.17308 .19753 L
.168 .19231 L
.15385 .17377 L
.15345 .17308 L
.1445 .15385 L
.14069 .13462 L
.14233 .11538 L
.15121 .09615 L
.15385 .09255 L
.17308 .07769 L
.174 .07692 L
F
0 g
.19231 .07108 m
.21154 .06914 L
.23077 .07062 L
.25 .07497 L
.25657 .07692 L
.26923 .08198 L
.28846 .09201 L
.29492 .09615 L
.30769 .10575 L
.31771 .11538 L
.32692 .126 L
.33219 .13462 L
.34037 .15385 L
.3428 .17308 L
.33915 .19231 L
.32728 .21154 L
.32692 .21194 L
.30769 .22647 L
.29903 .23077 L
.28846 .23329 L
.26923 .23582 L
.25 .23486 L
.23077 .23078 L
.23073 .23077 L
.21154 .22363 L
.19231 .21285 L
.19036 .21154 L
.17308 .19753 L
.168 .19231 L
.15385 .17377 L
.15345 .17308 L
.1445 .15385 L
.14069 .13462 L
.14233 .11538 L
.15121 .09615 L
.15385 .09255 L
.17308 .07769 L
.174 .07692 L
.19231 .07108 L
s
.9 g
.19231 .09297 m
.21154 .08838 L
.23077 .0888 L
.25 .093 L
.26002 .09615 L
.26923 .10056 L
.28846 .11262 L
.29189 .11538 L
.30769 .13157 L
.30966 .13462 L
.31896 .15385 L
.32085 .17308 L
.31428 .19231 L
.30769 .20158 L
.29133 .21154 L
.28846 .21256 L
.26923 .217 L
.25 .21658 L
.23077 .21214 L
.22876 .21154 L
.21154 .20394 L
.19456 .19231 L
.19231 .19057 L
.17657 .17308 L
.17308 .16759 L
.16656 .15385 L
.16322 .13462 L
.16755 .11538 L
.17308 .10459 L
.18516 .09615 L
F
0 g
.19231 .09297 m
.21154 .08838 L
.23077 .0888 L
.25 .093 L
.26002 .09615 L
.26923 .10056 L
.28846 .11262 L
.29189 .11538 L
.30769 .13157 L
.30966 .13462 L
.31896 .15385 L
.32085 .17308 L
.31428 .19231 L
.30769 .20158 L
.29133 .21154 L
.28846 .21256 L
.26923 .217 L
.25 .21658 L
.23077 .21214 L
.22876 .21154 L
.21154 .20394 L
.19456 .19231 L
.19231 .19057 L
.17657 .17308 L
.17308 .16759 L
.16656 .15385 L
.16322 .13462 L
.16755 .11538 L
.17308 .10459 L
.18516 .09615 L
.19231 .09297 L
s
1 g
.21154 .11449 m
.23077 .11156 L
.24936 .11538 L
.25 .11546 L
.26923 .12354 L
.28094 .13462 L
.28846 .14593 L
.29195 .15385 L
.29188 .17308 L
.28846 .1793 L
.26935 .19231 L
.26923 .19235 L
.25 .19393 L
.24113 .19231 L
.23077 .19019 L
.21154 .17813 L
.20656 .17308 L
.19402 .15385 L
.19264 .13462 L
.20961 .11538 L
F
0 g
.21154 .11449 m
.23077 .11156 L
.24936 .11538 L
.25 .11546 L
.26923 .12354 L
.28094 .13462 L
.28846 .14593 L
.29195 .15385 L
.29188 .17308 L
.28846 .1793 L
.26935 .19231 L
.26923 .19235 L
.25 .19393 L
.24113 .19231 L
.23077 .19019 L
.21154 .17813 L
.20656 .17308 L
.19402 .15385 L
.19264 .13462 L
.20961 .11538 L
.21154 .11449 L
s
.98077 .41138 m
.96227 .42308 L
.96154 .42349 L
.94231 .4333 L
.92308 .4411 L
.91969 .44231 L
.90385 .44711 L
.88462 .45148 L
.86538 .4543 L
.84615 .45566 L
.82692 .45559 L
.80769 .45411 L
.78846 .45121 L
.76923 .44688 L
.75363 .44231 L
.75 .44108 L
.73077 .43371 L
.71154 .42471 L
.70839 .42308 L
.69231 .41394 L
.67677 .40385 L
.67308 .40125 L
.65385 .38647 L
.65162 .38462 L
.63462 .36947 L
.63033 .36538 L
.61538 .35043 L
.61129 .34615 L
.59615 .33032 L
.59295 .32692 L
.57692 .3118 L
.574 .30769 L
.55769 .29912 L
.53846 .29572 L
.51923 .30131 L
.50758 .30769 L
.5 .31254 L
.48077 .32616 L
.47967 .32692 L
.46154 .34018 L
.45316 .34615 L
.44231 .3539 L
.42608 .36538 L
.42308 .36745 L
.40385 .38144 L
.39991 .38462 L
.38462 .39786 L
.37967 .40385 L
.36854 .42308 L
.36538 .43637 L
.36483 .44231 L
.36538 .4615 L
.36539 .46154 L
.36786 .48077 L
.37088 .5 L
.37365 .51923 L
.37577 .53846 L
.37705 .55769 L
.37744 .57692 L
.37701 .59615 L
.37586 .61538 L
.3742 .63462 L
.37233 .65385 L
.37081 .67308 L
.37082 .69231 L
.38054 .71154 L
.38462 .71376 L
.40385 .71518 L
.42291 .71154 L
.42308 .7115 L
.44231 .70614 L
.46154 .70005 L
.48077 .69376 L
.48534 .69231 L
.5 .68775 L
.51923 .68218 L
.53846 .67722 L
.55746 .67308 L
.55769 .67303 L
.57692 .66988 L
.59615 .66769 L
.61538 .66655 L
.63462 .66653 L
.65385 .66769 L
.67308 .67006 L
.68983 .67308 L
.69231 .67367 L
.71154 .67885 L
.73077 .68541 L
.74788 .69231 L
.75 .69329 L
.76923 .70305 L
.78408 .71154 L
.78846 .71434 L
.80769 .72769 L
.8118 .73077 L
.82692 .74329 L
.83437 .75 L
.84615 .76164 L
.8532 .76923 L
.86538 .78368 L
.86905 .78846 L
.88236 .80769 L
.88462 .8113 L
.89334 .82692 L
.90239 .84615 L
.90385 .84965 L
.90942 .86538 L
.9147 .88462 L
.9183 .90385 L
.9202 .92308 L
.92041 .94231 L
.91889 .96154 L
.91561 .98077 L
.98077 .98077 L
F
.98077 .41138 m
.96227 .42308 L
.96154 .42349 L
.94231 .4333 L
.92308 .4411 L
.91969 .44231 L
.90385 .44711 L
.88462 .45148 L
.86538 .4543 L
.84615 .45566 L
.82692 .45559 L
.80769 .45411 L
.78846 .45121 L
.76923 .44688 L
.75363 .44231 L
.75 .44108 L
.73077 .43371 L
.71154 .42471 L
.70839 .42308 L
.69231 .41394 L
.67677 .40385 L
.67308 .40125 L
.65385 .38647 L
.65162 .38462 L
.63462 .36947 L
.63033 .36538 L
.61538 .35043 L
.61129 .34615 L
.59615 .33032 L
.59295 .32692 L
.57692 .3118 L
.574 .30769 L
.55769 .29912 L
.53846 .29572 L
.51923 .30131 L
.50758 .30769 L
.5 .31254 L
.48077 .32616 L
.47967 .32692 L
.46154 .34018 L
.45316 .34615 L
.44231 .3539 L
.42608 .36538 L
.42308 .36745 L
.40385 .38144 L
.39991 .38462 L
.38462 .39786 L
.37967 .40385 L
.36854 .42308 L
.36538 .43637 L
Mistroke
.36483 .44231 L
.36538 .4615 L
.36539 .46154 L
.36786 .48077 L
.37088 .5 L
.37365 .51923 L
.37577 .53846 L
.37705 .55769 L
.37744 .57692 L
.37701 .59615 L
.37586 .61538 L
.3742 .63462 L
.37233 .65385 L
.37081 .67308 L
.37082 .69231 L
.38054 .71154 L
.38462 .71376 L
.40385 .71518 L
.42291 .71154 L
.42308 .7115 L
.44231 .70614 L
.46154 .70005 L
.48077 .69376 L
.48534 .69231 L
.5 .68775 L
.51923 .68218 L
.53846 .67722 L
.55746 .67308 L
.55769 .67303 L
.57692 .66988 L
.59615 .66769 L
.61538 .66655 L
.63462 .66653 L
.65385 .66769 L
.67308 .67006 L
.68983 .67308 L
.69231 .67367 L
.71154 .67885 L
.73077 .68541 L
.74788 .69231 L
.75 .69329 L
.76923 .70305 L
.78408 .71154 L
.78846 .71434 L
.80769 .72769 L
.8118 .73077 L
.82692 .74329 L
.83437 .75 L
.84615 .76164 L
.8532 .76923 L
Mistroke
.86538 .78368 L
.86905 .78846 L
.88236 .80769 L
.88462 .8113 L
.89334 .82692 L
.90239 .84615 L
.90385 .84965 L
.90942 .86538 L
.9147 .88462 L
.9183 .90385 L
.9202 .92308 L
.92041 .94231 L
.91889 .96154 L
.91561 .98077 L
Mfstroke
.2 g
.86749 .98077 m
.87184 .96154 L
.87396 .94231 L
.87396 .92308 L
.87187 .90385 L
.86771 .88462 L
.86538 .8765 L
.86136 .86538 L
.85268 .84615 L
.84615 .83433 L
.84149 .82692 L
.82741 .80769 L
.82692 .8071 L
.80983 .78846 L
.80769 .78639 L
.78846 .76977 L
.78776 .76923 L
.76923 .75622 L
.75903 .75 L
.75 .74509 L
.73077 .73605 L
.71721 .73077 L
.71154 .72889 L
.69231 .72351 L
.67308 .71975 L
.65385 .71757 L
.63462 .71695 L
.61538 .71788 L
.59615 .72036 L
.57692 .72439 L
.55769 .73 L
.55541 .73077 L
.53846 .73732 L
.51923 .74639 L
.51248 .75 L
.5 .75736 L
.48245 .76923 L
.48077 .77047 L
.46154 .78611 L
.45893 .78846 L
.44231 .80495 L
.43982 .80769 L
.42415 .82692 L
.42308 .82838 L
.41138 .84615 L
.40385 .8598 L
.40115 .86538 L
.39327 .88462 L
.38759 .90385 L
.38462 .91762 L
.38407 .92308 L
.38271 .94231 L
.38358 .96154 L
.38462 .96949 L
.38682 .98077 L
F
0 g
.86749 .98077 m
.87184 .96154 L
.87396 .94231 L
.87396 .92308 L
.87187 .90385 L
.86771 .88462 L
.86538 .8765 L
.86136 .86538 L
.85268 .84615 L
.84615 .83433 L
.84149 .82692 L
.82741 .80769 L
.82692 .8071 L
.80983 .78846 L
.80769 .78639 L
.78846 .76977 L
.78776 .76923 L
.76923 .75622 L
.75903 .75 L
.75 .74509 L
.73077 .73605 L
.71721 .73077 L
.71154 .72889 L
.69231 .72351 L
.67308 .71975 L
.65385 .71757 L
.63462 .71695 L
.61538 .71788 L
.59615 .72036 L
.57692 .72439 L
.55769 .73 L
.55541 .73077 L
.53846 .73732 L
.51923 .74639 L
.51248 .75 L
.5 .75736 L
.48245 .76923 L
.48077 .77047 L
.46154 .78611 L
.45893 .78846 L
.44231 .80495 L
.43982 .80769 L
.42415 .82692 L
.42308 .82838 L
.41138 .84615 L
.40385 .8598 L
.40115 .86538 L
.39327 .88462 L
.38759 .90385 L
.38462 .91762 L
Mistroke
.38407 .92308 L
.38271 .94231 L
.38358 .96154 L
.38462 .96949 L
.38682 .98077 L
Mfstroke
.3 g
.8347 .98077 m
.84025 .96154 L
.84305 .94231 L
.8433 .92308 L
.84107 .90385 L
.83636 .88462 L
.82907 .86538 L
.82692 .86073 L
.81892 .84615 L
.80769 .8297 L
.80552 .82692 L
.78846 .80804 L
.7881 .80769 L
.76923 .79146 L
.7652 .78846 L
.75 .77842 L
.73314 .76923 L
.73077 .76811 L
.71154 .76017 L
.69231 .75431 L
.67308 .75039 L
.67041 .75 L
.65385 .74837 L
.63462 .74819 L
.61538 .74985 L
.6141 .75 L
.59615 .75344 L
.57692 .75903 L
.55769 .76677 L
.55254 .76923 L
.53846 .77695 L
.52121 .78846 L
.51923 .78995 L
.5 .8065 L
.49879 .80769 L
.4816 .82692 L
.48077 .82798 L
.46822 .84615 L
.46154 .85789 L
.45793 .86538 L
.45037 .88462 L
.44536 .90385 L
.44288 .92308 L
.44299 .94231 L
.44588 .96154 L
.45187 .98077 L
F
0 g
.8347 .98077 m
.84025 .96154 L
.84305 .94231 L
.8433 .92308 L
.84107 .90385 L
.83636 .88462 L
.82907 .86538 L
.82692 .86073 L
.81892 .84615 L
.80769 .8297 L
.80552 .82692 L
.78846 .80804 L
.7881 .80769 L
.76923 .79146 L
.7652 .78846 L
.75 .77842 L
.73314 .76923 L
.73077 .76811 L
.71154 .76017 L
.69231 .75431 L
.67308 .75039 L
.67041 .75 L
.65385 .74837 L
.63462 .74819 L
.61538 .74985 L
.6141 .75 L
.59615 .75344 L
.57692 .75903 L
.55769 .76677 L
.55254 .76923 L
.53846 .77695 L
.52121 .78846 L
.51923 .78995 L
.5 .8065 L
.49879 .80769 L
.4816 .82692 L
.48077 .82798 L
.46822 .84615 L
.46154 .85789 L
.45793 .86538 L
.45037 .88462 L
.44536 .90385 L
.44288 .92308 L
.44299 .94231 L
.44588 .96154 L
.45187 .98077 L
s
.54179 .01923 m
.53846 .02192 L
.51923 .03177 L
.5 .03159 L
.48077 .02528 L
.46486 .01923 L
F
.54179 .01923 m
.53846 .02192 L
.51923 .03177 L
.5 .03159 L
.48077 .02528 L
.46486 .01923 L
s
.4 g
.80694 .98077 m
.80769 .97913 L
.81395 .96154 L
.81756 .94231 L
.81813 .92308 L
.81581 .90385 L
.81056 .88462 L
.80769 .87683 L
.80221 .86538 L
.79034 .84615 L
.78846 .84358 L
.77414 .82692 L
.76923 .82209 L
.75191 .80769 L
.75 .80632 L
.73077 .79439 L
.71883 .78846 L
.71154 .78543 L
.69231 .77902 L
.67308 .77491 L
.65385 .77299 L
.63462 .77324 L
.61538 .77569 L
.59615 .78047 L
.57692 .78781 L
.57549 .78846 L
.55769 .79812 L
.54396 .80769 L
.53846 .81214 L
.52314 .82692 L
.51923 .83133 L
.50814 .84615 L
.5 .85977 L
.49728 .86538 L
.48984 .88462 L
.48546 .90385 L
.48406 .92308 L
.48574 .94231 L
.49078 .96154 L
.49972 .98077 L
F
0 g
.80694 .98077 m
.80769 .97913 L
.81395 .96154 L
.81756 .94231 L
.81813 .92308 L
.81581 .90385 L
.81056 .88462 L
.80769 .87683 L
.80221 .86538 L
.79034 .84615 L
.78846 .84358 L
.77414 .82692 L
.76923 .82209 L
.75191 .80769 L
.75 .80632 L
.73077 .79439 L
.71883 .78846 L
.71154 .78543 L
.69231 .77902 L
.67308 .77491 L
.65385 .77299 L
.63462 .77324 L
.61538 .77569 L
.59615 .78047 L
.57692 .78781 L
.57549 .78846 L
.55769 .79812 L
.54396 .80769 L
.53846 .81214 L
.52314 .82692 L
.51923 .83133 L
.50814 .84615 L
.5 .85977 L
.49728 .86538 L
.48984 .88462 L
.48546 .90385 L
.48406 .92308 L
.48574 .94231 L
.49078 .96154 L
.49972 .98077 L
s
.5 g
.78051 .98077 m
.78846 .96454 L
.78956 .96154 L
.79427 .94231 L
.79529 .92308 L
.79287 .90385 L
.78846 .88709 L
.78698 .88462 L
.77731 .86538 L
.76923 .85355 L
.76309 .84615 L
.75 .83307 L
.74256 .82692 L
.73077 .81869 L
.71154 .80835 L
.71016 .80769 L
.69231 .80119 L
.67308 .79679 L
.65385 .79498 L
.63462 .79572 L
.61538 .79911 L
.59615 .80543 L
.59089 .80769 L
.57692 .8152 L
.56069 .82692 L
.55769 .82951 L
.54214 .84615 L
.53846 .85094 L
.52976 .86538 L
.52183 .88462 L
.51923 .89459 L
.51767 .90385 L
.51708 .92308 L
.51923 .93851 L
.52014 .94231 L
.52727 .96154 L
.53846 .97888 L
.53934 .98077 L
F
0 g
.78051 .98077 m
.78846 .96454 L
.78956 .96154 L
.79427 .94231 L
.79529 .92308 L
.79287 .90385 L
.78846 .88709 L
.78698 .88462 L
.77731 .86538 L
.76923 .85355 L
.76309 .84615 L
.75 .83307 L
.74256 .82692 L
.73077 .81869 L
.71154 .80835 L
.71016 .80769 L
.69231 .80119 L
.67308 .79679 L
.65385 .79498 L
.63462 .79572 L
.61538 .79911 L
.59615 .80543 L
.59089 .80769 L
.57692 .8152 L
.56069 .82692 L
.55769 .82951 L
.54214 .84615 L
.53846 .85094 L
.52976 .86538 L
.52183 .88462 L
.51923 .89459 L
.51767 .90385 L
.51708 .92308 L
.51923 .93851 L
.52014 .94231 L
.52727 .96154 L
.53846 .97888 L
.53934 .98077 L
s
.6 g
.75235 .98077 m
.76488 .96154 L
.76923 .95019 L
.77124 .94231 L
.77293 .92308 L
.7704 .90385 L
.76923 .89771 L
.76365 .88462 L
.75201 .86538 L
.75 .86275 L
.73383 .84615 L
.73077 .84365 L
.71154 .83104 L
.70348 .82692 L
.69231 .82276 L
.67308 .81792 L
.65385 .81622 L
.63462 .81761 L
.61538 .82235 L
.60372 .82692 L
.59615 .83101 L
.57692 .84517 L
.57588 .84615 L
.56013 .86538 L
.55769 .86871 L
.55088 .88462 L
.54649 .90385 L
.54647 .92308 L
.55089 .94231 L
.55769 .95774 L
.56042 .96154 L
.57669 .98077 L
F
0 g
.75235 .98077 m
.76488 .96154 L
.76923 .95019 L
.77124 .94231 L
.77293 .92308 L
.7704 .90385 L
.76923 .89771 L
.76365 .88462 L
.75201 .86538 L
.75 .86275 L
.73383 .84615 L
.73077 .84365 L
.71154 .83104 L
.70348 .82692 L
.69231 .82276 L
.67308 .81792 L
.65385 .81622 L
.63462 .81761 L
.61538 .82235 L
.60372 .82692 L
.59615 .83101 L
.57692 .84517 L
.57588 .84615 L
.56013 .86538 L
.55769 .86871 L
.55088 .88462 L
.54649 .90385 L
.54647 .92308 L
.55089 .94231 L
.55769 .95774 L
.56042 .96154 L
.57669 .98077 L
s
.7 g
.71576 .98077 m
.73077 .9642 L
.73685 .96154 L
.7464 .94231 L
.74921 .92308 L
.7466 .90385 L
.73838 .88462 L
.73077 .87334 L
.72311 .86538 L
.71154 .85597 L
.69352 .84615 L
.69231 .84569 L
.67308 .84004 L
.65385 .83847 L
.63462 .84094 L
.61793 .84615 L
.61538 .84804 L
.59615 .86182 L
.59282 .86538 L
.58031 .88462 L
.57692 .89422 L
.57498 .90385 L
.57535 .92308 L
.57692 .93017 L
.58146 .94231 L
.59475 .96154 L
.59615 .96274 L
.61538 .97679 L
.61989 .98077 L
F
0 g
.71576 .98077 m
.73077 .9642 L
.73685 .96154 L
.7464 .94231 L
.74921 .92308 L
.7466 .90385 L
.73838 .88462 L
.73077 .87334 L
.72311 .86538 L
.71154 .85597 L
.69352 .84615 L
.69231 .84569 L
.67308 .84004 L
.65385 .83847 L
.63462 .84094 L
.61793 .84615 L
.61538 .84804 L
.59615 .86182 L
.59282 .86538 L
.58031 .88462 L
.57692 .89422 L
.57498 .90385 L
.57535 .92308 L
.57692 .93017 L
.58146 .94231 L
.59475 .96154 L
.59615 .96274 L
.61538 .97679 L
.61989 .98077 L
s
.8 g
.65385 .86529 m
.6655 .86538 L
.67308 .86641 L
.69231 .87361 L
.70612 .88462 L
.71154 .89234 L
.71769 .90385 L
.72066 .92308 L
.71456 .94231 L
.71154 .94777 L
.69231 .96129 L
.69143 .96154 L
.67308 .96447 L
.65385 .96355 L
.64495 .96154 L
.63462 .95741 L
.61753 .94231 L
.61538 .93902 L
.60799 .92308 L
.60742 .90385 L
.61538 .8861 L
.61624 .88462 L
.63462 .86958 L
.65296 .86538 L
F
0 g
.65385 .86529 m
.6655 .86538 L
.67308 .86641 L
.69231 .87361 L
.70612 .88462 L
.71154 .89234 L
.71769 .90385 L
.72066 .92308 L
.71456 .94231 L
.71154 .94777 L
.69231 .96129 L
.69143 .96154 L
.67308 .96447 L
.65385 .96355 L
.64495 .96154 L
.63462 .95741 L
.61753 .94231 L
.61538 .93902 L
.60799 .92308 L
.60742 .90385 L
.61538 .8861 L
.61624 .88462 L
.63462 .86958 L
.65296 .86538 L
.65385 .86529 L
s
.2 g
.85631 .01923 m
.86538 .02392 L
.88462 .03607 L
.88784 .03846 L
.90385 .05231 L
.90916 .05769 L
.92308 .07425 L
.92503 .07692 L
.93718 .09615 L
.94231 .10611 L
.94635 .11538 L
.953 .13462 L
.95732 .15385 L
.95941 .17308 L
.95925 .19231 L
.95673 .21154 L
.95158 .23077 L
.94331 .25 L
.94231 .2519 L
.93107 .26923 L
.92308 .27868 L
.91291 .28846 L
.90385 .2955 L
.88462 .30672 L
.8827 .30769 L
.86538 .31392 L
.84615 .31785 L
.82692 .3189 L
.80769 .31725 L
.78846 .31293 L
.77327 .30769 L
.76923 .30584 L
.75 .29571 L
.7391 .28846 L
.73077 .28201 L
.71673 .26923 L
.71154 .26377 L
.70012 .25 L
.69231 .23883 L
.68739 .23077 L
.67765 .21154 L
.67308 .20025 L
.67051 .19231 L
.66576 .17308 L
.66334 .15385 L
.66326 .13462 L
.6656 .11538 L
.67056 .09615 L
.67308 .08893 L
.6785 .07692 L
.69023 .05769 L
.69231 .05492 L
.70739 .03846 L
.71154 .03487 L
.73077 .02157 L
.73484 .01923 L
F
0 g
.85631 .01923 m
.86538 .02392 L
.88462 .03607 L
.88784 .03846 L
.90385 .05231 L
.90916 .05769 L
.92308 .07425 L
.92503 .07692 L
.93718 .09615 L
.94231 .10611 L
.94635 .11538 L
.953 .13462 L
.95732 .15385 L
.95941 .17308 L
.95925 .19231 L
.95673 .21154 L
.95158 .23077 L
.94331 .25 L
.94231 .2519 L
.93107 .26923 L
.92308 .27868 L
.91291 .28846 L
.90385 .2955 L
.88462 .30672 L
.8827 .30769 L
.86538 .31392 L
.84615 .31785 L
.82692 .3189 L
.80769 .31725 L
.78846 .31293 L
.77327 .30769 L
.76923 .30584 L
.75 .29571 L
.7391 .28846 L
.73077 .28201 L
.71673 .26923 L
.71154 .26377 L
.70012 .25 L
.69231 .23883 L
.68739 .23077 L
.67765 .21154 L
.67308 .20025 L
.67051 .19231 L
.66576 .17308 L
.66334 .15385 L
.66326 .13462 L
.6656 .11538 L
.67056 .09615 L
.67308 .08893 L
.6785 .07692 L
Mistroke
.69023 .05769 L
.69231 .05492 L
.70739 .03846 L
.71154 .03487 L
.73077 .02157 L
.73484 .01923 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .745 .915 r
.39882 .6034 .40494 .60893 .41519 .606 .4091 .60046 Mtetra
.657 .746 .915 r
.4091 .60046 .41519 .606 .42549 .60306 .41942 .59751 Mtetra
.657 .746 .916 r
.41942 .59751 .42549 .60306 .43582 .60012 .42978 .59456 Mtetra
.656 .746 .916 r
.42978 .59456 .43582 .60012 .4462 .59719 .44018 .59162 Mtetra
.655 .746 .917 r
.44018 .59162 .4462 .59719 .45661 .59429 .45062 .5887 Mtetra
.652 .746 .918 r
.45062 .5887 .45661 .59429 .46707 .59143 .4611 .58583 Mtetra
.649 .745 .92 r
.4611 .58583 .46707 .59143 .47757 .58866 .47162 .58303 Mtetra
.644 .744 .921 r
.47162 .58303 .47757 .58866 .4881 .58599 .48219 .58035 Mtetra
.638 .742 .924 r
.48219 .58035 .4881 .58599 .49868 .58347 .49279 .57781 Mtetra
.63 .74 .927 r
.49279 .57781 .49868 .58347 .50931 .58114 .50344 .57546 Mtetra
.619 .737 .93 r
.50344 .57546 .50931 .58114 .51998 .57904 .51414 .57335 Mtetra
.606 .732 .934 r
.51414 .57335 .51998 .57904 .5307 .57723 .52489 .57153 Mtetra
.59 .727 .939 r
.52489 .57153 .5307 .57723 .54147 .57574 .53568 .57003 Mtetra
.571 .721 .943 r
.53568 .57003 .54147 .57574 .5523 .57462 .54654 .56891 Mtetra
.549 .713 .948 r
.54654 .56891 .5523 .57462 .56319 .57388 .55745 .5682 Mtetra
.524 .704 .953 r
.55745 .5682 .56319 .57388 .57414 .57356 .56843 .56792 Mtetra
.494 .694 .957 r
.56843 .56792 .57414 .57356 .58517 .57368 .57948 .56811 Mtetra
.459 .682 .961 r
.57948 .56811 .58517 .57368 .59627 .57425 .59061 .5688 Mtetra
.415 .666 .964 r
.59061 .5688 .59627 .57425 .60745 .5753 .60182 .57003 Mtetra
.359 .646 .964 r
.60182 .57003 .60745 .5753 .61871 .57687 .61312 .57186 Mtetra
.283 .616 .958 r
.61312 .57186 .61871 .57687 .63007 .579 .62451 .57436 Mtetra
.179 .57 .936 r
.62451 .57436 .63007 .579 .64154 .58177 .63602 .57764 Mtetra
.035 .496 .883 r
.63602 .57764 .64154 .58177 .65312 .58526 .64765 .58179 Mtetra
0 .384 .777 r
.64765 .58179 .65312 .58526 .66482 .58953 .65942 .58691 Mtetra
.339 0 0 r
.65942 .58691 .66482 .58953 .67666 .59462 .67133 .59302 Mtetra
.499 0 0 r
.67133 .59302 .67666 .59462 .68864 .60049 .6834 .60008 Mtetra
.601 .031 0 r
.6834 .60008 .68864 .60049 .70076 .60702 .69563 .60793 Mtetra
.652 .111 0 r
.69563 .60793 .70076 .60702 .71303 .61394 .70801 .61625 Mtetra
.667 .154 .011 r
.70801 .61625 .71303 .61394 .72541 .62085 .72053 .62455 Mtetra
.657 .167 .075 r
.72053 .62455 .72541 .62085 .73788 .6272 .73313 .63218 Mtetra
.625 .152 .11 r
.73313 .63218 .73788 .6272 .75039 .63235 .74577 .6384 Mtetra
.571 .11 .119 r
.74577 .6384 .75039 .63235 .76288 .63561 .75839 .64243 Mtetra
.486 .033 .101 r
.75839 .64243 .76288 .63561 .77529 .63632 .7709 .64352 Mtetra
.355 0 .049 r
.7709 .64352 .77529 .63632 .78754 .63396 .78324 .64112 Mtetra
.156 0 0 r
.78324 .64112 .78754 .63396 .79959 .62821 .79534 .63491 Mtetra
0 0 0 r
.79534 .63491 .79959 .62821 .81138 .61905 .80716 .62491 Mtetra
.80716 .62491 .81138 .61905 .82292 .60674 .81869 .61146 Mtetra
.701 .891 .516 r
.81869 .61146 .82292 .60674 .8342 .59182 .82995 .59518 Mtetra
.855 .955 .609 r
.82995 .59518 .8342 .59182 .84528 .57503 .84099 .57693 Mtetra
.926 .965 .666 r
.84099 .57693 .84528 .57503 .85621 .55722 .85187 .55765 Mtetra
.952 .953 .704 r
.85187 .55765 .85621 .55722 .86707 .53923 .86267 .53827 Mtetra
.953 .935 .735 r
.86267 .53827 .86707 .53923 .87794 .52182 .87349 .5196 Mtetra
.94 .915 .763 r
.87349 .5196 .87794 .52182 .88888 .50559 .88439 .50228 Mtetra
.918 .895 .79 r
.88439 .50228 .88888 .50559 .89996 .49094 .89543 .48671 Mtetra
.889 .874 .816 r
.89543 .48671 .89996 .49094 .91122 .47806 .90666 .47309 Mtetra
.855 .853 .839 r
.90666 .47309 .91122 .47806 .92267 .46696 .9181 .46141 Mtetra
.82 .832 .858 r
.9181 .46141 .92267 .46696 .93432 .45752 .92975 .45153 Mtetra
.785 .812 .874 r
.92975 .45153 .93432 .45752 .94617 .44953 .94161 .44322 Mtetra
.754 .794 .885 r
.94161 .44322 .94617 .44953 .9582 .44273 .95366 .43619 Mtetra
.728 .779 .893 r
.95366 .43619 .9582 .44273 .97039 .43686 .96587 .43015 Mtetra
.657 .746 .916 r
.39266 .59785 .39882 .6034 .4091 .60046 .40296 .59491 Mtetra
.657 .747 .916 r
.40296 .59491 .4091 .60046 .41942 .59751 .41331 .59195 Mtetra
.656 .747 .917 r
.41331 .59195 .41942 .59751 .42978 .59456 .42369 .589 Mtetra
.42369 .589 .42978 .59456 .44018 .59162 .43412 .58604 Mtetra
.654 .747 .918 r
.43412 .58604 .44018 .59162 .45062 .5887 .44458 .58311 Mtetra
.652 .747 .919 r
.44458 .58311 .45062 .5887 .4611 .58583 .45509 .58022 Mtetra
.649 .746 .92 r
.45509 .58022 .4611 .58583 .47162 .58303 .46564 .5774 Mtetra
.645 .745 .922 r
.46564 .5774 .47162 .58303 .48219 .58035 .47623 .57468 Mtetra
.639 .743 .924 r
.47623 .57468 .48219 .58035 .49279 .57781 .48686 .57211 Mtetra
.631 .74 .926 r
.48686 .57211 .49279 .57781 .50344 .57546 .49754 .56972 Mtetra
.62 .736 .929 r
.49754 .56972 .50344 .57546 .51414 .57335 .50826 .56756 Mtetra
.608 .731 .932 r
.50826 .56756 .51414 .57335 .52489 .57153 .51903 .56569 Mtetra
.593 .725 .936 r
.51903 .56569 .52489 .57153 .53568 .57003 .52985 .56415 Mtetra
.575 .717 .939 r
.52985 .56415 .53568 .57003 .54654 .56891 .54073 .56298 Mtetra
.554 .708 .943 r
.54073 .56298 .54654 .56891 .55745 .5682 .55167 .56223 Mtetra
.53 .698 .946 r
.55167 .56223 .55745 .5682 .56843 .56792 .56267 .56193 Mtetra
.502 .686 .949 r
.56267 .56193 .56843 .56792 .57948 .56811 .57375 .56212 Mtetra
.469 .672 .952 r
.57375 .56212 .57948 .56811 .59061 .5688 .5849 .56284 Mtetra
.428 .654 .954 r
.5849 .56284 .59061 .5688 .60182 .57003 .59613 .56415 Mtetra
.376 .632 .954 r
.59613 .56415 .60182 .57003 .61312 .57186 .60746 .56614 Mtetra
.306 .601 .949 r
.60746 .56614 .61312 .57186 .62451 .57436 .61889 .5689 Mtetra
.211 .556 .934 r
.61889 .5689 .62451 .57436 .63602 .57764 .63043 .57255 Mtetra
.081 .489 .896 r
.63043 .57255 .63602 .57764 .64765 .58179 .6421 .57722 Mtetra
0 .391 .82 r
.6421 .57722 .64765 .58179 .65942 .58691 .65392 .583 Mtetra
0 .263 .693 r
.65392 .583 .65942 .58691 .67133 .59302 .66589 .58993 Mtetra
.441 0 0 r
.66589 .58993 .67133 .59302 .6834 .60008 .67803 .59795 Mtetra
.563 0 0 r
.67803 .59795 .6834 .60008 .69563 .60793 .69034 .60686 Mtetra
.634 .071 0 r
.69034 .60686 .69563 .60793 .70801 .61625 .70282 .61629 Mtetra
.661 .112 0 r
.70282 .61629 .70801 .61625 .72053 .62455 .71543 .62566 Mtetra
.655 .116 0 r
.71543 .62566 .72053 .62455 .73313 .63218 .72814 .63425 Mtetra
.617 .081 0 r
.72814 .63425 .73313 .63218 .74577 .6384 .74088 .64123 Mtetra
.537 0 0 r
.74088 .64123 .74577 .6384 .75839 .64243 .75358 .64573 Mtetra
.391 0 0 r
.75358 .64573 .75839 .64243 .7709 .64352 .76617 .64698 Mtetra
.131 0 0 r
.76617 .64698 .7709 .64352 .78324 .64112 .77857 .64438 Mtetra
0 0 0 r
.77857 .64438 .78324 .64112 .79534 .63491 .79071 .63766 Mtetra
.632 .93 .677 r
.79071 .63766 .79534 .63491 .80716 .62491 .80255 .62687 Mtetra
.842 .99 .726 r
.80255 .62687 .80716 .62491 .81869 .61146 .81408 .61242 Mtetra
.926 .974 .728 r
.81408 .61242 .81869 .61146 .82995 .59518 .82533 .59505 Mtetra
.955 .943 .723 r
.82533 .59505 .82995 .59518 .84099 .57693 .83635 .57568 Mtetra
.96 .915 .722 r
.83635 .57568 .84099 .57693 .85187 .55765 .84721 .55532 Mtetra
.955 .893 .728 r
.84721 .55532 .85187 .55765 .86267 .53827 .85799 .53496 Mtetra
.943 .876 .74 r
.85799 .53496 .86267 .53827 .87349 .5196 .86879 .51545 Mtetra
.926 .862 .757 r
.86879 .51545 .87349 .5196 .88439 .50228 .87968 .49741 Mtetra
.905 .849 .778 r
.87968 .49741 .88439 .50228 .89543 .48671 .89072 .48128 Mtetra
.878 .837 .801 r
.89072 .48128 .89543 .48671 .90666 .47309 .90196 .46721 Mtetra
.848 .825 .825 r
.90196 .46721 .90666 .47309 .9181 .46141 .91342 .45519 Mtetra
.816 .811 .846 r
.91342 .45519 .9181 .46141 .92975 .45153 .92509 .44506 Mtetra
.784 .798 .864 r
.92509 .44506 .92975 .45153 .94161 .44322 .93698 .43656 Mtetra
.754 .784 .878 r
.93698 .43656 .94161 .44322 .95366 .43619 .94905 .4294 Mtetra
.729 .773 .888 r
.94905 .4294 .95366 .43619 .96587 .43015 .9613 .42326 Mtetra
.655 .747 .917 r
.38645 .59231 .39266 .59785 .40296 .59491 .39678 .58938 Mtetra
.655 .748 .918 r
.39678 .58938 .40296 .59491 .41331 .59195 .40714 .58642 Mtetra
.655 .749 .919 r
.40714 .58642 .41331 .59195 .42369 .589 .41755 .58346 Mtetra
.655 .75 .92 r
.41755 .58346 .42369 .589 .43412 .58604 .42801 .5805 Mtetra
.654 .75 .92 r
.42801 .5805 .43412 .58604 .44458 .58311 .4385 .57756 Mtetra
.652 .75 .921 r
.4385 .57756 .44458 .58311 .45509 .58022 .44903 .57464 Mtetra
.649 .749 .922 r
.44903 .57464 .45509 .58022 .46564 .5774 .45961 .57179 Mtetra
.645 .747 .923 r
.45961 .57179 .46564 .5774 .47623 .57468 .47022 .56903 Mtetra
.64 .745 .925 r
.47022 .56903 .47623 .57468 .48686 .57211 .48088 .56639 Mtetra
.632 .742 .927 r
.48088 .56639 .48686 .57211 .49754 .56972 .49159 .56394 Mtetra
.623 .737 .929 r
.49159 .56394 .49754 .56972 .50826 .56756 .50234 .56171 Mtetra
.611 .731 .931 r
.50234 .56171 .50826 .56756 .51903 .56569 .51313 .55975 Mtetra
.597 .724 .933 r
.51313 .55975 .51903 .56569 .52985 .56415 .52398 .55811 Mtetra
.58 .715 .935 r
.52398 .55811 .52985 .56415 .54073 .56298 .53488 .55685 Mtetra
.561 .705 .938 r
.53488 .55685 .54073 .56298 .55167 .56223 .54584 .556 Mtetra
.539 .693 .939 r
.54584 .556 .55167 .56223 .56267 .56193 .55687 .5556 Mtetra
.513 .68 .941 r
.55687 .5556 .56267 .56193 .57375 .56212 .56797 .5557 Mtetra
.483 .664 .942 r
.56797 .5557 .57375 .56212 .5849 .56284 .57914 .55637 Mtetra
.446 .645 .943 r
.57914 .55637 .5849 .56284 .59613 .56415 .59039 .55766 Mtetra
.399 .622 .942 r
.59039 .55766 .59613 .56415 .60746 .56614 .60174 .55968 Mtetra
.338 .591 .938 r
.60174 .55968 .60746 .56614 .61889 .5689 .61319 .56255 Mtetra
.255 .549 .928 r
.61319 .56255 .61889 .5689 .63043 .57255 .62476 .5664 Mtetra
.146 .49 .903 r
.62476 .5664 .63043 .57255 .6421 .57722 .63646 .57138 Mtetra
.007 .41 .855 r
.63646 .57138 .6421 .57722 .65392 .583 .64831 .57758 Mtetra
0 .308 .776 r
.64831 .57758 .65392 .583 .66589 .58993 .66033 .58505 Mtetra
0 .198 .669 r
.66033 .58505 .66589 .58993 .67803 .59795 .67252 .5937 Mtetra
.437 0 0 r
.67252 .5937 .67803 .59795 .69034 .60686 .68488 .60331 Mtetra
.521 0 0 r
.68488 .60331 .69034 .60686 .70282 .61629 .69742 .61344 Mtetra
.559 0 0 r
.69742 .61344 .70282 .61629 .71543 .62566 .71009 .62346 Mtetra
.548 0 0 r
.71009 .62346 .71543 .62566 .72814 .63425 .72286 .63259 Mtetra
.476 0 0 r
.72286 .63259 .72814 .63425 .74088 .64123 .73567 .63993 Mtetra
.305 0 0 r
.73567 .63993 .74088 .64123 .75358 .64573 .74843 .64457 Mtetra
.024 .587 .8 r
.74843 .64457 .75358 .64573 .76617 .64698 .76106 .64571 Mtetra
.451 .862 .957 r
.76106 .64571 .76617 .64698 .77857 .64438 .77348 .64277 Mtetra
.74 .955 .944 r
.77348 .64277 .77857 .64438 .79071 .63766 .78564 .63552 Mtetra
.864 .939 .868 r
.78564 .63552 .79071 .63766 .80255 .62687 .7975 .62406 Mtetra
.91 .902 .804 r
.7975 .62406 .80255 .62687 .81408 .61242 .80904 .60888 Mtetra
.927 .87 .763 r
.80904 .60888 .81408 .61242 .82533 .59505 .8203 .59078 Mtetra
.931 .847 .739 r
.8203 .59078 .82533 .59505 .83635 .57568 .83132 .57073 Mtetra
.928 .831 .728 r
.83132 .57073 .83635 .57568 .84721 .55532 .8422 .5498 Mtetra
.922 .82 .727 r
.8422 .5498 .84721 .55532 .85799 .53496 .853 .52897 Mtetra
.913 .813 .734 r
.853 .52897 .85799 .53496 .86879 .51545 .86383 .5091 Mtetra
.9 .808 .748 r
.86383 .5091 .86879 .51545 .87968 .49741 .87476 .49082 Mtetra
.883 .804 .767 r
.87476 .49082 .87968 .49741 .89072 .48128 .88584 .4745 Mtetra
.862 .801 .789 r
.88584 .4745 .89072 .48128 .90196 .46721 .89712 .46033 Mtetra
.836 .796 .813 r
.89712 .46033 .90196 .46721 .91342 .45519 .90862 .44824 Mtetra
.808 .79 .835 r
.90862 .44824 .91342 .45519 .92509 .44506 .92034 .43807 Mtetra
.779 .782 .855 r
.92034 .43807 .92509 .44506 .93698 .43656 .93227 .42954 Mtetra
.752 .774 .871 r
.93227 .42954 .93698 .43656 .94905 .4294 .94439 .42234 Mtetra
.727 .766 .883 r
.94439 .42234 .94905 .4294 .9613 .42326 .95667 .41619 Mtetra
.654 .75 .92 r
.38019 .58682 .38645 .59231 .39678 .58938 .39054 .5839 Mtetra
.654 .751 .921 r
.39054 .5839 .39678 .58938 .40714 .58642 .40093 .58096 Mtetra
.654 .752 .922 r
.40093 .58096 .40714 .58642 .41755 .58346 .41137 .578 Mtetra
.654 .753 .923 r
.41137 .578 .41755 .58346 .42801 .5805 .42185 .57504 Mtetra
.653 .754 .924 r
.42185 .57504 .42801 .5805 .4385 .57756 .43237 .57208 Mtetra
.652 .754 .924 r
.43237 .57208 .4385 .57756 .44903 .57464 .44293 .56914 Mtetra
.65 .753 .925 r
.44293 .56914 .44903 .57464 .45961 .57179 .45353 .56625 Mtetra
.646 .751 .926 r
.45353 .56625 .45961 .57179 .47022 .56903 .46417 .56342 Mtetra
.641 .749 .927 r
.46417 .56342 .47022 .56903 .48088 .56639 .47486 .56072 Mtetra
.635 .745 .928 r
.47486 .56072 .48088 .56639 .49159 .56394 .48559 .55817 Mtetra
.626 .74 .929 r
.48559 .55817 .49159 .56394 .50234 .56171 .49637 .55583 Mtetra
.615 .733 .93 r
.49637 .55583 .50234 .56171 .51313 .55975 .50719 .55374 Mtetra
.603 .725 .931 r
.50719 .55374 .51313 .55975 .52398 .55811 .51806 .55196 Mtetra
.587 .716 .932 r
.51806 .55196 .52398 .55811 .53488 .55685 .52899 .55054 Mtetra
.57 .704 .933 r
.52899 .55054 .53488 .55685 .54584 .556 .53998 .54953 Mtetra
.55 .691 .933 r
.53998 .54953 .54584 .556 .55687 .5556 .55102 .54896 Mtetra
.527 .677 .933 r
.55102 .54896 .55687 .5556 .56797 .5557 .56214 .5489 Mtetra
.5 .659 .932 r
.56214 .5489 .56797 .5557 .57914 .55637 .57333 .5494 Mtetra
.467 .639 .931 r
.57333 .5494 .57914 .55637 .59039 .55766 .5846 .55056 Mtetra
.426 .615 .929 r
.5846 .55056 .59039 .55766 .60174 .55968 .59597 .55248 Mtetra
.373 .585 .925 r
.59597 .55248 .60174 .55968 .61319 .56255 .60743 .55529 Mtetra
.305 .546 .917 r
.60743 .55529 .61319 .56255 .62476 .5664 .61902 .55915 Mtetra
.218 .495 .901 r
.61902 .55915 .62476 .5664 .63646 .57138 .63074 .56419 Mtetra
.112 .431 .873 r
.63074 .56419 .63646 .57138 .64831 .57758 .64261 .57052 Mtetra
0 .357 .83 r
.64261 .57052 .64831 .57758 .66033 .58505 .65464 .57819 Mtetra
0 .28 .775 r
.65464 .57819 .66033 .58505 .67252 .5937 .66686 .58708 Mtetra
0 .215 .722 r
.66686 .58708 .67252 .5937 .68488 .60331 .67925 .59694 Mtetra
0 .179 .688 r
.67925 .59694 .68488 .60331 .69742 .61344 .69181 .60729 Mtetra
0 .186 .69 r
.69181 .60729 .69742 .61344 .71009 .62346 .70451 .61748 Mtetra
0 .249 .739 r
.70451 .61748 .71009 .62346 .72286 .63259 .7173 .62666 Mtetra
0 .374 .832 r
.7173 .62666 .72286 .63259 .73567 .63993 .73012 .63392 Mtetra
.201 .538 .926 r
.73012 .63392 .73567 .63993 .74843 .64457 .74289 .63834 Mtetra
.46 .677 .958 r
.74289 .63834 .74843 .64457 .76106 .64571 .75553 .63913 Mtetra
.65 .748 .922 r
.75553 .63913 .76106 .64571 .77348 .64277 .76797 .63575 Mtetra
.76 .77 .861 r
.76797 .63575 .77348 .64277 .78564 .63552 .78013 .628 Mtetra
.819 .771 .807 r
.78013 .628 .78564 .63552 .7975 .62406 .792 .61607 Mtetra
.851 .766 .767 r
.792 .61607 .7975 .62406 .80904 .60888 .80356 .6005 Mtetra
.869 .761 .741 r
.80356 .6005 .80904 .60888 .8203 .59078 .81484 .58211 Mtetra
.878 .757 .725 r
.81484 .58211 .8203 .59078 .83132 .57073 .82591 .56191 Mtetra
.882 .755 .718 r
.82591 .56191 .83132 .57073 .8422 .5498 .83684 .54095 Mtetra
.882 .756 .719 r
.83684 .54095 .8422 .5498 .853 .52897 .84771 .52022 Mtetra
.878 .758 .726 r
.84771 .52022 .853 .52897 .86383 .5091 .85861 .50052 Mtetra
.87 .761 .74 r
.85861 .50052 .86383 .5091 .87476 .49082 .86961 .48246 Mtetra
.858 .764 .758 r
.86961 .48246 .87476 .49082 .88584 .4745 .88077 .46639 Mtetra
.842 .767 .78 r
.88077 .46639 .88584 .4745 .89712 .46033 .89213 .45244 Mtetra
.821 .769 .804 r
.89213 .45244 .89712 .46033 .90862 .44824 .9037 .44055 Mtetra
.797 .769 .827 r
.9037 .44055 .90862 .44824 .92034 .43807 .91549 .43055 Mtetra
.771 .767 .849 r
.91549 .43055 .92034 .43807 .93227 .42954 .92748 .42214 Mtetra
.746 .763 .866 r
.92748 .42214 .93227 .42954 .94439 .42234 .93965 .41504 Mtetra
.724 .759 .88 r
.93965 .41504 .94439 .42234 .95667 .41619 .95199 .40893 Mtetra
.651 .753 .924 r
.37388 .5814 .38019 .58682 .39054 .5839 .38426 .57852 Mtetra
.651 .755 .926 r
.38426 .57852 .39054 .5839 .40093 .58096 .39467 .57561 Mtetra
.652 .757 .927 r
.39467 .57561 .40093 .58096 .41137 .578 .40513 .57267 Mtetra
.652 .759 .928 r
.40513 .57267 .41137 .578 .42185 .57504 .41564 .56972 Mtetra
.652 .76 .929 r
.41564 .56972 .42185 .57504 .43237 .57208 .42618 .56675 Mtetra
.651 .76 .929 r
.42618 .56675 .43237 .57208 .44293 .56914 .43677 .56378 Mtetra
.65 .76 .93 r
.43677 .56378 .44293 .56914 .45353 .56625 .4474 .56084 Mtetra
.647 .758 .93 r
.4474 .56084 .45353 .56625 .46417 .56342 .45807 .55794 Mtetra
.644 .755 .93 r
.45807 .55794 .46417 .56342 .47486 .56072 .46879 .55514 Mtetra
.638 .751 .93 r
.46879 .55514 .47486 .56072 .48559 .55817 .47955 .55247 Mtetra
.631 .745 .93 r
.47955 .55247 .48559 .55817 .49637 .55583 .49035 .54998 Mtetra
.621 .738 .93 r
.49035 .54998 .49637 .55583 .50719 .55374 .5012 .54772 Mtetra
.61 .729 .93 r
.5012 .54772 .50719 .55374 .51806 .55196 .5121 .54575 Mtetra
.596 .718 .929 r
.5121 .54575 .51806 .55196 .52899 .55054 .52306 .54412 Mtetra
.58 .706 .928 r
.52306 .54412 .52899 .55054 .53998 .54953 .53406 .54287 Mtetra
.563 .692 .927 r
.53406 .54287 .53998 .54953 .55102 .54896 .54513 .54207 Mtetra
.542 .676 .925 r
.54513 .54207 .55102 .54896 .56214 .5489 .55627 .54175 Mtetra
.518 .658 .923 r
.55627 .54175 .56214 .5489 .57333 .5494 .56747 .542 Mtetra
.489 .637 .92 r
.56747 .542 .57333 .5494 .5846 .55056 .57876 .54291 Mtetra
.454 .613 .917 r
.57876 .54291 .5846 .55056 .59597 .55248 .59014 .54459 Mtetra
.41 .583 .912 r
.59014 .54459 .59597 .55248 .60743 .55529 .60162 .54717 Mtetra
.355 .547 .904 r
.60162 .54717 .60743 .55529 .61902 .55915 .61321 .55082 Mtetra
.288 .503 .891 r
.61321 .55082 .61902 .55915 .63074 .56419 .62494 .55567 Mtetra
.211 .452 .873 r
.62494 .55567 .63074 .56419 .64261 .57052 .63681 .56183 Mtetra
.132 .397 .848 r
.63681 .56183 .64261 .57052 .65464 .57819 .64885 .56931 Mtetra
.061 .346 .822 r
.64885 .56931 .65464 .57819 .66686 .58708 .66106 .57802 Mtetra
.015 .31 .8 r
.66106 .57802 .66686 .58708 .67925 .59694 .67344 .58765 Mtetra
.007 .299 .793 r
.67344 .58765 .67925 .59694 .69181 .60729 .68599 .59773 Mtetra
.049 .321 .805 r
.68599 .59773 .69181 .60729 .70451 .61748 .69868 .60756 Mtetra
.144 .376 .83 r
.69868 .60756 .70451 .61748 .7173 .62666 .71145 .61632 Mtetra
.28 .452 .853 r
.71145 .61632 .7173 .62666 .73012 .63392 .72425 .62308 Mtetra
.427 .528 .858 r
.72425 .62308 .73012 .63392 .74289 .63834 .737 .62694 Mtetra
.557 .588 .841 r
.737 .62694 .74289 .63834 .75553 .63913 .74962 .62718 Mtetra
.654 .628 .811 r
.74962 .62718 .75553 .63913 .76797 .63575 .76204 .6233 Mtetra
.722 .652 .78 r
.76204 .6233 .76797 .63575 .78013 .628 .7742 .61517 Mtetra
.767 .667 .752 r
.7742 .61517 .78013 .628 .792 .61607 .78608 .60302 Mtetra
.798 .677 .731 r
.78608 .60302 .792 .61607 .80356 .6005 .79767 .58743 Mtetra
.818 .685 .717 r
.79767 .58743 .80356 .6005 .81484 .58211 .80901 .56923 Mtetra
.831 .691 .709 r
.80901 .56923 .81484 .58211 .82591 .56191 .82015 .54941 Mtetra
.84 .698 .707 r
.82015 .54941 .82591 .56191 .83684 .54095 .83117 .52899 Mtetra
.844 .706 .71 r
.83117 .52899 .83684 .54095 .84771 .52022 .84215 .50889 Mtetra
.844 .714 .719 r
.84215 .50889 .84771 .52022 .85861 .50052 .85316 .48988 Mtetra
.841 .722 .733 r
.85316 .48988 .85861 .50052 .86961 .48246 .86427 .47249 Mtetra
.833 .731 .752 r
.86427 .47249 .86961 .48246 .88077 .46639 .87555 .45704 Mtetra
.821 .739 .774 r
.87555 .45704 .88077 .46639 .89213 .45244 .88701 .44364 Mtetra
.804 .746 .798 r
.88701 .44364 .89213 .45244 .9037 .44055 .89868 .43221 Mtetra
.784 .751 .823 r
.89868 .43221 .9037 .44055 .91549 .43055 .91055 .42255 Mtetra
.762 .753 .845 r
.91055 .42255 .91549 .43055 .92748 .42214 .92262 .41441 Mtetra
.739 .753 .863 r
.92262 .41441 .92748 .42214 .93965 .41504 .93486 .40749 Mtetra
.719 .752 .878 r
.93486 .40749 .93965 .41504 .95199 .40893 .94726 .40151 Mtetra
.647 .759 .931 r
.36752 .57612 .37388 .5814 .38426 .57852 .37791 .57329 Mtetra
.647 .762 .932 r
.37791 .57329 .38426 .57852 .39467 .57561 .38836 .57044 Mtetra
.648 .764 .934 r
.38836 .57044 .39467 .57561 .40513 .57267 .39884 .56755 Mtetra
.649 .767 .935 r
.39884 .56755 .40513 .57267 .41564 .56972 .40937 .56461 Mtetra
.649 .769 .936 r
.40937 .56461 .41564 .56972 .42618 .56675 .41994 .56164 Mtetra
.65 .769 .936 r
.41994 .56164 .42618 .56675 .43677 .56378 .43056 .55865 Mtetra
.43056 .55865 .43677 .56378 .4474 .56084 .44122 .55564 Mtetra
.649 .768 .936 r
.44122 .55564 .4474 .56084 .45807 .55794 .45192 .55266 Mtetra
.646 .765 .935 r
.45192 .55266 .45807 .55794 .46879 .55514 .46267 .54973 Mtetra
.642 .76 .934 r
.46267 .54973 .46879 .55514 .47955 .55247 .47346 .5469 Mtetra
.636 .753 .933 r
.47346 .5469 .47955 .55247 .49035 .54998 .48429 .54423 Mtetra
.628 .745 .931 r
.48429 .54423 .49035 .54998 .5012 .54772 .49517 .54176 Mtetra
.618 .735 .93 r
.49517 .54176 .5012 .54772 .5121 .54575 .5061 .53955 Mtetra
.607 .724 .928 r
.5061 .53955 .5121 .54575 .52306 .54412 .51708 .53764 Mtetra
.593 .71 .925 r
.51708 .53764 .52306 .54412 .53406 .54287 .52811 .53611 Mtetra
.577 .695 .922 r
.52811 .53611 .53406 .54287 .54513 .54207 .5392 .53499 Mtetra
.558 .679 .919 r
.5392 .53499 .54513 .54207 .55627 .54175 .55035 .53434 Mtetra
.537 .66 .915 r
.55035 .53434 .55627 .54175 .56747 .542 .56158 .53425 Mtetra
.512 .639 .911 r
.56158 .53425 .56747 .542 .57876 .54291 .57288 .53479 Mtetra
.482 .614 .905 r
.57288 .53479 .57876 .54291 .59014 .54459 .58426 .53609 Mtetra
.445 .586 .899 r
.58426 .53609 .59014 .54459 .60162 .54717 .59575 .53829 Mtetra
.401 .552 .89 r
.59575 .53829 .60162 .54717 .61321 .55082 .60734 .54152 Mtetra
.351 .513 .878 r
.60734 .54152 .61321 .55082 .62494 .55567 .61906 .54592 Mtetra
.296 .471 .863 r
.61906 .54592 .62494 .55567 .63681 .56183 .63093 .5516 Mtetra
.245 .429 .845 r
.63093 .5516 .63681 .56183 .64885 .56931 .64295 .55856 Mtetra
.206 .393 .827 r
.64295 .55856 .64885 .56931 .66106 .57802 .65513 .56666 Mtetra
.189 .37 .812 r
.65513 .56666 .66106 .57802 .67344 .58765 .66749 .57562 Mtetra
.204 .366 .804 r
.66749 .57562 .67344 .58765 .68599 .59773 .68 .58495 Mtetra
.251 .383 .802 r
.68 .58495 .68599 .59773 .69868 .60756 .69264 .59396 Mtetra
.325 .416 .802 r
.69264 .59396 .69868 .60756 .71145 .61632 .70536 .60185 Mtetra
.415 .459 .798 r
.70536 .60185 .71145 .61632 .72425 .62308 .7181 .60773 Mtetra
.504 .501 .787 r
.7181 .60773 .72425 .62308 .737 .62694 .73079 .61078 Mtetra
.583 .538 .77 r
.73079 .61078 .737 .62694 .74962 .62718 .74337 .61033 Mtetra
.646 .567 .752 r
.74337 .61033 .74962 .62718 .76204 .6233 .75575 .60596 Mtetra
.695 .59 .734 r
.75575 .60596 .76204 .6233 .7742 .61517 .76791 .5976 Mtetra
.732 .608 .719 r
.76791 .5976 .7742 .61517 .78608 .60302 .7798 .58551 Mtetra
.76 .622 .707 r
.7798 .58551 .78608 .60302 .79767 .58743 .79144 .57028 Mtetra
.78 .635 .7 r
.79144 .57028 .79767 .58743 .80901 .56923 .80285 .55274 Mtetra
.795 .646 .697 r
.80285 .55274 .80901 .56923 .82015 .54941 .8141 .5338 Mtetra
.806 .657 .698 r
.8141 .5338 .82015 .54941 .83117 .52899 .82524 .51441 Mtetra
.812 .669 .704 r
.82524 .51441 .83117 .52899 .84215 .50889 .83636 .49543 Mtetra
.815 .68 .715 r
.83636 .49543 .84215 .50889 .85316 .48988 .84751 .47754 Mtetra
.814 .692 .73 r
.84751 .47754 .85316 .48988 .86427 .47249 .85878 .46121 Mtetra
.81 .705 .749 r
.85878 .46121 .86427 .47249 .87555 .45704 .87019 .44671 Mtetra
.801 .716 .772 r
.87019 .44671 .87555 .45704 .88701 .44364 .88178 .43411 Mtetra
.787 .727 .796 r
.88178 .43411 .88701 .44364 .89868 .43221 .89356 .42333 Mtetra
.77 .735 .821 r
.89356 .42333 .89868 .43221 .91055 .42255 .90554 .41418 Mtetra
.751 .741 .843 r
.90554 .41418 .91055 .42255 .92262 .41441 .9177 .40642 Mtetra
.731 .744 .862 r
.9177 .40642 .92262 .41441 .93486 .40749 .93002 .39976 Mtetra
.713 .746 .877 r
.93002 .39976 .93486 .40749 .94726 .40151 .94249 .39395 Mtetra
.64 .766 .939 r
.36109 .57104 .36752 .57612 .37791 .57329 .37151 .56831 Mtetra
.641 .77 .941 r
.37151 .56831 .37791 .57329 .38836 .57044 .38198 .56554 Mtetra
.642 .774 .944 r
.38198 .56554 .38836 .57044 .39884 .56755 .39249 .56271 Mtetra
.644 .778 .945 r
.39249 .56271 .39884 .56755 .40937 .56461 .40304 .55981 Mtetra
.646 .781 .946 r
.40304 .55981 .40937 .56461 .41994 .56164 .41364 .55685 Mtetra
.648 .782 .946 r
.41364 .55685 .41994 .56164 .43056 .55865 .42429 .55383 Mtetra
.649 .782 .945 r
.42429 .55383 .43056 .55865 .44122 .55564 .43498 .55076 Mtetra
.65 .781 .944 r
.43498 .55076 .44122 .55564 .45192 .55266 .44572 .54766 Mtetra
.649 .778 .942 r
.44572 .54766 .45192 .55266 .46267 .54973 .4565 .54459 Mtetra
.647 .772 .94 r
.4565 .54459 .46267 .54973 .47346 .5469 .46732 .54157 Mtetra
.643 .765 .937 r
.46732 .54157 .47346 .5469 .48429 .54423 .47818 .53867 Mtetra
.637 .756 .934 r
.47818 .53867 .48429 .54423 .49517 .54176 .4891 .53593 Mtetra
.629 .745 .931 r
.4891 .53593 .49517 .54176 .5061 .53955 .50005 .53342 Mtetra
.618 .732 .928 r
.50005 .53342 .5061 .53955 .51708 .53764 .51106 .5312 Mtetra
.606 .718 .924 r
.51106 .5312 .51708 .53764 .52811 .53611 .52211 .5293 Mtetra
.592 .702 .919 r
.52211 .5293 .52811 .53611 .5392 .53499 .53323 .5278 Mtetra
.576 .684 .914 r
.53323 .5278 .5392 .53499 .55035 .53434 .5444 .52676 Mtetra
.557 .665 .909 r
.5444 .52676 .55035 .53434 .56158 .53425 .55564 .52623 Mtetra
.535 .643 .903 r
.55564 .52623 .56158 .53425 .57288 .53479 .56695 .52632 Mtetra
.509 .619 .896 r
.56695 .52632 .57288 .53479 .58426 .53609 .57835 .52713 Mtetra
.479 .591 .888 r
.57835 .52713 .58426 .53609 .59575 .53829 .58983 .52878 Mtetra
.444 .56 .878 r
.58983 .52878 .59575 .53829 .60734 .54152 .60142 .53142 Mtetra
.405 .525 .866 r
.60142 .53142 .60734 .54152 .61906 .54592 .61313 .53516 Mtetra
.366 .489 .851 r
.61313 .53516 .61906 .54592 .63093 .5516 .62498 .54009 Mtetra
.333 .454 .834 r
.62498 .54009 .63093 .5516 .64295 .55856 .63697 .5462 Mtetra
.311 .426 .817 r
.63697 .5462 .64295 .55856 .65513 .56666 .64911 .55336 Mtetra
.307 .408 .802 r
.64911 .55336 .65513 .56666 .66749 .57562 .66142 .56126 Mtetra
.326 .404 .789 r
.66142 .56126 .66749 .57562 .68 .58495 .67386 .56943 Mtetra
.364 .413 .779 r
.67386 .56943 .68 .58495 .69264 .59396 .68643 .57724 Mtetra
.418 .433 .769 r
.68643 .57724 .69264 .59396 .70536 .60185 .69907 .58391 Mtetra
.479 .459 .758 r
.69907 .58391 .70536 .60185 .7181 .60773 .71173 .58866 Mtetra
.539 .487 .746 r
.71173 .58866 .7181 .60773 .73079 .61078 .72435 .59072 Mtetra
.594 .513 .733 r
.72435 .59072 .73079 .61078 .74337 .61033 .73686 .58952 Mtetra
.64 .536 .72 r
.73686 .58952 .74337 .61033 .75575 .60596 .74921 .58472 Mtetra
.678 .556 .709 r
.74921 .58472 .75575 .60596 .76791 .5976 .76135 .5763 Mtetra
.709 .573 .7 r
.76135 .5763 .76791 .5976 .7798 .58551 .77326 .56455 Mtetra
.733 .588 .693 r
.77326 .56455 .7798 .58551 .79144 .57028 .78496 .55004 Mtetra
.752 .602 .69 r
.78496 .55004 .79144 .57028 .80285 .55274 .79647 .53353 Mtetra
.767 .615 .69 r
.79647 .53353 .80285 .55274 .8141 .5338 .80784 .51588 Mtetra
.778 .629 .694 r
.80784 .51588 .8141 .5338 .82524 .51441 .81913 .49794 Mtetra
.786 .642 .702 r
.81913 .49794 .82524 .51441 .83636 .49543 .83041 .48044 Mtetra
.791 .656 .714 r
.83041 .48044 .83636 .49543 .84751 .47754 .84173 .464 Mtetra
.792 .671 .73 r
.84173 .464 .84751 .47754 .85878 .46121 .85316 .449 Mtetra
.789 .685 .75 r
.85316 .449 .85878 .46121 .87019 .44671 .86473 .43568 Mtetra
.782 .7 .773 r
.86473 .43568 .87019 .44671 .88178 .43411 .87647 .42407 Mtetra
.771 .713 .798 r
.87647 .42407 .88178 .43411 .89356 .42333 .88838 .41408 Mtetra
.756 .724 .822 r
.88838 .41408 .89356 .42333 .90554 .41418 .90047 .40555 Mtetra
.74 .732 .844 r
.90047 .40555 .90554 .41418 .9177 .40642 .91272 .39823 Mtetra
.723 .738 .863 r
.91272 .39823 .9177 .40642 .93002 .39976 .92513 .39188 Mtetra
.707 .741 .878 r
.92513 .39188 .93002 .39976 .94249 .39395 .93766 .38628 Mtetra
.631 .775 .95 r
.3546 .56625 .36109 .57104 .37151 .56831 .36504 .56365 Mtetra
.631 .781 .953 r
.36504 .56365 .37151 .56831 .38198 .56554 .37553 .56099 Mtetra
.633 .787 .956 r
.37553 .56099 .38198 .56554 .39249 .56271 .38606 .55826 Mtetra
.636 .792 .957 r
.38606 .55826 .39249 .56271 .40304 .55981 .39665 .55542 Mtetra
.639 .796 .958 r
.39665 .55542 .40304 .55981 .41364 .55685 .40728 .55248 Mtetra
.643 .799 .957 r
.40728 .55248 .41364 .55685 .42429 .55383 .41795 .54944 Mtetra
.648 .8 .956 r
.41795 .54944 .42429 .55383 .43498 .55076 .42868 .54629 Mtetra
.651 .799 .954 r
.42868 .54629 .43498 .55076 .44572 .54766 .43945 .54307 Mtetra
.653 .795 .951 r
.43945 .54307 .44572 .54766 .4565 .54459 .45026 .53981 Mtetra
.653 .789 .947 r
.45026 .53981 .4565 .54459 .46732 .54157 .46112 .53657 Mtetra
.651 .781 .943 r
.46112 .53657 .46732 .54157 .47818 .53867 .47202 .53339 Mtetra
.647 .77 .938 r
.47202 .53339 .47818 .53867 .4891 .53593 .48297 .53034 Mtetra
.64 .758 .934 r
.48297 .53034 .4891 .53593 .50005 .53342 .49396 .52747 Mtetra
.632 .744 .929 r
.49396 .52747 .50005 .53342 .51106 .5312 .50499 .52486 Mtetra
.621 .728 .923 r
.50499 .52486 .51106 .5312 .52211 .5293 .51607 .52256 Mtetra
.608 .711 .917 r
.51607 .52256 .52211 .5293 .53323 .5278 .52721 .52062 Mtetra
.594 .693 .911 r
.52721 .52062 .53323 .5278 .5444 .52676 .53841 .5191 Mtetra
.577 .673 .904 r
.53841 .5191 .5444 .52676 .55564 .52623 .54966 .51808 Mtetra
.558 .651 .897 r
.54966 .51808 .55564 .52623 .56695 .52632 .56099 .51763 Mtetra
.536 .627 .889 r
.56099 .51763 .56695 .52632 .57835 .52713 .57239 .51784 Mtetra
.51 .6 .88 r
.57239 .51784 .57835 .52713 .58983 .52878 .58388 .51885 Mtetra
.482 .571 .869 r
.58388 .51885 .58983 .52878 .60142 .53142 .59546 .52075 Mtetra
.452 .539 .856 r
.59546 .52075 .60142 .53142 .61313 .53516 .60716 .52366 Mtetra
.423 .507 .84 r
.60716 .52366 .61313 .53516 .62498 .54009 .61898 .52764 Mtetra
.4 .477 .824 r
.61898 .52764 .62498 .54009 .63697 .5462 .63093 .53266 Mtetra
.387 .452 .806 r
.63093 .53266 .63697 .5462 .64911 .55336 .64302 .53859 Mtetra
.388 .436 .789 r
.64302 .53859 .64911 .55336 .66142 .56126 .65526 .54514 Mtetra
.404 .43 .774 r
.65526 .54514 .66142 .56126 .67386 .56943 .66763 .55188 Mtetra
.434 .434 .76 r
.66763 .55188 .67386 .56943 .68643 .57724 .6801 .55822 Mtetra
.473 .446 .747 r
.6801 .55822 .68643 .57724 .69907 .58391 .69265 .56346 Mtetra
.517 .462 .735 r
.69265 .56346 .69907 .58391 .71173 .58866 .70521 .56691 Mtetra
.56 .481 .723 r
.70521 .56691 .71173 .58866 .72435 .59072 .71775 .56791 Mtetra
.601 .501 .712 r
.71775 .56791 .72435 .59072 .73686 .58952 .73019 .56598 Mtetra
.637 .519 .703 r
.73019 .56598 .73686 .58952 .74921 .58472 .74249 .56085 Mtetra
.668 .536 .695 r
.74249 .56085 .74921 .58472 .76135 .5763 .75462 .55255 Mtetra
.693 .552 .69 r
.75462 .55255 .76135 .5763 .77326 .56455 .76657 .54138 Mtetra
.715 .567 .687 r
.76657 .54138 .77326 .56455 .78496 .55004 .77834 .52786 Mtetra
.732 .581 .686 r
.77834 .52786 .78496 .55004 .79647 .53353 .78995 .51269 Mtetra
.746 .595 .689 r
.78995 .51269 .79647 .53353 .80784 .51588 .80146 .49661 Mtetra
.757 .61 .694 r
.80146 .49661 .80784 .51588 .81913 .49794 .81291 .48037 Mtetra
.765 .624 .704 r
.81291 .48037 .81913 .49794 .83041 .48044 .82436 .4646 Mtetra
.77 .64 .717 r
.82436 .4646 .83041 .48044 .84173 .464 .83587 .4498 Mtetra
.772 .656 .734 r
.83587 .4498 .84173 .464 .85316 .449 .84748 .43631 Mtetra
.77 .672 .755 r
.84748 .43631 .85316 .449 .86473 .43568 .85922 .42428 Mtetra
.765 .688 .778 r
.85922 .42428 .86473 .43568 .87647 .42407 .8711 .41376 Mtetra
.756 .703 .802 r
.8711 .41376 .87647 .42407 .88838 .41408 .88315 .40464 Mtetra
.743 .716 .826 r
.88315 .40464 .88838 .41408 .90047 .40555 .89536 .39676 Mtetra
.729 .726 .848 r
.89536 .39676 .90047 .40555 .91272 .39823 .90771 .38993 Mtetra
.714 .733 .866 r
.90771 .38993 .91272 .39823 .92513 .39188 .9202 .38392 Mtetra
.701 .737 .88 r
.9202 .38392 .92513 .39188 .93766 .38628 .9328 .37853 Mtetra
.615 .787 .964 r
.34804 .56182 .3546 .56625 .36504 .56365 .3585 .5594 Mtetra
.615 .795 .968 r
.3585 .5594 .36504 .56365 .37553 .56099 .36901 .55691 Mtetra
.618 .803 .971 r
.36901 .55691 .37553 .56099 .38606 .55826 .37956 .55431 Mtetra
.622 .81 .972 r
.37956 .55431 .38606 .55826 .39665 .55542 .39017 .55157 Mtetra
.628 .816 .973 r
.39017 .55157 .39665 .55542 .40728 .55248 .40084 .54866 Mtetra
.636 .82 .971 r
.40084 .54866 .40728 .55248 .41795 .54944 .41155 .54559 Mtetra
.643 .822 .969 r
.41155 .54559 .41795 .54944 .42868 .54629 .42231 .54236 Mtetra
.651 .821 .965 r
.42231 .54236 .42868 .54629 .43945 .54307 .43312 .53898 Mtetra
.656 .817 .961 r
.43312 .53898 .43945 .54307 .45026 .53981 .44397 .53551 Mtetra
.66 .81 .955 r
.44397 .53551 .45026 .53981 .46112 .53657 .45487 .53199 Mtetra
.661 .801 .95 r
.45487 .53199 .46112 .53657 .47202 .53339 .4658 .52848 Mtetra
.659 .789 .944 r
.4658 .52848 .47202 .53339 .48297 .53034 .47679 .52505 Mtetra
.654 .775 .937 r
.47679 .52505 .48297 .53034 .49396 .52747 .48781 .52178 Mtetra
.647 .759 .931 r
.48781 .52178 .49396 .52747 .50499 .52486 .49888 .51872 Mtetra
.637 .742 .924 r
.49888 .51872 .50499 .52486 .51607 .52256 .50999 .51595 Mtetra
.626 .723 .917 r
.50999 .51595 .51607 .52256 .52721 .52062 .52115 .51351 Mtetra
.613 .704 .909 r
.52115 .51351 .52721 .52062 .53841 .5191 .53237 .51147 Mtetra
.598 .683 .901 r
.53237 .51147 .53841 .5191 .54966 .51808 .54365 .50989 Mtetra
.58 .661 .893 r
.54365 .50989 .54966 .51808 .56099 .51763 .55498 .50884 Mtetra
.561 .638 .884 r
.55498 .50884 .56099 .51763 .57239 .51784 .56639 .50841 Mtetra
.539 .612 .874 r
.56639 .50841 .57239 .51784 .58388 .51885 .57788 .50868 Mtetra
.516 .584 .862 r
.57788 .50868 .58388 .51885 .59546 .52075 .58946 .50975 Mtetra
.492 .555 .849 r
.58946 .50975 .59546 .52075 .60716 .52366 .60114 .51171 Mtetra
.47 .526 .833 r
.60114 .51171 .60716 .52366 .61898 .52764 .61293 .5146 Mtetra
.453 .499 .816 r
.61293 .5146 .61898 .52764 .63093 .53266 .62485 .51839 Mtetra
.444 .476 .798 r
.62485 .51839 .63093 .53266 .64302 .53859 .63689 .52293 Mtetra
.445 .46 .78 r
.63689 .52293 .64302 .53859 .65526 .54514 .64905 .52798 Mtetra
.458 .452 .764 r
.64905 .52798 .65526 .54514 .66763 .55188 .66134 .53313 Mtetra
.48 .452 .749 r
.66134 .53313 .66763 .55188 .6801 .55822 .67372 .53786 Mtetra
.509 .458 .735 r
.67372 .53786 .6801 .55822 .69265 .56346 .68616 .54158 Mtetra
.542 .469 .723 r
.68616 .54158 .69265 .56346 .70521 .56691 .69863 .54369 Mtetra
.575 .482 .712 r
.69863 .54369 .70521 .56691 .71775 .56791 .71107 .54364 Mtetra
.607 .497 .703 r
.71107 .54364 .71775 .56791 .73019 .56598 .72345 .54104 Mtetra
.635 .512 .695 r
.72345 .54104 .73019 .56598 .74249 .56085 .73571 .53571 Mtetra
.661 .527 .69 r
.73571 .53571 .74249 .56085 .75462 .55255 .74784 .5277 Mtetra
.683 .541 .686 r
.74784 .5277 .75462 .55255 .76657 .54138 .75982 .51728 Mtetra
.701 .555 .685 r
.75982 .51728 .76657 .54138 .77834 .52786 .77166 .50494 Mtetra
.717 .569 .687 r
.77166 .50494 .77834 .52786 .78995 .51269 .78339 .49127 Mtetra
.73 .583 .691 r
.78339 .49127 .78995 .51269 .80146 .49661 .79504 .47692 Mtetra
.74 .598 .699 r
.79504 .47692 .80146 .49661 .81291 .48037 .80666 .4625 Mtetra
.748 .614 .709 r
.80666 .4625 .81291 .48037 .82436 .4646 .81829 .44855 Mtetra
.753 .63 .724 r
.81829 .44855 .82436 .4646 .83587 .4498 .82998 .43547 Mtetra
.755 .648 .742 r
.82998 .43547 .83587 .4498 .84748 .43631 .84177 .42353 Mtetra
.754 .665 .763 r
.84177 .42353 .84748 .43631 .85922 .42428 .85367 .41284 Mtetra
.75 .682 .786 r
.85367 .41284 .85922 .42428 .8711 .41376 .86571 .40341 Mtetra
.742 .698 .81 r
.86571 .40341 .8711 .41376 .88315 .40464 .87789 .39516 Mtetra
.731 .712 .833 r
.87789 .39516 .88315 .40464 .89536 .39676 .89021 .38795 Mtetra
.718 .723 .853 r
.89021 .38795 .89536 .39676 .90771 .38993 .90266 .38159 Mtetra
.706 .73 .87 r
.90266 .38159 .90771 .38993 .9202 .38392 .91523 .37591 Mtetra
.694 .736 .882 r
.91523 .37591 .9202 .38392 .9328 .37853 .92791 .37075 Mtetra
.59 .8 .98 r
.3414 .55786 .34804 .56182 .3585 .5594 .35187 .55568 Mtetra
.59 .811 .984 r
.35187 .55568 .3585 .5594 .36901 .55691 .3624 .55341 Mtetra
.593 .821 .987 r
.3624 .55341 .36901 .55691 .37956 .55431 .37298 .55098 Mtetra
.599 .831 .988 r
.37298 .55098 .37956 .55431 .39017 .55157 .38362 .54836 Mtetra
.609 .839 .987 r
.38362 .54836 .39017 .55157 .40084 .54866 .39431 .5455 Mtetra
.622 .845 .985 r
.39431 .5455 .40084 .54866 .41155 .54559 .40506 .54241 Mtetra
.635 .848 .981 r
.40506 .54241 .41155 .54559 .42231 .54236 .41586 .53907 Mtetra
.648 .848 .977 r
.41586 .53907 .42231 .54236 .43312 .53898 .42671 .53551 Mtetra
.659 .843 .971 r
.42671 .53551 .43312 .53898 .44397 .53551 .4376 .53178 Mtetra
.667 .836 .964 r
.4376 .53178 .44397 .53551 .45487 .53199 .44854 .52793 Mtetra
.672 .825 .957 r
.44854 .52793 .45487 .53199 .4658 .52848 .45952 .52404 Mtetra
.673 .811 .949 r
.45952 .52404 .4658 .52848 .47679 .52505 .47055 .52018 Mtetra
.67 .795 .941 r
.47055 .52018 .47679 .52505 .48781 .52178 .48161 .51643 Mtetra
.664 .777 .933 r
.48161 .51643 .48781 .52178 .49888 .51872 .49271 .51287 Mtetra
.655 .758 .925 r
.49271 .51287 .49888 .51872 .50999 .51595 .50386 .50956 Mtetra
.645 .738 .917 r
.50386 .50956 .50999 .51595 .52115 .51351 .51505 .50658 Mtetra
.632 .717 .909 r
.51505 .50658 .52115 .51351 .53237 .51147 .52629 .50397 Mtetra
.618 .696 .9 r
.52629 .50397 .53237 .51147 .54365 .50989 .53759 .50179 Mtetra
.602 .674 .891 r
.53759 .50179 .54365 .50989 .55498 .50884 .54895 .5001 Mtetra
.585 .651 .881 r
.54895 .5001 .55498 .50884 .56639 .50841 .56037 .49897 Mtetra
.566 .626 .871 r
.56037 .49897 .56639 .50841 .57788 .50868 .57186 .49847 Mtetra
.546 .6 .859 r
.57186 .49847 .57788 .50868 .58946 .50975 .58344 .49867 Mtetra
.527 .573 .845 r
.58344 .49867 .58946 .50975 .60114 .51171 .5951 .49964 Mtetra
.509 .546 .829 r
.5951 .49964 .60114 .51171 .61293 .5146 .60687 .50138 Mtetra
.495 .52 .812 r
.60687 .50138 .61293 .5146 .62485 .51839 .61874 .50387 Mtetra
.488 .499 .795 r
.61874 .50387 .62485 .51839 .63689 .52293 .63073 .50698 Mtetra
.489 .482 .777 r
.63073 .50698 .63689 .52293 .64905 .52798 .64282 .51046 Mtetra
.498 .473 .76 r
.64282 .51046 .64905 .52798 .66134 .53313 .65503 .51398 Mtetra
.514 .469 .744 r
.65503 .51398 .66134 .53313 .67372 .53786 .66732 .51711 Mtetra
.536 .472 .731 r
.66732 .51711 .67372 .53786 .68616 .54158 .67966 .51933 Mtetra
.561 .478 .719 r
.67966 .51933 .68616 .54158 .69863 .54369 .69204 .52015 Mtetra
.587 .488 .709 r
.69204 .52015 .69863 .54369 .71107 .54364 .7044 .51914 Mtetra
.612 .499 .7 r
.7044 .51914 .71107 .54364 .72345 .54104 .71671 .51599 Mtetra
.635 .511 .694 r
.71671 .51599 .72345 .54104 .73571 .53571 .72894 .51057 Mtetra
.657 .524 .69 r
.72894 .51057 .73571 .53571 .74784 .5277 .74107 .50296 Mtetra
.675 .537 .688 r
.74107 .50296 .74784 .5277 .75982 .51728 .7531 .49341 Mtetra
.692 .55 .689 r
.7531 .49341 .75982 .51728 .77166 .50494 .76502 .48233 Mtetra
.706 .564 .692 r
.76502 .48233 .77166 .50494 .78339 .49127 .77686 .47022 Mtetra
.718 .578 .698 r
.77686 .47022 .78339 .49127 .79504 .47692 .78865 .45762 Mtetra
.727 .594 .707 r
.78865 .45762 .79504 .47692 .80666 .4625 .80044 .44503 Mtetra
.735 .61 .719 r
.80044 .44503 .80666 .4625 .81829 .44855 .81224 .43287 Mtetra
.739 .627 .734 r
.81224 .43287 .81829 .44855 .82998 .43547 .82411 .42147 Mtetra
.741 .645 .753 r
.82411 .42147 .82998 .43547 .84177 .42353 .83606 .41101 Mtetra
.74 .663 .774 r
.83606 .41101 .84177 .42353 .85367 .41284 .84812 .4016 Mtetra
.736 .681 .797 r
.84812 .4016 .85367 .41284 .86571 .40341 .8603 .39322 Mtetra
.729 .697 .82 r
.8603 .39322 .86571 .40341 .87789 .39516 .87261 .38579 Mtetra
.719 .711 .841 r
.87261 .38579 .87789 .39516 .89021 .38795 .88504 .3792 Mtetra
.709 .722 .86 r
.88504 .3792 .89021 .38795 .90266 .38159 .89758 .37329 Mtetra
.698 .73 .875 r
.89758 .37329 .90266 .38159 .91523 .37591 .91023 .36791 Mtetra
.689 .735 .886 r
.91023 .36791 .91523 .37591 .92791 .37075 .92298 .36294 Mtetra
.55 .812 .994 r
.33466 .55445 .3414 .55786 .35187 .55568 .34515 .55259 Mtetra
.548 .824 .997 r
.34515 .55259 .35187 .55568 .3624 .55341 .3557 .55058 Mtetra
.551 .837 .998 r
.3557 .55058 .3624 .55341 .37298 .55098 .3663 .54837 Mtetra
.561 .849 .997 r
.3663 .54837 .37298 .55098 .38362 .54836 .37697 .5459 Mtetra
.577 .86 .996 r
.37697 .5459 .38362 .54836 .39431 .5455 .38769 .54311 Mtetra
.597 .869 .993 r
.38769 .54311 .39431 .5455 .40506 .54241 .39848 .53999 Mtetra
.619 .875 .99 r
.39848 .53999 .40506 .54241 .41586 .53907 .40932 .53653 Mtetra
.641 .876 .985 r
.40932 .53653 .41586 .53907 .42671 .53551 .42022 .53276 Mtetra
.66 .873 .979 r
.42022 .53276 .42671 .53551 .4376 .53178 .43116 .52872 Mtetra
.675 .865 .971 r
.43116 .52872 .4376 .53178 .44854 .52793 .44215 .52448 Mtetra
.684 .852 .963 r
.44215 .52448 .44854 .52793 .45952 .52404 .45318 .52013 Mtetra
.688 .836 .954 r
.45318 .52013 .45952 .52404 .47055 .52018 .46425 .51577 Mtetra
.687 .818 .945 r
.46425 .51577 .47055 .52018 .48161 .51643 .47535 .51148 Mtetra
.683 .798 .936 r
.47535 .51148 .48161 .51643 .49271 .51287 .4865 .50735 Mtetra
.675 .776 .927 r
.4865 .50735 .49271 .51287 .50386 .50956 .49768 .50346 Mtetra
.664 .755 .918 r
.49768 .50346 .50386 .50956 .51505 .50658 .50891 .49988 Mtetra
.652 .733 .909 r
.50891 .49988 .51505 .50658 .52629 .50397 .52018 .49667 Mtetra
.638 .711 .9 r
.52018 .49667 .52629 .50397 .53759 .50179 .5315 .49386 Mtetra
.623 .688 .89 r
.5315 .49386 .53759 .50179 .54895 .5001 .54287 .49152 Mtetra
.608 .666 .88 r
.54287 .49152 .54895 .5001 .56037 .49897 .5543 .48968 Mtetra
.591 .642 .87 r
.5543 .48968 .56037 .49897 .57186 .49847 .56581 .4884 Mtetra
.574 .617 .858 r
.56581 .4884 .57186 .49847 .58344 .49867 .57738 .48773 Mtetra
.557 .592 .844 r
.57738 .48773 .58344 .49867 .5951 .49964 .58904 .4877 Mtetra
.542 .567 .829 r
.58904 .4877 .5951 .49964 .60687 .50138 .60078 .48832 Mtetra
.53 .543 .813 r
.60078 .48832 .60687 .50138 .61874 .50387 .61262 .48954 Mtetra
.524 .522 .796 r
.61262 .48954 .61874 .50387 .63073 .50698 .62456 .49124 Mtetra
.524 .506 .778 r
.62456 .49124 .63073 .50698 .64282 .51046 .6366 .49322 Mtetra
.53 .494 .761 r
.6366 .49322 .64282 .51046 .65503 .51398 .64873 .49519 Mtetra
.542 .489 .746 r
.64873 .49519 .65503 .51398 .66732 .51711 .66093 .4968 Mtetra
.558 .488 .732 r
.66093 .4968 .66732 .51711 .67966 .51933 .6732 .49763 Mtetra
.577 .491 .721 r
.6732 .49763 .67966 .51933 .69204 .52015 .68549 .49729 Mtetra
.597 .497 .711 r
.68549 .49729 .69204 .52015 .7044 .51914 .69778 .49545 Mtetra
.618 .506 .704 r
.69778 .49545 .7044 .51914 .71671 .51599 .71004 .49187 Mtetra
.637 .516 .699 r
.71004 .49187 .71671 .51599 .72894 .51057 .72225 .48648 Mtetra
.655 .527 .696 r
.72225 .48648 .72894 .51057 .74107 .50296 .7344 .47934 Mtetra
.671 .539 .695 r
.7344 .47934 .74107 .50296 .7531 .49341 .74646 .47069 Mtetra
.685 .551 .697 r
.74646 .47069 .7531 .49341 .76502 .48233 .75846 .46086 Mtetra
.698 .565 .701 r
.75846 .46086 .76502 .48233 .77686 .47022 .77042 .45027 Mtetra
.708 .579 .708 r
.77042 .45027 .77686 .47022 .78865 .45762 .78235 .43934 Mtetra
.717 .595 .719 r
.78235 .43934 .78865 .45762 .80044 .44503 .79428 .42846 Mtetra
.723 .612 .732 r
.79428 .42846 .80044 .44503 .81224 .43287 .80625 .41797 Mtetra
.728 .629 .749 r
.80625 .41797 .81224 .43287 .82411 .42147 .81827 .4081 Mtetra
.729 .648 .768 r
.81827 .4081 .82411 .42147 .83606 .41101 .83038 .39901 Mtetra
.728 .666 .789 r
.83038 .39901 .83606 .41101 .84812 .4016 .84259 .39075 Mtetra
.724 .683 .811 r
.84259 .39075 .84812 .4016 .8603 .39322 .8549 .38331 Mtetra
.717 .699 .832 r
.8549 .38331 .8603 .39322 .87261 .38579 .86732 .37662 Mtetra
.709 .712 .851 r
.86732 .37662 .87261 .38579 .88504 .3792 .87985 .37057 Mtetra
.7 .723 .868 r
.87985 .37057 .88504 .3792 .89758 .37329 .89248 .36505 Mtetra
.691 .73 .881 r
.89248 .36505 .89758 .37329 .91023 .36791 .90521 .35995 Mtetra
.684 .735 .89 r
.90521 .35995 .91023 .36791 .92298 .36294 .91802 .35515 Mtetra
.486 .815 1 r
.32783 .55168 .33466 .55445 .34515 .55259 .33833 .55019 Mtetra
.479 .827 .997 r
.33833 .55019 .34515 .55259 .3557 .55058 .34889 .54852 Mtetra
.483 .841 .994 r
.34889 .54852 .3557 .55058 .3663 .54837 .35952 .54658 Mtetra
.498 .856 .99 r
.35952 .54658 .3663 .54837 .37697 .5459 .37021 .54429 Mtetra
.523 .872 .989 r
.37021 .54429 .37697 .5459 .38769 .54311 .38097 .54158 Mtetra
.556 .887 .988 r
.38097 .54158 .38769 .54311 .39848 .53999 .3918 .53842 Mtetra
.593 .898 .987 r
.3918 .53842 .39848 .53999 .40932 .53653 .40269 .53481 Mtetra
.629 .904 .985 r
.40269 .53481 .40932 .53653 .42022 .53276 .41364 .53078 Mtetra
.659 .902 .98 r
.41364 .53078 .42022 .53276 .43116 .52872 .42463 .52637 Mtetra
.682 .894 .974 r
.42463 .52637 .43116 .52872 .44215 .52448 .43568 .52169 Mtetra
.698 .881 .966 r
.43568 .52169 .44215 .52448 .45318 .52013 .44676 .51682 Mtetra
.706 .863 .957 r
.44676 .51682 .45318 .52013 .46425 .51577 .45788 .51188 Mtetra
.707 .842 .947 r
.45788 .51188 .46425 .51577 .47535 .51148 .46904 .50698 Mtetra
.703 .819 .937 r
.46904 .50698 .47535 .51148 .4865 .50735 .48022 .50222 Mtetra
.695 .796 .927 r
.48022 .50222 .4865 .50735 .49768 .50346 .49145 .4977 Mtetra
.685 .773 .918 r
.49145 .4977 .49768 .50346 .50891 .49988 .50271 .49348 Mtetra
.672 .75 .909 r
.50271 .49348 .50891 .49988 .52018 .49667 .51401 .48962 Mtetra
.658 .727 .9 r
.51401 .48962 .52018 .49667 .5315 .49386 .52536 .48618 Mtetra
.644 .704 .89 r
.52536 .48618 .5315 .49386 .54287 .49152 .53676 .48317 Mtetra
.629 .682 .881 r
.53676 .48317 .54287 .49152 .5543 .48968 .54821 .48063 Mtetra
.613 .659 .871 r
.54821 .48063 .5543 .48968 .56581 .4884 .55972 .4786 Mtetra
.598 .636 .859 r
.55972 .4786 .56581 .4884 .57738 .48773 .5713 .47709 Mtetra
.583 .612 .847 r
.5713 .47709 .57738 .48773 .58904 .4877 .58295 .47613 Mtetra
.57 .589 .832 r
.58295 .47613 .58904 .4877 .60078 .48832 .59468 .47569 Mtetra
.56 .566 .817 r
.59468 .47569 .60078 .48832 .61262 .48954 .6065 .47572 Mtetra
.554 .546 .8 r
.6065 .47572 .61262 .48954 .62456 .49124 .6184 .47613 Mtetra
.553 .53 .784 r
.6184 .47613 .62456 .49124 .6366 .49322 .63039 .47674 Mtetra
.556 .518 .768 r
.63039 .47674 .6366 .49322 .64873 .49519 .64246 .47732 Mtetra
.565 .51 .753 r
.64246 .47732 .64873 .49519 .66093 .4968 .6546 .47757 Mtetra
.577 .507 .74 r
.6546 .47757 .66093 .4968 .6732 .49763 .66679 .47719 Mtetra
.591 .507 .728 r
.66679 .47719 .6732 .49763 .68549 .49729 .67902 .47586 Mtetra
.607 .511 .719 r
.67902 .47586 .68549 .49729 .69778 .49545 .69126 .47334 Mtetra
.624 .517 .713 r
.69126 .47334 .69778 .49545 .71004 .49187 .70348 .46945 Mtetra
.639 .525 .708 r
.70348 .46945 .71004 .49187 .72225 .48648 .71568 .46416 Mtetra
.655 .535 .706 r
.71568 .46416 .72225 .48648 .7344 .47934 .72784 .45753 Mtetra
.668 .546 .706 r
.72784 .45753 .7344 .47934 .74646 .47069 .73995 .44976 Mtetra
.681 .558 .709 r
.73995 .44976 .74646 .47069 .75846 .46086 .75203 .44111 Mtetra
.692 .571 .715 r
.75203 .44111 .75846 .46086 .77042 .45027 .76409 .4319 Mtetra
.701 .586 .723 r
.76409 .4319 .77042 .45027 .78235 .43934 .77614 .42247 Mtetra
.709 .602 .735 r
.77614 .42247 .78235 .43934 .79428 .42846 .78821 .41313 Mtetra
.714 .619 .749 r
.78821 .41313 .79428 .42846 .80625 .41797 .80032 .4041 Mtetra
.718 .637 .766 r
.80032 .4041 .80625 .41797 .81827 .4081 .8125 .39559 Mtetra
.719 .655 .785 r
.8125 .39559 .81827 .4081 .83038 .39901 .82474 .38768 Mtetra
.717 .673 .806 r
.82474 .38768 .83038 .39901 .84259 .39075 .83708 .38041 Mtetra
.713 .689 .826 r
.83708 .38041 .84259 .39075 .8549 .38331 .84951 .37377 Mtetra
.707 .704 .845 r
.84951 .37377 .8549 .38331 .86732 .37662 .86203 .3677 Mtetra
.7 .716 .862 r
.86203 .3677 .86732 .37662 .87985 .37057 .87465 .36212 Mtetra
.692 .726 .876 r
.87465 .36212 .87985 .37057 .89248 .36505 .88736 .35692 Mtetra
.685 .732 .886 r
.88736 .35692 .89248 .36505 .90521 .35995 .90016 .35203 Mtetra
.679 .737 .894 r
.90016 .35203 .90521 .35995 .91802 .35515 .91303 .34737 Mtetra
.385 .796 .98 r
.32089 .5496 .32783 .55168 .33833 .55019 .33139 .54856 Mtetra
.373 .804 .966 r
.33139 .54856 .33833 .55019 .34889 .54852 .34197 .54728 Mtetra
.378 .817 .955 r
.34197 .54728 .34889 .54852 .35952 .54658 .35262 .54565 Mtetra
.402 .837 .95 r
.35262 .54565 .35952 .54658 .37021 .54429 .36335 .54356 Mtetra
.443 .861 .951 r
.36335 .54356 .37021 .54429 .38097 .54158 .37415 .54094 Mtetra
.496 .887 .958 r
.37415 .54094 .38097 .54158 .3918 .53842 .38502 .53773 Mtetra
.554 .909 .965 r
.38502 .53773 .3918 .53842 .40269 .53481 .39596 .53394 Mtetra
.609 .924 .971 r
.39596 .53394 .40269 .53481 .41364 .53078 .40696 .5296 Mtetra
.655 .928 .973 r
.40696 .5296 .41364 .53078 .42463 .52637 .41802 .52477 Mtetra
.69 .922 .97 r
.41802 .52477 .42463 .52637 .43568 .52169 .42912 .51956 Mtetra
.713 .908 .964 r
.42912 .51956 .43568 .52169 .44676 .51682 .44027 .51409 Mtetra
.725 .889 .955 r
.44027 .51409 .44676 .51682 .45788 .51188 .45144 .50851 Mtetra
.728 .866 .946 r
.45144 .50851 .45788 .51188 .46904 .50698 .46265 .50293 Mtetra
.725 .841 .936 r
.46265 .50293 .46904 .50698 .48022 .50222 .47389 .49748 Mtetra
.717 .816 .926 r
.47389 .49748 .48022 .50222 .49145 .4977 .48516 .49227 Mtetra
.706 .791 .917 r
.48516 .49227 .49145 .4977 .50271 .49348 .49647 .48738 Mtetra
.693 .766 .908 r
.49647 .48738 .50271 .49348 .51401 .48962 .5078 .48287 Mtetra
.678 .743 .9 r
.5078 .48287 .51401 .48962 .52536 .48618 .51918 .47877 Mtetra
.664 .72 .891 r
.51918 .47877 .52536 .48618 .53676 .48317 .5306 .47511 Mtetra
.649 .698 .882 r
.5306 .47511 .53676 .48317 .54821 .48063 .54208 .4719 Mtetra
.634 .676 .873 r
.54208 .4719 .54821 .48063 .55972 .4786 .5536 .46916 Mtetra
.62 .654 .862 r
.5536 .46916 .55972 .4786 .5713 .47709 .56519 .46688 Mtetra
.607 .633 .851 r
.56519 .46688 .5713 .47709 .58295 .47613 .57685 .46506 Mtetra
.595 .611 .838 r
.57685 .46506 .58295 .47613 .59468 .47569 .58857 .46368 Mtetra
.586 .59 .824 r
.58857 .46368 .59468 .47569 .6065 .47572 .60037 .46267 Mtetra
.58 .572 .809 r
.60037 .46267 .6065 .47572 .6184 .47613 .61225 .46194 Mtetra
.577 .555 .793 r
.61225 .46194 .6184 .47613 .63039 .47674 .6242 .46136 Mtetra
.579 .543 .778 r
.6242 .46136 .63039 .47674 .64246 .47732 .63623 .46074 Mtetra
.585 .534 .764 r
.63623 .46074 .64246 .47732 .6546 .47757 .64832 .45985 Mtetra
.594 .529 .751 r
.64832 .45985 .6546 .47757 .66679 .47719 .66046 .45845 Mtetra
.605 .527 .741 r
.66046 .45845 .66679 .47719 .67902 .47586 .67264 .45632 Mtetra
.617 .529 .732 r
.67264 .45632 .67902 .47586 .69126 .47334 .68484 .45327 Mtetra
.63 .533 .726 r
.68484 .45327 .69126 .47334 .70348 .46945 .69704 .44919 Mtetra
.643 .54 .722 r
.69704 .44919 .70348 .46945 .71568 .46416 .70924 .44405 Mtetra
.656 .548 .721 r
.70924 .44405 .71568 .46416 .72784 .45753 .72142 .43792 Mtetra
.668 .559 .722 r
.72142 .43792 .72784 .45753 .73995 .44976 .73358 .43094 Mtetra
.678 .57 .726 r
.73358 .43094 .73995 .44976 .75203 .44111 .74574 .42333 Mtetra
.688 .583 .733 r
.74574 .42333 .75203 .44111 .76409 .4319 .75789 .41534 Mtetra
.696 .598 .742 r
.75789 .41534 .76409 .4319 .77614 .42247 .77005 .40721 Mtetra
.702 .614 .755 r
.77005 .40721 .77614 .42247 .78821 .41313 .78224 .39917 Mtetra
.707 .631 .77 r
.78224 .39917 .78821 .41313 .80032 .4041 .79448 .39139 Mtetra
.709 .648 .787 r
.79448 .39139 .80032 .4041 .8125 .39559 .80678 .384 Mtetra
.709 .666 .805 r
.80678 .384 .8125 .39559 .82474 .38768 .81914 .37707 Mtetra
.707 .682 .824 r
.81914 .37707 .82474 .38768 .83708 .38041 .83159 .37062 Mtetra
.703 .698 .842 r
.83159 .37062 .83708 .38041 .84951 .37377 .84413 .36463 Mtetra
.698 .711 .858 r
.84413 .36463 .84951 .37377 .86203 .3677 .85674 .35906 Mtetra
.692 .721 .872 r
.85674 .35906 .86203 .3677 .87465 .36212 .86944 .35384 Mtetra
.686 .729 .884 r
.86944 .35384 .87465 .36212 .88736 .35692 .88222 .3489 Mtetra
.68 .735 .892 r
.88222 .3489 .88736 .35692 .90016 .35203 .89508 .34418 Mtetra
.676 .739 .898 r
.89508 .34418 .90016 .35203 .91303 .34737 .90802 .33961 Mtetra
.244 .738 .915 r
.31383 .54822 .32089 .5496 .33139 .54856 .32434 .5477 Mtetra
.229 .738 .886 r
.32434 .5477 .33139 .54856 .34197 .54728 .33493 .54687 Mtetra
.24 .751 .868 r
.33493 .54687 .34197 .54728 .35262 .54565 .3456 .54558 Mtetra
.279 .779 .865 r
.3456 .54558 .35262 .54565 .36335 .54356 .35636 .54371 Mtetra
.342 .819 .877 r
.35636 .54371 .36335 .54356 .37415 .54094 .3672 .54117 Mtetra
.421 .864 .899 r
.3672 .54117 .37415 .54094 .38502 .53773 .37812 .5379 Mtetra
.506 .905 .924 r
.37812 .5379 .38502 .53773 .39596 .53394 .38912 .53389 Mtetra
.586 .934 .944 r
.38912 .53389 .39596 .53394 .40696 .5296 .40019 .52918 Mtetra
.651 .947 .956 r
.40019 .52918 .40696 .5296 .41802 .52477 .41131 .52387 Mtetra
.699 .945 .959 r
.41131 .52387 .41802 .52477 .42912 .51956 .42248 .51807 Mtetra
.73 .932 .956 r
.42248 .51807 .42912 .51956 .44027 .51409 .43369 .51193 Mtetra
.746 .911 .949 r
.43369 .51193 .44027 .51409 .45144 .50851 .44493 .50562 Mtetra
.751 .886 .94 r
.44493 .50562 .45144 .50851 .46265 .50293 .4562 .4993 Mtetra
.748 .86 .931 r
.4562 .4993 .46265 .50293 .47389 .49748 .4675 .49311 Mtetra
.739 .833 .923 r
.4675 .49311 .47389 .49748 .48516 .49227 .47882 .48718 Mtetra
.727 .807 .914 r
.47882 .48718 .48516 .49227 .49647 .48738 .49017 .48158 Mtetra
.713 .782 .906 r
.49017 .48158 .49647 .48738 .5078 .48287 .50154 .47639 Mtetra
.697 .758 .899 r
.50154 .47639 .5078 .48287 .51918 .47877 .51296 .47164 Mtetra
.682 .736 .891 r
.51296 .47164 .51918 .47877 .5306 .47511 .52441 .46735 Mtetra
.667 .714 .883 r
.52441 .46735 .5306 .47511 .54208 .4719 .53591 .46351 Mtetra
.653 .693 .875 r
.53591 .46351 .54208 .4719 .5536 .46916 .54745 .46012 Mtetra
.639 .673 .866 r
.54745 .46012 .5536 .46916 .56519 .46688 .55906 .45715 Mtetra
.627 .653 .856 r
.55906 .45715 .56519 .46688 .57685 .46506 .57072 .45459 Mtetra
.616 .633 .845 r
.57072 .45459 .57685 .46506 .58857 .46368 .58244 .45239 Mtetra
.608 .615 .833 r
.58244 .45239 .58857 .46368 .60037 .46267 .59424 .45049 Mtetra
.602 .597 .819 r
.59424 .45049 .60037 .46267 .61225 .46194 .6061 .44882 Mtetra
.599 .582 .805 r
.6061 .44882 .61225 .46194 .6242 .46136 .61803 .44725 Mtetra
.599 .569 .792 r
.61803 .44725 .6242 .46136 .63623 .46074 .63003 .44564 Mtetra
.603 .56 .779 r
.63003 .44564 .63623 .46074 .64832 .45985 .64209 .44382 Mtetra
.609 .554 .767 r
.64209 .44382 .64832 .45985 .66046 .45845 .6542 .44162 Mtetra
.617 .551 .757 r
.6542 .44162 .66046 .45845 .67264 .45632 .66635 .43887 Mtetra
.627 .551 .75 r
.66635 .43887 .67264 .45632 .68484 .45327 .67852 .43543 Mtetra
.637 .554 .744 r
.67852 .43543 .68484 .45327 .69704 .44919 .69072 .43124 Mtetra
.648 .559 .741 r
.69072 .43124 .69704 .44919 .70924 .44405 .70293 .42628 Mtetra
.658 .567 .741 r
.70293 .42628 .70924 .44405 .72142 .43792 .71513 .4206 Mtetra
.668 .576 .743 r
.71513 .4206 .72142 .43792 .73358 .43094 .72735 .41432 Mtetra
.677 .587 .747 r
.72735 .41432 .73358 .43094 .74574 .42333 .73957 .4076 Mtetra
.685 .6 .755 r
.73957 .4076 .74574 .42333 .75789 .41534 .7518 .40062 Mtetra
.692 .614 .765 r
.7518 .40062 .75789 .41534 .77005 .40721 .76406 .39356 Mtetra
.697 .63 .778 r
.76406 .39356 .77005 .40721 .78224 .39917 .77636 .38658 Mtetra
.7 .646 .792 r
.77636 .38658 .78224 .39917 .79448 .39139 .7887 .3798 Mtetra
.702 .663 .809 r
.7887 .3798 .79448 .39139 .80678 .384 .80111 .37331 Mtetra
.701 .679 .826 r
.80111 .37331 .80678 .384 .81914 .37707 .81358 .36716 Mtetra
.699 .694 .842 r
.81358 .36716 .81914 .37707 .83159 .37062 .82613 .36136 Mtetra
.695 .707 .858 r
.82613 .36136 .83159 .37062 .84413 .36463 .83875 .35588 Mtetra
.69 .719 .871 r
.83875 .35588 .84413 .36463 .85674 .35906 .85145 .35069 Mtetra
.685 .727 .882 r
.85145 .35069 .85674 .35906 .86944 .35384 .86422 .34575 Mtetra
.68 .734 .891 r
.86422 .34575 .86944 .35384 .88222 .3489 .87706 .341 Mtetra
.676 .739 .897 r
.87706 .341 .88222 .3489 .89508 .34418 .88998 .33639 Mtetra
.673 .742 .902 r
.88998 .33639 .89508 .34418 .90802 .33961 .90297 .33188 Mtetra
.077 .634 .798 r
.30666 .54753 .31383 .54822 .32434 .5477 .31717 .54758 Mtetra
.067 .63 .758 r
.31717 .54758 .32434 .5477 .33493 .54687 .32777 .54723 Mtetra
.091 .65 .741 r
.32777 .54723 .33493 .54687 .3456 .54558 .33846 .54631 Mtetra
.15 .692 .75 r
.33846 .54631 .3456 .54558 .35636 .54371 .34925 .54467 Mtetra
.237 .754 .78 r
.34925 .54467 .35636 .54371 .3672 .54117 .36014 .5422 Mtetra
.346 .824 .825 r
.36014 .5422 .3672 .54117 .37812 .5379 .37112 .53883 Mtetra
.461 .889 .872 r
.37112 .53883 .37812 .5379 .38912 .53389 .38218 .53456 Mtetra
.567 .936 .91 r
.38218 .53456 .38912 .53389 .40019 .52918 .39331 .52943 Mtetra
.653 .959 .933 r
.39331 .52943 .40019 .52918 .41131 .52387 .40451 .52356 Mtetra
.713 .962 .943 r
.40451 .52356 .41131 .52387 .42248 .51807 .41575 .5171 Mtetra
.75 .949 .944 r
.41575 .5171 .42248 .51807 .43369 .51193 .42704 .51022 Mtetra
.768 .927 .939 r
.42704 .51022 .43369 .51193 .44493 .50562 .43835 .50313 Mtetra
.774 .901 .931 r
.43835 .50313 .44493 .50562 .4562 .4993 .44968 .49602 Mtetra
.77 .874 .923 r
.44968 .49602 .4562 .4993 .4675 .49311 .46104 .48904 Mtetra
.76 .847 .916 r
.46104 .48904 .4675 .49311 .47882 .48718 .47242 .48235 Mtetra
.747 .82 .909 r
.47242 .48235 .47882 .48718 .49017 .48158 .48381 .47603 Mtetra
.732 .795 .903 r
.48381 .47603 .49017 .48158 .50154 .47639 .49523 .47017 Mtetra
.715 .772 .897 r
.49523 .47017 .50154 .47639 .51296 .47164 .50668 .46478 Mtetra
.699 .749 .891 r
.50668 .46478 .51296 .47164 .52441 .46735 .51817 .45988 Mtetra
.684 .729 .884 r
.51817 .45988 .52441 .46735 .53591 .46351 .52969 .45546 Mtetra
.669 .709 .878 r
.52969 .45546 .53591 .46351 .54745 .46012 .54127 .45148 Mtetra
.656 .69 .87 r
.54127 .45148 .54745 .46012 .55906 .45715 .55289 .44792 Mtetra
.644 .672 .862 r
.55289 .44792 .55906 .45715 .57072 .45459 .56456 .44472 Mtetra
.634 .655 .853 r
.56456 .44472 .57072 .45459 .58244 .45239 .5763 .44184 Mtetra
.626 .638 .843 r
.5763 .44184 .58244 .45239 .59424 .45049 .5881 .43922 Mtetra
.621 .623 .831 r
.5881 .43922 .59424 .45049 .6061 .44882 .59996 .43678 Mtetra
.617 .609 .82 r
.59996 .43678 .6061 .44882 .61803 .44725 .61188 .43442 Mtetra
.617 .597 .808 r
.61188 .43442 .61803 .44725 .63003 .44564 .62386 .43204 Mtetra
.619 .587 .796 r
.62386 .43204 .63003 .44564 .64209 .44382 .6359 .42951 Mtetra
.623 .581 .786 r
.6359 .42951 .64209 .44382 .6542 .44162 .648 .42669 Mtetra
.629 .577 .777 r
.648 .42669 .6542 .44162 .66635 .43887 .66013 .42348 Mtetra
.636 .576 .77 r
.66013 .42348 .66635 .43887 .67852 .43543 .6723 .41978 Mtetra
.644 .578 .766 r
.6723 .41978 .67852 .43543 .69072 .43124 .6845 .41554 Mtetra
.653 .583 .764 r
.6845 .41554 .69072 .43124 .70293 .42628 .69672 .41076 Mtetra
.661 .589 .764 r
.69672 .41076 .70293 .42628 .71513 .4206 .70897 .40547 Mtetra
.669 .598 .767 r
.70897 .40547 .71513 .4206 .72735 .41432 .72122 .39978 Mtetra
.677 .609 .772 r
.72122 .39978 .72735 .41432 .73957 .4076 .73351 .39378 Mtetra
.683 .621 .78 r
.73351 .39378 .73957 .4076 .7518 .40062 .74582 .38761 Mtetra
.688 .635 .79 r
.74582 .38761 .7518 .40062 .76406 .39356 .75816 .3814 Mtetra
.692 .649 .803 r
.75816 .3814 .76406 .39356 .77636 .38658 .77055 .37525 Mtetra
.694 .664 .817 r
.77055 .37525 .77636 .38658 .7887 .3798 .78299 .36925 Mtetra
.695 .679 .831 r
.78299 .36925 .7887 .3798 .80111 .37331 .79548 .36346 Mtetra
.693 .694 .846 r
.79548 .36346 .80111 .37331 .81358 .36716 .80805 .3579 Mtetra
.691 .707 .86 r
.80805 .3579 .81358 .36716 .82613 .36136 .82067 .35258 Mtetra
.688 .718 .872 r
.82067 .35258 .82613 .36136 .83875 .35588 .83337 .34748 Mtetra
.684 .727 .883 r
.83337 .34748 .83875 .35588 .85145 .35069 .84614 .34257 Mtetra
.68 .734 .891 r
.84614 .34257 .85145 .35069 .86422 .34575 .85898 .33782 Mtetra
.676 .739 .898 r
.85898 .33782 .86422 .34575 .87706 .341 .87188 .33319 Mtetra
.674 .742 .902 r
.87188 .33319 .87706 .341 .88998 .33639 .88485 .32866 Mtetra
.671 .744 .905 r
.88485 .32866 .88998 .33639 .90297 .33188 .89789 .32418 Mtetra
.083 0 0 r
.29937 .54742 .30666 .54753 .31717 .54758 .30988 .54808 Mtetra
.079 0 0 r
.30988 .54808 .31717 .54758 .32777 .54723 .32049 .54824 Mtetra
.037 0 0 r
.32049 .54824 .32777 .54723 .33846 .54631 .3312 .54769 Mtetra
0 0 0 r
.3312 .54769 .33846 .54631 .34925 .54467 .34202 .54627 Mtetra
.154 .689 .691 r
.34202 .54627 .34925 .54467 .36014 .5422 .35296 .54385 Mtetra
.291 .786 .76 r
.35296 .54385 .36014 .5422 .37112 .53883 .36399 .54034 Mtetra
.435 .874 .829 r
.36399 .54034 .37112 .53883 .38218 .53456 .37512 .53575 Mtetra
.566 .938 .882 r
.37512 .53575 .38218 .53456 .39331 .52943 .38633 .53015 Mtetra
.666 .969 .914 r
.38633 .53015 .39331 .52943 .40451 .52356 .39761 .52366 Mtetra
.734 .973 .928 r
.39761 .52366 .40451 .52356 .41575 .5171 .40894 .51648 Mtetra
.773 .959 .929 r
.40894 .51648 .41575 .5171 .42704 .51022 .4203 .50882 Mtetra
.791 .936 .925 r
.4203 .50882 .42704 .51022 .43835 .50313 .43169 .5009 Mtetra
.796 .91 .919 r
.43169 .5009 .43835 .50313 .44968 .49602 .4431 .49295 Mtetra
.791 .882 .912 r
.4431 .49295 .44968 .49602 .46104 .48904 .45452 .48516 Mtetra
.78 .855 .907 r
.45452 .48516 .46104 .48904 .47242 .48235 .46595 .47769 Mtetra
.766 .829 .902 r
.46595 .47769 .47242 .48235 .48381 .47603 .4774 .47066 Mtetra
.749 .805 .897 r
.4774 .47066 .48381 .47603 .49523 .47017 .48887 .46412 Mtetra
.732 .782 .893 r
.48887 .46412 .49523 .47017 .50668 .46478 .50036 .45813 Mtetra
.715 .761 .889 r
.50036 .45813 .50668 .46478 .51817 .45988 .51188 .45266 Mtetra
.699 .741 .885 r
.51188 .45266 .51817 .45988 .52969 .45546 .52344 .44771 Mtetra
.684 .723 .88 r
.52344 .44771 .52969 .45546 .54127 .45148 .53504 .44322 Mtetra
.67 .706 .874 r
.53504 .44322 .54127 .45148 .55289 .44792 .54668 .43914 Mtetra
.659 .69 .868 r
.54668 .43914 .55289 .44792 .56456 .44472 .55838 .43542 Mtetra
.649 .675 .861 r
.55838 .43542 .56456 .44472 .5763 .44184 .57013 .43199 Mtetra
.642 .661 .853 r
.57013 .43199 .5763 .44184 .5881 .43922 .58194 .4288 Mtetra
.636 .647 .844 r
.58194 .4288 .5881 .43922 .59996 .43678 .59381 .42576 Mtetra
.633 .635 .835 r
.59381 .42576 .59996 .43678 .61188 .43442 .60573 .42281 Mtetra
.631 .624 .825 r
.60573 .42281 .61188 .43442 .62386 .43204 .61771 .41985 Mtetra
.632 .616 .815 r
.61771 .41985 .62386 .43204 .6359 .42951 .62975 .41678 Mtetra
.635 .609 .807 r
.62975 .41678 .6359 .42951 .648 .42669 .64184 .41352 Mtetra
.639 .605 .8 r
.64184 .41352 .648 .42669 .66013 .42348 .65398 .40999 Mtetra
.645 .604 .794 r
.65398 .40999 .66013 .42348 .6723 .41978 .66615 .40611 Mtetra
.651 .606 .79 r
.66615 .40611 .6723 .41978 .6845 .41554 .67837 .40187 Mtetra
.658 .609 .789 r
.67837 .40187 .6845 .41554 .69672 .41076 .69061 .39725 Mtetra
.664 .615 .79 r
.69061 .39725 .69672 .41076 .70897 .40547 .70289 .3923 Mtetra
.67 .623 .793 r
.70289 .3923 .70897 .40547 .72122 .39978 .71519 .38707 Mtetra
.676 .633 .799 r
.71519 .38707 .72122 .39978 .73351 .39378 .72753 .38164 Mtetra
.681 .645 .807 r
.72753 .38164 .73351 .39378 .74582 .38761 .73991 .3761 Mtetra
.685 .657 .817 r
.73991 .3761 .74582 .38761 .75816 .3814 .75233 .37054 Mtetra
.687 .67 .828 r
.75233 .37054 .75816 .3814 .77055 .37525 .76479 .36502 Mtetra
.688 .684 .84 r
.76479 .36502 .77055 .37525 .78299 .36925 .77731 .3596 Mtetra
.688 .697 .853 r
.77731 .3596 .78299 .36925 .79548 .36346 .78989 .35432 Mtetra
.687 .708 .865 r
.78989 .35432 .79548 .36346 .80805 .3579 .80252 .34919 Mtetra
.684 .719 .876 r
.80252 .34919 .80805 .3579 .82067 .35258 .81522 .34421 Mtetra
.682 .728 .885 r
.81522 .34421 .82067 .35258 .83337 .34748 .82799 .33938 Mtetra
.679 .735 .893 r
.82799 .33938 .83337 .34748 .84614 .34257 .84082 .33466 Mtetra
.676 .74 .899 r
.84082 .33466 .84614 .34257 .85898 .33782 .85371 .33004 Mtetra
.674 .744 .903 r
.85371 .33004 .85898 .33782 .87188 .33319 .86667 .32549 Mtetra
.672 .746 .907 r
.86667 .32549 .87188 .33319 .88485 .32866 .8797 .32098 Mtetra
.67 .748 .909 r
.8797 .32098 .88485 .32866 .89789 .32418 .89278 .31651 Mtetra
.21 0 0 r
.29197 .54774 .29937 .54742 .30988 .54808 .30247 .54902 Mtetra
.189 0 0 r
.30247 .54902 .30988 .54808 .32049 .54824 .31309 .54968 Mtetra
.129 0 0 r
.31309 .54968 .32049 .54824 .3312 .54769 .32382 .5495 Mtetra
.03 0 0 r
.32382 .5495 .3312 .54769 .34202 .54627 .33469 .54828 Mtetra
0 0 0 r
.33469 .54828 .34202 .54627 .35296 .54385 .34567 .54585 Mtetra
.272 .77 .727 r
.34567 .54585 .35296 .54385 .36399 .54034 .35677 .54216 Mtetra
.443 .877 .812 r
.35677 .54216 .36399 .54034 .37512 .53575 .36797 .53721 Mtetra
.589 .948 .873 r
.36797 .53721 .37512 .53575 .38633 .53015 .37926 .53108 Mtetra
.696 .978 .906 r
.37926 .53108 .38633 .53015 .39761 .52366 .39063 .52394 Mtetra
.762 .978 .916 r
.39063 .52394 .39761 .52366 .40894 .51648 .40204 .51599 Mtetra
.798 .961 .915 r
.40204 .51599 .40894 .51648 .4203 .50882 .41349 .50751 Mtetra
.814 .937 .91 r
.41349 .50751 .4203 .50882 .43169 .5009 .42496 .49874 Mtetra
.816 .91 .904 r
.42496 .49874 .43169 .5009 .4431 .49295 .43644 .48994 Mtetra
.809 .883 .899 r
.43644 .48994 .4431 .49295 .45452 .48516 .44793 .48133 Mtetra
.797 .857 .895 r
.44793 .48133 .45452 .48516 .46595 .47769 .45943 .4731 Mtetra
.781 .833 .892 r
.45943 .4731 .46595 .47769 .4774 .47066 .47093 .46535 Mtetra
.764 .81 .89 r
.47093 .46535 .4774 .47066 .48887 .46412 .48245 .45818 Mtetra
.746 .789 .888 r
.48245 .45818 .48887 .46412 .50036 .45813 .49399 .45161 Mtetra
.728 .769 .886 r
.49399 .45161 .50036 .45813 .51188 .45266 .50555 .44563 Mtetra
.711 .751 .884 r
.50555 .44563 .51188 .45266 .52344 .44771 .51714 .4402 Mtetra
.696 .735 .881 r
.51714 .4402 .52344 .44771 .53504 .44322 .52877 .43526 Mtetra
.682 .72 .878 r
.52877 .43526 .53504 .44322 .54668 .43914 .54044 .43076 Mtetra
.671 .706 .874 r
.54044 .43076 .54668 .43914 .55838 .43542 .55216 .42661 Mtetra
.661 .693 .869 r
.55216 .42661 .55838 .43542 .57013 .43199 .56393 .42276 Mtetra
.654 .68 .863 r
.56393 .42276 .57013 .43199 .58194 .4288 .57576 .41913 Mtetra
.648 .669 .856 r
.57576 .41913 .58194 .4288 .59381 .42576 .58764 .41565 Mtetra
.645 .659 .849 r
.58764 .41565 .59381 .42576 .60573 .42281 .59958 .41225 Mtetra
.643 .65 .842 r
.59958 .41225 .60573 .42281 .61771 .41985 .61157 .40887 Mtetra
.643 .643 .835 r
.61157 .40887 .61771 .41985 .62975 .41678 .62361 .40543 Mtetra
.645 .637 .828 r
.62361 .40543 .62975 .41678 .64184 .41352 .63571 .40186 Mtetra
.648 .634 .822 r
.63571 .40186 .64184 .41352 .65398 .40999 .64786 .39811 Mtetra
.652 .633 .818 r
.64786 .39811 .65398 .40999 .66615 .40611 .66005 .39414 Mtetra
.656 .634 .816 r
.66005 .39414 .66615 .40611 .67837 .40187 .67229 .38992 Mtetra
.661 .637 .815 r
.67229 .38992 .67837 .40187 .69061 .39725 .68456 .38546 Mtetra
.666 .643 .817 r
.68456 .38546 .69061 .39725 .70289 .3923 .69687 .38077 Mtetra
.671 .65 .82 r
.69687 .38077 .70289 .3923 .71519 .38707 .70923 .3759 Mtetra
.675 .659 .826 r
.70923 .3759 .71519 .38707 .72753 .38164 .72162 .37091 Mtetra
.679 .669 .833 r
.72162 .37091 .72753 .38164 .73991 .3761 .73405 .36584 Mtetra
.681 .68 .842 r
.73405 .36584 .73991 .3761 .75233 .37054 .74654 .36075 Mtetra
.682 .691 .852 r
.74654 .36075 .75233 .37054 .76479 .36502 .75907 .35569 Mtetra
.683 .702 .862 r
.75907 .35569 .76479 .36502 .77731 .3596 .77166 .35068 Mtetra
.682 .713 .872 r
.77166 .35068 .77731 .3596 .78989 .35432 .7843 .34577 Mtetra
.681 .722 .881 r
.7843 .34577 .78989 .35432 .80252 .34919 .79701 .34094 Mtetra
.679 .731 .889 r
.79701 .34094 .80252 .34919 .81522 .34421 .80977 .3362 Mtetra
.677 .737 .896 r
.80977 .3362 .81522 .34421 .82799 .33938 .82259 .33153 Mtetra
.675 .742 .901 r
.82259 .33153 .82799 .33938 .84082 .33466 .83548 .32693 Mtetra
.673 .746 .905 r
.83548 .32693 .84082 .33466 .85371 .33004 .84843 .32238 Mtetra
.672 .749 .908 r
.84843 .32238 .85371 .33004 .86667 .32549 .86144 .31786 Mtetra
.671 .75 .91 r
.86144 .31786 .86667 .32549 .8797 .32098 .87451 .31337 Mtetra
.67 .751 .911 r
.87451 .31337 .8797 .32098 .89278 .31651 .88764 .30888 Mtetra
.297 0 0 r
.28446 .54827 .29197 .54774 .30247 .54902 .29496 .55015 Mtetra
.259 0 0 r
.29496 .55015 .30247 .54902 .31309 .54968 .30559 .55129 Mtetra
.181 0 0 r
.30559 .55129 .31309 .54968 .32382 .5495 .31635 .55144 Mtetra
.059 0 0 r
.31635 .55144 .32382 .5495 .33469 .54828 .32725 .55036 Mtetra
0 0 0 r
.32725 .55036 .33469 .54828 .34567 .54585 .33829 .54789 Mtetra
.3 .789 .74 r
.33829 .54789 .34567 .54585 .35677 .54216 .34946 .54397 Mtetra
.489 .902 .831 r
.34946 .54397 .35677 .54216 .36797 .53721 .36074 .5386 Mtetra
.639 .965 .885 r
.36074 .5386 .36797 .53721 .37926 .53108 .37211 .5319 Mtetra
.738 .984 .906 r
.37211 .5319 .37926 .53108 .39063 .52394 .38356 .52407 Mtetra
.795 .975 .908 r
.38356 .52407 .39063 .52394 .40204 .51599 .39507 .51534 Mtetra
.823 .953 .902 r
.39507 .51534 .40204 .51599 .41349 .50751 .4066 .50602 Mtetra
.833 .927 .894 r
.4066 .50602 .41349 .50751 .42496 .49874 .41816 .49641 Mtetra
.832 .901 .888 r
.41816 .49641 .42496 .49874 .43644 .48994 .42972 .48678 Mtetra
.823 .876 .884 r
.42972 .48678 .43644 .48994 .44793 .48133 .44128 .47738 Mtetra
.81 .853 .881 r
.44128 .47738 .44793 .48133 .45943 .4731 .45284 .46841 Mtetra
.794 .831 .881 r
.45284 .46841 .45943 .4731 .47093 .46535 .46441 .46 Mtetra
.776 .811 .881 r
.46441 .46 .47093 .46535 .48245 .45818 .47598 .45224 Mtetra
.757 .792 .881 r
.47598 .45224 .48245 .45818 .49399 .45161 .48756 .44514 Mtetra
.739 .775 .882 r
.48756 .44514 .49399 .45161 .50555 .44563 .49916 .43869 Mtetra
.721 .759 .882 r
.49916 .43869 .50555 .44563 .51714 .4402 .51079 .43285 Mtetra
.706 .744 .881 r
.51079 .43285 .51714 .4402 .52877 .43526 .52245 .42754 Mtetra
.692 .731 .88 r
.52245 .42754 .52877 .43526 .54044 .43076 .53416 .42269 Mtetra
.68 .718 .878 r
.53416 .42269 .54044 .43076 .55216 .42661 .5459 .41821 Mtetra
.671 .708 .875 r
.5459 .41821 .55216 .42661 .56393 .42276 .5577 .41403 Mtetra
.663 .698 .872 r
.5577 .41403 .56393 .42276 .57576 .41913 .56955 .41008 Mtetra
.658 .688 .867 r
.56955 .41008 .57576 .41913 .58764 .41565 .58145 .40628 Mtetra
.654 .68 .863 r
.58145 .40628 .58764 .41565 .59958 .41225 .59341 .40258 Mtetra
.652 .673 .858 r
.59341 .40258 .59958 .41225 .61157 .40887 .60542 .3989 Mtetra
.652 .668 .853 r
.60542 .3989 .61157 .40887 .62361 .40543 .61748 .39521 Mtetra
.652 .663 .848 r
.61748 .39521 .62361 .40543 .63571 .40186 .6296 .39144 Mtetra
.654 .661 .844 r
.6296 .39144 .63571 .40186 .64786 .39811 .64176 .38756 Mtetra
.657 .66 .841 r
.64176 .38756 .64786 .39811 .66005 .39414 .65398 .38354 Mtetra
.66 .661 .84 r
.65398 .38354 .66005 .39414 .67229 .38992 .66624 .37936 Mtetra
.664 .664 .84 r
.66624 .37936 .67229 .38992 .68456 .38546 .67855 .37503 Mtetra
.667 .669 .842 r
.67855 .37503 .68456 .38546 .69687 .38077 .6909 .37056 Mtetra
.67 .675 .846 r
.6909 .37056 .69687 .38077 .70923 .3759 .70329 .36596 Mtetra
.673 .683 .851 r
.70329 .36596 .70923 .3759 .72162 .37091 .71574 .36128 Mtetra
.675 .692 .858 r
.71574 .36128 .72162 .37091 .73405 .36584 .72823 .35655 Mtetra
.677 .701 .865 r
.72823 .35655 .73405 .36584 .74654 .36075 .74077 .3518 Mtetra
.678 .71 .873 r
.74077 .3518 .74654 .36075 .75907 .35569 .75337 .34707 Mtetra
.678 .719 .881 r
.75337 .34707 .75907 .35569 .77166 .35068 .76601 .34235 Mtetra
.677 .728 .888 r
.76601 .34235 .77166 .35068 .7843 .34577 .77872 .33768 Mtetra
.676 .735 .895 r
.77872 .33768 .7843 .34577 .79701 .34094 .79148 .33305 Mtetra
.675 .741 .9 r
.79148 .33305 .79701 .34094 .80977 .3362 .8043 .32846 Mtetra
.673 .746 .905 r
.8043 .32846 .80977 .3362 .82259 .33153 .81718 .3239 Mtetra
.672 .749 .909 r
.81718 .3239 .82259 .33153 .83548 .32693 .83012 .31937 Mtetra
.671 .752 .911 r
.83012 .31937 .83548 .32693 .84843 .32238 .84312 .31484 Mtetra
.671 .754 .913 r
.84312 .31484 .84843 .32238 .86144 .31786 .85617 .31033 Mtetra
.67 .755 .914 r
.85617 .31033 .86144 .31786 .87451 .31337 .86929 .3058 Mtetra
.86929 .3058 .87451 .31337 .88764 .30888 .88246 .30127 Mtetra
.348 0 0 r
.27688 .54871 .28446 .54827 .29496 .55015 .28738 .55114 Mtetra
.293 0 0 r
.28738 .55114 .29496 .55015 .30559 .55129 .29801 .55271 Mtetra
.193 0 0 r
.29801 .55271 .30559 .55129 .31635 .55144 .3088 .55312 Mtetra
.043 0 0 r
.3088 .55312 .31635 .55144 .32725 .55036 .31974 .55212 Mtetra
0 0 0 r
.31974 .55212 .32725 .55036 .33829 .54789 .33084 .54956 Mtetra
.376 .84 .801 r
.33084 .54956 .33829 .54789 .34946 .54397 .34207 .54535 Mtetra
.569 .939 .877 r
.34207 .54535 .34946 .54397 .36074 .5386 .35344 .53953 Mtetra
.704 .979 .908 r
.35344 .53953 .36074 .5386 .37211 .5319 .3649 .53224 Mtetra
.783 .978 .909 r
.3649 .53224 .37211 .5319 .38356 .52407 .37644 .52371 Mtetra
.825 .959 .899 r
.37644 .52371 .38356 .52407 .39507 .51534 .38804 .51422 Mtetra
.843 .934 .887 r
.38804 .51422 .39507 .51534 .4066 .50602 .39966 .50409 Mtetra
.847 .909 .877 r
.39966 .50409 .4066 .50602 .41816 .49641 .4113 .49367 Mtetra
.843 .885 .871 r
.4113 .49367 .41816 .49641 .42972 .48678 .42294 .48325 Mtetra
.833 .863 .868 r
.42294 .48325 .42972 .48678 .44128 .47738 .43458 .47312 Mtetra
.819 .843 .867 r
.43458 .47312 .44128 .47738 .45284 .46841 .44621 .46348 Mtetra
.802 .825 .868 r
.44621 .46348 .45284 .46841 .46441 .46 .45783 .45448 Mtetra
.784 .807 .871 r
.45783 .45448 .46441 .46 .47598 .45224 .46945 .44618 Mtetra
.766 .791 .874 r
.46945 .44618 .47598 .45224 .48756 .44514 .48108 .43863 Mtetra
.747 .776 .877 r
.48108 .43863 .48756 .44514 .49916 .43869 .49272 .43178 Mtetra
.729 .762 .879 r
.49272 .43178 .49916 .43869 .51079 .43285 .50439 .42559 Mtetra
.713 .75 .881 r
.50439 .42559 .51079 .43285 .52245 .42754 .51609 .41998 Mtetra
.699 .739 .882 r
.51609 .41998 .52245 .42754 .53416 .42269 .52782 .41485 Mtetra
.687 .728 .882 r
.52782 .41485 .53416 .42269 .5459 .41821 .5396 .41012 Mtetra
.677 .719 .881 r
.5396 .41012 .5459 .41821 .5577 .41403 .55143 .4057 Mtetra
.67 .711 .879 r
.55143 .4057 .5577 .41403 .56955 .41008 .5633 .40152 Mtetra
.664 .704 .877 r
.5633 .40152 .56955 .41008 .58145 .40628 .57523 .3975 Mtetra
.66 .698 .874 r
.57523 .3975 .58145 .40628 .59341 .40258 .58721 .39359 Mtetra
.658 .693 .871 r
.58721 .39359 .59341 .40258 .60542 .3989 .59925 .38973 Mtetra
.657 .689 .868 r
.59925 .38973 .60542 .3989 .61748 .39521 .61133 .38587 Mtetra
.657 .686 .866 r
.61133 .38587 .61748 .39521 .6296 .39144 .62347 .38199 Mtetra
.658 .685 .864 r
.62347 .38199 .6296 .39144 .64176 .38756 .63567 .37804 Mtetra
.66 .684 .862 r
.63567 .37804 .64176 .38756 .65398 .38354 .64791 .37401 Mtetra
.662 .686 .862 r
.64791 .37401 .65398 .38354 .66624 .37936 .6602 .36988 Mtetra
.664 .689 .863 r
.6602 .36988 .66624 .37936 .67855 .37503 .67255 .36566 Mtetra
.666 .693 .865 r
.67255 .36566 .67855 .37503 .6909 .37056 .68494 .36135 Mtetra
.668 .698 .869 r
.68494 .36135 .6909 .37056 .70329 .36596 .69738 .35696 Mtetra
.67 .705 .873 r
.69738 .35696 .70329 .36596 .71574 .36128 .70987 .35251 Mtetra
.672 .712 .879 r
.70987 .35251 .71574 .36128 .72823 .35655 .72242 .34803 Mtetra
.673 .72 .884 r
.72242 .34803 .72823 .35655 .74077 .3518 .73501 .34352 Mtetra
.673 .727 .89 r
.73501 .34352 .74077 .3518 .75337 .34707 .74766 .339 Mtetra
.673 .734 .896 r
.74766 .339 .75337 .34707 .76601 .34235 .76037 .33448 Mtetra
.673 .74 .901 r
.76037 .33448 .76601 .34235 .77872 .33768 .77313 .32997 Mtetra
.672 .746 .906 r
.77313 .32997 .77872 .33768 .79148 .33305 .78594 .32547 Mtetra
.671 .75 .91 r
.78594 .32547 .79148 .33305 .8043 .32846 .79882 .32096 Mtetra
.671 .754 .913 r
.79882 .32096 .8043 .32846 .81718 .3239 .81175 .31646 Mtetra
.671 .756 .915 r
.81175 .31646 .81718 .3239 .83012 .31937 .82473 .31194 Mtetra
.671 .758 .916 r
.82473 .31194 .83012 .31937 .84312 .31484 .83778 .30741 Mtetra
.67 .759 .917 r
.83778 .30741 .84312 .31484 .85617 .31033 .85088 .30287 Mtetra
.85088 .30287 .85617 .31033 .86929 .3058 .86404 .2983 Mtetra
.86404 .2983 .86929 .3058 .88246 .30127 .87726 .29372 Mtetra
.366 0 0 r
.26924 .54874 .27688 .54871 .28738 .55114 .27973 .55164 Mtetra
.291 0 0 r
.27973 .55164 .28738 .55114 .29801 .55271 .29038 .55354 Mtetra
.163 0 0 r
.29038 .55354 .29801 .55271 .3088 .55312 .3012 .55413 Mtetra
0 0 0 r
.3012 .55413 .3088 .55312 .31974 .55212 .31219 .55315 Mtetra
.262 .771 .792 r
.31219 .55315 .31974 .55212 .33084 .54956 .32334 .55042 Mtetra
.491 .903 .888 r
.32334 .55042 .33084 .54956 .34207 .54535 .33465 .54588 Mtetra
.661 .964 .926 r
.33465 .54588 .34207 .54535 .35344 .53953 .34609 .53959 Mtetra
.763 .972 .923 r
.34609 .53959 .35344 .53953 .3649 .53224 .35764 .53171 Mtetra
.818 .955 .905 r
.35764 .53171 .3649 .53224 .37644 .52371 .36927 .5225 Mtetra
.844 .93 .886 r
.36927 .5225 .37644 .52371 .38804 .51422 .38096 .51228 Mtetra
.853 .905 .87 r
.38096 .51228 .38804 .51422 .39966 .50409 .39267 .50141 Mtetra
.853 .882 .86 r
.39267 .50141 .39966 .50409 .4113 .49367 .4044 .49026 Mtetra
.847 .862 .854 r
.4044 .49026 .4113 .49367 .42294 .48325 .41612 .47915 Mtetra
.836 .845 .852 r
.41612 .47915 .42294 .48325 .43458 .47312 .42783 .46838 Mtetra
.823 .828 .853 r
.42783 .46838 .43458 .47312 .44621 .46348 .43952 .45816 Mtetra
.807 .814 .856 r
.43952 .45816 .44621 .46348 .45783 .45448 .4512 .44865 Mtetra
.789 .8 .861 r
.4512 .44865 .45783 .45448 .46945 .44618 .46287 .43991 Mtetra
.771 .787 .866 r
.46287 .43991 .46945 .44618 .48108 .43863 .47455 .43198 Mtetra
.753 .775 .871 r
.47455 .43198 .48108 .43863 .49272 .43178 .48624 .42481 Mtetra
.735 .764 .876 r
.48624 .42481 .49272 .43178 .50439 .42559 .49794 .41835 Mtetra
.719 .753 .88 r
.49794 .41835 .50439 .42559 .51609 .41998 .50968 .4125 Mtetra
.704 .744 .882 r
.50968 .4125 .51609 .41998 .52782 .41485 .52145 .40717 Mtetra
.692 .736 .884 r
.52145 .40717 .52782 .41485 .5396 .41012 .53326 .40225 Mtetra
.682 .728 .885 r
.53326 .40225 .5396 .41012 .55143 .4057 .54511 .39767 Mtetra
.674 .722 .885 r
.54511 .39767 .55143 .4057 .5633 .40152 .55702 .39333 Mtetra
.668 .717 .885 r
.55702 .39333 .5633 .40152 .57523 .3975 .56898 .38916 Mtetra
.664 .712 .884 r
.56898 .38916 .57523 .3975 .58721 .39359 .58098 .38512 Mtetra
.662 .709 .883 r
.58098 .38512 .58721 .39359 .59925 .38973 .59305 .38115 Mtetra
.66 .706 .881 r
.59305 .38115 .59925 .38973 .61133 .38587 .60516 .3772 Mtetra
.66 .705 .88 r
.60516 .3772 .61133 .38587 .62347 .38199 .61733 .37326 Mtetra
.66 .704 .88 r
.61733 .37326 .62347 .38199 .63567 .37804 .62956 .36929 Mtetra
.66 .705 .88 r
.62956 .36929 .63567 .37804 .64791 .37401 .64183 .36527 Mtetra
.662 .706 .88 r
.64183 .36527 .64791 .37401 .6602 .36988 .65416 .36121 Mtetra
.663 .709 .882 r
.65416 .36121 .6602 .36988 .67255 .36566 .66654 .35708 Mtetra
.664 .713 .884 r
.66654 .35708 .67255 .36566 .68494 .36135 .67898 .3529 Mtetra
.666 .718 .888 r
.67898 .3529 .68494 .36135 .69738 .35696 .69146 .34866 Mtetra
.667 .723 .891 r
.69146 .34866 .69738 .35696 .70987 .35251 .704 .34438 Mtetra
.667 .729 .896 r
.704 .34438 .70987 .35251 .72242 .34803 .7166 .34007 Mtetra
.668 .735 .9 r
.7166 .34007 .72242 .34803 .73501 .34352 .72924 .33573 Mtetra
.668 .741 .904 r
.72924 .33573 .73501 .34352 .74766 .339 .74194 .33136 Mtetra
.669 .746 .909 r
.74194 .33136 .74766 .339 .76037 .33448 .7547 .32697 Mtetra
.669 .751 .912 r
.7547 .32697 .76037 .33448 .77313 .32997 .76751 .32256 Mtetra
.669 .755 .915 r
.76751 .32256 .77313 .32997 .78594 .32547 .78038 .31812 Mtetra
.669 .759 .917 r
.78038 .31812 .78594 .32547 .79882 .32096 .7933 .31366 Mtetra
.669 .761 .919 r
.7933 .31366 .79882 .32096 .81175 .31646 .80628 .30917 Mtetra
.67 .763 .92 r
.80628 .30917 .81175 .31646 .82473 .31194 .81932 .30465 Mtetra
.67 .764 .921 r
.81932 .30465 .82473 .31194 .83778 .30741 .83241 .30009 Mtetra
.671 .764 .921 r
.83241 .30009 .83778 .30741 .85088 .30287 .84556 .2955 Mtetra
.671 .764 .92 r
.84556 .2955 .85088 .30287 .86404 .2983 .85876 .29087 Mtetra
.671 .763 .919 r
.85876 .29087 .86404 .2983 .87726 .29372 .87202 .28621 Mtetra
.349 0 0 r
.26157 .54799 .26924 .54874 .27973 .55164 .27207 .55125 Mtetra
.245 0 0 r
.27207 .55125 .27973 .55164 .29038 .55354 .28273 .55338 Mtetra
.076 0 0 r
.28273 .55338 .29038 .55354 .3012 .55413 .29358 .55405 Mtetra
.158 .698 .807 r
.29358 .55405 .3012 .55413 .31219 .55315 .30461 .55299 Mtetra
.409 .854 .916 r
.30461 .55299 .31219 .55315 .32334 .55042 .31583 .55004 Mtetra
.609 .935 .957 r
.31583 .55004 .32334 .55042 .33465 .54588 .32721 .54514 Mtetra
.734 .952 .948 r
.32721 .54514 .33465 .54588 .34609 .53959 .33873 .53838 Mtetra
.801 .938 .919 r
.33873 .53838 .34609 .53959 .35764 .53171 .35037 .52994 Mtetra
.834 .914 .89 r
.35037 .52994 .35764 .53171 .36927 .5225 .36208 .5201 Mtetra
.849 .89 .867 r
.36208 .5201 .36927 .5225 .38096 .51228 .37386 .50924 Mtetra
.854 .869 .851 r
.37386 .50924 .38096 .51228 .39267 .50141 .38566 .49773 Mtetra
.852 .851 .841 r
.38566 .49773 .39267 .50141 .4044 .49026 .39746 .48596 Mtetra
.845 .836 .837 r
.39746 .48596 .4044 .49026 .41612 .47915 .40925 .47429 Mtetra
.835 .823 .836 r
.40925 .47429 .41612 .47915 .42783 .46838 .42103 .463 Mtetra
.822 .811 .839 r
.42103 .463 .42783 .46838 .43952 .45816 .43278 .45232 Mtetra
.808 .8 .845 r
.43278 .45232 .43952 .45816 .4512 .44865 .44452 .44241 Mtetra
.791 .79 .851 r
.44452 .44241 .4512 .44865 .46287 .43991 .45625 .43334 Mtetra
.774 .78 .859 r
.45625 .43334 .46287 .43991 .47455 .43198 .46797 .42513 Mtetra
.756 .771 .866 r
.46797 .42513 .47455 .43198 .48624 .42481 .4797 .41772 Mtetra
.738 .762 .872 r
.4797 .41772 .48624 .42481 .49794 .41835 .49144 .41106 Mtetra
.722 .754 .878 r
.49144 .41106 .49794 .41835 .50968 .4125 .50321 .40504 Mtetra
.707 .747 .883 r
.50321 .40504 .50968 .4125 .52145 .40717 .51502 .39957 Mtetra
.695 .74 .886 r
.51502 .39957 .52145 .40717 .53326 .40225 .52686 .39453 Mtetra
.685 .735 .889 r
.52686 .39453 .53326 .40225 .54511 .39767 .53875 .38983 Mtetra
.677 .73 .89 r
.53875 .38983 .54511 .39767 .55702 .39333 .55069 .3854 Mtetra
.671 .726 .891 r
.55069 .3854 .55702 .39333 .56898 .38916 .56268 .38115 Mtetra
.666 .723 .892 r
.56268 .38115 .56898 .38916 .58098 .38512 .57472 .37703 Mtetra
.663 .721 .892 r
.57472 .37703 .58098 .38512 .59305 .38115 .58681 .373 Mtetra
.661 .72 .892 r
.58681 .373 .59305 .38115 .60516 .3772 .59896 .36902 Mtetra
.66 .719 .892 r
.59896 .36902 .60516 .3772 .61733 .37326 .61116 .36506 Mtetra
.66 .719 .893 r
.61116 .36506 .61733 .37326 .62956 .36929 .62342 .36109 Mtetra
.66 .72 .894 r
.62342 .36109 .62956 .36929 .64183 .36527 .63573 .35712 Mtetra
.66 .722 .895 r
.63573 .35712 .64183 .36527 .65416 .36121 .6481 .35311 Mtetra
.66 .725 .897 r
.6481 .35311 .65416 .36121 .66654 .35708 .66052 .34907 Mtetra
.661 .729 .9 r
.66052 .34907 .66654 .35708 .67898 .3529 .673 .345 Mtetra
.662 .733 .903 r
.673 .345 .67898 .3529 .69146 .34866 .68553 .34088 Mtetra
.663 .738 .906 r
.68553 .34088 .69146 .34866 .704 .34438 .69812 .33673 Mtetra
.663 .743 .909 r
.69812 .33673 .704 .34438 .7166 .34007 .71076 .33254 Mtetra
.664 .748 .913 r
.71076 .33254 .7166 .34007 .72924 .33573 .72345 .32832 Mtetra
.664 .752 .916 r
.72345 .32832 .72924 .33573 .74194 .33136 .73621 .32405 Mtetra
.665 .757 .919 r
.73621 .32405 .74194 .33136 .7547 .32697 .74901 .31974 Mtetra
.666 .761 .921 r
.74901 .31974 .7547 .32697 .76751 .32256 .76188 .31539 Mtetra
.667 .764 .923 r
.76188 .31539 .76751 .32256 .78038 .31812 .77479 .31099 Mtetra
.667 .767 .924 r
.77479 .31099 .78038 .31812 .7933 .31366 .78777 .30654 Mtetra
.668 .768 .925 r
.78777 .30654 .7933 .31366 .80628 .30917 .80079 .30204 Mtetra
.67 .77 .925 r
.80079 .30204 .80628 .30917 .81932 .30465 .81387 .29748 Mtetra
.671 .77 .925 r
.81387 .29748 .81932 .30465 .83241 .30009 .82701 .29287 Mtetra
.671 .77 .924 r
.82701 .29287 .83241 .30009 .84556 .2955 .8402 .28821 Mtetra
.672 .769 .923 r
.8402 .28821 .84556 .2955 .85876 .29087 .85345 .28351 Mtetra
.673 .768 .922 r
.85345 .28351 .85876 .29087 .87202 .28621 .86675 .27877 Mtetra
.283 0 0 r
.2539 .54613 .26157 .54799 .27207 .55125 .26441 .5496 Mtetra
0 .451 .698 r
.26441 .5496 .27207 .55125 .28273 .55338 .27509 .55183 Mtetra
.076 .624 .835 r
.27509 .55183 .28273 .55338 .29358 .55405 .28598 .55247 Mtetra
.329 .786 .947 r
.28598 .55247 .29358 .55405 .30461 .55299 .29706 .55126 Mtetra
.546 .882 .988 r
.29706 .55126 .30461 .55299 .31583 .55004 .30833 .54803 Mtetra
.689 .911 .972 r
.30833 .54803 .31583 .55004 .32721 .54514 .31978 .54276 Mtetra
.77 .903 .934 r
.31978 .54276 .32721 .54514 .33873 .53838 .33138 .53554 Mtetra
.813 .884 .897 r
.33138 .53554 .33873 .53838 .35037 .52994 .34309 .52659 Mtetra
.834 .864 .867 r
.34309 .52659 .35037 .52994 .36208 .5201 .35489 .51623 Mtetra
.844 .846 .845 r
.35489 .51623 .36208 .5201 .37386 .50924 .36674 .50484 Mtetra
.846 .83 .831 r
.36674 .50484 .37386 .50924 .38566 .49773 .37862 .49283 Mtetra
.844 .818 .823 r
.37862 .49283 .38566 .49773 .39746 .48596 .3905 .4806 Mtetra
.838 .808 .821 r
.3905 .4806 .39746 .48596 .40925 .47429 .40236 .46851 Mtetra
.83 .799 .822 r
.40236 .46851 .40925 .47429 .42103 .463 .4142 .45685 Mtetra
.818 .792 .827 r
.4142 .45685 .42103 .463 .43278 .45232 .42601 .44587 Mtetra
.805 .785 .834 r
.42601 .44587 .43278 .45232 .44452 .44241 .4378 .4357 Mtetra
.79 .778 .843 r
.4378 .4357 .44452 .44241 .45625 .43334 .44957 .42641 Mtetra
.773 .772 .852 r
.44957 .42641 .45625 .43334 .46797 .42513 .46134 .41801 Mtetra
.756 .766 .861 r
.46134 .41801 .46797 .42513 .4797 .41772 .47311 .41046 Mtetra
.739 .76 .869 r
.47311 .41046 .4797 .41772 .49144 .41106 .48489 .40368 Mtetra
.723 .754 .876 r
.48489 .40368 .49144 .41106 .50321 .40504 .4967 .39756 Mtetra
.709 .748 .882 r
.4967 .39756 .50321 .40504 .51502 .39957 .50854 .392 Mtetra
.696 .743 .887 r
.50854 .392 .51502 .39957 .52686 .39453 .52042 .38689 Mtetra
.686 .739 .891 r
.52042 .38689 .52686 .39453 .53875 .38983 .53234 .38213 Mtetra
.678 .736 .894 r
.53234 .38213 .53875 .38983 .55069 .3854 .54431 .37764 Mtetra
.671 .733 .896 r
.54431 .37764 .55069 .3854 .56268 .38115 .55634 .37336 Mtetra
.667 .731 .898 r
.55634 .37336 .56268 .38115 .57472 .37703 .56841 .36921 Mtetra
.663 .73 .899 r
.56841 .36921 .57472 .37703 .58681 .373 .58054 .36516 Mtetra
.661 .73 .901 r
.58054 .36516 .58681 .373 .59896 .36902 .59272 .36118 Mtetra
.659 .73 .902 r
.59272 .36118 .59896 .36902 .61116 .36506 .60496 .35723 Mtetra
.658 .731 .903 r
.60496 .35723 .61116 .36506 .62342 .36109 .61725 .3533 Mtetra
.657 .732 .905 r
.61725 .3533 .62342 .36109 .63573 .35712 .6296 .34937 Mtetra
.657 .735 .907 r
.6296 .34937 .63573 .35712 .6481 .35311 .64201 .34544 Mtetra
.657 .738 .909 r
.64201 .34544 .6481 .35311 .66052 .34907 .65447 .34148 Mtetra
.657 .741 .912 r
.65447 .34148 .66052 .34907 .673 .345 .66699 .3375 Mtetra
.658 .745 .915 r
.66699 .3375 .673 .345 .68553 .34088 .67957 .33349 Mtetra
.658 .749 .917 r
.67957 .33349 .68553 .34088 .69812 .33673 .6922 .32944 Mtetra
.659 .754 .92 r
.6922 .32944 .69812 .33673 .71076 .33254 .70489 .32534 Mtetra
.66 .758 .923 r
.70489 .32534 .71076 .33254 .72345 .32832 .71764 .3212 Mtetra
.661 .762 .925 r
.71764 .3212 .72345 .32832 .73621 .32405 .73044 .31701 Mtetra
.662 .766 .927 r
.73044 .31701 .73621 .32405 .74901 .31974 .7433 .31275 Mtetra
.663 .769 .929 r
.7433 .31275 .74901 .31974 .76188 .31539 .75621 .30844 Mtetra
.665 .772 .93 r
.75621 .30844 .76188 .31539 .77479 .31099 .76918 .30405 Mtetra
.666 .774 .93 r
.76918 .30405 .77479 .31099 .78777 .30654 .7822 .29959 Mtetra
.668 .776 .93 r
.7822 .29959 .78777 .30654 .80079 .30204 .79527 .29505 Mtetra
.67 .776 .93 r
.79527 .29505 .80079 .30204 .81387 .29748 .8084 .29045 Mtetra
.671 .776 .929 r
.8084 .29045 .81387 .29748 .82701 .29287 .82158 .28577 Mtetra
.673 .776 .928 r
.82158 .28577 .82701 .29287 .8402 .28821 .83481 .28103 Mtetra
.674 .775 .926 r
.83481 .28103 .8402 .28821 .85345 .28351 .8481 .27624 Mtetra
.675 .774 .925 r
.8481 .27624 .85345 .28351 .86675 .27877 .86145 .27139 Mtetra
0 .411 .748 r
.24627 .54284 .2539 .54613 .26441 .5496 .25679 .54637 Mtetra
.03 .554 .862 r
.25679 .54637 .26441 .5496 .27509 .55183 .2675 .54856 Mtetra
.26 .701 .961 r
.2675 .54856 .27509 .55183 .28598 .55247 .27842 .54907 Mtetra
.475 .803 1 r
.27842 .54907 .28598 .55247 .29706 .55126 .28955 .54762 Mtetra
.629 .845 .982 r
.28955 .54762 .29706 .55126 .30833 .54803 .30088 .54408 Mtetra
.723 .85 .942 r
.30088 .54408 .30833 .54803 .31978 .54276 .3124 .53844 Mtetra
.776 .84 .9 r
.3124 .53844 .31978 .54276 .33138 .53554 .32406 .53082 Mtetra
.806 .826 .866 r
.32406 .53082 .33138 .53554 .34309 .52659 .33585 .52146 Mtetra
.823 .813 .84 r
.33585 .52146 .34309 .52659 .35489 .51623 .34772 .5107 Mtetra
.831 .801 .823 r
.34772 .5107 .35489 .51623 .36674 .50484 .35964 .49893 Mtetra
.834 .793 .812 r
.35964 .49893 .36674 .50484 .37862 .49283 .37158 .48659 Mtetra
.833 .786 .807 r
.37158 .48659 .37862 .49283 .3905 .4806 .38352 .47407 Mtetra
.828 .78 .807 r
.38352 .47407 .3905 .4806 .40236 .46851 .39544 .46174 Mtetra
.821 .776 .81 r
.39544 .46174 .40236 .46851 .4142 .45685 .40733 .44989 Mtetra
.812 .773 .817 r
.40733 .44989 .4142 .45685 .42601 .44587 .4192 .43875 Mtetra
.8 .77 .825 r
.4192 .43875 .42601 .44587 .4378 .4357 .43103 .42846 Mtetra
.786 .767 .835 r
.43103 .42846 .4378 .4357 .44957 .42641 .44285 .41908 Mtetra
.771 .763 .846 r
.44285 .41908 .44957 .42641 .46134 .41801 .45466 .41061 Mtetra
.755 .76 .857 r
.45466 .41061 .46134 .41801 .47311 .41046 .46647 .403 Mtetra
.738 .756 .866 r
.46647 .403 .47311 .41046 .48489 .40368 .47829 .39617 Mtetra
.723 .752 .875 r
.47829 .39617 .48489 .40368 .4967 .39756 .49014 .39001 Mtetra
.709 .748 .883 r
.49014 .39001 .4967 .39756 .50854 .392 .50201 .38442 Mtetra
.696 .745 .889 r
.50201 .38442 .50854 .392 .52042 .38689 .51393 .37928 Mtetra
.686 .742 .893 r
.51393 .37928 .52042 .38689 .53234 .38213 .52589 .37451 Mtetra
.678 .739 .897 r
.52589 .37451 .53234 .38213 .54431 .37764 .53789 .37001 Mtetra
.671 .738 .9 r
.53789 .37001 .54431 .37764 .55634 .37336 .54995 .36571 Mtetra
.666 .737 .903 r
.54995 .36571 .55634 .37336 .56841 .36921 .56205 .36157 Mtetra
.662 .737 .905 r
.56205 .36157 .56841 .36921 .58054 .36516 .57422 .35754 Mtetra
.659 .737 .907 r
.57422 .35754 .58054 .36516 .59272 .36118 .58644 .35358 Mtetra
.657 .738 .909 r
.58644 .35358 .59272 .36118 .60496 .35723 .59871 .34967 Mtetra
.655 .739 .912 r
.59871 .34967 .60496 .35723 .61725 .3533 .61104 .34579 Mtetra
.654 .741 .914 r
.61104 .34579 .61725 .3533 .6296 .34937 .62344 .34193 Mtetra
.653 .744 .916 r
.62344 .34193 .6296 .34937 .64201 .34544 .63588 .33806 Mtetra
.653 .747 .919 r
.63588 .33806 .64201 .34544 .65447 .34148 .64839 .33419 Mtetra
.653 .751 .921 r
.64839 .33419 .65447 .34148 .66699 .3375 .66095 .3303 Mtetra
.653 .754 .924 r
.66095 .3303 .66699 .3375 .67957 .33349 .67358 .32638 Mtetra
.653 .759 .927 r
.67358 .32638 .67957 .33349 .6922 .32944 .68626 .32242 Mtetra
.654 .763 .929 r
.68626 .32242 .6922 .32944 .70489 .32534 .699 .31841 Mtetra
.655 .767 .931 r
.699 .31841 .70489 .32534 .71764 .3212 .71179 .31434 Mtetra
.657 .771 .933 r
.71179 .31434 .71764 .3212 .73044 .31701 .72464 .3102 Mtetra
.659 .774 .934 r
.72464 .3102 .73044 .31701 .7433 .31275 .73755 .30598 Mtetra
.661 .777 .935 r
.73755 .30598 .7433 .31275 .75621 .30844 .75051 .30167 Mtetra
.663 .78 .936 r
.75051 .30167 .75621 .30844 .76918 .30405 .76353 .29728 Mtetra
.665 .782 .936 r
.76353 .29728 .76918 .30405 .7822 .29959 .7766 .29279 Mtetra
.668 .783 .935 r
.7766 .29279 .7822 .29959 .79527 .29505 .78972 .28821 Mtetra
.67 .783 .934 r
.78972 .28821 .79527 .29505 .8084 .29045 .80289 .28354 Mtetra
.672 .783 .933 r
.80289 .28354 .8084 .29045 .82158 .28577 .81612 .27879 Mtetra
.674 .783 .931 r
.81612 .27879 .82158 .28577 .83481 .28103 .8294 .27396 Mtetra
.676 .781 .929 r
.8294 .27396 .83481 .28103 .8481 .27624 .84273 .26905 Mtetra
.677 .78 .928 r
.84273 .26905 .8481 .27624 .86145 .27139 .85611 .26409 Mtetra
.025 .498 .878 r
.2387 .53789 .24627 .54284 .25679 .54637 .24925 .54132 Mtetra
.215 .614 .952 r
.24925 .54132 .25679 .54637 .2675 .54856 .25999 .54334 Mtetra
.407 .708 .984 r
.25999 .54334 .2675 .54856 .27842 .54907 .27095 .5436 Mtetra
.56 .761 .972 r
.27095 .5436 .27842 .54907 .28955 .54762 .28213 .54186 Mtetra
.663 .781 .936 r
.28213 .54186 .28955 .54762 .30088 .54408 .29351 .538 Mtetra
.728 .783 .897 r
.29351 .538 .30088 .54408 .3124 .53844 .30508 .53202 Mtetra
.767 .778 .862 r
.30508 .53202 .3124 .53844 .32406 .53082 .3168 .52408 Mtetra
.792 .772 .835 r
.3168 .52408 .32406 .53082 .33585 .52146 .32865 .51442 Mtetra
.807 .766 .816 r
.32865 .51442 .33585 .52146 .34772 .5107 .34057 .50341 Mtetra
.815 .762 .803 r
.34057 .50341 .34772 .5107 .35964 .49893 .35255 .49145 Mtetra
.819 .758 .796 r
.35255 .49145 .35964 .49893 .37158 .48659 .36455 .47896 Mtetra
.819 .756 .794 r
.36455 .47896 .37158 .48659 .38352 .47407 .37654 .46635 Mtetra
.816 .755 .795 r
.37654 .46635 .38352 .47407 .39544 .46174 .38851 .45398 Mtetra
.811 .755 .801 r
.38851 .45398 .39544 .46174 .40733 .44989 .40044 .44212 Mtetra
.803 .755 .809 r
.40044 .44212 .40733 .44989 .4192 .43875 .41235 .431 Mtetra
.793 .755 .819 r
.41235 .431 .4192 .43875 .43103 .42846 .42423 .42074 Mtetra
.781 .755 .83 r
.42423 .42074 .43103 .42846 .44285 .41908 .43609 .41139 Mtetra
.767 .755 .842 r
.43609 .41139 .44285 .41908 .45466 .41061 .44793 .40295 Mtetra
.752 .754 .854 r
.44793 .40295 .45466 .41061 .46647 .403 .45978 .39537 Mtetra
.736 .752 .865 r
.45978 .39537 .46647 .403 .47829 .39617 .47164 .38855 Mtetra
.721 .75 .875 r
.47164 .38855 .47829 .39617 .49014 .39001 .48352 .38241 Mtetra
.708 .748 .883 r
.48352 .38241 .49014 .39001 .50201 .38442 .49543 .37683 Mtetra
.695 .745 .89 r
.49543 .37683 .50201 .38442 .51393 .37928 .50738 .3717 Mtetra
.685 .744 .896 r
.50738 .3717 .51393 .37928 .52589 .37451 .51937 .36693 Mtetra
.676 .742 .9 r
.51937 .36693 .52589 .37451 .53789 .37001 .53141 .36245 Mtetra
.669 .741 .904 r
.53141 .36245 .53789 .37001 .54995 .36571 .54351 .35817 Mtetra
.664 .741 .907 r
.54351 .35817 .54995 .36571 .56205 .36157 .55565 .35406 Mtetra
.66 .741 .91 r
.55565 .35406 .56205 .36157 .57422 .35754 .56785 .35006 Mtetra
.656 .742 .913 r
.56785 .35006 .57422 .35754 .58644 .35358 .58011 .34615 Mtetra
.654 .743 .916 r
.58011 .34615 .58644 .35358 .59871 .34967 .59242 .34229 Mtetra
.652 .745 .918 r
.59242 .34229 .59871 .34967 .61104 .34579 .60479 .33848 Mtetra
.65 .748 .921 r
.60479 .33848 .61104 .34579 .62344 .34193 .61722 .3347 Mtetra
.649 .751 .924 r
.61722 .3347 .62344 .34193 .63588 .33806 .62971 .33092 Mtetra
.648 .754 .927 r
.62971 .33092 .63588 .33806 .64839 .33419 .64226 .32714 Mtetra
.648 .758 .93 r
.64226 .32714 .64839 .33419 .66095 .3303 .65488 .32334 Mtetra
.648 .762 .932 r
.65488 .32334 .66095 .3303 .67358 .32638 .66755 .31951 Mtetra
.649 .766 .935 r
.66755 .31951 .67358 .32638 .68626 .32242 .68027 .31563 Mtetra
.65 .77 .937 r
.68027 .31563 .68626 .32242 .699 .31841 .69306 .31169 Mtetra
.651 .774 .939 r
.69306 .31169 .699 .31841 .71179 .31434 .70591 .30768 Mtetra
.653 .778 .94 r
.70591 .30768 .71179 .31434 .72464 .3102 .71881 .30359 Mtetra
.655 .782 .941 r
.71881 .30359 .72464 .3102 .73755 .30598 .73177 .29939 Mtetra
.658 .785 .941 r
.73177 .29939 .73755 .30598 .75051 .30167 .74478 .2951 Mtetra
.661 .787 .941 r
.74478 .2951 .75051 .30167 .76353 .29728 .75784 .29069 Mtetra
.665 .789 .941 r
.75784 .29069 .76353 .29728 .7766 .29279 .77096 .28617 Mtetra
.668 .79 .94 r
.77096 .28617 .7766 .29279 .78972 .28821 .78413 .28153 Mtetra
.671 .791 .938 r
.78413 .28153 .78972 .28821 .80289 .28354 .79735 .27678 Mtetra
.674 .791 .937 r
.79735 .27678 .80289 .28354 .81612 .27879 .81062 .27194 Mtetra
.676 .79 .935 r
.81062 .27194 .81612 .27879 .8294 .27396 .82394 .26699 Mtetra
.678 .788 .932 r
.82394 .26699 .8294 .27396 .84273 .26905 .83732 .26197 Mtetra
.68 .786 .93 r
.83732 .26197 .84273 .26905 .85611 .26409 .85074 .25688 Mtetra
.198 .545 .929 r
.23122 .53116 .2387 .53789 .24925 .54132 .24179 .53433 Mtetra
.355 .621 .952 r
.24179 .53433 .24925 .54132 .25999 .54334 .25257 .53605 Mtetra
.493 .675 .946 r
.25257 .53605 .25999 .54334 .27095 .5436 .26357 .53598 Mtetra
.598 .706 .919 r
.26357 .53598 .27095 .5436 .28213 .54186 .2748 .53391 Mtetra
.671 .72 .886 r
.2748 .53391 .28213 .54186 .29351 .538 .28622 .52974 Mtetra
.72 .726 .854 r
.28622 .52974 .29351 .538 .30508 .53202 .29784 .52348 Mtetra
.753 .727 .829 r
.29784 .52348 .30508 .53202 .3168 .52408 .30961 .51532 Mtetra
.775 .728 .809 r
.30961 .51532 .3168 .52408 .32865 .51442 .3215 .50551 Mtetra
.789 .728 .795 r
.3215 .50551 .32865 .51442 .34057 .50341 .33347 .49443 Mtetra
.798 .728 .787 r
.33347 .49443 .34057 .50341 .35255 .49145 .34549 .48246 Mtetra
.803 .73 .783 r
.34549 .48246 .35255 .49145 .36455 .47896 .35752 .47004 Mtetra
.805 .732 .783 r
.35752 .47004 .36455 .47896 .37654 .46635 .36955 .45755 Mtetra
.804 .734 .787 r
.36955 .45755 .37654 .46635 .38851 .45398 .38155 .44533 Mtetra
.8 .737 .794 r
.38155 .44533 .38851 .45398 .40044 .44212 .39353 .43364 Mtetra
.794 .741 .803 r
.39353 .43364 .40044 .44212 .41235 .431 .40547 .42269 Mtetra
.785 .744 .815 r
.40547 .42269 .41235 .431 .42423 .42074 .41738 .4126 Mtetra
.775 .746 .827 r
.41738 .4126 .42423 .42074 .43609 .41139 .42928 .40339 Mtetra
.762 .748 .84 r
.42928 .40339 .43609 .41139 .44793 .40295 .44116 .39508 Mtetra
.748 .749 .853 r
.44116 .39508 .44793 .40295 .45978 .39537 .45304 .38759 Mtetra
.733 .749 .865 r
.45304 .38759 .45978 .39537 .47164 .38855 .46494 .38085 Mtetra
.719 .749 .876 r
.46494 .38085 .47164 .38855 .48352 .38241 .47685 .37476 Mtetra
.706 .748 .884 r
.47685 .37476 .48352 .38241 .49543 .37683 .4888 .36922 Mtetra
.694 .746 .892 r
.4888 .36922 .49543 .37683 .50738 .3717 .50078 .36413 Mtetra
.683 .745 .898 r
.50078 .36413 .50738 .3717 .51937 .36693 .51281 .3594 Mtetra
.675 .744 .903 r
.51281 .3594 .51937 .36693 .53141 .36245 .52489 .35494 Mtetra
.667 .744 .907 r
.52489 .35494 .53141 .36245 .54351 .35817 .53701 .35071 Mtetra
.662 .744 .911 r
.53701 .35071 .54351 .35817 .55565 .35406 .54919 .34663 Mtetra
.657 .745 .915 r
.54919 .34663 .55565 .35406 .56785 .35006 .56143 .34269 Mtetra
.653 .746 .918 r
.56143 .34269 .56785 .35006 .58011 .34615 .57372 .33884 Mtetra
.65 .748 .921 r
.57372 .33884 .58011 .34615 .59242 .34229 .58608 .33506 Mtetra
.647 .75 .924 r
.58608 .33506 .59242 .34229 .60479 .33848 .59849 .33133 Mtetra
.645 .753 .927 r
.59849 .33133 .60479 .33848 .61722 .3347 .61096 .32763 Mtetra
.644 .756 .93 r
.61096 .32763 .61722 .3347 .62971 .33092 .6235 .32395 Mtetra
.643 .76 .934 r
.6235 .32395 .62971 .33092 .64226 .32714 .63609 .32026 Mtetra
.642 .764 .937 r
.63609 .32026 .64226 .32714 .65488 .32334 .64875 .31656 Mtetra
.642 .768 .939 r
.64875 .31656 .65488 .32334 .66755 .31951 .66147 .31282 Mtetra
.643 .772 .942 r
.66147 .31282 .66755 .31951 .68027 .31563 .67425 .30903 Mtetra
.644 .777 .944 r
.67425 .30903 .68027 .31563 .69306 .31169 .68709 .30517 Mtetra
.646 .781 .946 r
.68709 .30517 .69306 .31169 .70591 .30768 .69998 .30122 Mtetra
.649 .785 .947 r
.69998 .30122 .70591 .30768 .71881 .30359 .71294 .29717 Mtetra
.652 .789 .947 r
.71294 .29717 .71881 .30359 .73177 .29939 .72595 .293 Mtetra
.656 .792 .947 r
.72595 .293 .73177 .29939 .74478 .2951 .73901 .2887 Mtetra
.66 .795 .947 r
.73901 .2887 .74478 .2951 .75784 .29069 .75212 .28427 Mtetra
.664 .797 .946 r
.75212 .28427 .75784 .29069 .77096 .28617 .76529 .2797 Mtetra
.668 .798 .944 r
.76529 .2797 .77096 .28617 .78413 .28153 .77851 .275 Mtetra
.672 .798 .942 r
.77851 .275 .78413 .28153 .79735 .27678 .79177 .27017 Mtetra
.675 .798 .94 r
.79177 .27017 .79735 .27678 .81062 .27194 .80509 .26521 Mtetra
.678 .797 .938 r
.80509 .26521 .81062 .27194 .82394 .26699 .81846 .26015 Mtetra
.681 .795 .935 r
.81846 .26015 .82394 .26699 .83732 .26197 .83187 .25499 Mtetra
.683 .793 .933 r
.83187 .25499 .83732 .26197 .85074 .25688 .84534 .24976 Mtetra
.325 .556 .918 r
.22384 .52261 .23122 .53116 .24179 .53433 .23445 .52539 Mtetra
.441 .603 .914 r
.23445 .52539 .24179 .53433 .25257 .53605 .24527 .52671 Mtetra
.539 .637 .896 r
.24527 .52671 .25257 .53605 .26357 .53598 .25631 .52626 Mtetra
.615 .66 .87 r
.25631 .52626 .26357 .53598 .2748 .53391 .26757 .52385 Mtetra
.67 .673 .844 r
.26757 .52385 .2748 .53391 .28622 .52974 .27904 .5194 Mtetra
.71 .682 .821 r
.27904 .5194 .28622 .52974 .29784 .52348 .29069 .51296 Mtetra
.738 .688 .803 r
.29069 .51296 .29784 .52348 .30961 .51532 .30249 .5047 Mtetra
.758 .693 .789 r
.30249 .5047 .30961 .51532 .3215 .50551 .31441 .49491 Mtetra
.772 .697 .78 r
.31441 .49491 .3215 .50551 .33347 .49443 .3264 .48394 Mtetra
.782 .702 .775 r
.3264 .48394 .33347 .49443 .34549 .48246 .33845 .47218 Mtetra
.788 .707 .774 r
.33845 .47218 .34549 .48246 .35752 .47004 .3505 .46004 Mtetra
.792 .712 .777 r
.3505 .46004 .35752 .47004 .36955 .45755 .36255 .44786 Mtetra
.792 .718 .782 r
.36255 .44786 .36955 .45755 .38155 .44533 .37458 .43598 Mtetra
.79 .724 .791 r
.37458 .43598 .38155 .44533 .39353 .43364 .38658 .42464 Mtetra
.785 .73 .802 r
.38658 .42464 .39353 .43364 .40547 .42269 .39855 .41401 Mtetra
.778 .736 .814 r
.39855 .41401 .40547 .42269 .41738 .4126 .4105 .4042 Mtetra
.768 .741 .828 r
.4105 .4042 .41738 .4126 .42928 .40339 .42242 .39523 Mtetra
.757 .745 .842 r
.42242 .39523 .42928 .40339 .44116 .39508 .43433 .38711 Mtetra
.744 .748 .855 r
.43433 .38711 .44116 .39508 .45304 .38759 .44625 .37977 Mtetra
.73 .749 .867 r
.44625 .37977 .45304 .38759 .46494 .38085 .45818 .37314 Mtetra
.717 .75 .878 r
.45818 .37314 .46494 .38085 .47685 .37476 .47013 .36713 Mtetra
.704 .749 .887 r
.47013 .36713 .47685 .37476 .4888 .36922 .48211 .36165 Mtetra
.692 .748 .895 r
.48211 .36165 .4888 .36922 .50078 .36413 .49413 .3566 Mtetra
.681 .747 .901 r
.49413 .3566 .50078 .36413 .51281 .3594 .50619 .3519 Mtetra
.672 .747 .906 r
.50619 .3519 .51281 .3594 .52489 .35494 .51831 .34749 Mtetra
.665 .746 .911 r
.51831 .34749 .52489 .35494 .53701 .35071 .53047 .3433 Mtetra
.659 .747 .915 r
.53047 .3433 .53701 .35071 .54919 .34663 .54269 .33928 Mtetra
.653 .747 .919 r
.54269 .33928 .54919 .34663 .56143 .34269 .55496 .3354 Mtetra
.649 .749 .922 r
.55496 .3354 .56143 .34269 .57372 .33884 .56729 .33163 Mtetra
.645 .751 .926 r
.56729 .33163 .57372 .33884 .58608 .33506 .57969 .32793 Mtetra
.642 .753 .929 r
.57969 .32793 .58608 .33506 .59849 .33133 .59214 .3243 Mtetra
.64 .757 .933 r
.59214 .3243 .59849 .33133 .61096 .32763 .60466 .3207 Mtetra
.638 .76 .936 r
.60466 .3207 .61096 .32763 .6235 .32395 .61723 .31712 Mtetra
.637 .764 .94 r
.61723 .31712 .6235 .32395 .63609 .32026 .62988 .31355 Mtetra
.636 .768 .943 r
.62988 .31355 .63609 .32026 .64875 .31656 .64258 .30995 Mtetra
.636 .773 .946 r
.64258 .30995 .64875 .31656 .66147 .31282 .65535 .30631 Mtetra
.637 .778 .948 r
.65535 .30631 .66147 .31282 .67425 .30903 .66818 .30261 Mtetra
.639 .782 .95 r
.66818 .30261 .67425 .30903 .68709 .30517 .68107 .29883 Mtetra
.641 .787 .952 r
.68107 .29883 .68709 .30517 .69998 .30122 .69402 .29494 Mtetra
.645 .792 .953 r
.69402 .29494 .69998 .30122 .71294 .29717 .70702 .29093 Mtetra
.649 .796 .953 r
.70702 .29093 .71294 .29717 .72595 .293 .72008 .28678 Mtetra
.653 .799 .953 r
.72008 .28678 .72595 .293 .73901 .2887 .7332 .28248 Mtetra
.658 .802 .952 r
.7332 .28248 .73901 .2887 .75212 .28427 .74637 .27802 Mtetra
.663 .804 .95 r
.74637 .27802 .75212 .28427 .76529 .2797 .75958 .2734 Mtetra
.668 .806 .949 r
.75958 .2734 .76529 .2797 .77851 .275 .77285 .26862 Mtetra
.673 .806 .946 r
.77285 .26862 .77851 .275 .79177 .27017 .78616 .26369 Mtetra
.677 .806 .944 r
.78616 .26369 .79177 .27017 .80509 .26521 .79953 .25862 Mtetra
.681 .804 .941 r
.79953 .25862 .80509 .26521 .81846 .26015 .81294 .25342 Mtetra
.684 .802 .938 r
.81294 .25342 .81846 .26015 .83187 .25499 .82639 .24811 Mtetra
.686 .799 .935 r
.82639 .24811 .83187 .25499 .84534 .24976 .8399 .24272 Mtetra
.407 .552 .887 r
.21656 .51237 .22384 .52261 .23445 .52539 .22721 .51465 Mtetra
.492 .583 .874 r
.22721 .51465 .23445 .52539 .24527 .52671 .23807 .5155 Mtetra
.564 .607 .854 r
.23807 .5155 .24527 .52671 .25631 .52626 .24915 .51464 Mtetra
.621 .625 .833 r
.24915 .51464 .25631 .52626 .26757 .52385 .26044 .51191 Mtetra
.666 .639 .814 r
.26044 .51191 .26757 .52385 .27904 .5194 .27194 .50726 Mtetra
.699 .65 .797 r
.27194 .50726 .27904 .5194 .29069 .51296 .28361 .50074 Mtetra
.724 .659 .784 r
.28361 .50074 .29069 .51296 .30249 .5047 .29543 .49254 Mtetra
.743 .666 .775 r
.29543 .49254 .30249 .5047 .31441 .49491 .30736 .48295 Mtetra
.758 .674 .77 r
.30736 .48295 .31441 .49491 .3264 .48394 .31937 .47229 Mtetra
.768 .682 .768 r
.31937 .47229 .3264 .48394 .33845 .47218 .33142 .46094 Mtetra
.775 .69 .77 r
.33142 .46094 .33845 .47218 .3505 .46004 .34348 .44927 Mtetra
.78 .699 .774 r
.34348 .44927 .3505 .46004 .36255 .44786 .35554 .43762 Mtetra
.781 .708 .782 r
.35554 .43762 .36255 .44786 .37458 .43598 .36758 .42625 Mtetra
.781 .717 .792 r
.36758 .42625 .37458 .43598 .38658 .42464 .3796 .4154 Mtetra
.777 .726 .804 r
.3796 .4154 .38658 .42464 .39855 .41401 .39159 .40521 Mtetra
.772 .734 .818 r
.39159 .40521 .39855 .41401 .4105 .4042 .40355 .39577 Mtetra
.763 .741 .832 r
.40355 .39577 .4105 .4042 .42242 .39523 .41551 .38712 Mtetra
.753 .747 .846 r
.41551 .38712 .42242 .39523 .43433 .38711 .42745 .37922 Mtetra
.741 .751 .86 r
.42745 .37922 .43433 .38711 .44625 .37977 .4394 .37205 Mtetra
.728 .753 .872 r
.4394 .37205 .44625 .37977 .45818 .37314 .45137 .36553 Mtetra
.715 .753 .882 r
.45137 .36553 .45818 .37314 .47013 .36713 .46335 .35959 Mtetra
.702 .753 .891 r
.46335 .35959 .47013 .36713 .48211 .36165 .47537 .35416 Mtetra
.69 .752 .899 r
.47537 .35416 .48211 .36165 .49413 .3566 .48742 .34914 Mtetra
.68 .751 .905 r
.48742 .34914 .49413 .3566 .50619 .3519 .49952 .34447 Mtetra
.67 .75 .91 r
.49952 .34447 .50619 .3519 .51831 .34749 .51167 .3401 Mtetra
.662 .749 .915 r
.51167 .3401 .51831 .34749 .53047 .3433 .52387 .33595 Mtetra
.656 .749 .919 r
.52387 .33595 .53047 .3433 .54269 .33928 .53612 .33199 Mtetra
.65 .75 .923 r
.53612 .33199 .54269 .33928 .55496 .3354 .54843 .32818 Mtetra
.645 .751 .927 r
.54843 .32818 .55496 .3354 .56729 .33163 .56081 .32449 Mtetra
.64 .753 .931 r
.56081 .32449 .56729 .33163 .57969 .32793 .57324 .32089 Mtetra
.637 .756 .934 r
.57324 .32089 .57969 .32793 .59214 .3243 .58574 .31737 Mtetra
.634 .759 .938 r
.58574 .31737 .59214 .3243 .60466 .3207 .59829 .31388 Mtetra
.631 .763 .942 r
.59829 .31388 .60466 .3207 .61723 .31712 .61092 .31042 Mtetra
.63 .768 .946 r
.61092 .31042 .61723 .31712 .62988 .31355 .62361 .30696 Mtetra
.629 .772 .949 r
.62361 .30696 .62988 .31355 .64258 .30995 .63636 .30348 Mtetra
.629 .777 .952 r
.63636 .30348 .64258 .30995 .65535 .30631 .64918 .29995 Mtetra
.63 .782 .954 r
.64918 .29995 .65535 .30631 .66818 .30261 .66206 .29635 Mtetra
.633 .788 .956 r
.66206 .29635 .66818 .30261 .68107 .29883 .675 .29265 Mtetra
.636 .793 .958 r
.675 .29265 .68107 .29883 .69402 .29494 .688 .28883 Mtetra
.64 .798 .958 r
.688 .28883 .69402 .29494 .70702 .29093 .70106 .28486 Mtetra
.645 .802 .958 r
.70106 .28486 .70702 .29093 .72008 .28678 .71418 .28073 Mtetra
.651 .806 .958 r
.71418 .28073 .72008 .28678 .7332 .28248 .72735 .27642 Mtetra
.657 .809 .957 r
.72735 .27642 .7332 .28248 .74637 .27802 .74057 .27193 Mtetra
.663 .812 .955 r
.74057 .27193 .74637 .27802 .75958 .2734 .75383 .26725 Mtetra
.669 .813 .952 r
.75383 .26725 .75958 .2734 .77285 .26862 .76715 .26239 Mtetra
.675 .814 .95 r
.76715 .26239 .77285 .26862 .78616 .26369 .78051 .25735 Mtetra
.68 .813 .947 r
.78051 .25735 .78616 .26369 .79953 .25862 .79392 .25214 Mtetra
.684 .812 .943 r
.79392 .25214 .79953 .25862 .81294 .25342 .80738 .2468 Mtetra
.688 .809 .94 r
.80738 .2468 .81294 .25342 .82639 .24811 .82088 .24133 Mtetra
.691 .806 .937 r
.82088 .24133 .82639 .24811 .8399 .24272 .83443 .23576 Mtetra
.46 .546 .857 r
.20937 .50064 .21656 .51237 .22721 .51465 .22007 .50235 Mtetra
.523 .567 .842 r
.22007 .50235 .22721 .51465 .23807 .5155 .23097 .50271 Mtetra
.578 .586 .825 r
.23097 .50271 .23807 .5155 .24915 .51464 .24208 .50146 Mtetra
.624 .602 .808 r
.24208 .50146 .24915 .51464 .26044 .51191 .2534 .49847 Mtetra
.66 .616 .793 r
.2534 .49847 .26044 .51191 .27194 .50726 .26491 .4937 Mtetra
.689 .627 .781 r
.26491 .4937 .27194 .50726 .28361 .50074 .27659 .48725 Mtetra
.712 .638 .773 r
.27659 .48725 .28361 .50074 .29543 .49254 .28841 .47928 Mtetra
.73 .649 .768 r
.28841 .47928 .29543 .49254 .30736 .48295 .30033 .47007 Mtetra
.745 .659 .765 r
.30033 .47007 .30736 .48295 .31937 .47229 .31233 .45993 Mtetra
.756 .67 .767 r
.31233 .45993 .31937 .47229 .33142 .46094 .32437 .4492 Mtetra
.764 .681 .771 r
.32437 .4492 .33142 .46094 .34348 .44927 .33643 .43821 Mtetra
.77 .692 .778 r
.33643 .43821 .34348 .44927 .35554 .43762 .34849 .42724 Mtetra
.773 .705 .787 r
.34849 .42724 .35554 .43762 .36758 .42625 .36053 .41655 Mtetra
.774 .717 .799 r
.36053 .41655 .36758 .42625 .3796 .4154 .37255 .40632 Mtetra
.772 .729 .813 r
.37255 .40632 .3796 .4154 .39159 .40521 .38456 .39666 Mtetra
.768 .739 .827 r
.38456 .39666 .39159 .40521 .40355 .39577 .39655 .38765 Mtetra
.761 .749 .842 r
.39655 .38765 .40355 .39577 .41551 .38712 .40853 .37932 Mtetra
.751 .756 .856 r
.40853 .37932 .41551 .38712 .42745 .37922 .4205 .37166 Mtetra
.74 .76 .869 r
.4205 .37166 .42745 .37922 .4394 .37205 .43249 .36463 Mtetra
.728 .762 .88 r
.43249 .36463 .4394 .37205 .45137 .36553 .44449 .35819 Mtetra
.715 .762 .89 r
.44449 .35819 .45137 .36553 .46335 .35959 .45651 .35228 Mtetra
.702 .761 .898 r
.45651 .35228 .46335 .35959 .47537 .35416 .46857 .34685 Mtetra
.69 .759 .904 r
.46857 .34685 .47537 .35416 .48742 .34914 .48066 .34183 Mtetra
.679 .756 .91 r
.48066 .34183 .48742 .34914 .49952 .34447 .49279 .33716 Mtetra
.669 .754 .914 r
.49279 .33716 .49952 .34447 .51167 .3401 .50498 .33279 Mtetra
.66 .753 .919 r
.50498 .33279 .51167 .3401 .52387 .33595 .51721 .32868 Mtetra
.653 .752 .923 r
.51721 .32868 .52387 .33595 .53612 .33199 .5295 .32477 Mtetra
.646 .752 .927 r
.5295 .32477 .53612 .33199 .54843 .32818 .54185 .32103 Mtetra
.64 .754 .931 r
.54185 .32103 .54843 .32818 .56081 .32449 .55426 .31743 Mtetra
.635 .756 .935 r
.55426 .31743 .56081 .32449 .57324 .32089 .56674 .31393 Mtetra
.631 .758 .939 r
.56674 .31393 .57324 .32089 .58574 .31737 .57928 .31052 Mtetra
.627 .762 .943 r
.57928 .31052 .58574 .31737 .59829 .31388 .59188 .30716 Mtetra
.624 .766 .947 r
.59188 .30716 .59829 .31388 .61092 .31042 .60455 .30383 Mtetra
.622 .77 .951 r
.60455 .30383 .61092 .31042 .62361 .30696 .61729 .3005 Mtetra
.621 .775 .955 r
.61729 .3005 .62361 .30696 .63636 .30348 .63009 .29714 Mtetra
.621 .781 .958 r
.63009 .29714 .63636 .30348 .64918 .29995 .64296 .29373 Mtetra
.623 .786 .96 r
.64296 .29373 .64918 .29995 .66206 .29635 .65589 .29024 Mtetra
.626 .792 .962 r
.65589 .29024 .66206 .29635 .675 .29265 .66889 .28662 Mtetra
.63 .798 .963 r
.66889 .28662 .675 .29265 .688 .28883 .68194 .28287 Mtetra
.635 .803 .964 r
.68194 .28287 .688 .28883 .70106 .28486 .69506 .27895 Mtetra
.641 .808 .963 r
.69506 .27895 .70106 .28486 .71418 .28073 .70823 .27484 Mtetra
.648 .813 .962 r
.70823 .27484 .71418 .28073 .72735 .27642 .72145 .27052 Mtetra
.655 .816 .961 r
.72145 .27052 .72735 .27642 .74057 .27193 .73472 .26599 Mtetra
.663 .819 .959 r
.73472 .26599 .74057 .27193 .75383 .26725 .74804 .26124 Mtetra
.67 .82 .956 r
.74804 .26124 .75383 .26725 .76715 .26239 .76141 .25629 Mtetra
.677 .821 .953 r
.76141 .25629 .76715 .26239 .78051 .25735 .77482 .25113 Mtetra
.683 .82 .949 r
.77482 .25113 .78051 .25735 .79392 .25214 .78828 .24578 Mtetra
.688 .819 .945 r
.78828 .24578 .79392 .25214 .80738 .2468 .80178 .24027 Mtetra
.692 .816 .942 r
.80178 .24027 .80738 .2468 .82088 .24133 .81532 .23462 Mtetra
.695 .813 .938 r
.81532 .23462 .82088 .24133 .83443 .23576 .82891 .22886 Mtetra
.496 .543 .834 r
.20225 .48776 .20937 .50064 .22007 .50235 .213 .48888 Mtetra
.544 .558 .82 r
.213 .48888 .22007 .50235 .23097 .50271 .22394 .48874 Mtetra
.587 .573 .805 r
.22394 .48874 .23097 .50271 .24208 .50146 .23508 .48715 Mtetra
.624 .587 .792 r
.23508 .48715 .24208 .50146 .2534 .49847 .24641 .484 Mtetra
.655 .601 .782 r
.24641 .484 .2534 .49847 .26491 .4937 .25792 .47926 Mtetra
.681 .613 .774 r
.25792 .47926 .26491 .4937 .27659 .48725 .26959 .47302 Mtetra
.702 .626 .769 r
.26959 .47302 .27659 .48725 .28841 .47928 .28139 .46548 Mtetra
.719 .638 .767 r
.28139 .46548 .28841 .47928 .30033 .47007 .2933 .45685 Mtetra
.733 .651 .768 r
.2933 .45685 .30033 .47007 .31233 .45993 .30527 .44744 Mtetra
.745 .665 .772 r
.30527 .44744 .31233 .45993 .32437 .4492 .31728 .43753 Mtetra
.755 .68 .779 r
.31728 .43753 .32437 .4492 .33643 .43821 .32932 .42741 Mtetra
.762 .695 .788 r
.32932 .42741 .33643 .43821 .34849 .42724 .34136 .4173 Mtetra
.767 .711 .8 r
.34136 .4173 .34849 .42724 .36053 .41655 .3534 .40741 Mtetra
.769 .728 .814 r
.3534 .40741 .36053 .41655 .37255 .40632 .36542 .39788 Mtetra
.769 .743 .829 r
.36542 .39788 .37255 .40632 .38456 .39666 .37744 .38881 Mtetra
.767 .756 .844 r
.37744 .38881 .38456 .39666 .39655 .38765 .38945 .38025 Mtetra
.761 .767 .858 r
.38945 .38025 .39655 .38765 .40853 .37932 .40146 .37222 Mtetra
.753 .775 .871 r
.40146 .37222 .40853 .37932 .4205 .37166 .41348 .36473 Mtetra
.743 .779 .883 r
.41348 .36473 .4205 .37166 .43249 .36463 .4255 .35777 Mtetra
.731 .78 .892 r
.4255 .35777 .43249 .36463 .44449 .35819 .43754 .35132 Mtetra
.718 .778 .9 r
.43754 .35132 .44449 .35819 .45651 .35228 .4496 .34536 Mtetra
.705 .775 .906 r
.4496 .34536 .45651 .35228 .46857 .34685 .4617 .33985 Mtetra
.692 .77 .911 r
.4617 .33985 .46857 .34685 .48066 .34183 .47383 .33475 Mtetra
.68 .765 .915 r
.47383 .33475 .48066 .34183 .49279 .33716 .486 .33002 Mtetra
.669 .761 .919 r
.486 .33002 .49279 .33716 .50498 .33279 .49822 .32562 Mtetra
.659 .758 .923 r
.49822 .32562 .50498 .33279 .51721 .32868 .5105 .3215 Mtetra
.65 .756 .927 r
.5105 .3215 .51721 .32868 .5295 .32477 .52283 .31762 Mtetra
.642 .755 .931 r
.52283 .31762 .5295 .32477 .54185 .32103 .53521 .31395 Mtetra
.635 .756 .935 r
.53521 .31395 .54185 .32103 .55426 .31743 .54767 .31043 Mtetra
.629 .757 .94 r
.54767 .31043 .55426 .31743 .56674 .31393 .56018 .30704 Mtetra
.624 .76 .944 r
.56018 .30704 .56674 .31393 .57928 .31052 .57276 .30375 Mtetra
.619 .763 .948 r
.57276 .30375 .57928 .31052 .59188 .30716 .58541 .30052 Mtetra
.616 .768 .952 r
.58541 .30052 .59188 .30716 .60455 .30383 .59812 .29733 Mtetra
.614 .772 .956 r
.59812 .29733 .60455 .30383 .61729 .3005 .61091 .29414 Mtetra
.613 .778 .96 r
.61091 .29414 .61729 .3005 .63009 .29714 .62376 .29092 Mtetra
.613 .783 .963 r
.62376 .29092 .63009 .29714 .64296 .29373 .63668 .28764 Mtetra
.615 .79 .965 r
.63668 .28764 .64296 .29373 .65589 .29024 .64967 .28425 Mtetra
.618 .796 .967 r
.64967 .28425 .65589 .29024 .66889 .28662 .66272 .28073 Mtetra
.623 .802 .968 r
.66272 .28073 .66889 .28662 .68194 .28287 .67583 .27705 Mtetra
.629 .808 .968 r
.67583 .27705 .68194 .28287 .69506 .27895 .689 .27317 Mtetra
.637 .814 .968 r
.689 .27317 .69506 .27895 .70823 .27484 .70222 .26908 Mtetra
.645 .818 .966 r
.70222 .26908 .70823 .27484 .72145 .27052 .7155 .26475 Mtetra
.654 .822 .964 r
.7155 .26475 .72145 .27052 .73472 .26599 .72883 .26018 Mtetra
.663 .825 .962 r
.72883 .26018 .73472 .26599 .74804 .26124 .7422 .25536 Mtetra
.671 .827 .958 r
.7422 .25536 .74804 .26124 .76141 .25629 .75562 .25029 Mtetra
.679 .827 .955 r
.75562 .25029 .76141 .25629 .77482 .25113 .76908 .245 Mtetra
.686 .827 .951 r
.76908 .245 .77482 .25113 .78828 .24578 .78259 .2395 Mtetra
.692 .825 .947 r
.78259 .2395 .78828 .24578 .80178 .24027 .79613 .23382 Mtetra
.697 .822 .942 r
.79613 .23382 .80178 .24027 .81532 .23462 .80972 .22798 Mtetra
.7 .818 .938 r
.80972 .22798 .81532 .23462 .82891 .22886 .82335 .22201 Mtetra
.52 .543 .82 r
.19518 .4741 .20225 .48776 .213 .48888 .20597 .47465 Mtetra
.557 .554 .807 r
.20597 .47465 .213 .48888 .22394 .48874 .21694 .4741 Mtetra
.592 .567 .795 r
.21694 .4741 .22394 .48874 .23508 .48715 .22809 .47226 Mtetra
.622 .58 .785 r
.22809 .47226 .23508 .48715 .24641 .484 .23943 .46907 Mtetra
.649 .593 .778 r
.23943 .46907 .24641 .484 .25792 .47926 .25093 .46452 Mtetra
.672 .606 .774 r
.25093 .46452 .25792 .47926 .26959 .47302 .26257 .4587 Mtetra
.692 .621 .772 r
.26257 .4587 .26959 .47302 .28139 .46548 .27434 .45178 Mtetra
.709 .636 .774 r
.27434 .45178 .28139 .46548 .2933 .45685 .2862 .44397 Mtetra
.724 .652 .778 r
.2862 .44397 .2933 .45685 .30527 .44744 .29813 .4355 Mtetra
.736 .67 .786 r
.29813 .4355 .30527 .44744 .31728 .43753 .3101 .42662 Mtetra
.747 .69 .796 r
.3101 .42662 .31728 .43753 .32932 .42741 .3221 .41753 Mtetra
.757 .711 .809 r
.3221 .41753 .32932 .42741 .34136 .4173 .33412 .40843 Mtetra
.764 .733 .824 r
.33412 .40843 .34136 .4173 .3534 .40741 .34614 .39945 Mtetra
.769 .754 .84 r
.34614 .39945 .3534 .40741 .36542 .39788 .35817 .39069 Mtetra
.771 .774 .855 r
.35817 .39069 .36542 .39788 .37744 .38881 .37021 .38221 Mtetra
.77 .79 .87 r
.37021 .38221 .37744 .38881 .38945 .38025 .38224 .37405 Mtetra
.766 .802 .882 r
.38224 .37405 .38945 .38025 .40146 .37222 .39429 .36624 Mtetra
.759 .809 .893 r
.39429 .36624 .40146 .37222 .41348 .36473 .40635 .35882 Mtetra
.75 .811 .901 r
.40635 .35882 .41348 .36473 .4255 .35777 .41842 .35179 Mtetra
.738 .809 .908 r
.41842 .35179 .4255 .35777 .43754 .35132 .43051 .34519 Mtetra
.726 .803 .913 r
.43051 .34519 .43754 .35132 .4496 .34536 .44262 .33903 Mtetra
.712 .796 .916 r
.44262 .33903 .4496 .34536 .4617 .33985 .45476 .3333 Mtetra
.698 .787 .92 r
.45476 .3333 .4617 .33985 .47383 .33475 .46693 .32801 Mtetra
.684 .779 .922 r
.46693 .32801 .47383 .33475 .486 .33002 .47915 .32312 Mtetra
.671 .771 .925 r
.47915 .32312 .486 .33002 .49822 .32562 .49141 .31862 Mtetra
.659 .765 .928 r
.49141 .31862 .49822 .32562 .5105 .3215 .50372 .31445 Mtetra
.648 .761 .932 r
.50372 .31445 .5105 .3215 .52283 .31762 .51609 .31057 Mtetra
.639 .759 .935 r
.51609 .31057 .52283 .31762 .53521 .31395 .52852 .30693 Mtetra
.63 .758 .94 r
.52852 .30693 .53521 .31395 .54767 .31043 .54101 .3035 Mtetra
.623 .759 .944 r
.54101 .3035 .54767 .31043 .56018 .30704 .55356 .30021 Mtetra
.617 .761 .948 r
.55356 .30021 .56018 .30704 .57276 .30375 .56619 .29705 Mtetra
.611 .765 .953 r
.56619 .29705 .57276 .30375 .58541 .30052 .57888 .29396 Mtetra
.607 .769 .957 r
.57888 .29396 .58541 .30052 .59812 .29733 .59164 .29091 Mtetra
.605 .774 .961 r
.59164 .29091 .59812 .29733 .61091 .29414 .60448 .28787 Mtetra
.604 .779 .965 r
.60448 .28787 .61091 .29414 .62376 .29092 .61738 .28479 Mtetra
.604 .785 .968 r
.61738 .28479 .62376 .29092 .63668 .28764 .63035 .28164 Mtetra
.606 .792 .97 r
.63035 .28164 .63668 .28764 .64967 .28425 .64339 .27837 Mtetra
.611 .799 .972 r
.64339 .27837 .64967 .28425 .66272 .28073 .6565 .27495 Mtetra
.616 .805 .972 r
.6565 .27495 .66272 .28073 .67583 .27705 .66966 .27134 Mtetra
.624 .812 .972 r
.66966 .27134 .67583 .27705 .689 .27317 .68289 .2675 Mtetra
.633 .818 .971 r
.68289 .2675 .689 .27317 .70222 .26908 .69617 .26343 Mtetra
.643 .823 .97 r
.69617 .26343 .70222 .26908 .7155 .26475 .7095 .25908 Mtetra
.653 .828 .967 r
.7095 .25908 .7155 .26475 .72883 .26018 .72289 .25446 Mtetra
.663 .831 .964 r
.72289 .25446 .72883 .26018 .7422 .25536 .73631 .24955 Mtetra
.673 .833 .96 r
.73631 .24955 .7422 .25536 .75562 .25029 .74978 .24438 Mtetra
.682 .833 .956 r
.74978 .24438 .75562 .25029 .76908 .245 .7633 .23895 Mtetra
.69 .832 .952 r
.7633 .23895 .76908 .245 .78259 .2395 .77685 .23328 Mtetra
.696 .83 .947 r
.77685 .23328 .78259 .2395 .79613 .23382 .79044 .22741 Mtetra
.701 .827 .943 r
.79044 .22741 .79613 .23382 .80972 .22798 .80407 .22136 Mtetra
.705 .823 .938 r
.80407 .22136 .80972 .22798 .82335 .22201 .81775 .21518 Mtetra
.536 .547 .813 r
.1881 .46009 .19518 .4741 .20597 .47465 .19893 .46016 Mtetra
.565 .555 .802 r
.19893 .46016 .20597 .47465 .21694 .4741 .20993 .45929 Mtetra
.593 .566 .793 r
.20993 .45929 .21694 .4741 .22809 .47226 .22109 .45735 Mtetra
.618 .578 .787 r
.22109 .45735 .22809 .47226 .23943 .46907 .23241 .4543 Mtetra
.642 .592 .783 r
.23241 .4543 .23943 .46907 .25093 .46452 .24387 .45015 Mtetra
.662 .607 .782 r
.24387 .45015 .25093 .46452 .26257 .4587 .25547 .44497 Mtetra
.681 .624 .785 r
.25547 .44497 .26257 .4587 .27434 .45178 .26719 .43891 Mtetra
.698 .643 .791 r
.26719 .43891 .27434 .45178 .2862 .44397 .27898 .43214 Mtetra
.713 .665 .8 r
.27898 .43214 .2862 .44397 .29813 .4355 .29085 .42485 Mtetra
.728 .689 .813 r
.29085 .42485 .29813 .4355 .3101 .42662 .30277 .4172 Mtetra
.741 .716 .828 r
.30277 .4172 .3101 .42662 .3221 .41753 .31473 .40934 Mtetra
.753 .746 .846 r
.31473 .40934 .3221 .41753 .33412 .40843 .32671 .40137 Mtetra
.762 .776 .864 r
.32671 .40137 .33412 .40843 .34614 .39945 .33872 .39338 Mtetra
.77 .804 .881 r
.33872 .39338 .34614 .39945 .35817 .39069 .35076 .3854 Mtetra
.774 .829 .895 r
.35076 .3854 .35817 .39069 .37021 .38221 .36281 .37747 Mtetra
.775 .847 .906 r
.36281 .37747 .37021 .38221 .38224 .37405 .37489 .36962 Mtetra
.773 .858 .913 r
.37489 .36962 .38224 .37405 .39429 .36624 .38698 .36189 Mtetra
.768 .862 .919 r
.38698 .36189 .39429 .36624 .40635 .35882 .39909 .35434 Mtetra
.761 .859 .922 r
.39909 .35434 .40635 .35882 .41842 .35179 .41122 .34705 Mtetra
.751 .851 .925 r
.41122 .34705 .41842 .35179 .43051 .34519 .42337 .34008 Mtetra
.739 .839 .926 r
.42337 .34008 .43051 .34519 .44262 .33903 .43554 .3335 Mtetra
.724 .825 .927 r
.43554 .3335 .44262 .33903 .45476 .3333 .44774 .32738 Mtetra
.709 .811 .928 r
.44774 .32738 .45476 .3333 .46693 .32801 .45997 .32173 Mtetra
.693 .797 .93 r
.45997 .32173 .46693 .32801 .47915 .32312 .47223 .31656 Mtetra
.677 .785 .931 r
.47223 .31656 .47915 .32312 .49141 .31862 .48453 .31185 Mtetra
.662 .775 .933 r
.48453 .31185 .49141 .31862 .50372 .31445 .49689 .30756 Mtetra
.648 .768 .936 r
.49689 .30756 .50372 .31445 .51609 .31057 .50929 .30363 Mtetra
.636 .764 .94 r
.50929 .30363 .51609 .31057 .52852 .30693 .52176 .3 Mtetra
.626 .761 .944 r
.52176 .3 .52852 .30693 .54101 .3035 .53429 .29662 Mtetra
.617 .761 .948 r
.53429 .29662 .54101 .3035 .55356 .30021 .54689 .29344 Mtetra
.609 .762 .953 r
.54689 .29344 .55356 .30021 .56619 .29705 .55955 .2904 Mtetra
.603 .765 .957 r
.55955 .2904 .56619 .29705 .57888 .29396 .57229 .28745 Mtetra
.598 .769 .961 r
.57229 .28745 .57888 .29396 .59164 .29091 .5851 .28455 Mtetra
.595 .774 .965 r
.5851 .28455 .59164 .29091 .60448 .28787 .59798 .28166 Mtetra
.594 .78 .969 r
.59798 .28166 .60448 .28787 .61738 .28479 .61093 .27873 Mtetra
.595 .786 .972 r
.61093 .27873 .61738 .28479 .63035 .28164 .62396 .27571 Mtetra
.598 .793 .974 r
.62396 .27571 .63035 .28164 .64339 .27837 .63705 .27256 Mtetra
.603 .8 .975 r
.63705 .27256 .64339 .27837 .6565 .27495 .65021 .26924 Mtetra
.61 .808 .976 r
.65021 .26924 .6565 .27495 .66966 .27134 .66344 .2657 Mtetra
.619 .815 .975 r
.66344 .2657 .66966 .27134 .68289 .2675 .67672 .26191 Mtetra
.629 .821 .974 r
.67672 .26191 .68289 .2675 .69617 .26343 .69006 .25784 Mtetra
.641 .827 .972 r
.69006 .25784 .69617 .26343 .7095 .25908 .70345 .25347 Mtetra
.652 .832 .969 r
.70345 .25347 .7095 .25908 .72289 .25446 .71689 .24879 Mtetra
.664 .835 .965 r
.71689 .24879 .72289 .25446 .73631 .24955 .73037 .2438 Mtetra
.675 .837 .961 r
.73037 .2438 .73631 .24955 .74978 .24438 .74389 .2385 Mtetra
.685 .838 .956 r
.74389 .2385 .74978 .24438 .7633 .23895 .75746 .23292 Mtetra
.694 .837 .952 r
.75746 .23292 .7633 .23895 .77685 .23328 .77106 .22707 Mtetra
.701 .835 .947 r
.77106 .22707 .77685 .23328 .79044 .22741 .78469 .221 Mtetra
.707 .832 .942 r
.78469 .221 .79044 .22741 .80407 .22136 .79837 .21474 Mtetra
.711 .827 .937 r
.79837 .21474 .80407 .22136 .81775 .21518 .81209 .20834 Mtetra
.546 .554 .814 r
.18099 .44617 .1881 .46009 .19893 .46016 .19185 .44587 Mtetra
.568 .56 .806 r
.19185 .44587 .19893 .46016 .20993 .45929 .20285 .44485 Mtetra
.59 .57 .8 r
.20285 .44485 .20993 .45929 .22109 .45735 .214 .44301 Mtetra
.611 .582 .797 r
.214 .44301 .22109 .45735 .23241 .4543 .22528 .44032 Mtetra
.63 .597 .798 r
.22528 .44032 .23241 .4543 .24387 .45015 .2367 .4368 Mtetra
.649 .615 .802 r
.2367 .4368 .24387 .45015 .25547 .44497 .24823 .43253 Mtetra
.666 .637 .811 r
.24823 .43253 .25547 .44497 .26719 .43891 .25987 .4276 Mtetra
.683 .662 .824 r
.25987 .4276 .26719 .43891 .27898 .43214 .27158 .42214 Mtetra
.699 .693 .84 r
.27158 .42214 .27898 .43214 .29085 .42485 .28337 .41626 Mtetra
.715 .728 .861 r
.28337 .41626 .29085 .42485 .30277 .4172 .29522 .41005 Mtetra
.73 .768 .884 r
.29522 .41005 .30277 .4172 .31473 .40934 .30712 .40358 Mtetra
.743 .811 .906 r
.30712 .40358 .31473 .40934 .32671 .40137 .31908 .39687 Mtetra
.753 .851 .924 r
.31908 .39687 .32671 .40137 .33872 .39338 .33107 .38991 Mtetra
.76 .886 .935 r
.33107 .38991 .33872 .39338 .35076 .3854 .34312 .3827 Mtetra
.764 .911 .939 r
.34312 .3827 .35076 .3854 .36281 .37747 .35521 .37523 Mtetra
.768 .926 .939 r
.35521 .37523 .36281 .37747 .37489 .36962 .36733 .36752 Mtetra
.771 .932 .937 r
.36733 .36752 .37489 .36962 .38698 .36189 .37949 .35966 Mtetra
.773 .929 .936 r
.37949 .35966 .38698 .36189 .39909 .35434 .39168 .35173 Mtetra
.773 .919 .936 r
.39168 .35173 .39909 .35434 .41122 .34705 .40389 .34389 Mtetra
.767 .904 .936 r
.40389 .34389 .41122 .34705 .42337 .34008 .41612 .33627 Mtetra
.757 .884 .936 r
.41612 .33627 .42337 .34008 .43554 .3335 .42837 .32902 Mtetra
.743 .863 .936 r
.42837 .32902 .43554 .3335 .44774 .32738 .44063 .32225 Mtetra
.725 .841 .936 r
.44063 .32225 .44774 .32738 .45997 .32173 .45292 .31604 Mtetra
.706 .82 .936 r
.45292 .31604 .45997 .32173 .47223 .31656 .46524 .31042 Mtetra
.687 .802 .937 r
.46524 .31042 .47223 .31656 .48453 .31185 .47759 .30537 Mtetra
.668 .788 .938 r
.47759 .30537 .48453 .31185 .49689 .30756 .48999 .30086 Mtetra
.651 .777 .941 r
.48999 .30086 .49689 .30756 .50929 .30363 .50243 .29681 Mtetra
.635 .769 .944 r
.50243 .29681 .50929 .30363 .52176 .3 .51494 .29315 Mtetra
.622 .765 .948 r
.51494 .29315 .52176 .3 .53429 .29662 .52751 .2898 Mtetra
.611 .763 .952 r
.52751 .2898 .53429 .29662 .54689 .29344 .54015 .2867 Mtetra
.602 .763 .956 r
.54015 .2867 .54689 .29344 .55955 .2904 .55286 .28378 Mtetra
.594 .765 .961 r
.55286 .28378 .55955 .2904 .57229 .28745 .56564 .28097 Mtetra
.589 .769 .965 r
.56564 .28097 .57229 .28745 .5851 .28455 .57849 .27823 Mtetra
.585 .773 .969 r
.57849 .27823 .5851 .28455 .59798 .28166 .59142 .27549 Mtetra
.584 .779 .972 r
.59142 .27549 .59798 .28166 .61093 .27873 .60443 .27271 Mtetra
.585 .786 .975 r
.60443 .27271 .61093 .27873 .62396 .27571 .61751 .26983 Mtetra
.589 .793 .977 r
.61751 .26983 .62396 .27571 .63705 .27256 .63066 .2668 Mtetra
.595 .801 .978 r
.63066 .2668 .63705 .27256 .65021 .26924 .64387 .26357 Mtetra
.604 .809 .978 r
.64387 .26357 .65021 .26924 .66344 .2657 .65715 .2601 Mtetra
.614 .816 .978 r
.65715 .2601 .66344 .2657 .67672 .26191 .67049 .25635 Mtetra
.626 .823 .976 r
.67049 .25635 .67672 .26191 .69006 .25784 .68389 .25228 Mtetra
.639 .829 .974 r
.68389 .25228 .69006 .25784 .70345 .25347 .69734 .24789 Mtetra
.653 .834 .97 r
.69734 .24789 .70345 .25347 .71689 .24879 .71083 .24314 Mtetra
.666 .838 .966 r
.71083 .24314 .71689 .24879 .73037 .2438 .72437 .23805 Mtetra
.678 .84 .961 r
.72437 .23805 .73037 .2438 .74389 .2385 .73794 .23262 Mtetra
.689 .841 .956 r
.73794 .23262 .74389 .2385 .75746 .23292 .75156 .22687 Mtetra
.699 .84 .951 r
.75156 .22687 .75746 .23292 .77106 .22707 .76521 .22084 Mtetra
.706 .838 .945 r
.76521 .22084 .77106 .22707 .78469 .221 .77889 .21456 Mtetra
.712 .834 .94 r
.77889 .21456 .78469 .221 .79837 .21474 .79261 .20808 Mtetra
.716 .83 .935 r
.79261 .20808 .79837 .21474 .81209 .20834 .80637 .20145 Mtetra
.549 .564 .822 r
.17379 .43273 .18099 .44617 .19185 .44587 .18466 .43226 Mtetra
.564 .57 .817 r
.18466 .43226 .19185 .44587 .20285 .44485 .19565 .4313 Mtetra
.58 .579 .816 r
.19565 .4313 .20285 .44485 .214 .44301 .20677 .42979 Mtetra
.595 .592 .819 r
.20677 .42979 .214 .44301 .22528 .44032 .21799 .42773 Mtetra
.611 .61 .826 r
.21799 .42773 .22528 .44032 .2367 .4368 .22933 .42514 Mtetra
.625 .633 .838 r
.22933 .42514 .2367 .4368 .24823 .43253 .24078 .42206 Mtetra
.639 .663 .857 r
.24078 .42206 .24823 .43253 .25987 .4276 .25231 .41855 Mtetra
.653 .7 .881 r
.25231 .41855 .25987 .4276 .27158 .42214 .26392 .41468 Mtetra
.666 .746 .91 r
.26392 .41468 .27158 .42214 .28337 .41626 .27562 .41047 Mtetra
.676 .799 .94 r
.27562 .41047 .28337 .41626 .29522 .41005 .28738 .40593 Mtetra
.682 .855 .965 r
.28738 .40593 .29522 .41005 .30712 .40358 .29922 .40101 Mtetra
.681 .905 .975 r
.29922 .40101 .30712 .40358 .31908 .39687 .31114 .39564 Mtetra
.674 .94 .964 r
.31114 .39564 .31908 .39687 .33107 .38991 .32313 .38973 Mtetra
.67 .96 .94 r
.32313 .38973 .33107 .38991 .34312 .3827 .3352 .38321 Mtetra
.676 .971 .917 r
.3352 .38321 .34312 .3827 .35521 .37523 .34734 .37605 Mtetra
.695 .978 .903 r
.34734 .37605 .35521 .37523 .36733 .36752 .35954 .36827 Mtetra
.722 .983 .901 r
.35954 .36827 .36733 .36752 .37949 .35966 .3718 .35997 Mtetra
.751 .983 .908 r
.3718 .35997 .37949 .35966 .39168 .35173 .38409 .35134 Mtetra
.772 .975 .918 r
.38409 .35134 .39168 .35173 .40389 .34389 .3964 .3426 Mtetra
.781 .957 .926 r
.3964 .3426 .40389 .34389 .41612 .33627 .40873 .33398 Mtetra
.779 .933 .932 r
.40873 .33398 .41612 .33627 .42837 .32902 .42108 .32573 Mtetra
.767 .904 .936 r
.42108 .32573 .42837 .32902 .44063 .32225 .43342 .31803 Mtetra
.748 .875 .938 r
.43342 .31803 .44063 .32225 .45292 .31604 .44579 .31102 Mtetra
.725 .847 .939 r
.44579 .31102 .45292 .31604 .46524 .31042 .45816 .30474 Mtetra
.701 .823 .94 r
.45816 .30474 .46524 .31042 .47759 .30537 .47057 .29921 Mtetra
.678 .803 .942 r
.47057 .29921 .47759 .30537 .48999 .30086 .48302 .29436 Mtetra
.656 .787 .944 r
.48302 .29436 .48999 .30086 .50243 .29681 .49551 .29011 Mtetra
.636 .775 .947 r
.49551 .29011 .50243 .29681 .51494 .29315 .50806 .28637 Mtetra
.62 .768 .951 r
.50806 .28637 .51494 .29315 .52751 .2898 .52067 .28303 Mtetra
.606 .764 .955 r
.52067 .28303 .52751 .2898 .54015 .2867 .53335 .27999 Mtetra
.595 .763 .959 r
.53335 .27999 .54015 .2867 .55286 .28378 .5461 .27718 Mtetra
.586 .764 .964 r
.5461 .27718 .55286 .28378 .56564 .28097 .55892 .2745 Mtetra
.579 .767 .968 r
.55892 .2745 .56564 .28097 .57849 .27823 .57183 .27191 Mtetra
.576 .772 .972 r
.57183 .27191 .57849 .27823 .59142 .27549 .5848 .26932 Mtetra
.575 .778 .975 r
.5848 .26932 .59142 .27549 .60443 .27271 .59786 .26668 Mtetra
.576 .784 .978 r
.59786 .26668 .60443 .27271 .61751 .26983 .61099 .26394 Mtetra
.581 .792 .979 r
.61099 .26394 .61751 .26983 .63066 .2668 .62419 .26102 Mtetra
.589 .8 .98 r
.62419 .26102 .63066 .2668 .64387 .26357 .63746 .25789 Mtetra
.599 .808 .98 r
.63746 .25789 .64387 .26357 .65715 .2601 .6508 .25448 Mtetra
.611 .816 .979 r
.6508 .25448 .65715 .2601 .67049 .25635 .6642 .25076 Mtetra
.624 .824 .977 r
.6642 .25076 .67049 .25635 .68389 .25228 .67765 .24669 Mtetra
.639 .83 .974 r
.67765 .24669 .68389 .25228 .69734 .24789 .69116 .24226 Mtetra
.654 .835 .97 r
.69116 .24226 .69734 .24789 .71083 .24314 .70471 .23744 Mtetra
.668 .839 .965 r
.70471 .23744 .71083 .24314 .72437 .23805 .7183 .23224 Mtetra
.682 .841 .96 r
.7183 .23224 .72437 .23805 .73794 .23262 .73193 .22667 Mtetra
.693 .842 .954 r
.73193 .22667 .73794 .23262 .75156 .22687 .74559 .22075 Mtetra
.704 .841 .948 r
.74559 .22075 .75156 .22687 .76521 .22084 .75929 .21453 Mtetra
.712 .839 .943 r
.75929 .21453 .76521 .22084 .77889 .21456 .77303 .20804 Mtetra
.718 .836 .937 r
.77303 .20804 .77889 .21456 .79261 .20808 .78679 .20133 Mtetra
.722 .831 .932 r
.78679 .20133 .79261 .20808 .80637 .20145 .8006 .19445 Mtetra
.543 .577 .839 r
.16646 .42015 .17379 .43273 .18466 .43226 .17732 .41972 Mtetra
.55 .582 .839 r
.17732 .41972 .18466 .43226 .19565 .4313 .18828 .41908 Mtetra
.557 .592 .844 r
.18828 .41908 .19565 .4313 .20677 .42979 .19933 .4182 Mtetra
.564 .608 .855 r
.19933 .4182 .20677 .42979 .21799 .42773 .21048 .41708 Mtetra
.569 .631 .873 r
.21048 .41708 .21799 .42773 .22933 .42514 .22171 .41573 Mtetra
.573 .662 .898 r
.22171 .41573 .22933 .42514 .24078 .42206 .23303 .41417 Mtetra
.572 .704 .931 r
.23303 .41417 .24078 .42206 .25231 .41855 .24444 .4124 Mtetra
.563 .756 .968 r
.24444 .4124 .25231 .41855 .26392 .41468 .25593 .41041 Mtetra
.54 .812 .996 r
.25593 .41041 .26392 .41468 .27562 .41047 .26751 .40813 Mtetra
.494 .855 .99 r
.26751 .40813 .27562 .41047 .28738 .40593 .27918 .40546 Mtetra
.429 .862 .929 r
.27918 .40546 .28738 .40593 .29922 .40101 .29096 .40222 Mtetra
.368 .837 .829 r
.29096 .40222 .29922 .40101 .31114 .39564 .30284 .39825 Mtetra
.339 .811 .736 r
.30284 .39825 .31114 .39564 .32313 .38973 .31484 .39335 Mtetra
.353 .807 .681 r
.31484 .39335 .32313 .38973 .3352 .38321 .32695 .3874 Mtetra
.407 .832 .67 r
.32695 .3874 .3352 .38321 .34734 .37605 .33917 .38033 Mtetra
.49 .878 .694 r
.33917 .38033 .34734 .37605 .35954 .36827 .35147 .37218 Mtetra
.586 .93 .742 r
.35147 .37218 .35954 .36827 .3718 .35997 .36385 .36311 Mtetra
.676 .972 .797 r
.36385 .36311 .3718 .35997 .38409 .35134 .37628 .35338 Mtetra
.745 .993 .846 r
.37628 .35338 .38409 .35134 .3964 .3426 .38873 .34333 Mtetra
.786 .992 .883 r
.38873 .34333 .3964 .3426 .40873 .33398 .40119 .33333 Mtetra
.801 .972 .907 r
.40119 .33333 .40873 .33398 .42108 .32573 .41365 .32372 Mtetra
.795 .942 .922 r
.41365 .32372 .42108 .32573 .43342 .31803 .42611 .31478 Mtetra
.776 .908 .931 r
.42611 .31478 .43342 .31803 .44579 .31102 .43856 .30669 Mtetra
.75 .874 .936 r
.43856 .30669 .44579 .31102 .45816 .30474 .45101 .29955 Mtetra
.721 .844 .94 r
.45101 .29955 .45816 .30474 .47057 .29921 .46348 .29336 Mtetra
.691 .818 .943 r
.46348 .29336 .47057 .29921 .48302 .29436 .47598 .28806 Mtetra
.664 .798 .946 r
.47598 .28806 .48302 .29436 .49551 .29011 .48852 .28353 Mtetra
.64 .782 .95 r
.48852 .28353 .49551 .29011 .50806 .28637 .50111 .27965 Mtetra
.619 .772 .954 r
.50111 .27965 .50806 .28637 .52067 .28303 .51376 .27627 Mtetra
.602 .765 .958 r
.51376 .27627 .52067 .28303 .53335 .27999 .52648 .27328 Mtetra
.588 .763 .962 r
.52648 .27328 .53335 .27999 .5461 .27718 .53927 .27056 Mtetra
.578 .763 .966 r
.53927 .27056 .5461 .27718 .55892 .2745 .55214 .26801 Mtetra
.571 .765 .97 r
.55214 .26801 .55892 .2745 .57183 .27191 .56509 .26556 Mtetra
.567 .769 .974 r
.56509 .26556 .57183 .27191 .5848 .26932 .57812 .26312 Mtetra
.566 .775 .977 r
.57812 .26312 .5848 .26932 .59786 .26668 .59122 .26062 Mtetra
.568 .782 .979 r
.59122 .26062 .59786 .26668 .61099 .26394 .6044 .258 Mtetra
.574 .789 .981 r
.6044 .258 .61099 .26394 .62419 .26102 .61766 .25519 Mtetra
.583 .798 .981 r
.61766 .25519 .62419 .26102 .63746 .25789 .63099 .25214 Mtetra
.594 .806 .981 r
.63099 .25214 .63746 .25789 .6508 .25448 .64438 .24879 Mtetra
.608 .815 .979 r
.64438 .24879 .6508 .25448 .6642 .25076 .65784 .24509 Mtetra
.624 .823 .977 r
.65784 .24509 .6642 .25076 .67765 .24669 .67135 .24101 Mtetra
.64 .829 .973 r
.67135 .24101 .67765 .24669 .69116 .24226 .68491 .23653 Mtetra
.656 .835 .969 r
.68491 .23653 .69116 .24226 .70471 .23744 .69852 .23162 Mtetra
.671 .839 .964 r
.69852 .23162 .70471 .23744 .7183 .23224 .71216 .22631 Mtetra
.686 .841 .958 r
.71216 .22631 .7183 .23224 .73193 .22667 .72585 .22059 Mtetra
.698 .842 .952 r
.72585 .22059 .73193 .22667 .74559 .22075 .73956 .2145 Mtetra
.709 .841 .945 r
.73956 .2145 .74559 .22075 .75929 .21453 .75331 .20808 Mtetra
.717 .838 .939 r
.75331 .20808 .75929 .21453 .77303 .20804 .76709 .20137 Mtetra
.723 .835 .934 r
.76709 .20137 .77303 .20804 .78679 .20133 .78091 .19443 Mtetra
.727 .831 .929 r
.78091 .19443 .78679 .20133 .8006 .19445 .79475 .18732 Mtetra
.524 .591 .864 r
.15896 .40871 .16646 .42015 .17732 .41972 .16979 .4086 Mtetra
.518 .596 .872 r
.16979 .4086 .17732 .41972 .18828 .41908 .18068 .40857 Mtetra
.508 .607 .886 r
.18068 .40857 .18828 .41908 .19933 .4182 .19164 .40863 Mtetra
.493 .624 .908 r
.19164 .40863 .19933 .4182 .21048 .41708 .20267 .40878 Mtetra
.468 .65 .938 r
.20267 .40878 .21048 .41708 .22171 .41573 .21377 .40902 Mtetra
.424 .681 .97 r
.21377 .40902 .22171 .41573 .23303 .41417 .22494 .40932 Mtetra
.346 .708 .984 r
.22494 .40932 .23303 .41417 .24444 .4124 .2362 .40962 Mtetra
.221 .701 .934 r
.2362 .40962 .24444 .4124 .25593 .41041 .24754 .4098 Mtetra
.069 .63 .782 r
.24754 .4098 .25593 .41041 .26751 .40813 .25899 .40968 Mtetra
.051 0 0 r
.25899 .40968 .26751 .40813 .27918 .40546 .27056 .40904 Mtetra
.109 0 0 r
.27056 .40904 .27918 .40546 .29096 .40222 .28227 .40757 Mtetra
.112 0 0 r
.28227 .40757 .29096 .40222 .30284 .39825 .29413 .40499 Mtetra
.072 0 0 r
.29413 .40499 .30284 .39825 .31484 .39335 .30615 .40101 Mtetra
0 0 0 r
.30615 .40101 .31484 .39335 .32695 .3874 .31833 .39543 Mtetra
.31833 .39543 .32695 .3874 .33917 .38033 .33065 .38817 Mtetra
.33065 .38817 .33917 .38033 .35147 .37218 .3431 .37929 Mtetra
.3431 .37929 .35147 .37218 .36385 .36311 .35564 .36904 Mtetra
.582 .9 .639 r
.35564 .36904 .36385 .36311 .37628 .35338 .36824 .3578 Mtetra
.707 .97 .739 r
.36824 .3578 .37628 .35338 .38873 .34333 .38086 .34603 Mtetra
.786 .998 .814 r
.38086 .34603 .38873 .34333 .40119 .33333 .39349 .33424 Mtetra
.822 .993 .864 r
.39349 .33424 .40119 .33333 .41365 .32372 .40609 .32291 Mtetra
.825 .968 .895 r
.40609 .32291 .41365 .32372 .42611 .31478 .41867 .31241 Mtetra
.808 .934 .914 r
.41867 .31241 .42611 .31478 .43856 .30669 .43123 .303 Mtetra
.779 .897 .927 r
.43123 .303 .43856 .30669 .45101 .29955 .44377 .29479 Mtetra
.744 .863 .935 r
.44377 .29479 .45101 .29955 .46348 .29336 .45631 .2878 Mtetra
.709 .833 .941 r
.45631 .2878 .46348 .29336 .47598 .28806 .46887 .28193 Mtetra
.675 .808 .946 r
.46887 .28193 .47598 .28806 .48852 .28353 .48146 .27704 Mtetra
.645 .789 .951 r
.48146 .27704 .48852 .28353 .50111 .27965 .49409 .27296 Mtetra
.62 .775 .955 r
.49409 .27296 .50111 .27965 .51376 .27627 .50679 .26951 Mtetra
.599 .766 .959 r
.50679 .26951 .51376 .27627 .52648 .27328 .51955 .26653 Mtetra
.583 .762 .964 r
.51955 .26653 .52648 .27328 .53927 .27056 .53238 .26389 Mtetra
.571 .76 .968 r
.53238 .26389 .53927 .27056 .55214 .26801 .5453 .26145 Mtetra
.563 .762 .971 r
.5453 .26145 .55214 .26801 .56509 .26556 .55829 .25913 Mtetra
.558 .765 .975 r
.55829 .25913 .56509 .26556 .57812 .26312 .57136 .25683 Mtetra
.558 .771 .978 r
.57136 .25683 .57812 .26312 .59122 .26062 .58452 .25446 Mtetra
.561 .778 .98 r
.58452 .25446 .59122 .26062 .6044 .258 .59775 .25196 Mtetra
.568 .786 .981 r
.59775 .25196 .6044 .258 .61766 .25519 .61106 .24925 Mtetra
.579 .794 .981 r
.61106 .24925 .61766 .25519 .63099 .25214 .62444 .24627 Mtetra
.592 .803 .98 r
.62444 .24627 .63099 .25214 .64438 .24879 .63789 .24296 Mtetra
.607 .812 .979 r
.63789 .24296 .64438 .24879 .65784 .24509 .6514 .23927 Mtetra
.624 .82 .976 r
.6514 .23927 .65784 .24509 .67135 .24101 .66497 .23517 Mtetra
.642 .827 .972 r
.66497 .23517 .67135 .24101 .68491 .23653 .67859 .23063 Mtetra
.659 .832 .966 r
.67859 .23063 .68491 .23653 .69852 .23162 .69225 .22563 Mtetra
.675 .836 .961 r
.69225 .22563 .69852 .23162 .71216 .22631 .70595 .22019 Mtetra
.69 .838 .954 r
.70595 .22019 .71216 .22631 .72585 .22059 .71969 .21432 Mtetra
.703 .839 .948 r
.71969 .21432 .72585 .22059 .73956 .2145 .73346 .20805 Mtetra
.714 .838 .941 r
.73346 .20805 .73956 .2145 .75331 .20808 .74726 .20143 Mtetra
.722 .836 .935 r
.74726 .20143 .75331 .20808 .76709 .20137 .76109 .19451 Mtetra
.728 .833 .929 r
.76109 .19451 .76709 .20137 .78091 .19443 .77495 .18734 Mtetra
.732 .828 .924 r
.77495 .18734 .78091 .19443 .79475 .18732 .78884 .17999 Mtetra
.481 .604 .898 r
.15125 .39862 .15896 .40871 .16979 .4086 .16202 .3991 Mtetra
.448 .605 .913 r
.16202 .3991 .16979 .4086 .18068 .40857 .17282 .4 Mtetra
.398 .609 .934 r
.17282 .4 .18068 .40857 .19164 .40863 .18366 .40134 Mtetra
.318 .611 .953 r
.18366 .40134 .19164 .40863 .20267 .40878 .19453 .40312 Mtetra
.19 .595 .943 r
.19453 .40312 .20267 .40878 .21377 .40902 .20546 .40529 Mtetra
0 .529 .849 r
.20546 .40529 .21377 .40902 .22494 .40932 .21645 .40778 Mtetra
.202 0 0 r
.21645 .40778 .22494 .40932 .2362 .40962 .22752 .41043 Mtetra
.34 0 0 r
.22752 .41043 .2362 .40962 .24754 .4098 .2387 .41302 Mtetra
.4 0 0 r
.2387 .41302 .24754 .4098 .25899 .40968 .25001 .41525 Mtetra
.409 0 0 r
.25001 .41525 .25899 .40968 .27056 .40904 .26147 .41673 Mtetra
.387 0 0 r
.26147 .41673 .27056 .40904 .28227 .40757 .27312 .41704 Mtetra
.34 0 0 r
.27312 .41704 .28227 .40757 .29413 .40499 .28497 .41576 Mtetra
.269 0 0 r
.28497 .41576 .29413 .40499 .30615 .40101 .29704 .41251 Mtetra
.169 0 0 r
.29704 .41251 .30615 .40101 .31833 .39543 .30932 .40702 Mtetra
.034 0 0 r
.30932 .40702 .31833 .39543 .33065 .38817 .32179 .39923 Mtetra
0 0 0 r
.32179 .39923 .33065 .38817 .3431 .37929 .33442 .38923 Mtetra
.33442 .38923 .3431 .37929 .35564 .36904 .34716 .37739 Mtetra
.536 .839 .521 r
.34716 .37739 .35564 .36904 .36824 .3578 .35997 .36421 Mtetra
.697 .943 .652 r
.35997 .36421 .36824 .3578 .38086 .34603 .3728 .35032 Mtetra
.8 .992 .75 r
.3728 .35032 .38086 .34603 .39349 .33424 .38562 .3364 Mtetra
.848 .998 .817 r
.38562 .3364 .39349 .33424 .40609 .32291 .3984 .32303 Mtetra
.856 .978 .861 r
.3984 .32303 .40609 .32291 .41867 .31241 .41112 .31072 Mtetra
.839 .947 .89 r
.41112 .31072 .41867 .31241 .43123 .303 .4238 .29976 Mtetra
.808 .911 .911 r
.4238 .29976 .43123 .303 .44377 .29479 .43644 .29033 Mtetra
.769 .876 .925 r
.43644 .29033 .44377 .29479 .45631 .2878 .44906 .28241 Mtetra
.728 .844 .936 r
.44906 .28241 .45631 .2878 .46887 .28193 .46168 .27589 Mtetra
.688 .816 .944 r
.46168 .27589 .46887 .28193 .48146 .27704 .47432 .27057 Mtetra
.653 .794 .95 r
.47432 .27057 .48146 .27704 .49409 .27296 .48701 .26625 Mtetra
.622 .777 .955 r
.48701 .26625 .49409 .27296 .50679 .26951 .49975 .2627 Mtetra
.598 .766 .96 r
.49975 .2627 .50679 .26951 .51955 .26653 .51255 .25972 Mtetra
.579 .76 .964 r
.51255 .25972 .51955 .26653 .53238 .26389 .52542 .25713 Mtetra
.565 .757 .968 r
.52542 .25713 .53238 .26389 .5453 .26145 .53838 .25479 Mtetra
.556 .758 .972 r
.53838 .25479 .5453 .26145 .55829 .25913 .55142 .25259 Mtetra
.552 .761 .975 r
.55142 .25259 .55829 .25913 .57136 .25683 .56454 .2504 Mtetra
.552 .766 .977 r
.56454 .2504 .57136 .25683 .58452 .25446 .57774 .24815 Mtetra
.556 .773 .979 r
.57774 .24815 .58452 .25446 .59775 .25196 .59102 .24575 Mtetra
.564 .781 .98 r
.59102 .24575 .59775 .25196 .61106 .24925 .60438 .24313 Mtetra
.576 .789 .98 r
.60438 .24313 .61106 .24925 .62444 .24627 .61782 .2402 Mtetra
.591 .798 .979 r
.61782 .2402 .62444 .24627 .63789 .24296 .63132 .23692 Mtetra
.608 .807 .977 r
.63132 .23692 .63789 .24296 .6514 .23927 .64489 .23324 Mtetra
.626 .815 .973 r
.64489 .23324 .6514 .23927 .66497 .23517 .65851 .2291 Mtetra
.644 .822 .968 r
.65851 .2291 .66497 .23517 .67859 .23063 .67219 .22449 Mtetra
.663 .828 .963 r
.67219 .22449 .67859 .23063 .69225 .22563 .68591 .21939 Mtetra
.679 .832 .956 r
.68591 .21939 .69225 .22563 .70595 .22019 .69966 .21382 Mtetra
.695 .834 .95 r
.69966 .21382 .70595 .22019 .71969 .21432 .71345 .2078 Mtetra
.708 .834 .943 r
.71345 .2078 .71969 .21432 .73346 .20805 .72728 .20135 Mtetra
.718 .834 .936 r
.72728 .20135 .73346 .20805 .74726 .20143 .74113 .19452 Mtetra
.727 .832 .93 r
.74113 .19452 .74726 .20143 .76109 .19451 .755 .18739 Mtetra
.733 .828 .924 r
.755 .18739 .76109 .19451 .77495 .18734 .76891 .18 Mtetra
.737 .824 .919 r
.76891 .18 .77495 .18734 .78884 .17999 .78285 .17242 Mtetra
.394 .605 .932 r
.14331 .38997 .15125 .39862 .16202 .3991 .15399 .39134 Mtetra
.3 .586 .942 r
.15399 .39134 .16202 .3991 .17282 .4 .16466 .39348 Mtetra
.151 .543 .925 r
.16466 .39348 .17282 .4 .18366 .40134 .17534 .39642 Mtetra
0 .448 .826 r
.17534 .39642 .18366 .40134 .19453 .40312 .18603 .40013 Mtetra
.306 0 0 r
.18603 .40013 .19453 .40312 .20546 .40529 .19675 .40454 Mtetra
.471 0 0 r
.19675 .40454 .20546 .40529 .21645 .40778 .20754 .40949 Mtetra
.545 0 0 r
.20754 .40949 .21645 .40778 .22752 .41043 .21841 .41472 Mtetra
.565 .054 0 r
.21841 .41472 .22752 .41043 .2387 .41302 .2294 .41988 Mtetra
.556 .08 .079 r
.2294 .41988 .2387 .41302 .25001 .41525 .24056 .42452 Mtetra
.529 .078 .124 r
.24056 .42452 .25001 .41525 .26147 .41673 .25192 .42811 Mtetra
.487 .054 .141 r
.25192 .42811 .26147 .41673 .27312 .41704 .26353 .43008 Mtetra
.428 .007 .136 r
.26353 .43008 .27312 .41704 .28497 .41576 .27539 .4299 Mtetra
.346 0 .107 r
.27539 .4299 .28497 .41576 .29704 .41251 .28754 .42709 Mtetra
.234 0 .051 r
.28754 .42709 .29704 .41251 .30932 .40702 .29995 .42136 Mtetra
.082 0 0 r
.29995 .42136 .30932 .40702 .32179 .39923 .3126 .41264 Mtetra
0 0 0 r
.3126 .41264 .32179 .39923 .33442 .38923 .32545 .40114 Mtetra
.32545 .40114 .33442 .38923 .34716 .37739 .33843 .38731 Mtetra
.569 .836 .483 r
.33843 .38731 .34716 .37739 .35997 .36421 .35149 .37184 Mtetra
.739 .942 .619 r
.35149 .37184 .35997 .36421 .3728 .35032 .36457 .35553 Mtetra
.839 .988 .717 r
.36457 .35553 .3728 .35032 .38562 .3364 .3776 .3392 Mtetra
.882 .992 .784 r
.3776 .3392 .38562 .3364 .3984 .32303 .39058 .3236 Mtetra
.887 .974 .83 r
.39058 .3236 .3984 .32303 .41112 .31072 .40347 .3093 Mtetra
.868 .946 .864 r
.40347 .3093 .41112 .31072 .4238 .29976 .41628 .2967 Mtetra
.835 .914 .89 r
.41628 .2967 .4238 .29976 .43644 .29033 .42903 .28595 Mtetra
.793 .881 .91 r
.42903 .28595 .43644 .29033 .44906 .28241 .44173 .27704 Mtetra
.747 .849 .926 r
.44173 .27704 .44906 .28241 .46168 .27589 .45442 .26982 Mtetra
.702 .821 .938 r
.45442 .26982 .46168 .27589 .47432 .27057 .46712 .26405 Mtetra
.661 .797 .947 r
.46712 .26405 .47432 .27057 .48701 .26625 .47986 .25946 Mtetra
.626 .778 .954 r
.47986 .25946 .48701 .26625 .49975 .2627 .49264 .25579 Mtetra
.598 .765 .959 r
.49264 .25579 .49975 .2627 .51255 .25972 .50548 .25278 Mtetra
.576 .757 .964 r
.50548 .25278 .51255 .25972 .52542 .25713 .5184 .25024 Mtetra
.56 .753 .968 r
.5184 .25024 .52542 .25713 .53838 .25479 .5314 .24798 Mtetra
.551 .753 .971 r
.5314 .24798 .53838 .25479 .55142 .25259 .54448 .24587 Mtetra
.546 .755 .974 r
.54448 .24587 .55142 .25259 .56454 .2504 .55764 .2438 Mtetra
.547 .76 .976 r
.55764 .2438 .56454 .2504 .57774 .24815 .57089 .24165 Mtetra
.552 .767 .977 r
.57089 .24165 .57774 .24815 .59102 .24575 .58422 .23933 Mtetra
.562 .775 .978 r
.58422 .23933 .59102 .24575 .60438 .24313 .59764 .23677 Mtetra
.575 .783 .978 r
.59764 .23677 .60438 .24313 .61782 .2402 .61112 .23389 Mtetra
.591 .792 .976 r
.61112 .23389 .61782 .2402 .63132 .23692 .62468 .23062 Mtetra
.609 .801 .973 r
.62468 .23062 .63132 .23692 .64489 .23324 .6383 .22691 Mtetra
.629 .809 .969 r
.6383 .22691 .64489 .23324 .65851 .2291 .65198 .22273 Mtetra
.648 .816 .964 r
.65198 .22273 .65851 .2291 .67219 .22449 .66571 .21804 Mtetra
.666 .821 .958 r
.66571 .21804 .67219 .22449 .68591 .21939 .67948 .21284 Mtetra
.684 .825 .951 r
.67948 .21284 .68591 .21939 .69966 .21382 .69329 .20713 Mtetra
.699 .827 .944 r
.69329 .20713 .69966 .21382 .71345 .2078 .70714 .20094 Mtetra
.712 .828 .937 r
.70714 .20094 .71345 .2078 .72728 .20135 .72101 .19432 Mtetra
.723 .827 .93 r
.72101 .19432 .72728 .20135 .74113 .19452 .73491 .1873 Mtetra
.731 .825 .923 r
.73491 .1873 .74113 .19452 .755 .18739 .74884 .17996 Mtetra
.737 .823 .918 r
.74884 .17996 .755 .18739 .76891 .18 .7628 .17235 Mtetra
.74 .819 .913 r
.7628 .17235 .76891 .18 .78285 .17242 .77678 .16456 Mtetra
.232 .567 .938 r
.13514 .38272 .14331 .38997 .15399 .39134 .14569 .38524 Mtetra
.025 .478 .877 r
.14569 .38524 .15399 .39134 .16466 .39348 .1562 .3889 Mtetra
0 .317 .7 r
.1562 .3889 .16466 .39348 .17534 .39642 .16668 .39371 Mtetra
.473 0 0 r
.16668 .39371 .17534 .39642 .18603 .40013 .17716 .39962 Mtetra
.597 .033 0 r
.17716 .39962 .18603 .40013 .19675 .40454 .18766 .40649 Mtetra
.644 .124 0 r
.18766 .40649 .19675 .40454 .20754 .40949 .19821 .41407 Mtetra
.651 .17 .098 r
.19821 .41407 .20754 .40949 .21841 .41472 .20886 .42197 Mtetra
.639 .187 .163 r
.20886 .42197 .21841 .41472 .2294 .41988 .21967 .42971 Mtetra
.614 .183 .2 r
.21967 .42971 .2294 .41988 .24056 .42452 .23069 .43668 Mtetra
.579 .162 .216 r
.23069 .43668 .24056 .42452 .25192 .42811 .24196 .44221 Mtetra
.53 .123 .214 r
.24196 .44221 .25192 .42811 .26353 .43008 .25354 .44559 Mtetra
.463 .062 .193 r
.25354 .44559 .26353 .43008 .27539 .4299 .26545 .44616 Mtetra
.369 0 .151 r
.26545 .44616 .27539 .4299 .28754 .42709 .27771 .44342 Mtetra
.237 0 .078 r
.27771 .44342 .28754 .42709 .29995 .42136 .29029 .43704 Mtetra
.052 0 0 r
.29029 .43704 .29995 .42136 .3126 .41264 .30317 .42701 Mtetra
0 0 0 r
.30317 .42701 .3126 .41264 .32545 .40114 .31627 .41364 Mtetra
.31627 .41364 .32545 .40114 .33843 .38731 .32953 .39754 Mtetra
.68 .889 .525 r
.32953 .39754 .33843 .38731 .35149 .37184 .34286 .37954 Mtetra
.823 .964 .64 r
.34286 .37954 .35149 .37184 .36457 .35553 .3562 .36064 Mtetra
.894 .984 .715 r
.3562 .36064 .36457 .35553 .3776 .3392 .36947 .34182 Mtetra
.918 .976 .767 r
.36947 .34182 .3776 .3392 .39058 .3236 .38266 .32393 Mtetra
.913 .956 .806 r
.38266 .32393 .39058 .3236 .40347 .3093 .39572 .30765 Mtetra
.89 .931 .839 r
.39572 .30765 .40347 .3093 .41628 .2967 .40868 .2934 Mtetra
.855 .904 .868 r
.40868 .2934 .41628 .2967 .42903 .28595 .42154 .28136 Mtetra
.811 .875 .893 r
.42154 .28136 .42903 .28595 .44173 .27704 .43433 .27148 Mtetra
.764 .847 .914 r
.43433 .27148 .44173 .27704 .45442 .26982 .4471 .26358 Mtetra
.715 .82 .93 r
.4471 .26358 .45442 .26982 .46712 .26405 .45985 .25736 Mtetra
.67 .796 .942 r
.45985 .25736 .46712 .26405 .47986 .25946 .47263 .25251 Mtetra
.63 .777 .951 r
.47263 .25251 .47986 .25946 .49264 .25579 .48546 .24871 Mtetra
.598 .762 .957 r
.48546 .24871 .49264 .25579 .50548 .25278 .49835 .24567 Mtetra
.574 .753 .962 r
.49835 .24567 .50548 .25278 .5184 .25024 .5113 .24316 Mtetra
.557 .748 .966 r
.5113 .24316 .5184 .25024 .5314 .24798 .52434 .24097 Mtetra
.547 .747 .969 r
.52434 .24097 .5314 .24798 .54448 .24587 .53746 .23894 Mtetra
.543 .749 .972 r
.53746 .23894 .54448 .24587 .55764 .2438 .55067 .23695 Mtetra
.544 .753 .973 r
.55067 .23695 .55764 .2438 .57089 .24165 .56397 .23488 Mtetra
.551 .76 .974 r
.56397 .23488 .57089 .24165 .58422 .23933 .57735 .23263 Mtetra
.562 .767 .975 r
.57735 .23263 .58422 .23933 .59764 .23677 .59081 .23011 Mtetra
.576 .776 .974 r
.59081 .23011 .59764 .23677 .61112 .23389 .60435 .22725 Mtetra
.593 .785 .972 r
.60435 .22725 .61112 .23389 .62468 .23062 .61796 .22397 Mtetra
.612 .793 .968 r
.61796 .22397 .62468 .23062 .6383 .22691 .63163 .22023 Mtetra
.632 .801 .964 r
.63163 .22023 .6383 .22691 .65198 .22273 .64536 .21599 Mtetra
.652 .808 .958 r
.64536 .21599 .65198 .22273 .66571 .21804 .65915 .21121 Mtetra
.67 .813 .952 r
.65915 .21121 .66571 .21804 .67948 .21284 .67297 .2059 Mtetra
.688 .817 .944 r
.67297 .2059 .67948 .21284 .69329 .20713 .68684 .20005 Mtetra
.703 .819 .937 r
.68684 .20005 .69329 .20713 .70714 .20094 .70073 .19371 Mtetra
.716 .82 .93 r
.70073 .19371 .70714 .20094 .72101 .19432 .71466 .18691 Mtetra
.726 .819 .923 r
.71466 .18691 .72101 .19432 .73491 .1873 .72861 .1797 Mtetra
.734 .818 .917 r
.72861 .1797 .73491 .1873 .74884 .17996 .74259 .17216 Mtetra
.739 .815 .911 r
.74259 .17216 .74884 .17996 .7628 .17235 .7566 .16436 Mtetra
.743 .812 .907 r
.7566 .16436 .7628 .17235 .77678 .16456 .77063 .15637 Mtetra
0 .451 .856 r
.12674 .37671 .13514 .38272 .14569 .38524 .13713 .38059 Mtetra
0 .255 .644 r
.13713 .38059 .14569 .38524 .1562 .3889 .14746 .38596 Mtetra
.541 0 0 r
.14746 .38596 .1562 .3889 .16668 .39371 .15772 .39282 Mtetra
.656 .109 0 r
.15772 .39282 .16668 .39371 .17716 .39962 .16796 .40108 Mtetra
.697 .195 .042 r
.16796 .40108 .17716 .39962 .18766 .40649 .17821 .4105 Mtetra
.704 .238 .141 r
.17821 .4105 .18766 .40649 .19821 .41407 .18852 .42072 Mtetra
.694 .254 .201 r
.18852 .42072 .19821 .41407 .20886 .42197 .19896 .43122 Mtetra
.674 .252 .236 r
.19896 .43122 .20886 .42197 .21967 .42971 .20959 .44137 Mtetra
.645 .235 .253 r
.20959 .44137 .21967 .42971 .23069 .43668 .22049 .45041 Mtetra
.604 .202 .254 r
.22049 .45041 .23069 .43668 .24196 .44221 .2317 .45751 Mtetra
.549 .151 .239 r
.2317 .45751 .24196 .44221 .25354 .44559 .24329 .46186 Mtetra
.471 .073 .204 r
.24329 .46186 .25354 .44559 .26545 .44616 .25528 .46274 Mtetra
.355 0 .141 r
.25528 .46274 .26545 .44616 .27771 .44342 .26769 .45959 Mtetra
.181 0 .038 r
.26769 .45959 .27771 .44342 .29029 .43704 .28048 .45214 Mtetra
0 0 0 r
.28048 .45214 .29029 .43704 .30317 .42701 .29361 .44045 Mtetra
.29361 .44045 .30317 .42701 .31627 .41364 .30699 .42496 Mtetra
.654 .869 .494 r
.30699 .42496 .31627 .41364 .32953 .39754 .32054 .40644 Mtetra
.829 .956 .615 r
.32054 .40644 .32953 .39754 .34286 .37954 .33416 .38589 Mtetra
.911 .974 .684 r
.33416 .38589 .34286 .37954 .3562 .36064 .34776 .36446 Mtetra
.94 .963 .726 r
.34776 .36446 .3562 .36064 .36947 .34182 .36128 .34325 Mtetra
.942 .944 .758 r
.36128 .34325 .36947 .34182 .38266 .32393 .37467 .32324 Mtetra
.927 .924 .788 r
.37467 .32324 .38266 .32393 .39572 .30765 .38791 .30515 Mtetra
.901 .903 .817 r
.38791 .30515 .39572 .30765 .40868 .2934 .40101 .28942 Mtetra
.866 .882 .847 r
.40101 .28942 .40868 .2934 .42154 .28136 .41398 .27622 Mtetra
.823 .86 .875 r
.41398 .27622 .42154 .28136 .43433 .27148 .42687 .26549 Mtetra
.775 .837 .9 r
.42687 .26549 .43433 .27148 .4471 .26358 .4397 .257 Mtetra
.725 .814 .92 r
.4397 .257 .4471 .26358 .45985 .25736 .45252 .25039 Mtetra
.677 .792 .936 r
.45252 .25039 .45985 .25736 .47263 .25251 .46535 .24532 Mtetra
.634 .773 .947 r
.46535 .24532 .47263 .25251 .48546 .24871 .47822 .24141 Mtetra
.599 .758 .954 r
.47822 .24141 .48546 .24871 .49835 .24567 .49114 .23834 Mtetra
.573 .748 .96 r
.49114 .23834 .49835 .24567 .5113 .24316 .50414 .23585 Mtetra
.555 .742 .963 r
.50414 .23585 .5113 .24316 .52434 .24097 .51722 .23371 Mtetra
.545 .74 .966 r
.51722 .23371 .52434 .24097 .53746 .23894 .53038 .23174 Mtetra
.541 .742 .968 r
.53038 .23174 .53746 .23894 .55067 .23695 .54363 .22981 Mtetra
.543 .746 .97 r
.54363 .22981 .55067 .23695 .56397 .23488 .55697 .2278 Mtetra
.551 .752 .97 r
.55697 .2278 .56397 .23488 .57735 .23263 .5704 .22558 Mtetra
.563 .759 .97 r
.5704 .22558 .57735 .23263 .59081 .23011 .58391 .22309 Mtetra
.578 .767 .969 r
.58391 .22309 .59081 .23011 .60435 .22725 .5975 .22022 Mtetra
.596 .776 .966 r
.5975 .22022 .60435 .22725 .61796 .22397 .61115 .21693 Mtetra
.616 .784 .962 r
.61115 .21693 .61796 .22397 .63163 .22023 .62488 .21314 Mtetra
.636 .792 .957 r
.62488 .21314 .63163 .22023 .64536 .21599 .63866 .20882 Mtetra
.655 .798 .951 r
.63866 .20882 .64536 .21599 .65915 .21121 .6525 .20394 Mtetra
.674 .803 .944 r
.6525 .20394 .65915 .21121 .67297 .2059 .66638 .19851 Mtetra
.691 .807 .937 r
.66638 .19851 .67297 .2059 .68684 .20005 .68029 .19253 Mtetra
.706 .809 .929 r
.68029 .19253 .68684 .20005 .70073 .19371 .69424 .18603 Mtetra
.718 .81 .922 r
.69424 .18603 .70073 .19371 .71466 .18691 .70822 .17906 Mtetra
.728 .81 .915 r
.70822 .17906 .71466 .18691 .72861 .1797 .72222 .17168 Mtetra
.736 .808 .909 r
.72222 .17168 .72861 .1797 .74259 .17216 .73625 .16396 Mtetra
.741 .807 .904 r
.73625 .16396 .74259 .17216 .7566 .16436 .75031 .15598 Mtetra
.744 .804 .9 r
.75031 .15598 .7566 .16436 .77063 .15637 .7644 .14781 Mtetra
0 .268 .67 r
.11813 .37164 .12674 .37671 .13713 .38059 .12836 .37699 Mtetra
.543 0 0 r
.12836 .37699 .13713 .38059 .14746 .38596 .13847 .38416 Mtetra
.676 .131 0 r
.13847 .38416 .14746 .38596 .15772 .39282 .14851 .39312 Mtetra
.728 .227 .042 r
.14851 .39312 .15772 .39282 .16796 .40108 .1585 .40371 Mtetra
.741 .276 .145 r
.1585 .40371 .16796 .40108 .17821 .4105 .1685 .41559 Mtetra
.736 .297 .208 r
.1685 .41559 .17821 .4105 .18852 .42072 .17858 .42827 Mtetra
.721 .3 .246 r
.17858 .42827 .18852 .42072 .19896 .43122 .18883 .44109 Mtetra
.698 .288 .265 r
.18883 .44109 .19896 .43122 .20959 .44137 .19931 .45326 Mtetra
.666 .261 .268 r
.19931 .45326 .20959 .44137 .22049 .45041 .21011 .46388 Mtetra
.621 .217 .257 r
.21011 .46388 .22049 .45041 .2317 .45751 .22131 .47201 Mtetra
.555 .149 .226 r
.22131 .47201 .2317 .45751 .24329 .46186 .23295 .47676 Mtetra
.454 .042 .168 r
.23295 .47676 .24329 .46186 .25528 .46274 .24507 .47738 Mtetra
.29 0 .065 r
.24507 .47738 .25528 .46274 .26769 .45959 .25766 .47333 Mtetra
.025 0 0 r
.25766 .47333 .26769 .45959 .28048 .45214 .27069 .46442 Mtetra
0 0 0 r
.27069 .46442 .28048 .45214 .29361 .44045 .28408 .45083 Mtetra
.678 .897 .543 r
.28408 .45083 .29361 .44045 .30699 .42496 .29775 .43314 Mtetra
.864 .97 .651 r
.29775 .43314 .30699 .42496 .32054 .40644 .31159 .41227 Mtetra
.936 .966 .696 r
.31159 .41227 .32054 .40644 .33416 .38589 .32549 .38937 Mtetra
.957 .942 .716 r
.32549 .38937 .33416 .38589 .34776 .36446 .33934 .36571 Mtetra
.956 .917 .732 r
.33934 .36571 .34776 .36446 .36128 .34325 .35309 .34249 Mtetra
.944 .897 .75 r
.35309 .34249 .36128 .34325 .37467 .32324 .36667 .32073 Mtetra
.925 .88 .772 r
.36667 .32073 .37467 .32324 .38791 .30515 .38007 .30119 Mtetra
.899 .866 .798 r
.38007 .30119 .38791 .30515 .40101 .28942 .3933 .2843 Mtetra
.866 .853 .827 r
.3933 .2843 .40101 .28942 .41398 .27622 .40637 .27023 Mtetra
.826 .838 .857 r
.40637 .27023 .41398 .27622 .42687 .26549 .41934 .25886 Mtetra
.779 .821 .885 r
.41934 .25886 .42687 .26549 .4397 .257 .43224 .24992 Mtetra
.73 .802 .909 r
.43224 .24992 .4397 .257 .45252 .25039 .44512 .24304 Mtetra
.681 .783 .928 r
.44512 .24304 .45252 .25039 .46535 .24532 .45799 .2378 Mtetra
.637 .766 .941 r
.45799 .2378 .46535 .24532 .47822 .24141 .4709 .23382 Mtetra
.6 .751 .95 r
.4709 .23382 .47822 .24141 .49114 .23834 .48387 .23073 Mtetra
.573 .741 .956 r
.48387 .23073 .49114 .23834 .50414 .23585 .49691 .22825 Mtetra
.555 .735 .96 r
.49691 .22825 .50414 .23585 .51722 .23371 .51003 .22615 Mtetra
.544 .733 .962 r
.51003 .22615 .51722 .23371 .53038 .23174 .52323 .22423 Mtetra
.541 .734 .964 r
.52323 .22423 .53038 .23174 .54363 .22981 .53652 .22234 Mtetra
.544 .737 .965 r
.53652 .22234 .54363 .22981 .55697 .2278 .54991 .22035 Mtetra
.553 .743 .965 r
.54991 .22035 .55697 .2278 .5704 .22558 .56337 .21815 Mtetra
.565 .75 .964 r
.56337 .21815 .5704 .22558 .58391 .22309 .57693 .21565 Mtetra
.581 .758 .962 r
.57693 .21565 .58391 .22309 .5975 .22022 .59056 .21276 Mtetra
.6 .766 .959 r
.59056 .21276 .5975 .22022 .61115 .21693 .60427 .20942 Mtetra
.619 .774 .955 r
.60427 .20942 .61115 .21693 .62488 .21314 .61805 .20556 Mtetra
.639 .781 .949 r
.61805 .20556 .62488 .21314 .63866 .20882 .63188 .20116 Mtetra
.659 .787 .942 r
.63188 .20116 .63866 .20882 .6525 .20394 .64577 .19618 Mtetra
.677 .792 .935 r
.64577 .19618 .6525 .20394 .66638 .19851 .6597 .19062 Mtetra
.694 .795 .928 r
.6597 .19062 .66638 .19851 .68029 .19253 .67366 .1845 Mtetra
.708 .797 .92 r
.67366 .1845 .68029 .19253 .69424 .18603 .68766 .17786 Mtetra
.72 .799 .913 r
.68766 .17786 .69424 .18603 .70822 .17906 .70169 .17074 Mtetra
.73 .799 .907 r
.70169 .17074 .70822 .17906 .72222 .17168 .71575 .1632 Mtetra
.737 .798 .901 r
.71575 .1632 .72222 .17168 .73625 .16396 .72983 .15532 Mtetra
.742 .797 .897 r
.72983 .15532 .73625 .16396 .75031 .15598 .74394 .14718 Mtetra
.745 .795 .893 r
.74394 .14718 .75031 .15598 .7644 .14781 .75808 .13886 Mtetra
.477 0 0 r
.10937 .36709 .11813 .37164 .12836 .37699 .11941 .37391 Mtetra
.659 .104 0 r
.11941 .37391 .12836 .37699 .13847 .38416 .12932 .38283 Mtetra
.738 .226 0 r
.12932 .38283 .13847 .38416 .14851 .39312 .13913 .39377 Mtetra
.766 .292 .115 r
.13913 .39377 .14851 .39312 .1585 .40371 .14888 .40648 Mtetra
.77 .323 .189 r
.14888 .40648 .1585 .40371 .1685 .41559 .15866 .42052 Mtetra
.761 .333 .233 r
.15866 .42052 .1685 .41559 .17858 .42827 .16854 .43526 Mtetra
.745 .327 .256 r
.16854 .43526 .17858 .42827 .18883 .44109 .17863 .44988 Mtetra
.72 .307 .263 r
.17863 .44988 .18883 .44109 .19931 .45326 .189 .46347 Mtetra
.685 .27 .253 r
.189 .46347 .19931 .45326 .21011 .46388 .19977 .47501 Mtetra
.632 .209 .223 r
.19977 .47501 .21011 .46388 .22131 .47201 .211 .48347 Mtetra
.545 .109 .163 r
.211 .48347 .22131 .47201 .23295 .47676 .22275 .48795 Mtetra
.391 0 .048 r
.22275 .48795 .23295 .47676 .24507 .47738 .23503 .48771 Mtetra
.1 0 0 r
.23503 .48771 .24507 .47738 .25766 .47333 .24783 .4823 Mtetra
0 0 0 r
.24783 .4823 .25766 .47333 .27069 .46442 .26111 .47165 Mtetra
.752 .965 .679 r
.26111 .47165 .27069 .46442 .28408 .45083 .27477 .45609 Mtetra
.91 .982 .733 r
.27477 .45609 .28408 .45083 .29775 .43314 .28871 .43633 Mtetra
.952 .942 .732 r
.28871 .43633 .29775 .43314 .31159 .41227 .30281 .41343 Mtetra
.958 .904 .725 r
.30281 .41343 .31159 .41227 .32549 .38937 .31695 .38865 Mtetra
.952 .875 .723 r
.31695 .38865 .32549 .38937 .33934 .36571 .33102 .36331 Mtetra
.941 .855 .728 r
.33102 .36331 .33934 .36571 .35309 .34249 .34495 .33866 Mtetra
.927 .841 .739 r
.34495 .33866 .35309 .34249 .36667 .32073 .35869 .31574 Mtetra
.909 .832 .757 r
.35869 .31574 .36667 .32073 .38007 .30119 .37223 .29528 Mtetra
.887 .825 .781 r
.37223 .29528 .38007 .30119 .3933 .2843 .38556 .2777 Mtetra
.857 .819 .81 r
.38556 .2777 .3933 .2843 .40637 .27023 .39873 .26312 Mtetra
.821 .811 .841 r
.39873 .26312 .40637 .27023 .41934 .25886 .41177 .25139 Mtetra
.777 .801 .872 r
.41177 .25139 .41934 .25886 .43224 .24992 .42473 .24223 Mtetra
.729 .787 .899 r
.42473 .24223 .43224 .24992 .44512 .24304 .43766 .23521 Mtetra
.681 .772 .92 r
.43766 .23521 .44512 .24304 .45799 .2378 .45058 .2299 Mtetra
.637 .757 .935 r
.45058 .2299 .45799 .2378 .4709 .23382 .46353 .22588 Mtetra
.6 .744 .945 r
.46353 .22588 .4709 .23382 .48387 .23073 .47654 .2228 Mtetra
.573 .734 .951 r
.47654 .2228 .48387 .23073 .49691 .22825 .48961 .22034 Mtetra
.555 .728 .955 r
.48961 .22034 .49691 .22825 .51003 .22615 .50277 .21825 Mtetra
.545 .725 .957 r
.50277 .21825 .51003 .22615 .52323 .22423 .51601 .21635 Mtetra
.543 .726 .959 r
.51601 .21635 .52323 .22423 .53652 .22234 .52934 .21447 Mtetra
.547 .729 .959 r
.52934 .21447 .53652 .22234 .54991 .22035 .54276 .21248 Mtetra
.556 .734 .959 r
.54276 .21248 .54991 .22035 .56337 .21815 .55628 .21027 Mtetra
.569 .741 .957 r
.55628 .21027 .56337 .21815 .57693 .21565 .56987 .20774 Mtetra
.585 .748 .954 r
.56987 .20774 .57693 .21565 .59056 .21276 .58355 .20481 Mtetra
.604 .755 .951 r
.58355 .20481 .59056 .21276 .60427 .20942 .59731 .2014 Mtetra
.623 .763 .946 r
.59731 .2014 .60427 .20942 .61805 .20556 .61113 .19747 Mtetra
.643 .769 .94 r
.61113 .19747 .61805 .20556 .63188 .20116 .62501 .19296 Mtetra
.662 .775 .933 r
.62501 .19296 .63188 .20116 .64577 .19618 .63895 .18787 Mtetra
.68 .779 .926 r
.63895 .18787 .64577 .19618 .6597 .19062 .65293 .18219 Mtetra
.695 .783 .918 r
.65293 .18219 .6597 .19062 .67366 .1845 .66694 .17594 Mtetra
.709 .785 .911 r
.66694 .17594 .67366 .1845 .68766 .17786 .681 .16916 Mtetra
.721 .787 .905 r
.681 .16916 .68766 .17786 .70169 .17074 .69508 .1619 Mtetra
.73 .788 .899 r
.69508 .1619 .70169 .17074 .71575 .1632 .70918 .15422 Mtetra
.737 .788 .893 r
.70918 .15422 .71575 .1632 .72983 .15532 .72332 .14621 Mtetra
.742 .787 .889 r
.72332 .14621 .72983 .15532 .74394 .14718 .73748 .13793 Mtetra
.745 .786 .886 r
.73748 .13793 .74394 .14718 .75808 .13886 .75167 .12948 Mtetra
.582 .015 0 r
.1005 .36259 .10937 .36709 .11941 .37391 .11037 .37073 Mtetra
.717 .184 0 r
.11037 .37073 .11941 .37391 .12932 .38283 .12009 .38118 Mtetra
.773 .279 .042 r
.12009 .38118 .12932 .38283 .13913 .39377 .12969 .39379 Mtetra
.793 .329 .137 r
.12969 .39379 .13913 .39377 .14888 .40648 .13925 .40822 Mtetra
.794 .351 .194 r
.13925 .40822 .14888 .40648 .15866 .42052 .14884 .42391 Mtetra
.786 .355 .225 r
.14884 .42391 .15866 .42052 .16854 .43526 .15858 .44009 Mtetra
.77 .342 .235 r
.15858 .44009 .16854 .43526 .17863 .44988 .16856 .45582 Mtetra
.744 .313 .226 r
.16856 .45582 .17863 .44988 .189 .46347 .1789 .47005 Mtetra
.704 .26 .194 r
.1789 .47005 .189 .46347 .19977 .47501 .18969 .4817 Mtetra
.633 .165 .123 r
.18969 .4817 .19977 .47501 .211 .48347 .20101 .48973 Mtetra
.49 0 0 r
.20101 .48973 .211 .48347 .22275 .48795 .21291 .49324 Mtetra
.157 0 0 r
.21291 .49324 .22275 .48795 .23503 .48771 .22538 .4916 Mtetra
.444 .866 .736 r
.22538 .4916 .23503 .48771 .24783 .4823 .23841 .4845 Mtetra
.821 .997 .851 r
.23841 .4845 .24783 .4823 .26111 .47165 .25193 .47201 Mtetra
.915 .94 .807 r
.25193 .47201 .26111 .47165 .27477 .45609 .26584 .45461 Mtetra
.931 .881 .763 r
.26584 .45461 .27477 .45609 .28871 .43633 .28001 .43315 Mtetra
.93 .841 .734 r
.28001 .43315 .28871 .43633 .30281 .41343 .29431 .40877 Mtetra
.925 .816 .719 r
.29431 .40877 .30281 .41343 .31695 .38865 .30864 .38279 Mtetra
.918 .799 .714 r
.30864 .38279 .31695 .38865 .33102 .36331 .32287 .35653 Mtetra
.91 .79 .717 r
.32287 .35653 .33102 .36331 .34495 .33866 .33694 .33123 Mtetra
.899 .785 .727 r
.33694 .33123 .34495 .33866 .35869 .31574 .35079 .30786 Mtetra
.885 .784 .744 r
.35079 .30786 .35869 .31574 .37223 .29528 .36442 .28712 Mtetra
.866 .784 .767 r
.36442 .28712 .37223 .29528 .38556 .2777 .37783 .26939 Mtetra
.842 .784 .796 r
.37783 .26939 .38556 .2777 .39873 .26312 .39107 .25473 Mtetra
.809 .783 .828 r
.39107 .25473 .39873 .26312 .41177 .25139 .40417 .24299 Mtetra
.77 .778 .86 r
.40417 .24299 .41177 .25139 .42473 .24223 .41717 .23383 Mtetra
.725 .77 .889 r
.41717 .23383 .42473 .24223 .43766 .23521 .43014 .22684 Mtetra
.678 .759 .912 r
.43014 .22684 .43766 .23521 .45058 .2299 .4431 .22156 Mtetra
.635 .746 .928 r
.4431 .22156 .45058 .2299 .46353 .22588 .45609 .21757 Mtetra
.6 .734 .939 r
.45609 .21757 .46353 .22588 .47654 .2228 .46914 .21451 Mtetra
.573 .725 .946 r
.46914 .21451 .47654 .2228 .48961 .22034 .48225 .21206 Mtetra
.556 .72 .95 r
.48225 .21206 .48961 .22034 .50277 .21825 .49544 .20999 Mtetra
.547 .717 .952 r
.49544 .20999 .50277 .21825 .51601 .21635 .50872 .20808 Mtetra
.545 .717 .953 r
.50872 .20808 .51601 .21635 .52934 .21447 .52209 .20619 Mtetra
.55 .72 .952 r
.52209 .20619 .52934 .21447 .54276 .21248 .53555 .20417 Mtetra
.56 .725 .951 r
.53555 .20417 .54276 .21248 .55628 .21027 .54911 .20192 Mtetra
.573 .731 .949 r
.54911 .20192 .55628 .21027 .56987 .20774 .56274 .19934 Mtetra
.59 .737 .946 r
.56274 .19934 .56987 .20774 .58355 .20481 .57647 .19633 Mtetra
.608 .744 .941 r
.57647 .19633 .58355 .20481 .59731 .2014 .59027 .19284 Mtetra
.627 .751 .936 r
.59027 .19284 .59731 .2014 .61113 .19747 .60413 .18881 Mtetra
.646 .757 .93 r
.60413 .18881 .61113 .19747 .62501 .19296 .61806 .1842 Mtetra
.664 .762 .923 r
.61806 .1842 .62501 .19296 .63895 .18787 .63204 .179 Mtetra
.681 .767 .916 r
.63204 .179 .63895 .18787 .65293 .18219 .64607 .1732 Mtetra
.696 .77 .909 r
.64607 .1732 .65293 .18219 .66694 .17594 .66014 .16682 Mtetra
.709 .773 .902 r
.66014 .16682 .66694 .17594 .681 .16916 .67424 .15992 Mtetra
.72 .775 .896 r
.67424 .15992 .681 .16916 .69508 .1619 .68837 .15253 Mtetra
.729 .776 .89 r
.68837 .15253 .69508 .1619 .70918 .15422 .70253 .14474 Mtetra
.736 .777 .886 r
.70253 .14474 .70918 .15422 .72332 .14621 .71671 .13661 Mtetra
.74 .777 .882 r
.71671 .13661 .72332 .14621 .73748 .13793 .73093 .12823 Mtetra
.743 .776 .88 r
.73093 .12823 .73748 .13793 .75167 .12948 .74517 .11968 Mtetra
.63 .076 0 r
.0916 .35762 .1005 .36259 .11037 .37073 .10133 .36679 Mtetra
.745 .224 0 r
.10133 .36679 .11037 .37073 .12009 .38118 .11089 .37839 Mtetra
.795 .306 .041 r
.11089 .37839 .12009 .38118 .12969 .39379 .12034 .3922 Mtetra
.814 .349 .12 r
.12034 .3922 .12969 .39379 .13925 .40822 .12975 .40777 Mtetra
.817 .366 .163 r
.12975 .40777 .13925 .40822 .14884 .42391 .13922 .42442 Mtetra
.811 .365 .18 r
.13922 .42442 .14884 .42391 .15858 .44009 .14888 .44127 Mtetra
.796 .344 .171 r
.14888 .44127 .15858 .44009 .16856 .45582 .15883 .45726 Mtetra
.768 .299 .13 r
.15883 .45726 .16856 .45582 .1789 .47005 .1692 .47128 Mtetra
.711 .207 .036 r
.1692 .47128 .1789 .47005 .18969 .4817 .18009 .48221 Mtetra
.573 .01 0 r
.18009 .48221 .18969 .4817 .20101 .48973 .19155 .48905 Mtetra
.169 0 0 r
.19155 .48905 .20101 .48973 .21291 .49324 .20364 .491 Mtetra
.504 .87 .984 r
.20364 .491 .21291 .49324 .22538 .4916 .21633 .48758 Mtetra
.783 .885 .919 r
.21633 .48758 .22538 .4916 .23841 .4845 .22958 .47863 Mtetra
.851 .828 .825 r
.22958 .47863 .23841 .4845 .25193 .47201 .24331 .46441 Mtetra
.87 .786 .766 r
.24331 .46441 .25193 .47201 .26584 .45461 .25741 .44554 Mtetra
.876 .76 .731 r
.25741 .44554 .26584 .45461 .28001 .43315 .27174 .42295 Mtetra
.878 .745 .711 r
.27174 .42295 .28001 .43315 .29431 .40877 .28619 .39784 Mtetra
.878 .736 .701 r
.28619 .39784 .29431 .40877 .30864 .38279 .30062 .37149 Mtetra
.876 .733 .7 r
.30062 .37149 .30864 .38279 .32287 .35653 .31494 .34518 Mtetra
.873 .733 .704 r
.31494 .34518 .32287 .35653 .33694 .33123 .32907 .32005 Mtetra
.867 .735 .716 r
.32907 .32005 .33694 .33123 .35079 .30786 .34298 .29701 Mtetra
.857 .74 .733 r
.34298 .29701 .35079 .30786 .36442 .28712 .35666 .27668 Mtetra
.842 .746 .757 r
.35666 .27668 .36442 .28712 .37783 .26939 .37012 .25935 Mtetra
.822 .752 .786 r
.37012 .25935 .37783 .26939 .39107 .25473 .38339 .24507 Mtetra
.793 .755 .819 r
.38339 .24507 .39107 .25473 .40417 .24299 .39653 .23365 Mtetra
.757 .756 .851 r
.39653 .23365 .40417 .24299 .41717 .23383 .40957 .22473 Mtetra
.716 .752 .881 r
.40957 .22473 .41717 .23383 .43014 .22684 .42257 .21792 Mtetra
.672 .744 .905 r
.42257 .21792 .43014 .22684 .4431 .22156 .43557 .21277 Mtetra
.632 .735 .922 r
.43557 .21277 .4431 .22156 .45609 .21757 .4486 .20886 Mtetra
.598 .725 .933 r
.4486 .20886 .45609 .21757 .46914 .21451 .46167 .20584 Mtetra
.573 .717 .94 r
.46167 .20584 .46914 .21451 .48225 .21206 .47482 .20341 Mtetra
.557 .712 .944 r
.47482 .20341 .48225 .21206 .49544 .20999 .48805 .20133 Mtetra
.55 .709 .945 r
.48805 .20133 .49544 .20999 .50872 .20808 .50136 .1994 Mtetra
.549 .709 .946 r
.50136 .1994 .50872 .20808 .52209 .20619 .51477 .19746 Mtetra
.554 .711 .945 r
.51477 .19746 .52209 .20619 .53555 .20417 .52827 .19539 Mtetra
.564 .715 .943 r
.52827 .19539 .53555 .20417 .54911 .20192 .54186 .19307 Mtetra
.578 .721 .94 r
.54186 .19307 .54911 .20192 .56274 .19934 .55554 .1904 Mtetra
.594 .727 .936 r
.55554 .1904 .56274 .19934 .57647 .19633 .5693 .18731 Mtetra
.612 .733 .931 r
.5693 .18731 .57647 .19633 .59027 .19284 .58315 .18371 Mtetra
.63 .739 .926 r
.58315 .18371 .59027 .19284 .60413 .18881 .59706 .17957 Mtetra
.649 .744 .919 r
.59706 .17957 .60413 .18881 .61806 .1842 .61103 .17485 Mtetra
.666 .75 .913 r
.61103 .17485 .61806 .1842 .63204 .179 .62506 .16953 Mtetra
.682 .754 .906 r
.62506 .16953 .63204 .179 .64607 .1732 .63913 .16361 Mtetra
.696 .758 .899 r
.63913 .16361 .64607 .1732 .66014 .16682 .65324 .15713 Mtetra
.709 .76 .893 r
.65324 .15713 .66014 .16682 .67424 .15992 .66739 .15011 Mtetra
.719 .763 .887 r
.66739 .15011 .67424 .15992 .68837 .15253 .68158 .14262 Mtetra
.727 .764 .882 r
.68158 .14262 .68837 .15253 .70253 .14474 .69578 .13473 Mtetra
.734 .766 .878 r
.69578 .13473 .70253 .14474 .71671 .13661 .71002 .12652 Mtetra
.738 .767 .876 r
.71002 .12652 .71671 .13661 .73093 .12823 .72429 .11806 Mtetra
.741 .767 .874 r
.72429 .11806 .73093 .12823 .74517 .11968 .73859 .10945 Mtetra
.636 .093 0 r
.08273 .35172 .0916 .35762 .10133 .36679 .09237 .36152 Mtetra
.749 .231 0 r
.09237 .36152 .10133 .36679 .11089 .37839 .10183 .37376 Mtetra
.802 .31 0 r
.10183 .37376 .11089 .37839 .12034 .3922 .11118 .38815 Mtetra
.825 .35 .057 r
.11118 .38815 .12034 .3922 .12975 .40777 .12052 .40415 Mtetra
.831 .364 .084 r
.12052 .40415 .12975 .40777 .13922 .42442 .12995 .42097 Mtetra
.825 .354 .075 r
.12995 .42097 .13922 .42442 .14888 .44127 .13961 .43763 Mtetra
.804 .315 .021 r
.13961 .43763 .14888 .44127 .15883 .45726 .14962 .45301 Mtetra
.745 .224 0 r
.14962 .45301 .15883 .45726 .1692 .47128 .16009 .46597 Mtetra
.571 .011 0 r
.16009 .46597 .1692 .47128 .18009 .48221 .17113 .47544 Mtetra
0 .396 .818 r
.17113 .47544 .18009 .48221 .19155 .48905 .18279 .48049 Mtetra
.449 .668 .956 r
.18279 .48049 .19155 .48905 .20364 .491 .19508 .48048 Mtetra
.673 .707 .873 r
.19508 .48048 .20364 .491 .21633 .48758 .20797 .4751 Mtetra
.755 .697 .797 r
.20797 .4751 .21633 .48758 .22958 .47863 .22142 .4644 Mtetra
.791 .686 .748 r
.22142 .4644 .22958 .47863 .24331 .46441 .23531 .44877 Mtetra
.811 .678 .717 r
.23531 .44877 .24331 .46441 .25741 .44554 .24953 .42897 Mtetra
.822 .674 .699 r
.24953 .42897 .25741 .44554 .27174 .42295 .26396 .40597 Mtetra
.83 .673 .689 r
.26396 .40597 .27174 .42295 .28619 .39784 .27845 .38093 Mtetra
.834 .675 .685 r
.27845 .38093 .28619 .39784 .30062 .37149 .29291 .35509 Mtetra
.837 .68 .687 r
.29291 .35509 .30062 .37149 .31494 .34518 .30724 .32959 Mtetra
.837 .686 .695 r
.30724 .32959 .31494 .34518 .32907 .32005 .32137 .30546 Mtetra
.835 .694 .708 r
.32137 .30546 .32907 .32005 .34298 .29701 .33528 .28348 Mtetra
.828 .703 .726 r
.33528 .28348 .34298 .29701 .35666 .27668 .34895 .26417 Mtetra
.817 .714 .751 r
.34895 .26417 .35666 .27668 .37012 .25935 .36242 .24776 Mtetra
.8 .723 .78 r
.36242 .24776 .37012 .25935 .38339 .24507 .3757 .23425 Mtetra
.774 .731 .813 r
.3757 .23425 .38339 .24507 .39653 .23365 .38886 .22343 Mtetra
.742 .735 .846 r
.38886 .22343 .39653 .23365 .40957 .22473 .40193 .21498 Mtetra
.704 .735 .875 r
.40193 .21498 .40957 .22473 .42257 .21792 .41495 .20849 Mtetra
.664 .731 .899 r
.41495 .20849 .42257 .21792 .43557 .21277 .42798 .20354 Mtetra
.626 .723 .916 r
.42798 .20354 .43557 .21277 .4486 .20886 .44104 .19975 Mtetra
.596 .715 .928 r
.44104 .19975 .4486 .20886 .46167 .20584 .45415 .19679 Mtetra
.573 .708 .934 r
.45415 .19679 .46167 .20584 .47482 .20341 .46733 .19436 Mtetra
.559 .704 .937 r
.46733 .19436 .47482 .20341 .48805 .20133 .48059 .19225 Mtetra
.553 .701 .938 r
.48059 .19225 .48805 .20133 .50136 .1994 .49394 .19027 Mtetra
.49394 .19027 .50136 .1994 .51477 .19746 .50738 .18827 Mtetra
.559 .703 .937 r
.50738 .18827 .51477 .19746 .52827 .19539 .52092 .18611 Mtetra
.57 .706 .934 r
.52092 .18611 .52827 .19539 .54186 .19307 .53455 .18369 Mtetra
.583 .711 .931 r
.53455 .18369 .54186 .19307 .55554 .1904 .54827 .18092 Mtetra
.599 .716 .926 r
.54827 .18092 .55554 .1904 .5693 .18731 .56207 .17771 Mtetra
.616 .722 .921 r
.56207 .17771 .5693 .18731 .58315 .18371 .57595 .17401 Mtetra
.633 .727 .915 r
.57595 .17401 .58315 .18371 .59706 .17957 .5899 .16975 Mtetra
.65 .732 .909 r
.5899 .16975 .59706 .17957 .61103 .17485 .60392 .1649 Mtetra
.667 .737 .903 r
.60392 .1649 .61103 .17485 .62506 .16953 .61799 .15947 Mtetra
.682 .741 .896 r
.61799 .15947 .62506 .16953 .63913 .16361 .63211 .15344 Mtetra
.695 .745 .89 r
.63211 .15344 .63913 .16361 .65324 .15713 .64627 .14685 Mtetra
.707 .748 .884 r
.64627 .14685 .65324 .15713 .66739 .15011 .66047 .13975 Mtetra
.717 .751 .879 r
.66047 .13975 .66739 .15011 .68158 .14262 .6747 .13218 Mtetra
.725 .753 .875 r
.6747 .13218 .68158 .14262 .69578 .13473 .68896 .12422 Mtetra
.731 .755 .872 r
.68896 .12422 .69578 .13473 .71002 .12652 .70325 .11595 Mtetra
.735 .757 .87 r
.70325 .11595 .71002 .12652 .72429 .11806 .71757 .10745 Mtetra
.738 .758 .868 r
.71757 .10745 .72429 .11806 .73859 .10945 .73193 .0988 Mtetra
.596 .067 0 r
.07395 .34452 .08273 .35172 .09237 .36152 .08355 .35447 Mtetra
.717 .203 0 r
.08355 .35447 .09237 .36152 .10183 .37376 .09298 .36677 Mtetra
.778 .282 0 r
.09298 .36677 .10183 .37376 .11118 .38815 .10232 .38106 Mtetra
.804 .319 0 r
.10232 .38106 .11118 .38815 .12052 .40415 .11166 .39672 Mtetra
.805 .323 0 r
.11166 .39672 .12052 .40415 .12995 .42097 .12114 .41289 Mtetra
.775 .288 0 r
.12114 .41289 .12995 .42097 .13961 .43763 .13089 .42853 Mtetra
.682 .191 0 r
.13089 .42853 .13961 .43763 .14962 .45301 .14103 .44251 Mtetra
0 .018 .552 r
.14103 .44251 .14962 .45301 .16009 .46597 .15167 .45371 Mtetra
.005 .309 .8 r
.15167 .45371 .16009 .46597 .17113 .47544 .16291 .46114 Mtetra
.381 .496 .851 r
.16291 .46114 .17113 .47544 .18279 .48049 .17477 .46403 Mtetra
.574 .566 .806 r
.17477 .46403 .18279 .48049 .19508 .48048 .18727 .46191 Mtetra
.668 .59 .759 r
.18727 .46191 .19508 .48048 .20797 .4751 .20035 .45466 Mtetra
.718 .6 .724 r
.20035 .45466 .20797 .4751 .22142 .4644 .21393 .44251 Mtetra
.748 .606 .7 r
.21393 .44251 .22142 .4644 .23531 .44877 .22792 .42598 Mtetra
.767 .611 .685 r
.22792 .42598 .23531 .44877 .24953 .42897 .24219 .40589 Mtetra
.781 .617 .676 r
.24219 .40589 .24953 .42897 .26396 .40597 .25662 .38323 Mtetra
.791 .623 .673 r
.25662 .38323 .26396 .40597 .27845 .38093 .27108 .35908 Mtetra
.798 .631 .674 r
.27108 .35908 .27845 .38093 .29291 .35509 .28548 .33453 Mtetra
.804 .64 .679 r
.28548 .33453 .29291 .35509 .30724 .32959 .29974 .3106 Mtetra
.806 .65 .689 r
.29974 .3106 .30724 .32959 .32137 .30546 .31381 .28815 Mtetra
.806 .662 .704 r
.31381 .28815 .32137 .30546 .33528 .28348 .32766 .26782 Mtetra
.802 .674 .724 r
.32766 .26782 .33528 .28348 .34895 .26417 .34129 .25003 Mtetra
.793 .688 .749 r
.34129 .25003 .34895 .26417 .36242 .24776 .35472 .23493 Mtetra
.777 .7 .779 r
.35472 .23493 .36242 .24776 .3757 .23425 .368 .2225 Mtetra
.755 .711 .811 r
.368 .2225 .3757 .23425 .38886 .22343 .38115 .21252 Mtetra
.725 .718 .843 r
.38115 .21252 .38886 .22343 .40193 .21498 .39424 .20467 Mtetra
.69 .72 .872 r
.39424 .20467 .40193 .21498 .41495 .20849 .40728 .19859 Mtetra
.654 .718 .895 r
.40728 .19859 .41495 .20849 .42798 .20354 .42034 .19391 Mtetra
.62 .713 .912 r
.42034 .19391 .42798 .20354 .44104 .19975 .43342 .19027 Mtetra
.593 .706 .922 r
.43342 .19027 .44104 .19975 .45415 .19679 .44656 .18736 Mtetra
.573 .701 .928 r
.44656 .18736 .45415 .19679 .46733 .19436 .45978 .18493 Mtetra
.562 .696 .931 r
.45978 .18493 .46733 .19436 .48059 .19225 .47307 .18277 Mtetra
.557 .694 .931 r
.47307 .18277 .48059 .19225 .49394 .19027 .48646 .18071 Mtetra
.558 .694 .931 r
.48646 .18071 .49394 .19027 .50738 .18827 .49993 .17861 Mtetra
.565 .695 .928 r
.49993 .17861 .50738 .18827 .52092 .18611 .51351 .17634 Mtetra
.575 .698 .925 r
.51351 .17634 .52092 .18611 .53455 .18369 .52717 .1738 Mtetra
.588 .702 .921 r
.52717 .1738 .53455 .18369 .54827 .18092 .54092 .1709 Mtetra
.603 .706 .917 r
.54092 .1709 .54827 .18092 .56207 .17771 .55476 .16756 Mtetra
.619 .711 .911 r
.55476 .16756 .56207 .17771 .57595 .17401 .56868 .16372 Mtetra
.636 .716 .905 r
.56868 .16372 .57595 .17401 .5899 .16975 .58267 .15934 Mtetra
.652 .721 .899 r
.58267 .15934 .5899 .16975 .60392 .1649 .59673 .15437 Mtetra
.667 .726 .893 r
.59673 .15437 .60392 .1649 .61799 .15947 .61084 .14883 Mtetra
.681 .73 .887 r
.61084 .14883 .61799 .15947 .63211 .15344 .625 .1427 Mtetra
.694 .734 .881 r
.625 .1427 .63211 .15344 .64627 .14685 .63921 .13602 Mtetra
.705 .737 .876 r
.63921 .13602 .64627 .14685 .66047 .13975 .65346 .12884 Mtetra
.715 .74 .872 r
.65346 .12884 .66047 .13975 .6747 .13218 .66773 .12122 Mtetra
.722 .743 .868 r
.66773 .12122 .6747 .13218 .68896 .12422 .68205 .11322 Mtetra
.728 .745 .866 r
.68205 .11322 .68896 .12422 .70325 .11595 .69639 .10492 Mtetra
.732 .747 .864 r
.69639 .10492 .70325 .11595 .71757 .10745 .71077 .09641 Mtetra
.735 .749 .864 r
.71077 .09641 .71757 .10745 .73193 .0988 .72518 .08775 Mtetra
0 .005 .506 r
.0653 .33584 .07395 .34452 .08355 .35447 .07493 .34541 Mtetra
.622 .127 0 r
.07493 .34541 .08355 .35447 .09298 .36677 .0844 .35717 Mtetra
.684 .202 0 r
.0844 .35717 .09298 .36677 .10232 .38106 .09381 .37068 Mtetra
.695 .227 0 r
.09381 .37068 .10232 .38106 .11166 .39672 .10325 .38528 Mtetra
.652 .201 0 r
.10325 .38528 .11166 .39672 .12114 .41289 .11286 .40006 Mtetra
0 0 .454 r
.11286 .40006 .12114 .41289 .13089 .42853 .12277 .41398 Mtetra
0 .061 .625 r
.12277 .41398 .13089 .42853 .14103 .44251 .1331 .42594 Mtetra
.065 .257 .749 r
.1331 .42594 .14103 .44251 .15167 .45371 .14396 .43489 Mtetra
.337 .397 .776 r
.14396 .43489 .15167 .45371 .16291 .46114 .15541 .43999 Mtetra
.504 .473 .756 r
.15541 .43999 .16291 .46114 .17477 .46403 .16749 .44061 Mtetra
.6 .512 .727 r
.16749 .44061 .17477 .46403 .18727 .46191 .18016 .43648 Mtetra
.658 .535 .703 r
.18016 .43648 .18727 .46191 .20035 .45466 .19338 .42767 Mtetra
.694 .549 .685 r
.19338 .42767 .20035 .45466 .21393 .44251 .20704 .41453 Mtetra
.719 .56 .673 r
.20704 .41453 .21393 .44251 .22792 .42598 .22105 .3977 Mtetra
.737 .57 .666 r
.22105 .3977 .22792 .42598 .24219 .40589 .23529 .378 Mtetra
.751 .579 .663 r
.23529 .378 .24219 .40589 .25662 .38323 .24964 .35636 Mtetra
.762 .589 .663 r
.24964 .35636 .25662 .38323 .27108 .35908 .26399 .33376 Mtetra
.77 .599 .667 r
.26399 .33376 .27108 .35908 .28548 .33453 .27826 .31114 Mtetra
.776 .611 .675 r
.27826 .31114 .28548 .33453 .29974 .3106 .2924 .28934 Mtetra
.779 .624 .687 r
.2924 .28934 .29974 .3106 .31381 .28815 .30634 .26905 Mtetra
.78 .638 .704 r
.30634 .26905 .31381 .28815 .32766 .26782 .32009 .25078 Mtetra
.777 .653 .725 r
.32009 .25078 .32766 .26782 .34129 .25003 .33365 .23483 Mtetra
.769 .668 .751 r
.33365 .23483 .34129 .25003 .35472 .23493 .34703 .2213 Mtetra
.755 .683 .781 r
.34703 .2213 .35472 .23493 .368 .2225 .36027 .21012 Mtetra
.735 .695 .813 r
.36027 .21012 .368 .2225 .38115 .21252 .37341 .2011 Mtetra
.707 .704 .845 r
.37341 .2011 .38115 .21252 .39424 .20467 .3865 .19395 Mtetra
.676 .708 .872 r
.3865 .19395 .39424 .20467 .40728 .19859 .39956 .18834 Mtetra
.644 .707 .893 r
.39956 .18834 .40728 .19859 .42034 .19391 .41264 .18393 Mtetra
.614 .704 .908 r
.41264 .18393 .42034 .19391 .43342 .19027 .42575 .18043 Mtetra
.591 .698 .918 r
.42575 .18043 .43342 .19027 .44656 .18736 .43892 .17757 Mtetra
.574 .694 .923 r
.43892 .17757 .44656 .18736 .45978 .18493 .45217 .17511 Mtetra
.565 .69 .925 r
.45217 .17511 .45978 .18493 .47307 .18277 .46549 .17288 Mtetra
.561 .688 .924 r
.46549 .17288 .47307 .18277 .48646 .18071 .47891 .17071 Mtetra
.564 .687 .923 r
.47891 .17071 .48646 .18071 .49993 .17861 .49242 .16848 Mtetra
.57 .688 .92 r
.49242 .16848 .49993 .17861 .51351 .17634 .50603 .16608 Mtetra
.58 .69 .917 r
.50603 .16608 .51351 .17634 .52717 .1738 .51973 .16339 Mtetra
.593 .693 .912 r
.51973 .16339 .52717 .1738 .54092 .1709 .53352 .16034 Mtetra
.607 .697 .907 r
.53352 .16034 .54092 .1709 .55476 .16756 .54739 .15686 Mtetra
.622 .701 .902 r
.54739 .15686 .55476 .16756 .56868 .16372 .56134 .15288 Mtetra
.638 .706 .896 r
.56134 .15288 .56868 .16372 .58267 .15934 .57537 .14836 Mtetra
.653 .71 .89 r
.57537 .14836 .58267 .15934 .59673 .15437 .58947 .14328 Mtetra
.667 .715 .884 r
.58947 .14328 .59673 .15437 .61084 .14883 .60362 .13763 Mtetra
.681 .719 .878 r
.60362 .13763 .61084 .14883 .625 .1427 .61783 .13141 Mtetra
.692 .723 .873 r
.61783 .13141 .625 .1427 .63921 .13602 .63208 .12467 Mtetra
.703 .727 .869 r
.63208 .12467 .63921 .13602 .65346 .12884 .64637 .11743 Mtetra
.712 .73 .865 r
.64637 .11743 .65346 .12884 .66773 .12122 .6607 .10977 Mtetra
.719 .733 .862 r
.6607 .10977 .66773 .12122 .68205 .11322 .67506 .10176 Mtetra
.724 .736 .861 r
.67506 .10176 .68205 .11322 .69639 .10492 .68945 .09346 Mtetra
.728 .739 .86 r
.68945 .09346 .69639 .10492 .71077 .09641 .70389 .08496 Mtetra
.731 .741 .86 r
.70389 .08496 .71077 .09641 .72518 .08775 .71836 .07633 Mtetra
0 .114 .642 r
.05679 .32565 .0653 .33584 .07493 .34541 .06651 .33438 Mtetra
0 0 .545 r
.06651 .33438 .07493 .34541 .0844 .35717 .07611 .34505 Mtetra
0 0 .499 r
.07611 .34505 .0844 .35717 .09381 .37068 .08566 .35719 Mtetra
0 0 .512 r
.08566 .35719 .09381 .37068 .10325 .38528 .09527 .37011 Mtetra
0 .001 .576 r
.09527 .37011 .10325 .38528 .11286 .40006 .10508 .38292 Mtetra
0 .113 .661 r
.10508 .38292 .11286 .40006 .12277 .41398 .11521 .39461 Mtetra
.109 .24 .719 r
.11521 .39461 .12277 .41398 .1331 .42594 .12578 .40416 Mtetra
.311 .344 .735 r
.12578 .40416 .1331 .42594 .14396 .43489 .13687 .41064 Mtetra
.454 .414 .724 r
.13687 .41064 .14396 .43489 .15541 .43999 .14855 .41335 Mtetra
.548 .459 .706 r
.14855 .41335 .15541 .43999 .16749 .44061 .1608 .41186 Mtetra
.609 .487 .689 r
.1608 .41186 .16749 .44061 .18016 .43648 .17361 .40605 Mtetra
.651 .507 .675 r
.17361 .40605 .18016 .43648 .19338 .42767 .18691 .39612 Mtetra
.68 .522 .665 r
.18691 .39612 .19338 .42767 .20704 .41453 .20058 .38255 Mtetra
.701 .534 .659 r
.20058 .38255 .20704 .41453 .22105 .3977 .21455 .36601 Mtetra
.717 .545 .656 r
.21455 .36601 .22105 .3977 .23529 .378 .22868 .34728 Mtetra
.729 .556 .656 r
.22868 .34728 .23529 .378 .24964 .35636 .24288 .32721 Mtetra
.739 .567 .66 r
.24288 .32721 .24964 .35636 .26399 .33376 .25707 .30665 Mtetra
.747 .579 .666 r
.25707 .30665 .26399 .33376 .27826 .31114 .27116 .28636 Mtetra
.753 .592 .677 r
.27116 .28636 .27826 .31114 .2924 .28934 .28512 .26702 Mtetra
.757 .606 .691 r
.28512 .26702 .2924 .28934 .30634 .26905 .29892 .24915 Mtetra
.758 .622 .709 r
.29892 .24915 .30634 .26905 .32009 .25078 .31254 .23313 Mtetra
.755 .639 .732 r
.31254 .23313 .32009 .25078 .33365 .23483 .32599 .21916 Mtetra
.748 .655 .758 r
.32599 .21916 .33365 .23483 .34703 .2213 .33931 .20728 Mtetra
.735 .671 .788 r
.33931 .20728 .34703 .2213 .36027 .21012 .35251 .19743 Mtetra
.715 .685 .819 r
.35251 .19743 .36027 .21012 .37341 .2011 .36563 .1894 Mtetra
.69 .694 .849 r
.36563 .1894 .37341 .2011 .3865 .19395 .37871 .18295 Mtetra
.662 .699 .874 r
.37871 .18295 .3865 .19395 .39956 .18834 .39179 .1778 Mtetra
.634 .699 .893 r
.39179 .1778 .39956 .18834 .41264 .18393 .40488 .17366 Mtetra
.609 .696 .906 r
.40488 .17366 .41264 .18393 .42575 .18043 .41802 .17029 Mtetra
.589 .692 .914 r
.41802 .17029 .42575 .18043 .43892 .17757 .43122 .16744 Mtetra
.575 .688 .917 r
.43122 .16744 .43892 .17757 .45217 .17511 .4445 .16494 Mtetra
.568 .684 .919 r
.4445 .16494 .45217 .17511 .46549 .17288 .45786 .1626 Mtetra
.566 .682 .918 r
.45786 .1626 .46549 .17288 .47891 .17071 .47131 .1603 Mtetra
.569 .681 .916 r
.47131 .1603 .47891 .17071 .49242 .16848 .48485 .15792 Mtetra
.576 .682 .912 r
.48485 .15792 .49242 .16848 .50603 .16608 .49849 .15535 Mtetra
.586 .683 .908 r
.49849 .15535 .50603 .16608 .51973 .16339 .51222 .1525 Mtetra
.598 .686 .904 r
.51222 .1525 .51973 .16339 .53352 .16034 .52604 .14929 Mtetra
.611 .689 .898 r
.52604 .14929 .53352 .16034 .54739 .15686 .53995 .14564 Mtetra
.625 .693 .893 r
.53995 .14564 .54739 .15686 .56134 .15288 .55394 .14152 Mtetra
.639 .697 .887 r
.55394 .14152 .56134 .15288 .57537 .14836 .568 .13686 Mtetra
.653 .701 .882 r
.568 .13686 .57537 .14836 .58947 .14328 .58214 .13167 Mtetra
.667 .705 .876 r
.58214 .13167 .58947 .14328 .60362 .13763 .59633 .12591 Mtetra
.679 .71 .871 r
.59633 .12591 .60362 .13763 .61783 .13141 .61057 .11962 Mtetra
.69 .714 .866 r
.61057 .11962 .61783 .13141 .63208 .12467 .62487 .11282 Mtetra
.7 .718 .863 r
.62487 .11282 .63208 .12467 .64637 .11743 .6392 .10555 Mtetra
.709 .721 .86 r
.6392 .10555 .64637 .11743 .6607 .10977 .65358 .09788 Mtetra
.715 .725 .857 r
.65358 .09788 .6607 .10977 .67506 .10176 .66799 .08987 Mtetra
.721 .728 .856 r
.66799 .08987 .67506 .10176 .68945 .09346 .68244 .0816 Mtetra
.724 .731 .856 r
.68244 .0816 .68945 .09346 .70389 .08496 .69693 .07314 Mtetra
.727 .734 .857 r
.69693 .07314 .70389 .08496 .71836 .07633 .71146 .06457 Mtetra
0 .237 .753 r
.04841 .31413 .05679 .32565 .06651 .33438 .05829 .32161 Mtetra
0 .149 .692 r
.05829 .32161 .06651 .33438 .07611 .34505 .06807 .33075 Mtetra
0 .11 .664 r
.06807 .33075 .07611 .34505 .08566 .35719 .07782 .34107 Mtetra
0 .122 .669 r
.07782 .34107 .08566 .35719 .09527 .37011 .08767 .35188 Mtetra
0 .175 .693 r
.08767 .35188 .09527 .37011 .10508 .38292 .09773 .36235 Mtetra
.15 .25 .713 r
.09773 .36235 .10508 .38292 .11521 .39461 .10812 .37153 Mtetra
.3 .323 .717 r
.10812 .37153 .11521 .39461 .12578 .40416 .11894 .37853 Mtetra
.42 .381 .709 r
.11894 .37853 .12578 .40416 .13687 .41064 .13027 .38257 Mtetra
.508 .423 .695 r
.13027 .38257 .13687 .41064 .14855 .41335 .14213 .38308 Mtetra
.57 .454 .681 r
.14213 .38308 .14855 .41335 .1608 .41186 .15454 .3798 Mtetra
.615 .476 .67 r
.15454 .3798 .1608 .41186 .17361 .40605 .16743 .37275 Mtetra
.646 .494 .661 r
.16743 .37275 .17361 .40605 .18691 .39612 .18074 .36224 Mtetra
.67 .507 .656 r
.18074 .36224 .18691 .39612 .20058 .38255 .19437 .34878 Mtetra
.688 .52 .653 r
.19437 .34878 .20058 .38255 .21455 .36601 .20822 .33302 Mtetra
.702 .531 .653 r
.20822 .33302 .21455 .36601 .22868 .34728 .2222 .31572 Mtetra
.713 .542 .656 r
.2222 .31572 .22868 .34728 .24288 .32721 .23621 .29758 Mtetra
.722 .554 .662 r
.23621 .29758 .24288 .32721 .25707 .30665 .25019 .27932 Mtetra
.73 .567 .671 r
.25019 .27932 .25707 .30665 .27116 .28636 .26408 .26155 Mtetra
.735 .581 .683 r
.26408 .26155 .27116 .28636 .28512 .26702 .27784 .24476 Mtetra
.738 .597 .699 r
.27784 .24476 .28512 .26702 .29892 .24915 .29147 .22935 Mtetra
.739 .614 .719 r
.29147 .22935 .29892 .24915 .31254 .23313 .30495 .21557 Mtetra
.736 .631 .743 r
.30495 .21557 .31254 .23313 .32599 .21916 .3183 .20354 Mtetra
.728 .649 .77 r
.3183 .20354 .32599 .21916 .33931 .20728 .33153 .19328 Mtetra
.715 .665 .799 r
.33153 .19328 .33931 .20728 .35251 .19743 .34469 .18469 Mtetra
.697 .679 .828 r
.34469 .18469 .35251 .19743 .36563 .1894 .35779 .1776 Mtetra
.674 .688 .855 r
.35779 .1776 .36563 .1894 .37871 .18295 .37087 .17181 Mtetra
.649 .693 .877 r
.37087 .17181 .37871 .18295 .39179 .1778 .38395 .16707 Mtetra
.625 .693 .893 r
.38395 .16707 .39179 .1778 .40488 .17366 .39707 .16316 Mtetra
.604 .691 .904 r
.39707 .16316 .40488 .17366 .41802 .17029 .41023 .15988 Mtetra
.588 .687 .91 r
.41023 .15988 .41802 .17029 .43122 .16744 .42346 .15702 Mtetra
.578 .683 .913 r
.42346 .15702 .43122 .16744 .4445 .16494 .43677 .15442 Mtetra
.572 .68 .913 r
.43677 .15442 .4445 .16494 .45786 .1626 .45016 .15196 Mtetra
.572 .678 .912 r
.45016 .15196 .45786 .1626 .47131 .1603 .46364 .1495 Mtetra
.575 .677 .909 r
.46364 .1495 .47131 .1603 .48485 .15792 .47722 .14694 Mtetra
.582 .677 .905 r
.47722 .14694 .48485 .15792 .49849 .15535 .49089 .14419 Mtetra
.591 .678 .901 r
.49089 .14419 .49849 .15535 .51222 .1525 .50465 .14115 Mtetra
.602 .68 .896 r
.50465 .14115 .51222 .1525 .52604 .14929 .51851 .13776 Mtetra
.614 .682 .891 r
.51851 .13776 .52604 .14929 .53995 .14564 .53245 .13395 Mtetra
.628 .686 .885 r
.53245 .13395 .53995 .14564 .55394 .14152 .54647 .12967 Mtetra
.641 .689 .88 r
.54647 .12967 .55394 .14152 .568 .13686 .56057 .12489 Mtetra
.654 .693 .874 r
.56057 .12489 .568 .13686 .58214 .13167 .57474 .11957 Mtetra
.666 .697 .869 r
.57474 .11957 .58214 .13167 .59633 .12591 .58897 .11373 Mtetra
.678 .701 .865 r
.58897 .11373 .59633 .12591 .61057 .11962 .60325 .10737 Mtetra
.688 .705 .861 r
.60325 .10737 .61057 .11962 .62487 .11282 .61759 .10053 Mtetra
.697 .71 .858 r
.61759 .10053 .62487 .11282 .6392 .10555 .63197 .09325 Mtetra
.705 .714 .855 r
.63197 .09325 .6392 .10555 .65358 .09788 .64639 .08559 Mtetra
.712 .717 .854 r
.64639 .08559 .65358 .09788 .66799 .08987 .66086 .07762 Mtetra
.717 .721 .853 r
.66086 .07762 .66799 .08987 .68244 .0816 .67536 .0694 Mtetra
.72 .725 .853 r
.67536 .0694 .68244 .0816 .69693 .07314 .6899 .06101 Mtetra
.723 .728 .855 r
.6899 .06101 .69693 .07314 .71146 .06457 .70449 .05252 Mtetra
.08 .343 .817 r
.04013 .30157 .04841 .31413 .05829 .32161 .05021 .30754 Mtetra
.034 .278 .774 r
.05021 .30754 .05829 .32161 .06807 .33075 .06021 .31486 Mtetra
.043 .248 .747 r
.06021 .31486 .06807 .33075 .07782 .34107 .07022 .32307 Mtetra
.105 .254 .734 r
.07022 .32307 .07782 .34107 .08767 .35188 .08034 .33155 Mtetra
.2 .284 .727 r
.08034 .33155 .08767 .35188 .09773 .36235 .09068 .33951 Mtetra
.305 .326 .719 r
.09068 .33951 .09773 .36235 .10812 .37153 .10134 .34615 Mtetra
.401 .368 .707 r
.10134 .34615 .10812 .37153 .11894 .37853 .11241 .35068 Mtetra
.479 .404 .694 r
.11241 .35068 .11894 .37853 .13027 .38257 .12395 .35248 Mtetra
.539 .433 .682 r
.12395 .35248 .13027 .38257 .14213 .38308 .13598 .35113 Mtetra
.585 .456 .671 r
.13598 .35113 .14213 .38308 .15454 .3798 .14848 .3465 Mtetra
.619 .474 .663 r
.14848 .3465 .15454 .3798 .16743 .37275 .1614 .3387 Mtetra
.644 .489 .658 r
.1614 .3387 .16743 .37275 .18074 .36224 .17467 .32809 Mtetra
.664 .502 .655 r
.17467 .32809 .18074 .36224 .19437 .34878 .1882 .31519 Mtetra
.68 .514 .655 r
.1882 .31519 .19437 .34878 .20822 .33302 .2019 .30061 Mtetra
.692 .525 .657 r
.2019 .30061 .20822 .33302 .2222 .31572 .21568 .285 Mtetra
.702 .537 .662 r
.21568 .285 .2222 .31572 .23621 .29758 .22948 .26896 Mtetra
.71 .55 .67 r
.22948 .26896 .23621 .29758 .25019 .27932 .24324 .25307 Mtetra
.716 .563 .68 r
.24324 .25307 .25019 .27932 .26408 .26155 .25691 .23777 Mtetra
.721 .578 .695 r
.25691 .23777 .26408 .26155 .27784 .24476 .27048 .22344 Mtetra
.723 .595 .712 r
.27048 .22344 .27784 .24476 .29147 .22935 .28394 .21035 Mtetra
.723 .612 .734 r
.28394 .21035 .29147 .22935 .30495 .21557 .29728 .19864 Mtetra
.719 .631 .758 r
.29728 .19864 .30495 .21557 .3183 .20354 .31053 .1884 Mtetra
.711 .648 .785 r
.31053 .1884 .3183 .20354 .33153 .19328 .32369 .17959 Mtetra
.698 .664 .813 r
.32369 .17959 .33153 .19328 .34469 .18469 .3368 .17212 Mtetra
.68 .677 .84 r
.3368 .17212 .34469 .18469 .35779 .1776 .34988 .16585 Mtetra
.66 .685 .863 r
.34988 .16585 .35779 .1776 .37087 .17181 .36296 .16062 Mtetra
.638 .689 .881 r
.36296 .16062 .37087 .17181 .38395 .16707 .37605 .15622 Mtetra
.618 .69 .894 r
.37605 .15622 .38395 .16707 .39707 .16316 .38919 .15248 Mtetra
.601 .687 .903 r
.38919 .15248 .39707 .16316 .41023 .15988 .40238 .14923 Mtetra
.589 .684 .907 r
.40238 .14923 .41023 .15988 .42346 .15702 .41564 .14632 Mtetra
.581 .68 .909 r
.41564 .14632 .42346 .15702 .43677 .15442 .42898 .14361 Mtetra
.577 .677 .908 r
.42898 .14361 .43677 .15442 .45016 .15196 .4424 .14099 Mtetra
.578 .675 .906 r
.4424 .14099 .45016 .15196 .46364 .1495 .45592 .13834 Mtetra
.581 .673 .903 r
.45592 .13834 .46364 .1495 .47722 .14694 .46953 .13559 Mtetra
.588 .673 .899 r
.46953 .13559 .47722 .14694 .49089 .14419 .48323 .13263 Mtetra
.596 .673 .894 r
.48323 .13263 .49089 .14419 .50465 .14115 .49703 .1294 Mtetra
.606 .675 .889 r
.49703 .1294 .50465 .14115 .51851 .13776 .51091 .12582 Mtetra
.618 .677 .884 r
.51091 .12582 .51851 .13776 .53245 .13395 .52489 .12184 Mtetra
.63 .68 .878 r
.52489 .12184 .53245 .13395 .54647 .12967 .53894 .1174 Mtetra
.642 .683 .873 r
.53894 .1174 .54647 .12967 .56057 .12489 .55308 .11248 Mtetra
.654 .687 .868 r
.55308 .11248 .56057 .12489 .57474 .11957 .56728 .10706 Mtetra
.666 .69 .864 r
.56728 .10706 .57474 .11957 .58897 .11373 .58154 .10114 Mtetra
.676 .695 .86 r
.58154 .10114 .58897 .11373 .60325 .10737 .59587 .09473 Mtetra
.686 .699 .856 r
.59587 .09473 .60325 .10737 .61759 .10053 .61025 .08787 Mtetra
.694 .703 .854 r
.61025 .08787 .61759 .10053 .63197 .09325 .62467 .08059 Mtetra
.702 .707 .852 r
.62467 .08059 .63197 .09325 .64639 .08559 .63914 .07297 Mtetra
.708 .711 .851 r
.63914 .07297 .64639 .08559 .66086 .07762 .65365 .06504 Mtetra
.713 .715 .851 r
.65365 .06504 .66086 .07762 .67536 .0694 .66821 .0569 Mtetra
.716 .719 .852 r
.66821 .0569 .67536 .0694 .6899 .06101 .6828 .04859 Mtetra
.718 .723 .853 r
.6828 .04859 .6899 .06101 .70449 .05252 .69745 .0402 Mtetra
.236 .426 .845 r
.0319 .28835 .04013 .30157 .05021 .30754 .0422 .29267 Mtetra
.209 .374 .81 r
.0422 .29267 .05021 .30754 .06021 .31486 .05246 .29804 Mtetra
.219 .346 .78 r
.05246 .29804 .06021 .31486 .07022 .32307 .06275 .30406 Mtetra
.263 .342 .757 r
.06275 .30406 .07022 .32307 .08034 .33155 .07315 .31016 Mtetra
.327 .354 .737 r
.07315 .31016 .08034 .33155 .09068 .33951 .08377 .31567 Mtetra
.397 .376 .719 r
.08377 .31567 .09068 .33951 .10134 .34615 .0947 .31989 Mtetra
.461 .401 .704 r
.0947 .31989 .10134 .34615 .11241 .35068 .106 .32219 Mtetra
.516 .424 .69 r
.106 .32219 .11241 .35068 .12395 .35248 .11771 .32209 Mtetra
.56 .445 .679 r
.11771 .32209 .12395 .35248 .13598 .35113 .12986 .31929 Mtetra
.595 .463 .67 r
.12986 .31929 .13598 .35113 .14848 .3465 .14242 .31375 Mtetra
.623 .478 .664 r
.14242 .31375 .14848 .3465 .1614 .3387 .15532 .30564 Mtetra
.644 .491 .661 r
.15532 .30564 .1614 .3387 .17467 .32809 .16851 .29534 Mtetra
.661 .503 .66 r
.16851 .29534 .17467 .32809 .1882 .31519 .18191 .28333 Mtetra
.674 .515 .662 r
.18191 .28333 .1882 .31519 .2019 .30061 .19543 .27014 Mtetra
.685 .527 .666 r
.19543 .27014 .2019 .30061 .21568 .285 .20901 .25633 Mtetra
.693 .539 .673 r
.20901 .25633 .21568 .285 .22948 .26896 .22259 .24239 Mtetra
.7 .552 .683 r
.22259 .24239 .22948 .26896 .24324 .25307 .23613 .22875 Mtetra
.705 .567 .696 r
.23613 .22875 .24324 .25307 .25691 .23777 .2496 .21574 Mtetra
.709 .583 .712 r
.2496 .21574 .25691 .23777 .27048 .22344 .26298 .20363 Mtetra
.71 .6 .731 r
.26298 .20363 .27048 .22344 .28394 .21035 .27628 .19258 Mtetra
.709 .618 .753 r
.27628 .19258 .28394 .21035 .29728 .19864 .28951 .18268 Mtetra
.704 .636 .778 r
.28951 .18268 .29728 .19864 .31053 .1884 .30266 .17396 Mtetra
.695 .652 .803 r
.30266 .17396 .31053 .1884 .32369 .17959 .31576 .16638 Mtetra
.682 .667 .829 r
.31576 .16638 .32369 .17959 .3368 .17212 .32884 .15985 Mtetra
.666 .678 .852 r
.32884 .15985 .3368 .17212 .34988 .16585 .3419 .15425 Mtetra
.648 .685 .871 r
.3419 .15425 .34988 .16585 .36296 .16062 .35498 .14945 Mtetra
.63 .688 .886 r
.35498 .14945 .36296 .16062 .37605 .15622 .36809 .1453 Mtetra
.614 .688 .896 r
.36809 .1453 .37605 .15622 .38919 .15248 .38125 .14166 Mtetra
.6 .686 .902 r
.38125 .14166 .38919 .15248 .40238 .14923 .39447 .13839 Mtetra
.591 .682 .905 r
.39447 .13839 .40238 .14923 .41564 .14632 .40776 .13539 Mtetra
.585 .679 .905 r
.40776 .13539 .41564 .14632 .42898 .14361 .42113 .13253 Mtetra
.582 .675 .904 r
.42113 .13253 .42898 .14361 .4424 .14099 .43459 .12972 Mtetra
.583 .673 .901 r
.43459 .12972 .4424 .14099 .45592 .13834 .44814 .12687 Mtetra
.587 .671 .897 r
.44814 .12687 .45592 .13834 .46953 .13559 .46178 .1239 Mtetra
.593 .67 .893 r
.46178 .1239 .46953 .13559 .48323 .13263 .47551 .12073 Mtetra
.601 .67 .888 r
.47551 .12073 .48323 .13263 .49703 .1294 .48934 .11729 Mtetra
.611 .671 .883 r
.48934 .11729 .49703 .1294 .51091 .12582 .50326 .11352 Mtetra
.621 .673 .878 r
.50326 .11352 .51091 .12582 .52489 .12184 .51727 .10936 Mtetra
.632 .675 .873 r
.51727 .10936 .52489 .12184 .53894 .1174 .53135 .10477 Mtetra
.643 .678 .868 r
.53135 .10477 .53894 .1174 .55308 .11248 .54552 .09972 Mtetra
.654 .681 .863 r
.54552 .09972 .55308 .11248 .56728 .10706 .55976 .0942 Mtetra
.665 .685 .859 r
.55976 .0942 .56728 .10706 .58154 .10114 .57406 .0882 Mtetra
.675 .689 .856 r
.57406 .0882 .58154 .10114 .59587 .09473 .58842 .08176 Mtetra
.684 .693 .853 r
.58842 .08176 .59587 .09473 .61025 .08787 .60284 .07489 Mtetra
.692 .698 .851 r
.60284 .07489 .61025 .08787 .62467 .08059 .61731 .06763 Mtetra
.698 .702 .85 r
.61731 .06763 .62467 .08059 .63914 .07297 .63182 .06005 Mtetra
.704 .706 .849 r
.63182 .06005 .63914 .07297 .65365 .06504 .64638 .0522 Mtetra
.709 .71 .85 r
.64638 .0522 .65365 .06504 .66821 .0569 .66099 .04415 Mtetra
.712 .714 .851 r
.66099 .04415 .66821 .0569 .6828 .04859 .67564 .03595 Mtetra
.714 .718 .853 r
.67564 .03595 .6828 .04859 .69745 .0402 .69034 .02767 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.9902 .36087 m
.97793 .371 L
.9644 .38126 L
.9386 .39519 L
.93529 .3968 L
.9128 .40428 L
.887 .40921 L
.8612 .41034 L
.8354 .40774 L
.8096 .40122 L
.79723 .3968 L
.7838 .39035 L
.758 .37408 L
.75402 .371 L
.7322 .35031 L
.72783 .3452 L
.71005 .3194 L
.7064 .31291 L
.69801 .2936 L
.69052 .2678 L
.68702 .242 L
.68726 .2162 L
.69126 .1904 L
.69931 .1646 L
.7064 .14865 L
.712 .1388 L
.7307 .113 L
.7322 .1113 L
.758 .08751 L
.7584 .0872 L
.7838 .07122 L
.80641 .0614 L
.8096 .06037 L
.8354 .05385 L
.8612 .05124 L
.887 .05237 L
.9128 .05731 L
.92691 .0614 L
.9386 .06637 L
.9644 .08033 L
.97371 .0872 L
.9902 .10071 L
s
.3194 .08461 m
.34223 .0872 L
.3452 .08791 L
.371 .09874 L
.38929 .113 L
.3968 .12114 L
.40735 .1388 L
.41577 .1646 L
.41685 .1904 L
.41093 .2162 L
.3968 .24129 L
.39606 .242 L
.371 .26436 L
.36449 .2678 L
.3452 .27538 L
.3194 .27871 L
.2936 .27497 L
.2715 .2678 L
.2678 .26348 L
.24408 .242 L
.242 .23993 L
.22935 .2162 L
.2234 .1904 L
.22448 .1646 L
.23295 .1388 L
.242 .12302 L
.25097 .113 L
.2678 .09966 L
.2936 .0883 L
.29803 .0872 L
.3194 .08461 L
s
.82478 .9902 m
.83192 .9644 L
.83243 .9386 L
.82645 .9128 L
.8122 .887 L
.8096 .88358 L
.78416 .8612 L
.7838 .86098 L
.758 .84929 L
.7322 .84516 L
.7064 .84753 L
.6806 .85699 L
.67277 .8612 L
.6548 .8757 L
.64516 .887 L
.63119 .9128 L
.629 .91956 L
.62514 .9386 L
.62567 .9644 L
.629 .97924 L
.63282 .9902 L
s
.113 .44004 m
.1388 .4366 L
.1646 .43853 L
.1904 .44609 L
.19611 .4484 L
.2162 .4603 L
.2325 .4742 L
.242 .48492 L
.25196 .5 L
.26312 .5258 L
.2678 .54859 L
.26811 .5516 L
.2678 .57707 L
.26777 .5774 L
.26206 .6032 L
.24997 .629 L
.242 .64069 L
.2291 .6548 L
.2162 .66535 L
.1904 .67958 L
.18778 .6806 L
.1646 .68712 L
.1388 .68905 L
.113 .68561 L
.09365 .6806 L
.0872 .6764 L
.0614 .65969 L
.05585 .6548 L
.0356 .63012 L
.03496 .629 L
.02323 .6032 L
.01746 .5774 L
.01712 .5516 L
.02218 .5258 L
.03304 .5 L
.0356 .49539 L
.05239 .4742 L
.0614 .46592 L
.0872 .44932 L
.08813 .4484 L
.113 .44004 L
s
.1904 .05827 m
.2162 .05083 L
.242 .05071 L
.2678 .05786 L
.27623 .0614 L
.2936 .07377 L
.30624 .0872 L
.3194 .10997 L
.32036 .113 L
.32627 .1388 L
.325 .1646 L
.3194 .18346 L
.31643 .1904 L
.29765 .2162 L
.2936 .21994 L
.2678 .23634 L
.24899 .242 L
.242 .24319 L
.2162 .24306 L
.21013 .242 L
.1904 .23595 L
.1646 .21909 L
.16151 .2162 L
.14266 .1904 L
.1388 .18111 L
.13414 .1646 L
.13287 .1388 L
.13878 .113 L
.1388 .11292 L
.1529 .0872 L
.1646 .07459 L
.18308 .0614 L
.1904 .05827 L
s
.93623 .0098 m
.9386 .01582 L
.94476 .0356 L
.94921 .0614 L
.94988 .0872 L
.9468 .113 L
.93976 .1388 L
.9386 .14217 L
.92832 .1646 L
.9128 .18846 L
.91126 .1904 L
.887 .21555 L
.88624 .2162 L
.8612 .23393 L
.84599 .242 L
.8354 .24636 L
.8096 .25421 L
.7838 .25803 L
.758 .25809 L
.7322 .25441 L
.7064 .24671 L
.69488 .242 L
.6806 .23445 L
.6548 .21631 L
.65467 .2162 L
.62965 .1904 L
.629 .18959 L
.61258 .1646 L
.6032 .14463 L
.60113 .1388 L
.59409 .113 L
.59102 .0872 L
.59168 .0614 L
.59613 .0356 L
.6032 .01346 L
.60467 .0098 L
s
.20266 .0098 m
.2162 .02877 L
.22778 .0356 L
.24036 .0614 L
.242 .06721 L
.24521 .0872 L
.24331 .113 L
.242 .11853 L
.2345 .1388 L
.2162 .16391 L
.21551 .1646 L
.1904 .18295 L
.17037 .1904 L
.1646 .19178 L
.1388 .1937 L
.11839 .1904 L
.113 .18887 L
.0872 .17633 L
.07283 .1646 L
.0614 .15129 L
.05436 .1388 L
.04528 .113 L
.04343 .0872 L
.04828 .0614 L
.06125 .0356 L
.0614 .03549 L
.08702 .0098 L
s
.0098 .59793 m
.03393 .6032 L
.0356 .60339 L
.0614 .60351 L
.06418 .6032 L
.0872 .59828 L
.113 .58681 L
.12709 .5774 L
.1388 .56689 L
.15166 .5516 L
.1646 .52894 L
.16583 .5258 L
.17337 .5 L
.17528 .4742 L
.17182 .4484 L
.1646 .42502 L
.16254 .4226 L
.14586 .3968 L
.1388 .38902 L
.11627 .371 L
.113 .36908 L
.0872 .35751 L
.0614 .35223 L
.0356 .35234 L
.0098 .35787 L
s
.0098 .57399 m
.0356 .5678 L
.0614 .56361 L
.0872 .56134 L
.113 .56096 L
.1388 .56247 L
.1646 .56588 L
.1904 .57126 L
.21228 .5774 L
.2162 .5787 L
.242 .58832 L
.2678 .60036 L
.2732 .6032 L
.2936 .61508 L
.31415 .629 L
.3194 .63291 L
.3452 .65449 L
.34554 .6548 L
.37078 .6806 L
.371 .68084 L
.39152 .7064 L
.3968 .71383 L
.40866 .7322 L
.4226 .75762 L
.42279 .758 L
.4343 .7838 L
.44346 .8096 L
.4484 .82679 L
.45046 .8354 L
.45542 .8612 L
.45843 .887 L
.45955 .9128 L
.45878 .9386 L
.45612 .9644 L
.45152 .9902 L
s
.67808 .9902 m
.6806 .98868 L
.7064 .97243 L
.71731 .9644 L
.7322 .94427 L
.73494 .9386 L
.74373 .9128 L
.74552 .887 L
.74077 .8612 L
.7322 .83954 L
.72852 .8354 L
.7064 .81124 L
.70462 .8096 L
.6806 .79607 L
.6548 .78933 L
.629 .78921 L
.6032 .79567 L
.57837 .8096 L
.5774 .81051 L
.55431 .8354 L
.5516 .83825 L
.54201 .8612 L
.53726 .887 L
.53906 .9128 L
.54783 .9386 L
.5516 .94617 L
.56546 .9644 L
.5774 .9731 L
.6032 .98929 L
.60471 .9902 L
s
.66178 .9902 m
.66337 .9644 L
.66021 .9386 L
.6548 .91722 L
.65199 .9128 L
.63765 .887 L
.629 .87581 L
.61439 .8612 L
.6032 .85253 L
.5774 .83818 L
.57304 .8354 L
.5516 .82994 L
.5258 .82677 L
.5 .82835 L
.4742 .83488 L
.47261 .8354 L
.4484 .84696 L
.42867 .8612 L
.4226 .8668 L
.4054 .887 L
.3968 .90049 L
.39108 .9128 L
.38283 .9386 L
.37969 .9644 L
.38127 .9902 L
s
0 g
.03 w
.86629 .23079 Mdot
.32013 .1816 Mdot
.72877 .9494 Mdot
.1424 .56283 Mdot
.22956 .14702 Mdot
.77045 .0789 Mdot
.14438 .09287 Mdot
.04905 .47791 Mdot
.10528 .91516 Mdot
.6414 .89274 Mdot
.52153 .9686 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.20588 .10693 m
.22549 .10395 L
.24444 .10784 L
.2451 .10792 L
.26471 .11616 L
.27665 .12745 L
.28431 .13899 L
.28787 .14706 L
.2878 .16667 L
.28431 .17302 L
.26483 .18627 L
.26471 .18631 L
.2451 .18792 L
.23606 .18627 L
.22549 .18412 L
.20588 .17182 L
.20081 .16667 L
.18802 .14706 L
.18662 .12745 L
.20391 .10784 L
.20588 .10693 L
s
.18627 .08499 m
.20588 .08031 L
.22549 .08073 L
.2451 .08502 L
.25532 .08824 L
.26471 .09273 L
.28431 .10502 L
.28781 .10784 L
.30392 .12434 L
.30592 .12745 L
.31541 .14706 L
.31734 .16667 L
.31064 .18627 L
.30392 .19573 L
.28724 .20588 L
.28431 .20692 L
.26471 .21145 L
.2451 .21102 L
.22549 .20649 L
.22344 .20588 L
.20588 .19813 L
.18857 .18627 L
.18627 .1845 L
.17022 .16667 L
.16667 .16107 L
.16002 .14706 L
.15661 .12745 L
.16103 .10784 L
.16667 .09683 L
.17899 .08824 L
.18627 .08499 L
s
.65686 .87246 m
.66874 .87255 L
.67647 .8736 L
.69608 .88093 L
.71016 .89216 L
.71569 .90003 L
.72196 .91176 L
.72499 .93137 L
.71877 .95098 L
.71569 .95655 L
.69608 .97034 L
.69518 .97059 L
.67647 .97357 L
.65686 .97263 L
.64779 .97059 L
.63725 .96638 L
.61983 .95098 L
.61765 .94762 L
.61011 .93137 L
.60953 .91176 L
.61765 .89367 L
.61852 .89216 L
.63725 .87683 L
.65596 .87255 L
.65686 .87246 L
s
.18627 .06267 m
.20588 .0607 L
.22549 .0622 L
.2451 .06664 L
.2518 .06863 L
.26471 .07379 L
.28431 .08401 L
.2909 .08824 L
.30392 .09802 L
.31414 .10784 L
.32353 .11867 L
.3289 .12745 L
.33724 .14706 L
.33972 .16667 L
.33599 .18627 L
.32389 .20588 L
.32353 .20629 L
.30392 .22111 L
.29508 .22549 L
.28431 .22806 L
.26471 .23064 L
.2451 .22966 L
.22549 .2255 L
.22545 .22549 L
.20588 .21821 L
.18627 .20722 L
.18428 .20588 L
.16667 .1916 L
.16149 .18627 L
.14706 .16738 L
.14665 .16667 L
.13753 .14706 L
.13364 .12745 L
.13532 .10784 L
.14437 .08824 L
.14706 .08456 L
.16667 .06941 L
.16761 .06863 L
.18627 .06267 L
s
.16667 .04782 m
.18627 .04372 L
.20588 .04307 L
.22549 .0452 L
.2435 .04902 L
.2451 .04975 L
.26471 .05658 L
.28431 .06581 L
.28943 .06863 L
.30392 .07778 L
.31746 .08824 L
.32353 .0936 L
.33666 .10784 L
.34314 .11622 L
.34952 .12745 L
.35711 .14706 L
.3598 .16667 L
.35747 .18627 L
.3492 .20588 L
.34314 .2148 L
.33228 .22549 L
.32353 .23188 L
.30392 .24145 L
.29392 .2451 L
.28431 .2465 L
.26471 .24821 L
.2451 .24704 L
.23354 .2451 L
.22549 .24321 L
.20588 .23667 L
.18627 .22719 L
.18332 .22549 L
.16667 .21426 L
.15659 .20588 L
.14706 .19663 L
.13822 .18627 L
.12745 .17053 L
.12538 .16667 L
.11707 .14706 L
.11302 .12745 L
.11342 .10784 L
.11908 .08824 L
.12745 .07374 L
.13225 .06863 L
.14706 .05661 L
.16277 .04902 L
.16667 .04782 L
s
.71999 .9902 m
.73529 .9733 L
.74149 .97059 L
.75123 .95098 L
.7541 .93137 L
.75143 .91176 L
.74305 .89216 L
.73529 .88066 L
.72748 .87255 L
.71569 .86295 L
.69732 .85294 L
.69608 .85247 L
.67647 .8467 L
.65686 .8451 L
.63725 .84763 L
.62024 .85294 L
.61765 .85486 L
.59804 .86892 L
.59464 .87255 L
.58188 .89216 L
.57843 .90195 L
.57645 .91176 L
.57683 .93137 L
.57843 .93861 L
.58306 .95098 L
.59661 .97059 L
.59804 .97181 L
.61765 .98614 L
.62224 .9902 L
s
.16667 .02835 m
.18627 .02578 L
.20588 .02599 L
.22549 .02854 L
.23054 .02941 L
.2451 .03319 L
.26471 .0398 L
.28431 .0484 L
.28559 .04902 L
.30392 .05916 L
.31816 .06863 L
.32353 .07263 L
.34132 .08824 L
.34314 .09005 L
.358 .10784 L
.36275 .11464 L
.3695 .12745 L
.37648 .14706 L
.37925 .16667 L
.37774 .18627 L
.37151 .20588 L
.36275 .22128 L
.35929 .22549 L
.34314 .24112 L
.3376 .2451 L
.32353 .25303 L
.30392 .26036 L
.28431 .26438 L
.28163 .26471 L
.26471 .26567 L
.24662 .26471 L
.2451 .26453 L
.22549 .26105 L
.20588 .25518 L
.18627 .24678 L
.18293 .2451 L
.16667 .23549 L
.15285 .22549 L
.14706 .22069 L
.13176 .20588 L
.12745 .20106 L
.11616 .18627 L
.10784 .17278 L
.1048 .16667 L
.09718 .14706 L
.09315 .12745 L
.09282 .10784 L
.09666 .08824 L
.10576 .06863 L
.10784 .06539 L
Mistroke
.12288 .04902 L
.12745 .04543 L
.14706 .0344 L
.16132 .02941 L
.16667 .02835 L
Mfstroke
.7573 .9902 m
.77007 .97059 L
.77451 .95902 L
.77656 .95098 L
.77828 .93137 L
.77571 .91176 L
.77451 .90551 L
.76882 .89216 L
.75695 .87255 L
.7549 .86987 L
.73841 .85294 L
.73529 .85039 L
.71569 .83753 L
.70747 .83333 L
.69608 .82909 L
.67647 .82416 L
.65686 .82242 L
.63725 .82384 L
.61765 .82867 L
.60575 .83333 L
.59804 .8375 L
.57843 .85194 L
.57737 .85294 L
.56131 .87255 L
.55882 .87594 L
.55188 .89216 L
.5474 .91176 L
.54738 .93137 L
.55189 .95098 L
.55882 .96672 L
.5616 .97059 L
.5782 .9902 L
s
.06863 .46911 m
.08824 .4653 L
.10784 .46845 L
.12745 .47945 L
.12867 .48039 L
.1452 .5 L
.14706 .50415 L
.15224 .51961 L
.1525 .53922 L
.14706 .55447 L
.14513 .55882 L
.12745 .57416 L
.11168 .57843 L
.10784 .57884 L
.09651 .57843 L
.08824 .5769 L
.06863 .56794 L
.05747 .55882 L
.04902 .5491 L
.04468 .53922 L
.03936 .51961 L
.04119 .5 L
.04902 .4849 L
.05111 .48039 L
.06863 .46911 L
s
.78601 .9902 m
.79412 .97365 L
.79524 .97059 L
.80004 .95098 L
.80108 .93137 L
.79861 .91176 L
.79412 .89468 L
.79261 .89216 L
.78274 .87255 L
.77451 .86048 L
.76825 .85294 L
.7549 .8396 L
.74731 .83333 L
.73529 .82494 L
.71569 .8144 L
.71428 .81373 L
.69608 .8071 L
.67647 .80261 L
.65686 .80076 L
.63725 .80151 L
.61765 .80497 L
.59804 .81142 L
.59268 .81373 L
.57843 .82138 L
.56188 .83333 L
.55882 .83597 L
.54297 .85294 L
.53922 .85782 L
.53034 .87255 L
.52226 .89216 L
.51961 .90232 L
.51802 .91176 L
.51741 .93137 L
.51961 .94711 L
.52053 .95098 L
.5278 .97059 L
.53922 .98827 L
.54011 .9902 L
s
.21651 .0098 m
.22549 .01136 L
.2451 .01609 L
.26471 .02255 L
.2815 .02941 L
.28431 .0307 L
.30392 .04064 L
.31803 .04902 L
.32353 .05262 L
.34314 .06729 L
.34472 .06863 L
.36275 .08596 L
.36477 .08824 L
.3796 .10784 L
.38235 .11212 L
.38999 .12745 L
.39645 .14706 L
.3992 .16667 L
.39824 .18627 L
.39331 .20588 L
.38375 .22549 L
.38235 .22771 L
.36805 .2451 L
.36275 .25005 L
.34314 .26405 L
.34202 .26471 L
.32353 .27341 L
.30392 .27951 L
.28431 .283 L
.26471 .28422 L
.2451 .28335 L
.22549 .28039 L
.20588 .27527 L
.18627 .26787 L
.17934 .26471 L
.16667 .25785 L
.14736 .2451 L
.14706 .24487 L
.12745 .22818 L
.12469 .22549 L
.10784 .20654 L
.10733 .20588 L
.09391 .18627 L
.08824 .17615 L
.08384 .16667 L
.07688 .14706 L
.07297 .12745 L
.07221 .10784 L
.0749 .08824 L
.08164 .06863 L
Mistroke
.08824 .05642 L
.09369 .04902 L
.10784 .03443 L
.11432 .02941 L
.12745 .02152 L
.14706 .01357 L
.16144 .0098 L
Mfstroke
.0098 .57979 m
.0261 .59804 L
.02941 .60116 L
.04902 .61552 L
.05246 .61765 L
.06863 .6252 L
.08824 .63107 L
.10784 .63345 L
.12745 .63231 L
.14706 .62724 L
.16599 .61765 L
.16667 .61715 L
.18627 .59925 L
.18723 .59804 L
.19903 .57843 L
.20528 .55882 L
.20588 .5556 L
.20742 .53922 L
.20601 .51961 L
.20588 .51882 L
.20127 .5 L
.19306 .48039 L
.18627 .46846 L
.18095 .46078 L
.16667 .4442 L
.16356 .44118 L
.14706 .42818 L
.13612 .42157 L
.12745 .41776 L
.10784 .41179 L
.08824 .40968 L
.06863 .41117 L
.04902 .41642 L
.03691 .42157 L
.02941 .4262 L
.01186 .44118 L
.0098 .44282 L
s
.81296 .9902 m
.81373 .98852 L
.8201 .97059 L
.82379 .95098 L
.82437 .93137 L
.822 .91176 L
.81665 .89216 L
.81373 .88422 L
.80814 .87255 L
.79603 .85294 L
.79412 .85032 L
.77952 .83333 L
.77451 .82841 L
.75685 .81373 L
.7549 .81233 L
.73529 .80016 L
.72312 .79412 L
.71569 .79103 L
.69608 .7845 L
.67647 .7803 L
.65686 .77835 L
.63725 .77859 L
.61765 .78109 L
.59804 .78597 L
.57843 .79345 L
.57697 .79412 L
.55882 .80397 L
.54483 .81373 L
.53922 .81826 L
.52359 .83333 L
.51961 .83783 L
.5083 .85294 L
.5 .86683 L
.49723 .87255 L
.48964 .89216 L
.48517 .91176 L
.48374 .93137 L
.48546 .95098 L
.4906 .97059 L
.49972 .9902 L
s
.27988 .0098 m
.28431 .0117 L
.30392 .02098 L
.3193 .02941 L
.32353 .03192 L
.34314 .0448 L
.34889 .04902 L
.36275 .06025 L
.37184 .06863 L
.38235 .07959 L
.38954 .08824 L
.40196 .10626 L
.40287 .10784 L
.41232 .12745 L
.41832 .14706 L
.421 .16667 L
.42039 .18627 L
.41635 .20588 L
.40855 .22549 L
.40196 .2371 L
.39621 .2451 L
.38235 .26048 L
.37768 .26471 L
.36275 .27603 L
.34876 .28431 L
.34314 .28709 L
.32353 .295 L
.30392 .3005 L
.28473 .30392 L
.28431 .30396 L
.26471 .30555 L
.2451 .30544 L
.22775 .30392 L
.22549 .30361 L
.20588 .2997 L
.18627 .29351 L
.16667 .285 L
.16525 .28431 L
.14706 .27316 L
.13523 .26471 L
.12745 .25819 L
.11334 .2451 L
.10784 .23931 L
.09588 .22549 L
.08824 .21545 L
.08166 .20588 L
.07021 .18627 L
.06863 .1832 L
.06139 .16667 L
.05512 .14706 L
Mistroke
.05143 .12745 L
.05044 .10784 L
.05235 .08824 L
.05752 .06863 L
.06664 .04902 L
.06863 .0457 L
.08109 .02941 L
.08824 .02235 L
.10439 .0098 L
Mfstroke
.84126 .9902 m
.84692 .97059 L
.84978 .95098 L
.85003 .93137 L
.84776 .91176 L
.84296 .89216 L
.83552 .87255 L
.83333 .86781 L
.82517 .85294 L
.81373 .83617 L
.81151 .83333 L
.79412 .81408 L
.79375 .81373 L
.77451 .79718 L
.7704 .79412 L
.7549 .78388 L
.73771 .77451 L
.73529 .77336 L
.71569 .76528 L
.69608 .75929 L
.67647 .7553 L
.67376 .7549 L
.65686 .75324 L
.63725 .75306 L
.61765 .75475 L
.61634 .7549 L
.59804 .75841 L
.57843 .76411 L
.55882 .772 L
.55357 .77451 L
.53922 .78238 L
.52163 .79412 L
.51961 .79564 L
.5 .81251 L
.49876 .81373 L
.48124 .83333 L
.48039 .83441 L
.4676 .85294 L
.46078 .86491 L
.4571 .87255 L
.4494 .89216 L
.44429 .91176 L
.44176 .93137 L
.44187 .95098 L
.44481 .97059 L
.45093 .9902 L
s
.0098 .64011 m
.02941 .65382 L
.03454 .65686 L
.04902 .66418 L
.06863 .6717 L
.08724 .67647 L
.08824 .67663 L
.10784 .67907 L
.12745 .67901 L
.1464 .67647 L
.14706 .67634 L
.16667 .67073 L
.18627 .66165 L
.19412 .65686 L
.20588 .648 L
.21712 .63725 L
.22549 .62725 L
.23202 .61765 L
.242 .59804 L
.2451 .59026 L
.24833 .57843 L
.25167 .55882 L
.25238 .53922 L
.25069 .51961 L
.24673 .5 L
.2451 .49378 L
.24063 .48039 L
.23249 .46078 L
.22549 .44675 L
.22248 .44118 L
.21078 .42157 L
.20588 .41481 L
.19763 .40196 L
.18627 .38822 L
.18328 .38235 L
.1679 .36275 L
.1724 .34314 L
.18627 .34218 L
.20588 .34018 L
.22549 .33853 L
.2451 .33648 L
.26471 .33386 L
.28431 .33049 L
.30392 .32615 L
.31388 .32353 L
.32353 .32044 L
.34314 .31302 L
.36214 .30392 L
.36275 .30359 L
.38235 .29129 L
Mistroke
.39152 .28431 L
.40196 .27508 L
.41182 .26471 L
.42157 .25236 L
.42633 .2451 L
.43652 .22549 L
.44118 .2136 L
.44314 .20588 L
.44652 .18627 L
.44692 .16667 L
.4444 .14706 L
.44118 .13297 L
.43889 .12745 L
.43017 .10784 L
.42157 .09318 L
.41814 .08824 L
.40231 .06863 L
.40196 .06824 L
.38235 .04919 L
.38215 .04902 L
.36275 .03359 L
.3569 .02941 L
.34314 .02028 L
.32536 .0098 L
Mfstroke
.0098 .38309 m
.01129 .38235 L
.02941 .37269 L
.04902 .36482 L
.05469 .36275 L
.06863 .35896 L
.08824 .35475 L
.10784 .35223 L
.12745 .34817 L
.14706 .34665 L
.15696 .34314 L
.14706 .33558 L
.13687 .32353 L
.12745 .31213 L
.12079 .30392 L
.10784 .28774 L
.10517 .28431 L
.09027 .26471 L
.08824 .26177 L
.07637 .2451 L
.06863 .23314 L
.06376 .22549 L
.05267 .20588 L
.04902 .1987 L
.04331 .18627 L
.03583 .16667 L
.03035 .14706 L
.02941 .14565 L
.027 .12745 L
.02593 .10784 L
.02729 .08824 L
.02941 .07318 L
.03133 .06863 L
.03846 .04902 L
.04902 .02985 L
.04932 .02941 L
.0653 .0098 L
s
.0098 .31938 m
.02577 .30392 L
.02941 .29881 L
.03522 .28431 L
.03524 .26471 L
.03041 .2451 L
.02941 .24132 L
.02356 .22549 L
.01628 .20588 L
.0098 .18713 L
s
.8747 .9902 m
.87913 .97059 L
.88129 .95098 L
.88129 .93137 L
.87916 .91176 L
.87492 .89216 L
.87255 .88388 L
.86844 .87255 L
.85959 .85294 L
.85294 .84089 L
.84819 .83333 L
.83383 .81373 L
.83333 .81312 L
.81591 .79412 L
.81373 .792 L
.79412 .77506 L
.79341 .77451 L
.77451 .76124 L
.76411 .7549 L
.7549 .7499 L
.73529 .74068 L
.72147 .73529 L
.71569 .73337 L
.69608 .72789 L
.67647 .72406 L
.65686 .72183 L
.63725 .7212 L
.61765 .72215 L
.59804 .72468 L
.57843 .72879 L
.55882 .73451 L
.55649 .73529 L
.53922 .74198 L
.51961 .75122 L
.51273 .7549 L
.5 .76241 L
.4821 .77451 L
.48039 .77577 L
.46078 .79172 L
.45813 .79412 L
.44118 .81093 L
.43864 .81373 L
.42266 .83333 L
.42157 .83482 L
.40965 .85294 L
.40196 .86685 L
.39921 .87255 L
.39118 .89216 L
.38539 .91176 L
.38235 .92581 L
Mistroke
.3818 .93137 L
.38041 .95098 L
.3813 .97059 L
.38235 .97869 L
.3846 .9902 L
Mfstroke
.8633 .0098 m
.87255 .01458 L
.89216 .02697 L
.89545 .02941 L
.91176 .04353 L
.91718 .04902 L
.93137 .0659 L
.93337 .06863 L
.94575 .08824 L
.95098 .09838 L
.95511 .10784 L
.96188 .12745 L
.96629 .14706 L
.96842 .16667 L
.96826 .18627 L
.96569 .20588 L
.96043 .22549 L
.952 .2451 L
.95098 .24703 L
.93952 .26471 L
.93137 .27434 L
.921 .28431 L
.91176 .29149 L
.89216 .30293 L
.8902 .30392 L
.87255 .31027 L
.85294 .31428 L
.83333 .31534 L
.81373 .31366 L
.79412 .30926 L
.77863 .30392 L
.77451 .30203 L
.7549 .2917 L
.74379 .28431 L
.73529 .27774 L
.72098 .26471 L
.71569 .25913 L
.70405 .2451 L
.69608 .23371 L
.69106 .22549 L
.68114 .20588 L
.67647 .19437 L
.67386 .18627 L
.66901 .16667 L
.66654 .14706 L
.66646 .12745 L
.66885 .10784 L
.6739 .08824 L
.67647 .08087 L
.682 .06863 L
Mistroke
.69396 .04902 L
.69608 .04619 L
.71146 .02941 L
.71569 .02575 L
.73529 .01219 L
.73945 .0098 L
Mfstroke
.0098 .69814 m
.02941 .70877 L
.04508 .71569 L
.04902 .71718 L
.06863 .72351 L
.08824 .72791 L
.10784 .73041 L
.12745 .73104 L
.14706 .72973 L
.16667 .7264 L
.18627 .72086 L
.19965 .71569 L
.20588 .71277 L
.22549 .70156 L
.23327 .69608 L
.2451 .68627 L
.25498 .67647 L
.26471 .66492 L
.2705 .65686 L
.28193 .63725 L
.28431 .63233 L
.29027 .61765 L
.2961 .59804 L
.29975 .57843 L
.30143 .55882 L
.30129 .53922 L
.29944 .51961 L
.29606 .5 L
.2914 .48039 L
.28589 .46078 L
.28431 .45595 L
.28025 .44118 L
.27589 .42157 L
.27551 .40196 L
.28431 .38295 L
.28483 .38235 L
.30392 .36688 L
.3128 .36275 L
.32353 .35724 L
.34314 .34801 L
.35361 .34314 L
.36275 .33845 L
.38235 .32757 L
.38901 .32353 L
.40196 .31477 L
.41607 .30392 L
.42157 .2992 L
.43682 .28431 L
.44118 .27952 L
.45285 .26471 L
Mistroke
.46078 .25294 L
.46516 .2451 L
.4743 .22549 L
.48039 .20699 L
.48062 .20588 L
.4838 .18627 L
.48431 .16667 L
.48211 .14706 L
.48039 .13737 L
.4769 .12745 L
.4685 .10784 L
.46078 .09357 L
.45727 .08824 L
.44259 .06863 L
.44118 .06691 L
.42428 .04902 L
.42157 .04639 L
.40201 .02941 L
.40196 .02937 L
.38235 .01472 L
.37506 .0098 L
Mfstroke
.0098 .03754 m
.01367 .02941 L
.02541 .0098 L
s
.9902 .40964 m
.97133 .42157 L
.97059 .42199 L
.95098 .43199 L
.93137 .43995 L
.92792 .44118 L
.91176 .44608 L
.89216 .45053 L
.87255 .45341 L
.85294 .45479 L
.83333 .45472 L
.81373 .45321 L
.79412 .45026 L
.77451 .44584 L
.7586 .44118 L
.7549 .43992 L
.73529 .43241 L
.71569 .42323 L
.71248 .42157 L
.69608 .41225 L
.68024 .40196 L
.67647 .39931 L
.65686 .38424 L
.6546 .38235 L
.63725 .36691 L
.63289 .36275 L
.61765 .3475 L
.61347 .34314 L
.59804 .327 L
.59477 .32353 L
.57843 .30811 L
.57545 .30392 L
.55882 .29518 L
.53922 .29172 L
.51961 .29741 L
.50773 .30392 L
.5 .30887 L
.48039 .32275 L
.47928 .32353 L
.46078 .33704 L
.45224 .34314 L
.44118 .35103 L
.42463 .36275 L
.42157 .36485 L
.40196 .37911 L
.39794 .38235 L
.38235 .39586 L
.37731 .40196 L
.36596 .42157 L
.36275 .43512 L
Mistroke
.36218 .44118 L
.36275 .46075 L
.36275 .46078 L
.36527 .48039 L
.36835 .5 L
.37117 .51961 L
.37333 .53922 L
.37463 .55882 L
.37504 .57843 L
.3746 .59804 L
.37343 .61765 L
.37173 .63725 L
.36983 .65686 L
.36827 .67647 L
.36829 .69608 L
.3782 .71569 L
.38235 .71795 L
.40196 .7194 L
.4214 .71569 L
.42157 .71564 L
.44118 .71019 L
.46078 .70397 L
.48039 .69756 L
.48506 .69608 L
.5 .69143 L
.51961 .68576 L
.53922 .6807 L
.55859 .67647 L
.55882 .67643 L
.57843 .67321 L
.59804 .67098 L
.61765 .66982 L
.63725 .6698 L
.65686 .67098 L
.67647 .6734 L
.69356 .67647 L
.69608 .67708 L
.71569 .68236 L
.73529 .68905 L
.75274 .69608 L
.7549 .69708 L
.77451 .70703 L
.78965 .71569 L
.79412 .71854 L
.81373 .73215 L
.81792 .73529 L
.83333 .74807 L
.84093 .7549 L
.85294 .76677 L
.86013 .77451 L
Mistroke
.87255 .78925 L
.87629 .79412 L
.88986 .81373 L
.89216 .81741 L
.90106 .83333 L
.91028 .85294 L
.91176 .8565 L
.91744 .87255 L
.92283 .89216 L
.9265 .91176 L
.92844 .93137 L
.92865 .95098 L
.9271 .97059 L
.92376 .9902 L
Mfstroke
.0098 .78678 m
.02588 .79412 L
.02941 .79556 L
.04902 .8027 L
.06863 .80845 L
.08824 .81286 L
.09257 .81373 L
.10784 .81597 L
.12745 .81794 L
.14706 .81893 L
.16667 .8191 L
.18627 .81863 L
.20588 .81785 L
.22549 .81729 L
.2451 .81811 L
.26471 .82502 L
.27031 .83333 L
.27401 .85294 L
.27339 .87255 L
.27172 .89216 L
.27008 .91176 L
.26901 .93137 L
.26887 .95098 L
.26989 .97059 L
.27229 .9902 L
s
.54261 .0098 m
.53922 .01254 L
.51961 .02259 L
.5 .02241 L
.48039 .01597 L
.46417 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
o`000=7ooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0coooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`3?ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo0<oooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo1000
0009ooooo`D000001_ooool00ol00000000000000006ooooo`<000001Oooool2000000kooooo0ol0
0009ooooo`?o00008?ooool00`00003o0000o`00000Eooooo`03o`0000000000000001Oooooo00?o
0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo0P0I6AT00ol00000<c<c03<c
<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH200000180Ogmo0`00
000606IVIP8000001`1<C4`00`000000<c<c03<c<`0403<c<`8000003olI6AT3o`0000D0000000?o
0000oaTI6OlI6AT08?lI6AT00`000000<c<c03<c<`0I03<c<`0300000?lI6AWo6ATI013o6ATI1?oo
ool00ol0003oooooooooo`3?ooooo`002Oooool01_l0003oooooooooooooool06ATIo`0000H0<c<c
00?o000004a<C01<C4`00P1<C4`2000000@0IVIV0P00000807moO`P000001`1oOgl4000000@0IVIV
0P00000604a<C0030000000c<c<0<c<c00D0<c<c00<00000oaTI6OlI6AT03olI6AT5o`0002;o6ATI
00<0000003<c<`0c<c<06`0c<c<00`00003o6ATIoaTI6@0?oaTI6@Cooooo00?o0000ooooooooool0
coooool000Wooooo00Go0000ooooooooooooooooo`00000603<c<`03o`00001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`0400000?l0003o0000000000P0
VIVI00@00000o`000000000000001`1oOgl2000000@0IVIV00?o000004a<C01<C4`0101<C4`00`00
0000<c<c03<c<`0503<c<`800000=OlI6AT00ol00000<c<c03<c<`0M03<c<`03o`000000003o6ATI
00ko6ATI1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00H0<c<c00?o000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo
00<0Ogmo0P00000@09VIV@<000001P1oOgl2000000<0IVIV0P00000504a<C003o`0000000000<c<c
00H0<c<c00<00000oaTI6OlI6AT0<OlI6AT00`000000<c<c03<c<`0O03<c<`0300000?lI6AWo6ATI
00go6ATI1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00D0<c<c00?o000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo
0080Ogmo0P00000E09VIV@@00000101oOgl00`000000IVIV06IVIP0206IVIP8000001@1<C4`00`00
0000<c<c03<c<`0503<c<`0300000?lI6AWo6ATI02oo6ATI00<0000003<c<`0c<c<08@0c<c<00`00
003o6ATIoaTI6@0<oaTI6@Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooo
oooooooo1P0c<c<01Ol00000C4a<04a<C01<C4`0000000@0IVIV00<0000007moO`1oOgl00P1oOgl0
0`000000VIVI09VIV@0409VIV@ko00001`2IVIT00ol00000Ogmo07moO`0207moO`030000001VIVH0
IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00`00003o000003<c<`0503<c<`0300000?lI6AWo
6ATI02go6ATI00<0000003<c<`0c<c<08`0c<c<00ol0003o6ATIoaTI6@0;oaTI6@Cooooo00?o0000
ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo1@0c<c<00ol00000C4a<04a<C002
04a<C005o`00001VIVH0IVIV06IVIP000000101oOgl00`00003o000009VIV@0409VIV@;o00003@2c
/k<3o`0000@0VIVI0`00000307moO`03o`0000000000000000<0IVIV00<0000004a<C01<C4`00`1<
C4`00`000000<c<c03<c<`0403<c<`03o`000?lI6AWo6ATI02go6ATI00?o000003<c<`0c<c<0900c
<c<00`00003o6ATIoaTI6@0:oaTI6@Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000
oooooooooooooooo1@0c<c<00ol00000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVI_l00000
0`1oOgl00`000000VIVI09VIV@0209VIV@?o00004P2c/k<3o`0000@0VIVI0P00000407moO`050000
001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI02co
6ATI00<0000003<c<`0c<c<09@0c<c<00`00003o6ATIoaTI6@09oaTI6@Cooooo00?o0000oooooooo
ool0coooool000Wooooo00Co0000oooooooooooooooo100c<c<00ol00000C4a<04a<C00204a<C005
0000001VIVH0IVIV06IVIP0000000`1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c
00D0/k>c2`0000060;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl01000
0000IVIV06IVIP1VIVH2000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`00003o6ATIoaTI6@0Z
oaTI6@030000000c<c<0<c<c02L0<c<c00<00000oaTI6OlI6AT02?lI6AT4ooooo`03o`000?oooooo
oooo0<oooooo0009ooooo`04o`000?ooooooooooooooo`<0<c<c00?o000004a<C01<C4`00P1<C4`0
1@000000IVIV06IVIP1VIVH0000000@0Ogmo00Go000009VIV@2IVIT0VIVIo`0000050;>c/`03o`00
00000000000000/0c<c<00Co000000000000000000000`2c/k<3o`0000<0VIVI00?o000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c
<c<0100c<c<00`00003o6ATIoaTI6@0XoaTI6@030000000c<c<0<c<c02T0<c<c00<00000oaTI6OlI
6AT01olI6AT4ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooo`<0
<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00@0000009VI
V@2IVIWo00001@2c/k<00`000000c<c<0<c<c00@0<c<c0800000102c/k<01Ol00000VIVI09VIV@2I
VIT0000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0000000H0<c<c
00<00000oaTI6OlI6AT0:?lI6AT00`000000<c<c03<c<`0Y03<c<`0300000?lI6AWo6ATI00Oo6ATI
1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003oooooooooooooool303<c<`03o`00
001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`050000002IVIT0VIVI09VI
VOl00000102c/k<00`000000c<c<0<c<c0050<c<c0So00001P3<c<`00`000000/k>c0;>c/`020;>c
/`05o`00002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV06IVIP0206IVIP050000001<C4`0
C4a<04a<C00000001P0c<c<00`00003o6ATIoaTI6@0VoaTI6@030000000c<c<0<c<c02/0<c<c00<0
0000oaTI6OlI6AT01_lI6AT4ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?oooooo
ooooooooo`<0<c<c00Go000004a<C01<C4`0C4a<0000000306IVIP030000001oOgl0Ogmo0080Ogmo
00@0000009VIV@2IVIWo0000102c/k<00`000000c<c<0<c<c0040<c<c0;o0000203Vi^H2o`0000D0
c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIT0000000@0Ogmo00Go000006IV
IP1VIVH0IVIV0000000404a<C0030000000c<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT09OlI6AT0
0`000000<c<c03<c<`0[03<c<`0300000?lI6AWo6ATI00Ko6ATI1?ooool00ol0003oooooooooo`2;
ooooo`;o0000@_ooool000Wooooo00Co0000oooooooooooooooo0`0c<c<01Ol00000C4a<04a<C01<
C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@05o`00002c/k<0/k>c0;>c/ol0
00001@3<c<`2o`0000`0i^KV0ol000030<c<c0<000000P2c/k<2o`000080VIVI00?o00000000001o
Ogl00P1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<00000o`00000c<c<0100c<c<00`00
003o0000oaTI6@0SoaTI6@030000000c<c<0<c<c02d0<c<c00?o0000oaTI6OlI6AT01OlI6AT4oooo
o`03o`000?oooooooooo08Sooooo0ol000000ooooooo0000ooooo`11ooooo`002Oooool01?l0003o
ooooooooooooool303<c<`05o`00001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1o
Ogl0000000<0VIVI00Go00000;>c/`2c/k<0/k>c000000030<c<c0;o00004@3Vi^H00ol00000c<c<
0<c<c0030<c<c0050000002c/k<0/k>c0;>c/ol000000P2IVIT01@000000Ogmo07moO`1oOgl00000
00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI
02;o6ATI00<0000003<c<`0c<c<0;P0c<c<00`00003o6ATIoaTI6@04oaTI6@Cooooo00?o0000oooo
ooooool0Q_ooool2o`0000Cooooo0_l00011ooooo`002Oooool01?l0003oooooooooooooool203<c
<`03o`00001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0
VIVI09VIVOl000000`2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00H0i^KV1@00
00060>KViP03o`00003<c<`0c<c<00<0c<c<00D000000;>c/`2c/k<0/k>co`00000209VIV@050000
001oOgl0Ogmo07moO`0000000`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0
<c<c00<00000oaTI6OlI6AT08?lI6AT00`000000<c<c03<c<`0_03<c<`0300000?lI6AWo6ATI00Co
6ATI1?ooool00ol0003oooooooooo`23ooooo`?o00001_ooool00ol0003oooooo`000010ooooo`00
2Oooool01?l0003oooooooooooooool203<c<`03o`00001<C4`0C4a<0080C4a<00D0000006IVIP1V
IVH0IVIV0000000207moO`050000002IVIT0VIVI09VIVOl000000`2c/k<01@000000c<c<0<c<c03<
c<co000000L0i^KV00?o00000000003oool0103oool3000000@0i^KV0_l000040<c<c0050000002c
/k<0/k>c0;>c/ol000000P2IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00<0000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI023o6ATI00<0000003<c<`0c
<c<0<00c<c<00`00003o6ATIoaTI6@03oaTI6@Cooooo00?o0000ooooooooool0P?ooool3o`0000Wo
oooo00?o0000ooooool00000@?ooool000Wooooo00Co0000oooooooooooooooo0P0c<c<00ol00000
C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIWo
000000<0/k>c00D000000<c<c03<c<`0c<c<o`0000060>KViP030000003oool0oooo00P0oooo0P00
00040>KViP05o`00003<c<`0c<c<0<c<c0000000102c/k<01?l00000VIVI09VIV@00000307moO`04
0000001VIVH0IVIV000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`00003o6ATIoaTI6@0PoaTI
6@030000000c<c<0<c<c0300<c<c00<00000oaTI6OlI6AT00olI6AT4ooooo`03o`000?oooooooooo
07kooooo0_l0000<ooooo`04o`000?ooooooooooo`0003oooooo0009ooooo`04o`000?oooooooooo
ooooo`<0<c<c00Go000004a<C01<C4`0C4a<0000000306IVIP040000001oOgl0Ogmo000000<0VIVI
00Go00000;>c/`2c/k<0/k>c000000030<c<c003o`00003Vi^H0i^KV00<0i^KV00<000000?ooo`3o
ool02`3oool00`000000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c?l000000`2c/k<01?l0
0000VIVI09VIV@00000307moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c03<c
<`0403<c<`0300000?lI6AWo6ATI01oo6ATI00<0000003<c<`0c<c<0<@0c<c<00`00003o6ATIoaTI
6@02oaTI6@Cooooo00?o0000ooooooooool0Noooool3o`0000gooooo00<0][OJo`000?ooool00_oo
ool00ol0003oooooooooo`0looooo`002Oooool01?l0003oooooooooooooool303<c<`05o`00001<
C4`0C4a<04a<C00000000`1VIVH010000000Ogmo07moO`00000309VIV@05o`00002c/k<0/k>c0;>c
/`0000000`3<c<`00ol00000i^KV0>KViP020>KViP030000003oool0oooo00d0oooo00<000000>KV
iP3Vi^H00P3Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00Co000009VIV@2IVIT000000`1o
Ogl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00`0c<c<00`00003o6ATI
oaTI6@0OoaTI6@030000000c<c<0<c<c0340<c<c00<00000oaTI6OlI6AT00_lI6AT4ooooo`03o`00
0?oooooooooo07Wooooo0_l0000?ooooo`80][OJ00Go0000ooooooooooooooooo`00000nooooo`00
2Oooool01?l0003oooooooooooooool303<c<`05o`00001<C4`0C4a<04a<C00000000`1VIVH01000
0000Ogmo07moO`00000309VIV@05o`00002c/k<0/k>c0;>c/`0000000`3<c<`00ol00000i^KV0>KV
iP020>KViP030000003oool0oooo00d0oooo00<000000>KViP3Vi^H00P3Vi^H01Ol00000c<c<0<c<
c03<c<`0000000<0/k>c00Co000009VIV@2IVIT000000`1oOgl01@000000IVIV06IVIP1VIVH00000
00@0C4a<00?o000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@0OoaTI6@030000000c<c<0<c<c
0340<c<c00<00000oaTI6OlI6AT00_lI6AT4ooooo`03o`000?oooooooooo07Kooooo0ol0000?oooo
o`80][KI0P2f]mX00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo0009ooooo`04
o`000?ooooooooooooooo`<0<c<c00Go000004a<C01<C4`0C4a<0000000306IVIP040000001oOgl0
Ogmo000000<0VIVI00Go00000;>c/`2c/k<0/k>c000000030<c<c003o`00003Vi^H0i^KV0080i^KV
00<000000?ooo`3oool03P3oool00`000000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c000
00000P2c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV00000004
04a<C0030000000c<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT07_lI6AT00`000000<c<c03<c<`0a
03<c<`0300000?lI6AWo6ATI00;o6ATI1?ooool00ol0003oooooooooo`1dooooo`;o00004?ooool0
0`2e]MT0][KI0;Jff@020;Jff@030;Jgf_l00000]kWJ00?ooooo00?o0000ooooooooool0>oooool0
00Wooooo00Co0000oooooooooooooooo0`0c<c<00ol00000C4a<04a<C00204a<C0040000001VIVH0
IVIV000000<0Ogmo00D0000009VIV@2IVIT0VIVIo`0000020;>c/`050000003<c<`0c<c<0<c<c?l0
0000103Vi^H00`000000oooo0?ooo`0>0?ooo`03o`00003Vi^H0i^KV0080i^KV00Go00000<c<c03<
c<`0c<c<000000030;>c/`04o`00002IVIT0VIVI000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000
000404a<C0030000000c<c<0<c<c00<0<c<c00<00000oaTI6OlI6AT07_lI6AT00`000000<c<c03<c
<`0b03<c<`0400000?lI6AWo6ATIoaTI6@Cooooo00?o0000ooooooooool0LOooool3o`00017ooooo
0`2e]MT20;Jff@040;NhfP2g^M[o00000;NifPCooooo00?o0000ooooooooool0>_ooool000Wooooo
00Co0000oooooooooooooooo0`0c<c<00ol00000C4a<04a<C00204a<C0040000001VIVH0IVIV0000
00<0Ogmo00D0000009VIV@2IVIT0VIVIo`0000020;>c/`050000003<c<`0c<c<0<c<c?l00000103V
i^H00`000000oooo0?ooo`0?0?ooo`030000003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<
000000020;>c/`05o`00002IVIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH00000
00@0C4a<00<0000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@0NoaTI6@030000000c<c<0<c<c
0380<c<c00@00000oaTI6OlI6AWo6ATI1?ooool00ol0003oooooooooo`1^ooooo`?o00004_ooool0
1@2d]=T0]KGI0;Fef@2e]MT0][OI00@0]kSJ00?o00000;VjfP2i^]X01?ooool00ol0003ooooooooo
o`0iooooo`002Oooool01?l0003oooooooooooooool303<c<`03o`00001<C4`0C4a<0080C4a<00@0
000006IVIP1VIVH000000`1oOgl01@000000VIVI09VIV@2IVIWo00000080/k>c00D000000<c<c03<
c<`0c<c<o`0000040>KViP030000003oool0oooo00l0oooo00<000000>KViP3Vi^H00P3Vi^H01Ol0
0000c<c<0<c<c03<c<`000000080/k>c00Go000009VIV@2IVIT0VIVI0000000207moO`050000001V
IVH0IVIV06IVIP000000101<C4`00`000000<c<c03<c<`0303<c<`0300000?lI6AWo6ATI01ko6ATI
00<0000003<c<`0c<c<0<P0c<c<01000003o6ATIoaTI6OlI6AT4ooooo`03o`000?oooooooooo06co
oooo0_l0000Booooo`80/[?I0`2d]=T0102e]MT0][OI0;Jgf@2f]mT20;NhfP030;RifP2i^][o0000
0080^K[J0oooool00ol0003oooooooooo`0iooooo`002Oooool01?l0003oooooooooooooool403<c
<`03o`00001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH000000`1oOgl01@000000VIVI09VIV@2I
VIWo00000080/k>c00D000000<c<c03<c<`0c<c<o`0000040>KViP030000003oool0oooo00h0oooo
00<000000>KViP3Vi^H00P3Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00Co000009VIV@2I
VIT000000`1oOgl010000000IVIV06IVIP00000404a<C0030000000c<c<0<c<c00@0<c<c00<00000
oaTI6OlI6AT07OlI6AT00`000000<c<c03<c<`0b03<c<`0400000?lI6AWo6ATIoaTI6@Cooooo00?o
0000ooooooooool0JOooool3o`0001;ooooo00<0/K;I0;:cf@2b/mT00P2b/mT00`2d]=T0]KKI0;Ff
f@030;Jgf@070;NhfP2h^MX0^;WJ0;Rif_l00000^K[J0;Zkf`04ooooo`03o`000?oooooooooo03So
oooo0009ooooo`04o`000?ooooooooooooooo`@0<c<c00?o000004a<C01<C4`00P1<C4`01@000000
IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVIo`0000030;>c/`050000003<c<`0
c<c<0<c<c?l00000103Vi^H00`000000oooo0?ooo`0=0?ooo`030000003Vi^H0i^KV0080i^KV00Go
00000<c<c03<c<`0c<c<000000030;>c/`04o`00002IVIT0VIVI000000<0Ogmo00@0000006IVIP1V
IVH00000101<C4`00`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI01go6ATI00<0000003<c
<`0c<c<0<P0c<c<01000003o6ATIoaTI6OlI6AT4ooooo`03o`000?oooooooooo06Oooooo0_l0000D
ooooo`<0/K;I0P2b/mT00`2c]=X0]KKI0;Fff@020;Fff@030;Jgf@2g^=X0^;WJ0080^;WJ00<0^K_K
o`00002j^m/00P2j^m/4ooooo`03o`000?oooooooooo03Oooooo0009ooooo`04o`000?oooooooooo
ooooo`@0<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0
000009VIV@2IVIT0VIVIo`0000030;>c/`05o`00003<c<`0c<c<0<c<c?l000001@3Vi^H00ol00000
00000?ooo`0<0?ooo`030000003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<000000030;>c
/`04o`00002IVIT0VIVI000000<0Ogmo00@0000006IVIP1VIVH00000101<C4`00`000000<c<c03<c
<`0403<c<`0300000?lI6AWo6ATI01go6ATI00<0000003<c<`0c<c<0<P0c<c<01000003o6ATIoaTI
6OlI6AT4ooooo`03o`000?oooooooooo06Cooooo0ol0000Dooooo`030:nafP2a/]T0/K;I0080/K;I
00@0/[?I0;>dfP2c]=X0/kCJ0P2e]]T01@2f]mX0]kSJ0;NhfP2g^=X0^;WJ0080^K_K00Co00000;Zk
f`2j^m/0^kgL1?ooool00ol0003oooooooooo`0gooooo`002Oooool01?l0003oooooooooooooool5
03<c<`03o`00001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`040000002I
VIT0VIVIo`0000<0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViP030000
003oool0oooo00P0oooo0P0000050>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<01?l00000
VIVI09VIV@00000307moO`040000001VIVH0IVIV000000@0C4a<00<0000003<c<`0c<c<0100c<c<0
0`00003o6ATIoaTI6@0MoaTI6@030000000c<c<0<c<c0380<c<c00@00000oaTI6OlI6AWo6ATI1?oo
ool00ol0003oooooooooo`1Rooooo`;o00005?ooool20:b`f`<0[k7J0P2a/]T00`2a/mX0/kCJ0;>d
fP020;>dfP050;Fff@2f]mX0][OJ0;JgfP2g^=X00P2h^]/20;Vkf`03o`00002k_M`0^kgL0080^kgL
1?ooool00ol0003oooooooooo`0fooooo`002Oooool01?l0003oooooooooooooool503<c<`03o`00
001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0VIVI09VI
VOl000000`2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00@0i^KV00<000000?oo
o`3oool01P3oool00`000000i^KV0>KViP040>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<0
1Ol00000VIVI09VIV@2IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000
000c<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT07_lI6AT00`000000<c<c03<c<`0a03<c<`040000
0?lI6AWo6ATIoaTI6@Cooooo00?o0000ooooooooool0Goooool3o`0001Cooooo00<0ZZoK0:b`f`2/
/=/00P2//=/00`2_/MX0[k;K0:nbf`030;6cfP80/kCJ00D0];KJ0;JgfP2f]mX0][OJ0;Nif`040;Rj
f`030;Vkfol00000^[gL00<0^kgL1Oooool00ol0003oooooooooo`0eooooo`002Oooool01Ol0003o
oooooooooooooooo000000D0<c<c00Go000004a<C01<C4`0C4a<o`00000406IVIP040000001oOgl0
Ogmo000000<0VIVI00Go00000;>c/`2c/k<0/k>c000000040<c<c0;o00001@3Vi^H300000003o`00
000000000000008000001`3Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00Go000009VIV@2I
VIT0VIVI0000000207moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c03<c<`04
03<c<`0300000?lI6AWo6ATI01ko6ATI00<0000003<c<`0c<c<0<@0c<c<01000003o6ATIoaTI6OlI
6AT4ooooo`03o`000?oooooooooo05gooooo0_l0000Dooooo`80YjkL0`2Z[m/20:b`f`030:fag02_
/]/0[k;K0080[k;K00<0/K?J0;:ef`2b]M/00`2d]]X0102f]mX0]kWK0;Nif`2g^M/20;Rjf`030;Vl
g02j_Mco00000080^[gL00<0^kgL0;bog@2l_md01?ooool00ol0003oooooooooo`0eooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000D0<c<c00Go000004a<C01<C4`0C4a<0000000406IVIP04
0000001oOgl0Ogmo000000@0VIVI00Ko00000;>c/`2c/k<0/k>co`00000000040<c<c003o`00003V
i^H0i^KV0140i^KV00Go00000<c<c03<c<`0c<c<000000030;>c/`05o`00002IVIT0VIVI09VIV@00
00000P1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`00
003o6ATIoaTI6@0OoaTI6@03o`00000c<c<0<c<c0300<c<c00@00000oaTI6OlI6AWo6ATI1?ooool0
0ol0003oooooooooo`1Jooooo`?o00005?ooool00`2T[Mh0YjkL0:N^g0020:N^g0030:Z_f`2Z/=d0
[K7L00<0[K7L0P2_/]/00`2`]=`0/[GK0;:ef`020;:ef`030;BffP2e^=`0]KSL00<0]kWK00L0^;[K
0;Vlg02i_=`0^KcLo`00002j_M`0^koM00<0_;oM00<0_<;Nooooooooool00_ooool00ol0003ooooo
ooooo`0dooooo`002Oooool01_l0003oooooooooooooool06ATIo`0000D0<c<c00Go000004a<C01<
C4`0C4a<0000000406IVIP040000001oOgl0Ogmo000000@0VIVI0_l000030;>c/`8000000`3<c<`3
o`0000h0i^KV0_l000030<c<c0050000002c/k<0/k>c0;>c/ol000000`2IVIT01@000000Ogmo07mo
O`1oOgl0000000<0IVIV00D0000004a<C01<C4`0C4a<0000000603<c<`0300000?lI6AWo6ATI023o
6ATI00<0000003<c<`0c<c<0<00c<c<01000003o6ATIoaTI6OlI6AT4ooooo`03o`000?oooooooooo
05Oooooo0ol0000Dooooo`80XJcO0`2T[Mh20:N^g0040:N_gP2Z/=d0Z[3M0:Z`g@<0[K7L00@0[k;K
0;2dg02`]=`0/;CL0P2b]M/00`2c]m`0]KSL0;Fhg0020;Fhg0030;Nif`2h^m`0^KcL0080^KcL00<0
^[kMo`00002k_md00P2k_md0102l_md0_<;N0;c2gP2l`]h4ooooo`03o`000?oooooooooo03?ooooo
0009ooooo`06o`000?ooooooooooooooo`0I6AWo00001@0c<c<00ol00000C4a<04a<C00204a<C003
0000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl00000o`00000409VIV@03o`00002c/k<0/k>c
0080/k>c00<000000<c<c03<c<`00`3<c<`4o`0000P0i^KV0_l000040<c<c0030000002c/k<0/k>c
0080/k>c00Go000009VIV@2IVIT0VIVI0000000307moO`050000001VIVH0IVIV06IVIP0000000`1<
C4`00`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI027o6ATI00<0000003<c<`0c<c<0;`0c
<c<01000003o6ATIoaTI6OlI6AT4ooooo`03o`000?oooooooooo05Gooooo0_l0000Eooooo`0309j/
h02Q[=l0XJcO0080XJcO00<0Y:gN0:B^g`2W[mh00`2W[mh30:Z`g@030:fag02]/md0/;CL00<0/;CL
00@0/[GK0;>gg02c]m`0/kOL0P2e^=`01@2f^]d0^;_L0;Rkg02h^m`0^KcL0080^[kM00?o00000;^o
g@2k_md00P2l`Mh20;c2gP030;g4gooooooooooo00;ooooo00?o0000ooooooooool0<oooool000Wo
oooo00Ko0000oooooooooooooooo01TI6Ol0000503<c<`03o`00001<C4`0C4a<00<0C4a<00D00000
06IVIP1VIVH0IVIV0000000407moO`050000002IVIT0VIVI09VIVOl00000102c/k<00ol000000000
0<c<c0070<c<c0So00001@3<c<`00`000000/k>c0;>c/`030;>c/`05o`00002IVIT0VIVI09VIV@00
00000`1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<0100c<c<00ol0
003o6ATIoaTI6@0QoaTI6@030000000c<c<0<c<c02l0<c<c00@00000oaTI6OlI6AWo6ATI1?ooool0
0ol0003oooooooooo`1Booooo`?o00004_ooool00`2IZn<0W:_R09b[hP0409j/h080XJcO00@0XJkP
0:B^g`2T[]l0Y:kO0`2W[mh20:Z`g@040:ZbgP2]/md0[K?M0:fcg@80/;CL00D0/;KM0;>gg02c]m`0
/kOL0;>jgP040;Jjg@030;Rkg02h_]h0^;kN0080^[kM00Go00000;c1gP2l`Mh0_<7N0;c4h0040;g4
g`Cooooo00?o0000ooooooooool0<_ooool000Wooooo00Ko0000oooooooooooooooo01TI6Ol00006
03<c<`03o`00001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`040000002I
VIT0VIVI09VIV@;o0000102c/k<00`000000c<c<0<c<c00A0<c<c0030000002c/k<0/k>c00<0/k>c
00Go000009VIV@2IVIT0VIVI0000000307moO`050000001VIVH0IVIV06IVIP000000101<C4`00`00
0000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI027o6ATI00<0000003<c<`0c<c<0;`0c<c<01000
003o6ATIoaTI6OlI6AT4ooooo`03o`000?oooooooooo053ooooo0_l0000Booooo`0309N[i02IZn<0
VJ_S0080VJ_S0P2LZn8209j/h00309j]hP2Q[^00XJkP0080XJkP0P2T[]l20:N_gP030:Nag`2Z/]h0
Z[;N0080Z[;N00<0[K?M0:fegP2]]Mh00`2`]]d0102c]m`0/k[N0;>jgP2c^]h20;Jjg@030;Nmg`2h
_]h0^;kN0080^;kN00@0^[kMo`00002k`Ml0_<7N0`2la>020;g4g`030;k6hOoooooooooo00;ooooo
00?o0000ooooooooool0<_ooool000Wooooo00Co0000oooooooooooooooo0P0I6AT00ol00000<c<c
03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo
07moO`0207moO`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00P2c/k<3000000h0c<c<
0P0000050;>c/`05o`00002IVIT0VIVI09VIVOl00000101oOgl01@000000IVIV06IVIP1VIVH00000
00@0C4a<00<0000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@0SoaTI6@030000000c<c<0<c<c
02d0<c<c00<00000oaTI6OlI6AT00_lI6AT4ooooo`03o`000?oooooooooo04gooooo0ol0000?oooo
o`0409F/iP2FZnD0UZ_U09J[i@<0Uj_T0`2IZn<00`2LZn80VjcS09^/h`0309j]hP<0XJkP00<0Y:kO
0:B`h@2T/>400`2W/Ml20:ZbgP030:Zdh02]]Mh0[KGN0080[KGN00<0/;KM0;6ig`2a^Ml00`2c^]h0
102d_>00]kgO0;Nmg`2g_Ml20;RngP80^L3O00?o00000;_4h02ka>000`2la>040;k6h@Cooooo00?o
0000ooooooooool0<Oooool000Wooooo00Co0000oooooooooooooooo0P0I6AT00ol00000<c<c03<c
<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH2000000<0Ogmo00?o
000009VIV@2IVIT00P2IVIT3o`0000@0/k>c100000060<c<c0@000001@2c/k<2o`0000@0VIVI00D0
000007moO`1oOgl0Ogmo0000000306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
100c<c<00`00003o6ATIoaTI6@0SoaTI6@030000000c<c<0<c<c02d0<c<c00<00000oaTI6OlI6AT0
0_lI6AT4ooooo`03o`000?oooooooooo04_ooooo0_l0000=ooooo`80UJgW0P2D[>L309F/iP<0UZ_U
00<0Uj_T09J/iP2F[>H00P2H[>@409^/h`0309j]hP2M[^@0WJkT0080X:oR102T/>400`2W/Ml0Yk?Q
0:Nch@030:Zdh080[KGN00<0[[SP0;6ig`2a^Ml00P2a^Ml01P2c^]h0];cP0;Blh02d_>00]kgO0;O0
h@<0^L3O00<0^/?Qo`00002ka>000P2ka>000`2la>00_LKQ0;g6h@020;k6h@80_/WR1?ooool00ol0
003oooooooooo`0`ooooo`002Oooool01?l0003oooooooooooooool201TI6@03o`00000c<c<0<c<c
00D0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP050000001oOgl0Ogmo
07moO`0000001P2IVIT00ol00000/k>c0;>c/`050;>c/`H000001`2c/k<2o`0000D0VIVI00D00000
07moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c
<c<00`00003o6ATIoaTI6@0ToaTI6@03o`00000c<c<0<c<c02`0<c<c00<00000oaTI6OlI6AT00_lI
6AT4ooooo`03o`000?oooooooooo04Sooooo0ol0000:ooooo`80VJoV0P2G[^L409F]i`80U:cW00<0
UJcV09>/i`2C[>L00P2D[>L409J/iP80V:cT0P2K[><00`2J[^D0WJkT09f^i00209f^i080X:oR0P2T
/>400`2S/^<0Yk?Q0:Nch@020:Nch@030:Zdh02Z]n80Z[OR00<0[[SP0P2a^Ml01@2a^n40];cP0;Bl
h02d_>00];oR00<0]l3Q00@0^L3O0;[3h@2j`n7o00000P2ka>001@2la^80_LKQ0;g6h@2ma^40_LWS
00<0_/WR1?ooool00ol0003oooooooooo`0`ooooo`002Oooool01?l0003oooooooooooooool301TI
6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IV
IP040000001oOgl0Ogmo07moO`<00000102IVIT3o`000100/k>c00?o000009VIV@2IVIT0102IVIT0
1@000000Ogmo07moO`1oOgl0000000@0IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c
<`0403<c<`0300000?lI6AWo6ATI02Ko6ATI00<0000003<c<`0c<c<0:P0c<c<00`00003o6ATIoaTI
6@03oaTI6@Cooooo00?o0000ooooooooool0AOooool3o`0000Wooooo00<0XK3R09f`i@2M/>D0102I
[nH209N^i`80UJgW00<0U:kX09>]j02C[NP0102C[>L209B/i`80UZcV00@0U:gW09N]iP2G[NH0UjgV
0`2J[^D209f^i00409b`i@2O/N@0Wk7T09nai0<0Xk;S0P2W/n400`2W]N<0Z[OR0:ZghP020:ZghP03
0:jhh02^^^<0/K_Q00<0/K_Q00D0];cP0;BohP2d_n80];oR0;O0h@020;S3h`80^/?Q00?o00000;c6
hP2la^800P2la^801@2ma^40_LWS0;g9h`2mbN<0_/WR0080_/_T1?ooool00ol0003oooooooooo`0_
ooooo`002Oooool01?l0003oooooooooooooool301TI6@03o`00000c<c<0<c<c00D0<c<c00?o0000
04a<C01<C4`0101<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<00000
09VIV@2IVIT0102IVIT4o`0000P0/k>c1?l0000409VIV@80000000Go000007moO`1oOgl0Ogmoo`00
000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`00003o6ATIoaTI
6@0XoaTI6@030000000c<c<0<c<c02T0<c<c00?o0000oaTI6OlI6AT00olI6AT4ooooo`03o`000?oo
oooooooo04?ooooo0_l00009ooooo`80YJoN0`2Q/>8209f`i@80VJoV00@0VJoW09J_j02F[nP0UZoX
0`2D[^P209>]j080TjcW00@0TZgY09>]j02C[NP0TjgX0`2D[NL309N]iP0309Z^i@2I[nL0VJoW00<0
W;3U0`2O/N@00`2S/^<0XkCU0:Neh`030:Neh`80Z[OR00@0Z[WT0:jjh`2^^^<0[[[S0P2a^n401@2a
_^<0];oR0;BohP2d_n80]L;T00@0^<?S00<0^/?Qo`00002ja^<00P2la^820;c9i080_LWS0P2mc>D0
0`2nbn@0_/gV0;k=iP04ooooo`03o`000?oooooooooo02kooooo0009ooooo`04o`000?oooooooooo
ooooo`<06ATI00?o000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0
IVIV00@0IVIV00<0000007moO`1oOgl00`1oOgl00ol0000000000000000709VIV@So00001`2IVIT0
0`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`0
0`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI02So6ATI00<0000003<c<`0c<c<0:00c<c<0
0`00003o6ATIoaTI6@04oaTI6@Cooooo00?o0000ooooooooool0@?ooool3o`0000Wooooo00<0ZZgJ
0:F_gP2U[mh00P2U[mh00`2Q/>80Xk3Q09j`i00209j`i0<0VJoW0`2F[nP00`2D[^P0TjkY09:^j@02
09:^j@<0TZgY0`2C[NP00`2D[NL0TjkY09>^j@0209J^j0@0VJoW00<0W;3U09^bj02O/nH00P2O/nH3
0:>di@80YkGS00<0Y[SV0:Zii02Z^N@00P2Z^N@00`2^^^<0[[gU0:jmi@030;6nh`040;BohP2e`^@0
]L;T0;G2i080^<?S0P2ha^D00ol00000^/WV0;[9iP030;c9i0<0_LcU00D0_LkW0;k=iP2ncNH0_/gV
0;k?j003ooooo`03o`000?oooooooooo02kooooo0009ooooo`04o`000?ooooooooooooooo`<06ATI
00?o000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV00@0IVIV
00<0000007moO`1oOgl01@1oOgl300000140VIVI0P00000507moO`030000001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI02Wo6ATI
00<0000003<c<`0c<c<09`0c<c<00`00003o6ATIoaTI6@04oaTI6@Cooooo00?o0000ooooooooool0
?_ooool2o`0000[ooooo00@0[Z[D0:Z]fP2Z[MX0ZZgJ0P2U[mh0102X[m`0Xk3Q0:>`h@2S/>4309j`
i00309V_i`2J/>L0V[3W00<0UZoX0P2C[^T309:^j@0309:]j@2@[^/0T:k[0080TJkZ102C[^T209J^
j080VJoW00@0Uk7Y09^bj02K/^P0Vk;X0`2O/nH00`2S]>D0X[OW0::gi`030:JhiP80Z[WT00<0Z[cW
0:jmi@2^_ND00P2^_ND00`2a_^<0//;V0;;2iP020;G2i0060;G5iP2ha^D0^<KU0;S6i@2hbNOo0000
0`2jbNH0102lbN@0_<cV0;c<iP2mc>D30;g>i`040;k=iP2ncnP0_/oX0;k?j0?ooooo00?o0000oooo
ooooool0;Oooool000Wooooo00Co0000oooooooooooooooo100I6AT00ol00000<c<c03<c<`0703<c
<`03o`00001<C4`0C4a<00<0C4a<0P00000506IVIP<000001`1oOgl4000000T0VIVI1000000607mo
O`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c
<`0300000?lI6AWo6ATI02_o6ATI00<0000003<c<`0c<c<09@0c<c<00`00003o6ATIoaTI6@05oaTI
6@Cooooo00?o0000ooooooooool0>oooool3o`0000[ooooo102^Z]@00`2Z[MX0[ZgG0:j]e`030:R_
g0030:>`h@2V/N00Y[7P0080Wk7T102J/>L00`2F[nP0U[7Y09>`jP0209>`jP<0TJo[0`2@[^/2096^
jP80TjkY00<0TK3[09B`jP2D/>X0102G/NT00`2K/^P0V[CZ09ZdjP0209jfj@@0X[OW00<0Y[SV0:Jk
j02V^nP00`2Z_>L20:jmi@80[/7W00<0//;V0;;5j02baNP00`2eaNH0102ha^D0^<WW0;S9iol00002
0;[9iP80^/cX00<0_<cV0;c>j02lc^P00P2mc^L20;g@j@80_/oX0P2mdNT3ooooo`03o`000?oooooo
oooo02cooooo0009ooooo`04o`000?ooooooooooooooo`@06ATI00?o000003<c<`0c<c<01`0c<c<0
0ol00000C4a<04a<C00504a<C08000001P1VIVH00`00003o00000000000807moO`0300000?l00000
000000H000001`1oOgl200000003o`00001VIVH0IVIV0080IVIV0P00000504a<C0030000000c<c<0
<c<c00@0<c<c00<00000oaTI6OlI6AT0;OlI6AT00ol00000<c<c03<c<`0S03<c<`0300000?lI6AWo
6ATI00Ko6ATI1?ooool00ol0003oooooooooo`0iooooo`;o00003?ooool20;6Vc@<0[Z[D102^[ML0
0`2X[m`0[;3J0:b`fP030:Jah080Wk7T0P2J/>L0102K/^L0U[7Y09Jaj@2F/NT309>`jP03096_j`2@
/>`0T;3/0080Sk3/0`2@[n`3096`j`80U;3Z0P2G/NT00`2F/n/0V[CZ09ZdjP0209ZdjP80W[KY0P2R
]nL00`2R^^X0Y[_X0:Jkj0020:Jkj0030:Zli`2Z_nT0[/7W0080[/7W00<0[/CZ0;;5j02baNP00P2b
aNP00`2eaNH0]LSY0;G8j@020;S9i`05o`00002jc>P0^/cX0;[<j02jcnX00`2lc^P30;g@j@050;cB
j`2mdNT0_M7Y0;gAj@2ld^/00oooool00ol0003oooooooooo`0/ooooo`002Oooool01?l0003ooooo
ooooooooool401TI6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`01P1<C4`2000000L0
IVIV00<0000007moO`1oOgl04P1oOgl3000000H0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0403<c<`0300000?lI6AWo6ATI02oo6ATI00<0000003<c<`0c<c<08P0c<c<00`00003o
6ATIoaTI6@06oaTI6@Cooooo00?o0000ooooooooool0=_ooool3o`0000cooooo00<0]:;70;6Vc@2a
Y/d00P2aY/d00`2^Z]@0/ZW@0;:Yd0020:j]e`030;:]d`2//=X0[;3J0080[;3J00<0Y[7P0:Vbg`2R
/^@00`2R/^@209^bi`0309Jaj@2G/^/0Uk;[0080T[7/102@/>`208n`k003092_k02>/Nh0S[7^0080
T;7]102C/^`209Jcj`80V[CZ00<0VKO]09fhj`2M^>/00P2M^>/20::jjP80Y[_X0P2V_^/20:Zoj@04
0:k1i`2^a>X0[/CZ0:k4jP80//GX0P2ab>/01`2eb>T0]Lc[0;G<j`2hc>Wo00000;S<j@2jc>P00`2j
cnX0102lc^P0^m7Z0;_AjP2md>T30;cBj`040;gAj@2ld^/0_=;[0;cBj`?ooooo00?o0000oooooooo
ool0:oooool000Wooooo00Co0000oooooooooooooooo100I6AT00ol00000<c<c03<c<`0903<c<`03
o`00001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH01@1VIVH3000000d0Ogmo1000000706IVIP80
00001@1<C4`2000000H0<c<c00<00000oaTI6OlI6AT0<OlI6AT200000200<c<c0P000009oaTI6@Co
oooo00?o0000ooooooooool0<oooool3o`0000gooooo102dX/L20;6Vc@050;JUb02bZM00/ZW@0;:Y
d02^[ML00`2b[M<20:b`fP040;2af@2Y/]l0ZK;O0:Vbg`80X[;T00<0Y;CT09fdj02M]>P0102G/^/2
09:ak080T;3/00<0Sk;^08jakP2>/Nh0102>/Nh2092ak@80Tk;/00@0TKC_09FfkP2E]^h0UKK^0`2I
]nd209fhj`0409bkkP2Q_Nd0XKg]0:6mk@80Y[k[00<0YL7^0:W3k02Y`n`00P2Y`n`00`2^a>X0[/O]
0;78j`020;78j`030;7;k@2ec>/0]Lc[0080]Lc[00?o00000;O?k02gcn`00P2jcnX20;WAk0050;_A
jP2kdn`0^m?/0;_Ck02ld^/00P2kdn`20;cBj`80^m?/0_ooool00ol0003oooooooooo`0[ooooo`00
2Oooool01?l0003oooooooooooooool401TI6@03o`00000c<c<0<c<c00X0<c<c00?o000004a<C01<
C4`01`1<C4`2000000P0IVIV3@00000:06IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00ol0003o6ATIoaTI6@0doaTI6@030000000c<c<0<c<c01`0<c<c00<00000oaTI6OlI
6AT02OlI6AT4ooooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`80]Ik00`2dX/L40;JUb003
0;:Yd02gZ/`0]j[<00<0/ZgC102`/MT00`2Y/]l0[KGO0:feg`030:Bdi080WKCX0P2G/^/00`2G]>`0
T[?]09:ck@0209:ck@80Sk;^102>/Nh00`2=/o00Sk?_08nck`0208nck`80TKC_0`2E]^h00`2I]nd0
V;[_09bkkP0309bkkP030:6mk@2P`>l0X<3_00<0YL7^0P2Y`n`01@2Ya^h0[/O]0:k7k@2^and0/LS[
00<0/L_]0P2ec>/20;C?k@03o`00002gdNh0]m7^0080^M7/0P2idnh20;_Ck080^]C^00<0^m?/0;[E
k@2jeNd00P2kdn`20;[Dk@;ooooo00?o0000ooooooooool0:_ooool000Wooooo00Co0000oooooooo
oooooooo100I6AT00ol00000<c<c03<c<`0:03<c<`03o`00001<C4`0C4a<00T0C4a<0P00000J06IV
IP<000001`1<C4`00`000000<c<c03<c<`0503<c<`0300000?lI6AWo6ATI03Go6ATI00<0000003<c
<`0c<c<06P0c<c<00`00003o6ATIoaTI6@0:oaTI6@Cooooo00?o0000ooooooooool0;_ooool3o`00
013ooooo102eW/000`2dX/L0^:720;RQ`P030;JUb0@0]j[<00<0/ZgC0;N_d@2g[m400`2`/MT40:fe
g`030:Bdi02W]nD0W[KY00<0W[KY0P2G]>`209:ck@0309:ek`2?]>l0SkC_00H0SK?`0P2?/nl00`2=
]_40T;Oa092gl@0409>hl080V;[_0P2L^nh00`2K__00X<3_0:30k`020:30k`030:G1kP2Ta?00ZLK^
00<0ZLK^00D0[/O]0:g:k`2]b^l0[L[_0;7;k@020;3>k`80]<o]00<0/m7_o`00002gdNh00P2fdnl3
0;WCkP<0^]C^00@0^=K_0;[Ek@2jeNd0^]G]0`2je>d01@2he>kooooooooooooooooo000002_ooooo
0009ooooo`04o`000?ooooooooooooooo`<06ATI00?o000003<c<`0c<c<02`0c<c<00ol00000C4a<
04a<C00;04a<C0<00000501VIVH3000000P0C4a<0P00000703<c<`0300000?lI6AWo6ATI00oo6ATI
1`00000QoaTI6@<000005`0c<c<2000000go6ATI1?ooool00ol0003oooooooooo`0/ooooo`;o0000
4_ooool20;FI^`80]Ik000<0^Ibk0;RQ`P2hXL800P2hXL800`2fYLP0^ZK50;ZVa@020;NZc0030;b[
b@2g[m40]joA0080]joA00<0/;7I0;Bdf02d]=P00P2]]Ml0102`^=l0YkOU0:Ngi@2W]nD209jfj@03
0:2ijP2H]nd0V;O]0080V;O]0P2B]Nl208ndk`80SK?`00@0S;Ga08belP2<]O80S;Gb0`2=]_42092g
l@80TkS`00<0T[_b09NllP2G_?800P2G_?8209^nl080X<3_0P2O`o820:C4l080ZLK^0P2XbO420:g:
k`80[<ga00<0/<k_0;3Al@2cdNl00P2cdNl00ol00000]]?_0;KCk`020;KCk`040;WCkP2geNl0]mG_
0;[DkP<0^=K_00@0^]G]0;WEk`2ieNl0^]C]0`2he>h2ooooo`03o`000?oooooooooo02Wooooo0009
ooooo`04o`000?ooooooooooooooo`<06ATI00?o000003<c<`0c<c<0300c<c<00ol00000C4a<04a<
C00=04a<C0<000003@1VIVH4000000T0C4a<0P00000803<c<`0300000?lI6AWo6ATI00go6ATI2`00
000SoaTI6@030000000c<c<0<c<c01<0<c<c00<00000oaTI6OlI6AT03OlI6AT4ooooo`03o`000?oo
oooooooo02Wooooo0ol0000Booooo`050;FE]P2eVK/0]IVk0;FI^`2eW/000`2iW;/20;RQ`P050;bQ
_P2jY/D0^ZK50;ZVa@2gZ/`00`2lZlT20;N_d@050;bad02d]=P0];CH0;Bdf02i]mL00`2`^=l00`2W
]nD0ZK_V0:VkiP030:2ijP80V;O]00@0VKW^09:gl02B]o00T[O`0`2>]_4208bel@0308belP2;]o<0
RkOc0080S;Sc102?^O<209:klP80Ukcb00@0UKod09[1l`2J`O<0V/7c0P2O`o800`2Na_@0XlOb0:?7
lP020:?7lP030:S9l@2Wc?<0Ylcc0080[<ga00P0Zm3c0;3Al@2`dO40/=7a0;?Ak`2bdo7o00000;;C
l@80]]?_0P2eeO400`2geNl0]]K`0;KFl0020;SFk`80]mK`00<0^MG_0;OFk`2ge^l00P2he>h20;OD
k`;ooooo00?o0000ooooooooool0:?ooool000Wooooo00Co0000oooooooooooooooo0P0I6AT00ol0
0000<c<c03<c<`0>03<c<`03o`00001<C4`0C4a<00l0C4a<3@00000;04a<C0800000200c<c<00`00
003o0000oaTI6@0=oaTI6@h000008olI6AT00ol0000000000000000?03<c<`<000004?lI6AT4oooo
o`03o`000?oooooooooo02Oooooo0_l0000Dooooo`80]IFf0`2eVK/40;VL^`040;RQ`P2lXKh0_:6n
0;bQ_P80^ZK500D0_jO20;b[b@2lZlT0_:_90<6^a`030;bad0060;Bdf02i]mL0^KOG0;Vge`2`^=l0
];cO102Y^nH0102P^NX0XKc/0:6lk02Q_>`209VikP0309:gl02B^O80T[Wb0080S[Sc0`2<]o<308^g
l`80S;Sc0P2?^O<0102>^oD0TKgd096mm02A_O@309Fom00409[1l`2Ia?D0VLCe09W4m@80W/Kd0P2S
ao820:;:m0030:O<l`2Vc_D0Zm3c00<0Zm3c00D0/=7a0:oCl`2_do<0[m?co`0000020;7El`80]MGa
0P2ce_800`2fe_00]MOa0;GGl@020;OFl080]]Ka00<0]mK_0;KEl02feO000P2ge>l20;KCk`;ooooo
00?o0000ooooooooool09oooool000Wooooo00Ko0000oooooooooooooooo01TI6Ol0000B03<c<`03
o`00001<C4`0C4a<02<0C4a<0`00000903<c<`0300000?lI6AWo6ATI00co6ATI4@00000UoaTI6@H0
00001P0c<c<3000001?o6ATI1?ooool00ol0003oooooooooo`0Tooooo`?o00005Oooool40;FE]P80
]IVk00@0^IRf0;VL^`2iW;/0^Ibk102lXKh01@2jY/D0_jO20;nW`P2oYl80_:_900<0`Jk700<0_;7@
0<6fc`2i]mL00P2i]mL0102m_=P0];cO0;Blg`2d_=l20:VkiP80[;kW0P2Q_>`0102R_^d0VK_`09Vk
l02I^o0309:ilP80S[Sc00<0S;Oc08^im02;^O@00`2;^OD308bjm@80S[_e00@0TKgd092omP2@_oH0
T;of0P2D`_H209W4m@0409S6m`2Mb?H0WLSf09g8mP80X/[d0P2QcOH20:K>m@80Zm3c0P2Zd_D20:oC
l`030:gDm?l00000/MGc0080/=Kd0P2ce_820;;Gl`030;GGl@2deo80]=Ob0080]]Ka0P2de_400`2f
eO00]=Ca0;CDl@020;KCk`80]=;`00?oooooo`000?ooool0:?ooool000Wooooo00Go0000oooooooo
ooooooooo`00000D03<c<`03o`00001<C4`0C4a<0200C4a<0P00000:03<c<`8000003_lI6ATC0000
02[o6ATI1P00000FoaTI6@Cooooo00?o0000ooooooooool08_ooool2o`0001Sooooo102eUKH00`2e
VK/0^IRf0;VH]P030;VL^`040;fM^02lXKh0_:6n0;bQ_P@0_jO21031[/L30<6fc`050;Vge`2m_=P0
_KcH0;flf02d_=l00`2g`>400`2/_^L0[L;Y0:g2j@030::nk@0309Vkl02I__40VKka00<0T[_c0P2>
^_@308^im00308^im@2:^oH0Rkcg00<0Rkcg0P2=__L2092omP040932n02Ca?P0TlCh09?4n0<0V<Kg
00<0WLSf09c;m`2LboL00P2QcOH00`2QcoP0YM3f0:G@mP020:G@mP030:[Bm@2YdoH0ZM?f0080[MCd
00?o00000:cFmP2`e_@00P2_eoD20;;Gl`80/MOd00D0]=Ob0;;Gl`2beo<0/]Oc0;CFl@020;?ElP06
0;CDl@2cdo40/m?a0;?Cl@2dd_00/m7`0_ooool00ol0003oooooooooo`0Vooooo`002Oooool01?l0
003ooooooooooooooolF03<c<`03o`00001<C4`0C4a<01`0C4a<0`00000;03<c<`0300000?lI6AWo
6ATI00go6ATI5@000015oaTI6@Cooooo00?o0000ooooooooool07oooool3o`0001Wooooo0P2dTK82
0;FE]P030;RC/@2iV;H0^IRf0080^IRf00D0^Ibk0;fM^02mWKP0_Ifh0;bQ_P020<6S^`80_jO20P34
Zl020<6^a`80a[?70P31]/l20<Jkd0030;flf031`MT0`L7I0080]l3Q00<0^LGS0:g2j@2]`^T00P2]
`^T00`2R_^d0Xl7_0:?1k`0309Vnl@0309:kl`2B_O@0S[ce00<0S[ce0P2;^oH208ZkmP80Rkcg00@0
Rkkh08g0n02=`?P0SL3h0`2@`_P0102Ca?P0TlKi09?6n@2Ca_T209O8n00409c;m`2KcOT0Vlgi09_=
n@80XLoh0P2Ud?H20:CBm`050:WCmP2Xe?L0Z=Cg0:cFm_l000000P2[e_H01@2_eoD0[]Oe0:kGm@2^
eoD0/MOd0080/=Od0P2beo<20;7Fl`030;?ElP2be?80/]Cb0080/m?a00@0/];a0;?Al02cdO00/m7`
0_ooool00ol0003oooooooooo`0Uooooo`002Oooool01?l0003ooooooooooooooolG03<c<`03o`00
001<C4`0C4a<01D0C4a<1@0000000ol00000<c<c03<c<`0:03<c<`0300000?l0003o6ATI00ko6ATI
5P0000000ol0003o6ATIoaTI6@12oaTI6@Cooooo00?o0000ooooooooool07?ooool3o`0001[ooooo
00D0/hf^0;BA/P2dTK80]96b0;FE]P030;RC/@80^IRf00<0_9Rb0;fM^02mWKP00P2mWKP30<6S^`05
0;nW`P34Zl00a:_00<B[`031[/L00`36/lL01031]/l0a[_@0<Jkd03;`M430<71f@040<G7g02iaN<0
^LGS0;W5h`80[L;Y0P2^aN/00`2S`Nl0XlC`0:?4l00309W0l`80T[gd0P2>_?D0102>_OH0Rkgg08^m
m`2;_OL308Zmm`80Rkkh00@0SL3h08g2n@2=`_T0SL;i0P2?a?T209?6n@0409?8nP2Gb_T0Ul[i09O:
n@80Vlgi0P2Kc_X20:3@n@80Y=;g0P2TdoP01@2Xe?L0YmGh0:OEn?l00000ZmKf0080ZmKg0P2^eoD2
0:gGmP030;3Gm02_e_@0[mKd0080/MKc0P2`e?<00`2be?80/M?b0;;Bl@030;;Bl@050;?Al02ad?00
/M3`ooooool000009oooool000Wooooo00Co0000oooooooooooooooo600c<c<00ol00000C4a<04a<
C00@04a<C0@00000400c<c<20000013o6ATI6@000013oaTI6@Cooooo00?o0000ooooooooool06_oo
ool2o`0001cooooo0P2cSJh30;BA/P@0^9>a00@0^IRf0;bH/P2lV;80_9Rb0P2mWKP20<:O]@80`J>k
00D0aZNi0<B[`034Zl00a:_00<^`_`030<Jca`030<bia`36^m00bl7A0080bl7A00D0`L7I0<G7g035
am`0aLOL0;W5h`030;[9iP030:k5j`2^b>d0XlC`00<0XlC`00<0VL3c09W2m02B_oD00`2B_oD208jm
mP0308^mm`2<_oP0S;oh00<0Rkoh0P2;`?T208g2n@0408g4nP2?a_X0SlKj08o6nP<0TlSj00<0Ul[i
09O<nP2Gc?X00P2Kc_X209_?nP80Wm7i0P2TdoP20:?Dn@80YmGh00?o00000:OEn02[e_L00P2Ze_L2
0:gGmP80[=Kf00<0[mKd0:kEm02^eO@00P2`e?<0102_do<0/M?b0;7ClP2ado820;;Bl@80/M3a00D0
/M3`0;3>k`2`c^ooooooo`00000Vooooo`002Oooool01?l0003ooooooooooooooolI03<c<`03o`00
001<C4`0C4a<00D0C4a<2P00000C03<c<`0300000?lI6AWo6ATI00ko6ATI70000012oaTI6@Cooooo
00?o0000ooooooooool05oooool3o`0001gooooo102cSJh20;BA/P040;N@[P2hTk40^9>a0;RC/@@0
_9Rb00D0_Ifh0<:O]@32WkD0`Yne0<6S^`030<JW^@050<B[`03;/;l0bk2o0<^`_`36/lL00P3<^LL0
1@3B`<T0bl7A0<_1d@3;`M40clSC00<0aLOL00<0a/gO0;[9iP2jbNH00P2jcNP20:k8k@80XlC`0P2R
aO8209W2m080T[oe0P2B`?H208jom`<0S;oh00<0Rkoh08_1n@2;`OT00`2<`_T208g4nP0408o6nP2@
aoX0T<Oj0937nP80TlWj00D0Ulcj09O=nP2GcOX0Ulgj09_?nP0209_@nP<0Wm;j0`2Se?T2o`000080
YmGh00<0Z]Kg0:WEm`2YeOL00P2/e_H20:cEm@030:kEm02]do@0[m?c00<0[m?c00<0/M?b0;3Al@2`
dO400P2ad?420;3?l0050;3>k`2_c>l0[lc_ooooool000009Oooool000Wooooo00Co0000oooooooo
oooooooo5P0c<c<5o`00000304a<C0000000000000<000006`0c<c<00`00003o0000oaTI6@0>oaTI
6Al00000@OlI6AT4ooooo`03o`000?oooooooooo01Kooooo0_l0000Nooooo`80/HV/0`2cSJh00`2d
TK80]i2^0;N@[P030;RC/@040;bD[P2lV;80_9Rb0;bH/P@0`Yne1036YkT40<^`_`<0c;W70P3B`<T0
1@3;`M40clSC0<o8d`3?b=<0aLOL0080a/gO00@0am;R0;[=j02jcNP0^/gX102]b^l00`2RaO80XLKc
0:76l`0209W3m080T/3f00@0Tl7f08o0m`2?`?L0Sl3g0`2=`?P00`2;`OT0SL;i08g4nP0308g4nP80
S/Gj0P2@aoX20979n`80U<_k0P2GcOX209S>n`0309_@nP2Ld?X0W=3j0080Wm;j0ol000000`2Se?Wo
00000:OEn0020:KDn0030:WEm`2Ye?H0ZMCf0080[=Ge0P2[doD20:gCm080[m?c0P2^dO800`2`dO40
[loa0:o?l@020;3?l080[lg`00@0[lc_0:k;k_oooooo00009Oooool000Wooooo00Co0000oooooooo
oooooooo400c<c<6o`0000H0C4a<00<0000003<c<`0c<c<06P0c<c<3000000oo6ATI8P000010oaTI
6@Cooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00000Looooo`<0/HV/0`2cSJh40;N@
[P030;RC/@2lU:h0_9B^00<0_9Rb1032WkD40<JW^@030<f/^@3;/;l0bk2o0080dKK000@0c;W70=;0
b@3B`<T0d/390`3?b=<20=;?e`050<K=g`37d^80am;R0<OBhP2jcNP00P2id>/20:g:k`80Zl_a00<0
XLKc0:37m02I`oD00`2I`oD209?1mP0408o0m`2@`OL0T<7g0931m`80S/;h0P2=`_T208g4nP80S/Gj
0P2?aoX20979n`80T/Wk0P2Ec?/209S>n`80VLkj00@0W=3jo`000?l0003o00000P2Pd_T01@2Se?T0
Y=?h0:CCn?l00000Y]Ch0080Ym?g00<0ZMCf0:WCmP2YdoH00P2[doD0102[dO@0[M;c0:gBl`2]d_<2
0:kAlP80[]3b00<0[loa0:k=l02^cO000P2_cO001P2^bnl0[/_^0:k;kP2^bnkoooooo`0002Cooooo
0009ooooo`04o`000?ooooooooooooooo``0<c<c1?l0000<04a<C0030000000c<c<0<c<c01L0<c<c
0`00000AoaTI6B@00000?olI6AT4ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
00006_ooool0102_QZX0/HV/0;69[02aRJ`30;>=[P@0]i2^102lU:h00`2lV;80`I^`0<6K/0020<:O
]@80aj>d0P36YkT20<f/^@040<^`_`3A]/00dKK00=6f`0<0d/390P3Gb</01@3?b=<0d/oG0=;?e`3B
cmL0dmKK0080am;R0P36e^H01@2id>/0]m7^0;OAkP2gdNh0Zl_a0080ZLcb0P2Pao@209W3m@80VLCe
0P2D`_H20931m`0409;2m`2@`oP0T<?h0933n0<0S/?i00<0S/Gj0936nP2@a_X00`2Ab?X00`2BbO/0
U<[j09C:nP0309K<nP?o00000P2Md?X20:3Bn@80XM;i00D0Y=?h0:CBn02Td_So00000:OCm`020:OB
mP030:WCmP2YdOD0ZM7e00<0Zm7d00<0[M;c0:c@l`2/d?<00P2^d?820:g>l@030:k=l02]c?00[Lc`
00<0[/__00@0[/_^0:k9kP2^bNko00009?ooool000Wooooo00Co0000oooooooooooooooo200c<c<4
o`000100C4a<00<0000003<c<`0c<c<05P0c<c<00`00003o6ATIoaTI6@0AoaTI6@03o`0000000000
000002<00000?_lI6AT4ooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00
000Hooooo`80[hJZ102aRJ`00`2cSJh0]Hb[0;F<Z`030;N@[P@0_9B^0`31Vk001@32WkD0aj>d0<NS
]037Xk@0aZNi00<0cJbi00H0dk>i0=6f`03A]/00dKK00=Nn`@3B`<T30=O8b`80fm7?00<0d/oG0=?F
f`3Ce]/00P3Bg=l00`36e^H0`mSY0<?Hj@020;OAkP80/m;`00<0ZLcb0:O;l`2Oa_@00`2Oa_@209W4
m@@0UL?f0P2B`_L00`2@`oP0T/?h09;3n0030974n@030936nP2CaoT0TlOi00<0TlSj00<0U<[j09K;
n_l000000_l00000102HcOX0V/oj09c>n@2Lc_T309k@n@040:7Bn@2RdOP0X]7h0:CBn080YM7g00Ko
00000:OBmP2Wd?H0Ym3f0:WAm@2Yco@40:_@l`030:c@l`2/c_80[<kb0080[Lka0P2/c?000`2]c?00
[L[_0:g9kP020:g9kP80[/W^0P2]and00ol0003oooooooooo`0Qooooo`002Oooool01?l0003ooooo
ooooooooool503<c<`?o0000501<C4`00`000000<c<c03<c<`0D03<c<`0300000?l0003o6ATI01;o
6ATI9`0000000ol0003o6ATIoaTI6@0koaTI6@Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Cooooo102_QZX30;69[0<0]Hb[0P2gT:h20;ZAZ`<0
_9B^0`31Vk040<NS]0040<jY]03=[;T0cJbi0<f/^@80dk>i00<0dKK00=Nn`@3G_/400P3Mb<@01P3G
b</0fm7?0=_Ac`3KdLl0gM[C0=?Ff`80d]cO0P3?gn@01@33f>T0_mW]0;oIk@2ofNd0/m;`0080/=3a
0P2Wbo<209o6m080W/Kd0P2Ia?D209G3mP80U/?f0P2C`oL0102B`oP0U<Cg09C4m`2Da?L209?5n004
09?7n@2EaoP0ULOh09G9n@?o00000P2IboT309[<n@0309c>n@2Mc_P0WLkh00<0Wloh00<0X]7h0:?@
m`2Sd?L00P2UdOL00ol00000YM3f0:O@mP020:S?m080ZLod0P2[d?<20:_>lP030:c>lP2/c?40[<ca
0080[<c`00D0[<[_0:g:k`2]b^l0[L[_0:g9kP040:g7k@030:c6k?oooooo000002;ooooo0009oooo
o`04o`000?ooooooooooooooo`80<c<c0ol0000H04a<C0030000000c<c<0<c<c0180<c<c00<00000
oaTI6OlI6AT04OlI6AT[000003co6ATI1?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool20:b3Z@<0[hJZ0P2aRJ`01@2cRJT0]Hb[0;F<Z`2e
S:/0]i2^00<0^Y6[0P2lU:h20<2G[@80`I^`00@0ain_0<NS]037Xk@0aj>d0P3>ZK@0103=[;T0dk>i
0=>c^@3C/kT30=Nn`@80gLS40`3KdLl20=gJd`030=gQf03Bg=l0cmoT0080cmoT00<0bn7X0;oIk@2o
fNd00P2jf>l00`2`d?40[<kb0:c>lP030:G9l`0309k6m02NaO@0W/Gd00<0V/?e00<0U/?f09S3m@2H
`oD00P2F`oH209C4m`0409K4m`2EaOP0ULGh09G5n0?o000000@0ULWi09S9n02HbOP0VL_i0P2Kb_P3
09c<n00309g>n02OcOL0Wlgg00<0XLkg00<0Xm3g0:C>mP2Tc_H00P2Ud?H01?l00000Y/ke0:S?m02X
cO<30:W=l`80Zlkb0P2[c?400`2/c?40Zl[`0:_:l0030:c:k`040:g:k`2/b>h0[<S^0:g7k@80[<K]
0`2/a^`00ol0003oooooooooo`0Pooooo`002Oooool01_l0003oooooooooooooool0<c<co`0001/0
C4a<00<0000003<c<`0c<c<04@0c<c<00`00003o6ATIoaTI6@0AoaTI6@03o`0000000000000002X0
0000>olI6AT4ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0@ooooo`<0[8>Y0`2_QZX0102aRJ`0/hVY0;>9Z@2cRJT20;F<Z`@0^Y6[00D0_9B^0<2G
[@30Ujd0`9N]0<6K/0030<NO[`040<NS]03>ZK@0cZVd0<jY]0@0dk>i00<0fkfk0=Nn`@3Mb<@00P3M
b<@0103SdlL0fm7?0=gJd`3Mf]<20=gQf080f^ON00<0cmoT0<_Qj03;hNP00P34h>`0102jf>l0]MG`
0;GEl02/c_820:W<lP<0XlSc00<0W/Gd09k4l`2K`o@00`2K`o@00`2H`oD0V/?d09S3mP0309S3mP05
09K4mol0003o0000o`00002Ha_L00`2HaoP00`2HbOP0V/Sg09[8m`0309_:n00409c<n02NboL0W/_g
09o=m`80XLcf0`2RcOH00`2Tc_H0YLge0:G=m@020:K>m@05o`00002Wc?<0Z<gc0:S=l`2YcO<00P2Y
c?820:_<l@<0Zl[`00<0ZlS_0:c8kP2/b>h00`2/b>h30:c6k@D0[<C/00?o0000ooooooooool07ooo
ool000Wooooo00Go0000ooooooooooooooooo`00000M04a<C0030000000c<c<0<c<c00l0<c<c00<0
0000oaTI6OlI6AT04OlI6AT`000003Wo6ATI1?ooool00ol0003oooooooooo`0Eooooo`03o`00000l
KMSooooo00Kooooo00?o0000ooooooooool03_ooool0102YP:P0[8>Y0:b3Z@2/PjT30:n6ZP@0/hVY
0P2eS:/0102hSJT0^Y6[0;ZAZ`2jTJ/40<2G[@@0ain_103>ZK@00`3E/KD0dk>i0=>c^@020=^m^`<0
gLS40P3SdlL20>KMc0040>KWd@3MhMP0f^ON0=[WgP80eNWS00<0bn7X0<CPk034h>`00P2ng>l00`2e
eO00/=7a0;3Al@030:W<lP030:?8l`2Ra_80X/Kb0080W/Cc0P2K`o@209c3l`80V/?d00@0V<?fo`00
0?l0003o00000P2Ia?H0102Ha_L0V/Kf09[6mP2Ja_H209[7m`0309[8m`2Lb?H0W<Sf00<0WL[g00@0
W/_g0:3:mP2Pb_H0XLcf0`2RboD20:?<m@030:G=m@2Vbo<0Y/_c0080Ylcc00Go00000:S;lP2Xbo80
Z<_b0:W<lP030:[9l0030:_:l02[b>l0ZlS_0080ZlS_0P2/b>h20:_6k@030:c6k@2[aN`0[<C/00@0
[<C/0P2[`n/00ol0003oooooooooo`0Nooooo`002Oooool01?l0003ooooooooooooooolO04a<C003
o`00000c<c<0<c<c00h0<c<c00<00000oaTI6OlI6AT04?lI6ATb000003So6ATI1?ooool00ol0003o
ooooooooo`0Eooooo`03o`00000lKMP0=Eo?00Oooooo00?o0000ooooooooool03?ooool20:V0Z0@0
[8>Y0P2_QZX40;>9Z@030;F<Z`2hSJT0^8fY00<0^Y6[1030Ujd40<NO[`030<jV/03>ZK@0cZVd0080
eK6e00H0dk>i0=^m^`3K_K/0fkfk0>;8_P3Mb<@30>?Ca`050>KMc03Vim40i^OA0>?^eP3Jimh00P3E
jN<20<kYj@80anG]00@0_]c_0;SHl02hf?00/=7a0P2]cO430:O9l@030:;6lP2Ra?40X/Ca00<0Wl?b
00<0W<?c09g2lP2M`_800_l0000209[3m080W<?c0P2Ka?@209[6mP80WLGd0P2LaoD00`2Lb?H0W/Oe
09k7m@0309o9m@030:3:mP2RbO@0X/Wd0080X/_e00D0Y<Wc0:G:l`2Ub_<0YL[c0:K;l`020:K9lP04
0:O:l_l00000Yl[b0:S;lP80ZLW`0P2ZbO020:[8k`<0ZlS_0P2[a^h20:_6k@@0ZlG/00<0[<C/0:_3
j`2[`n/00P2[`n/00`2[`^[o0000ooooo`0Oooooo`002Oooool01?l0003ooooooooooooooolP04a<
C0030000000c<c<0<c<c00`0<c<c00<00000oaTI6OlI6AT04?lI6AT00ol0000000000000000a0000
03Oo6ATI1?ooool00ol0003oooooooooo`0Eooooo`03o`00000lKMP0?6gH0080>5S71_ooool00ol0
003oooooooooo`09ooooo`030:AmZ@2YP:P0ZH2X0080ZH2X0`2/PjT00`2_QZX0/HJX0;66Z0030;>9
Z@<0^8fY0P2jTJ/20;nDZP80`9N]0P36W:`20<NO[`80cZJ`00@0cZVd0=Fa]@3E/KD0eK6e0`3K_K/2
0>;8_P80j=C100<0hm?70>KMc03Vim400P3Vim401@3Sk]H0g_;M0=Kbh`3Fl^<0c^WY0080anG]0P2o
gnl00`2hf?00/m;`0;?Bl0030:g=l@040:O9l@2Va_00Y/K`0:;4l@80X/?`0P2P`_43o`0000@0WL;b
00<0W<?c09k3lP2Ma?<00P2Ma?<209g5m00509o5l`2Na_@0W/Kd09k6m02NaoD00P2Qa_<30:78m003
0:;9m02Sb?<0XlSc00<0Y<Wc00@0YL[c0:K8lP2Vb?80Y/Wb0P2Wb?00102Xb?3o00000:S8l02YbO02
0:W7k`80Z/S_00<0Z/K^0:_6kP2[a^h00P2[a^h40:_5k0D0Zl?[1@2[`^X00ol0003oooooooooo`0M
ooooo`002Oooool01?l0003ooooooooooooooolQ04a<C0030000000c<c<0<c<c00/0<c<c00<00000
oaTI6OlI6AT03olI6ATg000003Go6ATI1?ooool00ol0003oooooooooo`0Dooooo`06o`000?oooooo
oooo01AGd@0eGll0>5S70P13El45ooooo`03o`000?oooooooooo00Oooooo0`2TOJT30:V0Z080[8>Y
00@0[X>W0;66Z02aQZP0/HJX0P2cRJT00`2fRZL0^8fY0;R=Z@020;R=Z@040;ZAZ`2oU:X0_iBZ0<2G
[@<0aYb/00@0ain_0<jV/03>Y[00cZJ`103E/KD00`3M_;L0fkfk0>;8_P020>;8_P80j=C100H0k>75
0>g/b@3]k<T0i^OA0>?^eP3Nl]d30=Kbh`040<k_j@37iNd0_mo_0;oOk`80^MS`00<0/m;`0:o=k`2_
cNl00`2[bO00102Va_00YLC_0:G4k`2R`o03o`000080XL;`0P2O`_4209g2lP80Wl;a0P2N`o80102M
a?<0WlCb09o4lP2Oa?8209o5l`0309k6m02QaO80XLGb00<0XLKc00D0XLSd0:?7lP2Sao80XlSc0:C6
l@040:G7lP050:K8lP2Wao00YlO`0:O8l02Xa^l00P2Ya^l00ol00000ZLK_0:W7k`020:[5kP<0Z/K^
00@0ZlK^0:_4k02[a>`0ZlG/1P2[`n/30:_2jPD0Zl7Y00?o0000ooooooooool07?ooool000Wooooo
00Co0000oooooooooooooooo301<C4`5o`000100C4a<00<0000003<c<`0c<c<02`0c<c<00`00003o
6ATIoaTI6@0?oaTI6CP00000=?lI6AT01@00003ooooooooooooooooo000001Kooooo00So0000oooo
oooooooooooo01AGd@08AlH0>5S704=G`@80DeZl1?ooool00ol0003oooooooooo`05ooooo`0409mj
Z@2TOJT0Y7fY0:AmZ@<0ZH2X00<0[8>Y0:j3Y`2^PjL00`2aQZP0102cRJT0]XZW0;J:Y`2fRZL30;R=
Z@<0_iBZ1036W:`40<jV/0030=J_/@3E/KD0eK6e0080gKbg0P3Vb;X00`3Rb;h0j=C10>SD`@020>cQ
a@80kNc900H0jOC>0>?ie03Kn]`0fo[L0=Kbh`3>knT20<KXkP80_mo`00<0^MS`0;CAk`2ddNl00`2_
cNl00`2[bO00ZLK^0:W6kP03o`0000<0Xl;_00<0XL;`0:;1k`2Q`O000`2Q`O000`2O`_40XL;`0:33
l@020:33l@80WlCb0P2Q`o420:74lP030:75lP2Ra?40X/Ca00<0X/Gb00<0XlOb0:C5l@2TaO400P2T
a_420:G7lP80Y/K`00<0YlO`0:S5kP2XaNh00P2Xa^l20:W6k`04o`00002Ya>d0Z/G^0:[3k0@0Z/C/
00<0ZlC/0:_2j`2[`^/0102[`n/30:_2jPH0Zl7Y00<0Zl3Yo`000?ooool07Oooool000Wooooo00Co
0000oooooooooooooooo2@1<C4`3o`0000D0IVIV0ol0000>04a<C0030000000c<c<0<c<c00X0<c<c
00<00000oaTI6OlI6AT03_lI6ATk0000037o6ATI00<00000ooooooooool00_ooool00ol0003ooooo
ooooo`0Dooooo`04o`000?ooooooooooooooo`8003c000@02cno04=G`@13El40DeZl0P1UH;P3oooo
o`03o`000?oooooooooo00;ooooo00<0V7J[09mjZ@2ONZT00`2TOJT30:V0Z0@0[X>W0P2aQZP40;J:
Y`80^8fY00D0_I6X0;nDZP2oU:X0_iBZ0<FIZP030<JL[0030<fS[@3>Y[00cZJ`00<0eZna00<0eK6e
0=fl]`3M_;L00P3Vb;X0103]ekd0j=C10>cQa@3/hLD20>g/b@80jOC>00H0hoWD0=_jg03CmnD0doOU
0<_ak036j>h20;oOl080^MO_00<0]=7_0;7<kP2ac>h00P2]b>h3o`0000050:S3k@2U`^h0YL;^0:G2
kP2S`^l00P2T`Nh20:;1k`80XL7`0P2R`Nl20:72l0030:33l@2R`_00X/;`0080XL?a00H0Xl;_0:?3
l02S`o00Xl?`0:;4l@2T`nl40:C4l0030:C5l@2Va>l0Y/C_0080Y/G_0P2Va_020:O4kP030:S5kP2Y
`n`0ZLC]00<0ZLC]00?o00000:[2j`2Z`^/00P2Z`n`20:[4k080Zl;Z00<0Zl;[0:_1j@2[`NX00P2[
`NX20:_2jP80Zl3Y0`2[`NT20:^oj080Zl3Y00<0ZkoXo`000?ooool07?ooool000Wooooo00Co0000
oooooooooooooooo1P1<C4`3o`0000/0IVIV0_l0000<04a<C0030000000c<c<0<c<c00X0<c<c00<0
0000oaTI6OlI6AT03_lI6ATl000002oo6ATI0P000004ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00_ooool01@00?<0024O600/o_`13El40DeZl0080IF2h0P1fI[@208A//080Sg6]
0`2HMZ/309mjZ@<0Y7fY00<0ZH2X0:V0Y`2^PjL00`2^PjL20;66Z0@0]XZW00D0^8fY0;fAZ02mTJP0
_I6X0;nDZP020<FIZP80aYb/0P3=Xjd20<jV/0<0eZna0P3M_;L30>K8^P050>gG_@3aiKl0lNFo0>cQ
a@3]k<T00P3Ym<h01@3SnM@0fo[L0=?gi@3CmnD0bo7/00<0a>O_00D0_]c_0;WGk`2ecnd0]Lo]0;7<
kP03o`000080ZlG/00<0Z<?]0:S2k02X`^`00`2V`Nd00`2T`Nh0YL3]0:G0k@020:?1kP80X/7_0P2S
`>h20:?1k`040:;2l02S`Nh0Xl7^0:?1kP80Xl;_00<0Xl?`0:C2k`2T`^l00P2T`nl20:C4l080YL?^
00<0Y/C_0:O2k@2W`nd00`2W`nd00`2Wa>h0Z<;/0:W3k0020:W3k080ZLC]0P2Z`N/00ol00000Zl3Y
0:_1jP020:_1jP80Zl;Z00D0ZkoX0:_1j@2[`NT0Zl7Y0:_1jP020:boj080Zl3Y00H0[;kW0:boj02/
_nP0[;oX0:^oj02/_^P30:^oj003ooooool0003ooooo01_ooooo0009ooooo`04o`000?oooooooooo
ooooo`<0C4a<0ol0000@06IVIP;o00002`1<C4`00`000000<c<c03<c<`0903<c<`0300000?lI6AWo
6ATI00go6ATI?P0000000ol000000000oaTI6@0XoaTI6@D000001?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo00H003c000/o_`0J@K/06T6k05=J_01UH;P207IV]080Q6b`
0`2?LJd209QfZ`<0WgZY0P2TOJT00`2TOJP0ZH2W0:V0Y`040:j3Y`030;66Z02cQjL0]XZW00<0]XZW
102mTJP00`2oU:X0aIVZ0<FIZP020<JL[0<0cJ>]00H0cZJ`0=J_/@3F[k40eZna0=nk]03M_;L20>K8
^P80kMNm0P3aiKl01P3alL80joW40>7mb03QoLP0fOoA0=;ng@80cOSX0P37k^h01034inl0_]c_0;WC
k@2idnd3o`0000<0[lO/00<0ZlG/0:_2j`2[`^/00`2X`^`01@2V`Nd0Yl3/0:O0k02U`>d0Y[o/00@0
YL3]00<0Xl3^0:G0k@2T`>d00P2T`>d20:?1kP060:G0k@2T`Nh0Y<7^0:C1kP2T`^l0YL7]102U`^h0
0`2U`nh0Yl7/0:O1k0020:O2k@80Yl?]0P2X`N/20:S2k0030:W3k02Y`>X0ZL3Z0080Z/7[00D0ZkkX
0:_0jOl00000Zl3Y0:_1jP020:bni`<0ZkoX00D0Zl7Y0:bni`2/_^L0[;oX0:bmiP030:bni`80[;oX
0P2/_^L20:bnj0040:^oj02[_^L0ZkkWo`0001cooooo0009ooooo`04o`000?ooooooooooooooo`80
C4a<00?o000006IVIP1VIVH04`1VIVH2o`0000T0C4a<00<0000003<c<`0c<c<02@0c<c<00`00003o
6ATIoaTI6@0=oaTI6D4000009OlI6AT8000000Cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`04ooooo`04000LZ@0;?kl06T6k05=J_080IF2h00<0MVJd08A//024K;000`2?LJd309Qf
Z`80WgZY00<0Y7fY0:AmZ02TOJP00`2YP:L30:j3Y`<0/hNW0`2fRZL40;fAZ0050;nDZP35VJX0aIVZ
0<FIZP36W:`00`3=Xjd30=J_/@80gk^d00@0j<Zg0>K8^P3]ekd0kMNm0P3aiKl20?7a`P80hOg800@0
fOoA0<WmhP39oN80cOSX0P37k^h20<7Rk`?o000000D0]/_Z0;;9j`2bbN/0//W[0:o7k0020:k3jP03
0:_2j`2[`NT0Zl7Y00<0Z<3[00<0Yl3/0:Noj`2V_n`00P2V_n`20:G0k@80Y[o/0P2U`>d00`2T`>d0
YKo/0:Fok0030:G0k@030:C1kP2V`>`0Y/3/0080YL7]0P2U`^h20:O0j`030:O1k02X_^X0Z;oZ0080
Z;oZ0P2X`N/01@2Y_^P0ZKoY0:Voj@2Y_nT0ZL3Z0080ZkgW0`2[_^P01Ol00000[;gV0:bmiP2/_^L0
[KcU00@0[;gV00<0[;kW0:fli@2/_NH00P2/_NH00`2/_^L0[KgV0:fmiP020:bni`080:fmi@2/_NH0
[;gV0:bmiP2[_^L0[;gVooooool0000Kooooo`002Oooool01_l0003oooooooooooooool0C4a<o`00
01P0IVIV00?o000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`0300000?lI6AWo6ATI
00_o6ATI00?o0000000000000000@P00000QoaTI6@T000001?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo00<001bY01Y1^`0cB;X00P1UH;P207IV]080Q6b`0P2?LJd309Qf
Z`80WgZY0`2TOJP30:V0Y`80[X>W00@0/8FW0;>7Y`2cQjL0/hNW0P2fRZL00`2jSZL0_I6X0;fAZ002
0;fAZ0@0aIVZ103=Xjd00`3F[Zl0eZna0=nk]0020=nk]0050>S:]`3`f[X0l=Zj0>gG_@3aiKl00P3a
lL820=Kl]`040<cm_`39oN80bOgR0<Odk@80a>O_0ol000000`2me^d0]/_Z0;K;jP020;K;jP040;;9
j`2aaNT0/LGY0:k3jP80[L7X0`2[`NT00`2X`>/0ZKoZ0:VojP020:Noj`060:Jok02W_n/0Yko[0:No
j`2V_n`0Ykk[0`2V_n/00`2U_n`0Y[k[0:Jnj`030:Joj`030:K0k02W_^X0Yko[0080Yko[0P2W`>/0
1@2X_NT0Z;kZ0:RnjP2X_^X0Z;oZ0080ZKcW0`2Y_^P01@2Y_nT0ZkcV0:^liP2[_NL0[;[S00@0[;_U
00?o00000:fjh`2]_>D00P2]_>D20:bmiP80[K_S0P2]_>D01@2/_NH0[KcT0:fli02]_NH0[[_T00@0
[KgU00<0[;gV0:fmi@2]_ND00P2/_NH00ol0003oooooooooo`0Iooooo`002Oooool01Ol0003ooooo
oooooooooooo000001X0IVIV00?o000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`03
00000?lI6AWo6ATI00_o6ATIB@00000JoaTI6@80000000?o00000000000000001`000004ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool010007j/06T6k04iC^01>DkP207IV
]080Q6b`0`2?LJd209QfZ`0309mjZ@2NNJT0Y7fX00<0Y7fX0P2YP:L00`2^PjL0/8FW0;25Y`030;>7
Y`040;J:Y`2jSZL0^XjW0;Z>Y`<0_I6X1035VJX00`3<XJ`0cJ>]0<fS[@020=J^[`030=J_/@3O^k@0
gk^d0080j<Zg0P3`f[X01`3dj[/0l?Ji0?3f^@3TnkL0e_bg0<cm_`2no]P00P35nN/00`35jnoo0000
o`0000020<3Ik0030;gFk@2icNT0^LgY0080]/_Z0P2da^L0102aaNT0/<;W0;32i`2]`NP20:k0i`<0
ZkoX00<0ZKoZ0:Znj@2X_nX00P2X_nX20:Noj`80Z;kZ0P2W_^/00`2V_n/0YkkZ0:NnjP030:Jnj`03
0:Joj`2W_NT0YkgY0080YkkZ00@0Yko[0:Rlj02X_>P0Z;cX0P2X_NT01@2X_^X0ZK_W0:Vki`2Y_>L0
Z[WT00@0Z[[U00<0ZkcV0:bhhP2/^^<00P2/^^<20:bki@050:fhh@2]^^?o00000:fjh`2]_>D00P2^
^>420:fkh`060:nhh02^^^80[[[R0:jjhP2]_>@0[k[R0`2^^n@20:fmi@80[[_T00<0[KgU0:jli02]
_ND00P2]_ND00ol0003oooooooooo`0Hooooo`002Oooool01?l0003ooooooooooooooolK06IVIP03
o`00001<C4`0C4a<00P0C4a<00?o000003<c<`0c<c<01`0c<c<00`00003o6ATIoaTI6@0;oaTI6D`0
00005?lI6AT?000000Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`04
0000O`007j/0<dRj04iC^080IUjd0P24K;0308ma[@0409QfZ`2EM:/0WWVY09iiZ@@0Y7fX0P2YP:L4
0;25Y`80/hNW102jSZL20;fAZ080`iJY0P35VJX20<bQ[0040<fS[@3F[Zl0eZj_0=J^[`80gk^d0P3X
b[L30?3J^P070?CZ^`3`m[T0i?^g0=Kl]`2blJH0__kH0<Gij`03o`000080`]_/00@0`=W/0;c?j02l
cnP0^LgY0`2ganH01@2da^L0/l;U0;?2i@2``^L0/<3V00@0[/3W00<0ZkoX0:boi`2/_nL00P2Z_^T0
1P2X_nX0ZKkY0:Vnj@2Y_^T0Z;kZ0:Rmj0<0YkgY00<0YkkZ0:Rlj02W_NT0102W_NT00`2X^nL0Z;cX
0:Rlj0030:Rlj0060:Rii@2Y^^H0ZK[V0:VjiP2Y^nL0Z[OS0`2Z^N@20:Zji@050:bfh@2/^>80[;SR
0:bhhP2/^^<00P2]]Ml30:fhh@050:fjhol00000[[KO0:jhh@2_]Md00`2_^>020:jjhP050;2gg`2_
^^80[k[R0:njhP2^^n@00P2_^^420:jki0050:njhP2^_>@0[[cT0:jli02]_ND00P2]_>@00ol0003o
ooooooooo`0Gooooo`002Oooool01?l0003ooooooooooooooolL06IVIP03o`00001<C4`0C4a<00L0
C4a<00<0000003<c<`0c<c<01`0c<c<00`00003o6ATIoaTI6@0;oaTI6Fl000001?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00D0001o000//@1>DkP0CU>h06IN]00207YW
/@<0RFj^0P2EM:/309iiZ@<0Y7fX0P2YP:L40;25Y`80/hNW00D0]h^W0;Z>Y`2jSZL0^XjW0;fAZ003
0<>FZ@040<FIZP3<XJ`0c:6/0<bQ[0@0eZj_00@0h;^c0=nk]03Xb[L0j<Zg0P3`f[X01@3dj[/0l?Ji
0=;fX`2mlIh0/_6V00?o000000@0aNg_0<CLj`34g>/0`]_/0P2ocnH00`2lcnP0^lOT0;_7i0020;O7
iP80]l?S00<0/l;U0;?0i02``>H00P2``>H20:k0i`80[[oV00<0[;oW0:bni`2Z_^P00P2Z_^P20:Vn
j@050:Vmj02X_NP0Z;gX0:Rmj02W_NT0102X_>P20:Nmj@@0Z;_W00<0Z;cX0:Rhi@2X^>D00`2X^ND0
0`2Y^^H0ZKKR0:VfhP020:Zgh`040:Zii02[]=l0ZkCO0:^dg`80[;KQ00D0[;SR0:fcg@2]/md0[KGO
0:j`fP040:jcg003o`00002`/]X0[kGM0080[kGM00<0[kSP0;2dg02`]=`00`2`]ml01@2_^^80/;SN
0;2hgP2_^^40/KSO00@0[k[R00H0[[cT0:nkhP2_^n80[KcT0:nlhol0000Iooooo`002Oooool01?l0
003ooooooooooooooolM06IVIP03o`00001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`00003o6ATIoaTI6@0;oaTI6Fl000001?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Wooooo00<001n[000//@1>DkP00P1VG[@207YW/@80RFj^0P2EM:/309iiZ@<0Y7fX00<0ZH2W
0:^1Y`2`QJL00`2`QJL00`2cQjL0]h^W0;N;Y`030;Z>Y`@0`iJY103<XJ`00`3E[:l0eZj_0=J^[`02
0>2k/`80jlbf00D0j<Zg0?3J^P3dj[/0m>Zk0=;fX`03o`000080aNk_00<0aNg_0<CLj`34g>/00P32
cn@0102ocnH0_/OR0;k7hP2kan@30;[3h@030;O3h`2g`>40/l3T0080/l3T00H0/<3V0;6oi@2a_nD0
/KoU0:joiP2^_^D30:bni`040:Znj02[_NL0ZkgW0:^mi`80ZKgX00D0Z;gX0:Vli`2Y_>L0Z;cX0:Vj
iP040:RjiP030:Rki`2X^>@0Z;ST0080Z;ST00<0Z;SU0:Vdh@2Y]N400`2Y]N400`2Y]^80Z[7M0:^b
gP020:^bgP80ZkCO00H0[:kI0:baf`2//M/0[;7K0:fcg@2^[]L30:j`fP80[[?L00H0/:oG0;2bf_l0
0000/;;J0:neg@2a/MP30;2dg0@0/KCK00<0/;SN0;:ff`2a^=l00P2a^=l20:njhP040;6ih02_^n80
[k_R0;2jh@<0[kcS00?o0000ooooooooool05_ooool000Wooooo00Co0000oooooooooooooooo301V
IVH5o`0000d0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI
6AWo6ATI00[o6ATIK`000004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_oo
ool01000;;409Snf02Ho]P1VG[@207YW/@<0RFj^0P2EM:/209iiZ@80Y7fX00@0YGjY0:^1Y`2[PJL0
Zh6W0`2`QJL30;N;Y`<0^XjW1033UZT30<bQ[080eJb_00@0eZj_0>2k/`3P^k<0h;^c0P3[c;H00`3c
gkT0m?6go`000002o`00000409K^_@2hnnH0aNk_0<G^k`80aM_Y0P34cN401032cn@0`<KN0<36gP2n
an830;g2gP030;[3h@2j`=l0]l3Q0080]l3Q00<0/l3T0;Boh`2d_n<00P2a_nD20;6ni080[[kU00<0
[;kW0:fmiP2]_NH00P2[_NL01@2[_>H0Z[cW0:Zli`2Z_>L0ZKcW00@0ZK[V0P2X^^H50:Rhi0040:Rd
h@2Y]>40ZKCQ0:Vdh@80ZKGQ00H0ZK3L0:Zag@2Z/Md0Z[7M0:^bgP2[[=P40:b^f@030:baf`2]ZmD0
[ZkG0080[ZkG00<0[[3J0:n[d`2`[mL00`2`[mL00`2`/][o00000;6af0020;6af0030;2dg02b/ML0
/[7G0080/KCK00D0/k;G0;:ff`2b]]/0/[KK0;6hg`020;>gg0030;6ih02c^Mh0/;[Q00<0/;[Q00@0
[kcS0;2lhP2`_>;o00005oooool000Wooooo00Co0000oooooooooooooooo2@1VIVH3o`0000D0Ogmo
0_l0000<06IVIP03o`00001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c<c<00`00003o6ATI
oaTI6@0:oaTI6Fl000001?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo
00@0002C000//@0V?kH0C5:g0P1jIk4308U^[P80UGB[0P2NNJT00`2TOJP0YGjY0:EnZ@030:^1Y`80
/8FW00<0/hRX0;N;Y`2gRjL00P2gRjL00`2jSZL0`9BY0<2DZ@020<>FZ@80bYn/00D0c:6/0=F/[`3E
[:l0eJb_0>2l/`020>2k/`80jlbf0ol000000`3dlKL0d_JS0;7ji`020<C]l080a]SW00@0aM_Y0<C=
h@34cN40`/CK0`30a]h30;g2gP050;g0g02j`=l0^/3O0;[0g`2g`>400P2g_n001P2d_n<0];oR0;Bo
hP2d_n80/KkT0;6nh`<0[kkU00<0[KgV0:fmi@2]_ND00`2[_>H00`2Z_>L0Z[_U0:Zki@030:VjiP80
ZKST102X^>@40:Rdh@030:Vdh@2Y[m`0ZJoL00<0ZK3L00<0Z[7M0:Z[e`2[[=P00P2[[=P20:b^f@06
0:bXd`2]ZmD0[J_E0:f[e@2^[]L0[jSA0`2_Zm<20;2_e`050;6Yd@2a[M@0/JgDo`00002a/MP00P2c
[M<00`2b/ML0]:kB0;>be`030;>be`050;:ff`2d]=P0];CH0;>gg02e]]T00`2c^Mh20;2jh@80/[[O
00<0/;cR0;6lhOl000005oooool000Wooooo00Co0000oooooooooooooooo201VIVH00ol00000Ogmo
07moO`0807moO`03o`00001VIVH0IVIV00T0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c
03<c<`0703<c<`0300000?lI6AWo6ATI00[o6ATIKP000004ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03?ooool0100009<09Snf04aB]`1<D[L207YW/@80RFj^0P2EM:/00`2NNJT0
WGV[0:EnZ@020:EnZ@<0Zh6W00<0/8FW0;>8Z02cR:P0102gRjL0102jSZL0`9BY0<2DZ@33UZT30<ZO
[0040<bQ[03E[:l0eJb_0=F/[`80h;bc0ol00000103cgkT0m?6g0?Ca]`3YnJl20<?Yl080a]CU00@0
a]SW0<G:gP35b]h0a<gQ0`32a=/01030a]h0`<7K0<31f`2m`]h30;g0g0040;[0g`2j_md0^[oM0;No
h080^;oP0P2d_n801@2e_n80/KkS0;6nh`2a_^<0[kkU0080[kgT00<0[KgU0:fli02]_>@00`2[^nD0
0`2Z^nD0Z[WT0:Vhi0030:Vhi0P0Z;CQ00<0Z:oL0:V_g02Y[m`00P2Y[m`00`2Y/=`0ZJWG0:Z[e`02
0:Z[e`030:^/f02[Y]40[:SC00<0[:SC00<0[J_E0:jUcP2_Z=400P2_Z=400`2_Zm<0/JK=0;6Yd@03
0;6Yd@030;6]e?l00000/jgC0080/jgC0`2d[]820;>be`80][3C00<0];CH0;Nbe02e]]T00P2e]]T0
0`2c^Mh0]KSL0;Fhg0020;:jg`050;BjgP2a_>40/KcQ0;6lhOl000005_ooool000Wooooo00Co0000
oooooooooooooooo1`1VIVH00ol00000Ogmo07moO`0:07moO`;o00002P1VIVH00ol00000C4a<04a<
C00604a<C0030000000c<c<0<c<c00H0<c<c00<00000oaTI6OlI6AT02_lI6AU^000000Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`809Snf00<0C5:g06]Q]@1[HKD00P22
K;42095d[P80WGV[102UOZT20:^1Y`@0/hRX0`2gRjL30<2DZ@@0bYn/0`3E[:l3o`0000080>c@^03[
c;H0lmni0??O^@3dlKL0e?BM00000033jO030<KDi@030<G6fP35b]h0a<7H0080a<7H00@0`/CK0<:o
e`32_mL0`<7K0`30_mP0102m`=`0_[oJ0;jofP2j_md20;^og@030;Roh02h_ml0^;oO00<0]KoR00<0
/KkS0;:nh`2b_^<00P2__N@40:fli0030:^ki@2[^N@0Z[WT0080Z[WT00<0ZKST0:VehP2X]>40102X
]>440:R_g@80Z:oL0P2Y[m`01P2XZML0ZJWG0:VYe`2YZML0ZZ_G0:ZTd@<0ZjKA0P2/Z=<01P2]X/`0
[ZG>0:jUcP2^YLh0[jSA0;2RbP<0/JK=0P2aZM401@2cYLX0/jW?0;>Ycol00000/jgC0080]J[>00<0
]:kB0;N/cP2f/=<00P2f/=<01@2i[/l0]k;D0;Nbe02g/]@0]KKI0080^;KG00<0]KSL0;NifP2d^]h0
0P2d^]h20;6lh@80/kcQ00?o0000ooooooooool04oooool000Wooooo00Co0000oooooooooooooooo
1`1VIVH00ol00000Ogmo07moO`0<07moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0603<c<`0300000?lI6AWo6ATI00[o6ATIKP000004ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00`007:T09Snf04aB]`0206]Q]@80PVba
0P2AM:h209eiZ`@0YGjY0P2[PJL40;>8Z080]h^W00D0_96Z0<2DZ@30U:T0`9BY0<NM[@030<ZO[003
0=B//?l0003o000000<0h;bc00@0k=2h0?GW^@3eikT0lmni0P3Dm9d30<G=h@040<KDi@35a]X0aLKJ
0<Bne0<0a<7H0`32_mL30<2of0040<6ne`2n_mX0_[oJ0;jofP<0^koM00@0_<3M0;Rog`2h_ml0^;oO
0`2e_n820;:nh`<0[kgT0P2]_>@20:fjh`80ZkWT00<0Z[WT0:VfhP2Y]^800P2Y]N820:Rdh@030:R`
gP2X[md0Z:oM0080Z:oM00@0YjWH0:RXe`2XZ=L0Z:SG0`2XZML00`2YZML0ZJ?@0:ZTd@020:ZTd@03
0:^Vd@2[Wl/0[J;<00<0[J;<00<0[ZG>0:jNa`2`X/X00P2`X/X00`2aY/d0/Z770;:Qa`030;>UbP03
0;>Yc`2eYLWo00000080]J[>0`2g[<h01P2f/=<0^Jk?0;V^c`2i[/l0]k;D0;Zbd@<0^;KG0`2g^MX0
0`2d^]h0][_M0;Jkg@020;>lh@030;Bmh?l0003ooooo01Cooooo0009ooooo`04o`000?oooooooooo
ooooo`H0IVIV00?o000007moO`1oOgl03P1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0
C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`00003o6ATIoaTI6@0:oaTI6Fh000001?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00<001bY04aB]`1<D[L00P1[HKD0
0`22K;40TGB^095d[P0309eiZ`<0YGjY00<0Zh6W0:j5ZP2cR:P00`2cR:P01@2gRjL0_96Z0;bAZP2l
TJX0`9BY0080aif]00H0bYn/o`000?l0003o00000=B//03E[:l20>2l/`80k=2h0P3eikT01@3_mk80
e?BM0<?6g@33a]d0aLgQ0080a<7G00D0aLKJ0<Bne034_]@0a;kD0<C1f0020<Bmd`040<:oe`33_M@0
`kgD0<2of0<0`KkG00@0_[oJ0;nofP2o_mX0^koM0`2l`=d0102h_ml0^L3O0;W0g`2e_n820;Foh@80
/[kS00H0[kgT0:nlh`2__><0[kcS0:fjh`2/^>830:^ghP030:VfhP2X/]l0Z;7N00<0Z;7N0P2X/=h0
0`2X[md0YZWI0:NYf0020:NYf0030:RXe`2VX]40Yj;@0080Yj;@0`2YXm000`2ZY=40ZIg:0:^Ob`02
0:^Ob`80[J;<00@0[I_50:jNa`2^W/L0[Yk70P2`X/X40;:Qa`030;>UbP2dXLD0]JG90080]JG900Go
00000;RWb02hYlP0]jc>0;ZZb@030;V^c`050;b^c02j/]40^[;A0;Zbd@2h]]L00P2k]]D0102g^MX0
^[WI0;Zif@2f^md20;Vlg080];gP00<0][kPo`000?ooool04oooool000Wooooo00Co0000oooooooo
oooooooo1@1VIVH00ol00000Ogmo07moO`0@07moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<
C01<C4`01@1<C4`00ol00000<c<c03<c<`0503<c<`0300000?lI6AWo6ATI00[o6ATIKP000004oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00`007:T06cfh01/m^00206]Q
]@80PVba0P2AM:h209eiZ`80YGjY00@0YX6/0:j5ZP2^QJX0[XFZ0`2cR:P40;bAZP050<2DZOl0003o
0000o`00003:Wj`00`3D[;020>2l/`80k=2h0`3eikT0103Dm9d0`lKM0<?6g@33^m830<C1e`<0a;kD
0P35^]001034_M<0aK_A0<Fkd@33_M@30<Bmd`040<6ne`33_mL0`koG0;nofP80`<7J0P2l`=d20;c1
g@050;W0g`2i`N00^L7P0;Foh@2d_n800`2a_N820:nlh`060:jjhP2/^>80[;SR0:bhhP2[]n80ZKCP
0`2X/]l20:RagP040:J/f`2VZmX0YZ_J0:J[fP80YZWI00<0YjWH0:FRdP2VX]400P2VX]430:NRd003
0:VSd02XVlT0ZIg:0080ZIg:00<0Zio;0:^Ia02]VlD00`2]VlD20:jNa`030;2RbP2aWL<0/Ig30080
/Z7700L0/ig10;BQa@2dXLD0]:750;FUb@2gXlCo00000080^:O80`2jZ/T01@2i[/l0_:k<0;b^c02l
[/`0^[;A0080_K;?00D0^kKE0;jgd`2n]m<0^[WI0;fkf0030;Vlg0<0][kP00?o0000ooooooooool0
4_ooool000Wooooo00Co0000oooooooooooooooo1@1VIVH00ol00000Ogmo07moO`0@07moO`03o`00
001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`030000
0?lI6AWo6ATI00[o6ATIKP000004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3oooool010007:T06cfh04mH_01?F;`2089//@80TGB^0P2MNJ/00`2UOZT0YX6/0:J1[0030:j5ZP80
/hRX00<0^8n/0;bAZP2lTJX00ol000030<NM[@060<ZO[03D[;00e:b`0=B//03P_[H0h;bc0P3/d;P2
0?GW^@030>og/P30_]P0`lKM00<0`k_B00@0a<7G0<Bjd034^]00a;kD0`35^]030<Fkd@040<Nld034
_M<0a;gC0<Bmd`<0`koG00<0a<7G0<31fP31`]/00P31`]/01@2l`Md0_L;N0;g2gP2i`N00^<7P00<0
];oR00@0/KgR0;6lhP2a_>80/KcR0P2^^^800`2/^>80ZkKQ0:^fh@020:Vdh0030:Rbg`2W[]`0YZcK
00<0YZcK00@0YZ_J0:BTe@2UXm<0YJ?C0`2UX]830:JRd@030:NRd02VVlX0Z9_90080Z9_900<0ZIg:
0:VF``2[VL@00P2[VL@30:fKa@030:jNa`2_VL40/Ig30080/Ig300@0/Z770;>M`@2cWL40/ig10P2d
XLD30;NSa005o`00002jYL@0^ZG40;ZZb@2mZLH00`2l[/`0102o[/T0_K;?0;fbc`2m//l30;jgd`<0
_K_H00@0^KcL0;^ng02k_]`0][kP0P2h`>000ol0003oooooooooo`0Aooooo`002Oooool01?l0003o
ooooooooooooool506IVIP03o`00001oOgl0Ogmo0100Ogmo00?o000006IVIP1VIVH01`1VIVH00ol0
0000C4a<04a<C00504a<C0030000000c<c<0<c<c00D0<c<c00<00000oaTI6OlI6AT02_lI6AU^0000
00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`0301/m^01?F;`0CeRl
0080M6Vi0P2AM:h00`2MNJ/0Vgb`0:J1[0030:J1[080[XFZ00<0/hRX0;R?[?l000000_l000020;bA
ZP@0aif]0`3D[;020>2n]P80k]Nk00<0k=2h0?GW^@3Mn:H00P30_]P01P31]/l0`k_B0<>kdP33^m80
a;K<0<Bjd0<0a[O<00@0aK[@0<Jic@36^Ld0aK_A0`37_=001034_M<0a[kC0<Jnd`33_mL20<C1e`<0
`L;K00@0`LCL0;g2gP2m`]h0_L;N0`2h`N001P2d_n80];kQ0;Bnh@2d_^40/KcR0:njh@<0[KSQ00<0
ZkKQ0:Vbg`2X/=d00P2X/=d20:N^g080YZcK00@0Y:KG0:BTe@2TY=D0Y:CE0P2UXm<00`2UX]80Xi[<
0:FJb`020:FJb`<0YY_:00<0Z9_90:NE``2YU/<00P2YU/<30:^Ia0030:fKa@2]U[l0[iW10080[iW1
00<0/Ig30;:I_@2cWL400`2cWL400`2dXLD0]Yjo0;JN_`020;NSa0030;ZUa?l00000^ZG400<0_JW6
00D0_:k<0;n^b@2o[/T0_jk90;fbc`020<6cc@040;jgd`31^M80`KWB0;fkf080`;gG00@0^kkL0;g0
g02m`=`0^<3P0P2i`^400ol0003oooooooooo`0@ooooo`002Oooool01?l0003oooooooooooooool5
06IVIP03o`00001oOgl0Ogmo0140Ogmo00?o000006IVIP1VIVH01P1VIVH00ol00000C4a<04a<C005
04a<C0030000000c<c<0<c<c00H0<c<c00<00000oaTI6OlI6AT02_lI6AU]000000Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03000?W`0K?KP0CeRl0080M6Vi0P2<MK@3
09]l/0<0YX6/00@0[XFZo`000?l0003o00000P2hSj`20;bAZP030<BL[`37WJd0aif]0080aif]00<0
dZbb0=B//03P_[H00P3P_[H20>kG^`040??a^`3Mn:H0gORV0<2nf0<0`KK?00@0`k_B0<Bfc034]/`0
aKC90`36]l`30<Jic@<0akc@0P38_]001036_]<0al7D0<O1e034`ML20<G3f0050<72f`31a=`0`LCL
0<74g02m`]h00P2l`ml00`2h`N00^<3Q0;S0h@020;Bnh@060;:mh@2_^^40[k[Q0:njh@2]^>40ZkGO
0`2Y/]l00`2X/=d0YJ_K0:FXf@020:FXf@<0Y:KG0P2TY=D00`2UXm<0XY_>0:>Jc0020:>Jc0<0YI[;
00<0YY_:0:BCa02WUL<00P2WUL<20:VF``80ZiW400@0Zi>n0:fF_`2]U[l0[IJo0P2_VL430;:I_@80
/ig100D0]IZl0;JN_`2fW[l0]Yjo0;NSa0020;ZQ_`030;ZUa?l00000_JG00080_JW60`2o[/T01033
/<L0`K?=0<6cc@31/ld30<6idP<0`;gG00<0`l3H0;g0g02n`md00`2i`^400ol0003oooooooooo`0@
ooooo`002Oooool01?l0003oooooooooooooool506IVIP03o`00001oOgl0Ogmo0140Ogmo00?o0000
06IVIP1VIVH01P1VIVH00ol00000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<00000
oaTI6OlI6AT02_lI6AU]000000Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`04000?W`1?F;`0CeRl07AY^@80S7Fd0`2KO;00102VPJco0000o`000?l000020;6<[`<0^8n/
00@0_96Z0<BL[`34W:l0a9b_0P37WJd20=://P030=B//03P_[H0h;jf00<0k]Nk00<0lo6k0=ghYP2o
/</00P2o/</01031]/l0`k790<>ab@34]/`30<Fdb@040<Jgc037]lX0akO:0<Jic@80b;[=00@0akc@
0<Rnd038_]00b;k@0`37`M@00`39a=D0aL?H0<G5fP020<G5fP040<74g031aMd0`LGM0;c3g`80_<?P
00@0^<3Q0;Joh@2f_n40][oQ0P2b_N400`2_^^40[[OP0:jgh0020:^eg`030:Vbg`2W[]`0YJ_K0080
YJ_K0`2UZ=T0102TY]L0XIoC0:6Md02QWM030::KcP80Xi[<0P2UV//0102RTlD0Y9?40:BCa02TTl@2
0:NE``030:VF``2XTKd0Zi>n00<0Zi>n0P2]U[l00`2_VL40/9Fk0;2E^`020;:I_@040;>M`@2eV[`0
]IZl0;FJ_080]Yjo0`2jXKl0102mYL3o00000;fU`02mZLH20<6Z``050;n^b@33/<L0`k370<>`a`31
/ld00P35]/`01031^M80aKcB0<FldP30_ML20<?0f0<0_/?M00@0^L;Q0;[4hP2ja>;o00004Oooool0
00Wooooo00Co0000oooooooooooooooo1@1VIVH00ol00000Ogmo07moO`0A07moO`03o`00001VIVH0
IVIV00H0IVIV00?o000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`0300000?lI6AWo
6ATI00[o6ATIK@000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool0
100@@Kl0CeRl07AY^@1dJKT208ae]0?o00000P2VPJ`30;6<[`<0^8n/1034W:l01037WJd0dZbb0=:/
/P3B[;820>32^`050>2n]P3^ek/0k]Nk0??a^`2]iH/00`2o/</01031[/L0`k790<>ab@33/LT30<Fd
b@040<Neb037]lX0akO:0<NgbP<0b;[=0P3;_Ld01038_]00bl7A0<_1d@37`M@20<W4e@060<[7e`35
aMX0aLGJ0<G5fP36am/0`LGM0P30a]h00`2l`n00^/?Q0;[3h@020;Joh@060;Bnh@2a^n40/K_Q0;6k
h@2^]n00ZkCO0`2Y/Mh20:N^g0030:F[f`2RYMP0XZGH0080XZ;E0`2QWm<20:6Md0040::KcP2OU<T0
XI?60:6CaP@0XY?50P2TTl@00`2WUL<0YHnm0:RA_@020:RA_@<0Zi>n00<0[IJo0:fA^@2`UK/00P2`
UK/00`2bVKd0/iJi0;FJ_0030;FJ_0040;JN_`2iW;/0^Ibk0;ZQ_`80_J2k00<0_JG0o`000031Z/<0
0P31Z/<30<>`a`060<Rca@35]/`0aKK<0<Ffc039^//0aKcB0P38`=801033`=P0aLCI0<G4f@2n`md2
0<36gP040;[4hP2jaN<0^/GSo`00013ooooo0009ooooo`04o`000?ooooooooooooooo`H0IVIV00?o
000007moO`1oOgl0401oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00D0C4a<00<0
000003<c<`0c<c<01@0c<c<00`00003o6ATIoaTI6@0:oaTI6Fd000001?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Cooooo00<0446o07AY^Ol000000_l0000309]l/0030:J1[02X
R;<0/Hb_0080/Hb_0`2hSj`0102oVk<0a9b_0<BL[`34W:l40=://P80h<:k00@0k^730>kG^`3Xnk/0
[NF;0P2lZlT01@2o/</0`Jk70<6^a`31[/L0`k790080aK7700D0aKC90<Neb037]LP0akG80<NgbP02
0<ZibP040<Rjc@3;_Ld0bkg=0<g1c`<0bl7A00<0c<GC0<W4e@3:amL00P3:amL01@35aMX0a/OK0<K7
f`35bMd0`<KN0080_lKP00<0^/?Q0;S2h@2h`^400`2d_^400`2a^n40[[SP0:^dg`020:^dg`040:Va
gP2V[=`0Y:WJ0:BYfP@0XZGH0P2RX]D0102QWm<0WIS>09jFb`2NU//309nDb@80XI?60`2RTlD00`2T
Tl@0Xhfn0:F?_@020:F?_@<0Z96m00<0Zi>n0:^?^02]TKT00P2]TKT20;2E^`<0/iJi0`2eV[`30;VL
^`<0_J2k00@0_JG00<6U_Ol00000`J[30P35[<401`33/<L0b;?50<Rca@38/lD0aKK<0<Vjb`3=_/`0
0`38`=801@3<a=<0aLCI0<O8fP37b=X0`<KN0080`LSP00<0^/GS0;[7i?l000004?ooool000Wooooo
00Co0000oooooooooooooooo1P1VIVH00ol00000Ogmo07moO`0@07moO`03o`00001VIVH0IVIV00L0
IVIV00?o000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`0300000?lI6AWo6ATI00[o
6ATIK@000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool2o`000003
05IUaP2<MK@0S7Fd0080Vgb`00@0VH>j0:R8/`2XR;<0Z8Rc0`2aS:l00`2hSj`0_i^c0;nK/`030<BL
[`030<n]]`3B[;80dZbb00<0h<:k00<0k^730>Sk^`3Xnk/00`2lZlT0102nZ/D0`Jk70<6^a`31[/L3
0<Faa`040<NbaP37]LP0akG80<Neb0<0b[W:00<0c;c;0<^mc@3=`Ll00P3=`Ll0103;`M40c<GC0<c5
d`3>b=D20<[7e`80b/[I00<0a/OK0<G9g@35bMd00`2oa^040;S2h@030;Bnh@2b_>40/[cQ0080[[SP
00<0ZkCO0:R`gP2V[=`00P2V[=`20:BYfP80XZGH00<0WYoD09fKd@2MVm400`2MV<h209jFb`80WiC9
0`2QTlH00`2RTlD0X8fo0:>=_P020:>=_P80YHnm0P2XTKd0102WS;P0Zhnh0:^?^02[SkP20:fA^@03
0;2E^`2aT[L0/iJi00<0/iJi00<0]IZl0;NH^02gV;P00P2iW;/00`2lW;P0_J2k0;fP^`030<6U_@03
o`000035[<40aJc100<0b;?500<0cKO50<Vjb`3=_/`00P3=_/`00`38`=80c<CC0<k:e@020<O8fP04
0<S<g@31b>00`LSP0<7;hP80^/OT00?o0000ooooooooool03_ooool000Wooooo00Co0000oooooooo
oooooooo1P1VIVH00ol00000Ogmo07moO`0@07moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<
C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`0300000?lI6AWo6ATI00[o6ATIK@000004oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool3o`000003ooooo`0@@Kl0EVG6
0080PGW10`2IPkX30:R8/`80/Hb_00<0]iVi0;nK/`2oVk<00P2oVk<01@34W:l0cjfg0<n]]`3?[KL0
dZbb0080h<:k0P3^hL<0103Xnk/0^JK70;VVa`2lZlT30;jZa@040<6^a`33[/D0`jk50<Faa`<0ak;6
00@0akG80<Zgb03:]lP0b[W:0P3<_</01P3?`Ld0cL7?0<g1c`3=`Ll0clGA0<c5d`80c/SE0P3>c=P0
103:b]T0bLcL0<W<g035bMd20<C:g`030;o6h02ma^40_LKQ0080^<;Q0P2f`>800`2b_>40[kWQ0:^d
g`020:^dg`80Z;3N00<0YZcL0::WfP2PXmL00P2PXmL309jOe080WI_A0P2MV<h0102NU//0VXo709^=
a02KSL@309f=`@<0X8fo0P2SSKh00`2USkd0Y8Zh0:N<^0020:N<^0<0Zhnh00<0[I6i0:j>]@2aT[L0
0P2aT[L20;>F^@050;FD]@2gV;P0]iRh0;NH^02iW;/00P2lW;P00`2mX;/0`:6i0<2Q^@020<6U_@05
o`000035[<40bJno0<V__`38/lD00P3=]lD30<fnc0050=;4c@3<a=<0c/[E0<k:e@37b=X00P38c=d0
0`38cml0`L_Rooooo`02ooooo`03o`000?oooooooooo00kooooo0009ooooo`04o`000?oooooooooo
ooooo`L0IVIV00?o000007moO`1oOgl03P1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0
C4a<00H0C4a<00<0000003<c<`0c<c<01@0c<c<00`00003o6ATIoaTI6@0:oaTI6Fd000001?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo0ol00005ooooo`0405IUaP21NL40
PGW1085i`@<0VH>j0P2XR;<00`2aS:l0]iVi0;NI^@040;nK/`@0cjfg00H0g/W40>32^`3^hL<0k^73
0>Sk^`2eX/H20;VVa`040;^Va02nZ/D0_Z[50;jZa@<0`jk50`37//H01P3:]/H0b[O80<Zgb03:]lP0
cK_90<blb`<0cl7=00D0cL7?0<o5d@3?aM40dL[C0<k8e@030<k<f0050<k@f`39c=`0b<kN0<S>gP34
b]l00P31b^401P2ma^40^/CR0;[4hP2ja>80]/3R0;:mhP<0[kWQ00<0ZkCO0:N`gP2T[=`00P2T[=`2
0::WfP<0X:?G00@0WYoD09ZHd@2IU<h0VIC>0P2ITLX309Z?a`80Vhg40`2MSL420:2=_`040:>=_P2Q
R;T0Y8Zh0:B:^0@0Yhbh0P2[SkP20:j>]@<0/I:g00@0/iJi0;FD]@2eU;D0]IBe0P2gV;P30;bL^0<0
`:6i00@0`JFm0<FW^`35Yk_o00000P39[kl30<fga@060=:maP3=_/`0d/C=0=;4c@3Fbm00c/[E0P3@
cmP00`38c=d0b<oO0<S?g`05ooooo`03o`000?oooooooooo00gooooo0009ooooo`04o`000?oooooo
ooooooooo`L0IVIV00?o000007moO`1oOgl03P1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<
C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`00003o6ATIoaTI6@0:oaTI6Fd000001?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol00009ooooo`0305IUaP21
NL40PGW100<0VH>j0P2XR;<40;NI^@80_i^c0P3:[kl20<n]]`80g/W40P3Zl<h0103^hL<0]J;60;FR
aP2iY/L30;^Va0030;jZa@31Zl@0`J_40080`jk500<0a[350<NbaP3:]/H00P3:]/H0103:]lP0cK_9
0<fkb@3@`L/30<o1c@040=;6c`3?aM40dL[C0=7:d`80d/oF00D0c/cH0<k@f`3>d=/0cM?N0<S>gP02
0<K?h@050<7:h@2nbN<0_/WS0;k9h`2ja>800P2g`^<20;:mhP030:nih@2[]N00ZkGP0080Yk3N00@0
Y:cL0:2Wf`2MX]P0WJ;H0`2KWMD309ZHd@80VIC>0P2ITLX209Z?a`<0Vhg40P2MSL40102PSKl0WHNk
0:68^@2QR;T30:B:^0<0Yhbh00<0Zhnh0:^;]02^S[D00P2^S[D20;6B]`@0]IBe00<0]iRh0;ZH]02j
V;@00P2lW;P00`2oWKD0`:6i0<2Q^@030<FW^`050<Z[^_l00000bJno0<nd_`3=]lD00P3B_LH0103G
a<L0d/C=0=K;d03Fbm030=3?f0030=7Df`38cmoooooo00Gooooo00?o0000ooooooooool03Oooool0
00Wooooo00Co0000oooooooooooooooo201VIVH00ol00000Ogmo07moO`0<07moO`;o00002@1VIVH0
0ol00000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<00000oaTI6OlI6AT02_lI6AU]
000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00003Oooool3
085i`@80VH>j00<0Z8Rc0:^G`P2[Ul800`2gVKT01@2oVk<0bZno0<Z__`3:[kl0cjfg00<0g/W400D0
j_3>0<3g[@2aW/D0]J;60;RSa0030;^Va0050;jX``31Zl@0`J_40<6[a033[/D00P36/<D01P39]<H0
b[K60<ZfaP3:]/H0c[_80<fkb@<0d<7;00D0cl7=0=;6c`3Ba/l0e<cB0=7:d`020=;?eP80d]?J00D0
c]3K0<gCgP3=dmh0bmCQ0<K?h@020<??h`80_/WS0P2kb>@00`2g`^<0/[oT0:njhP020:njhP040:^e
h02W/Ml0XjcM0:>/g@<0X:OK0P2MX]P309^Me@80VYSA0P2IU<h0102ITLX0U8_709F8``2ER<<309R7
`080VXJm0P2MQk/30:68^@80Y8Zh0P2WS;P0102WR;@0Zh^d0:^;]02[Rk@20:j>]@030;6B]`2bT;<0
/Y2c00<0]IBe0`2jV;@0102lW;P0_ife0;nM]@30XKT20<FS]`040<FW^`3:ZkX0bZ^jo`000080ckBo
0`3B_LH01P3Ga<L0e/_@0=K;d03Fbm00fM?C0=3?f080dMCK1oooool00ol0003oooooooooo`0=oooo
o`002Oooool01?l0003oooooooooooooool906IVIP03o`00001oOgl0Ogmo00X0Ogmo00?o000006IV
IP1VIVH02@1VIVH00ol00000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<00000oaTI
6OlI6AT02_lI6AU]000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06oooo
o`?o00004Oooool2065nf@80TY3>0`2[Ul830;NI^@@0bZno00D0fM?C0=k9a03NbL@0j_3>00000002
0;6Na@<0^:?400@0^jK40;jX``2nZ<<0_ZS30P31Zl@30<J`a@80bKC600<0b[K60<jkb03>^lP00`3@
`L/20=?7cP050=;6c`3Dc=80e<cB0=GBeP3BcmH00`3BdmX01P3Aemd0cM?N0<_Dh@3;e>40amGT0<??
h`<0_lkU00<0^lST0;O5i@2gaND00P2b_n@00`2_^^80Z[KR0:ZfhP020:Nag`80XjcM00<0X:OK09^R
f@2HW=H00P2HW=H209JGdP80U9;?0P2CS//309B;a`0309F8``2HQl00V8O00080V8O00P2JQ[d209f7
^`80XHRi00<0Y8Zh0:>6]@2WR;@00P2WR;@30:^;]0030:j>]@2_SK80/Y2c00<0/Y2c00<0]IBe0;NC
/P2gTk800P2jV;@30;nM]@<0aJ>g0`3:ZkX01@3?];oo00000<nd_`3E^l00d[g60080elC700H0g<g9
0=K;d03Idm<0fM?C0=[JeP3Ae=/8ooooo`03o`000?oooooooooo00gooooo0009ooooo`04o`000?oo
ooooooooooooo`X0IVIV0ol0000807moO`03o`00001VIVH0IVIV00T0IVIV00?o000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0603<c<`0300000?lI6AWo6ATI00[o6ATIK@000004ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00oooool3o`0001Gooooo0P1QO]T209:@cP<0ZiO2
00<0]iVi0<6bc031//`00`3:[kl20=WCd`040=k9a0000000[9_60;6Na@80/j340P2hXl@01@2jY/@0
_ZS30;jX``2nZ<<0`J_40080a:k400@0a[350<VdaP39]<H0bKC60`3>^lP00`3A`L/0d<7;0=?7cP02
0=?7cP040=K>dP3Dc=80eM;F0=GBeP80e]SJ00D0d]?J0=7Gg@3?f^40cm[Q0<_Dh@020<OEi080a=CV
00D0_lkU0;_;i`2kbnL0]lGU0;;2iP030:jli0040:ZfhP2V/^40XZgO0::]g`<0WZOL0P2KX]T309RL
eP80UYOB0P2DT/l209>>b`80U8_70P2ER<<309R7`080VXJm0P2MQk/00`2QR;T0WhBf0:>6]@020:>6
]@<0YhRd0P2[Rk@30:n=/P80/Y2c00D0]92a0;NC/P2gTk80]i>b0;ZH]0020;fI/P80_ife00@0`ind
0<FS]`35XkL0bZNf0P3:ZkX01P3@/KX0ckBoo`00003E^l00fl?20=O4a`80g<g900@0h=K=0=WCd`3J
f]H0f][F2Oooool00ol0003oooooooooo`0=ooooo`002Oooool01?l0003oooooooooooooool=06IV
IPSo0000301VIVH00ol00000C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00<00000oaTI
6OlI6AT02_lI6AU]000000Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool3
o`0001[ooooo0P2BT<h20:^G`P030:bdg`31//`0`K;<0080`K;<00L0bZno0=WCd`3Idm<0d_oI0:JG
a`2/VlH0[Yc600<0/j3400H0^:?40;ZVa02jY/@0^ZK40;jX``32[<D30<B^a080b;?600@0bKC60<fj
b03=^/P0c[_80P3A`L/20=G9cP050=?7cP3Fc]80e/kB0=SFeP3Ed]H00`3Ff=X00`3Eg=h0d^3R0<oJ
h@020<cKi@030<OEi034e>H0a=CV0080_m7X00<0^l_W0;K8i`2fb>L00P2b`^H00`2^_>@0ZKST0:Jb
h@020:Jbh@80XZgO00<0WZOL09VRf`2EW=P00P2EW=P2096Fe080Si3A0P2=Rl`208f7b080SXC40P2@
P/0209R7`00309>1_@2GPKX0Uh6j0080Vh:h0P2OQ;H30:>6]@<0YhRd00<0Zh^d0:^9/@2_SK800P2_
SK800`2bT;<0]92a0;B@/@030;NC/P<0_IVb00@0_ife0<>O]033Wk@0aJ>g0P3:YkH02@3:ZkX0d;6j
0=2a^P3G^;/0eK_0o`00003K`l80h/g40=c=b@020>3Fc@030>?Od03Jf]Kooooo00Wooooo00?o0000
ooooooooool03Oooool000Wooooo00Go0000ooooooooooooooooo`00000P06IVIP03o`00001<C4`0
C4a<00H0C4a<00<0000003<c<`0c<c<01P0c<c<00`00003o6ATIoaTI6@0:oaTI6Fd000001?ooool0
0ol0003oooooooooo`0?ooooo`Co00007_ooool207:[m0<0[;CO0P31//`20<SRj`040=WCd`2OU<P0
YYO70:NIb0<0[Yc600<0/j340;JSa@2jY/@00P2jY/@01@2nZ/H0`Zc50<:/a@32[<D0a:k400<0b;?6
0`3=^/P00`3A`//0dL7;0=G9cP020=G9cP040=SAdP3Fc]80f=KF0=SFeP80f=cJ00H0e]SJ0=GLgP3B
h>80d^3R0<oRiP3<fnD20<OJj080`]SZ00D0_m7X0;[>j@2jc^T0]/SW0;74j0030:fniP80ZKST00<0
Y[;Q0:6^h@2LZ=h00P2LZ=h209VRf`<0UIcH0P2AU]@208n@d@80SH_<0P2=QlP00`2>Q<@0T8;00922
`00309>1_@80Uh6j0P2KP[P309n4]P<0XhJe00<0YhRd0:N6/P2[RK400P2[RK420:n=/P@0]92a0P2g
Tk830;fI/P<0`ind0`3:YkH30=2a^P070=Nh^`3K`l;o00000=_3`P3RcL@0imW70>3Fc@020>?Od0_o
oooo00?o0000ooooooooool03Oooool000Wooooo00Go0000ooooooooooooooooo`00000O06IVIP03
o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`00003o6ATIoaTI6@0:oaTI6Fd0
00001?ooool00ol0003oooooooooo`0?ooooo`;o00008Oooool207:[m0060:bdg`21g_/0PMkk087N
n`38h^/0UY;>0P2OU/X30:NIb0030:jLaP2`X<L0]Z?50080]Z?500@0^ZK40;jZaP2nZ/H0_Z[60P32
[<D30<RcaP80c;[900<0cK[80=72b`3A`//00P3Ebll01@3EbLh0f=7B0=SAdP3JfML0f=KF0080f=cJ
0P3Gh]h00`3Di^<0d^3R0<oRiP020<[Qj@030<OJj032f>X0`]SZ0080_MG/00<0^/kY0;C:jP2db^X0
0P2aa>P00`2]_^H0Z;[V0:RjiP020:Bdh`80XJkQ00<0W:SN09NTgP2BWM/00P2BWM/208jGf080RY7D
0P27Rm0208f;c080SHO80P2>Q<@20922`0<0Th6m0P2GPKX209^2^080WhBf0P2SQ[D00`2SQ;80YhJb
0:N6/P030:^9/@030:n=/P2aS;00/Hb`00<0]92a00<0]i>b0;ZE/02jUK000P2mVK801031W;40`ind
0<>O]039Y;<20<ZW]P0;0=2^]`3@/KX0ekRk0=Nh^`3N`[d0fl?2o`00003RcL@0imW70>_UbP3Sgm00
3Oooool00ol0003oooooooooo`0<ooooo`002Oooool01_l0003oooooooooooooool0C4a<o`0001h0
IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`0300000?lI6AWo6ATI00_o
6ATIK@000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00`1nRmD0
RhkA08^>d@0309JBcP80WiK:00<0YiW80:RMb`2`X<L00P2`X<L20;JSa@050;VXb02nZ/H0_Z[60;jZ
aP32[<D00P35//L01P38/lH0c;[90<bjb@3<^/T0d<?=0=72b`80eL_?0P3He=@0103HdM80f]WG0=[I
e`3JhM`20=SXh0060=ORgP3Di^<0d>SW0=3Xi`3;j>/0b^7Y0P35gn`20;oLkP050;gEk02gd>d0]m3]
0;C:jP2_aN/00`2/_nP0102X^^H0XkKV09n`h`2O/><309^Zh@80UjCN0`2BWM/208jGf080RY7D00<0
Qh_@08J5b`26QL/00P26PLL208Mn`P<0T8;00P2CPKd209N1^P80Vh:h00<0WhBf09j1]02SQ;800P2S
Q;830:N6/P80ZhVa0`2aS;030;B@/@<0^YF`00@0_IVb0<6L/@31W;40`ind0P39Y;<00`3:YkH0d:jg
0=2^]`020=Nh^`80g/:m00D0i/jo0>;=a?l00000imW70>_UbP0>ooooo`03o`000?oooooooooo00co
oooo0009ooooo`04o`000?ooooooooooooooo`80C4a<0ol0000I06IVIP;o00002@1<C4`00`000000
<c<c03<c<`0603<c<`0300000?lI6AWo6ATI00_o6ATIK@000004ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool08?ooool207j;e@80RhkA0P2FT/h00`2OU/X0Wi[>0:RMb`020:RMb`80
/:3700H0]Z?50;VXb02iZ<P0^JS80;jZaP32/LT30<Fba`80bK[;00D0c;[90=33c@3@`ld0e<gB0=G;
c`030=SDe0030=[Nf@3JfML0f^7L00<0f>SP00@0eNgT0=3_j03@j>L0bnS[0`36i^h01@30h_00_mc^
0;WGk`2ienl0]m3]0080/L_]0P2_aN/00`2/_nP0Y[_X0:Jkj0020:>fiP80Wk3S00<0Vj[Q09FVh@2@
X=h00P2@X=h208^If`80QY;H0P2:TM@208N;d080QXG;0P26PLL01027O/80RWfn08Ym_P2:OKh208il
^`80Tgfh0P2HOkH309j1]0<0XhBb0P2WQ[800`2[RK40[8V`0;6</0030;6</0030;B@/@2gTJl0^YF`
0080^YF`0`31W;430<VT/`<0d:jg00T0f;Jh0=Nh^`3N`[d0g/:m0>K>_`3]g<40imW7o`00003[iLX0
3_ooool00ol0003oooooooooo`0<ooooo`002Oooool01?l0003oooooooooooooool504a<C003o`00
001VIVH0IVIV01D0IVIV00?o000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0603<c<`030000
0?lI6AWo6ATI00_o6ATIK@000004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7oooool207F;f`80QI7G0P2CU]<309nJcP80Z9g;00<0/:370;:Vc02bY/`00`2iZ<P30<:ab@040<Fb
a`39^//0bK[;0<k4d0<0d<?=00@0e<gB0=SHf03Hf=P0f=CD0P3Jg]T01`3Jimh0enoS0=O_h`3Hj>00
eNgT0=3_j03:kn`00`34kO001@36i^h0`>;`0;[MlP2jgO80^MO_0080/m7_00<0/L_]0:c6k@2/a^d0
0P2Y`N/00`2V^nP0XKOX09jbiP0209jbiP80VZcT0P2EY^43092PgP80RiWK00<0QY;H08:;e022Rm@0
0P1nQLl207aob`80QX770P27O/8208Ym_P80SWbk0P2COKP209Qo]P<0WX6d0`2SQ;800`2WQ[80Z8J`
0:b9/0020:b9/0<0/Hb`0`2gTJl20;ZE/0040;jH/031W;40`Iba0<NQ/@80bJBc00H0cj^d0=2^]`3H
][P0f;Jh0>32^@3N`[d20>K>_`030>gL`@3`j/?o000000oooooo00?o0000ooooooooool03?ooool0
00Wooooo00Co0000oooooooooooooooo1P1<C4`00ol00000IVIV06IVIP0C06IVIP03o`00001<C4`0
C4a<00T0C4a<00<0000003<c<`0c<c<01P0c<c<00`00003o6ATIoaTI6@0<oaTI6Fd000001?ooool0
0ol0003oooooooooo`0Dooooo`;o00008?ooool207F;f`80QI7G0P2CU]<209nJcP030:RMb`2ZXm00
/ZK<00<0/ZK<00@0^JS80;b`c@2l/<d0`[790P36^/l01@39^//0c/C@0<k4d03>a=00d<?=0080e<gB
0P3Hf=P00`3Ihmd0f]kI0=[WgP020=O_h`050=;ciP3<m^X0c?KZ0<Gek@2ol_400P34kO00102njO80
^N?d0;WSm02jgO820;CGlP040;?Ak`2^c>l0[/c_0:c6k@80Yl;/0P2U_>X20:6gj00309jbiP2I[^H0
U:WT0080U:WT0P2?Xn8208VLg`80Q9GL0P1mS]T208:;e080OXG?00<0O7o;07ekaP1mNlH00`1oNL82
08Ym_P80SWbk0P2COKP209Qo]P<0WX6d00@0XhBb0::2/@2XQ[00Z8J`0`2/RK020;6</0050;>>[`2g
TJl0]i6_0;NA[`2jUK000P2nV;001031W;40aj6a0<NQ/@39Y;<20<n[]0<0f;Jh00<0h<:i0>W@^`3V
c[l00P3]g<400`3`j/?oooooo`00000>ooooo`03o`000?oooooooooo00cooooo0009ooooo`04o`00
0?ooooooooooooooo`L0C4a<0_l0000A06IVIP;o00002`1<C4`00`000000<c<c03<c<`0703<c<`03
00000?lI6AWo6ATI00co6ATIK@000004ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool07_ooool00`1XSN<0OIGO07fEg`02092KfP80WYoE0`2ZXm020;:Vc0040;F^dP2l/<d0_;3=0;b`
c@<0a[[?0P3:aMD0103>a=00d]3G0=;@e`3DcM820=SHf080fN?M00P0f>kR0=?eiP3;nNP0boWX0<?j
jP3<m^X0aOG]0;obl@80^^kd0P2fj?H0102iho@0]=cd0;3Fm02`e_@20:oAl@050:k<k`2Ya^h0ZLK^
0:O2k02S_N`00`2P^NX209bdj080VJkV0`2DZN@208nShP80RIcO0P24UM`00`1mS]T0N8KE07R6e@02
07=od080O7o;00@0OG_607mi`P1oNL80OgW20P23N;h208il^`80Tgfh0P2HOkH209j1]00309ao/`2R
P[40XX:a00<0Z8J`0P2/RK00102aS;00/hj_0;>>[`2cSZl20;NA[`<0_YR`0`37XK430<n[]0070=Rd
]@3H][P0h<:i0>32^@3Yd;/0lN2m0>gL`@020?3Z``;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`002Oooool01?l0003oooooooooooooool904a<C003o`00001VIVH0IVIV
00d0IVIV00?o000004a<C01<C4`02`1<C4`00`000000<c<c03<c<`0703<c<`0300000?lI6AWo6ATI
00co6ATIK@000004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07_ooool00`1X
SN<0OIGO07fEg`02092KfP80WYoE00<0ZZ?@0:^/f02[[=P00`2e[]80102l/<d0`;[D0<2je036^/l3
0<[5e@040<kCg@3Bd=L0eMgM0=GMg@80eNWS00<0fN?M0=S^hP3CmNH00P3;nNP00`33n^X0^oW]0;Kf
l@020;;am@80/>ch00D0]^Sf0;;Qm`2_f_H0[m[f0;3Fm0020:c?lP80Zl_`00<0ZLK^0:G2kP2U`^h0
0P2S_N`00`2P^NX0VkKZ09Raj@0309Raj@80TjcW0P2>Y^D208VPh`0308:Ih@1kT]h0Ni;N0080LhWK
0P1hQ]D00`1cOm00LGW<075ic00207ekaP80OgW20P23N;h208Uh^`80SgZh0P2FO;D309ao/`<0XX:a
0P2XQ[020:b9/0@0/hj_0P2gTJl30;jH/0<0aj6a00@0cZRb0<n[]03H];D0f;Be0P3P`[T20>W@^`03
0?7P_@3ckk`0l>[300Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`00
2Oooool01?l0003oooooooooooooool:04a<C0?o00002@1VIVH3o`0000d0C4a<00<0000003<c<`0c
<c<01`0c<c<00`00003o6ATIoaTI6@0=oaTI6Fd000001?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01kooooo00<0Dhk[072Jj@1`V^T00P29XnD209fXgP<0ZjcH00@0]JkB0;RifP2h
^MX0`;[D0`34am`01@3:aMD0c]?M0<kCg@3@h^D0eMgM0080eNWS00L0dOCW0<Sjj02lnnL0_?_W0;;j
i`2Zn>T0YoG^0080Y_;d00@0Yngi0:SVnP2Xi_X0[^Ci0P2/gOP0102_f_H0[=?d0:cCm02/co820:S9
l@80YlK_00<0YL;^0:6nk@2Q_^d00P2N^^`209^fjP80V;7Y00<0TjoY08jZj02>Z^P00P28Y>L208:N
i@80NYOS0P1kT]h00`1cRM/0K87G06b1e`0207=od003075ic01aMLL0LGG700<0OgW20P23N;h00`29
N;/0SgZh08mj^00309Il]@<0W7nc0P2RP[420:R6/0030:b9/02^RZl0[XZ_00<0/hj_00@0]i6_0;^D
[`2kU:l0_YR`0P34WK001037XK40cZRb0<jX/P3?Zk@20=Rd]@030>71^03P`[T0jM2k0080lN2m00<0
lnnlooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`04o`000?ooooooooooooooo`d0C4a<2Ol0000?04a<C0030000000c<c<0<c<c00P0<c<c00<0
0000oaTI6OlI6AT03OlI6AU]000000Cooooo00?o0000ooooooooool06Oooool2o`0001oooooo00<0
<X_]072Jj@1`V^T00P29XnD209fXgP040:^/f02[^>80ZkSR0;RifP80^/SU0`34am`01036enH0c]?M
0=3Ri@3@h^D20<g`j`060<?hk02dn^P0XoOR09Kbg`2@l>40TNoX0P2Fko401@2Kk?P0XNOl0:7Wo02X
i_X0Z=oj0080Z=Oh00<0Z]Kf0:S?m02Xco@00P2YcO<00`2XbO40YLG`0:G5l0020:?2k`040:6nk@2N
^nd0W[_]09jkk@80VkO/0P2G/n/209>_j@80SZ[X0P28Y>L208:Ni@0307ZGh`1aSn00LHoP0080IhKM
00H0K87G06IjdP1VN]80Hg?>075ic01aMLL307Ec``80PgRn0P29N;/208mj^080UWbe0`2LOk<20::2
/@030:R6/02YQ[00[XZ_0080[XZ_0`2cSZl30;^D[`040;jH/034WK00a9f`0<NQ/@80cZRb0P3H];D2
0>71^0030>cA^P3Yd;/0lN2m0080lnnl1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo0009ooooo`05o`000?ooooooooooooooo`0000008`1<C4`00`000000<c<c03<c<`09
03<c<`03o`000?lI6AWo6ATI00go6ATIK@000004ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07_ooool205ZNl`80OZcb0P2I]>/00`2[^>80ZLO_0;[8i@030;[8i@050<C7g036enH0
aNO_0<GWk`3@h^D00P3=l>/01@33n>`0]?[X077Pc`1_gm@0JmgV0080O^?e00D0SNSg09OUo02Ngod0
W]om0:CPo0020:GInP040:SGn02WdOH0Ym7f0:S?m0<0YlWb0P2Vao400`2UaO00Xl7_0:?1k`020:6n
kP0309jkk@2K^Nd0UkG/0080UkG/0P2C/N`208j]j`80RJSZ0P23XnT00`1kWNL0LIKV076FiP02076?
h00306N6g@1MOMT0GGgI0080IW[B00<0Hg?>075ea`1aMLL00P1eLl<207Yc_`80PWFl0P2?N[P309Il
]@80W7nc00<0XX:a0::3/@2YQ[000P2YQ[030:j:[`030;>>[`2gTJl0^iB_0080^iB_0`34WK030<jX
/P080=Nb]03H];D0hL6h0>71^03/dKX0m>Bj0?7P_@3ckk`8ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02oooool000Wooooo00Ko0000oooooooooooooooo03<c<`00000Q04a<C003
0000000c<c<0<c<c00X0<c<c00<00000oaTI6OlI6AT03OlI6AU]000000Cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Nooooo`80=igc0P1X]O/208o2n080ZLO_0P2jb>D0102ifO40
/>Wh0;3Yn035inl20;_clP030:Wfk@2Al>00ALFj0080I]Kc00D0LMcc08GOo@2Cg?h0Tmcn09SNoP02
09oHo0050:;In`2Td_P0Y=;h0:CBn02Vd_L00P2Vc?@20:O;l`030:O9lP2UaO00YLG`0080Y<?_00<0
Xl7_0:2nkP2P_^h00P2N_>h209^ik@0309Nek02D]>d0T;7]0080T;7]0P2:[N`00`24Z>`0OJ?[07fS
j`0207BLjP80LIKV00@0IXgS05V3h01IPn00GGgI0P1EM=D0101SLlh0Hfo906=_b@1SKlT207Ec``03
07Yc_`22MK`0PWFl0080RWRi0`2CNkH209]o/`80XX>a0`2YQ[030:j:[`<0]i6_0P2kU:l01@30V[00
a9f`0<BM/03;YK80cZRb0080ek:d0P3Q`KP20>cA^P030?CT^P3clkCooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01?l0003oooooooooooooool203<c
<`030000001<C4`0C4a<01`0C4a<0P00000<03<c<`0300000?lI6AWo6ATI00go6ATIKP000004oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool200N=g080@[?f0P1icOl0102Q
f?/0Rn7l08_Qo02`jOP209__m00507gWh`1OcOL0N]?o07[Co`1keoh00P2=e_l01@2?fOl0VMCl09WD
o02Ie?`0VmKl0080X=3i0P2RdOP0102Td_P0YLcd0:G<m02Vc?@40:K7l@030:G5l02T`^l0Y<;_0080
X/3^00<0X;k^09jlkP2N_>h00P2L^^h209Rgk@80U;C]00@0T;7]08b`kP26[Nh0QZg^0P1oZ>h207fS
j`80M9cZ00@0J9GY05Z<i`1JS>L0FH?P0P1;N=`00`1EM=D0CfgA04m]d@0206=_b@80Ifk60P1jLkl0
1022MK`0RWRi08Yh^@2:N;T209=k]P80Vgnc0`2RPk430:V6/0030:j:[`2aSK00]i6_0080]i6_00@0
^iB_0<2J/030V[00a9f`0P3;YK801P3>Z;80ek:d0=Nb]03Q`KL0hL6h0>cA^P80m>Bj00<0lo>doooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`04
o`000?ooooooooooooooo`<0<c<c00?o00000000000000006P1<C4`00`000000<c<c03<c<`0;03<c
<`0300000?lI6AWo6ATI00ko6ATIKP000004ooooo`03o`000?oooooooooo01kooooo0_l0000]oooo
o`80S<on00@0S=;o09O?n`2Gco/0Um;l0P2NcOP209o?n0040:3@n@2SboD0Xl_e0:C<m080YLSb0P2V
b?400`2Vao40Y/C_0:K4k`020:G3k`030:C2k`2S`>h0Xl3^0080XKk^00<0W[c^09fkkP2M^nh00P2J
^Nh209JgkP80TKC^0P2</>h208J]kP80OjS^0P1gXnh206fMk@0505nEk01JS>L0FXcW04V0i01;N=`0
0P0nKMP01@1?KM40CVS=04iXc@1SKlT0Ifk60080Kfo20P22MK`208Yh^@<0Tg^f0P2KOk<20::3/@80
ZHJ`00@0ZhVa0;6=/02aSK00/Hf`0P2gTJl30<2J/0<0bjFb0P3G/[@20>71]`040>gD^P3/dKX0m>Bj
0??c]0cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`002Oooool01?l0
003oooooooooooooool603<c<`030000001<C4`0C4a<01D0C4a<00<00000o`00000c<c<03@0c<c<0
0`00003o6ATIoaTI6@0>oaTI6Fh000001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02_ooooo00<0Ulcj09g9mP2MbOH00P2MboL0102NcOP0X/Wd0:;9m02Rb_@20:C7l@80YLOb00<0
YLSb0:K4k`2Va>l00`2Va>l20:G2kP80Y<7^00<0Xl3^0::nk@2R_^d00P2P_Nd00`2M^nh0W;_^09bk
kP0209RikP80U;O_0P2?]?0208Val080Pjk`0P1kZO4207:Ul@0406JOl@1FUo00EYO`04j;jP80=gkV
00@0=W?O03i]f00dI=<0=6CC0P1>J<d206M^aP0306m_`P1iL[l0NG:o0080RWRi0`2CNkH209]o/`80
XX>a00<0ZHJ`0:^9/@2[RK400`2aSK000`2gTJl0^iJa0;^F/@020<2J/0050<NR/`3;YK80bjFb0=B`
]@3G/[@00P3Q`KL00`3]e;X0mNZh0>ggZP0>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool000Wooooo00Co0000oooooooooooooooo1`0c<c<300000180C4a<0P00000?03<c
<`0300000?lI6AWo6ATI00oo6ATIKP000004ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0:oooool0102MbOH0XLKc0:76l`2Qao<20:C5l080Y<Ka00<0Y<Oa0:K4k`2Va>l00`2Va>l2
0:K2k@80Y/;^00<0YL;^0:G0k@2U`>d00P2T_nd00`2R_^d0XKg]0:6mk@0209nlk@0309bkkP2K^nh0
UkW_0080UkW_0P2C]o0208fel@80Qk;b0P20[o8207R/l`80KJOd00@0H:7d05JGl01FUo00@Hc]0P0g
O^H01@0LK]l08FGI03ATd`0dI=<0CVS=0080DfO900<0Kfo207Ub_`1iL[l00`24M[`209=k]P80Vgnc
00<0XX>a0:>4/`2[RK400`2[RK420;6=/0<0^iJa00@0`9Z`0<NR/`37X[<0bjFb0P3D/;D01P3P`KT0
hL6g0>gD^P3]e;X0mNZh0>ggZPoooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`002Oooool01?l0003oooooooooooooool:03<c<`<000003@1<C4`200000100<c<c00<00000
oaTI6OlI6AT04?lI6AU^000000Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0]
ooooo`040:?4l02TaO00YL?^0:G3kP80YL?_00<0Y/C_0:K2k@2V`^d00`2V`^d20:K1k080Y/3/00<0
YL3]0:Fok02U_n`00P2S_^`30:6mk@80W[c]0P2K^nh00`2G^Nl0Uk[`09Njl00209:hl@80S;Kb0P26
]?<207jam080MJkf0P1ZZ_H01`1KYOH0CYWb04jIlP0fS^l09GgW005XfP00Fm@00P0?F=82031Nc`04
05=Wb@1MJLL0Kfo207Ub_`<0Q7Jl0P2?NkT209V0]P<0XhBc0`2[RK400`2aSK00]I:c0;^F/@020;^F
/@<0aj:c0`3D/;D01@3P`KT0k]Rm0>gD^P3ej[P0kONZ013ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`002Oooool01?l0003oooooooooooooool=03<c<`03o`0000000000
000000X000004@0c<c<00`00003o6ATIoaTI6@0AoaTI6B@000005_lI6ATd000000Cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0]ooooo`80YL;^00D0YL?^0:K1k@2V`Nd0Y/7]0:K2
k@020:O0k080Yl7/00<0Y/7/0:Joj`2V_n/00P2V_n`00`2U_n`0YKk/0:Fnk0020:>nk0<0XKg]0P2N
_>h209^kk`0309Njl?oooooooooo00oooooo00@0;I7_01Ami@01J=X005_D0P0?F=80100`G/l0=5g=
05=Wb@1MJLL207Ub_`80Q7Jl0P2?NkT209V0]P<0XhBc0`2[RK430;FB/`80^iJa00D0`Ynd0<NR/`37
X[<0dJng0=B`]@020>31^@030>kH_@3dlKT0mNZh01;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`002Oooool01?l0003ooooooooooooooolZ03<c<`0300000?lI6AWo6ATI
01;o6ATI8000000MoaTI6C4000001?ooool00ol0003oooooooooo`0Tooooo`;o0000;_ooool20:K0
k0030:K1k@2W`>/0Yl3[00<0Yl3/0`2W_n/30:Joj`80Y[k[00<0YKk/0:Bnj`2T_^/00P2S_N`00`2Q
_Ngoooooooooo`0Iooooo`06001>aP00AlH004O600=?c00dGLd0GFW70P1[K/@308Af_080Sg^i0P2I
P;H30:>4/`030:^9/@2]S[D0]I:c0080]I:c00@0^iJa0<:O]032Wk@0aj:c0P3A[kL20>31^@80k]Rm
00<0m?6i0=[dVoooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
0009ooooo`04o`000?ooooooooooooooobP0<c<c0P00000EoaTI6AT00000:?lI6AT]000000Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0/ooooo`80Yko[00<0Yl3[0:Noj`2W_n/0
0`2W_n/20:NojP80Yko[00D0Y[o[0:Jnj`2V_^/0Y[k[0:Bnj`0Qooooo`06000bZ`00=kP00Dc;041R
c@1MJLL0Jfk40`1jML8208mk^@80VH2f0P2SQ;<0102SRKP0[Hje0:f>]@2]S[D20;FB/`<0`Ynd0`3A
[kL00`3N`[d0h<6i0>kH_@020?Ca^ACooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`002Oooool01?l0003ooooooooooooooolW03<c<`0300000?lI6AWo6ATI01Go6ATI5P00
000^oaTI6@03o`0000000000000002L000001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02cooooo0P2W_nX00`2W_n/0Z;oZ0:RojP030:NojP@0YkkZ00<0Y[k[ooooooooool09?oo
ool00`00=kP00Dc;041Rc@0206]^a080NWG20P29O;h209R3^`<0XhVh0`2]S[D00`2eT[<0^i^h0;^K
^0020<:O]0070<b]^`3A[kL0g/:m0=k2_@3]g/<0k]Rm0?Ca^@0Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool000Wooooo00Co0000oooooooooooooooo0`00000R03<c<`03
00000?l0003o6ATI01Oo6ATI500000000ol0003o6ATIoaTI6@0`oaTI6BL000001?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02cooooo0P2X_^X00`2X_nX0Z;kZ0:RnjP020:RnjP03
0:Nnj_oooooooooo02[ooooo00@035;>05=Zc@1CJ/d0Df[=0P1jML801029O;h0V8>k09R3^`2HPk/3
0:>9^080[Hje0`2kVkP01032Wk@0c:fk0<b]^`3A[kL20=k2_@030>gN``3]nKX0/nB401Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003ooooooooooooo
ool3oaTI6@8000007P0c<c<2000001_o6ATI4P00000eoaTI6BH000001?ooool00ol0003ooooooooo
o`0Yooooo`;o0000;Oooool30:RnjS7ooooo00<035;>05=Zc@1CJ/d00P1ZML`208Ul_P80V8>k0`2S
RKP00`2]S[D0/INk0;6G^`020;^K^0<0c:fk00D0fLC40=k2_@3]g/<0kMk30>gi^P0Iooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooooooo
1OlI6AT00`000000<c<c03<c<`0J03<c<`0300000?lI6AWo6ATI01_o6ATI3P00000koaTI6B@00000
1?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
<_ooool202APe00405=Zc@1ZML`0PH390860b@<0V8>k00<0XhVh0:FA`02aUk/00P2aUk/00`2kVkP0
a:[00<BZ`0020<b]^`040=W4a03Xi/d0kMk30>gi^Q[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`002Oooool01?l0003oooooooooooooool6oaTI6@04o`00000000000000
000001H0<c<c00<00000o`000?lI6AT07_lI6AT00ol00000000000000007000003oo6ATI00?o0000
00000000000080000004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0cooooo`80963D0P1ZML`01021P<T0UHW509F9a@2ERLD30:FA`080/INk0`34
Z/001@3<[K/0fLC40=W4a03Xi/d0eofi01cooooo00Go0000ooooooooooooooooo`00000;ooooo`00
2Oooool01?l0003oooooooooooooool:oaTI6@<00000400c<c<3000004Ko6ATI4`00000CoaTI6B40
00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=?ooool00`00?kd0Ag?J04McfP020860b@<0UHW50P2UTL000`2aUk/0^:K70;RVa`020<BZ`004
0=75cP3Ia<@0j>K=0>SVcAkooooo00Co0000oooooooooooo00002oooool000Wooooo00Co0000oooo
oooooooooooo3OlI6AT@000004Ko6ATI0`00000C03<c<`<000004OlI6ATP000000Cooooo00?o0000
ooooooooool0;_ooool2o`0002Sooooo00?o0000ooooooooool0=_ooool00`17LmX0KHOK06f7f`03
09F9a@030:FA`02WX<l0^:K70080^:K700D0a:[00=75cP3AaLh0gO3N0>SVc@0Pooooo`03o`000?oo
oooo000000_ooooo0009ooooo`04o`000?oooooooooooooooeoo6ATI0P0000000ol00000000003<c
<`0H03<c<`80000000?o000000000?lI6AT03OlI6AT00ol0000000000000000L000000Cooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo00<0
05oD06f7f`2>U]L00P2>U]L30:NPc`060;RVa`32aM`0`/GL0=75cP3Ml=h0XNj]8Oooool00ol0003o
ooooo`00000;ooooo`002Oooool01?l0003ooooooooooooooomLoaTI6@<000008@0c<c<2000000oo
6ATI70000004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0iooooo`0503>9k@2>U]L0SYKG08jFe`2WX<l00P2V_n`00`32aM`0_OCa0;gdl@0Toooo
o`03o`000?oooooo000000[ooooo0009ooooo`04o`000?oooooooooooooooe_o6ATI00<0000003<c
<`0c<c<0900c<c<2000000ko6ATI6`000004ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`<0MJge00@0Y[o/07?Lm01cg?@0_OCa9_ooool2
o`0000[ooooo0009ooooo`04o`000?oooooooooooooooe[o6ATI00?o000003<c<`0c<c<0400c<c<8
o`0000l0<c<c00<00000oaTI6OlI6AT02olI6ATK000000Cooooo00?o0000ooooooooool0<oooool2
o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0000[ooooo0009ooooo`04o`000?oooooooooo
oooooeSo6ATI0P00000<03<c<`Oo0000201<C4`6o`0000X0<c<c00?o000000000?lI6AT02olI6ATJ
000000Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06?ooooo1?l0000=ooooo`002Oooool01?l0003ooooooooooooooomEoaTI6@<000002`0c<c<3
o`0001D0C4a<0_l0000:03<c<`8000002olI6ATI000000Cooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo0ol0000Aooooo`002Oooool01?l0
003ooooooooooooooomDoaTI6@030000000c<c<0<c<c00/0<c<c00?o000004a<C01<C4`0601<C4`3
o`0000T0<c<c00<00000oaTI6OlI6AT02OlI6AT00ol0000000000000000E000000Cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000D
ooooo`002Oooool01?l0003ooooooooooooooomCoaTI6@030000000c<c<0<c<c00T0<c<c0ol0000N
04a<C0?o00001`0c<c<00`00003o0000oaTI6@09oaTI6AL000001?ooool00ol0003oooooooooo`0h
ooooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00Co0000oooo
ooooooooooooD_lI6AT00`000000<c<c03<c<`0903<c<`03o`00001<C4`0C4a<00T0C4a<3ol0000:
04a<C003o`00000c<c<0<c<c00H0<c<c00<00000oaTI6OlI6AT01olI6ATG000000Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000L
ooooo`002Oooool01Ol0003ooooooooooooooooo0000053o6ATI00<0000003<c<`0c<c<0200c<c<2
o`0000T0C4a<0ol0000?06IVIP?o0000201<C4`00ol00000<c<c03<c<`0603<c<`0300000?lI6AWo
6ATI00Oo6ATI5P000004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo00Ko0000oooooooooooooooo00000?l0
001>oaTI6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`01`1<C4`2o`0001D0IVIV0_l0
000704a<C003o`00000c<c<0<c<c00H0<c<c00<00000oaTI6OlI6AT01olI6AT00ol0000000000000
000B000000Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04gooooo1?l0000Sooooo`002Oooool01?l0003oooooooooooooool2000000Co0000BOlI
6AT00`000000<c<c03<c<`0703<c<`;o0000201<C4`2o`0001T0IVIV0_l0000604a<C0?o00001@0c
<c<00ol000000000oaTI6@08oaTI6A@000001?ooool00ol0003oooooooooo`0mooooo`;o00006Ooo
ool00ol0003oooooooooo`19ooooo`Co00009oooool000Wooooo00Co0000oooooooooooooooo1P00
0004o`0004Co6ATI00<0000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C0?o00002P1V
IVH<o`0000L0IVIV0_l0000704a<C003o`00000c<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT01olI
6ATC000000Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04Gooooo1?l0000[ooooo`002Oooool01?l0003oooooooooooooool:000000?o0000@?lI
6AT00`000000<c<c03<c<`0703<c<`03o`00001<C4`0C4a<00D0C4a<00?o000006IVIP1VIVH0201V
IVH3o`0000`0Ogmo0ol0000606IVIP;o00001P1<C4`00ol00000<c<c03<c<`0403<c<`0300000?lI
6AWo6ATI00Oo6ATI4P000004ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`13ooooo`?o0000;oooool000Wooooo00Co0000oooooooooooooooo3@00
0007o`0003So6ATI00<0000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C003o`00001V
IVH0IVIV00D0IVIV1?l0000B07moO`?o00001@1VIVH00ol00000C4a<04a<C00404a<C003o`00000c
<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT01olI6AT00ol0000000000000000>000000Cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo1?l0
000booooo`002Oooool01?l0003ooooooooooooooolD000001So00008?lI6AT00`000000<c<c03<c
<`0703<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH0101VIVH2o`0001T0Ogmo00?o
000006IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00<0
0000oaTI6OlI6AT01olI6ATA000000Cooooo00?o0000ooooooooool0@_ooool2o`0001?ooooo00?o
0000ooooooooool0>oooool4o`0003Kooooo0009ooooo`04o`000?ooooooooooooooob`000000_l0
000MoaTI6@030000000c<c<0<c<c00L0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IV
IP0306IVIP03o`00001oOgl0Ogmo00L0Ogmo3?l0000707moO`03o`00001VIVH0IVIV00<0IVIV00?o
000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`0300000?lI6AWo6ATI00Ko6ATI4@00
0004ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0gooooo`Co0000>_ooool000Wooooo00Co0000oooooooooooooooo;@0000000ol0003o6ATIoaTI
6@0JoaTI6@030000000c<c<0<c<c00L0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IV
IP0306IVIP03o`00001oOgl0Ogmo00D0Ogmo0ol0000<09VIV@;o00001P1oOgl00ol00000IVIV06IV
IP0306IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI
6@07oaTI6A0000001?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<oooool4o`0003kooooo0009ooooo`04o`000?ooooooooooooooobh0000000?o
0000oaTI6OlI6AT06?lI6AT00`000000<c<c03<c<`0703<c<`03o`00001<C4`0C4a<00@0C4a<0_l0
000506IVIP03o`00001oOgl0Ogmo00<0Ogmo0ol0000A09VIV@?o0000101oOgl2o`0000@0IVIV00?o
000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0303<c<`0300000?lI6AWo6ATI00Oo6ATI3`00
0004ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0`ooooo`?o0000@_ooool000Wooooo00Co0000oooooooooooooooo;P0000000ol0003o6ATIoaTI
6@0GoaTI6@030000000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IV
IP0306IVIP03o`00001oOgl0Ogmo00<0Ogmo00?o000009VIV@2IVIT05@2IVIT00ol00000Ogmo07mo
O`0307moO`03o`00001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c
<`0403<c<`03o`000?lI6AWo6ATI00Ko6ATI3`000004ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wooooo00Co0000
oooooooooooooooo;P0000000ol0003o6ATIoaTI6@0FoaTI6@030000000c<c<0<c<c00P0<c<c00?o
000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00<0Ogmo00?o
000009VIV@2IVIT01P2IVIT;o`0000H0VIVI00?o000007moO`1oOgl00`1oOgl00ol00000IVIV06IV
IP0206IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI
6@07oaTI6@h000001?ooool00ol0003oooooooooo`18ooooo`;o00003Oooool00ol0003ooooooooo
o`0Xooooo`Co0000BOooool000Wooooo00Co0000oooooooooooooooo;P0000000ol0003o6ATIoaTI
6@0EoaTI6@030000000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IV
IP0306IVIP03o`00001oOgl0Ogmo00<0Ogmo00?o000009VIV@2IVIT0102IVIT3o`0000/0/k>c0_l0
000509VIV@;o0000101oOgl00ol00000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<0080C4a<00?o
000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@06oaTI6@03o`0000000000000000/000001?oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?oo
ool4o`0004gooooo0009ooooo`04o`000?ooooooooooooooobh0000000?o0000oaTI6OlI6AT05OlI
6AT00`000000<c<c03<c<`0803<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00P1V
IVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<03P2c
/k<2o`0000D0VIVI00?o000007moO`1oOgl00P1oOgl01Ol00000IVIV06IVIP1VIVKo000000@0C4a<
00?o000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@06oaTI6@h000001?ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo
0009ooooo`04o`000?ooooooooooooooobh0000000?o0000oaTI6OlI6AT05?lI6AT00`000000<c<c
03<c<`0803<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo
07moO`0307moO`03o`00002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<04@2c/k<00ol00000VIVI
09VIV@0309VIV@05o`00001oOgl0Ogmo07moOol00000101VIVH00ol00000C4a<04a<C00204a<C003
o`00000c<c<0<c<c00<0<c<c00<00000oaTI6OlI6AT01OlI6AT>000000Cooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0001Dooooo`00
2Oooool01?l0003oooooooooooooool^00000003o`000?lI6AWo6ATI01Co6ATI00?o000003<c<`0c
<c<0200c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1o
Ogl00`1oOgl00ol00000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c01<0/k>c00?o000009VIV@2I
VIT00`2IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00?o000004a<C01<C4`00`1<C4`00ol0
0000<c<c03<c<`0203<c<`0300000?lI6AWo6ATI00Ko6ATI3@000004ooooo`03o`000?oooooooooo
04gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001Hooooo`002Oooool01?l0003o
ooooooooooooool^00000003o`000?lI6AWo6ATI01Co6ATI00<0000003<c<`0c<c<01`0c<c<00ol0
0000C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl00P1oOgl00ol0
0000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00@0/k>c2ol000060;>c/`03o`00002IVIT0VIVI
0080VIVI00?o000007moO`1oOgl00P1oOgl01Ol00000IVIV06IVIP1VIVKo000000@0C4a<00?o0000
03<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@05oaTI6@d000001?ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0005cooooo0009oooo
o`04o`000?ooooooooooooooobh0000000?o0000oaTI6OlI6AT05?lI6AT00`000000<c<c03<c<`07
03<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`02
07moO`03o`00002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c009
0<c<c0;o00001@2c/k<01Ol00000VIVI09VIV@2IVIWo000000@0Ogmo00Go000006IVIP1VIVH0IVIV
o`00000404a<C003o`00000c<c<0<c<c00<0<c<c00<00000oaTI6OlI6AT01OlI6AT=000000Cooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo
0ol0001Pooooo`002Oooool01?l0003oooooooooooooool^00000003o`000?lI6AWo6ATI01?o6ATI
00<0000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV
00?o000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00<0/k>c
00?o00000<c<c03<c<`0303<c<`00ol00000/k>c0;>c/`030;>c/`05o`00002IVIT0VIVI09VIVOl0
0000101oOgl01Ol00000IVIV06IVIP1VIVKo000000@0C4a<00?o000003<c<`0c<c<00P0c<c<00`00
003o6ATIoaTI6@06oaTI6@`000001?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`04o`000?oooooooooooooo
obh0000000?o0000oaTI6OlI6AT04_lI6AT00`000000<c<c03<c<`0803<c<`03o`00001<C4`0C4a<
00@0C4a<00?o000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`03o`00002IVIT0VIVI
0080VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c00>0<c<c003o`00002c/k<0/k>c
00<0/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`;o00000`1VIVH01Ol00000C4a<04a<C01<
C4co000000D0<c<c00?o0000oaTI6OlI6AT01OlI6AT<000000Cooooo00?o0000ooooooooool0D_oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo0009ooooo`04o`000?oooooo
ooooooooobh0000000?o0000oaTI6OlI6AT04_lI6AT00`000000<c<c03<c<`0803<c<`03o`00001<
C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`03o`00002I
VIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c00?0<c<c003o`00002c
/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVIo`00000407moO`05o`00001VIVH0IVIV06IVI_l0
00000`1<C4`00ol00000<c<c03<c<`0303<c<`0300000?lI6AWo6ATI00Go6ATI30000004ooooo`03
o`000?oooooooooo05Cooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`04
o`000?ooooooooooooooobh0000000?o0000oaTI6OlI6AT04OlI6AT00`000000<c<c03<c<`0803<c
<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0207mo
O`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c00@0<c<
c003o`00002c/k<0/k>c00<0/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`03o`00001VIVH0
IVIV0080IVIV00Go000004a<C01<C4`0C4a<o`00000503<c<`0300000?lI6AWo6ATI00Go6ATI2`00
0004ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooool000001Oooool3o`0006oooooo0009
ooooo`04o`000?ooooooooooooooobh0000000?o0000oaTI6OlI6AT04OlI6AT00`000000<c<c03<c
<`0803<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07mo
O`0207moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<
c00A0<c<c003o`00002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`03o`00
001VIVH0IVIV0080IVIV00Go000004a<C01<C4`0C4a<o`00000503<c<`0300000?lI6AWo6ATI00Go
6ATI2`000004ooooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002o`0007;o
oooo0009ooooo`04o`000?ooooooooooooooobh0000000?o0000oaTI6OlI6AT04OlI6AT00`000000
<c<c03<c<`0803<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000
Ogmo07moO`0207moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000
c<c<0<c<c00A0<c<c003o`00002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVIo`00000307mo
O`03o`00001VIVH0IVIV0080IVIV00Go000004a<C01<C4`0C4a<o`00000503<c<`0300000?lI6AWo
6ATI00Go6ATI2`000004ooooo`03o`000?oooooooooo05Oooooo0_l0001fooooo`002Oooool01?l0
003oooooooooooooool^00000003o`000?lI6AWo6ATI017o6ATI00<0000003<c<`0c<c<0200c<c<0
0ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl00P1oOgl0
0ol00000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`04@3<c<`0
0ol00000/k>c0;>c/`020;>c/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl00ol00000IVIV06IV
IP0206IVIP05o`00001<C4`0C4a<04a<C?l000001@0c<c<00`00003o6ATIoaTI6@05oaTI6@/00000
1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003oooooooooooooool^00000003o`00
0?lI6AWo6ATI017o6ATI00?o000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C003o`00
001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0209VIV@03o`00
002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`04@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00
002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmoo`00000306IVIP03o`00001<C4`0C4a<0080
C4a<00?o000003<c<`0c<c<00P0c<c<00`00003o6ATIoaTI6@05oaTI6@/000001?ooool00ol0003o
ooooooooo`3?ooooo`002Oooool01?l0003oooooooooooooool^00000003o`000?lI6AWo6ATI017o
6ATI00<0000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00<0
IVIV00?o000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0
/k>c00?o00000<c<c03<c<`04@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI0080
VIVI00Go000007moO`1oOgl0Ogmoo`00000306IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c
<`0c<c<00P0c<c<00`00003o6ATIoaTI6@05oaTI6@/000001?ooool00ol0003oooooooooo`3?oooo
o`002Oooool01?l0003oooooooooooooool^00000003o`000?lI6AWo6ATI017o6ATI00<0000003<c
<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00<0IVIV00?o000007mo
O`1oOgl00P1oOgl00ol00000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00?o00000<c<
c03<c<`04@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007mo
O`1oOgl0Ogmoo`00000306IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<0
0`00003o6ATIoaTI6@05oaTI6@/000001?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0
003oooooooooooooool^00000003o`000?lI6AWo6ATI013o6ATI00<0000003<c<`0c<c<0200c<c<0
0ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl00`1oOgl0
1Ol00000VIVI09VIV@2IVIWo000000H0/k>c00?o00000<c<c03<c<`03`3<c<`00ol00000/k>c0;>c
/`030;>c/`05o`00002IVIT0VIVI09VIVOl00000101oOgl01Ol00000IVIV06IVIP1VIVKo000000<0
C4a<00?o000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@05oaTI6@/000001?ooool00ol0003o
ooooooooo`3?ooooo`002Oooool01?l0003oooooooooooooool^00000003o`000?lI6AWo6ATI013o
6ATI00<0000003<c<`0c<c<0200c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00<0
IVIV00?o000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0
/k>c0_l0000@0<c<c003o`00002c/k<0/k>c00<0/k>c00Go000009VIV@2IVIT0VIVIo`00000407mo
O`05o`00001VIVH0IVIV06IVI_l000000`1<C4`00ol00000<c<c03<c<`0303<c<`0300000?lI6AWo
6ATI00Go6ATI2`000004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?oooooooooo
ooooobh0000000?o0000oaTI6OlI6AT04?lI6AT00`000000<c<c03<c<`0803<c<`03o`00001<C4`0
C4a<00D0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0307moO`03o`00002IVIT0
VIVI0080VIVI00?o00000;>c/`2c/k<01@2c/k<00ol00000c<c<0<c<c00<0<c<c0;o00001@2c/k<0
1Ol00000VIVI09VIV@2IVIWo000000@0Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C003o`00
000c<c<0<c<c00<0<c<c00<00000oaTI6OlI6AT01OlI6AT;000000Cooooo00?o0000ooooooooool0
coooool000Wooooo00Co0000oooooooooooooooo;P0000000ol0003o6ATIoaTI6@0@oaTI6@030000
000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0306IVIP03o`00
001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`050;>c/`03o`00
003<c<`0c<c<00X0c<c<00?o00000;>c/`2c/k<0102c/k<00ol00000VIVI09VIV@0209VIV@03o`00
001oOgl0Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C003o`00000c<c<0<c<c00<0
<c<c00<00000oaTI6OlI6AT01OlI6AT;000000Cooooo00?o0000ooooooooool0coooool000Wooooo
00Co0000oooooooooooooooo;P0000000ol0003o6ATIoaTI6@0@oaTI6@030000000c<c<0<c<c00T0
<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00<0
Ogmo00?o000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`050;>c/`;o00002@3<c<`00ol00000
/k>c0;>c/`050;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmoo`00000306IV
IP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00`0c<c<00`00003o6ATIoaTI6@05oaTI
6@/000001?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003oooooooooooooool^0000
0003o`000?lI6AWo6ATI013o6ATI00?o000003<c<`0c<c<02@0c<c<00ol00000C4a<04a<C00504a<
C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0409VI
V@03o`00002c/k<0/k>c00H0/k>c2Ol000060;>c/`;o0000102IVIT00ol00000Ogmo07moO`0207mo
O`05o`00001VIVH0IVIV06IVI_l00000101<C4`00ol00000<c<c03<c<`0303<c<`0300000?lI6AWo
6ATI00Go6ATI2`000004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?oooooooooo
ooooobh0000000?o0000oaTI6OlI6AT04OlI6AT00`000000<c<c03<c<`0803<c<`03o`00001<C4`0
C4a<00D0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0
VIVI00@0VIVI00?o00000;>c/`2c/k<04`2c/k<00ol00000VIVI09VIV@0409VIV@03o`00001oOgl0
Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIVo`00000404a<C003o`00000c<c<0<c<c00<0<c<c00<0
0000oaTI6OlI6AT01OlI6AT;000000Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000
oooooooooooooooo;P0000000ol0003o6ATIoaTI6@0AoaTI6@030000000c<c<0<c<c00T0<c<c00?o
000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00@0Ogmo00?o
000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`0A0;>c/`03o`00002IVIT0VIVI00@0VIVI00?o
000007moO`1oOgl00P1oOgl01Ol00000IVIV06IVIP1VIVKo000000@0C4a<00?o000003<c<`0c<c<0
0`0c<c<00`00003o6ATIoaTI6@06oaTI6@/000001?ooool00ol0003oooooooooo`3?ooooo`002Ooo
ool01?l0003oooooooooooooool^00000003o`000?lI6AWo6ATI017o6ATI00<0000003<c<`0c<c<0
2@0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00@0IVIV0_l0000507moO`03o`00
002IVIT0VIVI00@0VIVI0_l0000@0;>c/`03o`00002IVIT0VIVI00@0VIVI00?o000007moO`1oOgl0
0P1oOgl00ol00000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<0
0`0c<c<00`00003o6ATIoaTI6@06oaTI6@/000001?ooool00ol0003oooooooooo`3?ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo0<oooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool0coooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`3?ooooo`002Ooooonfo`000=7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0009
oooookKo00004Ooooonf000000[ooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo00gooooo00<0003oooooooooool04_ooool00`000?ooooooooooo`15ooooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`03ooooo`80
00002?ooool2000000Wooooo1@000007ooooo`8000001_ooool2000000Oooooo00?o0000oooooooo
ool03Oooool3000000[ooooo0P00000Qooooo`0300000?l0003o000001Gooooo0P00000Gooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00cooooo00<0003oooooooooool0
4oooool00`000?ooooooooooo`15ooooo`03o`00oooooooooooo03[ooooo00<0003oooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo0`00000@ooooo`<00000
1_ooool2000000Kooooo00<00000ooooooooool01Oooool00ol000000000ooooo`0?ooooo`<00000
1Oooool2000002;ooooo00<00000ooooooooool06?ooool2000001Gooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`0Eooooo`030000oooo
oooooooo04Cooooo00<0003oooooooooool0>_ooool00`000?ooooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo00D00000oooooooooooooooo00000006ooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool01?ooool2000001Kooooo0`000005ooooo`8000001Oooool2000000Oooooo
0P00000Aooooo`D000008oooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo01;ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02_ooool00`000?oooooooooo
o`0Gooooo`030000oooooooooooo04?ooooo00<0003oooooooooool0>_ooool00`000?oooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00D00000oooooooooooooooo00000005ooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`05ooooo`03o`00
00000000000000P0000000?o0000ooooooooool01_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0eooooo`030000
0?oooooooooo01gooooo00?o0000ooooooooool04Oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`09ooooo`030000oooooooooooo01Wooooo00<0003oooooooooool0@Ooo
ool00`000?ooooooooooo`0looooo`030000oooooooooooo00Oooooo00?o0000ooooooooool03ooo
ool01000003oooooooooo`000005ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
0_ooool00ol000000000ooooo`03ooooo`<0000000?o0000ooooooooool02_ooool5000000Cooooo
0P000005ooooo`03o`0000000000000000Cooooo00<00000o`000?ooool01Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01kooooo0P00000Aooooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool06oooool00`000?oooooooooo
o`10ooooo`030000oooooooooooo03cooooo00<0003oooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooo000000Kooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00;ooooo0P00000Eooooo`<000000oooool2000000Kooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo03?ooooo00<0
0000ooooooooool08Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool06oooool00`000?ooooooooooo`10
ooooo`030000oooooooooooo03cooooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01_ooool<000000Kooooo00<00000
ooooooooool00_ooool3000000Cooooo00?o0000ooooooooool00oooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo037ooooo00<00000ooooooooool08oooool00ol0003oooooooooo`0=
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00<0003ooooo
ooooool06Oooool80000ockooooo00<0003oooooooooool0:oooool5o`00o`cooooo00<0003ooooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00`00003o00000000000<ooooo`<000001?ooool00ol00000000000000004oooo
o`03o`000?oooooooooo00;ooooo0P000004ooooo`0300000?oooooooooo00Cooooo00<00000o`00
0?ooool0;oooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00`000?ooooooooooo`0Gooooo`80
003o1Oooool00`000?ooooooooooo`030000oc[ooooo00<0003oooooooooool09oooool5o`00o`Go
oooo1Ol00?l8ooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00;ooooo00D00000ooooooooooooooooo`000005oooo
o`0300000?oooooooooo00;ooooo0P00000Booooo`<000001?ooool00`00003oooooooooo`02oooo
o`8000001?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool0;Oooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`0Eooooo`<0
003o2?ooool00ol00?ooooooooooo`02ooooo`03o`00o`000?oooooo03Oooooo00<0003ooooooooo
ool08oooool4o`00o`oooooo1_l00?l2ooooo`030000oooooooooooo00Kooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo00D00000oooooooo
oooooooo00000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01oooool80000
00Kooooo00<00000ooooooooool00_ooool2000000Cooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0:oooool00`00
003oooooooooo`0Wooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`0Dooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0eooooo`030000oooooooooooo027o
oooo0_l00?lIooooo`;o003o00<0003oooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo00?ooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool00000
00Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`@000002?ooool20000
00Gooooo00?o0000ooooooooool00oooool00`00003oooooooooo`02ooooo`05o`000?oooooooooo
ooooo`0000001Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02Wooooo00<00000
ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Kooooo00<0003oooooooooool04oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Gooooo00<0003oooooooooool0=?ooool00`000?ooooooooooo`0Loooo
o`?o00000_l00?lMooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`02ooooo`03o`000000003ooooo00?ooooo00D00000oooooooooooooooo00000003
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool00_ooool3000000kooooo0P000004
ooooo`<000000oooool01?l000000000ooooooooool2000000?ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00<00000ooooooooool0:ooo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo00Gooooo00<0003oooooooooool04oooool00`000?ooooooooooo`0;ooooo`030000oooooooo
oooo00Kooooo00<0003oooooooooool0<oooool00`000?ooooooooooo`0Kooooo`Go00007_ooool0
0`000?oo003oooooo`06ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`03ooooo`0500000?ooooooooooooooo`0000000oooool01@00003ooooooooo
oooooooo000000Cooooo00<00000ooooooooool04Oooool3000000Cooooo00<00000ooooooooool0
0_ooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo02Oooooo00<00000ooooooooool0:oooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo
00<0003oooooooooool03_ooool3o`000003ooooo`000?oooooo00gooooo00<0003oooooooooool0
1oooool00`000?ooooooo`00o`04o`00obkooooo00<0003oooooooooool06oooool5o`0001kooooo
00@0003oooooool00?oo003o1Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0000000?ooooo00<00000oooo
ooooool00_ooool01@00003oooooooooooooool0000000Sooooo20000007ooooo`8000000oooool0
0`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool2000000Cooooo00<0
0000ooooooooool01?ooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo02gooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05
ooooo`030000oooooooooooo00gooooo1Ol0000?ooooo`030000oooooooooooo00Gooooo0ol00?l0
0`000?ooooooooooo`03ooooo`Co003o:_ooool00`000?ooooooooooo`0Jooooo`03o`00ool0003o
000000?o00007_ooool010000?ooooooooooooooool2o`00o`?ooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo
00000003ooooo`0500000?ooooooooooooooo`0000000oooool00ol0003oooooooooo`03ooooo`@0
00002?ooool4000000Gooooo00@00000oooooooooooooooo0P000003ooooo`0500000?oooooooooo
ooooo`0000001?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000
ooooooooool09?ooool00ol0003oooooooooo`0^ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0=oooo
o`Go00003oooool00`000?ooooooooooo`03ooooo`;o003o0oooool00`000?ooooooooooo`07oooo
o`;o003o:?ooool00`000?ooooooooooo`0Iooooo`03o`00oooooooooooo00?o00007oooool00`00
0?ooooooooooo`03ooooo`04o`00ooooooooooooo`00017ooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool01@00003ooooooooo
ooooool0000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0>ooooo`800000
1?ooool00`00003oooooooooo`02ooooo`0400000?oooooooooo000000?ooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09?ooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0=ooooo`Go0000
3oooool010000?ooooooooooooooool2o`00o`Kooooo00<0003oooooooooool02?ooool00ol00?oo
ooooooooo`0Uooooo`030000oooooooooooo01Sooooo00?o003oooooooooool08oooool00`000?oo
ooooooooo`04ooooo`03o`00oooooooo0000017ooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0
000000?ooooo00D00000oooooooooooooooo0000000Cooooo`0300000?oooooooooo00;ooooo00D0
0000oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`0000001?ooool01@00003o
ooooooooooooool0000000Kooooo00<00000ooooooooool09?ooool00`00003oooooooooo`0_oooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool01Oooool00`000?ooooooooooo`0>ooooo`?o00004?ooool010000?ooooooooooool00?l9oooo
o`030000oooooooooooo00Sooooo00?o003oooooooooool09?ooool00`000?ooooooooooo`0Goooo
o`03o`00oooooooooooo02?ooooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000003ooooo`0500000?oooooo
ooooooooo`0000000oooool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool0
1_ooool5000000Oooooo00?o0000ooooooooool00_ooool01@00003oooooooooooooool0000000?o
oooo00D00000oooooooooooooooo00000004ooooo`05o`000?ooooooooooooooo`0000001_ooool0
0`00003oooooooooo`0Rooooo`0300000?oooooooooo033ooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000oooooooooooo
00oooooo00<0003oooooooooool03oooool00`000?ooooooo`00o`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool08oooool00`000?ooooooooooo`0Fooooo`03o`00oooooooooooo
02Cooooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo
00;ooooo00D00000oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`0000000ooo
ool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool01Oooool00ol000000000
ooooo`04ooooo`<000001Oooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooool0
00000oooool01Ol0003oooooooooooooool0000000?ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo027ooooo00<00000ooooooooool0<Oooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Go
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`0@ooooo`;o003o3?ooool00`000?oo
ooooooooo`09ooooo`;o003o8oooool00`000?ooooooooooo`0Fooooo`03o`00oooooooooooo02Co
oooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;o
oooo00D00000oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`0000000oooool0
1@00003oooooooooooooool0000000?ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`08ooooo`8000001?ooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`000000
0oooool01000003oooooooooo`000003ooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo037ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000
oooooooooooo00kooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`0;ooooo`030000
oooooooooooo00_ooooo00?o003oooooooooool08?ooool00`000?ooooooooooo`0Fooooo`03o`00
oooooooooooo02Cooooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo00;ooooo00D00000oooooooooooooooo00000003ooooo`0500000?oooooooooooooo
o`0000000oooool01000003oooooooooo`000003ooooo`0300000?oooooooooo00Cooooo00<00000
ooooooooool02oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00Co0000
ooooooooool000000oooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool0
0_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo023ooooo00<00000ooooooooool0
<_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00Kooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`0@ooooo`030000oooo
oooooooo00_ooooo00<0003oooooooooool02oooool00ol00?ooooooooooo`0Qooooo`030000oooo
oooooooo01Cooooo00?o003oooooooooool09Oooool00`000?ooooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0000000?ooooo
00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000?ooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool00_ooool01000003oooooooooo`000003ooooo`0500000?ooooooooooooooo`0000000ooo
ool01@00003oooooooooooooool0000000Kooooo00<00000ooooooooool08?ooool00`00003ooooo
ooooo`0booooo`0300000?oooooooooo00Cooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool01_ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo013ooooo00<0
003oooooooooool03Oooool00`000?ooooooooooo`0;ooooo`03o`00oooooooooooo023ooooo00<0
003oooooooooool04oooool00ol00?ooooooooooo`0Uooooo`030000oooooooooooo00Sooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`000000
0oooool01@00003oooooooooooooool0000000?ooooo00@00000ooooooooool000000oooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`02ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo0000
0003ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00`00003ooooooooo
o`0Pooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`030000oooooooooooo00_ooooo00<0003o
ooooooooool03Oooool3o`00013ooooo00<0003oooooooooool03?ooool00ol00?ooooooooooo`0P
ooooo`030000oooooooooooo017ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00_ooool01@00003ooooooooooooo
ool0000000?ooooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000?o
oooo00<00000ooooooooool00oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00;o
oooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000?ooooo00D00000
oooooooooooooooo00000004ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool07ooo
ool00`00003oooooooooo`0booooo`0300000?oooooooooo00Cooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool01oooool00`000?ooooooooooo`0;ooooo`030000oooooooo
oooo00cooooo1Ol0000?ooooo`030000oooooooooooo00cooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo02Kooooo00<0003oooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool0
1@00003oooooooooooooool0000000?ooooo00@00000ooooooooool000000oooool01@00003ooooo
ooooooooool0000000Cooooo00<00000ooooooooool03_ooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00;ooooo00@00000ooooooooool000000oooool01@00003oooooooooooooool0
000000?ooooo00D00000oooooooooooooooo00000006ooooo`0300000?oooooooooo01oooooo00<0
0000ooooooooool0<oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0<
ooooo`Go00003oooool00`000?ooooooooooo`0<ooooo`03o`00oooooooooooo023ooooo00<0003o
ooooooooool04?ooool00ol00?ooooooooooo`0Wooooo`030000oooooooooooo00Sooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`02ooooo`0300000?l0003ooooo00;ooooo00D00000
oooooooooooooooo00000003ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooo
oooo00000004ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool00_ooool01@00003o
ooooooooooooool0000000?ooooo00@00000ooooooooool000000oooool01@00003ooooooooooooo
ool0000000?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Oooooo`0300000?oo
oooooooo03?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`08ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03?ooool5
o`0000oooooo00<0003oooooooooool03Oooool00ol00?ooooooooooo`0Pooooo`030000oooooooo
oooo00oooooo00?o003oooooooooool09_ooool00`000?ooooooooooo`09ooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool00oooool01@00003oooooooooooooool0000000?ooooo00D0
0000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000oooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool00_ooool01@00003o
ooooooooooooool0000000?ooooo00@00000ooooooooool000000oooool01@00003ooooooooooooo
ool0000000?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Oooooo`0300000?oo
oooooooo03?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03Oooool3
o`00013ooooo00<0003oooooooooool03Oooool00ol00?ooooooooooo`0Pooooo`030000oooooooo
oooo00kooooo00?o003oooooooooool09oooool00`000?ooooooooooo`09ooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool01?ooool01@00003oooooooooooooool0000000?ooooo00D0
0000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000oooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`02ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000000oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool07_ooool0
0`00003oooooooooo`0cooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool02_ooool20000o`Wooooo00<0003oooooooooool02oooool20000
o`03ooooool00?oooooo013ooooo00<0003oooooooooool03Oooool01?l00?oooooooooooooooolI
0?nf`@Oooooo00<0003oooooooooool03?ooool00ol00?ooooooooooo`0Wooooo`030000oooooooo
oooo00[ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`04ooooo`0500000?oooooo
ooooooooo`0000000oooool01@00003oooooooooooooool0000000?ooooo00D00000oooooooooooo
oooo00000003ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo00;ooooo00@00000ooooooooool000000oooool01000
003oooooooooo`000003ooooo`0300000?oooooooooo0080okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@0=0?nf`A7ooooo00<00000ooooooooool0<oooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00cooooo00<0003ooooo
ooooool01_ooool00`000?ooooooooooo`0:ooooo`050000ooooooooooooooooool00?l03oooool3
o`0000oooooo00?o003o0?nf`@3o]/407@3o]/44ooooo`030000oooooooooooo00cooooo00?o003o
ooooooooool09oooool00`000?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool01?ooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`0500000?ooooooooooooooo`0000001Oooool00ol00000
0000ooooo`0;ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool01000003o
ooooooooo`000003ooooo`0400000?oooooooooo000000?ooooo00<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK10100okK13_ooool00`00003oooooooooo`0c
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool03Oooool20000o`Oooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`02oooo
o`03o`00oooooooooooo00cooooo1Ol0000<ooooo`80okK100?o003o0?nf`@3o]/40803o]/42oooo
o`030000oooooooooooo00_ooooo00?o003oooooooooool09_ooool00`000?ooooooooooo`0;oooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool01?ooool00`00003oooooooooo`02oooo
o`0500000?ooooooooooooooo`0000000oooool01000003oooooooooo`000004ooooo`0500000?oo
ooooooooooooo`0000001_ooool2000000Wooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`02ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000000`3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/404`3o]/4;oooo
o`0300000?oooooooooo03?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0?ooooo`<0003o1?ooool00`000?ooooooooooo`06ooooo`80
003o1?ooool00ol00?ooooooooooo`0=ooooo`Go00002Oooool50?nf`@03o`00o`3o]/40okK102<0
okK100<0003oooooooooool02Oooool00ol00?ooooooooooo`0Vooooo`030000oooooooooooo00co
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00;o
oooo00@00000ooooooooool000001?ooool01000003oooooooooo`000003ooooo`0300000?oooooo
oooo00;ooooo00<00000ooooooooool01Oooool2000000Kooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003ooooo0?nf
`@3o]/40000000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK101H0okK12Oooool00`00003oooooooooo`0booooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool04_ooool01@000?oooooooooo
ooooool0003o00Kooooo0P000?l6ooooo`03o`00oooooooooooo00gooooo1Ol00006ooooo`P0okK1
00?o003o0?nf`@3o]/40903o]/400`000?l0okK1ooooo`08ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool03Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0000000Gooooo
00<00000ooooooooool00_ooool01Ol0003oooooooooooooool0000000?ooooo00D00000oooooooo
oooooooo00000003ooooo`0300000?oooooooooo00;ooooo0P000007ooooo`0300000?l000000000
00<000001oooool00`00003oooooooooo`02ooooo`0800000?ooooooooooooooo`00003ooooo0?nf
`@0000030?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK101T0okK11_ooool00`00003oooooooooo`0booooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool04oooool00ol00?l0003o
0000o`060000o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool3o`0000Cooooo
2`3o]/400ol00?l0okK10?nf`@0T0?nf`@03o`00o`3o]/40okK10080okK11_ooool00ol00?oooooo
ooooo`0Tooooo`80003o3oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0000000Gooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0400000?oooooooooo000000Co
oooo00H00000ooooooooooooooooo`0000000004ooooo`0300000?oooooooooo017ooooo00<00000
ooooooooool00_ooool01@00003oooooooooo`3o]/4000000080okK100D000000?nf`@3o]/40okK1
000000030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/400`000000okK1
0?nf`@0L0?nf`@?ooooo00?o0000ooooooooool0<_ooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo00<0003oooooooooool02ooo
ool00ol00?ooooooooooo`0>ooooo`040000ooooooooooooooooo`h0okK100?o003o0?nf`@3o]/40
9@3o]/400`000?l0okK10?nf`@020?nf`@Gooooo00?o003oooooooooool08oooool00`000?oooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000001Oooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo00;ooooo00@00000ooooooooool000001?ooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo0`00000>ooooo`8000001?ooool01@00
0000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0N0?nf`@;ooooo00<0
0000ooooooooool0<_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01Sooooo00<0003oooooooooool02oooool00ol00?ooooooooooo`0<
ooooo`040000ooooooooooooooooo`l0okK100?o003o0?nf`@3o]/409P3o]/400`000?l0okK10?nf
`@020?nf`@Cooooo00?o003oooooooooool08_ooool00`000?ooooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00@00000ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`030000
0?oooooooooo00;ooooo00D00000ooooooooool00000o`000003ooooo`03o`000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool4000000Sooooo00?o000000000?ooool00oooool2000000<0
okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@000000103o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK101l0okK10_ooool00`00003oooooooooo`0a
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool06Oooool00`000?ooooooooooo`0:ooooo`03o`00oooooooooooo00_ooooo00<0003ooooo
ooooool0403o]/400ol00?l0okK10?nf`@0X0?nf`@030000o`3o]/40okK100@0okK100?o003ooooo
ooooool08_ooool00`000?ooooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00@00000oooo
ooooool000001_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01@00003oooooooooooooool0000000Cooooo00?o000000000?ooool01ooo
ool8000000Gooooo00<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000<0okK1
00D000000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o
]/408@3o]/400`00003oooooooooo`0aooooo`0300000?oooooooooo00?ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool06_ooool00`000?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooo`3o]/404@3o]/400ol00?l0okK10?nf`@0Y0?nf`@80003o
103o]/400ol00?l0okK1ooooo`0Pooooo`80003o5?ooool00ol0003oooooooooo`0?ooooo`040000
0?oooooooooo000000Oooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00;ooooo00@00000oooooooooooooooo0P000004ooooo`0300000?oooooooooo
017ooooo00<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000<0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/408P3o]/400`000000okK1ooooo`0`ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool00ol00?l0003oooooo`09oooo
o`03o`00oooooooooooo00Oooooo0P000?l00oooool0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK1
02/0okK100D0003o0?nf`@3o]/40okK1o`00o`020?nf`Acooooo0ol000000`000?ooooooooooo`0D
ooooo`03o`000?oooooooooo00oooooo00D00000oooooooooooooooo00000006ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool00_ooool3000000kooooo0P0000050?nf`@030000003o
]/40okK10080okK100Go00000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0S0?nf`@030000003o]/40okK102oooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Mooooo`80003o2Oooool00ol00?ooooooooooo`05ooooo`030000oooooooooooo01<0okK100?o
003o0?nf`@3o]/40;@3o]/4010000?l0okK10?nf`Ol00?l30?nf`A[ooooo1Ol0000Fooooo`03o`00
0?oooooooooo00oooooo00D00000oooooooooooooooo00000007ooooo`0300000?oooooooooo00;o
oooo0P000004ooooo`8000000oooool00ol0003oooooooooo`02ooooo`0300000?l00000000000Co
oooo10000006ooooo`@000001P3o]/400ol00000okK10?nf`@020?nf`@050000003o]/40okK10?nf
`@000000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/40903o]/400`000000okK10?nf`@0^ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool07oooool00`000?ooooooooooo`06ooooo`03
o`00oooooooooooo00Cooooo00<0003oooooooooool0503o]/400ol00?l0okK10?nf`@0^0?nf`@03
0000o`3o]/7o003o00@0okK16Oooool5o`0001Kooooo00?o0000ooooooooool03oooool01@00003o
ooooooooooooool0000000Sooooo00?o0000ooooooooool00oooool00`00003oooooooooo`03oooo
o`0500000?ooooooooooooooo`0000001_ooool00`00003oooooooooo`05ooooo`H000000oooool5
0?nf`@800000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK102D0okK100?o0000
0?nf`@3o]/40;Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo023ooooo0`000?l5ooooo`04o`00ooooooooooooooooo`<0003o00?ooooo
0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0_0?nf`@<0003o1@3o]/4Gooooo`Go00005_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00?ooooo00@00000oooooooooooooooo0`00
0004ooooo`<000002oooool50?nf`@8000001@3o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK10080okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o
]/40okK102H0okK100<000000?nf`@3o]/400P3o]/4Zooooo`0300000?oooooooooo00Gooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08oooool00`000?oo003o0000o`04
0000o`03o`00o`000?oooooo00;ooooo5@3o]/42o`00oc<0okK100Co003o0?nf`@000?l0003o103o
]/4Dooooo`80003o00Coooooo`000?l0003o00005oooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo00;ooooo00<00000o`000?ooool01_ooool00`00003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`04ooooo`800000
00?o000000000?ooool01Oooool20?nf`@@000001@3o]/400`00003o00000?nf`@030?nf`@03o`00
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK102P0okK100<000000?nf`@3o]/400P3o]/4Xooooo`03o`000?oooooooooo00Kooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:oooool00ol00?oooooooooo
o`0E0?nf`@03o`00o`3o]/40okK103<0okK100Co003o0?nf`@3o]/40okK10`000?l20?nf`A3ooooo
0`000?lMooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`05ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`03ooooo`03o`0000000000000000Oooooo200000080?nf`@030000003o]/40okK10080okK1
0P0000040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK1
0?nf`@0X0?nf`@030000003o]/40okK100<0okK19oooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02cooooo00?o003o0?nf`@3o]/404`3o
]/400ol00?l0okK10?nf`@0d0?nf`@03o`00o`3o]/40okK100@0okK11@000?l8ooooo`D0003o8?oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01Ooo
ool3000000Sooooo2@3o]/43000000@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40:P3o]/400`000000okK10?nf
`@030?nf`BKooooo00<00000ooooooooool01_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0/ooooo`030?nf`Ol00?l0okK10180okK100?o003o0?nf`@3o]/40=P3o]/40
0ol00?l0okK10?nf`@070?nf`@03ooooo`000?l0003o00H0003o9Oooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01oooool00`00003oooooooooo`04
ooooo`8000001Oooool3000000Oooooo10000003ooooo`H0okK1100000060?nf`@030000003o]/40
okK100<0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK102/0okK100<000000?nf`@3o]/400`3o]/4Tooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:oooool30?nf`@03o`00o`3o]/40okK1
00l0okK100?o003o0?nf`@3o]/40=`3o]/400ol00?l0okK10?nf`@080?nf`Bgooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Sooooo00<00000o`00
000000001P0000080?nf`@8000001@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/40;@3o]/400ol0000000000?nf`@030?nf`B;ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Zooooo`@0
okK10ol00?l=0?nf`@;o003o>P3o]/400ol00?l0okK10?nf`@080?nf`Bgooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`05ooooo`03o`0000000000000000Sooooo3`3o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000
okK10?nf`@0_0?nf`@040000003o]/40okK10?nf`B7ooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Zooooo`L0okK11Ol00?l40?nf`@Co
003o?03o]/400ol00?l0okK10?nf`@090?nf`Bcooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool2000000So
oooo0`000005ooooo``0okK10`0000050?nf`@8000001P3o]/400`000000okK10?nf`@050?nf`@03
0000003o]/40okK10340okK100@000000?nf`@3o]/40okK17oooool00`00003oooooooooo`0:oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Wooooo3@3o]/44o`00od00
okK100?o003o0?nf`@3o]/402P3o]/4[ooooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<00000oooooooo
ool02?ooool7000000<0okK11`0000070?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o
]/401@3o]/400`000000okK10?nf`@0c0?nf`@040000003o]/40okK10?nf`Akooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Xoooooe<0
okK100?o003o0?nf`@3o]/402P3o]/4Zooooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`0:ooooo`0300000?l0003ooooo00Sooooo0`00000:ooooo`@0
okK10`00000;0?nf`@80000000?o00000?nf`@3o]/40103o]/42000000H0okK100<00000o`00003o
]/40=P3o]/4200000080okK16oooool2000000gooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool09ooooomD0?nf`@03o`00o`3o]/40okK100/0okK1:Oooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0:ooooo`@000001Oooool?0?nf`@@000001`3o]/42000000L0okK100<000000?nf`@3o]/40
403o]/45000002@0okK10P0000000`3o]/7oooooooooo`0Fooooo`8000003oooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0VoooooeD0okK100?o003o0?nf`@3o]/402`3o
]/4Yooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`0=ooooo`0300000?oooooooooo00gooooo0`0000000oooool0okK10?nf`@0;0?nf`@<000002P3o
]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100h0okK10`0000050?nf`@<000008`3o
]/400`00003oooooooooo`0Dooooo`8000004Oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0VoooooeH0okK100?o003o0?nf`@3o]/402`3o]/4Xooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`0300000?oooooo
oooo00oooooo300000000ol0000000000?nf`@0:0?nf`@800000203o]/400ol00000okK10?nf`@0=
0?nf`@8000002`3o]/400`000000okK10?nf`@0Q0?nf`@0400000?l0000000000000013ooooo0P00
000Cooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02GoooooE`3o]/40
0ol00?l0okK10?nf`@0<0?nf`BOooooo00?o0000ooooooooool03oooool01@00003ooooooooooooo
ool00000017ooooo00<00000ooooooooool03ooooolG0?nf`@8000002@3o]/400`000000okK10?nf
`@0=0?nf`@030000003o]/40okK100`0okK100?o00000?nf`@3o]/408P3o]/42ooooo`<000002Ooo
ool4000001Gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09?oooomI
0?nf`@03o`00o`3o]/40okK100/0okK19oooool00ol0003oooooooooo`0?ooooo`0400000?oooooo
oooo000001?ooooo00<00000ooooooooool03OoooolF0?nf`@8000002@3o]/42000000l0okK100<0
00000?nf`@3o]/403P3o]/400`000000okK10?nf`@0Q0?nf`@Gooooo2@00000Iooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo02CoooooF@3o]/400ol00?l0okK10?nf`@0<
0?nf`BKooooo00?o0000ooooooooool03oooool00`00003ooooo0000000Eooooo`0300000?oooooo
oooo00cooooo4`3o]/43000000X0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@0@
0?nf`@030000003o]/40okK10240okK19_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0SoooooeX0okK100?o003o0?nf`@3o]/40303o]/4Vooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0:ooooo`l0okK11@00000:0?nf
`@0300000?l00000000000l0okK10P00000D0?nf`@030000003o]/40okK10200okK19_ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Soooooe/0okK100?o003o0?nf`@3o
]/40303o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`09ooooo``0okK10`00000>0?nf`@030000003o]/40okK100h0okK10P00000G0?nf`@03
0000003o]/40okK10200okK19Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Roooooed0okK100?o003o0?nf`@3o]/40303o]/4Tooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool06?ooool00`00003oooooooooo`07ooooo`80okK12`00000?0?nf`@800000
403o]/400ol00000okK10?nf`@0H0?nf`@030000003o]/40okK10200okK19?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Qoooooel0okK100?o003o0?nf`@3o]/402`3o
]/4Tooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool06Oooool00ol0003ooooooooo
o`08000001P0okK10P00000A0?nf`@030000003o]/40okK101X0okK100<000000?nf`@3o]/407`3o
]/4Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027oooooH03o]/40
0ol00?l0okK10?nf`@0;0?nf`B?ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0C
ooooo`D0000000Go0000oooooooooooooooo00000004oooooaT0okK10P00000B0?nf`@030000003o
]/40okK101`0okK100?o00000?nf`@3o]/407`3o]/4Sooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00;ooooo2P000?lDooooof80okK100?o003o0?nf`@3o]/402P3o]/4S
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool03?ooool7000000Wooooo00@00000
oooooooooooooooo6@3o]/400`000000okK10?nf`@0@0?nf`@8000007`3o]/400`000000okK10?nf
`@0O0?nf`B?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`000?l00P000?l:
ooooo`<0003o4OoooomS0?nf`@03o`00o`3o]/40okK100X0okK18?ooool00ol00?ooooooo`00000A
ooooo`0300000?oooooooooo00Wooooo0`00000?ooooo`0300000?oooooooooo00;ooooo5`3o]/42
00000180okK100<000000?nf`@3o]/40803o]/400`000000okK10?nf`@0O0?nf`B;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool03oooool30000o`goooooI@3o]/400ol0
0?l0okK10?nf`@0:0?nf`Akooooo00Co003ooooooooooooo00004Oooool00`00003oooooooooo`05
ooooo`0400000?l000000000000001;ooooo00@00000oooooooooooooooo5@3o]/4300000180okK1
00<00000o`00003o]/408`3o]/400`00003o00000?nf`@0O0?nf`B7ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool04_ooool20000o`[oooooI`3o]/400ol00?l0okK10?nf
`@090?nf`Acooooo0_l00?l3ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00ooo
ool2000001Oooooo00<00000ooooo`3o]/40503o]/400`000000okK10?nf`@0B0?nf`@030000003o
]/40okK102H0okK100<000000?nf`@3o]/407@3o]/4Qooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01Cooooo00<0003oooooooooool01ooooomX0?nf`@;o003o2P3o]/4J
ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03oooool01000003ooooooooooooo
ool2000001[ooooo00<000000?nf`@3o]/404P3o]/400`000000okK10?nf`@0B0?nf`@030000003o
]/40okK102P0okK100<000000?nf`@3o]/407@3o]/4Pooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01Gooooo00<0003oooooooooool01Ooooom[0?nf`@;o003o203o]/4H
ooooo`;o003o1_ooool00ol0003oooooooooo`0?ooooo`0400000?ooool00000000001cooooo00<0
okK10000003o]/40403o]/400ol0000000000?nf`@0B0?nf`@0300000?l00000okK102/0okK100<0
00000?nf`@3o]/40703o]/4Pooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01Kooooo00<0003oooooooooool01?oooolg0?nf`@L0oooo;`3o]/400ol00?l0okK10?nf`@05
0?nf`AOooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo01gooooo0P3o]/400ol00000okK10?nf`@0>0?nf`@030000003o]/40okK10140okK100<00000
0?nf`@3o]/403@3o]/470?oooaT0okK100?o00000000003o]/406`3o]/4Pooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo01Kooooo00<0003oooooooooool01?oooolc0?nf
`@l0oooo;03o]/42o`00o`H0okK15Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool07Oooool20?nf`@030000003o]/40okK100h0okK100<000000?nf
`@3o]/40403o]/400`000000okK10?nf`@0:0?nf`@l0oooo5`3o]/400`000000okK10?nf`@0J0?nf
`Aoooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05oooool00`000?oo
ooooooooo`02oooooc80okK14`3oool/0?nf`@;o003o103o]/4Aooooo`Co003o2_ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo01cooooo103o]/400`000000okK10?nf`@0<0?nf`@03
0000003o]/40okK10100okK100?o00000?nf`@3o]/402@3o]/4C0?oooaH0okK100<000000?nf`@3o
]/406@3o]/4Oooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo
00<0003oooooooooool00_ooool`0?nf`AL0oooo;03o]/44o`00o`gooooo1?l00?l>ooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool07?ooool50?nf`@030000003o]/40okK100/0okK1
00<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@080?nf`AL0oooo5@3o]/400ol000000000
0?nf`@0H0?nf`Aoooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06?oo
ool010000?ooooooooooooooool_0?nf`AX0oooo;P3o]/4=o`00oa;ooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`08ooooo`P000003?ooool50?nf`@030000003o]/40okK100/0okK1
00<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@070?nf`AX0oooo5@3o]/400`000000okK1
0?nf`@0G0?nf`A_ooooo0P0000000oooool00000ooooo`09ooooo`002Oooool00ol0003ooooooooo
o`0Iooooo`030000ooooool0okK102h0okK1703oool^0?nf`Akooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`05ooooo`<000002?ooool4000000Oooooo1`3o]/400`000000okK10?nf
`@0:0?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/401`3o]/4L0?oooaD0okK10`00
000F0?nf`A[ooooo00D00000oooooooooooooooo0000000:ooooo`002Oooool00ol0003ooooooooo
o`0Iooooo`030000ooooool0okK102d0okK17P3oool]0?nf`Akooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`03ooooo`8000003oooool3000000Cooooo203o]/400ol00000okK10?nf
`@090?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/401`3o]/4N0?oooaL0okK100<0
00000?nf`@3o]/404`3o]/4Gooooo`80000000?o0000ooooooooool00_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`030000ool00?l0okK102/0okK1803oool/
0?nf`Akooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo01;ooooo00@00000oooooooooooooooo203o]/400`000000okK10?nf`@090?nf`@030000003o
]/40okK100d0okK100<000000?nf`@3o]/401P3o]/4P0?oooaH0okK100?o00000000000000004`3o
]/4Fooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool06oooool00`000?l0okK10?nf`@0Z0?nf`B00oooo;03o]/4Nooooo`03o`000?oooooo
oooo00oooooo00D00000oooooooooooooooo0000000Fooooo`80000000?ooooo0?nf`@3o]/401`3o
]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/401P3o
]/4P0?oooaT0okK10`00000@0?nf`ACooooo0P000008ooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01Cooooo1ol00?l00`000?oo003o0?nf`@0X0?nf`B<0oooo:`3o]/4N
ooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000006Oooool00`000000okK10?nf
`@070?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/40303o]/400ol00000okK10?nf
`@040?nf`B<0oooo6`3o]/42000000h0okK14_ooool2000000[ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool04?ooool4o`00o`Oooooo00<0okK10000ool00?l00_l00?lU
0?nf`BD0oooo:`3o]/4Mooooo`03o`000?oooooooooo00oooooo00<00000ooooool000006oooool0
0`000000okK10?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o]/40
0`000000okK10?nf`@030?nf`BD0oooo703o]/43000000`0okK13oooool2000000cooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool03?ooool4o`00o`[ooooo0P3o]/401000
0?l0okK10?nf`@3o]/43o`00ob80okK19@3oool[0?nf`Agooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`0Jooooo`80okK100<000000?nf`@3o]/401`3o]/400ol00000okK10?nf`@07
0?nf`@030000003o]/40okK100`0okK100<000000?nf`@3o]/400`3o]/4U0?oooal0okK10`000009
0?nf`@_ooooo1000000>ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00[ooooo0_l00?l>ooooo`80okK100<0003o0?nf`@3o]/40103o]/400ol00?l0okK10?nf`@0N0?nf
`BL0oooo:P3o]/4Mooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool06_ooool30?nf
`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@0<0?nf
`@030000003o]/40okK10080okK19`3ooolQ0?nf`A@000004_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00kooooo0P3o]/400`000?l0
okK10?nf`@050?nf`@03o`00o`3o]/40okK101d0okK19`3ooolZ0?nf`Agooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`0Jooooo`@0okK100<000000?nf`@3o]/401P3o]/400`000000
okK10?nf`@060?nf`@0300000?l00000okK100`0okK100<000000?nf`@3o]/400P3o]/4W0?ooobX0
okK17Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00oooooo0`3o]/400`000?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK101/0okK1
:@3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0<ooooo`@00000
2_ooool40?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@0;0?nf`@040000003o]/40okK10?nf`BT0oooo:@3o]/4Mooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00Gooooo0ol000000ol00?ooooooooooo`0?ooooo`<0okK1
00<0003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0J0?nf`BT0oooo:@3o]/4Mooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool02Oooool3000000Cooooo0`000007ooooo`D0okK1
00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100/0okK1
00@000000?nf`@3o]/40okK1:@3ooolY0?nf`Agooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01?ooool5o`00017ooooo0`3o]/400`000?l0okK10?nf`@070?nf`@03o`00
o`3o]/40okK101T0okK1:@3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`07ooooo`8000002_ooool00`00003oooooooooo`04ooooo`D0okK100<000000?nf`@3o]/40
1P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100X0okK100@000000?nf`@3o]/40
okK1:@3ooolY0?nf`Agooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
1?ooool5o`00017ooooo0`3o]/400`000?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK101P0okK1
:@3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool00oooool60?nf`@030000003o]/40okK100H0okK1
00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@0:0?nf`@040000003o]/40okK10?nf`BT0
oooo:@3o]/4Mooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo
1Ol0000Aooooo`<0okK100<0003o0?nf`@3o]/402@3o]/400ol00?l0okK10?nf`@0F0?nf`B/0oooo
:03o]/4Mooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`0300000?oooooooooo00?ooooo1P3o]/400`000000okK10?nf`@060?nf`@030000
003o]/40okK100H0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0[0?ooobP0okK1
7Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`?o00004_oo
ool20?nf`@030000o`3o]/40okK100X0okK100?o003o0?nf`@3o]/405P3o]/4[0?ooobP0okK17Ooo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`02ooooo`H0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@060?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/40:`3ooolX0?nf`Agooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0B
ooooo`<0okK100<0003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@0E0?nf`B/0oooo:03o]/4M
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0>
ooooo`0300000?oooooooooo00P0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@07
0?nf`@030000003o]/40okK100X0okK100<000000?nf`@3oool0:P3ooolX0?nf`Agooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Coooo
o`<0okK100<0003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0D0?nf`B/0oooo:03o]/4Moooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0?oooo
o`03o`0000000000okK100L0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf
`@030000003o]/40okK100X0okK100<000000?nf`@3oool0:P3ooolX0?nf`Agooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Cooooo`<0
okK100<0003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0D0?nf`B/0oooo:03o]/4Mooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0@ooooo`03
0000003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@03
0000003o]/40okK100X0okK100<000000?nf`@3oool0:P3ooolX0?nf`Agooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Dooooo`<0okK1
00<0003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0C0?nf`B/0oooo:03o]/4Mooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Booooo`030000
003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@060?nf`@030000
003o]/40okK100X0okK100<000000?nf`@3oool0:P3ooolX0?nf`Agooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`030?nf`@00
0?l0okK100l0okK100?o003o0?nf`@3o]/404`3o]/4[0?ooobP0okK17Oooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool04_ooool00`000000okK10?nf
`@060?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@0:0?nf`@030000003o]/40oooo02X0oooo:03o]/4Mooooo`0300000?oooooooooo00Sooooo0009
ooooo`05o`000?ooooooooooooooool00?l06?ooool00`3o]/40003o0?nf`@0@0?nf`@03o`00o`3o
]/40okK10180okK1:`3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo01;ooooo00<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?oo
o`0Z0?ooobP0okK17Oooool00`00003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooo
oooo003o01Sooooo00<0okK1o`00o`3o]/40403o]/400ol00?l0okK10?nf`@0C0?nf`BT0oooo:@3o
]/4Mooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Booooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@060?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/40:@3ooolY0?nf`Agooooo00<0
0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`00o`0Hooooo`030?nf`@00
0?l0okK10100okK100?o003o0?nf`@3o]/404`3o]/4Y0?ooobT0okK17Oooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool04Oooool00`000000okK10?nf
`@070?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@0:0?nf`@030000003o]/40oooo02P0oooo:@3o]/4Mooooo`0300000?oooooooooo00Sooooo0009
ooooo`04o`000?ooooooooooo`00oaWooooo00<0003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf
`@0B0?nf`BT0oooo:@3o]/4Mooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01Ooo
ool00`00003oooooooooo`0Aooooo`030000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o
]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100X0okK100<000000?nf`@3oool0:03o
oolY0?nf`Agooooo00<00000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o6Ooo
ool00`000?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK10180okK1:@3ooolY0?nf`Agooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00<0
00000?nf`@3o]/401`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100H0okK100<0
00000?nf`@3o]/402P3o]/400`000000okK10?ooo`0X0?ooobT0okK17Oooool00`00003ooooooooo
o`08ooooo`002Oooool01?l0003oooooooooool00?lEooooo`?o000000<0003o0?nf`@3o]/404P3o
]/400ol00?l0okK10?nf`@0C0?nf`BL0oooo:P3o]/4Mooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`0>ooooo`03o`000?ooool0okK100L0okK100<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100X0okK100<0
00000?nf`@3o]/409`3ooolZ0?nf`Agooooo00<00000ooooooooool02?ooool000Wooooo00Co0000
oooooooooooo003o5?ooool5o`0001@0okK100?o003o0?nf`@3o]/404`3o]/4W0?ooobX0okK17Ooo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`080?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401P3o
]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK102L0oooo:P3o]/4Mooooo`0300000?oo
oooooooo00Sooooo0009ooooo`04o`000?ooooooooooo`00o`Gooooo3`000?l5o`0000D0003o3`3o
]/400ol00?l0okK10?nf`@0D0?nf`BD0oooo:`3o]/4Mooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`0400000?ooooooooooooooo`P0okK1
00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100X0okK1
00@000000?nf`@3o]/40okK19@3oool[0?nf`Agooooo00<00000ooooooooool02?ooool000Wooooo
00Go0000oooooooooooo003oooooo`040000o`oooooo1Ol000000oooool0okK10?nf`@020?nf`@<0
003o303o]/400ol00?l0okK10?nf`@0F0?nf`B<0oooo:`3o]/4Mooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool02_ooool3000000Sooooo00<00000ooooooooool00oooool70?nf`@03
0000003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@0:0?nf`@03
0000003o]/40okK100<0okK18`3oool[0?nf`Agooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`000?l00P000?lCooooo`040000ool0003o0000o`0000;ooooo1`3o]/400`000?l0
okK10?nf`@090?nf`@03o`00o`3o]/40okK101H0okK18P3oool[0?nf`Akooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`0=ooooo`8000001?ooool2000000Kooooo1P3o]/400`000000
okK10?nf`@060?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/402`3o]/400`000000
okK10?nf`@030?nf`B80oooo:`3o]/4Nooooo`0300000?oooooooooo00Sooooo0009ooooo`04o`00
0?ooooooooooo`00oa;ooooo0P000?l6ooooo`P0okK100?o003o0000o`000?l00P000?l60?nf`@03
o`00o`3o]/40okK101L0okK1803oool/0?nf`Akooooo00?o0000ooooooooool03oooool00`00003o
oooo0000000?ooooo`@000002?ooool60?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o
]/401P3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100@0okK1803oool/0?nf`Ako
oooo00<00000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o4?ooool20000o`So
oooo3@3o]/430000o`<0okK100?o003o0?nf`@3o]/40603o]/4N0?ooobd0okK17_ooool00ol0003o
ooooooooo`0?ooooo`0400000?oooooooooo000001[ooooo1P3o]/400`000000okK10?nf`@060?nf
`@030000003o]/40okK100H0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@050?nf
`Ah0oooo;@3o]/4Nooooo`0300000?oooooooooo00Sooooo0009ooooo`04o`000?ooooooooooo`00
o`gooooo0`000?l:oooooa00okK10P000?l00ol00?l0okK10?nf`@0J0?nf`A`0oooo;P3o]/4Noooo
o`03o`000?oooooooooo00oooooo00D00000oooooooooooooooo0000000Iooooo`D0okK100<00000
0?nf`@3o]/401P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100/0okK100<00000
0?nf`@3o]/401P3o]/4L0?ooobh0okK17_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0000o`020000o`Wooooo0`000?l>oooooa40okK100<0003o0?nf`@3o]/406`3o]/4I0?oo
oc00okK17_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00?o0000oooo
ooooool05oooool30?nf`@030000003o]/40okK100L0okK100?o00000?nf`@3o]/401`3o]/400`00
0000okK10?nf`@0;0?nf`@030000003o]/40okK100L0okK16@3oool`0?nf`Akooooo00<00000oooo
ooooool02?ooool000Wooooo00Oo0000ooooooooooooooooo`00o`000?oo003o00@0003o00?o003o
0000o`000?l04Oooool@0?nf`@04o`00o`3o]/40003o0000oad0okK15@3ooola0?nf`Aoooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`02ooooo`8000006?ooool20?nf`@030000003o
]/40okK100P0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@0;0?nf`@030000003o
]/40okK100T0okK15@3ooola0?nf`Aoooooo00<00000ooooooooool02?ooool000Wooooo00Go0000
ooooooooooooooooo`00o`0Joooooa00okK100Co003o0?nf`@3o]/40okK10P000?lM0?nf`A40oooo
<`3o]/4Oooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01?ooool2000001Kooooo
00<0okK10000003o]/402@3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100/0okK1
00<000000?nf`@3o]/402`3o]/4A0?oooc<0okK17oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01Sooooo3P3o]/400ol00?l0okK10?nf
`@040?nf`@80003o7@3o]/4=0?ooocD0okK17oooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool04oooool00`000000okK10?nf`@090?nf`@030000003o
]/40okK100L0okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf`@0=0?nf`@d0oooo=@3o
]/4Oooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool06?ooool>0?nf`@03o`00o`3o]/40okK100H0okK100<0003o0?nf`@3o]/407P3o]/45
0?ooocP0okK18?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Oooooo0`00000@
ooooo`80000000?ooooo0?nf`@3o]/40203o]/400`000000okK10?nf`@080?nf`@030000003o]/40
okK100`0okK100<000000?nf`@3o]/404@3o]/450?ooocP0okK18?ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01Sooooo3P3o]/400ol0
0?l0okK10?nf`@070?nf`@030000o`3o]/40okK105X0okK18?ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo00[ooooo0`00000<ooooo`0400000?ooooooooooooooo`X0okK100<00000
0?nf`@3o]/401`3o]/400`000000okK10?nf`@0=0?nf`@030000003o]/40okK104h0okK18?ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`03ooooo`;o003o6Oooool<0?nf
`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/40F@3o]/4Pooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool03Oooool3000000?ooooo1P000005ooooo`L0okK10P0000090?nf
`@030000003o]/40okK100d0okK100<000000?nf`@3o]/40C`3o]/4Pooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool05oooool<0?nf`@03
o`00o`3o]/40okK100X0okK10P000?mH0?nf`B7ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`0@ooooo`<000002oooool60?nf`@030000003o]/40okK100T0okK100?o00000?nf`@3o
]/403@3o]/400`000000okK10?nf`@1>0?nf`B7ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Gooooo`X0okK100?o003o0?nf`@3o]/40
3@3o]/420000oeH0okK18Oooool00ol0003oooooooooo`0?ooooo`0400000?ooool00000000001ko
oooo103o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o
]/40CP3o]/4Qooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo
00?o003oooooooooool05oooool80?nf`@03o`00o`3o]/40okK10100okK100<0003o0?nf`@3o]/40
DP3o]/4Rooooo`03o`000?oooooooooo00oooooo00D00000oooooooooooooooo0000000Nooooo`80
okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK104d0
okK18_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo01Kooooo1P3o]/42o`00oa@0okK100<0003o0?nf`@3o]/40D03o]/4Sooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`030?nf
`@000000okK100`0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@1<0?nf`B?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool2o`00oaOooooo103o
]/400ol00?l0okK10?nf`@0D0?nf`@030000o`3o]/40okK10500okK18oooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo00?ooooo0`00000Jooooo`030000003o]/40okK100/0okK100<0
00000?nf`@3o]/403`3o]/400`000000okK10?nf`@1<0?nf`B?ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool02_ooool2o`00oaGooooo0P3o]/42o`00oaP0okK100<0003o
0?nf`@3o]/40CP3o]/4Tooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01_ooool2
000001Gooooo0P0000000ol0003ooooo0?nf`@0;0?nf`@03o`00003o]/40okK10100okK100<00000
0?nf`@3o]/40B`3o]/4Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00cooooo00?o003oooooooooool04_ooool00`3o]/7o003o0?nf`@0J0?nf`@030000o`3o]/40okK1
04d0okK19?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Sooooo0P00000@oooo
o`<000001?ooool;0?nf`@030000003o]/40okK10140okK100<000000?nf`@3o]/409@3o]/4?0000
01L0okK19?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0=ooooo`03
o`00oooooooooooo017ooooo00?o003o0?nf`@3o]/406`3o]/400`000?l0okK10?nf`@1<0?nf`BCo
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`0:ooooo`H000001_ooool4000000So
oooo2@3o]/400`000000okK10?nf`@0B0?nf`@030000003o]/40okK101h0okK11`00000?0?nf`@<0
000000?o00000?nf`@3o]/404@3o]/4Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00kooooo0ol00?l<ooooo`Co003o0_oooolM0?nf`@030000o`3o]/40okK104X0okK1
9Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo013ooooo1P00000=ooooo`L0okK1
00<000000?nf`@3o]/404`3o]/400`000000okK10?nf`@0J0?nf`@@000006P3o]/45000000d0okK1
9Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Aooooo`Co003o1?oo
ool4o`00o`Kooooo7@3o]/400`000?l0okK10?nf`@190?nf`BKooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`0Sooooo`H0okK100<000000?nf`@3o]/40503o]/400`000000okK10?nf
`@0F0?nf`@@000008`3o]/42000000X0okK19_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Eooooo`Co003o2ooooolM0?nf`@030000o`3o]/40okK104P0okK19_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo02Cooooo103o]/400`000000okK10?nf`@0E
0?nf`@030000003o]/40okK101<0okK10`00000Y0?nf`@<000001`3o]/4Vooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02Cooooo7P3o]/400`000?l0okK10?nf`@160?nf
`BOooooo00?o0000ooooooooool03oooool01000003ooooo00000000000Sooooo`<0okK100<00000
0?nf`@3o]/405P3o]/400`000000okK10?nf`@0?0?nf`@80000000?o00000000003o]/40;P3o]/40
0ol000000000000000030?nf`BOooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool09OoooolN0?nf`@030000o`3o]/40okK104D0okK19oooool00ol0003oooooooooo`0?oooo
o`0500000?ooooooooooooooo`0000008oooool00`00003o00000?nf`@0H0?nf`@030000003o]/40
okK100`0okK10`00000f0?nf`@030000003o]/40okK102Oooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool09_oooolN0?nf`@03o`00o`3o]/40okK104<0okK1:?ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo0P00000Oooooo`80000000?ooooo0?nf
`@3o]/40603o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK103P0okK10P00000Woooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Oooooo7P3o]/400`000?l0
okK10?nf`@110?nf`BWooooo00?o0000ooooooooool03oooool00`00003oooooooooo`04ooooo`03
00000?oooooooooo01_ooooo00<00000ooooooooool00_oooolJ0?nf`@030000003o]/40okK100D0
okK11@00000k0?nf`@;ooooo00<00000ooooooooool09?ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Xoooooad0okK100<0003o0?nf`@3o]/40@03o]/4Zooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool01Oooool01?l00000000000000000000Dooooo`@0
000000?o0000ooooooooool01?oooolI0?nf`@03o`0000000000000000D0000000?o00000?nf`@3o
]/408`3o]/44000001D0okK11?ooool00ol0000000000000000Sooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo02Sooooo7P3o]/400`000?l0okK10?nf`@0n0?nf`B_ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`09ooooo`@000003Oooool3000000_ooooo
@03o]/47000000@0okK11`00000=0?nf`@Sooooo00<00000ooooooooool08?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Yoooooah0okK100<0003o0?nf`@3o]/40?@3o
]/4[ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool03Oooool=000000oooooo>`3o
]/4400000180okK1100000090?nf`@Wooooo00?o0000ooooooooool07oooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Zoooooad0okK100<0003o0?nf`@3o]/40?03o]/4/
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0:_oooolg0?nf`@<000006P3o]/40
1000003o00000000000000040?nf`@_ooooo0P00000Oooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02_ooooo7@3o]/400`000?l0okK10?nf`@0j0?nf`Bgooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`0[oooooc<0okK10`00000Q0?nf`@80000000<0okK1
ooooooooool03?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo02cooooo703o]/400`000?l0okK10?nf`@0i0?nf`Bkooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`0/oooooc00okK10P00000V0?nf`@8000003_ooool00`00
003oooooooooo`0Kooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02go
oooo6`3o]/400`000?l0okK10?nf`@0g0?nf`C3ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`0]ooooobh0okK100?o00000?nf`@3o]/404@3o]/48000000/0okK11?ooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0;_oooolK0?nf`@03o`00o`000?l0okK103D0okK1<Oooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo02kooooo:`3o]/42000000d0okK11@0000000ol000000000
0?nf`@070?nf`@L000000`3o]/46ooooo`03o`000000003ooooo00_ooooo00<00000ooooooooool0
6_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0`oooooaX0okK100<0
003o0?nf`@3o]/40<`3o]/4booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0<?oo
oolV0?nf`@<00000303o]/43000001H0okK10P000009ooooo`8000002oooool00`00003ooooooooo
o`0Iooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo037ooooo6P3o]/40
0`000?l0okK10?nf`@0a0?nf`C?ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0a
ooooob@0okK100<000000?nf`@3o]/402`3o]/42000001X0okK100?ooooo0000000000002Oooool0
0`00003oooooooooo`09ooooo`8000006Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0boooooaT0okK100<0003o0?nf`@3o]/40<03o]/4dooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0<_oooolQ0?nf`@800000303o]/400`00003o00000?nf`@0J0?nf
`@Cooooo0P000008ooooo`0300000?l0003ooooo00[ooooo00<00000ooooooooool05_ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0coooooaP0okK100<0003o0?nf`@3o
]/40;`3o]/4eooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0<ooooolO0?nf`@03
0000003o]/40okK100/0okK100<000000?nf`@3o]/40203o]/4?000000<0okK11oooool2000000So
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03Gooooo5`3o]/400`000?l0okK10?nf`@0/0?nf`COooooo
00?o0000ooooooooool03oooool01000003ooooo00000000000doooooa`0okK100<000000?nf`@3o
]/402P3o]/42000000P0okK10`00000?0?nf`@@000002?ooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Sooooo00<00000ooooooooool05Oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0foooooaH0okK100<0003o0?nf`@3o]/407P3o]/4:0000o`<0okK1
>?ooool00ol0003oooooooooo`0?ooooo`0500000?ooooooooooooooo`000000=?oooolJ0?nf`@03
o`00003o]/40okK100T0okK10P0000090?nf`@030000003o]/40okK10100okK11?ooool2000000Oo
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo01Co
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>?oooolD0?nf`@030000
o`3o]/40okK101X0okK110000?l:0?nf`@<0003o>?ooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo00;ooooo0`00000coooooaP0okK100<000000?nf`@3o]/401`3o]/42000000P0okK1
0P0000000ol00000okK10?nf`@0?0?nf`@Sooooo0P000006ooooo`0300000?l00000000000Kooooo
00?o0000ooooooooool01oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo03[ooooo4`3o]/400`000?l0okK10?nf`@0G0?nf`@80003o3@3o
]/44ooooo`80003o=_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Gooooo1000
000aoooooaD0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@060?nf`@8000002`3o
]/4;000000Sooooo0P000007ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo03_ooooo4P3o]/400`000?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK100`0okK11oooool0
0`000?ooooooooooo`0cooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool02Oooool4
000002kooooo4`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100H0okK100<00000
0?nf`@3o]/401`3o]/44000000H0okK11Oooool4000000Kooooo0P000006ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo03kooooo3`3o]/400`000?l0okK10?nf`@0E0?nf
`@030000o`3o]/40okK100/0okK12_ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool03Oooool01?l00000000000000000000]ooooo`h0okK100<00000
o`00003o]/40203o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100D0okK100<00000
o`0000000000203o]/4;ooooo`8000001_ooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo047ooooo303o]/400`000?l0okK10?nf`@0D0?nf
`@030000o`3o]/40okK100T0okK13_ooool00`000?ooooooooooo`0aooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool04OoooolK000001Gooooo2`3o]/400`000000okK10?nf`@080?nf
`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@060?nf
`A3ooooo0P000005ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`07ooooo`0300000?oooooooooo017ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0A?ooool:0?nf`@030000o`3o]/40okK10180okK100<0003o0?nf`@3o
]/401`3o]/4Booooo`030000oooooooooooo033ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`0/ooooo`8000005_ooool70?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o
]/401@3o]/400`000000okK10?nf`@040?nf`@8000001P3o]/42ooooo`/000002?ooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo017ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0Aoooool70?nf`@03o`00o`3o]/40okK100@0okK13`000?l60?nf`AKooooo
00<0003oooooooooool0;oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo02gooooo
00<00000ooooooooool05oooool30?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK10_ooool3000000_ooooo
0`000006ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`03ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool04?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1:ooooo`D0okK100<0003o0?nf`@3o]/400`00
0?l<0?nf`@03o`00o`3o]/40okK10080003o00<0okK1ooooooooool06?ooool00`000?oooooooooo
o`0^ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0;_ooool00`00003ooooooooo
o`0Hooooo`030000003o]/40okK100P0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf
`@030?nf`@0300000?l00000okK10080okK10oooool20000017ooooo00<00000ooooooooool01?oo
ool2000000Cooooo00?o0000ooooooooool00oooool00`00003oooooooooo`03ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool03oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1=ooooo`80okK10`000?l?0?nf`@060000o`3o]/40okK1ooooool00?l0003o
6_ooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0
;_ooool00`00003oooooooooo`0Hooooo`0400000?ooooooooooooooo`L0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100Cooooo0P00000Dooooo`03
o`000000003ooooo00Gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04kooooo0P000?l6ooooo`@0okK1
1oooool00`000?ooooooooooo`03ooooo`<0003o4_ooool5o`00o`040000ool00?oo003oo`00obgo
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo01Ko
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`040?nf`@0300000?oooooooooo00?o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`05ooooo`/000001_ooool2000000Go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool01oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo04gooooo00<0003oooooo`000?l04?ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo00cooooo0ol00?l6ooooo`030000oooooooooooo00?o003o
:_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool0
5Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`0300000?l0003ooooo00Gooooo00?o000000000?ooool0
2_ooool3000000Gooooo00<00000o`000?ooool00oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`07ooooo`03o`00
0?oooooooooo00gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0C?oo
ool010000?ooooooooooo`000?l@ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool0
2_ooool00ol00?ooooooooooo`07ooooo`030000oooooooooooo00?ooooo0ol00?lWooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0Eooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool01?ooool2000000oooooo00<00000ooooooooool0
1?ooool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool03Oooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1:ooooo`80003o0oooool00`000?oooooo
ooooo`0=ooooo`030000oooooooooooo00[ooooo0P000?l8ooooo`;o003o2oooool00`000?oooooo
ooooo`05ooooo`03o`00oooooooooooo02Cooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`0_ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`05ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00_ooool00`00003ooooo
ooooo`03ooooo`8000004_ooool2000000Gooooo00D00000oooooooooooooooo00000004ooooo`03
00000?oooooooooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
BOooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00gooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`03ooooo`;o003o3Oooool00`000?ooooooooooo`06ooooo`03o`00
oooooooooooo02?ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0_ooooo`030000
0?oooooooooo01Cooooo00?o0000ooooooooool01oooool00`00003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`03o`00
0?oooooooooo01Cooooo00<00000ooooooooool00oooool01@00003oooooooooooooool0000000?o
oooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Oo
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`18ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool03Oooool00`000?oooooo
ooooo`0=ooooo`050000ooooooooooooooooool00?l03oooool00`000?ooooooooooo`07ooooo`03
o`00oooooooooooo02;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0_ooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`04ooooo`03
00000?oooooooooo00?ooooo00<00000ooooooooool00_ooool00`00003o0000ooooo`04ooooo`03
00000?oooooooooo00Kooooo0P0000000ol000000000o`000003000000Oooooo00<00000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000001?ooool00ol0
003oooooooooo`03ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool03?ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`17ooooo`030000oooooooooooo00Ko
oooo00<0003oooooooooool02oooool00`000?ooooooooooo`0>ooooo`050000oooooooooooooooo
ool00?l04?ooool00`000?ooooooooooo`07ooooo`03o`00oooooooooooo027ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo01?ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo0`000008oooo
o`8000001_ooool01Ol0003oooooooooooooool0000000Cooooo00D00000oooooooooooooooo0000
0004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Kooooo00<0003o
ooooooooool01oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00oooooo0ol0000A
ooooo`030000oooooooooooo00Sooooo0_l00?lQooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0;_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00<00000
ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00_ooooo00<00000
ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D00000
oooooooooooooooo00000004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo04Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0;ooooo`030000oooooooo
oooo00kooooo1Ol0000@ooooo`030000oooooooooooo00Wooooo00?o003oooooooooool07oooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool04oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0=ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool0
1@00003oooooooooooooool0000000Cooooo00Go0000oooooooooooooooo00000005ooooo`03o`00
0?oooooooooo00Kooooo00<00000ooooooooool02oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`15ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02ooo
ool00`000?ooooooooooo`0>ooooo`Go00004?ooool00`000?ooooooooooo`0:ooooo`03o`00oooo
oooooooo01kooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oo
oooooooo01?ooooo00<00000ooooooooool01oooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool00`00003oooooooooo`03ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool00_ooool01Ol0003oooooooooooooool0000000?ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0AOooool00`000?oooooooooo
o`08ooooo`030000oooooooooooo00cooooo00<0003oooooooooool03Oooool5o`00013ooooo00<0
003oooooooooool02_ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0;_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool01Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00kooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`000000
0oooool01@00003oooooooooooooool0000000Gooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00oooooo
0ol0000cooooo`030000oooooooooooo00Sooooo00<0003oooooooooool03?ooool00`000?oooooo
ooooo`0>ooooo`?o00004Oooool00`000?ooooooooooo`0:ooooo`03o`00oooooooooooo01kooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo01;ooooo
00<00000ooooooooool01oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool04?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo
00D00000oooooooooooooooo00000004ooooo`0500000?ooooooooooooooo`0000001Oooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool03_ooool5o`00037ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0<ooooo`030000oooooooooooo00gooooo00Go003ooooooooooooooooo0000o`0@oooo
o`030000oooooooooooo00_ooooo00?o003oooooooooool07Oooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo02kooooo00<00000ooooooooool04_ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool00oooool00`00003oooooooooo`02oooo
o`0300000?oooooooooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0Boooo
o`0300000?oooooooooo00;ooooo00D00000ooooooooooooooooo`000003ooooo`0300000?oooooo
oooo00;ooooo00D00000oooooooooooooooo00000005ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0>
ooooo`Go0000<Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool03Oooool01Ol00?oooooooooooooooooo003o013ooooo00<0003oooooooooool02ooo
ool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0;_oo
ool00`00003oooooooooo`0Booooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01Ooo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_oo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool00_oo
ool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00_ooool01@00003ooooo
ooooooooool0000000Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0:ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00kooooo1Ol0000`ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0=ooooo`05o`00
ooooooooooooooooo`000?l03oooool00`000?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo017o
oooo00?o0000ooooooooool02?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool04_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;o
oooo00D00000oooooooooooooooo00000003ooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool03oooool3o`00037ooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00cooooo00Go003ooooooooo
oooooooo0000o`0?ooooo`030000oooooooooooo00gooooo00?o003oooooooooool07?ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool04Oooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00oooool00`00
003oooooooooo`0Booooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool01@00
003oooooooooooooool0000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02_ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`13ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool03Oooool00`000?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00<0003ooooo
ooooool03?ooool00`000?ooooooooooo`0=ooooo`03o`00oooooooooooo01cooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo017ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool04_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D00000oooo
oooooooooooo00000003ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0@_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo
00gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`03ooooo`030000oooooooooooo
00Wooooo0ol0000Aooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`0^ooooo`0300000?oooooooooo017ooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool04Oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000003
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0@_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00kooooo00<0003ooooo
ooooool02_ooool00ol00?ooooooooooo`03ooooo`030000oooooooooooo00Sooooo1Ol0000@oooo
o`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0^oooo
o`0300000?oooooooooo017ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`02oooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool03oooool00`00003oooooooooo`03oooo
o`0500000?ooooooooooooooo`0000001?ooool01@00003oooooooooooooool0000000Cooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@_ooool00`000?ooooooooooo`0;
ooooo`030000oooooooooooo00kooooo00<0003oooooooooool02_ooool00ol00?ooooooooooo`03
ooooo`030000oooooooooooo00Sooooo1Ol0000@ooooo`03o`00oooooooooooo01_ooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo017ooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`03ooooo`0500000?ooooooooooooooo`0000001?oo
ool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool00_ooool00`00003ooooo
ooooo`06ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0@_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Oooooo0ol0
0005ooooo`030000oooooooooooo00Wooooo00?o003oooooooooool01?ooool00`000?oooooooooo
o`07ooooo`Go00003oooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0;_ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool01Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00gooooo00<0
0000ooooooooool01?ooool01@00003ooooooooooooooooo000000Cooooo00D00000oooooooooooo
oooo00000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0:ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04;ooooo
00<0003oooooooooool02oooool00`000?ooooooooooo`06ooooo`Go00001Oooool00`000?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Cooooo00<0003oooooooooool01oooool010000?oo0000
o`000?l0000@ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`0^ooooo`0300000?oooooooooo017ooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`05ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool01@00003o
ooooooooooooool0000000Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0@_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Kooooo1Ol00006ooooo`03
0000oooooooooooo00Oooooo00?o003oooooooooool01?ooool00`000?ooooooooooo`06ooooo`03
0000oooooooooooo01;ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo02kooooo00<00000ooooooooool04Oooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo00Kooooo00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00<00000ooooooooool01Oooool2000000[ooooo00<00000oooooooo
ool01Oooool01@00003oooooooooooooool0000000Cooooo00D00000oooooooooooooooo00000004
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04;ooooo00<0003ooooo
ooooool02oooool00`000?ooooooooooo`06ooooo`Go00001oooool20000o`Sooooo00?o003ooooo
ooooool00oooool00`000?ooooooooooo`04ooooo`80003o5Oooool00ol00?ooooooooooo`0Loooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo00<00000ooooooooool01_ooool00`00003oooooooooo`03oooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool00oooool2000000Oooooo2P000006oooo
o`03o`000000003ooooo00?ooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0
000000Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00[ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@_ooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Sooooo0ol0000:ooooo`80003o1_ooool00ol0
0?ooooooooooo`03ooooo`030000oooooooooooo00;ooooo0P000?lFooooo`03o`00oooooooooooo
01gooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo
017ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo
00Cooooo00<00000ooooooooool01?ooool00`00003oooooooooo`04ooooo`8000005?ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000004
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04;ooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0Gooooo`030000oooooooooooo00?ooooo00?o003ooooo
ooooool00oooool01@000?ooooooooooooooool0003o01Sooooo00?o003oooooooooool07Oooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool04Oooool0
0`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo0000
0004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04;ooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00oooool010000?ooooooooooo`000?lIooooo`03o`00oooooooooooo01gooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo01;ooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00<0
0000ooooooooool01?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Ooooonfo`00017ooooo]P00000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 g
.01923 .46469 m
.03646 .48077 L
.03846 .48222 L
.05769 .49409 L
.06962 .5 L
.07692 .50161 L
.09615 .50499 L
.11538 .5051 L
.13462 .50175 L
.14445 .5 L
.15385 .49481 L
.17308 .48229 L
.17521 .48077 L
.19231 .46373 L
.19415 .46154 L
.20708 .44231 L
.21154 .4338 L
.21578 .42308 L
.22119 .40385 L
.22401 .38462 L
.2248 .36538 L
.22454 .34615 L
.22545 .32692 L
.23077 .31292 L
.23578 .30769 L
.25 .2999 L
.26923 .29432 L
.28846 .28904 L
.2904 .28846 L
.30769 .28186 L
.32692 .27207 L
.33154 .26923 L
.34615 .25821 L
.35499 .25 L
.36538 .23833 L
.37095 .23077 L
.38292 .21154 L
.38462 .20853 L
.3919 .19231 L
.40258 .17308 L
.40385 .17164 L
.42308 .15971 L
.44231 .16484 L
.46154 .17257 L
.46288 .17308 L
.48077 .17875 L
.5 .18262 L
.51923 .18382 L
.53846 .18234 L
.55769 .17841 L
.57519 .17308 L
.57692 .17255 L
.59615 .16596 L
.61538 .16484 L
.62452 .17308 L
.63314 .19231 L
.63462 .19873 L
.63843 .21154 L
.64437 .23077 L
.65151 .25 L
.65385 .25544 L
.66078 .26923 L
.67275 .28846 L
.67308 .28892 L
.68843 .30769 L
.69231 .31173 L
.70931 .32692 L
.71154 .32864 L
.73077 .34152 L
.7391 .34615 L
.75 .35131 L
.76923 .35863 L
.78846 .36393 L
.79379 .36538 L
.80769 .36723 L
.82692 .3686 L
.84615 .3678 L
.86538 .36619 L
.86933 .36538 L
.88462 .36 L
.90385 .35058 L
.9135 .34615 L
.92308 .33961 L
.93987 .32692 L
.94231 .3248 L
.95979 .30769 L
.96154 .30574 L
.97522 .28846 L
.98077 .28006 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .46469 m
.03646 .48077 L
.03846 .48222 L
.05769 .49409 L
.06962 .5 L
.07692 .50161 L
.09615 .50499 L
.11538 .5051 L
.13462 .50175 L
.14445 .5 L
.15385 .49481 L
.17308 .48229 L
.17521 .48077 L
.19231 .46373 L
.19415 .46154 L
.20708 .44231 L
.21154 .4338 L
.21578 .42308 L
.22119 .40385 L
.22401 .38462 L
.2248 .36538 L
.22454 .34615 L
.22545 .32692 L
.23077 .31292 L
.23578 .30769 L
.25 .2999 L
.26923 .29432 L
.28846 .28904 L
.2904 .28846 L
.30769 .28186 L
.32692 .27207 L
.33154 .26923 L
.34615 .25821 L
.35499 .25 L
.36538 .23833 L
.37095 .23077 L
.38292 .21154 L
.38462 .20853 L
.3919 .19231 L
.40258 .17308 L
.40385 .17164 L
.42308 .15971 L
.44231 .16484 L
.46154 .17257 L
.46288 .17308 L
.48077 .17875 L
.5 .18262 L
.51923 .18382 L
.53846 .18234 L
.55769 .17841 L
Mistroke
.57519 .17308 L
.57692 .17255 L
.59615 .16596 L
.61538 .16484 L
.62452 .17308 L
.63314 .19231 L
.63462 .19873 L
.63843 .21154 L
.64437 .23077 L
.65151 .25 L
.65385 .25544 L
.66078 .26923 L
.67275 .28846 L
.67308 .28892 L
.68843 .30769 L
.69231 .31173 L
.70931 .32692 L
.71154 .32864 L
.73077 .34152 L
.7391 .34615 L
.75 .35131 L
.76923 .35863 L
.78846 .36393 L
.79379 .36538 L
.80769 .36723 L
.82692 .3686 L
.84615 .3678 L
.86538 .36619 L
.86933 .36538 L
.88462 .36 L
.90385 .35058 L
.9135 .34615 L
.92308 .33961 L
.93987 .32692 L
.94231 .3248 L
.95979 .30769 L
.96154 .30574 L
.97522 .28846 L
.98077 .28006 L
Mfstroke
.2 g
.01923 .63538 m
.02003 .63462 L
.03846 .61921 L
.04382 .61538 L
.05769 .60698 L
.07692 .59746 L
.07984 .59615 L
.09615 .59133 L
.11538 .5874 L
.13462 .58609 L
.15385 .58746 L
.17308 .59117 L
.19008 .59615 L
.19231 .59706 L
.21154 .60566 L
.2284 .61538 L
.23077 .61698 L
.25 .63207 L
.25276 .63462 L
.26923 .65253 L
.27027 .65385 L
.28335 .67308 L
.28846 .68224 L
.29337 .69231 L
.30156 .71154 L
.30769 .72603 L
.30987 .73077 L
.32276 .75 L
.32692 .75422 L
.34615 .76714 L
.35061 .76923 L
.36538 .77713 L
.38462 .78749 L
.38635 .78846 L
.40385 .80113 L
.41148 .80769 L
.42308 .81925 L
.42819 .82692 L
.44231 .84368 L
.44404 .84615 L
.45947 .86538 L
.46154 .86683 L
.47193 .86538 L
.48077 .85623 L
.48937 .84615 L
.5 .83379 L
.50705 .82692 L
.51923 .81563 L
.53012 .80769 L
.53846 .80296 L
.55769 .79457 L
.57692 .78951 L
.5839 .78846 L
.59615 .78758 L
.61538 .78778 L
.63042 .78846 L
.63462 .78928 L
.65385 .79024 L
.66639 .78846 L
.67308 .78595 L
.69161 .76923 L
.69231 .76816 L
.70524 .75 L
.71154 .74105 L
.71967 .73077 L
.73077 .71848 L
.73797 .71154 L
.75 .70142 L
.76221 .69231 L
.76923 .68768 L
.78846 .67422 L
.78984 .67308 L
.80584 .65385 L
.80764 .63462 L
.80408 .61538 L
.79977 .59615 L
.79652 .57692 L
.79524 .55769 L
.79636 .53846 L
.80011 .51923 L
.80657 .5 L
.80769 .49731 L
.81662 .48077 L
.82692 .46614 L
.83063 .46154 L
.84615 .4466 L
.85092 .44231 L
.86538 .43584 L
.88462 .42576 L
.89565 .42308 L
.90385 .42234 L
.92115 .42308 L
.92308 .42335 L
.94231 .428 L
.96154 .43546 L
.97417 .44231 L
.98077 .44559 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .63538 m
.02003 .63462 L
.03846 .61921 L
.04382 .61538 L
.05769 .60698 L
.07692 .59746 L
.07984 .59615 L
.09615 .59133 L
.11538 .5874 L
.13462 .58609 L
.15385 .58746 L
.17308 .59117 L
.19008 .59615 L
.19231 .59706 L
.21154 .60566 L
.2284 .61538 L
.23077 .61698 L
.25 .63207 L
.25276 .63462 L
.26923 .65253 L
.27027 .65385 L
.28335 .67308 L
.28846 .68224 L
.29337 .69231 L
.30156 .71154 L
.30769 .72603 L
.30987 .73077 L
.32276 .75 L
.32692 .75422 L
.34615 .76714 L
.35061 .76923 L
.36538 .77713 L
.38462 .78749 L
.38635 .78846 L
.40385 .80113 L
.41148 .80769 L
.42308 .81925 L
.42819 .82692 L
.44231 .84368 L
.44404 .84615 L
.45947 .86538 L
.46154 .86683 L
.47193 .86538 L
.48077 .85623 L
.48937 .84615 L
.5 .83379 L
.50705 .82692 L
.51923 .81563 L
.53012 .80769 L
.53846 .80296 L
Mistroke
.55769 .79457 L
.57692 .78951 L
.5839 .78846 L
.59615 .78758 L
.61538 .78778 L
.63042 .78846 L
.63462 .78928 L
.65385 .79024 L
.66639 .78846 L
.67308 .78595 L
.69161 .76923 L
.69231 .76816 L
.70524 .75 L
.71154 .74105 L
.71967 .73077 L
.73077 .71848 L
.73797 .71154 L
.75 .70142 L
.76221 .69231 L
.76923 .68768 L
.78846 .67422 L
.78984 .67308 L
.80584 .65385 L
.80764 .63462 L
.80408 .61538 L
.79977 .59615 L
.79652 .57692 L
.79524 .55769 L
.79636 .53846 L
.80011 .51923 L
.80657 .5 L
.80769 .49731 L
.81662 .48077 L
.82692 .46614 L
.83063 .46154 L
.84615 .4466 L
.85092 .44231 L
.86538 .43584 L
.88462 .42576 L
.89565 .42308 L
.90385 .42234 L
.92115 .42308 L
.92308 .42335 L
.94231 .428 L
.96154 .43546 L
.97417 .44231 L
.98077 .44559 L
Mfstroke
.3 g
.01923 .67843 m
.0231 .67308 L
.03846 .65567 L
.04038 .65385 L
.05769 .64013 L
.06642 .63462 L
.07692 .62922 L
.09615 .6218 L
.11538 .6174 L
.13462 .61583 L
.15385 .617 L
.17308 .62091 L
.19231 .6277 L
.20628 .63462 L
.21154 .63782 L
.23077 .65227 L
.23251 .65385 L
.24993 .67308 L
.25 .67318 L
.26226 .69231 L
.26923 .70663 L
.27129 .71154 L
.27845 .73077 L
.28612 .75 L
.28846 .75443 L
.30098 .76923 L
.30769 .77384 L
.32692 .78195 L
.34615 .78793 L
.3479 .78846 L
.36538 .7956 L
.38462 .8059 L
.38743 .80769 L
.40385 .82118 L
.40923 .82692 L
.42308 .84535 L
.42337 .84615 L
.43063 .86538 L
.4355 .88462 L
.43464 .90385 L
.42807 .92308 L
.42308 .9378 L
.41962 .94231 L
.40385 .96018 L
.40231 .96154 L
.38462 .97384 L
.36908 .98077 L
.01923 .98077 L
F
0 g
.01923 .67843 m
.0231 .67308 L
.03846 .65567 L
.04038 .65385 L
.05769 .64013 L
.06642 .63462 L
.07692 .62922 L
.09615 .6218 L
.11538 .6174 L
.13462 .61583 L
.15385 .617 L
.17308 .62091 L
.19231 .6277 L
.20628 .63462 L
.21154 .63782 L
.23077 .65227 L
.23251 .65385 L
.24993 .67308 L
.25 .67318 L
.26226 .69231 L
.26923 .70663 L
.27129 .71154 L
.27845 .73077 L
.28612 .75 L
.28846 .75443 L
.30098 .76923 L
.30769 .77384 L
.32692 .78195 L
.34615 .78793 L
.3479 .78846 L
.36538 .7956 L
.38462 .8059 L
.38743 .80769 L
.40385 .82118 L
.40923 .82692 L
.42308 .84535 L
.42337 .84615 L
.43063 .86538 L
.4355 .88462 L
.43464 .90385 L
.42807 .92308 L
.42308 .9378 L
.41962 .94231 L
.40385 .96018 L
.40231 .96154 L
.38462 .97384 L
.36908 .98077 L
s
.4 g
.01923 .77696 m
.02168 .78846 L
.02861 .80769 L
.03846 .82518 L
.03971 .82692 L
.05682 .84615 L
.05769 .84693 L
.07692 .86082 L
.08528 .86538 L
.09615 .86979 L
.11538 .87503 L
.13462 .87717 L
.15385 .87672 L
.17308 .87445 L
.19231 .87194 L
.21154 .87308 L
.22781 .88462 L
.23077 .88854 L
.24118 .90385 L
.25 .9198 L
.25245 .92308 L
.26789 .94231 L
.26923 .94373 L
.28846 .95932 L
.2918 .96154 L
.30769 .96883 L
.32692 .97349 L
.34615 .97379 L
.36538 .96965 L
.38291 .96154 L
.38462 .96027 L
.40385 .94317 L
.40451 .94231 L
.41617 .92308 L
.42228 .90385 L
.42301 .88462 L
.41856 .86538 L
.40902 .84615 L
.40385 .83861 L
.39277 .82692 L
.38462 .82039 L
.36538 .80915 L
.36276 .80769 L
.34615 .8024 L
.32692 .7983 L
.30769 .7956 L
.28846 .79197 L
.28019 .78846 L
.26923 .77795 L
.26488 .76923 L
.25899 .75 L
.25354 .73077 L
.25 .72044 L
.24622 .71154 L
.2355 .69231 L
.23077 .68571 L
.2195 .67308 L
.21154 .66599 L
.19352 .65385 L
.19231 .6532 L
.17308 .64502 L
.15385 .64047 L
.13462 .63918 L
.11538 .64105 L
.09615 .64625 L
.07923 .65385 L
.07692 .65523 L
.05769 .66915 L
.05347 .67308 L
.03846 .69097 L
.03757 .69231 L
.02723 .71154 L
.0209 .73077 L
.01923 .73916 L
F
0 g
.01923 .77696 m
.02168 .78846 L
.02861 .80769 L
.03846 .82518 L
.03971 .82692 L
.05682 .84615 L
.05769 .84693 L
.07692 .86082 L
.08528 .86538 L
.09615 .86979 L
.11538 .87503 L
.13462 .87717 L
.15385 .87672 L
.17308 .87445 L
.19231 .87194 L
.21154 .87308 L
.22781 .88462 L
.23077 .88854 L
.24118 .90385 L
.25 .9198 L
.25245 .92308 L
.26789 .94231 L
.26923 .94373 L
.28846 .95932 L
.2918 .96154 L
.30769 .96883 L
.32692 .97349 L
.34615 .97379 L
.36538 .96965 L
.38291 .96154 L
.38462 .96027 L
.40385 .94317 L
.40451 .94231 L
.41617 .92308 L
.42228 .90385 L
.42301 .88462 L
.41856 .86538 L
.40902 .84615 L
.40385 .83861 L
.39277 .82692 L
.38462 .82039 L
.36538 .80915 L
.36276 .80769 L
.34615 .8024 L
.32692 .7983 L
.30769 .7956 L
.28846 .79197 L
.28019 .78846 L
.26923 .77795 L
.26488 .76923 L
Mistroke
.25899 .75 L
.25354 .73077 L
.25 .72044 L
.24622 .71154 L
.2355 .69231 L
.23077 .68571 L
.2195 .67308 L
.21154 .66599 L
.19352 .65385 L
.19231 .6532 L
.17308 .64502 L
.15385 .64047 L
.13462 .63918 L
.11538 .64105 L
.09615 .64625 L
.07923 .65385 L
.07692 .65523 L
.05769 .66915 L
.05347 .67308 L
.03846 .69097 L
.03757 .69231 L
.02723 .71154 L
.0209 .73077 L
.01923 .73916 L
Mfstroke
.2 g
.01923 .83767 m
.02552 .84615 L
.03846 .86039 L
.04394 .86538 L
.05769 .87582 L
.07268 .88462 L
.07692 .88663 L
.09615 .8939 L
.11538 .89828 L
.13462 .90017 L
.15385 .90006 L
.17308 .89894 L
.19231 .89899 L
.21006 .90385 L
.21154 .90462 L
.23077 .9209 L
.23296 .92308 L
.24987 .94231 L
.25 .94246 L
.26923 .96039 L
.2707 .96154 L
.28846 .97311 L
.30651 .98077 L
.01923 .98077 L
F
0 g
.01923 .83767 m
.02552 .84615 L
.03846 .86039 L
.04394 .86538 L
.05769 .87582 L
.07268 .88462 L
.07692 .88663 L
.09615 .8939 L
.11538 .89828 L
.13462 .90017 L
.15385 .90006 L
.17308 .89894 L
.19231 .89899 L
.21006 .90385 L
.21154 .90462 L
.23077 .9209 L
.23296 .92308 L
.24987 .94231 L
.25 .94246 L
.26923 .96039 L
.2707 .96154 L
.28846 .97311 L
.30651 .98077 L
s
.1 g
.01923 .88054 m
.02365 .88462 L
.03846 .8964 L
.04987 .90385 L
.05769 .90817 L
.07692 .91679 L
.09615 .92279 L
.09699 .92308 L
.11538 .9264 L
.13462 .92803 L
.15385 .92817 L
.17308 .92791 L
.19231 .92949 L
.21154 .93636 L
.22261 .94231 L
.23077 .94983 L
.24529 .96154 L
.25 .9658 L
.26923 .97953 L
.27128 .98077 L
.01923 .98077 L
F
0 g
.01923 .88054 m
.02365 .88462 L
.03846 .8964 L
.04987 .90385 L
.05769 .90817 L
.07692 .91679 L
.09615 .92279 L
.09699 .92308 L
.11538 .9264 L
.13462 .92803 L
.15385 .92817 L
.17308 .92791 L
.19231 .92949 L
.21154 .93636 L
.22261 .94231 L
.23077 .94983 L
.24529 .96154 L
.25 .9658 L
.26923 .97953 L
.27128 .98077 L
s
.01923 .93433 m
.03212 .94231 L
.03846 .9457 L
.05769 .95453 L
.07692 .96127 L
.07777 .96154 L
.09615 .96605 L
.11538 .969 L
.13462 .97035 L
.15385 .97055 L
.17308 .97055 L
.19231 .97219 L
.21154 .97752 L
.22075 .98077 L
.01923 .98077 L
F
.01923 .93433 m
.03212 .94231 L
.03846 .9457 L
.05769 .95453 L
.07692 .96127 L
.07777 .96154 L
.09615 .96605 L
.11538 .969 L
.13462 .97035 L
.15385 .97055 L
.17308 .97055 L
.19231 .97219 L
.21154 .97752 L
.22075 .98077 L
s
.3 g
.01923 .43093 m
.02682 .44231 L
.03846 .45565 L
.04512 .46154 L
.05769 .46995 L
.07692 .4786 L
.08461 .48077 L
.09615 .48261 L
.11538 .48258 L
.12659 .48077 L
.13462 .47844 L
.15385 .4694 L
.16526 .46154 L
.17308 .45437 L
.18337 .44231 L
.19231 .42789 L
.1945 .42308 L
.20093 .40385 L
.20378 .38462 L
.20353 .36538 L
.20056 .34615 L
.19517 .32692 L
.19231 .31904 L
.18728 .30769 L
.1749 .28846 L
.17308 .2866 L
.15385 .27773 L
.13462 .27856 L
.11538 .27828 L
.09615 .28119 L
.07692 .28655 L
.07137 .28846 L
.05769 .29585 L
.04133 .30769 L
.03846 .31034 L
.02443 .32692 L
.01923 .33482 L
F
0 g
.01923 .43093 m
.02682 .44231 L
.03846 .45565 L
.04512 .46154 L
.05769 .46995 L
.07692 .4786 L
.08461 .48077 L
.09615 .48261 L
.11538 .48258 L
.12659 .48077 L
.13462 .47844 L
.15385 .4694 L
.16526 .46154 L
.17308 .45437 L
.18337 .44231 L
.19231 .42789 L
.1945 .42308 L
.20093 .40385 L
.20378 .38462 L
.20353 .36538 L
.20056 .34615 L
.19517 .32692 L
.19231 .31904 L
.18728 .30769 L
.1749 .28846 L
.17308 .2866 L
.15385 .27773 L
.13462 .27856 L
.11538 .27828 L
.09615 .28119 L
.07692 .28655 L
.07137 .28846 L
.05769 .29585 L
.04133 .30769 L
.03846 .31034 L
.02443 .32692 L
.01923 .33482 L
s
.1 g
.01923 .30182 m
.03323 .28846 L
.03846 .28457 L
.05769 .27133 L
.06075 .26923 L
.07692 .25945 L
.089 .25 L
.0892 .23077 L
.07692 .21893 L
.06758 .21154 L
.05769 .20213 L
.0445 .19231 L
.03846 .18606 L
.02724 .17308 L
.01923 .16055 L
F
0 g
.01923 .30182 m
.03323 .28846 L
.03846 .28457 L
.05769 .27133 L
.06075 .26923 L
.07692 .25945 L
.089 .25 L
.0892 .23077 L
.07692 .21893 L
.06758 .21154 L
.05769 .20213 L
.0445 .19231 L
.03846 .18606 L
.02724 .17308 L
.01923 .16055 L
s
.1 g
.01923 .06144 m
.02163 .05769 L
.03786 .03846 L
.03846 .03791 L
.05769 .0242 L
.0679 .01923 L
.01923 .01923 L
F
0 g
.01923 .06144 m
.02163 .05769 L
.03786 .03846 L
.03846 .03791 L
.05769 .0242 L
.0679 .01923 L
s
.01923 .57692 m
.03668 .55769 L
.03846 .55439 L
.03934 .53846 L
.03846 .53629 L
.02622 .51923 L
.01923 .50981 L
F
.01923 .57692 m
.03668 .55769 L
.03846 .55439 L
.03934 .53846 L
.03846 .53629 L
.02622 .51923 L
.01923 .50981 L
s
.01923 .2614 m
.02616 .25 L
.03281 .23077 L
.02449 .21154 L
.01923 .20026 L
F
.01923 .2614 m
.02616 .25 L
.03281 .23077 L
.02449 .21154 L
.01923 .20026 L
s
.01923 .02409 m
.02457 .01923 L
.01923 .01923 L
F
.01923 .02409 m
.02457 .01923 L
s
.3 g
.07692 .032 m
.09615 .02712 L
.11538 .02613 L
.13462 .02824 L
.15385 .03259 L
.17308 .03772 L
.17616 .03846 L
.19231 .04162 L
.21154 .04303 L
.23077 .04265 L
.25 .04229 L
.26923 .04353 L
.28846 .04731 L
.30769 .05424 L
.31484 .05769 L
.32692 .06499 L
.34223 .07692 L
.34615 .08042 L
.35976 .09615 L
.36538 .10296 L
.37186 .11538 L
.37562 .13462 L
.37662 .15385 L
.37368 .17308 L
.3679 .19231 L
.36538 .19882 L
.35866 .21154 L
.34615 .2293 L
.34488 .23077 L
.32692 .2474 L
.32339 .25 L
.30769 .25914 L
.28846 .26681 L
.28162 .26923 L
.26923 .27134 L
.25 .27348 L
.23077 .27372 L
.21154 .27178 L
.19231 .2697 L
.19075 .26923 L
.17308 .25921 L
.16435 .25 L
.15385 .23872 L
.14513 .23077 L
.13462 .22318 L
.11538 .21315 L
.11179 .21154 L
.09615 .20385 L
.07692 .19456 L
.07173 .19231 L
.05769 .18215 L
.04749 .17308 L
.03846 .16243 L
.0329 .15385 L
.02464 .13462 L
.02134 .11538 L
.0225 .09615 L
.02842 .07692 L
.03846 .05999 L
.04041 .05769 L
.05769 .04199 L
.06287 .03846 L
F
0 g
.07692 .032 m
.09615 .02712 L
.11538 .02613 L
.13462 .02824 L
.15385 .03259 L
.17308 .03772 L
.17616 .03846 L
.19231 .04162 L
.21154 .04303 L
.23077 .04265 L
.25 .04229 L
.26923 .04353 L
.28846 .04731 L
.30769 .05424 L
.31484 .05769 L
.32692 .06499 L
.34223 .07692 L
.34615 .08042 L
.35976 .09615 L
.36538 .10296 L
.37186 .11538 L
.37562 .13462 L
.37662 .15385 L
.37368 .17308 L
.3679 .19231 L
.36538 .19882 L
.35866 .21154 L
.34615 .2293 L
.34488 .23077 L
.32692 .2474 L
.32339 .25 L
.30769 .25914 L
.28846 .26681 L
.28162 .26923 L
.26923 .27134 L
.25 .27348 L
.23077 .27372 L
.21154 .27178 L
.19231 .2697 L
.19075 .26923 L
.17308 .25921 L
.16435 .25 L
.15385 .23872 L
.14513 .23077 L
.13462 .22318 L
.11538 .21315 L
.11179 .21154 L
.09615 .20385 L
.07692 .19456 L
.07173 .19231 L
Mistroke
.05769 .18215 L
.04749 .17308 L
.03846 .16243 L
.0329 .15385 L
.02464 .13462 L
.02134 .11538 L
.0225 .09615 L
.02842 .07692 L
.03846 .05999 L
.04041 .05769 L
.05769 .04199 L
.06287 .03846 L
.07692 .032 L
Mfstroke
.4 g
.07692 .30481 m
.09615 .2993 L
.11538 .29796 L
.13462 .30101 L
.15141 .30769 L
.15385 .30964 L
.17132 .32692 L
.17308 .32945 L
.18135 .34615 L
.18635 .36538 L
.18728 .38462 L
.18414 .40385 L
.17626 .42308 L
.17308 .42851 L
.16171 .44231 L
.15385 .44905 L
.13462 .46001 L
.13046 .46154 L
.11538 .465 L
.09615 .46514 L
.0798 .46154 L
.07692 .46052 L
.05769 .45016 L
.04824 .44231 L
.03846 .43096 L
.03374 .42308 L
.02604 .40385 L
.0233 .38462 L
.02518 .36538 L
.03191 .34615 L
.03846 .33468 L
.0449 .32692 L
.05769 .3155 L
.06995 .30769 L
F
0 g
.07692 .30481 m
.09615 .2993 L
.11538 .29796 L
.13462 .30101 L
.15141 .30769 L
.15385 .30964 L
.17132 .32692 L
.17308 .32945 L
.18135 .34615 L
.18635 .36538 L
.18728 .38462 L
.18414 .40385 L
.17626 .42308 L
.17308 .42851 L
.16171 .44231 L
.15385 .44905 L
.13462 .46001 L
.13046 .46154 L
.11538 .465 L
.09615 .46514 L
.0798 .46154 L
.07692 .46052 L
.05769 .45016 L
.04824 .44231 L
.03846 .43096 L
.03374 .42308 L
.02604 .40385 L
.0233 .38462 L
.02518 .36538 L
.03191 .34615 L
.03846 .33468 L
.0449 .32692 L
.05769 .3155 L
.06995 .30769 L
.07692 .30481 L
s
.4 g
.11538 .03842 m
.11621 .03846 L
.13462 .04103 L
.15385 .04635 L
.17308 .05267 L
.19231 .05751 L
.19344 .05769 L
.21154 .05932 L
.23077 .05895 L
.25 .05858 L
.26923 .06005 L
.28846 .06452 L
.30769 .07295 L
.31428 .07692 L
.32692 .08675 L
.33593 .09615 L
.34615 .11019 L
.34864 .11538 L
.35537 .13462 L
.35744 .15385 L
.35538 .17308 L
.34943 .19231 L
.34615 .19975 L
.33882 .21154 L
.32692 .22559 L
.32124 .23077 L
.30769 .24026 L
.28846 .24908 L
.28564 .25 L
.26923 .2537 L
.25 .25491 L
.23077 .25286 L
.2178 .25 L
.21154 .24714 L
.19231 .23655 L
.18369 .23077 L
.17308 .2224 L
.1569 .21154 L
.15385 .20971 L
.13462 .20082 L
.11538 .19495 L
.10541 .19231 L
.09615 .18901 L
.07692 .17992 L
.06611 .17308 L
.05769 .16583 L
.04746 .15385 L
.03846 .13768 L
.03754 .13462 L
.03365 .11538 L
.03505 .09615 L
.03846 .08486 L
.04213 .07692 L
.0574 .05769 L
.05769 .05744 L
.07692 .04521 L
.09615 .0395 L
.10616 .03846 L
F
0 g
.11538 .03842 m
.11621 .03846 L
.13462 .04103 L
.15385 .04635 L
.17308 .05267 L
.19231 .05751 L
.19344 .05769 L
.21154 .05932 L
.23077 .05895 L
.25 .05858 L
.26923 .06005 L
.28846 .06452 L
.30769 .07295 L
.31428 .07692 L
.32692 .08675 L
.33593 .09615 L
.34615 .11019 L
.34864 .11538 L
.35537 .13462 L
.35744 .15385 L
.35538 .17308 L
.34943 .19231 L
.34615 .19975 L
.33882 .21154 L
.32692 .22559 L
.32124 .23077 L
.30769 .24026 L
.28846 .24908 L
.28564 .25 L
.26923 .2537 L
.25 .25491 L
.23077 .25286 L
.2178 .25 L
.21154 .24714 L
.19231 .23655 L
.18369 .23077 L
.17308 .2224 L
.1569 .21154 L
.15385 .20971 L
.13462 .20082 L
.11538 .19495 L
.10541 .19231 L
.09615 .18901 L
.07692 .17992 L
.06611 .17308 L
.05769 .16583 L
.04746 .15385 L
.03846 .13768 L
.03754 .13462 L
.03365 .11538 L
Mistroke
.03505 .09615 L
.03846 .08486 L
.04213 .07692 L
.0574 .05769 L
.05769 .05744 L
.07692 .04521 L
.09615 .0395 L
.10616 .03846 L
.11538 .03842 L
Mfstroke
.5 g
.07692 .3215 m
.09615 .31527 L
.11538 .3146 L
.13462 .31971 L
.14757 .32692 L
.15385 .33304 L
.16336 .34615 L
.17055 .36538 L
.17211 .38462 L
.16848 .40385 L
.15839 .42308 L
.15385 .42866 L
.13624 .44231 L
.13462 .44306 L
.11538 .44932 L
.09615 .44955 L
.07692 .44385 L
.07341 .44231 L
.05769 .43046 L
.05143 .42308 L
.04148 .40385 L
.03846 .3889 L
.0382 .38462 L
.03846 .37682 L
.04043 .36538 L
.04891 .34615 L
.05769 .33502 L
.06695 .32692 L
F
0 g
.07692 .3215 m
.09615 .31527 L
.11538 .3146 L
.13462 .31971 L
.14757 .32692 L
.15385 .33304 L
.16336 .34615 L
.17055 .36538 L
.17211 .38462 L
.16848 .40385 L
.15839 .42308 L
.15385 .42866 L
.13624 .44231 L
.13462 .44306 L
.11538 .44932 L
.09615 .44955 L
.07692 .44385 L
.07341 .44231 L
.05769 .43046 L
.05143 .42308 L
.04148 .40385 L
.03846 .3889 L
.0382 .38462 L
.03846 .37682 L
.04043 .36538 L
.04891 .34615 L
.05769 .33502 L
.06695 .32692 L
.07692 .3215 L
s
.5 g
.09615 .66903 m
.11538 .66261 L
.13462 .66033 L
.15385 .66188 L
.17308 .66745 L
.18515 .67308 L
.19231 .67783 L
.20884 .69231 L
.21154 .69535 L
.22264 .71154 L
.23077 .72994 L
.23103 .73077 L
.23586 .75 L
.23824 .76923 L
.23896 .78846 L
.23652 .80769 L
.23149 .82692 L
.25 .82696 L
.25046 .82692 L
.26923 .81854 L
.28846 .81353 L
.30769 .81088 L
.32692 .81085 L
.34615 .81392 L
.36538 .82086 L
.37652 .82692 L
.38462 .83329 L
.39669 .84615 L
.40385 .85642 L
.4073 .86538 L
.41177 .88462 L
.41095 .90385 L
.40468 .92308 L
.40385 .92492 L
.3908 .94231 L
.38462 .94781 L
.36538 .9589 L
.35725 .96154 L
.34615 .96364 L
.32692 .96328 L
.31844 .96154 L
.30769 .95793 L
.28846 .94673 L
.28315 .94231 L
.26923 .92695 L
.26672 .92308 L
.25646 .90385 L
.25 .88682 L
.24967 .88462 L
.24747 .86538 L
.24377 .84615 L
.23077 .82745 L
.21154 .83751 L
.19231 .84525 L
.1897 .84615 L
.17308 .85138 L
.15385 .85517 L
.13462 .85605 L
.11538 .85355 L
.09615 .84707 L
.09409 .84615 L
.07692 .83556 L
.06709 .82692 L
.05769 .816 L
.05231 .80769 L
.04361 .78846 L
.03941 .76923 L
.03911 .75 L
.04265 .73077 L
.05054 .71154 L
.05769 .70007 L
.06413 .69231 L
.07692 .68054 L
.08791 .67308 L
F
0 g
.09615 .66903 m
.11538 .66261 L
.13462 .66033 L
.15385 .66188 L
.17308 .66745 L
.18515 .67308 L
.19231 .67783 L
.20884 .69231 L
.21154 .69535 L
.22264 .71154 L
.23077 .72994 L
.23103 .73077 L
.23586 .75 L
.23824 .76923 L
.23896 .78846 L
.23652 .80769 L
.23149 .82692 L
.25 .82696 L
.25046 .82692 L
.26923 .81854 L
.28846 .81353 L
.30769 .81088 L
.32692 .81085 L
.34615 .81392 L
.36538 .82086 L
.37652 .82692 L
.38462 .83329 L
.39669 .84615 L
.40385 .85642 L
.4073 .86538 L
.41177 .88462 L
.41095 .90385 L
.40468 .92308 L
.40385 .92492 L
.3908 .94231 L
.38462 .94781 L
.36538 .9589 L
.35725 .96154 L
.34615 .96364 L
.32692 .96328 L
.31844 .96154 L
.30769 .95793 L
.28846 .94673 L
.28315 .94231 L
.26923 .92695 L
.26672 .92308 L
.25646 .90385 L
.25 .88682 L
.24967 .88462 L
.24747 .86538 L
Mistroke
.24377 .84615 L
.23077 .82745 L
.21154 .83751 L
.19231 .84525 L
.1897 .84615 L
.17308 .85138 L
.15385 .85517 L
.13462 .85605 L
.11538 .85355 L
.09615 .84707 L
.09409 .84615 L
.07692 .83556 L
.06709 .82692 L
.05769 .816 L
.05231 .80769 L
.04361 .78846 L
.03941 .76923 L
.03911 .75 L
.04265 .73077 L
.05054 .71154 L
.05769 .70007 L
.06413 .69231 L
.07692 .68054 L
.08791 .67308 L
.09615 .66903 L
Mfstroke
.5 g
.07692 .0573 m
.09615 .05052 L
.11538 .0493 L
.13462 .05241 L
.15134 .05769 L
.15385 .05876 L
.17308 .06646 L
.19231 .0724 L
.21154 .07439 L
.23077 .07378 L
.25 .07326 L
.26923 .07495 L
.28171 .07692 L
.28846 .08025 L
.30769 .09073 L
.31452 .09615 L
.32692 .10975 L
.33047 .11538 L
.33876 .13462 L
.34157 .15385 L
.33964 .17308 L
.33283 .19231 L
.32692 .20278 L
.31977 .21154 L
.30769 .22242 L
.29422 .23077 L
.28846 .23306 L
.26923 .23825 L
.25 .23908 L
.23077 .23573 L
.21648 .23077 L
.21154 .22785 L
.19231 .21529 L
.18724 .21154 L
.17308 .20131 L
.15597 .19231 L
.15385 .19148 L
.13462 .18603 L
.11538 .18192 L
.09615 .17641 L
.08739 .17308 L
.07692 .16708 L
.06129 .15385 L
.05769 .1503 L
.04926 .13462 L
.04469 .11538 L
.04635 .09615 L
.05501 .07692 L
.05769 .0731 L
.07615 .05769 L
F
0 g
.07692 .0573 m
.09615 .05052 L
.11538 .0493 L
.13462 .05241 L
.15134 .05769 L
.15385 .05876 L
.17308 .06646 L
.19231 .0724 L
.21154 .07439 L
.23077 .07378 L
.25 .07326 L
.26923 .07495 L
.28171 .07692 L
.28846 .08025 L
.30769 .09073 L
.31452 .09615 L
.32692 .10975 L
.33047 .11538 L
.33876 .13462 L
.34157 .15385 L
.33964 .17308 L
.33283 .19231 L
.32692 .20278 L
.31977 .21154 L
.30769 .22242 L
.29422 .23077 L
.28846 .23306 L
.26923 .23825 L
.25 .23908 L
.23077 .23573 L
.21648 .23077 L
.21154 .22785 L
.19231 .21529 L
.18724 .21154 L
.17308 .20131 L
.15597 .19231 L
.15385 .19148 L
.13462 .18603 L
.11538 .18192 L
.09615 .17641 L
.08739 .17308 L
.07692 .16708 L
.06129 .15385 L
.05769 .1503 L
.04926 .13462 L
.04469 .11538 L
.04635 .09615 L
.05501 .07692 L
.05769 .0731 L
.07615 .05769 L
Mistroke
.07692 .0573 L
Mfstroke
.6 g
.07692 .33886 m
.09615 .331 L
.11538 .33076 L
.13462 .33839 L
.14402 .34615 L
.15385 .36409 L
.15429 .36538 L
.15676 .38462 L
.15385 .39913 L
.15225 .40385 L
.13753 .42308 L
.13462 .42513 L
.11538 .43373 L
.09615 .43405 L
.07692 .42635 L
.072 .42308 L
.05785 .40385 L
.05769 .4034 L
.05336 .38462 L
.05638 .36538 L
.05769 .36218 L
.06764 .34615 L
F
0 g
.07692 .33886 m
.09615 .331 L
.11538 .33076 L
.13462 .33839 L
.14402 .34615 L
.15385 .36409 L
.15429 .36538 L
.15676 .38462 L
.15385 .39913 L
.15225 .40385 L
.13753 .42308 L
.13462 .42513 L
.11538 .43373 L
.09615 .43405 L
.07692 .42635 L
.072 .42308 L
.05785 .40385 L
.05769 .4034 L
.05336 .38462 L
.05638 .36538 L
.05769 .36218 L
.06764 .34615 L
.07692 .33886 L
s
.6 g
.07692 .0693 m
.09615 .06095 L
.11538 .05956 L
.13462 .06322 L
.15385 .07111 L
.16464 .07692 L
.17308 .08052 L
.19231 .08768 L
.21154 .08953 L
.23077 .08827 L
.25 .08741 L
.26923 .08938 L
.28846 .09598 L
.28883 .09615 L
.30769 .10973 L
.31255 .11538 L
.3231 .13462 L
.32665 .15385 L
.32456 .17308 L
.31628 .19231 L
.30769 .20354 L
.29867 .21154 L
.28846 .21726 L
.26923 .2235 L
.25 .22421 L
.23077 .21977 L
.21372 .21154 L
.21154 .20993 L
.19231 .19556 L
.18823 .19231 L
.17308 .18242 L
.15385 .17551 L
.13704 .17308 L
.13462 .17281 L
.11538 .17028 L
.09615 .16505 L
.07692 .15413 L
.07656 .15385 L
.06066 .13462 L
.05769 .12687 L
.05532 .11538 L
.05741 .09615 L
.05769 .0953 L
.06806 .07692 L
F
0 g
.07692 .0693 m
.09615 .06095 L
.11538 .05956 L
.13462 .06322 L
.15385 .07111 L
.16464 .07692 L
.17308 .08052 L
.19231 .08768 L
.21154 .08953 L
.23077 .08827 L
.25 .08741 L
.26923 .08938 L
.28846 .09598 L
.28883 .09615 L
.30769 .10973 L
.31255 .11538 L
.3231 .13462 L
.32665 .15385 L
.32456 .17308 L
.31628 .19231 L
.30769 .20354 L
.29867 .21154 L
.28846 .21726 L
.26923 .2235 L
.25 .22421 L
.23077 .21977 L
.21372 .21154 L
.21154 .20993 L
.19231 .19556 L
.18823 .19231 L
.17308 .18242 L
.15385 .17551 L
.13704 .17308 L
.13462 .17281 L
.11538 .17028 L
.09615 .16505 L
.07692 .15413 L
.07656 .15385 L
.06066 .13462 L
.05769 .12687 L
.05532 .11538 L
.05741 .09615 L
.05769 .0953 L
.06806 .07692 L
.07692 .0693 L
s
.6 g
.11538 .68444 m
.13462 .6815 L
.15385 .68347 L
.17308 .69084 L
.17583 .69231 L
.19231 .70551 L
.19741 .71154 L
.20837 .73077 L
.21154 .74047 L
.21356 .75 L
.21438 .76923 L
.21154 .78553 L
.21063 .78846 L
.19994 .80769 L
.19231 .81555 L
.17401 .82692 L
.17308 .82732 L
.15385 .83337 L
.13462 .83484 L
.11538 .83171 L
.10085 .82692 L
.09615 .82321 L
.07816 .80769 L
.07692 .80636 L
.06617 .78846 L
.06073 .76923 L
.06034 .75 L
.06491 .73077 L
.0757 .71154 L
.07692 .70995 L
.09615 .69299 L
.09671 .69231 L
F
0 g
.11538 .68444 m
.13462 .6815 L
.15385 .68347 L
.17308 .69084 L
.17583 .69231 L
.19231 .70551 L
.19741 .71154 L
.20837 .73077 L
.21154 .74047 L
.21356 .75 L
.21438 .76923 L
.21154 .78553 L
.21063 .78846 L
.19994 .80769 L
.19231 .81555 L
.17401 .82692 L
.17308 .82732 L
.15385 .83337 L
.13462 .83484 L
.11538 .83171 L
.10085 .82692 L
.09615 .82321 L
.07816 .80769 L
.07692 .80636 L
.06617 .78846 L
.06073 .76923 L
.06034 .75 L
.06491 .73077 L
.0757 .71154 L
.07692 .70995 L
.09615 .69299 L
.09671 .69231 L
.11538 .68444 L
s
.7 g
.09615 .07192 m
.11538 .07 L
.13462 .07482 L
.13999 .07692 L
.15385 .08371 L
.1696 .09615 L
.17308 .09826 L
.19231 .10507 L
.21154 .10635 L
.23077 .1036 L
.25 .10208 L
.26923 .10439 L
.28846 .11333 L
.29135 .11538 L
.30656 .13462 L
.30769 .13759 L
.3113 .15385 L
.30859 .17308 L
.30769 .17545 L
.29775 .19231 L
.28846 .20007 L
.26923 .2082 L
.25 .20894 L
.23077 .20333 L
.21344 .19231 L
.21154 .19091 L
.19231 .17328 L
.19211 .17308 L
.17308 .16259 L
.15385 .15952 L
.13462 .15989 L
.11538 .15872 L
.09754 .15385 L
.09615 .15345 L
.07692 .14047 L
.0731 .13462 L
.06593 .11538 L
.06865 .09615 L
.07692 .08403 L
.08565 .07692 L
F
0 g
.09615 .07192 m
.11538 .07 L
.13462 .07482 L
.13999 .07692 L
.15385 .08371 L
.1696 .09615 L
.17308 .09826 L
.19231 .10507 L
.21154 .10635 L
.23077 .1036 L
.25 .10208 L
.26923 .10439 L
.28846 .11333 L
.29135 .11538 L
.30656 .13462 L
.30769 .13759 L
.3113 .15385 L
.30859 .17308 L
.30769 .17545 L
.29775 .19231 L
.28846 .20007 L
.26923 .2082 L
.25 .20894 L
.23077 .20333 L
.21344 .19231 L
.21154 .19091 L
.19231 .17328 L
.19211 .17308 L
.17308 .16259 L
.15385 .15952 L
.13462 .15989 L
.11538 .15872 L
.09754 .15385 L
.09615 .15345 L
.07692 .14047 L
.0731 .13462 L
.06593 .11538 L
.06865 .09615 L
.07692 .08403 L
.08565 .07692 L
.09615 .07192 L
s
.7 g
.07692 .3638 m
.09615 .34975 L
.11538 .34988 L
.13458 .36538 L
.13462 .36545 L
.13932 .38462 L
.13462 .39881 L
.13128 .40385 L
.11538 .41718 L
.09615 .4177 L
.07855 .40385 L
.07692 .40161 L
.07049 .38462 L
.07576 .36538 L
F
0 g
.07692 .3638 m
.09615 .34975 L
.11538 .34988 L
.13458 .36538 L
.13462 .36545 L
.13932 .38462 L
.13462 .39881 L
.13128 .40385 L
.11538 .41718 L
.09615 .4177 L
.07855 .40385 L
.07692 .40161 L
.07049 .38462 L
.07576 .36538 L
.07692 .3638 L
s
.8 g
.09615 .08519 m
.11538 .07875 L
.13462 .08604 L
.14621 .09615 L
.15385 .10541 L
.15857 .11538 L
.15709 .13462 L
.15385 .13712 L
.13462 .14826 L
.11538 .14797 L
.09615 .14115 L
.08646 .13462 L
.07893 .11538 L
.0833 .09615 L
F
0 g
.09615 .08519 m
.11538 .07875 L
.13462 .08604 L
.14621 .09615 L
.15385 .10541 L
.15857 .11538 L
.15709 .13462 L
.15385 .13712 L
.13462 .14826 L
.11538 .14797 L
.09615 .14115 L
.08646 .13462 L
.07893 .11538 L
.0833 .09615 L
.09615 .08519 L
s
.7 g
.11538 .70992 m
.13462 .70541 L
.15385 .7084 L
.1608 .71154 L
.17308 .71924 L
.18192 .73077 L
.18905 .75 L
.18898 .76923 L
.18118 .78846 L
.17308 .79806 L
.15521 .80769 L
.15385 .80817 L
.13462 .81079 L
.11923 .80769 L
.11538 .80642 L
.09615 .79211 L
.09353 .78846 L
.08484 .76923 L
.08427 .75 L
.09139 .73077 L
.09615 .72345 L
.11089 .71154 L
F
0 g
.11538 .70992 m
.13462 .70541 L
.15385 .7084 L
.1608 .71154 L
.17308 .71924 L
.18192 .73077 L
.18905 .75 L
.18898 .76923 L
.18118 .78846 L
.17308 .79806 L
.15521 .80769 L
.15385 .80817 L
.13462 .81079 L
.11923 .80769 L
.11538 .80642 L
.09615 .79211 L
.09353 .78846 L
.08484 .76923 L
.08427 .75 L
.09139 .73077 L
.09615 .72345 L
.11089 .71154 L
.11538 .70992 L
s
.9 g
.11538 .09973 m
.13139 .11538 L
.11538 .12779 L
.09782 .11538 L
F
0 g
.11538 .09973 m
.13139 .11538 L
.11538 .12779 L
.09782 .11538 L
.11538 .09973 L
s
.8 g
.13462 .74897 m
.14103 .75 L
.13462 .76725 L
.13197 .75 L
F
0 g
.13462 .74897 m
.14103 .75 L
.13462 .76725 L
.13197 .75 L
.13462 .74897 L
s
.1 g
.44036 .01923 m
.42308 .03846 L
.42308 .03847 L
.41074 .05769 L
.40385 .06279 L
.38462 .07165 L
.36538 .06355 L
.35264 .05769 L
.34615 .05151 L
.32692 .04044 L
.32303 .03846 L
.30769 .03183 L
.28846 .02608 L
.26923 .02297 L
.25 .02202 L
.23077 .02247 L
.21154 .02307 L
.19231 .02237 L
.17308 .01975 L
.16989 .01923 L
F
0 g
.44036 .01923 m
.42308 .03846 L
.42308 .03847 L
.41074 .05769 L
.40385 .06279 L
.38462 .07165 L
.36538 .06355 L
.35264 .05769 L
.34615 .05151 L
.32692 .04044 L
.32303 .03846 L
.30769 .03183 L
.28846 .02608 L
.26923 .02297 L
.25 .02202 L
.23077 .02247 L
.21154 .02307 L
.19231 .02237 L
.17308 .01975 L
.16989 .01923 L
s
.44231 .20745 m
.46154 .20708 L
.48077 .20975 L
.4927 .21154 L
.5 .21226 L
.51923 .2136 L
.53846 .21418 L
.55769 .21497 L
.57692 .21909 L
.59281 .23077 L
.59615 .23576 L
.60454 .25 L
.61367 .26923 L
.61538 .27285 L
.62357 .28846 L
.63462 .30692 L
.63513 .30769 L
.6495 .32692 L
.65385 .33203 L
.66747 .34615 L
.67308 .35128 L
.69068 .36538 L
.69231 .36653 L
.71154 .37873 L
.72222 .38462 L
.73077 .38873 L
.75 .39721 L
.76543 .40385 L
.76923 .40509 L
.78846 .41622 L
.79472 .42308 L
.79688 .44231 L
.79059 .46154 L
.78846 .46844 L
.78346 .48077 L
.77707 .5 L
.77208 .51923 L
.76923 .53572 L
.76905 .53846 L
.7681 .55769 L
.76836 .57692 L
.76923 .59615 L
.76923 .59626 L
.76925 .61538 L
.76923 .61556 L
.76486 .63462 L
.75067 .65385 L
.75 .65454 L
.73077 .67141 L
.72872 .67308 L
.71154 .68857 L
.70772 .69231 L
.69231 .70904 L
.69024 .71154 L
.67456 .73077 L
.67308 .7325 L
.65451 .75 L
.65385 .75041 L
.63462 .75854 L
.61538 .76155 L
.59615 .76339 L
.57692 .76588 L
.55897 .76923 L
.55769 .76967 L
.53846 .7771 L
.51923 .78673 L
.51638 .78846 L
.5 .79953 L
.48766 .80769 L
.48077 .81179 L
.46154 .81431 L
.44956 .80769 L
.44231 .80215 L
.42612 .78846 L
.42308 .78534 L
.40385 .76947 L
.40355 .76923 L
.38462 .75535 L
.37837 .75 L
.36538 .73839 L
.35927 .73077 L
.34777 .71154 L
.34615 .70797 L
.33928 .69231 L
.33086 .67308 L
.32692 .66485 L
.32092 .65385 L
.30861 .63462 L
.30769 .63332 L
.29301 .61538 L
.28846 .61052 L
.27324 .59615 L
.26923 .59281 L
.25 .5783 L
.24803 .57692 L
.23077 .56608 L
.21846 .55769 L
.21154 .55284 L
.19751 .53846 L
.19715 .51923 L
.2079 .5 L
.21154 .4932 L
.22044 .48077 L
.23077 .46339 L
.23178 .46154 L
.24056 .44231 L
.24747 .42308 L
.25 .41426 L
.25213 .40385 L
.25545 .38462 L
.25908 .36538 L
.2665 .34615 L
.26923 .34191 L
.28787 .32692 L
.28846 .32657 L
.30769 .31699 L
.32692 .30821 L
.32801 .30769 L
.34615 .2971 L
.35878 .28846 L
.36538 .28312 L
.38023 .26923 L
.38462 .26454 L
.39651 .25 L
.40385 .24056 L
.41045 .23077 L
.42308 .21743 L
.43126 .21154 L
F
.44231 .20745 m
.46154 .20708 L
.48077 .20975 L
.4927 .21154 L
.5 .21226 L
.51923 .2136 L
.53846 .21418 L
.55769 .21497 L
.57692 .21909 L
.59281 .23077 L
.59615 .23576 L
.60454 .25 L
.61367 .26923 L
.61538 .27285 L
.62357 .28846 L
.63462 .30692 L
.63513 .30769 L
.6495 .32692 L
.65385 .33203 L
.66747 .34615 L
.67308 .35128 L
.69068 .36538 L
.69231 .36653 L
.71154 .37873 L
.72222 .38462 L
.73077 .38873 L
.75 .39721 L
.76543 .40385 L
.76923 .40509 L
.78846 .41622 L
.79472 .42308 L
.79688 .44231 L
.79059 .46154 L
.78846 .46844 L
.78346 .48077 L
.77707 .5 L
.77208 .51923 L
.76923 .53572 L
.76905 .53846 L
.7681 .55769 L
.76836 .57692 L
.76923 .59615 L
.76923 .59626 L
.76925 .61538 L
.76923 .61556 L
.76486 .63462 L
.75067 .65385 L
.75 .65454 L
.73077 .67141 L
.72872 .67308 L
Mistroke
.71154 .68857 L
.70772 .69231 L
.69231 .70904 L
.69024 .71154 L
.67456 .73077 L
.67308 .7325 L
.65451 .75 L
.65385 .75041 L
.63462 .75854 L
.61538 .76155 L
.59615 .76339 L
.57692 .76588 L
.55897 .76923 L
.55769 .76967 L
.53846 .7771 L
.51923 .78673 L
.51638 .78846 L
.5 .79953 L
.48766 .80769 L
.48077 .81179 L
.46154 .81431 L
.44956 .80769 L
.44231 .80215 L
.42612 .78846 L
.42308 .78534 L
.40385 .76947 L
.40355 .76923 L
.38462 .75535 L
.37837 .75 L
.36538 .73839 L
.35927 .73077 L
.34777 .71154 L
.34615 .70797 L
.33928 .69231 L
.33086 .67308 L
.32692 .66485 L
.32092 .65385 L
.30861 .63462 L
.30769 .63332 L
.29301 .61538 L
.28846 .61052 L
.27324 .59615 L
.26923 .59281 L
.25 .5783 L
.24803 .57692 L
.23077 .56608 L
.21846 .55769 L
.21154 .55284 L
.19751 .53846 L
.19715 .51923 L
Mistroke
.2079 .5 L
.21154 .4932 L
.22044 .48077 L
.23077 .46339 L
.23178 .46154 L
.24056 .44231 L
.24747 .42308 L
.25 .41426 L
.25213 .40385 L
.25545 .38462 L
.25908 .36538 L
.2665 .34615 L
.26923 .34191 L
.28787 .32692 L
.28846 .32657 L
.30769 .31699 L
.32692 .30821 L
.32801 .30769 L
.34615 .2971 L
.35878 .28846 L
.36538 .28312 L
.38023 .26923 L
.38462 .26454 L
.39651 .25 L
.40385 .24056 L
.41045 .23077 L
.42308 .21743 L
.43126 .21154 L
.44231 .20745 L
Mfstroke
.8 g
.23077 .11973 m
.25 .11797 L
.26923 .12081 L
.28525 .13462 L
.28846 .1393 L
.29346 .15385 L
.28891 .17308 L
.28846 .17378 L
.26923 .18939 L
.25 .19076 L
.23077 .18517 L
.21965 .17308 L
.21154 .1598 L
.20936 .15385 L
.21154 .13594 L
.21265 .13462 L
F
0 g
.23077 .11973 m
.25 .11797 L
.26923 .12081 L
.28525 .13462 L
.28846 .1393 L
.29346 .15385 L
.28891 .17308 L
.28846 .17378 L
.26923 .18939 L
.25 .19076 L
.23077 .18517 L
.21965 .17308 L
.21154 .1598 L
.20936 .15385 L
.21154 .13594 L
.21265 .13462 L
.23077 .11973 L
s
.6 g
.30769 .82386 m
.32692 .82189 L
.34615 .82423 L
.35509 .82692 L
.36538 .83146 L
.38445 .84615 L
.38462 .84632 L
.39717 .86538 L
.4023 .88462 L
.40135 .90385 L
.39391 .92308 L
.38462 .93561 L
.37723 .94231 L
.36538 .9488 L
.34615 .95429 L
.32692 .95388 L
.30769 .94768 L
.29795 .94231 L
.28846 .93436 L
.27901 .92308 L
.26923 .90563 L
.2687 .90385 L
.26405 .88462 L
.26436 .86538 L
.26923 .84969 L
.27145 .84615 L
.28846 .83088 L
.29575 .82692 L
F
0 g
.30769 .82386 m
.32692 .82189 L
.34615 .82423 L
.35509 .82692 L
.36538 .83146 L
.38445 .84615 L
.38462 .84632 L
.39717 .86538 L
.4023 .88462 L
.40135 .90385 L
.39391 .92308 L
.38462 .93561 L
.37723 .94231 L
.36538 .9488 L
.34615 .95429 L
.32692 .95388 L
.30769 .94768 L
.29795 .94231 L
.28846 .93436 L
.27901 .92308 L
.26923 .90563 L
.2687 .90385 L
.26405 .88462 L
.26436 .86538 L
.26923 .84969 L
.27145 .84615 L
.28846 .83088 L
.29575 .82692 L
.30769 .82386 L
s
.7 g
.30769 .83583 m
.32692 .83203 L
.34615 .8339 L
.36538 .84202 L
.37159 .84615 L
.38462 .86044 L
.38707 .86538 L
.39305 .88462 L
.39192 .90385 L
.38462 .92061 L
.38318 .92308 L
.36538 .93891 L
.35732 .94231 L
.34615 .9452 L
.32692 .94474 L
.31824 .94231 L
.30769 .93765 L
.29075 .92308 L
.28846 .92198 L
.27978 .90385 L
.2757 .88462 L
.27819 .86538 L
.28846 .84738 L
.29035 .84615 L
F
0 g
.30769 .83583 m
.32692 .83203 L
.34615 .8339 L
.36538 .84202 L
.37159 .84615 L
.38462 .86044 L
.38707 .86538 L
.39305 .88462 L
.39192 .90385 L
.38462 .92061 L
.38318 .92308 L
.36538 .93891 L
.35732 .94231 L
.34615 .9452 L
.32692 .94474 L
.31824 .94231 L
.30769 .93765 L
.29075 .92308 L
.28846 .92198 L
.27978 .90385 L
.2757 .88462 L
.27819 .86538 L
.28846 .84738 L
.29035 .84615 L
.30769 .83583 L
s
.8 g
.32692 .8422 m
.34615 .84373 L
.35304 .84615 L
.36538 .8523 L
.37707 .86538 L
.38377 .88462 L
.38256 .90385 L
.37148 .92308 L
.36538 .92806 L
.34615 .93629 L
.32692 .93576 L
.30769 .9265 L
.30351 .92308 L
.29036 .90385 L
.28846 .89739 L
.28678 .88462 L
.28846 .87286 L
.29102 .86538 L
.30769 .84777 L
.31213 .84615 L
F
0 g
.32692 .8422 m
.34615 .84373 L
.35304 .84615 L
.36538 .8523 L
.37707 .86538 L
.38377 .88462 L
.38256 .90385 L
.37148 .92308 L
.36538 .92806 L
.34615 .93629 L
.32692 .93576 L
.30769 .9265 L
.30351 .92308 L
.29036 .90385 L
.28846 .89739 L
.28678 .88462 L
.28846 .87286 L
.29102 .86538 L
.30769 .84777 L
.31213 .84615 L
.32692 .8422 L
s
.9 g
.30769 .86248 m
.32692 .85195 L
.34615 .85317 L
.36386 .86538 L
.36538 .86713 L
.37427 .88462 L
.37234 .90385 L
.36538 .91412 L
.35365 .92308 L
.34615 .92598 L
.32692 .92531 L
.32154 .92308 L
.30769 .91248 L
.30153 .90385 L
.29755 .88462 L
.30537 .86538 L
F
0 g
.30769 .86248 m
.32692 .85195 L
.34615 .85317 L
.36386 .86538 L
.36538 .86713 L
.37427 .88462 L
.37234 .90385 L
.36538 .91412 L
.35365 .92308 L
.34615 .92598 L
.32692 .92531 L
.32154 .92308 L
.30769 .91248 L
.30153 .90385 L
.29755 .88462 L
.30537 .86538 L
.30769 .86248 L
s
1 g
.32692 .86641 m
.34615 .86727 L
.36106 .88462 L
.35784 .90385 L
.34615 .91308 L
.32692 .9123 L
.31645 .90385 L
.31154 .88462 L
F
0 g
.32692 .86641 m
.34615 .86727 L
.36106 .88462 L
.35784 .90385 L
.34615 .91308 L
.32692 .9123 L
.31645 .90385 L
.31154 .88462 L
.32692 .86641 L
s
.3854 .01923 m
.38462 .01943 L
.36567 .01923 L
F
.3854 .01923 m
.38462 .01943 L
.36567 .01923 L
s
.1 g
.46154 .38228 m
.48077 .37617 L
.5 .37272 L
.51923 .37226 L
.53846 .37481 L
.55769 .38019 L
.57021 .38462 L
.57692 .38843 L
.59615 .40212 L
.59819 .40385 L
.61519 .42308 L
.61538 .42334 L
.62535 .44231 L
.63283 .46154 L
.63462 .46823 L
.63617 .48077 L
.63691 .5 L
.63541 .51923 L
.63462 .52619 L
.63049 .53846 L
.62188 .55769 L
.61538 .56939 L
.60966 .57692 L
.59615 .59149 L
.59084 .59615 L
.57692 .60562 L
.55853 .61538 L
.55769 .61565 L
.53846 .62084 L
.51923 .6236 L
.5 .62346 L
.48077 .62046 L
.46223 .61538 L
.46154 .61505 L
.44231 .60471 L
.42979 .59615 L
.42308 .59026 L
.41102 .57692 L
.40385 .56733 L
.39899 .55769 L
.39073 .53846 L
.38575 .51923 L
.38462 .51053 L
.38427 .5 L
.38462 .48834 L
.38555 .48077 L
.39025 .46154 L
.39809 .44231 L
.40385 .43095 L
.40944 .42308 L
.42308 .40735 L
.42681 .40385 L
.44231 .39239 L
.45535 .38462 L
F
0 g
.46154 .38228 m
.48077 .37617 L
.5 .37272 L
.51923 .37226 L
.53846 .37481 L
.55769 .38019 L
.57021 .38462 L
.57692 .38843 L
.59615 .40212 L
.59819 .40385 L
.61519 .42308 L
.61538 .42334 L
.62535 .44231 L
.63283 .46154 L
.63462 .46823 L
.63617 .48077 L
.63691 .5 L
.63541 .51923 L
.63462 .52619 L
.63049 .53846 L
.62188 .55769 L
.61538 .56939 L
.60966 .57692 L
.59615 .59149 L
.59084 .59615 L
.57692 .60562 L
.55853 .61538 L
.55769 .61565 L
.53846 .62084 L
.51923 .6236 L
.5 .62346 L
.48077 .62046 L
.46223 .61538 L
.46154 .61505 L
.44231 .60471 L
.42979 .59615 L
.42308 .59026 L
.41102 .57692 L
.40385 .56733 L
.39899 .55769 L
.39073 .53846 L
.38575 .51923 L
.38462 .51053 L
.38427 .5 L
.38462 .48834 L
.38555 .48077 L
.39025 .46154 L
.39809 .44231 L
.40385 .43095 L
.40944 .42308 L
Mistroke
.42308 .40735 L
.42681 .40385 L
.44231 .39239 L
.45535 .38462 L
.46154 .38228 L
Mfstroke
.1 g
.51515 .98077 m
.5 .96529 L
.49884 .96154 L
.48267 .94231 L
.48077 .94014 L
.46154 .92364 L
.44231 .94138 L
.44104 .94231 L
.42346 .96154 L
.42308 .96295 L
.40385 .97922 L
.40156 .98077 L
F
0 g
.51515 .98077 m
.5 .96529 L
.49884 .96154 L
.48267 .94231 L
.48077 .94014 L
.46154 .92364 L
.44231 .94138 L
.44104 .94231 L
.42346 .96154 L
.42308 .96295 L
.40385 .97922 L
.40156 .98077 L
s
.2 g
.48077 .40013 m
.5 .39629 L
.51923 .39598 L
.53846 .39921 L
.55333 .40385 L
.55769 .40625 L
.57692 .41886 L
.58178 .42308 L
.59615 .43986 L
.59767 .44231 L
.60705 .46154 L
.61235 .48077 L
.61379 .5 L
.6115 .51923 L
.60532 .53846 L
.59615 .55593 L
.59488 .55769 L
.57726 .57692 L
.57692 .5772 L
.55769 .58976 L
.54332 .59615 L
.53846 .59733 L
.51923 .60052 L
.5 .60033 L
.48077 .59675 L
.47844 .59615 L
.46154 .58859 L
.44412 .57692 L
.44231 .57534 L
.42658 .55769 L
.42308 .55262 L
.41619 .53846 L
.41018 .51923 L
.40802 .5 L
.40962 .48077 L
.41501 .46154 L
.42308 .44442 L
.4245 .44231 L
.44062 .42308 L
.44231 .42156 L
.46154 .40806 L
.46933 .40385 L
F
0 g
.48077 .40013 m
.5 .39629 L
.51923 .39598 L
.53846 .39921 L
.55333 .40385 L
.55769 .40625 L
.57692 .41886 L
.58178 .42308 L
.59615 .43986 L
.59767 .44231 L
.60705 .46154 L
.61235 .48077 L
.61379 .5 L
.6115 .51923 L
.60532 .53846 L
.59615 .55593 L
.59488 .55769 L
.57726 .57692 L
.57692 .5772 L
.55769 .58976 L
.54332 .59615 L
.53846 .59733 L
.51923 .60052 L
.5 .60033 L
.48077 .59675 L
.47844 .59615 L
.46154 .58859 L
.44412 .57692 L
.44231 .57534 L
.42658 .55769 L
.42308 .55262 L
.41619 .53846 L
.41018 .51923 L
.40802 .5 L
.40962 .48077 L
.41501 .46154 L
.42308 .44442 L
.4245 .44231 L
.44062 .42308 L
.44231 .42156 L
.46154 .40806 L
.46933 .40385 L
.48077 .40013 L
s
.3 g
.48077 .41607 m
.5 .41139 L
.51923 .41108 L
.53846 .41509 L
.55654 .42308 L
.55769 .42391 L
.57692 .44028 L
.57862 .44231 L
.59058 .46154 L
.59615 .47518 L
.59685 .48077 L
.59846 .5 L
.59615 .51879 L
.59605 .51923 L
.58872 .53846 L
.57692 .55603 L
.57541 .55769 L
.55769 .57241 L
.55054 .57692 L
.53846 .5814 L
.51923 .58541 L
.5 .58515 L
.48077 .58061 L
.47119 .57692 L
.46154 .5709 L
.44614 .55769 L
.44231 .55333 L
.43288 .53846 L
.42563 .51923 L
.42308 .5 L
.4249 .48077 L
.43131 .46154 L
.44231 .44349 L
.44331 .44231 L
.46154 .42576 L
.46533 .42308 L
F
0 g
.48077 .41607 m
.5 .41139 L
.51923 .41108 L
.53846 .41509 L
.55654 .42308 L
.55769 .42391 L
.57692 .44028 L
.57862 .44231 L
.59058 .46154 L
.59615 .47518 L
.59685 .48077 L
.59846 .5 L
.59615 .51879 L
.59605 .51923 L
.58872 .53846 L
.57692 .55603 L
.57541 .55769 L
.55769 .57241 L
.55054 .57692 L
.53846 .5814 L
.51923 .58541 L
.5 .58515 L
.48077 .58061 L
.47119 .57692 L
.46154 .5709 L
.44614 .55769 L
.44231 .55333 L
.43288 .53846 L
.42563 .51923 L
.42308 .5 L
.4249 .48077 L
.43131 .46154 L
.44231 .44349 L
.44331 .44231 L
.46154 .42576 L
.46533 .42308 L
.48077 .41607 L
s
.3 g
.55732 .01923 m
.55769 .01963 L
.57692 .03573 L
.57962 .03846 L
.5922 .05769 L
.59615 .06674 L
.59866 .07692 L
.59986 .09615 L
.59642 .11538 L
.59615 .11799 L
.58432 .13462 L
.57692 .14253 L
.55963 .15385 L
.55769 .1548 L
.53846 .1616 L
.51923 .16424 L
.5 .16297 L
.48077 .15772 L
.47166 .15385 L
.46154 .14795 L
.44559 .13462 L
.44231 .13182 L
.43444 .11538 L
.42851 .09615 L
.43045 .07692 L
.43731 .05769 L
.44231 .04762 L
.44945 .03846 L
.46154 .02756 L
.47109 .01923 L
F
0 g
.55732 .01923 m
.55769 .01963 L
.57692 .03573 L
.57962 .03846 L
.5922 .05769 L
.59615 .06674 L
.59866 .07692 L
.59986 .09615 L
.59642 .11538 L
.59615 .11799 L
.58432 .13462 L
.57692 .14253 L
.55963 .15385 L
.55769 .1548 L
.53846 .1616 L
.51923 .16424 L
.5 .16297 L
.48077 .15772 L
.47166 .15385 L
.46154 .14795 L
.44559 .13462 L
.44231 .13182 L
.43444 .11538 L
.42851 .09615 L
.43045 .07692 L
.43731 .05769 L
.44231 .04762 L
.44945 .03846 L
.46154 .02756 L
.47109 .01923 L
s
.4 g
.46154 .44113 m
.48077 .42908 L
.5 .42357 L
.51923 .42323 L
.53846 .42798 L
.55769 .43898 L
.56169 .44231 L
.57689 .46154 L
.57692 .46155 L
.58422 .48077 L
.58623 .5 L
.58328 .51923 L
.57692 .53613 L
.57478 .53846 L
.55769 .5575 L
.55748 .55769 L
.53846 .5685 L
.51923 .5733 L
.5 .57299 L
.48077 .56753 L
.46389 .55769 L
.46154 .5556 L
.44683 .53846 L
.44231 .53232 L
.43834 .51923 L
.43545 .5 L
.43749 .48077 L
.44231 .46334 L
.44489 .46154 L
.46019 .44231 L
F
0 g
.46154 .44113 m
.48077 .42908 L
.5 .42357 L
.51923 .42323 L
.53846 .42798 L
.55769 .43898 L
.56169 .44231 L
.57689 .46154 L
.57692 .46155 L
.58422 .48077 L
.58623 .5 L
.58328 .51923 L
.57692 .53613 L
.57478 .53846 L
.55769 .5575 L
.55748 .55769 L
.53846 .5685 L
.51923 .5733 L
.5 .57299 L
.48077 .56753 L
.46389 .55769 L
.46154 .5556 L
.44683 .53846 L
.44231 .53232 L
.43834 .51923 L
.43545 .5 L
.43749 .48077 L
.44231 .46334 L
.44489 .46154 L
.46019 .44231 L
.46154 .44113 L
s
.47571 .98077 m
.46154 .97553 L
.44408 .98077 L
F
.47571 .98077 m
.46154 .97553 L
.44408 .98077 L
s
.5 g
.48077 .4411 m
.5 .43462 L
.51923 .43423 L
.53846 .43983 L
.54381 .44231 L
.55769 .45345 L
.56411 .46154 L
.5731 .48077 L
.57547 .5 L
.57201 .51923 L
.56151 .53846 L
.55769 .54293 L
.53846 .55675 L
.53629 .55769 L
.51923 .56235 L
.5 .56199 L
.48535 .55769 L
.48077 .55559 L
.46154 .5402 L
.46015 .53846 L
.44964 .51923 L
.4462 .5 L
.44861 .48077 L
.45766 .46154 L
.46154 .45631 L
.47834 .44231 L
F
0 g
.48077 .4411 m
.5 .43462 L
.51923 .43423 L
.53846 .43983 L
.54381 .44231 L
.55769 .45345 L
.56411 .46154 L
.5731 .48077 L
.57547 .5 L
.57201 .51923 L
.56151 .53846 L
.55769 .54293 L
.53846 .55675 L
.53629 .55769 L
.51923 .56235 L
.5 .56199 L
.48535 .55769 L
.48077 .55559 L
.46154 .5402 L
.46015 .53846 L
.44964 .51923 L
.4462 .5 L
.44861 .48077 L
.45766 .46154 L
.46154 .45631 L
.47834 .44231 L
.48077 .4411 L
s
.4 g
.48077 .03376 m
.5 .02644 L
.51923 .02492 L
.53846 .02962 L
.55605 .03846 L
.55769 .04003 L
.57181 .05769 L
.57692 .06955 L
.57881 .07692 L
.57935 .09615 L
.57692 .10648 L
.57299 .11538 L
.55769 .13329 L
.55616 .13462 L
.53846 .14371 L
.51923 .14756 L
.5 .14608 L
.48077 .13888 L
.47375 .13462 L
.46154 .12369 L
.45639 .11538 L
.44957 .09615 L
.45 .07692 L
.457 .05769 L
.46154 .04987 L
.47254 .03846 L
F
0 g
.48077 .03376 m
.5 .02644 L
.51923 .02492 L
.53846 .02962 L
.55605 .03846 L
.55769 .04003 L
.57181 .05769 L
.57692 .06955 L
.57881 .07692 L
.57935 .09615 L
.57692 .10648 L
.57299 .11538 L
.55769 .13329 L
.55616 .13462 L
.53846 .14371 L
.51923 .14756 L
.5 .14608 L
.48077 .13888 L
.47375 .13462 L
.46154 .12369 L
.45639 .11538 L
.44957 .09615 L
.45 .07692 L
.457 .05769 L
.46154 .04987 L
.47254 .03846 L
.48077 .03376 L
s
.6 g
.48077 .45288 m
.5 .44502 L
.51923 .44459 L
.53846 .45131 L
.55153 .46154 L
.55769 .46666 L
.56225 .48077 L
.56513 .5 L
.56093 .51923 L
.55769 .52757 L
.54814 .53846 L
.53846 .54516 L
.51923 .55204 L
.5 .55162 L
.48077 .54364 L
.47377 .53846 L
.46154 .52168 L
.46074 .51923 L
.45656 .5 L
.45947 .48077 L
.46154 .4726 L
.47033 .46154 L
F
0 g
.48077 .45288 m
.5 .44502 L
.51923 .44459 L
.53846 .45131 L
.55153 .46154 L
.55769 .46666 L
.56225 .48077 L
.56513 .5 L
.56093 .51923 L
.55769 .52757 L
.54814 .53846 L
.53846 .54516 L
.51923 .55204 L
.5 .55162 L
.48077 .54364 L
.47377 .53846 L
.46154 .52168 L
.46074 .51923 L
.45656 .5 L
.45947 .48077 L
.46154 .4726 L
.47033 .46154 L
.48077 .45288 L
s
.7 g
.5 .45576 m
.51923 .45518 L
.53441 .46154 L
.53846 .46229 L
.55161 .48077 L
.55492 .5 L
.55 .51923 L
.53846 .53411 L
.52792 .53846 L
.51923 .54127 L
.5 .54071 L
.4937 .53846 L
.48077 .53223 L
.47187 .51923 L
.46669 .5 L
.47021 .48077 L
.48077 .46331 L
.48732 .46154 L
F
0 g
.5 .45576 m
.51923 .45518 L
.53441 .46154 L
.53846 .46229 L
.55161 .48077 L
.55492 .5 L
.55 .51923 L
.53846 .53411 L
.52792 .53846 L
.51923 .54127 L
.5 .54071 L
.4937 .53846 L
.48077 .53223 L
.47187 .51923 L
.46669 .5 L
.47021 .48077 L
.48077 .46331 L
.48732 .46154 L
.5 .45576 L
s
.5 g
.48077 .05314 m
.5 .04154 L
.51923 .03991 L
.53846 .04579 L
.55239 .05769 L
.55769 .06834 L
.56063 .07692 L
.56062 .09615 L
.55769 .10447 L
.55179 .11538 L
.53846 .12565 L
.51923 .13125 L
.5 .12944 L
.48077 .1181 L
.47822 .11538 L
.46779 .09615 L
.46762 .07692 L
.47691 .05769 L
F
0 g
.48077 .05314 m
.5 .04154 L
.51923 .03991 L
.53846 .04579 L
.55239 .05769 L
.55769 .06834 L
.56063 .07692 L
.56062 .09615 L
.55769 .10447 L
.55179 .11538 L
.53846 .12565 L
.51923 .13125 L
.5 .12944 L
.48077 .1181 L
.47822 .11538 L
.46779 .09615 L
.46762 .07692 L
.47691 .05769 L
.48077 .05314 L
s
.8 g
.5 .46443 m
.51923 .46388 L
.53745 .48077 L
.53846 .48243 L
.54322 .5 L
.53846 .51409 L
.53483 .51923 L
.51923 .53129 L
.5 .53051 L
.48684 .51923 L
.48077 .5087 L
.4788 .5 L
.48077 .48792 L
.48425 .48077 L
F
0 g
.5 .46443 m
.51923 .46388 L
.53745 .48077 L
.53846 .48243 L
.54322 .5 L
.53846 .51409 L
.53483 .51923 L
.51923 .53129 L
.5 .53051 L
.48684 .51923 L
.48077 .5087 L
.4788 .5 L
.48077 .48792 L
.48425 .48077 L
.5 .46443 L
s
.6 g
.5 .06409 m
.51923 .06047 L
.53846 .07609 L
.53888 .07692 L
.53846 .09527 L
.53808 .09615 L
.51923 .1104 L
.5 .10674 L
.49049 .09615 L
.48961 .07692 L
F
0 g
.5 .06409 m
.51923 .06047 L
.53846 .07609 L
.53888 .07692 L
.53846 .09527 L
.53808 .09615 L
.51923 .1104 L
.5 .10674 L
.49049 .09615 L
.48961 .07692 L
.5 .06409 L
s
.3 g
.98077 .46714 m
.9706 .46154 L
.96154 .45541 L
.94231 .44815 L
.92308 .44465 L
.90385 .44499 L
.88462 .44948 L
.86538 .45839 L
.86005 .46154 L
.84615 .47326 L
.83911 .48077 L
.82692 .49834 L
.82604 .5 L
.81796 .51923 L
.8135 .53846 L
.81232 .55769 L
.81419 .57692 L
.81886 .59615 L
.82596 .61538 L
.82692 .61651 L
.83499 .63462 L
.84353 .65385 L
.84229 .67308 L
.82692 .68838 L
.81117 .69231 L
.80769 .69409 L
.78846 .70375 L
.77488 .71154 L
.76923 .71536 L
.75022 .73077 L
.75 .73097 L
.73306 .75 L
.73077 .75307 L
.72035 .76923 L
.71154 .78466 L
.7097 .78846 L
.69844 .80769 L
.69231 .81197 L
.67308 .81696 L
.65385 .81289 L
.63462 .80769 L
.63462 .80769 L
.61538 .80424 L
.59615 .80315 L
.57692 .80496 L
.56215 .80769 L
.55769 .8103 L
.53846 .82027 L
.52932 .82692 L
.51923 .83632 L
.51153 .84615 L
.5 .86416 L
.49946 .86538 L
.49294 .88462 L
.49159 .90385 L
.49534 .92308 L
.5 .93639 L
.50399 .94231 L
.51741 .96154 L
.51923 .96367 L
.53846 .97999 L
.53957 .98077 L
.98077 .98077 L
F
0 g
.98077 .46714 m
.9706 .46154 L
.96154 .45541 L
.94231 .44815 L
.92308 .44465 L
.90385 .44499 L
.88462 .44948 L
.86538 .45839 L
.86005 .46154 L
.84615 .47326 L
.83911 .48077 L
.82692 .49834 L
.82604 .5 L
.81796 .51923 L
.8135 .53846 L
.81232 .55769 L
.81419 .57692 L
.81886 .59615 L
.82596 .61538 L
.82692 .61651 L
.83499 .63462 L
.84353 .65385 L
.84229 .67308 L
.82692 .68838 L
.81117 .69231 L
.80769 .69409 L
.78846 .70375 L
.77488 .71154 L
.76923 .71536 L
.75022 .73077 L
.75 .73097 L
.73306 .75 L
.73077 .75307 L
.72035 .76923 L
.71154 .78466 L
.7097 .78846 L
.69844 .80769 L
.69231 .81197 L
.67308 .81696 L
.65385 .81289 L
.63462 .80769 L
.63462 .80769 L
.61538 .80424 L
.59615 .80315 L
.57692 .80496 L
.56215 .80769 L
.55769 .8103 L
.53846 .82027 L
.52932 .82692 L
.51923 .83632 L
Mistroke
.51153 .84615 L
.5 .86416 L
.49946 .86538 L
.49294 .88462 L
.49159 .90385 L
.49534 .92308 L
.5 .93639 L
.50399 .94231 L
.51741 .96154 L
.51923 .96367 L
.53846 .97999 L
.53957 .98077 L
Mfstroke
.9 g
.5 .48782 m
.51923 .48575 L
.52584 .5 L
.51923 .51082 L
.5 .50879 L
.49577 .5 L
F
0 g
.5 .48782 m
.51923 .48575 L
.52584 .5 L
.51923 .51082 L
.5 .50879 L
.49577 .5 L
.5 .48782 L
s
.4 g
.61677 .98077 m
.63462 .97329 L
.65224 .96154 L
.65385 .96018 L
.67048 .94231 L
.67308 .93933 L
.68169 .92308 L
.69231 .90396 L
.69234 .90385 L
.69934 .88462 L
.71154 .87065 L
.72403 .88462 L
.73077 .89133 L
.74466 .90385 L
.75 .90846 L
.76923 .92308 L
.76923 .92308 L
.78846 .93422 L
.80769 .94182 L
.80935 .94231 L
.82692 .94601 L
.84615 .94705 L
.86538 .94496 L
.87843 .94231 L
.88462 .93952 L
.90385 .93016 L
.91434 .92308 L
.92308 .91568 L
.93416 .90385 L
.94231 .89263 L
.94689 .88462 L
.95498 .86538 L
.9594 .84615 L
.96056 .82692 L
.95858 .80769 L
.95335 .78846 L
.94464 .76923 L
.94231 .76515 L
.93192 .75 L
.92308 .73988 L
.91424 .73077 L
.90385 .7236 L
.88611 .71154 L
.88462 .71096 L
.86538 .70889 L
.84615 .70699 L
.82692 .70968 L
.81828 .71154 L
.80769 .71566 L
.78846 .72474 L
.7786 .73077 L
.76923 .73785 L
.75634 .75 L
.75 .75737 L
.74165 .76923 L
.73126 .78846 L
.73077 .78941 L
.72397 .80769 L
.71848 .82692 L
.71242 .84615 L
.71154 .84988 L
.69231 .85815 L
.67796 .84615 L
.67308 .84263 L
.65385 .83073 L
.64586 .82692 L
.63462 .82219 L
.61538 .81695 L
.59615 .81512 L
.57692 .81702 L
.55769 .82312 L
.54974 .82692 L
.53846 .83478 L
.5267 .84615 L
.51923 .85565 L
.51434 .86538 L
.5078 .88462 L
.50628 .90385 L
.50984 .92308 L
.51822 .94231 L
.51923 .9441 L
.53394 .96154 L
.53846 .96534 L
.55769 .97695 L
.56799 .98077 L
F
0 g
.61677 .98077 m
.63462 .97329 L
.65224 .96154 L
.65385 .96018 L
.67048 .94231 L
.67308 .93933 L
.68169 .92308 L
.69231 .90396 L
.69234 .90385 L
.69934 .88462 L
.71154 .87065 L
.72403 .88462 L
.73077 .89133 L
.74466 .90385 L
.75 .90846 L
.76923 .92308 L
.76923 .92308 L
.78846 .93422 L
.80769 .94182 L
.80935 .94231 L
.82692 .94601 L
.84615 .94705 L
.86538 .94496 L
.87843 .94231 L
.88462 .93952 L
.90385 .93016 L
.91434 .92308 L
.92308 .91568 L
.93416 .90385 L
.94231 .89263 L
.94689 .88462 L
.95498 .86538 L
.9594 .84615 L
.96056 .82692 L
.95858 .80769 L
.95335 .78846 L
.94464 .76923 L
.94231 .76515 L
.93192 .75 L
.92308 .73988 L
.91424 .73077 L
.90385 .7236 L
.88611 .71154 L
.88462 .71096 L
.86538 .70889 L
.84615 .70699 L
.82692 .70968 L
.81828 .71154 L
.80769 .71566 L
.78846 .72474 L
Mistroke
.7786 .73077 L
.76923 .73785 L
.75634 .75 L
.75 .75737 L
.74165 .76923 L
.73126 .78846 L
.73077 .78941 L
.72397 .80769 L
.71848 .82692 L
.71242 .84615 L
.71154 .84988 L
.69231 .85815 L
.67796 .84615 L
.67308 .84263 L
.65385 .83073 L
.64586 .82692 L
.63462 .82219 L
.61538 .81695 L
.59615 .81512 L
.57692 .81702 L
.55769 .82312 L
.54974 .82692 L
.53846 .83478 L
.5267 .84615 L
.51923 .85565 L
.51434 .86538 L
.5078 .88462 L
.50628 .90385 L
.50984 .92308 L
.51822 .94231 L
.51923 .9441 L
.53394 .96154 L
.53846 .96534 L
.55769 .97695 L
.56799 .98077 L
Mfstroke
.5 g
.59615 .82548 m
.61068 .82692 L
.61538 .8279 L
.63462 .83484 L
.65222 .84615 L
.65385 .84739 L
.66835 .86538 L
.67308 .87506 L
.67527 .88462 L
.67387 .90385 L
.67308 .90949 L
.66786 .92308 L
.65588 .94231 L
.65385 .94486 L
.63462 .96138 L
.63443 .96154 L
.61538 .97023 L
.59615 .97373 L
.57692 .97231 L
.55769 .96561 L
.55023 .96154 L
.53846 .95171 L
.53071 .94231 L
.5208 .92308 L
.51923 .91783 L
.5172 .90385 L
.51868 .88462 L
.51923 .88218 L
.52601 .86538 L
.53846 .84852 L
.54092 .84615 L
.55769 .83444 L
.57692 .82741 L
.57934 .82692 L
F
0 g
.59615 .82548 m
.61068 .82692 L
.61538 .8279 L
.63462 .83484 L
.65222 .84615 L
.65385 .84739 L
.66835 .86538 L
.67308 .87506 L
.67527 .88462 L
.67387 .90385 L
.67308 .90949 L
.66786 .92308 L
.65588 .94231 L
.65385 .94486 L
.63462 .96138 L
.63443 .96154 L
.61538 .97023 L
.59615 .97373 L
.57692 .97231 L
.55769 .96561 L
.55023 .96154 L
.53846 .95171 L
.53071 .94231 L
.5208 .92308 L
.51923 .91783 L
.5172 .90385 L
.51868 .88462 L
.51923 .88218 L
.52601 .86538 L
.53846 .84852 L
.54092 .84615 L
.55769 .83444 L
.57692 .82741 L
.57934 .82692 L
.59615 .82548 L
s
.6 g
.55769 .84536 m
.57692 .83718 L
.59615 .83507 L
.61538 .83819 L
.63349 .84615 L
.63462 .84708 L
.65326 .86538 L
.65385 .86629 L
.66091 .88462 L
.66148 .90385 L
.65578 .92308 L
.65385 .92769 L
.64271 .94231 L
.63462 .9497 L
.61538 .96034 L
.61169 .96154 L
.59615 .96432 L
.57692 .96273 L
.57255 .96154 L
.55769 .95493 L
.54263 .94231 L
.53846 .93804 L
.53118 .92308 L
.52695 .90385 L
.52879 .88462 L
.53723 .86538 L
.53846 .86343 L
.55637 .84615 L
F
0 g
.55769 .84536 m
.57692 .83718 L
.59615 .83507 L
.61538 .83819 L
.63349 .84615 L
.63462 .84708 L
.65326 .86538 L
.65385 .86629 L
.66091 .88462 L
.66148 .90385 L
.65578 .92308 L
.65385 .92769 L
.64271 .94231 L
.63462 .9497 L
.61538 .96034 L
.61169 .96154 L
.59615 .96432 L
.57692 .96273 L
.57255 .96154 L
.55769 .95493 L
.54263 .94231 L
.53846 .93804 L
.53118 .92308 L
.52695 .90385 L
.52879 .88462 L
.53723 .86538 L
.53846 .86343 L
.55637 .84615 L
.55769 .84536 L
s
.7 g
.59615 .84438 m
.60827 .84615 L
.61538 .8482 L
.63462 .85986 L
.63959 .86538 L
.64958 .88462 L
.6508 .90385 L
.6447 .92308 L
.63462 .938 L
.62992 .94231 L
.61538 .95051 L
.59615 .95528 L
.57692 .95339 L
.55769 .94365 L
.55596 .94231 L
.54114 .92308 L
.53846 .9154 L
.53636 .90385 L
.53846 .88471 L
.53849 .88462 L
.54835 .86538 L
.55769 .85623 L
.57692 .8467 L
.5791 .84615 L
F
0 g
.59615 .84438 m
.60827 .84615 L
.61538 .8482 L
.63462 .85986 L
.63959 .86538 L
.64958 .88462 L
.6508 .90385 L
.6447 .92308 L
.63462 .938 L
.62992 .94231 L
.61538 .95051 L
.59615 .95528 L
.57692 .95339 L
.55769 .94365 L
.55596 .94231 L
.54114 .92308 L
.53846 .9154 L
.53636 .90385 L
.53846 .88471 L
.53849 .88462 L
.54835 .86538 L
.55769 .85623 L
.57692 .8467 L
.5791 .84615 L
.59615 .84438 L
s
.8 g
.57692 .85624 m
.59615 .85353 L
.61538 .85865 L
.62665 .86538 L
.63462 .87675 L
.63833 .88462 L
.64027 .90385 L
.63462 .92067 L
.63357 .92308 L
.61538 .9405 L
.61019 .94231 L
.59615 .94584 L
.57692 .94346 L
.57404 .94231 L
.55769 .93239 L
.55168 .92308 L
.54557 .90385 L
.54814 .88462 L
.55769 .86942 L
.56184 .86538 L
F
0 g
.57692 .85624 m
.59615 .85353 L
.61538 .85865 L
.62665 .86538 L
.63462 .87675 L
.63833 .88462 L
.64027 .90385 L
.63462 .92067 L
.63357 .92308 L
.61538 .9405 L
.61019 .94231 L
.59615 .94584 L
.57692 .94346 L
.57404 .94231 L
.55769 .93239 L
.55168 .92308 L
.54557 .90385 L
.54814 .88462 L
.55769 .86942 L
.56184 .86538 L
.57692 .85624 L
s
.9 g
.59615 .86413 m
.60262 .86538 L
.61538 .8715 L
.62772 .88462 L
.63029 .90385 L
.62115 .92308 L
.61538 .92855 L
.59615 .93693 L
.57692 .93402 L
.56464 .92308 L
.55769 .91038 L
.55621 .90385 L
.55769 .88984 L
.5597 .88462 L
.57692 .86767 L
.58334 .86538 L
F
0 g
.59615 .86413 m
.60262 .86538 L
.61538 .8715 L
.62772 .88462 L
.63029 .90385 L
.62115 .92308 L
.61538 .92855 L
.59615 .93693 L
.57692 .93402 L
.56464 .92308 L
.55769 .91038 L
.55621 .90385 L
.55769 .88984 L
.5597 .88462 L
.57692 .86767 L
.58334 .86538 L
.59615 .86413 L
s
1 g
.57692 .88268 m
.59615 .87712 L
.61025 .88462 L
.61538 .8945 L
.61573 .90385 L
.61538 .90498 L
.59615 .92268 L
.57692 .91732 L
.56931 .90385 L
.57495 .88462 L
F
0 g
.57692 .88268 m
.59615 .87712 L
.61025 .88462 L
.61538 .8945 L
.61573 .90385 L
.61538 .90498 L
.59615 .92268 L
.57692 .91732 L
.56931 .90385 L
.57495 .88462 L
.57692 .88268 L
s
.1 g
.73419 .01923 m
.73077 .02112 L
.71154 .03333 L
.70467 .03846 L
.69231 .04801 L
.6817 .05769 L
.67308 .0636 L
.65385 .07572 L
.63462 .07232 L
.62204 .05769 L
.61538 .04842 L
.60688 .03846 L
.59615 .02615 L
.58963 .01923 L
F
0 g
.73419 .01923 m
.73077 .02112 L
.71154 .03333 L
.70467 .03846 L
.69231 .04801 L
.6817 .05769 L
.67308 .0636 L
.65385 .07572 L
.63462 .07232 L
.62204 .05769 L
.61538 .04842 L
.60688 .03846 L
.59615 .02615 L
.58963 .01923 L
s
.2 g
.98077 .64154 m
.96539 .65385 L
.96154 .65605 L
.94231 .66883 L
.93824 .67308 L
.92308 .69053 L
.92286 .69231 L
.92308 .69631 L
.92956 .71154 L
.94231 .73072 L
.94234 .73077 L
.95478 .75 L
.96154 .76218 L
.96496 .76923 L
.97229 .78846 L
.97674 .80769 L
.97844 .82692 L
.97744 .84615 L
.97365 .86538 L
.96676 .88462 L
.96154 .89515 L
.95622 .90385 L
.94231 .92164 L
.94096 .92308 L
.92308 .93876 L
.91806 .94231 L
.90385 .95049 L
.88462 .95839 L
.87526 .96154 L
.86538 .96312 L
.84615 .96496 L
.82692 .96404 L
.81247 .96154 L
.80769 .96038 L
.78846 .95392 L
.76923 .94485 L
.76495 .94231 L
.75 .93403 L
.73077 .92473 L
.71154 .92472 L
.69231 .94018 L
.68981 .94231 L
.67308 .96 L
.67136 .96154 L
.65385 .97573 L
.64618 .98077 L
.98077 .98077 L
F
0 g
.98077 .64154 m
.96539 .65385 L
.96154 .65605 L
.94231 .66883 L
.93824 .67308 L
.92308 .69053 L
.92286 .69231 L
.92308 .69631 L
.92956 .71154 L
.94231 .73072 L
.94234 .73077 L
.95478 .75 L
.96154 .76218 L
.96496 .76923 L
.97229 .78846 L
.97674 .80769 L
.97844 .82692 L
.97744 .84615 L
.97365 .86538 L
.96676 .88462 L
.96154 .89515 L
.95622 .90385 L
.94231 .92164 L
.94096 .92308 L
.92308 .93876 L
.91806 .94231 L
.90385 .95049 L
.88462 .95839 L
.87526 .96154 L
.86538 .96312 L
.84615 .96496 L
.82692 .96404 L
.81247 .96154 L
.80769 .96038 L
.78846 .95392 L
.76923 .94485 L
.76495 .94231 L
.75 .93403 L
.73077 .92473 L
.71154 .92472 L
.69231 .94018 L
.68981 .94231 L
.67308 .96 L
.67136 .96154 L
.65385 .97573 L
.64618 .98077 L
s
.3 g
.98077 .20266 m
.97933 .21154 L
.97435 .23077 L
.9666 .25 L
.96154 .2597 L
.95563 .26923 L
.94231 .28658 L
.94062 .28846 L
.92308 .30503 L
.91975 .30769 L
.90385 .31844 L
.88771 .32692 L
.88462 .32821 L
.86538 .33478 L
.84615 .33869 L
.82692 .34008 L
.80769 .33909 L
.78846 .33576 L
.76923 .32997 L
.76146 .32692 L
.75 .32136 L
.73077 .30936 L
.72852 .30769 L
.71154 .29284 L
.70737 .28846 L
.69231 .26932 L
.69225 .26923 L
.68125 .25 L
.67329 .23077 L
.67308 .23021 L
.66794 .21154 L
.66474 .19231 L
.6636 .17308 L
.66484 .15385 L
.66917 .13462 L
.67308 .1213 L
.67617 .11538 L
.68815 .09615 L
.69231 .09003 L
.70374 .07692 L
.71154 .06901 L
.72478 .05769 L
.73077 .05325 L
.75 .04145 L
.75589 .03846 L
.76923 .0329 L
.78846 .02717 L
.80769 .02398 L
.82692 .02318 L
.84615 .02471 L
.86538 .02866 L
.88462 .03525 L
.89189 .03846 L
.90385 .04484 L
.92261 .05769 L
.92308 .05807 L
.94231 .07638 L
.94279 .07692 L
.95725 .09615 L
.96154 .10318 L
.96778 .11538 L
.97515 .13462 L
.97979 .15385 L
.98077 .1602 L
F
0 g
.98077 .20266 m
.97933 .21154 L
.97435 .23077 L
.9666 .25 L
.96154 .2597 L
.95563 .26923 L
.94231 .28658 L
.94062 .28846 L
.92308 .30503 L
.91975 .30769 L
.90385 .31844 L
.88771 .32692 L
.88462 .32821 L
.86538 .33478 L
.84615 .33869 L
.82692 .34008 L
.80769 .33909 L
.78846 .33576 L
.76923 .32997 L
.76146 .32692 L
.75 .32136 L
.73077 .30936 L
.72852 .30769 L
.71154 .29284 L
.70737 .28846 L
.69231 .26932 L
.69225 .26923 L
.68125 .25 L
.67329 .23077 L
.67308 .23021 L
.66794 .21154 L
.66474 .19231 L
.6636 .17308 L
.66484 .15385 L
.66917 .13462 L
.67308 .1213 L
.67617 .11538 L
.68815 .09615 L
.69231 .09003 L
.70374 .07692 L
.71154 .06901 L
.72478 .05769 L
.73077 .05325 L
.75 .04145 L
.75589 .03846 L
.76923 .0329 L
.78846 .02717 L
.80769 .02398 L
.82692 .02318 L
.84615 .02471 L
Mistroke
.86538 .02866 L
.88462 .03525 L
.89189 .03846 L
.90385 .04484 L
.92261 .05769 L
.92308 .05807 L
.94231 .07638 L
.94279 .07692 L
.95725 .09615 L
.96154 .10318 L
.96778 .11538 L
.97515 .13462 L
.97979 .15385 L
.98077 .1602 L
Mfstroke
.1 g
.79693 .98077 m
.78846 .97802 L
.76923 .97054 L
.75 .96203 L
.74883 .96154 L
.73077 .9558 L
.71154 .95721 L
.70226 .96154 L
.69231 .9679 L
.67432 .98077 L
F
0 g
.79693 .98077 m
.78846 .97802 L
.76923 .97054 L
.75 .96203 L
.74883 .96154 L
.73077 .9558 L
.71154 .95721 L
.70226 .96154 L
.69231 .9679 L
.67432 .98077 L
s
.4 g
.76923 .05622 m
.78846 .0495 L
.80769 .04578 L
.82692 .04484 L
.84615 .04663 L
.86538 .05125 L
.88205 .05769 L
.88462 .059 L
.90385 .0706 L
.91199 .07692 L
.92308 .08738 L
.9307 .09615 L
.94231 .11314 L
.94356 .11538 L
.9523 .13462 L
.95776 .15385 L
.96032 .17308 L
.96015 .19231 L
.95722 .21154 L
.95135 .23077 L
.94231 .24972 L
.94214 .25 L
.92867 .26923 L
.92308 .27552 L
.909 .28846 L
.90385 .29236 L
.88462 .304 L
.87691 .30769 L
.86538 .31179 L
.84615 .31639 L
.82692 .31814 L
.80769 .31715 L
.78846 .3134 L
.77144 .30769 L
.76923 .30665 L
.75 .29633 L
.73897 .28846 L
.73077 .28139 L
.71924 .26923 L
.71154 .25918 L
.70574 .25 L
.69645 .23077 L
.69231 .2193 L
.69046 .21154 L
.68733 .19231 L
.68685 .17308 L
.68912 .15385 L
.69231 .13962 L
.69444 .13462 L
.70342 .11538 L
.71154 .10263 L
.71659 .09615 L
.73077 .08119 L
.73566 .07692 L
.75 .06646 L
.76588 .05769 L
F
0 g
.76923 .05622 m
.78846 .0495 L
.80769 .04578 L
.82692 .04484 L
.84615 .04663 L
.86538 .05125 L
.88205 .05769 L
.88462 .059 L
.90385 .0706 L
.91199 .07692 L
.92308 .08738 L
.9307 .09615 L
.94231 .11314 L
.94356 .11538 L
.9523 .13462 L
.95776 .15385 L
.96032 .17308 L
.96015 .19231 L
.95722 .21154 L
.95135 .23077 L
.94231 .24972 L
.94214 .25 L
.92867 .26923 L
.92308 .27552 L
.909 .28846 L
.90385 .29236 L
.88462 .304 L
.87691 .30769 L
.86538 .31179 L
.84615 .31639 L
.82692 .31814 L
.80769 .31715 L
.78846 .3134 L
.77144 .30769 L
.76923 .30665 L
.75 .29633 L
.73897 .28846 L
.73077 .28139 L
.71924 .26923 L
.71154 .25918 L
.70574 .25 L
.69645 .23077 L
.69231 .2193 L
.69046 .21154 L
.68733 .19231 L
.68685 .17308 L
.68912 .15385 L
.69231 .13962 L
.69444 .13462 L
.70342 .11538 L
Mistroke
.71154 .10263 L
.71659 .09615 L
.73077 .08119 L
.73566 .07692 L
.75 .06646 L
.76588 .05769 L
.76923 .05622 L
Mfstroke
.5 g
.78846 .06944 m
.80769 .06509 L
.82692 .064 L
.84615 .06608 L
.86538 .07151 L
.8779 .07692 L
.88462 .08082 L
.90385 .09531 L
.90475 .09615 L
.92111 .11538 L
.92308 .11828 L
.93169 .13462 L
.93814 .15385 L
.94113 .17308 L
.94092 .19231 L
.9375 .21154 L
.93057 .23077 L
.92308 .24463 L
.91936 .25 L
.90385 .26759 L
.90205 .26923 L
.88462 .28208 L
.87279 .28846 L
.86538 .29141 L
.84615 .29684 L
.82692 .29891 L
.80769 .2978 L
.78846 .29343 L
.77503 .28846 L
.76923 .2854 L
.75 .27273 L
.74586 .26923 L
.73077 .25302 L
.72854 .25 L
.7173 .23077 L
.71154 .21631 L
.71032 .21154 L
.70683 .19231 L
.70652 .17308 L
.70941 .15385 L
.71154 .14495 L
.71584 .13462 L
.72653 .11538 L
.73077 .10953 L
.74298 .09615 L
.75 .09005 L
.76923 .07745 L
.77015 .07692 L
F
0 g
.78846 .06944 m
.80769 .06509 L
.82692 .064 L
.84615 .06608 L
.86538 .07151 L
.8779 .07692 L
.88462 .08082 L
.90385 .09531 L
.90475 .09615 L
.92111 .11538 L
.92308 .11828 L
.93169 .13462 L
.93814 .15385 L
.94113 .17308 L
.94092 .19231 L
.9375 .21154 L
.93057 .23077 L
.92308 .24463 L
.91936 .25 L
.90385 .26759 L
.90205 .26923 L
.88462 .28208 L
.87279 .28846 L
.86538 .29141 L
.84615 .29684 L
.82692 .29891 L
.80769 .2978 L
.78846 .29343 L
.77503 .28846 L
.76923 .2854 L
.75 .27273 L
.74586 .26923 L
.73077 .25302 L
.72854 .25 L
.7173 .23077 L
.71154 .21631 L
.71032 .21154 L
.70683 .19231 L
.70652 .17308 L
.70941 .15385 L
.71154 .14495 L
.71584 .13462 L
.72653 .11538 L
.73077 .10953 L
.74298 .09615 L
.75 .09005 L
.76923 .07745 L
.77015 .07692 L
.78846 .06944 L
s
.6 g
.78846 .08866 m
.80769 .08345 L
.82692 .08216 L
.84615 .08462 L
.86538 .09117 L
.87516 .09615 L
.88462 .10276 L
.89818 .11538 L
.90385 .12226 L
.91155 .13462 L
.91936 .15385 L
.9229 .17308 L
.92266 .19231 L
.9186 .21154 L
.91016 .23077 L
.90385 .24059 L
.89587 .25 L
.88462 .26012 L
.87062 .26923 L
.86538 .2717 L
.84615 .27826 L
.82692 .28072 L
.80769 .27942 L
.78846 .2742 L
.77701 .26923 L
.76923 .26435 L
.75206 .25 L
.75 .2478 L
.73772 .23077 L
.73077 .2164 L
.72928 .21154 L
.72517 .19231 L
.72489 .17308 L
.72842 .15385 L
.73077 .14569 L
.73623 .13462 L
.74971 .11538 L
.75 .11506 L
.76923 .09851 L
.7727 .09615 L
F
0 g
.78846 .08866 m
.80769 .08345 L
.82692 .08216 L
.84615 .08462 L
.86538 .09117 L
.87516 .09615 L
.88462 .10276 L
.89818 .11538 L
.90385 .12226 L
.91155 .13462 L
.91936 .15385 L
.9229 .17308 L
.92266 .19231 L
.9186 .21154 L
.91016 .23077 L
.90385 .24059 L
.89587 .25 L
.88462 .26012 L
.87062 .26923 L
.86538 .2717 L
.84615 .27826 L
.82692 .28072 L
.80769 .27942 L
.78846 .2742 L
.77701 .26923 L
.76923 .26435 L
.75206 .25 L
.75 .2478 L
.73772 .23077 L
.73077 .2164 L
.72928 .21154 L
.72517 .19231 L
.72489 .17308 L
.72842 .15385 L
.73077 .14569 L
.73623 .13462 L
.74971 .11538 L
.75 .11506 L
.76923 .09851 L
.7727 .09615 L
.78846 .08866 L
s
.5 g
.82692 .72747 m
.84615 .72538 L
.86538 .72717 L
.88183 .73077 L
.88462 .73341 L
.90385 .74558 L
.90918 .75 L
.92308 .76536 L
.92585 .76923 L
.93644 .78846 L
.94231 .80612 L
.94256 .80769 L
.94485 .82692 L
.94352 .84615 L
.94231 .8523 L
.93838 .86538 L
.92874 .88462 L
.92308 .89266 L
.91279 .90385 L
.90385 .9113 L
.88462 .92255 L
.88391 .92308 L
.86538 .92893 L
.84615 .93136 L
.82692 .93015 L
.80769 .92523 L
.80179 .92308 L
.78846 .91617 L
.77135 .90385 L
.76923 .90201 L
.75357 .88462 L
.75 .88011 L
.74358 .86538 L
.73839 .84615 L
.73832 .82692 L
.74203 .80769 L
.7492 .78846 L
.75 .78674 L
.7608 .76923 L
.76923 .75922 L
.77918 .75 L
.78846 .7433 L
.80769 .73326 L
.81136 .73077 L
F
0 g
.82692 .72747 m
.84615 .72538 L
.86538 .72717 L
.88183 .73077 L
.88462 .73341 L
.90385 .74558 L
.90918 .75 L
.92308 .76536 L
.92585 .76923 L
.93644 .78846 L
.94231 .80612 L
.94256 .80769 L
.94485 .82692 L
.94352 .84615 L
.94231 .8523 L
.93838 .86538 L
.92874 .88462 L
.92308 .89266 L
.91279 .90385 L
.90385 .9113 L
.88462 .92255 L
.88391 .92308 L
.86538 .92893 L
.84615 .93136 L
.82692 .93015 L
.80769 .92523 L
.80179 .92308 L
.78846 .91617 L
.77135 .90385 L
.76923 .90201 L
.75357 .88462 L
.75 .88011 L
.74358 .86538 L
.73839 .84615 L
.73832 .82692 L
.74203 .80769 L
.7492 .78846 L
.75 .78674 L
.7608 .76923 L
.76923 .75922 L
.77918 .75 L
.78846 .7433 L
.80769 .73326 L
.81136 .73077 L
.82692 .72747 L
s
.7 g
.78846 .10861 m
.80769 .10207 L
.82692 .10049 L
.84615 .10353 L
.86538 .11185 L
.87101 .11538 L
.88462 .12764 L
.89006 .13462 L
.90011 .15385 L
.90385 .16844 L
.90447 .17308 L
.90417 .19231 L
.90385 .19445 L
.89916 .21154 L
.88818 .23077 L
.88462 .23516 L
.86708 .25 L
.86538 .25099 L
.84615 .25934 L
.82692 .26239 L
.80769 .26079 L
.78846 .25424 L
.78041 .25 L
.76923 .24128 L
.75963 .23077 L
.75 .2148 L
.74878 .21154 L
.74367 .19231 L
.74336 .17308 L
.74778 .15385 L
.75 .14751 L
.75775 .13462 L
.76923 .12156 L
.7766 .11538 L
F
0 g
.78846 .10861 m
.80769 .10207 L
.82692 .10049 L
.84615 .10353 L
.86538 .11185 L
.87101 .11538 L
.88462 .12764 L
.89006 .13462 L
.90011 .15385 L
.90385 .16844 L
.90447 .17308 L
.90417 .19231 L
.90385 .19445 L
.89916 .21154 L
.88818 .23077 L
.88462 .23516 L
.86708 .25 L
.86538 .25099 L
.84615 .25934 L
.82692 .26239 L
.80769 .26079 L
.78846 .25424 L
.78041 .25 L
.76923 .24128 L
.75963 .23077 L
.75 .2148 L
.74878 .21154 L
.74367 .19231 L
.74336 .17308 L
.74778 .15385 L
.75 .14751 L
.75775 .13462 L
.76923 .12156 L
.7766 .11538 L
.78846 .10861 L
s
.6 g
.80769 .74963 m
.82692 .74325 L
.84615 .74136 L
.86538 .74394 L
.88294 .75 L
.88462 .75163 L
.90385 .76627 L
.90668 .76923 L
.92007 .78846 L
.92308 .79286 L
.9274 .80769 L
.93011 .82692 L
.92854 .84615 L
.92308 .86391 L
.92244 .86538 L
.9106 .88462 L
.90385 .89202 L
.88871 .90385 L
.88462 .90611 L
.86538 .91377 L
.84615 .91663 L
.82692 .91521 L
.80769 .90934 L
.79655 .90385 L
.78846 .89817 L
.7741 .88462 L
.76923 .87881 L
.76175 .86538 L
.75565 .84615 L
.75464 .82692 L
.75803 .80769 L
.766 .78846 L
.76923 .78285 L
.78007 .76923 L
.78846 .76154 L
.80684 .75 L
F
0 g
.80769 .74963 m
.82692 .74325 L
.84615 .74136 L
.86538 .74394 L
.88294 .75 L
.88462 .75163 L
.90385 .76627 L
.90668 .76923 L
.92007 .78846 L
.92308 .79286 L
.9274 .80769 L
.93011 .82692 L
.92854 .84615 L
.92308 .86391 L
.92244 .86538 L
.9106 .88462 L
.90385 .89202 L
.88871 .90385 L
.88462 .90611 L
.86538 .91377 L
.84615 .91663 L
.82692 .91521 L
.80769 .90934 L
.79655 .90385 L
.78846 .89817 L
.7741 .88462 L
.76923 .87881 L
.76175 .86538 L
.75565 .84615 L
.75464 .82692 L
.75803 .80769 L
.766 .78846 L
.76923 .78285 L
.78007 .76923 L
.78846 .76154 L
.80684 .75 L
.80769 .74963 L
s
.8 g
.78846 .13191 m
.80769 .12259 L
.82692 .12049 L
.84615 .12457 L
.86389 .13462 L
.86538 .1364 L
.87847 .15385 L
.88424 .17308 L
.88386 .19231 L
.87713 .21154 L
.86538 .22665 L
.86152 .23077 L
.84615 .23825 L
.82692 .24238 L
.80769 .24025 L
.78846 .23086 L
.78832 .23077 L
.77089 .21154 L
.76923 .20804 L
.76398 .19231 L
.76357 .17308 L
.76923 .1548 L
.76965 .15385 L
.7848 .13462 L
F
0 g
.78846 .13191 m
.80769 .12259 L
.82692 .12049 L
.84615 .12457 L
.86389 .13462 L
.86538 .1364 L
.87847 .15385 L
.88424 .17308 L
.88386 .19231 L
.87713 .21154 L
.86538 .22665 L
.86152 .23077 L
.84615 .23825 L
.82692 .24238 L
.80769 .24025 L
.78846 .23086 L
.78832 .23077 L
.77089 .21154 L
.76923 .20804 L
.76398 .19231 L
.76357 .17308 L
.76923 .1548 L
.76965 .15385 L
.7848 .13462 L
.78846 .13191 L
s
.7 g
.80769 .76621 m
.82692 .75858 L
.84615 .7566 L
.86538 .75994 L
.88427 .76923 L
.88462 .76965 L
.90294 .78846 L
.90385 .78929 L
.91219 .80769 L
.91547 .82692 L
.91359 .84615 L
.90601 .86538 L
.90385 .86916 L
.89033 .88462 L
.88462 .88894 L
.86538 .89853 L
.84615 .90196 L
.82692 .90026 L
.80769 .89304 L
.79508 .88462 L
.78846 .87832 L
.77921 .86538 L
.77166 .84615 L
.77005 .82692 L
.77365 .80769 L
.78328 .78846 L
.78846 .78168 L
.80254 .76923 L
F
0 g
.80769 .76621 m
.82692 .75858 L
.84615 .7566 L
.86538 .75994 L
.88427 .76923 L
.88462 .76965 L
.90294 .78846 L
.90385 .78929 L
.91219 .80769 L
.91547 .82692 L
.91359 .84615 L
.90601 .86538 L
.90385 .86916 L
.89033 .88462 L
.88462 .88894 L
.86538 .89853 L
.84615 .90196 L
.82692 .90026 L
.80769 .89304 L
.79508 .88462 L
.78846 .87832 L
.77921 .86538 L
.77166 .84615 L
.77005 .82692 L
.77365 .80769 L
.78328 .78846 L
.78846 .78168 L
.80254 .76923 L
.80769 .76621 L
s
.8 g
.80769 .78494 m
.82692 .77475 L
.84615 .77245 L
.86538 .77678 L
.88335 .78846 L
.88462 .78974 L
.89578 .80769 L
.89996 .82692 L
.89761 .84615 L
.88724 .86538 L
.88462 .86849 L
.86538 .88201 L
.85696 .88462 L
.84615 .88632 L
.82897 .88462 L
.82692 .88411 L
.80769 .87467 L
.79819 .86538 L
.78846 .84646 L
.78837 .84615 L
.78602 .82692 L
.78846 .81346 L
.79036 .80769 L
.80356 .78846 L
F
0 g
.80769 .78494 m
.82692 .77475 L
.84615 .77245 L
.86538 .77678 L
.88335 .78846 L
.88462 .78974 L
.89578 .80769 L
.89996 .82692 L
.89761 .84615 L
.88724 .86538 L
.88462 .86849 L
.86538 .88201 L
.85696 .88462 L
.84615 .88632 L
.82897 .88462 L
.82692 .88411 L
.80769 .87467 L
.79819 .86538 L
.78846 .84646 L
.78837 .84615 L
.78602 .82692 L
.78846 .81346 L
.79036 .80769 L
.80356 .78846 L
.80769 .78494 L
s
.9 g
.80769 .15039 m
.82692 .14597 L
.84479 .15385 L
.84615 .15493 L
.85972 .17308 L
.85902 .19231 L
.84615 .20792 L
.84092 .21154 L
.82692 .21645 L
.80769 .21202 L
.80694 .21154 L
.79113 .19231 L
.7904 .17308 L
.80312 .15385 L
F
0 g
.80769 .15039 m
.82692 .14597 L
.84479 .15385 L
.84615 .15493 L
.85972 .17308 L
.85902 .19231 L
.84615 .20792 L
.84092 .21154 L
.82692 .21645 L
.80769 .21202 L
.80694 .21154 L
.79113 .19231 L
.7904 .17308 L
.80312 .15385 L
.80769 .15039 L
s
.9 g
.82692 .79297 m
.84615 .7903 L
.86538 .7964 L
.87638 .80769 L
.88236 .82692 L
.87937 .84615 L
.86538 .8604 L
.85594 .86538 L
.84615 .86772 L
.83003 .86538 L
.82692 .86412 L
.80864 .84615 L
.80769 .84401 L
.80476 .82692 L
.80769 .8154 L
.81188 .80769 L
F
0 g
.82692 .79297 m
.84615 .7903 L
.86538 .7964 L
.87638 .80769 L
.88236 .82692 L
.87937 .84615 L
.86538 .8604 L
.85594 .86538 L
.84615 .86772 L
.83003 .86538 L
.82692 .86412 L
.80864 .84615 L
.80769 .84401 L
.80476 .82692 L
.80769 .8154 L
.81188 .80769 L
.82692 .79297 L
s
.4 g
.98077 .62221 m
.96552 .63462 L
.96154 .63775 L
.94231 .64792 L
.92571 .65385 L
.92308 .65399 L
.90385 .65653 L
.88821 .65385 L
.88462 .65231 L
.86538 .63757 L
.85906 .63462 L
.84615 .6182 L
.84411 .61538 L
.83422 .59615 L
.82822 .57692 L
.82692 .56966 L
.82588 .55769 L
.82692 .53966 L
.82711 .53846 L
.8323 .51923 L
.84218 .5 L
.84615 .4944 L
.85904 .48077 L
.86538 .4759 L
.88462 .46533 L
.89653 .46154 L
.90385 .46019 L
.92308 .4595 L
.93715 .46154 L
.94231 .46289 L
.96154 .471 L
.97373 .48077 L
.98077 .48499 L
F
0 g
.98077 .62221 m
.96552 .63462 L
.96154 .63775 L
.94231 .64792 L
.92571 .65385 L
.92308 .65399 L
.90385 .65653 L
.88821 .65385 L
.88462 .65231 L
.86538 .63757 L
.85906 .63462 L
.84615 .6182 L
.84411 .61538 L
.83422 .59615 L
.82822 .57692 L
.82692 .56966 L
.82588 .55769 L
.82692 .53966 L
.82711 .53846 L
.8323 .51923 L
.84218 .5 L
.84615 .4944 L
.85904 .48077 L
.86538 .4759 L
.88462 .46533 L
.89653 .46154 L
.90385 .46019 L
.92308 .4595 L
.93715 .46154 L
.94231 .46289 L
.96154 .471 L
.97373 .48077 L
.98077 .48499 L
s
.5 g
.98077 .60417 m
.9685 .61538 L
.96154 .62254 L
.94231 .63315 L
.93844 .63462 L
.92308 .63813 L
.90385 .63819 L
.88848 .63462 L
.88462 .63289 L
.86538 .61929 L
.86136 .61538 L
.84805 .59615 L
.84615 .59323 L
.84067 .57692 L
.8378 .55769 L
.83917 .53846 L
.84515 .51923 L
.84615 .51691 L
.85715 .5 L
.86538 .49154 L
.88057 .48077 L
.88462 .47893 L
.90385 .47291 L
.92308 .47192 L
.94231 .4757 L
.95574 .48077 L
.96154 .48491 L
.97733 .5 L
.98077 .50234 L
F
0 g
.98077 .60417 m
.9685 .61538 L
.96154 .62254 L
.94231 .63315 L
.93844 .63462 L
.92308 .63813 L
.90385 .63819 L
.88848 .63462 L
.88462 .63289 L
.86538 .61929 L
.86136 .61538 L
.84805 .59615 L
.84615 .59323 L
.84067 .57692 L
.8378 .55769 L
.83917 .53846 L
.84515 .51923 L
.84615 .51691 L
.85715 .5 L
.86538 .49154 L
.88057 .48077 L
.88462 .47893 L
.90385 .47291 L
.92308 .47192 L
.94231 .4757 L
.95574 .48077 L
.96154 .48491 L
.97733 .5 L
.98077 .50234 L
s
.6 g
.98077 .58403 m
.9704 .59615 L
.96154 .60828 L
.95271 .61538 L
.94231 .6201 L
.92308 .62531 L
.90385 .62473 L
.88462 .61771 L
.8804 .61538 L
.86538 .60131 L
.86161 .59615 L
.8523 .57692 L
.84881 .55769 L
.85035 .53846 L
.85746 .51923 L
.86538 .50725 L
.87242 .5 L
.88462 .49164 L
.90385 .48444 L
.92308 .4832 L
.94231 .48751 L
.96154 .49866 L
.96266 .5 L
.97731 .51923 L
.98077 .52338 L
F
0 g
.98077 .58403 m
.9704 .59615 L
.96154 .60828 L
.95271 .61538 L
.94231 .6201 L
.92308 .62531 L
.90385 .62473 L
.88462 .61771 L
.8804 .61538 L
.86538 .60131 L
.86161 .59615 L
.8523 .57692 L
.84881 .55769 L
.85035 .53846 L
.85746 .51923 L
.86538 .50725 L
.87242 .5 L
.88462 .49164 L
.90385 .48444 L
.92308 .4832 L
.94231 .48751 L
.96154 .49866 L
.96266 .5 L
.97731 .51923 L
.98077 .52338 L
s
.7 g
.90385 .49579 m
.92308 .49425 L
.94231 .49942 L
.94381 .5 L
.96154 .51328 L
.96463 .51923 L
.97214 .53846 L
.9741 .55769 L
.96907 .57692 L
.96154 .59359 L
.95907 .59615 L
.94231 .60774 L
.92308 .61341 L
.90385 .61235 L
.88462 .60358 L
.8758 .59615 L
.86538 .58072 L
.86405 .57692 L
.85967 .55769 L
.86148 .53846 L
.86538 .52781 L
.86995 .51923 L
.88462 .50441 L
.89259 .5 L
F
0 g
.90385 .49579 m
.92308 .49425 L
.94231 .49942 L
.94381 .5 L
.96154 .51328 L
.96463 .51923 L
.97214 .53846 L
.9741 .55769 L
.96907 .57692 L
.96154 .59359 L
.95907 .59615 L
.94231 .60774 L
.92308 .61341 L
.90385 .61235 L
.88462 .60358 L
.8758 .59615 L
.86538 .58072 L
.86405 .57692 L
.85967 .55769 L
.86148 .53846 L
.86538 .52781 L
.86995 .51923 L
.88462 .50441 L
.89259 .5 L
.90385 .49579 L
s
.8 g
.90385 .50732 m
.92308 .50541 L
.94231 .51184 L
.9527 .51923 L
.96154 .53455 L
.96258 .53846 L
.96401 .55769 L
.96154 .57155 L
.95959 .57692 L
.94231 .59482 L
.93911 .59615 L
.92308 .6014 L
.90385 .59973 L
.8957 .59615 L
.88462 .58923 L
.87627 .57692 L
.87069 .55769 L
.87282 .53846 L
.88462 .51965 L
.88503 .51923 L
F
0 g
.90385 .50732 m
.92308 .50541 L
.94231 .51184 L
.9527 .51923 L
.96154 .53455 L
.96258 .53846 L
.96401 .55769 L
.96154 .57155 L
.95959 .57692 L
.94231 .59482 L
.93911 .59615 L
.92308 .6014 L
.90385 .59973 L
.8957 .59615 L
.88462 .58923 L
.87627 .57692 L
.87069 .55769 L
.87282 .53846 L
.88462 .51965 L
.88503 .51923 L
.90385 .50732 L
s
.9 g
.92308 .51883 m
.92506 .51923 L
.94231 .5286 L
.95056 .53846 L
.9536 .55769 L
.94332 .57692 L
.94231 .578 L
.92308 .58928 L
.90385 .5867 L
.89269 .57692 L
.88462 .56105 L
.88396 .55769 L
.88462 .54595 L
.88709 .53846 L
.90385 .52168 L
.91143 .51923 L
F
0 g
.92308 .51883 m
.92506 .51923 L
.94231 .5286 L
.95056 .53846 L
.9536 .55769 L
.94332 .57692 L
.94231 .578 L
.92308 .58928 L
.90385 .5867 L
.89269 .57692 L
.88462 .56105 L
.88396 .55769 L
.88462 .54595 L
.88709 .53846 L
.90385 .52168 L
.91143 .51923 L
.92308 .51883 L
s
.1 g
.98077 .90647 m
.97012 .92308 L
.96154 .93367 L
.95335 .94231 L
.94231 .95211 L
.92946 .96154 L
.92308 .96553 L
.90385 .97519 L
.88815 .98077 L
.98077 .98077 L
F
0 g
.98077 .90647 m
.97012 .92308 L
.96154 .93367 L
.95335 .94231 L
.94231 .95211 L
.92946 .96154 L
.92308 .96553 L
.90385 .97519 L
.88815 .98077 L
s
1 g
.92308 .53816 m
.92388 .53846 L
.93298 .55769 L
.92308 .56809 L
.90385 .55972 L
.90308 .55769 L
.90385 .54706 L
.91278 .53846 L
F
0 g
.92308 .53816 m
.92388 .53846 L
.93298 .55769 L
.92308 .56809 L
.90385 .55972 L
.90308 .55769 L
.90385 .54706 L
.91278 .53846 L
.92308 .53816 L
s
.1 g
.98077 .08287 m
.97688 .07692 L
.96176 .05769 L
.96154 .05744 L
.94231 .03897 L
.94169 .03846 L
.92308 .02495 L
.91339 .01923 L
.98077 .01923 L
F
0 g
.98077 .08287 m
.97688 .07692 L
.96176 .05769 L
.96154 .05744 L
.94231 .03897 L
.94169 .03846 L
.92308 .02495 L
.91339 .01923 L
s
.98077 .96401 m
.96211 .98077 L
.98077 .98077 L
F
.98077 .96401 m
.96211 .98077 L
s
.1 g
.98077 .74897 m
.97223 .73077 L
.96494 .71154 L
.96523 .69231 L
.97724 .67308 L
.98077 .66868 L
F
0 g
.98077 .74897 m
.97223 .73077 L
.96494 .71154 L
.96523 .69231 L
.97724 .67308 L
.98077 .66868 L
s
.98077 .40707 m
.97814 .40385 L
.96534 .38462 L
.96991 .36538 L
.98077 .34989 L
F
.98077 .40707 m
.97814 .40385 L
.96534 .38462 L
.96991 .36538 L
.98077 .34989 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.479 .801 1 r
.39874 .60569 .40495 .6085 .41517 .60672 .40896 .60459 Mtetra
.429 .808 .992 r
.40896 .60459 .41517 .60672 .42543 .60494 .41924 .60348 Mtetra
.385 .811 .969 r
.41924 .60348 .42543 .60494 .43575 .60304 .42957 .60219 Mtetra
.36 .814 .938 r
.42957 .60219 .43575 .60304 .44611 .60091 .43996 .60057 Mtetra
.361 .825 .913 r
.43996 .60057 .44611 .60091 .45653 .59847 .45041 .59846 Mtetra
.387 .844 .902 r
.45041 .59846 .45653 .59847 .467 .59567 .46091 .59582 Mtetra
.42 .863 .901 r
.46091 .59582 .467 .59567 .47751 .59257 .47147 .59275 Mtetra
.424 .866 .9 r
.47147 .59275 .47751 .59257 .48807 .58941 .48207 .5896 Mtetra
.336 .817 .869 r
.48207 .5896 .48807 .58941 .49866 .58664 .49271 .58709 Mtetra
0 0 0 r
.49271 .58709 .49866 .58664 .50929 .58497 .50338 .58637 Mtetra
.423 0 0 r
.50338 .58637 .50929 .58497 .51997 .58529 .51409 .58885 Mtetra
.668 .2 .132 r
.51409 .58885 .51997 .58529 .53072 .58833 .52489 .59569 Mtetra
.728 .34 .315 r
.52489 .59569 .53072 .58833 .54156 .59412 .5358 .60699 Mtetra
.722 .38 .398 r
.5358 .60699 .54156 .59412 .55252 .60154 .54687 .62095 Mtetra
.684 .37 .437 r
.54687 .62095 .55252 .60154 .56358 .60823 .55808 .6338 Mtetra
.621 .327 .449 r
.55808 .6338 .56358 .60823 .57469 .61128 .56937 .64079 Mtetra
.528 .252 .44 r
.56937 .64079 .57469 .61128 .58578 .60851 .58061 .63835 Mtetra
.397 .139 .402 r
.58061 .63835 .58578 .60851 .5968 .59957 .59171 .62589 Mtetra
.214 0 .319 r
.59171 .62589 .5968 .59957 .60771 .58615 .60264 .6062 Mtetra
0 0 .163 r
.60264 .6062 .60771 .58615 .61856 .57118 .61343 .58407 Mtetra
0 0 0 r
.61343 .58407 .61856 .57118 .62941 .55759 .62422 .56418 Mtetra
.59 .83 .453 r
.62422 .56418 .62941 .55759 .64036 .54748 .63511 .54981 Mtetra
.513 .898 .732 r
.63511 .54981 .64036 .54748 .65149 .54202 .64624 .5427 Mtetra
.183 0 0 r
.64624 .5427 .65149 .54202 .66286 .5417 .65771 .54354 Mtetra
.689 .18 .023 r
.65771 .54354 .66286 .5417 .67452 .54653 .66959 .55227 Mtetra
.778 .367 .273 r
.66959 .55227 .67452 .54653 .6865 .55577 .68191 .56777 Mtetra
.765 .408 .379 r
.68191 .56777 .6865 .55577 .69874 .56751 .6946 .58715 Mtetra
.719 .396 .43 r
.6946 .58715 .69874 .56751 .71109 .5785 .70744 .60555 Mtetra
.651 .352 .452 r
.70744 .60555 .71109 .5785 .72332 .58497 .72011 .61714 Mtetra
.558 .282 .453 r
.72011 .61714 .72332 .58497 .73521 .58399 .73224 .61741 Mtetra
.436 .184 .432 r
.73224 .61741 .73521 .58399 .74664 .57494 .74367 .60539 Mtetra
.285 .056 .38 r
.74367 .60539 .74664 .57494 .75767 .55985 .75446 .5842 Mtetra
.107 0 .289 r
.75446 .5842 .75767 .55985 .76849 .54238 .76493 .55947 Mtetra
0 0 .145 r
.76493 .55947 .76849 .54238 .77936 .52621 .77545 .53675 Mtetra
0 0 0 r
.77545 .53675 .77936 .52621 .79048 .51375 .78632 .51966 Mtetra
.78632 .51966 .79048 .51375 .80196 .5058 .7977 .50934 Mtetra
.007 0 0 r
.7977 .50934 .80196 .5058 .81381 .50188 .80959 .50504 Mtetra
.312 0 0 r
.80959 .50504 .81381 .50188 .82596 .50085 .82191 .50504 Mtetra
.481 0 0 r
.82191 .50504 .82596 .50085 .83834 .50138 .83452 .5074 Mtetra
.535 .068 .091 r
.83452 .5074 .83834 .50138 .85083 .50228 .84729 .51034 Mtetra
.53 .101 .171 r
.84729 .51034 .85083 .50228 .86334 .50256 .86007 .51239 Mtetra
.493 .094 .212 r
.86007 .51239 .86334 .50256 .87579 .50145 .87274 .51243 Mtetra
.435 .058 .223 r
.87274 .51243 .87579 .50145 .88811 .49851 .8852 .50978 Mtetra
.357 0 .206 r
.8852 .50978 .88811 .49851 .90026 .4936 .89739 .50425 Mtetra
.253 0 .157 r
.89739 .50425 .90026 .4936 .91225 .4869 .90933 .4961 Mtetra
.113 0 .063 r
.90933 .4961 .91225 .4869 .92411 .47884 .92104 .48597 Mtetra
0 0 0 r
.92104 .48597 .92411 .47884 .93588 .47 .93262 .47471 Mtetra
.93262 .47471 .93588 .47 .94765 .46098 .94416 .46321 Mtetra
.603 .905 .629 r
.94416 .46321 .94765 .46098 .95947 .45228 .95577 .4522 Mtetra
.761 .996 .832 r
.95577 .4522 .95947 .45228 .9714 .44426 .9675 .44219 Mtetra
.272 .739 .946 r
.39242 .6039 .39874 .60569 .40896 .60459 .40265 .60373 Mtetra
.152 .685 .854 r
.40265 .60373 .40896 .60459 .41924 .60348 .41293 .60355 Mtetra
.058 .624 .74 r
.41293 .60355 .41924 .60348 .42957 .60219 .42327 .60311 Mtetra
0 0 0 r
.42327 .60311 .42957 .60219 .43996 .60057 .43369 .60218 Mtetra
.43369 .60218 .43996 .60057 .45041 .59846 .44417 .60054 Mtetra
.44417 .60054 .45041 .59846 .46091 .59582 .45472 .59812 Mtetra
.45472 .59812 .46091 .59582 .47147 .59275 .46533 .59505 Mtetra
.46533 .59505 .47147 .59275 .48207 .5896 .47598 .59185 Mtetra
.47598 .59185 .48207 .5896 .49271 .58709 .48667 .58954 Mtetra
.294 0 0 r
.48667 .58954 .49271 .58709 .50338 .58637 .49738 .58978 Mtetra
.604 .113 .061 r
.49738 .58978 .50338 .58637 .51409 .58885 .50813 .59459 Mtetra
.736 .329 .279 r
.50813 .59459 .51409 .58885 .52489 .59569 .51896 .60566 Mtetra
.767 .414 .385 r
.51896 .60566 .52489 .59569 .5358 .60699 .52994 .6232 Mtetra
.755 .432 .438 r
.52994 .6232 .5358 .60699 .54687 .62095 .54111 .64468 Mtetra
.715 .413 .465 r
.54111 .64468 .54687 .62095 .55808 .6338 .55248 .66466 Mtetra
.646 .36 .472 r
.55248 .66466 .55808 .6338 .56937 .64079 .56395 .67624 Mtetra
.538 .271 .458 r
.56395 .67624 .56937 .64079 .58061 .63835 .57536 .67411 Mtetra
.374 .131 .413 r
.57536 .67411 .58061 .63835 .59171 .62589 .58657 .65743 Mtetra
.135 0 .313 r
.58657 .65743 .59171 .62589 .60264 .6062 .59752 .63033 Mtetra
0 0 .134 r
.59752 .63033 .60264 .6062 .61343 .58407 .60828 .59978 Mtetra
0 0 0 r
.60828 .59978 .61343 .58407 .62422 .56418 .61899 .57253 Mtetra
.696 .844 .418 r
.61899 .57253 .62422 .56418 .63511 .54981 .62983 .55315 Mtetra
.572 .906 .668 r
.62983 .55315 .63511 .54981 .64624 .5427 .64095 .54396 Mtetra
.33 0 0 r
.64095 .54396 .64624 .5427 .65771 .54354 .65251 .54578 Mtetra
.765 .296 .132 r
.65251 .54578 .65771 .54354 .66959 .55227 .66459 .55846 Mtetra
.821 .433 .317 r
.66459 .55846 .66959 .55227 .68191 .56777 .67725 .58046 Mtetra
.804 .456 .399 r
.67725 .58046 .68191 .56777 .6946 .58715 .69039 .6079 Mtetra
.757 .435 .441 r
.69039 .6079 .6946 .58715 .70744 .60555 .70374 .63419 Mtetra
.681 .381 .46 r
.70374 .63419 .70744 .60555 .72011 .61714 .71685 .65129 Mtetra
.568 .293 .458 r
.71685 .65129 .72011 .61714 .73224 .61741 .72924 .65294 Mtetra
.408 .163 .428 r
.72924 .65294 .73224 .61741 .74367 .60539 .74066 .63777 Mtetra
.196 0 .357 r
.74066 .63777 .74367 .60539 .75446 .5842 .75124 .61014 Mtetra
0 0 .239 r
.75124 .61014 .75446 .5842 .76493 .55947 .76136 .57782 Mtetra
0 0 .081 r
.76136 .57782 .76493 .55947 .77545 .53675 .77154 .54839 Mtetra
0 0 0 r
.77154 .54839 .77545 .53675 .78632 .51966 .78218 .52671 Mtetra
.78218 .52671 .78632 .51966 .7977 .50934 .79348 .51424 Mtetra
.13 0 0 r
.79348 .51424 .7977 .50934 .80959 .50504 .80545 .50995 Mtetra
.464 0 0 r
.80545 .50995 .80959 .50504 .82191 .50504 .81798 .51149 Mtetra
.589 .133 .137 r
.81798 .51149 .82191 .50504 .83452 .5074 .8309 .51625 Mtetra
.612 .195 .228 r
.8309 .51625 .83452 .5074 .84729 .51034 .84401 .52179 Mtetra
.591 .205 .28 r
.84401 .52179 .84729 .51034 .86007 .51239 .85711 .52607 Mtetra
.545 .185 .307 r
.85711 .52607 .86007 .51239 .87274 .51243 .87004 .52756 Mtetra
.483 .142 .313 r
.87004 .52756 .87274 .51243 .8852 .50978 .88266 .52529 Mtetra
.403 .078 .298 r
.88266 .52529 .8852 .50978 .89739 .50425 .8949 .51899 Mtetra
.301 0 .259 r
.8949 .51899 .89739 .50425 .90933 .4961 .90676 .50903 Mtetra
.17 0 .186 r
.90676 .50903 .90933 .4961 .92104 .48597 .91829 .49632 Mtetra
0 0 .062 r
.91829 .49632 .92104 .48597 .93262 .47471 .92962 .48206 Mtetra
0 0 0 r
.92962 .48206 .93262 .47471 .94416 .46321 .94089 .46749 Mtetra
.94089 .46749 .94416 .46321 .95577 .4522 .95222 .45363 Mtetra
.744 .969 .699 r
.95222 .45363 .95577 .4522 .9675 .44219 .9637 .44117 Mtetra
.074 0 0 r
.386 .60327 .39242 .6039 .40265 .60373 .39622 .60431 Mtetra
.221 0 0 r
.39622 .60431 .40265 .60373 .41293 .60355 .40649 .60535 Mtetra
.293 0 0 r
.40649 .60535 .41293 .60355 .42327 .60311 .41684 .60604 Mtetra
.303 0 0 r
.41684 .60604 .42327 .60311 .43369 .60218 .42728 .60602 Mtetra
.271 0 0 r
.42728 .60602 .43369 .60218 .44417 .60054 .4378 .605 Mtetra
.21 0 0 r
.4378 .605 .44417 .60054 .45472 .59812 .4484 .60286 Mtetra
.139 0 0 r
.4484 .60286 .45472 .59812 .46533 .59505 .45907 .59975 Mtetra
.106 0 0 r
.45907 .59975 .46533 .59505 .47598 .59185 .46978 .59633 Mtetra
.194 0 0 r
.46978 .59633 .47598 .59185 .48667 .58954 .48053 .59396 Mtetra
.433 0 0 r
.48053 .59396 .48667 .58954 .49738 .58978 .49128 .59476 Mtetra
.66 .216 .185 r
.49128 .59476 .49738 .58978 .50813 .59459 .50207 .60136 Mtetra
.767 .384 .329 r
.50207 .60136 .50813 .59459 .51896 .60566 .51294 .61602 Mtetra
.797 .453 .405 r
.51294 .61602 .51896 .60566 .52994 .6232 .52396 .63904 Mtetra
.788 .467 .446 r
.52396 .63904 .52994 .6232 .54111 .64468 .53521 .66729 Mtetra
.75 .444 .466 r
.53521 .66729 .54111 .64468 .55248 .66466 .5467 .69378 Mtetra
.674 .382 .47 r
.5467 .69378 .55248 .66466 .56395 .67624 .55833 .70951 Mtetra
.535 .262 .448 r
.55833 .70951 .56395 .67624 .57536 .67411 .5699 .70751 Mtetra
.282 .047 .37 r
.5699 .70751 .57536 .67411 .58657 .65743 .58123 .68666 Mtetra
0 0 .188 r
.58123 .68666 .58657 .65743 .59752 .63033 .59223 .65242 Mtetra
0 0 0 r
.59223 .65242 .59752 .63033 .60828 .59978 .60297 .61388 Mtetra
.807 .814 .33 r
.60297 .61388 .60828 .59978 .61899 .57253 .61364 .57967 Mtetra
.903 .926 .542 r
.61364 .57967 .61899 .57253 .62983 .55315 .62444 .55552 Mtetra
.789 .994 .775 r
.62444 .55552 .62983 .55315 .64095 .54396 .63557 .54418 Mtetra
.285 0 0 r
.63557 .54418 .64095 .54396 .65251 .54578 .64719 .54652 Mtetra
.806 .338 .116 r
.64719 .54652 .65251 .54578 .66459 .55846 .65942 .56224 Mtetra
.862 .471 .298 r
.65942 .56224 .66459 .55846 .67725 .58046 .67233 .58945 Mtetra
.851 .494 .377 r
.67233 .58945 .67725 .58046 .69039 .6079 .68583 .62346 Mtetra
.808 .471 .418 r
.68583 .62346 .69039 .6079 .70374 .63419 .69957 .65624 Mtetra
.727 .407 .437 r
.69957 .65624 .70374 .63419 .71685 .65129 .71302 .67794 Mtetra
.576 .28 .428 r
.71302 .67794 .71685 .65129 .72924 .65294 .72563 .6808 Mtetra
.304 .056 .363 r
.72563 .6808 .72924 .65294 .74066 .63777 .73708 .66311 Mtetra
0 0 .207 r
.73708 .66311 .74066 .63777 .75124 .61014 .74751 .63032 Mtetra
0 0 .001 r
.74751 .63032 .75124 .61014 .76136 .57782 .7574 .59201 Mtetra
0 0 0 r
.7574 .59201 .76136 .57782 .77154 .54839 .76737 .55749 Mtetra
.7 .792 .318 r
.76737 .55749 .77154 .54839 .78218 .52671 .77788 .53261 Mtetra
0 0 0 r
.77788 .53261 .78218 .52671 .79348 .51424 .7892 .5191 Mtetra
.183 0 0 r
.7892 .5191 .79348 .51424 .80545 .50995 .80132 .51566 Mtetra
.555 .081 .083 r
.80132 .51566 .80545 .50995 .81798 .51149 .81412 .51944 Mtetra
.652 .224 .217 r
.81412 .51944 .81798 .51149 .8309 .51625 .82739 .52719 Mtetra
.659 .266 .29 r
.82739 .52719 .8309 .51625 .84401 .52179 .84088 .53583 Mtetra
.628 .263 .331 r
.84088 .53583 .84401 .52179 .85711 .52607 .85435 .54275 Mtetra
.575 .233 .351 r
.85435 .54275 .85711 .52607 .87004 .52756 .86758 .54593 Mtetra
.505 .183 .354 r
.86758 .54593 .87004 .52756 .88266 .52529 .88038 .54412 Mtetra
.417 .113 .339 r
.88038 .54412 .88266 .52529 .8949 .51899 .89267 .53693 Mtetra
.306 .019 .302 r
.89267 .53693 .8949 .51899 .90676 .50903 .90444 .52487 Mtetra
.167 0 .235 r
.90444 .52487 .90676 .50903 .91829 .49632 .91576 .50916 Mtetra
0 0 .124 r
.91576 .50916 .91829 .49632 .92962 .48206 .92681 .49143 Mtetra
0 0 0 r
.92681 .49143 .92962 .48206 .94089 .46749 .93775 .47332 Mtetra
.93775 .47332 .94089 .46749 .95222 .45363 .94876 .45618 Mtetra
.75 .934 .591 r
.94876 .45618 .95222 .45363 .9637 .44117 .95997 .44092 Mtetra
.393 0 0 r
.37947 .60382 .386 .60327 .39622 .60431 .38965 .60639 Mtetra
.472 0 0 r
.38965 .60639 .39622 .60431 .40649 .60535 .39992 .60895 Mtetra
.49 0 0 r
.39992 .60895 .40649 .60535 .41684 .60604 .41027 .61105 Mtetra
.47 0 .031 r
.41027 .61105 .41684 .60604 .42728 .60602 .42072 .61218 Mtetra
.423 0 .049 r
.42072 .61218 .42728 .60602 .4378 .605 .43128 .61194 Mtetra
.356 0 .035 r
.43128 .61194 .4378 .605 .4484 .60286 .44194 .61012 Mtetra
.28 0 0 r
.44194 .61012 .4484 .60286 .45907 .59975 .45267 .60688 Mtetra
.23 0 0 r
.45267 .60688 .45907 .59975 .46978 .59633 .46346 .603 Mtetra
.275 0 0 r
.46346 .603 .46978 .59633 .48053 .59396 .47428 .60006 Mtetra
.458 0 .069 r
.47428 .60006 .48053 .59396 .49128 .59476 .4851 .60057 Mtetra
.667 .239 .22 r
.4851 .60057 .49128 .59476 .50207 .60136 .49593 .60762 Mtetra
.784 .401 .33 r
.49593 .60762 .50207 .60136 .51294 .61602 .50682 .62387 Mtetra
.827 .475 .391 r
.50682 .62387 .51294 .61602 .52396 .63904 .51787 .64979 Mtetra
.83 .496 .423 r
.51787 .64979 .52396 .63904 .53521 .66729 .52915 .68186 Mtetra
.802 .476 .437 r
.52915 .68186 .53521 .66729 .5467 .69378 .5407 .7121 Mtetra
.723 .4 .432 r
.5407 .7121 .5467 .69378 .55833 .70951 .55243 .73013 Mtetra
.502 .189 .37 r
.55243 .73013 .55833 .70951 .5699 .70751 .56412 .72785 Mtetra
0 0 .098 r
.56412 .72785 .5699 .70751 .58123 .68666 .57555 .70397 Mtetra
.793 .79 .293 r
.57555 .70397 .58123 .68666 .59223 .65242 .58662 .66482 Mtetra
.964 .864 .462 r
.58662 .66482 .59223 .65242 .60297 .61388 .59741 .62088 Mtetra
.993 .873 .553 r
.59741 .62088 .60297 .61388 .61364 .57967 .60809 .582 Mtetra
.982 .891 .653 r
.60809 .582 .61364 .57967 .62444 .55552 .61889 .55459 Mtetra
.898 .935 .83 r
.61889 .55459 .62444 .55552 .63557 .54418 .63003 .54159 Mtetra
.065 .58 .88 r
.63003 .54159 .63557 .54418 .64719 .54652 .64168 .5438 Mtetra
.801 .31 0 r
.64168 .5438 .64719 .54652 .65942 .56224 .65398 .56077 Mtetra
.897 .485 .2 r
.65398 .56077 .65942 .56224 .67233 .58945 .66699 .59036 Mtetra
.905 .522 .285 r
.66699 .59036 .67233 .58945 .68583 .62346 .68063 .62748 Mtetra
.886 .508 .319 r
.68063 .62748 .68583 .62346 .69957 .65624 .69454 .66339 Mtetra
.821 .432 .317 r
.69454 .66339 .69957 .65624 .71302 .67794 .70816 .68736 Mtetra
.571 .16 .223 r
.70816 .68736 .71302 .67794 .72563 .6808 .72088 .6909 Mtetra
0 0 0 r
.72088 .6909 .72563 .6808 .73708 .66311 .73239 .67219 Mtetra
.912 .868 .432 r
.73239 .67219 .73708 .66311 .74751 .63032 .74282 .63722 Mtetra
.979 .866 .487 r
.74282 .63722 .74751 .63032 .7574 .59201 .75269 .59654 Mtetra
.989 .877 .537 r
.75269 .59654 .7574 .59201 .76737 .55749 .76266 .56031 Mtetra
.97 .927 .615 r
.76266 .56031 .76737 .55749 .77788 .53261 .77325 .5349 Mtetra
.774 .981 .719 r
.77325 .5349 .77788 .53261 .7892 .5191 .78471 .52223 Mtetra
.202 0 0 r
.78471 .52223 .7892 .5191 .80132 .51566 .79707 .52086 Mtetra
.629 .151 .1 r
.79707 .52086 .80132 .51566 .81412 .51944 .8102 .52762 Mtetra
.703 .281 .243 r
.8102 .52762 .81412 .51944 .82739 .52719 .82386 .53883 Mtetra
.697 .31 .311 r
.82386 .53883 .82739 .52719 .84088 .53583 .83776 .5509 Mtetra
.659 .297 .348 r
.83776 .5509 .84088 .53583 .85435 .54275 .85162 .56069 Mtetra
.598 .258 .365 r
.85162 .56069 .85435 .54275 .86758 .54593 .86516 .56572 Mtetra
.516 .197 .365 r
.86516 .56572 .86758 .54593 .88038 .54412 .87816 .5644 Mtetra
.41 .113 .347 r
.87816 .5644 .88038 .54412 .89267 .53693 .8905 .55625 Mtetra
.276 .003 .305 r
.8905 .55625 .89267 .53693 .90444 .52487 .90217 .54194 Mtetra
.109 0 .231 r
.90217 .54194 .90444 .52487 .91576 .50916 .91328 .52304 Mtetra
0 0 .112 r
.91328 .52304 .91576 .50916 .92681 .49143 .92402 .50161 Mtetra
0 0 0 r
.92402 .50161 .92681 .49143 .93775 .47332 .93463 .47974 Mtetra
.93463 .47974 .93775 .47332 .94876 .45618 .94531 .45915 Mtetra
.804 .927 .551 r
.94531 .45915 .94876 .45618 .95997 .44092 .95622 .44094 Mtetra
.57 .036 0 r
.37281 .60546 .37947 .60382 .38965 .60639 .38296 .60983 Mtetra
.596 .108 .066 r
.38296 .60983 .38965 .60639 .39992 .60895 .39319 .61421 Mtetra
.585 .131 .14 r
.39319 .61421 .39992 .60895 .41027 .61105 .40354 .61798 Mtetra
.552 .12 .174 r
.40354 .61798 .41027 .61105 .42072 .61218 .414 .62048 Mtetra
.499 .082 .18 r
.414 .62048 .42072 .61218 .43128 .61194 .4246 .62116 Mtetra
.427 .019 .16 r
.4246 .62116 .43128 .61194 .44194 .61012 .43531 .61969 Mtetra
.343 0 .119 r
.43531 .61969 .44194 .61012 .45267 .60688 .44613 .61623 Mtetra
.273 0 .069 r
.44613 .61623 .45267 .60688 .46346 .603 .45701 .61156 Mtetra
.274 0 .043 r
.45701 .61156 .46346 .603 .47428 .60006 .46792 .6074 Mtetra
.412 0 .085 r
.46792 .6074 .47428 .60006 .4851 .60057 .47882 .60645 Mtetra
.631 .193 .189 r
.47882 .60645 .4851 .60057 .49593 .60762 .48972 .61201 Mtetra
.786 .379 .28 r
.48972 .61201 .49593 .60762 .50682 .62387 .50065 .62691 Mtetra
.858 .479 .328 r
.50065 .62691 .50682 .62387 .51787 .64979 .5117 .65173 Mtetra
.885 .517 .34 r
.5117 .65173 .51787 .64979 .52915 .68186 .52298 .68299 Mtetra
.886 .506 .314 r
.52298 .68299 .52915 .68186 .5407 .7121 .53453 .71257 Mtetra
.827 .383 .175 r
.53453 .71257 .5407 .7121 .55243 .73013 .54626 .72994 Mtetra
.404 .853 .907 r
.54626 .72994 .55243 .73013 .56412 .72785 .55799 .72684 Mtetra
.952 .85 .705 r
.55799 .72684 .56412 .72785 .57555 .70397 .5695 .70194 Mtetra
.958 .788 .629 r
.5695 .70194 .57555 .70397 .58662 .66482 .58066 .66168 Mtetra
.954 .77 .615 r
.58066 .66168 .58662 .66482 .59741 .62088 .59154 .61668 Mtetra
.946 .769 .63 r
.59154 .61668 .59741 .62088 .60809 .582 .60229 .5769 Mtetra
.925 .778 .679 r
.60229 .5769 .60809 .582 .61889 .55459 .61316 .54874 Mtetra
.853 .789 .788 r
.61316 .54874 .61889 .55459 .63003 .54159 .62432 .53505 Mtetra
.434 .642 .945 r
.62432 .53505 .63003 .54159 .64168 .5438 .63597 .5365 Mtetra
.574 .115 0 r
.63597 .5365 .64168 .5438 .65398 .56077 .64823 .55251 Mtetra
.832 .411 0 r
.64823 .55251 .65398 .56077 .66699 .59036 .66117 .58088 Mtetra
.869 .472 .007 r
.66117 .58088 .66699 .59036 .68063 .62748 .6747 .6166 Mtetra
.82 .428 0 r
.6747 .6166 .68063 .62748 .69454 .66339 .68851 .65119 Mtetra
0 0 .459 r
.68851 .65119 .69454 .66339 .70816 .68736 .70206 .67431 Mtetra
.472 .515 .821 r
.70206 .67431 .70816 .68736 .72088 .6909 .71479 .67781 Mtetra
.811 .68 .719 r
.71479 .67781 .72088 .6909 .73239 .67219 .72639 .66001 Mtetra
.889 .71 .653 r
.72639 .66001 .73239 .67219 .74282 .63722 .73699 .62675 Mtetra
.915 .727 .633 r
.73699 .62675 .74282 .63722 .75269 .59654 .74709 .58831 Mtetra
.925 .752 .648 r
.74709 .58831 .75269 .59654 .76266 .56031 .75731 .55461 Mtetra
.921 .803 .712 r
.75731 .55461 .76266 .56031 .77325 .5349 .76816 .53195 Mtetra
.832 .914 .892 r
.76816 .53195 .77325 .5349 .78471 .52223 .77992 .52225 Mtetra
.187 0 0 r
.77992 .52225 .78471 .52223 .79707 .52086 .7926 .52414 Mtetra
.697 .198 .055 r
.7926 .52414 .79707 .52086 .8102 .52762 .80609 .53443 Mtetra
.751 .32 .228 r
.80609 .53443 .8102 .52762 .82386 .53883 .82014 .54928 Mtetra
.736 .34 .3 r
.82014 .54928 .82386 .53883 .83776 .5509 .83444 .56479 Mtetra
.691 .319 .337 r
.83444 .56479 .83776 .5509 .85162 .56069 .84867 .57741 Mtetra
.619 .268 .353 r
.84867 .57741 .85162 .56069 .86516 .56572 .86251 .58424 Mtetra
.517 .188 .349 r
.86251 .58424 .86516 .56572 .87816 .5644 .8757 .58339 Mtetra
.376 .075 .321 r
.8757 .58339 .87816 .5644 .8905 .55625 .88809 .57432 Mtetra
.193 0 .262 r
.88809 .57432 .8905 .55625 .90217 .54194 .89967 .55783 Mtetra
0 0 .161 r
.89967 .55783 .90217 .54194 .91328 .52304 .91058 .53584 Mtetra
0 0 .014 r
.91058 .53584 .91328 .52304 .92402 .50161 .92105 .51086 Mtetra
0 0 0 r
.92105 .51086 .92402 .50161 .93463 .47974 .93134 .4854 Mtetra
.758 .837 .381 r
.93134 .4854 .93463 .47974 .94531 .45915 .94172 .4615 Mtetra
.89 .941 .574 r
.94172 .4615 .94531 .45915 .95622 .44094 .95237 .44049 Mtetra
.661 .174 .084 r
.36605 .60789 .37281 .60546 .38296 .60983 .37614 .61427 Mtetra
.662 .214 .178 r
.37614 .61427 .38296 .60983 .39319 .61421 .38633 .62069 Mtetra
.639 .219 .228 r
.38633 .62069 .39319 .61421 .40354 .61798 .39665 .62634 Mtetra
.599 .196 .249 r
.39665 .62634 .40354 .61798 .414 .62048 .40713 .63038 Mtetra
.541 .149 .247 r
.40713 .63038 .414 .62048 .4246 .62116 .41776 .63209 Mtetra
.463 .078 .222 r
.41776 .63209 .4246 .62116 .43531 .61969 .42854 .63101 Mtetra
.366 0 .174 r
.42854 .63101 .43531 .61969 .44613 .61623 .43945 .6272 Mtetra
.266 0 .109 r
.43945 .6272 .44613 .61623 .45701 .61156 .45044 .62143 Mtetra
.213 0 .047 r
.45044 .62143 .45701 .61156 .46792 .6074 .46146 .61543 Mtetra
.285 0 .025 r
.46146 .61543 .46792 .6074 .47882 .60645 .47247 .61184 Mtetra
.51 .036 .067 r
.47247 .61184 .47882 .60645 .48972 .61201 .48345 .6139 Mtetra
.742 .27 .127 r
.48345 .6139 .48972 .61201 .50065 .62691 .49444 .62439 Mtetra
.862 .417 .131 r
.49444 .62439 .50065 .62691 .5117 .65173 .50552 .64398 Mtetra
.873 .45 .028 r
.50552 .64398 .5117 .65173 .52298 .68299 .51677 .66957 Mtetra
0 0 .315 r
.51677 .66957 .52298 .68299 .53453 .71257 .52826 .69391 Mtetra
.198 .271 .713 r
.52826 .69391 .53453 .71257 .54626 .72994 .53994 .70754 Mtetra
.634 .521 .707 r
.53994 .70754 .54626 .72994 .55799 .72684 .55163 .70311 Mtetra
.77 .596 .663 r
.55163 .70311 .55799 .72684 .5695 .70194 .56316 .6794 Mtetra
.825 .63 .639 r
.56316 .6794 .5695 .70194 .58066 .66168 .57441 .64211 Mtetra
.851 .651 .632 r
.57441 .64211 .58066 .66168 .59154 .61668 .58541 .60068 Mtetra
.86 .669 .643 r
.58541 .60068 .59154 .61668 .60229 .5769 .59629 .56401 Mtetra
.85 .685 .677 r
.59629 .56401 .60229 .5769 .61316 .54874 .60725 .53781 Mtetra
.792 .687 .749 r
.60725 .53781 .61316 .54874 .62432 .53505 .61847 .52461 Mtetra
.551 .593 .849 r
.61847 .52461 .62432 .53505 .63597 .5365 .63009 .5249 Mtetra
0 .198 .723 r
.63009 .5249 .63597 .5365 .64823 .55251 .64223 .53804 Mtetra
0 0 .481 r
.64223 .53804 .64823 .55251 .66117 .58088 .65495 .56198 Mtetra
0 0 .461 r
.65495 .56198 .66117 .58088 .6747 .6166 .66819 .59226 Mtetra
0 .034 .574 r
.66819 .59226 .6747 .6166 .68851 .65119 .68166 .62154 Mtetra
.291 .268 .66 r
.68166 .62154 .68851 .65119 .70206 .67431 .69495 .641 Mtetra
.55 .431 .669 r
.69495 .641 .70206 .67431 .71479 .67781 .70757 .64379 Mtetra
.688 .519 .653 r
.70757 .64379 .71479 .67781 .72639 .66001 .71927 .62856 Mtetra
.76 .57 .64 r
.71927 .62856 .72639 .66001 .73699 .62675 .73017 .60041 Mtetra
.798 .604 .639 r
.73017 .60041 .73699 .62675 .74709 .58831 .74069 .56823 Mtetra
.814 .633 .658 r
.74069 .56823 .74709 .58831 .75731 .55461 .75136 .54073 Mtetra
.802 .668 .715 r
.75136 .54073 .75731 .55461 .76816 .53195 .76264 .52352 Mtetra
.695 .712 .861 r
.76264 .52352 .76816 .53195 .77992 .52225 .77478 .51844 Mtetra
0 .389 .797 r
.77478 .51844 .77992 .52225 .7926 .52414 .78783 .52432 Mtetra
.739 .217 0 r
.78783 .52432 .7926 .52414 .80609 .53443 .80166 .53823 Mtetra
.797 .342 .162 r
.80166 .53823 .80609 .53443 .82014 .54928 .81605 .55642 Mtetra
.781 .358 .246 r
.81605 .55642 .82014 .54928 .83444 .56479 .83069 .57492 Mtetra
.731 .328 .285 r
.83069 .57492 .83444 .56479 .84867 .57741 .84523 .58995 Mtetra
.644 .257 .297 r
.84523 .58995 .84867 .57741 .86251 .58424 .85932 .5983 Mtetra
.501 .138 .281 r
.85932 .5983 .86251 .58424 .8757 .58339 .87267 .59787 Mtetra
.28 0 .224 r
.87267 .59787 .8757 .58339 .88809 .57432 .88511 .58801 Mtetra
0 0 .112 r
.88511 .58801 .88809 .57432 .89967 .55783 .89664 .56969 Mtetra
0 0 0 r
.89664 .56969 .89967 .55783 .91058 .53584 .9074 .54512 Mtetra
.9074 .54512 .91058 .53584 .92105 .51086 .91765 .51717 Mtetra
.816 .839 .372 r
.91765 .51717 .92105 .51086 .93134 .4854 .92771 .48873 Mtetra
.919 .906 .507 r
.92771 .48873 .93134 .4854 .94172 .4615 .93786 .4621 Mtetra
.961 .937 .625 r
.93786 .4621 .94172 .4615 .95237 .44049 .94831 .43878 Mtetra
.715 .257 .164 r
.35918 .61062 .36605 .60789 .37614 .61427 .36921 .61912 Mtetra
.705 .28 .235 r
.36921 .61912 .37614 .61427 .38633 .62069 .37935 .62767 Mtetra
.678 .273 .272 r
.37935 .62767 .38633 .62069 .39665 .62634 .38965 .6353 Mtetra
.633 .242 .285 r
.38965 .6353 .39665 .62634 .40713 .63038 .40012 .64098 Mtetra
.57 .186 .276 r
.40012 .64098 .40713 .63038 .41776 .63209 .41078 .64376 Mtetra
.48 .102 .244 r
.41078 .64376 .41776 .63209 .42854 .63101 .42163 .64307 Mtetra
.361 0 .184 r
.42163 .64307 .42854 .63101 .43945 .6272 .43263 .63884 Mtetra
.216 0 .094 r
.43263 .63884 .43945 .6272 .45044 .62143 .44374 .63178 Mtetra
.082 0 0 r
.44374 .63178 .45044 .62143 .46146 .61543 .45489 .62348 Mtetra
.03 0 0 r
.45489 .62348 .46146 .61543 .47247 .61184 .46604 .61641 Mtetra
.142 0 0 r
.46604 .61641 .47247 .61184 .48345 .6139 .47714 .61355 Mtetra
.41 0 0 r
.47714 .61355 .48345 .6139 .49444 .62439 .48823 .61744 Mtetra
0 .022 .542 r
.48823 .61744 .49444 .62439 .50552 .64398 .49935 .62883 Mtetra
0 .092 .642 r
.49935 .62883 .50552 .64398 .51677 .66957 .51059 .64536 Mtetra
.245 .257 .674 r
.51059 .64536 .51677 .66957 .52826 .69391 .522 .66127 Mtetra
.485 .385 .666 r
.522 .66127 .52826 .69391 .53994 .70754 .53358 .6691 Mtetra
.622 .466 .649 r
.53358 .6691 .53994 .70754 .55163 .70311 .54519 .66304 Mtetra
.701 .518 .637 r
.54519 .66304 .55163 .70311 .56316 .6794 .5567 .64211 Mtetra
.75 .554 .631 r
.5567 .64211 .56316 .6794 .57441 .64211 .56801 .61067 Mtetra
.78 .582 .632 r
.56801 .61067 .57441 .64211 .58541 .60068 .57913 .57611 Mtetra
.796 .606 .645 r
.57913 .57611 .58541 .60068 .59629 .56401 .59016 .54545 Mtetra
.793 .626 .675 r
.59016 .54545 .59629 .56401 .60725 .53781 .60124 .52325 Mtetra
.748 .631 .73 r
.60124 .52325 .60725 .53781 .61847 .52461 .61251 .5115 Mtetra
.592 .57 .798 r
.61251 .5115 .61847 .52461 .63009 .5249 .6241 .51054 Mtetra
.278 .37 .778 r
.6241 .51054 .63009 .5249 .64223 .53804 .63609 .51974 Mtetra
.069 .185 .678 r
.63609 .51974 .64223 .53804 .65495 .56198 .64853 .53737 Mtetra
.111 .166 .64 r
.64853 .53737 .65495 .56198 .66819 .59226 .66136 .5599 Mtetra
.276 .246 .643 r
.66136 .5599 .66819 .59226 .68166 .62154 .6744 .58162 Mtetra
.441 .341 .645 r
.6744 .58162 .68166 .62154 .69495 .641 .68731 .59585 Mtetra
.563 .416 .64 r
.68731 .59585 .69495 .641 .70757 .64379 .69976 .5975 Mtetra
.644 .47 .633 r
.69976 .5975 .70757 .64379 .71927 .62856 .71157 .5857 Mtetra
.696 .509 .631 r
.71157 .5857 .71927 .62856 .73017 .60041 .72281 .56443 Mtetra
.726 .538 .638 r
.72281 .56443 .73017 .60041 .74069 .56823 .73382 .54064 Mtetra
.734 .562 .659 r
.73382 .54064 .74069 .56823 .75136 .54073 .74503 .52123 Mtetra
.706 .579 .71 r
.74503 .52123 .75136 .54073 .76264 .52352 .75679 .51077 Mtetra
.564 .568 .816 r
.75679 .51077 .76264 .52352 .77478 .51844 .76933 .51088 Mtetra
0 .3 .795 r
.76933 .51088 .77478 .51844 .78783 .52432 .78269 .52067 Mtetra
.7 .187 0 r
.78269 .52067 .78783 .52432 .80166 .53823 .7968 .53762 Mtetra
.815 .331 .012 r
.7968 .53762 .80166 .53823 .81605 .55642 .81143 .55831 Mtetra
.818 .351 .106 r
.81143 .55831 .81605 .55642 .83069 .57492 .8263 .5789 Mtetra
.775 .309 .135 r
.8263 .5789 .83069 .57492 .84523 .58995 .84105 .59555 Mtetra
.668 .193 .114 r
.84105 .59555 .84523 .58995 .85932 .5983 .85532 .6049 Mtetra
.413 0 .02 r
.85532 .6049 .85932 .5983 .87267 .59787 .86879 .60472 Mtetra
0 0 0 r
.86879 .60472 .87267 .59787 .88511 .58801 .88128 .59435 Mtetra
.621 .8 .37 r
.88128 .59435 .88511 .58801 .89664 .56969 .8928 .57482 Mtetra
.86 .888 .46 r
.8928 .57482 .89664 .56969 .9074 .54512 .90348 .54855 Mtetra
.947 .899 .51 r
.90348 .54855 .9074 .54512 .91765 .51717 .91363 .51867 Mtetra
.98 .898 .556 r
.91363 .51867 .91765 .51717 .92771 .48873 .92357 .48827 Mtetra
.988 .896 .607 r
.92357 .48827 .92771 .48873 .93786 .4621 .93359 .45986 Mtetra
.979 .894 .665 r
.93359 .45986 .93786 .4621 .94831 .43878 .94394 .43504 Mtetra
.754 .31 .198 r
.35225 .613 .35918 .61062 .36921 .61912 .36221 .62355 Mtetra
.74 .323 .257 r
.36221 .62355 .36921 .61912 .37935 .62767 .3723 .63419 Mtetra
.71 .309 .285 r
.3723 .63419 .37935 .62767 .38965 .6353 .38255 .64375 Mtetra
.663 .27 .291 r
.38255 .64375 .38965 .6353 .40012 .64098 .39302 .65101 Mtetra
.592 .203 .275 r
.39302 .65101 .40012 .64098 .41078 .64376 .40371 .65485 Mtetra
.484 .097 .229 r
.40371 .65485 .41078 .64376 .42163 .64307 .41462 .65453 Mtetra
.324 0 .144 r
.41462 .65453 .42163 .64307 .43263 .63884 .42572 .64986 Mtetra
.102 0 .007 r
.42572 .64986 .43263 .63884 .44374 .63178 .43695 .64145 Mtetra
0 0 0 r
.43695 .64145 .44374 .63178 .45489 .62348 .44825 .63074 Mtetra
.44825 .63074 .45489 .62348 .46604 .61641 .45954 .61993 Mtetra
.565 .916 .717 r
.45954 .61993 .46604 .61641 .47714 .61355 .47079 .61165 Mtetra
.59 .889 .99 r
.47079 .61165 .47714 .61355 .48823 .61744 .48199 .60817 Mtetra
.453 .573 .885 r
.48199 .60817 .48823 .61744 .49935 .62883 .49319 .61037 Mtetra
.43 .418 .745 r
.49319 .61037 .49935 .62883 .51059 .64536 .50444 .61672 Mtetra
.488 .398 .68 r
.50444 .61672 .51059 .64536 .522 .66127 .51581 .62325 Mtetra
.561 .424 .651 r
.51581 .62325 .522 .66127 .53358 .6691 .52728 .62472 Mtetra
.625 .458 .637 r
.52728 .62472 .53358 .6691 .54519 .66304 .5388 .61705 Mtetra
.674 .491 .63 r
.5388 .61705 .54519 .66304 .5567 .64211 .55026 .59943 Mtetra
.71 .52 .629 r
.55026 .59943 .5567 .64211 .56801 .61067 .5616 .57483 Mtetra
.737 .546 .636 r
.5616 .57483 .56801 .61067 .57913 .57611 .57282 .54829 Mtetra
.752 .572 .651 r
.57282 .54829 .57913 .57611 .59016 .54545 .58398 .52472 Mtetra
.753 .595 .681 r
.58398 .52472 .59016 .54545 .60124 .52325 .59518 .50733 Mtetra
.72 .606 .729 r
.59518 .50733 .60124 .52325 .61251 .5115 .60651 .49752 Mtetra
.615 .571 .782 r
.60651 .49752 .61251 .5115 .6241 .51054 .61807 .49545 Mtetra
.436 .457 .783 r
.61807 .49545 .6241 .51054 .63609 .51974 .62992 .50061 Mtetra
.318 .342 .729 r
.62992 .50061 .63609 .51974 .64853 .53737 .64208 .5117 Mtetra
.331 .308 .683 r
.64208 .5117 .64853 .53737 .66136 .5599 .65453 .52619 Mtetra
.412 .333 .658 r
.65453 .52619 .66136 .5599 .6744 .58162 .66713 .54011 Mtetra
.499 .376 .644 r
.66713 .54011 .6744 .58162 .68731 .59585 .67968 .54895 Mtetra
.571 .418 .635 r
.67968 .54895 .68731 .59585 .69976 .5975 .69195 .54938 Mtetra
.624 .453 .631 r
.69195 .54938 .69976 .5975 .71157 .5857 .70383 .54093 Mtetra
.66 .482 .633 r
.70383 .54093 .71157 .5857 .72281 .56443 .71539 .52651 Mtetra
.679 .504 .642 r
.71539 .52651 .72281 .56443 .73382 .54064 .72686 .51105 Mtetra
.676 .52 .666 r
.72686 .51105 .73382 .54064 .74503 .52123 .73855 .49957 Mtetra
.629 .522 .714 r
.73855 .49957 .74503 .52123 .75679 .51077 .75074 .49551 Mtetra
.46 .475 .787 r
.75074 .49551 .75679 .51077 .76933 .51088 .76361 .50018 Mtetra
0 .248 .758 r
.76361 .50018 .76933 .51088 .78269 .52067 .77721 .51294 Mtetra
0 0 .46 r
.77721 .51294 .78269 .52067 .7968 .53762 .79147 .53175 Mtetra
.708 .237 0 r
.79147 .53175 .7968 .53762 .81143 .55831 .80621 .55364 Mtetra
.735 .25 0 r
.80621 .55364 .81143 .55831 .8263 .5789 .82117 .57503 Mtetra
.669 .154 0 r
.82117 .57503 .8263 .5789 .84105 .59555 .83599 .59222 Mtetra
.403 0 0 r
.83599 .59222 .84105 .59555 .85532 .6049 .85033 .60189 Mtetra
.33 .747 .977 r
.85033 .60189 .85532 .6049 .86879 .60472 .86386 .60177 Mtetra
.835 .937 .894 r
.86386 .60177 .86879 .60472 .88128 .59435 .87641 .59123 Mtetra
.947 .897 .746 r
.87641 .59123 .88128 .59435 .8928 .57482 .88796 .57132 Mtetra
.972 .86 .671 r
.88796 .57132 .8928 .57482 .90348 .54855 .89868 .54452 Mtetra
.977 .84 .641 r
.89868 .54452 .90348 .54855 .91363 .51867 .90885 .51403 Mtetra
.975 .83 .637 r
.90885 .51403 .91363 .51867 .92357 .48827 .9188 .48303 Mtetra
.967 .827 .653 r
.9188 .48303 .92357 .48827 .93359 .45986 .92884 .45407 Mtetra
.953 .828 .684 r
.92884 .45407 .93359 .45986 .94394 .43504 .93921 .42877 Mtetra
.786 .344 .197 r
.3453 .61429 .35225 .613 .36221 .62355 .35519 .62664 Mtetra
.773 .352 .248 r
.35519 .62664 .36221 .62355 .3723 .63419 .36521 .63911 Mtetra
.744 .333 .27 r
.36521 .63911 .3723 .63419 .38255 .64375 .37543 .65037 Mtetra
.693 .285 .268 r
.37543 .65037 .38255 .64375 .39302 .65101 .38588 .65903 Mtetra
.611 .198 .236 r
.38588 .65903 .39302 .65101 .40371 .65485 .3966 .66381 Mtetra
.469 .051 .162 r
.3966 .66381 .40371 .65485 .41462 .65453 .40757 .6638 Mtetra
.226 0 .017 r
.40757 .6638 .41462 .65453 .42572 .64986 .41876 .65874 Mtetra
0 0 0 r
.41876 .65874 .42572 .64986 .43695 .64145 .43011 .6491 Mtetra
.537 .821 .476 r
.43011 .6491 .43695 .64145 .44825 .63074 .44154 .63619 Mtetra
.79 .971 .676 r
.44154 .63619 .44825 .63074 .45954 .61993 .45299 .62197 Mtetra
.886 .986 .811 r
.45299 .62197 .45954 .61993 .47079 .61165 .46439 .60873 Mtetra
.84 .87 .865 r
.46439 .60873 .47079 .61165 .48199 .60817 .47573 .59852 Mtetra
.713 .679 .816 r
.47573 .59852 .48199 .60817 .49319 .61037 .48703 .59233 Mtetra
.621 .537 .738 r
.48703 .59233 .49319 .61037 .50444 .61672 .49833 .5895 Mtetra
.596 .474 .684 r
.49833 .5895 .50444 .61672 .51581 .62325 .50967 .58764 Mtetra
.61 .461 .655 r
.50967 .58764 .51581 .62325 .52728 .62472 .52108 .58348 Mtetra
.637 .47 .641 r
.52108 .58348 .52728 .62472 .5388 .61705 .53251 .57441 Mtetra
.665 .488 .635 r
.53251 .57441 .5388 .61705 .55026 .59943 .54393 .55981 Mtetra
.691 .509 .637 r
.54393 .55981 .55026 .59943 .5616 .57483 .55528 .54136 Mtetra
.711 .533 .646 r
.55528 .54136 .5616 .57483 .57282 .54829 .56657 .52212 Mtetra
.725 .559 .665 r
.56657 .52212 .57282 .54829 .58398 .52472 .57783 .50505 Mtetra
.727 .585 .697 r
.57783 .50505 .58398 .52472 .59518 .50733 .58912 .49214 Mtetra
.702 .604 .743 r
.58912 .49214 .59518 .50733 .60651 .49752 .60051 .48422 Mtetra
.632 .589 .788 r
.60051 .48422 .60651 .49752 .61807 .49545 .61206 .48134 Mtetra
.525 .522 .795 r
.61206 .48134 .61807 .49545 .62992 .50061 .62379 .48309 Mtetra
.45 .44 .756 r
.62379 .48309 .62992 .50061 .64208 .5117 .63574 .48861 Mtetra
.446 .397 .71 r
.63574 .48861 .64208 .5117 .65453 .52619 .64788 .49627 Mtetra
.485 .393 .677 r
.64788 .49627 .65453 .52619 .66713 .54011 .66014 .50362 Mtetra
.534 .409 .656 r
.66014 .50362 .66713 .54011 .67968 .54895 .67239 .50793 Mtetra
.578 .431 .645 r
.67239 .50793 .67968 .54895 .69195 .54938 .68452 .50725 Mtetra
.613 .453 .641 r
.68452 .50725 .69195 .54938 .70383 .54093 .69645 .50148 Mtetra
.637 .473 .644 r
.69645 .50148 .70383 .54093 .71539 .52651 .70825 .49258 Mtetra
.645 .489 .657 r
.70825 .49258 .71539 .52651 .72686 .51105 .72007 .48384 Mtetra
.629 .498 .683 r
.72007 .48384 .72686 .51105 .73855 .49957 .73213 .47865 Mtetra
.562 .486 .727 r
.73213 .47865 .73855 .49957 .75074 .49551 .74463 .47941 Mtetra
.381 .418 .774 r
.74463 .47941 .75074 .49551 .76361 .50018 .7577 .48713 Mtetra
.04 .24 .741 r
.7577 .48713 .76361 .50018 .77721 .51294 .7714 .50136 Mtetra
0 .043 .612 r
.7714 .50136 .77721 .51294 .79147 .53175 .78567 .52051 Mtetra
0 0 .542 r
.78567 .52051 .79147 .53175 .80621 .55364 .80037 .54206 Mtetra
0 .011 .585 r
.80037 .54206 .80621 .55364 .82117 .57503 .81526 .56283 Mtetra
0 .175 .708 r
.81526 .56283 .82117 .57503 .83599 .59222 .83003 .57938 Mtetra
.268 .402 .814 r
.83003 .57938 .83599 .59222 .85033 .60189 .84432 .5886 Mtetra
.57 .575 .819 r
.84432 .5886 .85033 .60189 .86386 .60177 .85786 .58836 Mtetra
.744 .661 .768 r
.85786 .58836 .86386 .60177 .87641 .59123 .87046 .57802 Mtetra
.832 .698 .717 r
.87046 .57802 .87641 .59123 .88796 .57132 .88211 .55862 Mtetra
.877 .718 .681 r
.88211 .55862 .88796 .57132 .89868 .54452 .89296 .53255 Mtetra
.9 .73 .662 r
.89296 .53255 .89868 .54452 .90885 .51403 .90329 .50289 Mtetra
.911 .741 .658 r
.90329 .50289 .90885 .51403 .9188 .48303 .9134 .47272 Mtetra
.914 .752 .667 r
.9134 .47272 .9188 .48303 .92884 .45407 .9236 .4445 Mtetra
.908 .764 .69 r
.9236 .4445 .92884 .45407 .93921 .42877 .9341 .41982 Mtetra
.813 .361 .159 r
.33836 .61374 .3453 .61429 .35519 .62664 .34819 .62745 Mtetra
.805 .367 .204 r
.34819 .62745 .35519 .62664 .36521 .63911 .35817 .6413 Mtetra
.779 .343 .216 r
.35817 .6413 .36521 .63911 .37543 .65037 .36835 .65386 Mtetra
.726 .282 .196 r
.36835 .65386 .37543 .65037 .38588 .65903 .37879 .66359 Mtetra
.624 .158 .126 r
.37879 .66359 .38588 .65903 .3966 .66381 .38952 .66906 Mtetra
.403 0 0 r
.38952 .66906 .3966 .66381 .40757 .6638 .40054 .66929 Mtetra
0 0 0 r
.40054 .66929 .40757 .6638 .41876 .65874 .41181 .66391 Mtetra
.61 .914 .648 r
.41181 .66391 .41876 .65874 .43011 .6491 .42326 .65333 Mtetra
.865 .993 .746 r
.42326 .65333 .43011 .6491 .44154 .63619 .43482 .63872 Mtetra
.932 .96 .766 r
.43482 .63872 .44154 .63619 .45299 .62197 .4464 .62185 Mtetra
.928 .902 .779 r
.4464 .62185 .45299 .62197 .46439 .60873 .45795 .60477 Mtetra
.88 .819 .784 r
.45795 .60477 .46439 .60873 .47573 .59852 .46942 .58936 Mtetra
.801 .713 .768 r
.46942 .58936 .47573 .59852 .48703 .59233 .48083 .57675 Mtetra
.721 .61 .732 r
.48083 .57675 .48703 .59233 .49833 .5895 .49219 .56693 Mtetra
.672 .54 .696 r
.49219 .56693 .49833 .5895 .50967 .58764 .50355 .55874 Mtetra
.655 .507 .67 r
.50355 .55874 .50967 .58764 .52108 .58348 .51492 .55036 Mtetra
.658 .498 .656 r
.51492 .55036 .52108 .58348 .53251 .57441 .52631 .54026 Mtetra
.67 .504 .652 r
.52631 .54026 .53251 .57441 .54393 .55981 .53769 .52792 Mtetra
.685 .519 .655 r
.53769 .52792 .54393 .55981 .55528 .54136 .54905 .51413 Mtetra
.699 .54 .668 r
.54905 .51413 .55528 .54136 .56657 .52212 .56038 .50042 Mtetra
.71 .566 .691 r
.56038 .50042 .56657 .52212 .57783 .50505 .57172 .48834 Mtetra
.711 .596 .726 r
.57172 .48834 .57783 .50505 .58912 .49214 .58309 .4789 Mtetra
.693 .62 .771 r
.58309 .4789 .58912 .49214 .60051 .48422 .59453 .47249 Mtetra
.646 .62 .809 r
.59453 .47249 .60051 .48422 .61206 .48134 .60607 .46908 Mtetra
.582 .58 .816 r
.60607 .46908 .61206 .48134 .62379 .48309 .61774 .46837 Mtetra
.534 .52 .787 r
.61774 .46837 .62379 .48309 .63574 .48861 .62955 .46983 Mtetra
.521 .473 .744 r
.62955 .46983 .63574 .48861 .64788 .49627 .64148 .47254 Mtetra
.536 .452 .707 r
.64148 .47254 .64788 .49627 .66014 .50362 .65351 .47513 Mtetra
.562 .449 .682 r
.65351 .47513 .66014 .50362 .67239 .50793 .66557 .47614 Mtetra
.588 .456 .668 r
.66557 .47614 .67239 .50793 .68452 .50725 .67759 .4746 Mtetra
.61 .468 .664 r
.67759 .4746 .68452 .50725 .69645 .50148 .68956 .4706 Mtetra
.622 .481 .669 r
.68956 .4706 .69645 .50148 .70825 .49258 .70151 .46542 Mtetra
.62 .491 .684 r
.70151 .46542 .70825 .49258 .72007 .48384 .71356 .46116 Mtetra
.589 .492 .712 r
.71356 .46116 .72007 .48384 .73213 .47865 .72585 .46 Mtetra
.506 .468 .75 r
.72585 .46 .73213 .47865 .74463 .47941 .73851 .46354 Mtetra
.336 .393 .773 r
.73851 .46354 .74463 .47941 .7577 .48713 .75166 .47249 Mtetra
.113 .266 .742 r
.75166 .47249 .7577 .48713 .7714 .50136 .76533 .48656 Mtetra
0 .164 .689 r
.76533 .48656 .7714 .50136 .78567 .52051 .77949 .50452 Mtetra
0 .145 .673 r
.77949 .50452 .78567 .52051 .80037 .54206 .79401 .52428 Mtetra
.074 .204 .696 r
.79401 .52428 .80037 .54206 .81526 .56283 .80871 .54311 Mtetra
.252 .306 .725 r
.80871 .54311 .81526 .56283 .83003 .57938 .82328 .55797 Mtetra
.434 .411 .734 r
.82328 .55797 .83003 .57938 .84432 .5886 .83745 .56609 Mtetra
.581 .495 .723 r
.83745 .56609 .84432 .5886 .85786 .58836 .85093 .56555 Mtetra
.684 .555 .703 r
.85093 .56555 .85786 .58836 .87046 .57802 .86358 .55577 Mtetra
.754 .597 .682 r
.86358 .55577 .87046 .57802 .88211 .55862 .87537 .5377 Mtetra
.801 .628 .667 r
.87537 .5377 .88211 .55862 .89296 .53255 .88645 .51349 Mtetra
.832 .652 .66 r
.88645 .51349 .89296 .53255 .90329 .50289 .89705 .48595 Mtetra
.851 .673 .661 r
.89705 .48595 .90329 .50289 .9134 .47272 .90745 .45789 Mtetra
.862 .693 .671 r
.90745 .45789 .9134 .47272 .9236 .4445 .91792 .43158 Mtetra
.864 .712 .692 r
.91792 .43158 .9236 .4445 .9341 .41982 .92867 .4085 Mtetra
.827 .355 .07 r
.33149 .61075 .33836 .61374 .34819 .62745 .34128 .62523 Mtetra
.827 .362 .103 r
.34128 .62523 .34819 .62745 .35817 .6413 .35122 .63986 Mtetra
.804 .329 .09 r
.35122 .63986 .35817 .6413 .36835 .65386 .36137 .65314 Mtetra
.743 .237 .014 r
.36137 .65314 .36835 .65386 .37879 .66359 .3718 .66346 Mtetra
.577 .011 0 r
.3718 .66346 .37879 .66359 .38952 .66906 .38255 .66933 Mtetra
.079 0 0 r
.38255 .66933 .38952 .66906 .40054 .66929 .3936 .66968 Mtetra
.622 .952 .93 r
.3936 .66968 .40054 .66929 .41181 .66391 .40493 .6641 Mtetra
.863 .958 .867 r
.40493 .6641 .41181 .66391 .42326 .65333 .41647 .65293 Mtetra
.915 .904 .799 r
.41647 .65293 .42326 .65333 .43482 .63872 .42812 .63727 Mtetra
.921 .86 .763 r
.42812 .63727 .43482 .63872 .4464 .62185 .43982 .61874 Mtetra
.909 .822 .748 r
.43982 .61874 .4464 .62185 .45795 .60477 .45148 .59923 Mtetra
.881 .778 .744 r
.45148 .59923 .45795 .60477 .46942 .58936 .46307 .58049 Mtetra
.835 .723 .74 r
.46307 .58049 .46942 .58936 .48083 .57675 .47458 .56375 Mtetra
.781 .659 .729 r
.47458 .56375 .48083 .57675 .49219 .56693 .48601 .54943 Mtetra
.733 .602 .711 r
.48601 .54943 .49219 .56693 .50355 .55874 .49741 .53719 Mtetra
.702 .562 .694 r
.49741 .53719 .50355 .55874 .51492 .55036 .50878 .52614 Mtetra
.688 .543 .683 r
.50878 .52614 .51492 .55036 .52631 .54026 .52015 .51541 Mtetra
.687 .54 .681 r
.52015 .51541 .52631 .54026 .53769 .52792 .53152 .50459 Mtetra
.692 .548 .687 r
.53152 .50459 .53769 .52792 .54905 .51413 .54288 .49385 Mtetra
.699 .567 .702 r
.54288 .49385 .54905 .51413 .56038 .50042 .55425 .48378 Mtetra
.704 .593 .729 r
.55425 .48378 .56038 .50042 .57172 .48834 .56564 .47498 Mtetra
.703 .624 .766 r
.56564 .47498 .57172 .48834 .58309 .4789 .57706 .46785 Mtetra
.688 .65 .806 r
.57706 .46785 .58309 .4789 .59453 .47249 .58855 .46247 Mtetra
.658 .656 .836 r
.58855 .46247 .59453 .47249 .60607 .46908 .6001 .45874 Mtetra
.621 .634 .842 r
.6001 .45874 .60607 .46908 .61774 .46837 .61175 .45648 Mtetra
.591 .592 .822 r
.61175 .45648 .61774 .46837 .62955 .46983 .62348 .45536 Mtetra
.577 .549 .786 r
.62348 .45536 .62955 .46983 .64148 .47254 .63531 .45492 Mtetra
.579 .518 .751 r
.63531 .45492 .64148 .47254 .65351 .47513 .64721 .45449 Mtetra
.589 .502 .724 r
.64721 .45449 .65351 .47513 .66557 .47614 .65915 .45338 Mtetra
.602 .498 .708 r
.65915 .45338 .66557 .47614 .67759 .4746 .67112 .4512 Mtetra
.612 .502 .704 r
.67112 .4512 .67759 .4746 .68956 .4706 .68311 .44813 Mtetra
.614 .508 .709 r
.68311 .44813 .68956 .4706 .70151 .46542 .69515 .44502 Mtetra
.6 .512 .726 r
.69515 .44502 .70151 .46542 .71356 .46116 .70732 .44316 Mtetra
.557 .504 .752 r
.70732 .44316 .71356 .46116 .72585 .46 .71972 .44392 Mtetra
.467 .47 .778 r
.71972 .44392 .72585 .46 .73851 .46354 .73243 .44834 Mtetra
.331 .399 .781 r
.73243 .44834 .73851 .46354 .75166 .47249 .74554 .45692 Mtetra
.201 .312 .754 r
.74554 .45692 .75166 .47249 .76533 .48656 .75908 .46947 Mtetra
.146 .258 .723 r
.75908 .46947 .76533 .48656 .77949 .50452 .77302 .48501 Mtetra
.178 .256 .707 r
.77302 .48501 .77949 .50452 .79401 .52428 .78728 .50188 Mtetra
.269 .296 .704 r
.78728 .50188 .79401 .52428 .80871 .54311 .80168 .51781 Mtetra
.382 .353 .702 r
.80168 .51781 .80871 .54311 .82328 .55797 .81599 .53024 Mtetra
.491 .413 .696 r
.81599 .53024 .82328 .55797 .83745 .56609 .82996 .53681 Mtetra
.582 .466 .686 r
.82996 .53681 .83745 .56609 .85093 .56555 .84336 .53589 Mtetra
.654 .51 .675 r
.84336 .53589 .85093 .56555 .86358 .55577 .85606 .52697 Mtetra
.71 .546 .665 r
.85606 .52697 .86358 .55577 .87537 .5377 .86803 .51085 Mtetra
.752 .577 .659 r
.86803 .51085 .87537 .5377 .88645 .51349 .87939 .48936 Mtetra
.783 .604 .658 r
.87939 .48936 .88645 .51349 .89705 .48595 .89034 .46489 Mtetra
.806 .629 .662 r
.89034 .46489 .89705 .48595 .90745 .45789 .90111 .43987 Mtetra
.82 .653 .675 r
.90111 .43987 .90745 .45789 .91792 .43158 .91194 .41631 Mtetra
.827 .676 .696 r
.91194 .41631 .91792 .43158 .92867 .4085 .92301 .39551 Mtetra
.792 .306 0 r
.32472 .60497 .33149 .61075 .34128 .62523 .33449 .61952 Mtetra
.792 .305 0 r
.33449 .61952 .34128 .62523 .35122 .63986 .34442 .63421 Mtetra
.745 .241 0 r
.34442 .63421 .35122 .63986 .36137 .65314 .35456 .64756 Mtetra
.589 .059 0 r
.35456 .64756 .36137 .65314 .3718 .66346 .36499 .65793 Mtetra
0 .336 .782 r
.36499 .65793 .3718 .66346 .38255 .66933 .37575 .66382 Mtetra
.447 .7 .974 r
.37575 .66382 .38255 .66933 .3936 .66968 .38682 .66415 Mtetra
.727 .787 .9 r
.38682 .66415 .3936 .66968 .40493 .6641 .39819 .65849 Mtetra
.824 .787 .818 r
.39819 .65849 .40493 .6641 .41647 .65293 .40978 .64714 Mtetra
.86 .777 .768 r
.40978 .64714 .41647 .65293 .42812 .63727 .4215 .63112 Mtetra
.874 .766 .74 r
.4215 .63112 .42812 .63727 .43982 .61874 .43327 .61196 Mtetra
.875 .755 .727 r
.43327 .61196 .43982 .61874 .45148 .59923 .44502 .59139 Mtetra
.864 .739 .724 r
.44502 .59139 .45148 .59923 .46307 .58049 .45669 .57108 Mtetra
.842 .717 .725 r
.45669 .57108 .46307 .58049 .47458 .56375 .46828 .55228 Mtetra
.811 .686 .726 r
.46828 .55228 .47458 .56375 .48601 .54943 .47978 .53568 Mtetra
.776 .651 .724 r
.47978 .53568 .48601 .54943 .49741 .53719 .49121 .52135 Mtetra
.745 .62 .72 r
.49121 .52135 .49741 .53719 .50878 .52614 .50261 .50896 Mtetra
.723 .599 .717 r
.50261 .50896 .50878 .52614 .52015 .51541 .51399 .49802 Mtetra
.711 .591 .72 r
.51399 .49802 .52015 .51541 .53152 .50459 .52536 .48815 Mtetra
.707 .596 .73 r
.52536 .48815 .53152 .50459 .54288 .49385 .53674 .47921 Mtetra
.706 .612 .749 r
.53674 .47921 .54288 .49385 .55425 .48378 .54814 .47126 Mtetra
.704 .635 .777 r
.54814 .47126 .55425 .48378 .56564 .47498 .55957 .46438 Mtetra
.699 .662 .81 r
.55957 .46438 .56564 .47498 .57706 .46785 .57104 .45859 Mtetra
.686 .683 .842 r
.57104 .45859 .57706 .46785 .58855 .46247 .58256 .45381 Mtetra
.666 .69 .863 r
.58256 .45381 .58855 .46247 .6001 .45874 .59414 .44993 Mtetra
.645 .679 .867 r
.59414 .44993 .6001 .45874 .61175 .45648 .60578 .44678 Mtetra
.628 .652 .855 r
.60578 .44678 .61175 .45648 .62348 .45536 .61749 .44422 Mtetra
.618 .62 .83 r
.61749 .44422 .62348 .45536 .63531 .45492 .62928 .44201 Mtetra
.614 .59 .803 r
.62928 .44201 .63531 .45492 .64721 .45449 .64112 .43986 Mtetra
.616 .569 .779 r
.64112 .43986 .64721 .45449 .65915 .45338 .65302 .4375 Mtetra
.619 .558 .764 r
.65302 .4375 .65915 .45338 .67112 .4512 .66497 .43485 Mtetra
.619 .554 .759 r
.66497 .43485 .67112 .4512 .68311 .44813 .67697 .43212 Mtetra
.612 .553 .765 r
.67697 .43212 .68311 .44813 .69515 .44502 .68906 .42985 Mtetra
.588 .55 .779 r
.68906 .42985 .69515 .44502 .70732 .44316 .70128 .42886 Mtetra
.538 .533 .798 r
.70128 .42886 .70732 .44316 .71972 .44392 .7137 .42999 Mtetra
.457 .492 .807 r
.7137 .42999 .71972 .44392 .73243 .44834 .72638 .43394 Mtetra
.362 .429 .797 r
.72638 .43394 .73243 .44834 .74554 .45692 .73938 .44105 Mtetra
.292 .367 .768 r
.73938 .44105 .74554 .45692 .75908 .46947 .75273 .45117 Mtetra
.275 .33 .739 r
.75273 .45117 .75908 .46947 .77302 .48501 .76642 .46358 Mtetra
.308 .326 .717 r
.76642 .46358 .77302 .48501 .78728 .50188 .78036 .47696 Mtetra
.372 .347 .702 r
.78036 .47696 .78728 .50188 .80168 .51781 .79443 .48951 Mtetra
.446 .381 .69 r
.79443 .48951 .80168 .51781 .81599 .53024 .80844 .49918 Mtetra
.519 .418 .68 r
.80844 .49918 .81599 .53024 .82996 .53681 .82219 .50405 Mtetra
.583 .455 .672 r
.82219 .50405 .82996 .53681 .84336 .53589 .8355 .50281 Mtetra
.637 .489 .664 r
.8355 .50281 .84336 .53589 .85606 .52697 .84825 .49502 Mtetra
.683 .52 .66 r
.84825 .49502 .85606 .52697 .86803 .51085 .86043 .48126 Mtetra
.721 .55 .658 r
.86043 .48126 .86803 .51085 .87939 .48936 .8721 .46297 Mtetra
.751 .577 .66 r
.8721 .46297 .87939 .48936 .89034 .46489 .88344 .44208 Mtetra
.775 .604 .668 r
.88344 .44208 .89034 .46489 .90111 .43987 .89462 .42057 Mtetra
.791 .631 .683 r
.89462 .42057 .90111 .43987 .91194 .41631 .90584 .40013 Mtetra
.801 .658 .705 r
.90584 .40013 .91194 .41631 .92301 .39551 .91726 .38189 Mtetra
.635 .175 0 r
.31806 .59635 .32472 .60497 .33449 .61952 .32785 .61026 Mtetra
.587 .144 0 r
.32785 .61026 .33449 .61952 .34442 .63421 .33779 .62431 Mtetra
0 0 .543 r
.33779 .62431 .34442 .63421 .35456 .64756 .34795 .63705 Mtetra
0 .212 .737 r
.34795 .63705 .35456 .64756 .36499 .65793 .35839 .64691 Mtetra
.284 .447 .847 r
.35839 .64691 .36499 .65793 .37575 .66382 .36915 .65244 Mtetra
.55 .583 .84 r
.36915 .65244 .37575 .66382 .38682 .66415 .38024 .65261 Mtetra
.69 .643 .798 r
.38024 .65261 .38682 .66415 .39819 .65849 .39162 .64698 Mtetra
.764 .671 .76 r
.39162 .64698 .39819 .65849 .40978 .64714 .40323 .63583 Mtetra
.804 .686 .734 r
.40323 .63583 .40978 .64714 .4215 .63112 .41498 .6201 Mtetra
.826 .694 .718 r
.41498 .6201 .4215 .63112 .43327 .61196 .42678 .6012 Mtetra
.837 .7 .711 r
.42678 .6012 .43327 .61196 .44502 .59139 .43857 .58076 Mtetra
.839 .702 .711 r
.43857 .58076 .44502 .59139 .45669 .57108 .4503 .56031 Mtetra
.832 .699 .717 r
.4503 .56031 .45669 .57108 .46828 .55228 .46194 .54107 Mtetra
.818 .691 .725 r
.46194 .54107 .46828 .55228 .47978 .53568 .47349 .52384 Mtetra
.797 .678 .733 r
.47349 .52384 .47978 .53568 .49121 .52135 .48496 .5089 Mtetra
.773 .663 .742 r
.48496 .5089 .49121 .52135 .50261 .50896 .49639 .49618 Mtetra
.752 .652 .75 r
.49639 .49618 .50261 .50896 .51399 .49802 .50779 .48538 Mtetra
.735 .647 .761 r
.50779 .48538 .51399 .49802 .52536 .48815 .51919 .47617 Mtetra
.723 .65 .777 r
.51919 .47617 .52536 .48815 .53674 .47921 .53059 .46826 Mtetra
.714 .662 .797 r
.53059 .46826 .53674 .47921 .54814 .47126 .54202 .46145 Mtetra
.705 .679 .822 r
.54202 .46145 .54814 .47126 .55957 .46438 .55349 .45558 Mtetra
.695 .697 .848 r
.55349 .45558 .55957 .46438 .57104 .45859 .56499 .4505 Mtetra
.683 .711 .869 r
.56499 .4505 .57104 .45859 .58256 .45381 .57655 .44605 Mtetra
.67 .716 .883 r
.57655 .44605 .58256 .45381 .59414 .44993 .58815 .44209 Mtetra
.658 .71 .886 r
.58815 .44209 .59414 .44993 .60578 .44678 .59981 .43851 Mtetra
.649 .696 .88 r
.59981 .43851 .60578 .44678 .61749 .44422 .61154 .43522 Mtetra
.643 .676 .867 r
.61154 .43522 .61749 .44422 .62928 .44201 .62331 .4321 Mtetra
.639 .655 .85 r
.62331 .4321 .62928 .44201 .64112 .43986 .63515 .42906 Mtetra
.637 .637 .834 r
.63515 .42906 .64112 .43986 .65302 .4375 .64704 .42602 Mtetra
.635 .625 .823 r
.64704 .42602 .65302 .4375 .66497 .43485 .65899 .42302 Mtetra
.628 .616 .819 r
.65899 .42302 .66497 .43485 .67697 .43212 .67101 .42025 Mtetra
.614 .609 .823 r
.67101 .42025 .67697 .43212 .68906 .42985 .68312 .41809 Mtetra
.585 .597 .831 r
.68312 .41809 .68906 .42985 .70128 .42886 .69535 .41703 Mtetra
.538 .572 .837 r
.69535 .41703 .70128 .42886 .7137 .42999 .70775 .41764 Mtetra
.476 .529 .833 r
.70775 .41764 .7137 .42999 .72638 .43394 .72036 .42037 Mtetra
.414 .474 .813 r
.72036 .42037 .72638 .43394 .73938 .44105 .73323 .42545 Mtetra
.374 .422 .783 r
.73323 .42545 .73938 .44105 .75273 .45117 .74638 .43279 Mtetra
.368 .389 .751 r
.74638 .43279 .75273 .45117 .76642 .46358 .75979 .44185 Mtetra
.392 .378 .724 r
.75979 .44185 .76642 .46358 .78036 .47696 .77342 .45165 Mtetra
.434 .385 .704 r
.77342 .45165 .78036 .47696 .79443 .48951 .78717 .46083 Mtetra
.484 .403 .689 r
.78717 .46083 .79443 .48951 .80844 .49918 .80089 .46784 Mtetra
.534 .427 .678 r
.80089 .46784 .80844 .49918 .82219 .50405 .81444 .47123 Mtetra
.582 .454 .671 r
.81444 .47123 .82219 .50405 .8355 .50281 .82768 .46992 Mtetra
.626 .482 .666 r
.82768 .46992 .8355 .50281 .84825 .49502 .84052 .46353 Mtetra
.666 .51 .664 r
.84052 .46353 .84825 .49502 .86043 .48126 .85292 .4524 Mtetra
.701 .54 .666 r
.85292 .4524 .86043 .48126 .8721 .46297 .86492 .43751 Mtetra
.732 .57 .671 r
.86492 .43751 .8721 .46297 .88344 .44208 .87665 .42028 Mtetra
.758 .6 .682 r
.87665 .42028 .88344 .44208 .89462 .42057 .88824 .40226 Mtetra
.777 .631 .698 r
.88824 .40226 .89462 .42057 .90584 .40013 .89983 .38481 Mtetra
.789 .66 .722 r
.89983 .38481 .90584 .40013 .91726 .38189 .91157 .36896 Mtetra
0 .024 .592 r
.31152 .58517 .31806 .59635 .32785 .61026 .32136 .59781 Mtetra
0 .077 .638 r
.32136 .59781 .32785 .61026 .33779 .62431 .33134 .61057 Mtetra
0 .193 .712 r
.33134 .61057 .33779 .62431 .34795 .63705 .34153 .6221 Mtetra
.218 .331 .766 r
.34153 .6221 .34795 .63705 .35839 .64691 .35199 .63096 Mtetra
.425 .445 .777 r
.35199 .63096 .35839 .64691 .36915 .65244 .36276 .6358 Mtetra
.569 .522 .763 r
.36276 .6358 .36915 .65244 .38024 .65261 .37385 .63567 Mtetra
.662 .571 .742 r
.37385 .63567 .38024 .65261 .39162 .64698 .38523 .63017 Mtetra
.722 .603 .723 r
.38523 .63017 .39162 .64698 .40323 .63583 .39683 .61954 Mtetra
.761 .626 .71 r
.39683 .61954 .40323 .63583 .41498 .6201 .40857 .60463 Mtetra
.787 .643 .703 r
.40857 .60463 .41498 .6201 .42678 .6012 .42038 .58674 Mtetra
.803 .657 .701 r
.42038 .58674 .42678 .6012 .43857 .58076 .43218 .56731 Mtetra
.812 .668 .704 r
.43218 .56731 .43857 .58076 .4503 .56031 .44392 .54775 Mtetra
.814 .676 .712 r
.44392 .54775 .4503 .56031 .46194 .54107 .45558 .52923 Mtetra
.809 .682 .724 r
.45558 .52923 .46194 .54107 .47349 .52384 .46716 .51249 Mtetra
.799 .685 .739 r
.46716 .51249 .47349 .52384 .48496 .5089 .47867 .49793 Mtetra
.783 .685 .756 r
.47867 .49793 .48496 .5089 .49639 .49618 .49012 .48557 Mtetra
.766 .685 .774 r
.49012 .48557 .49639 .49618 .50779 .48538 .50155 .47522 Mtetra
.748 .687 .793 r
.50155 .47522 .50779 .48538 .51919 .47617 .51297 .46657 Mtetra
.732 .692 .813 r
.51297 .46657 .51919 .47617 .53059 .46826 .52441 .4593 Mtetra
.717 .701 .834 r
.52441 .4593 .53059 .46826 .54202 .46145 .53587 .45313 Mtetra
.703 .712 .855 r
.53587 .45313 .54202 .46145 .55349 .45558 .54737 .44779 Mtetra
.691 .722 .873 r
.54737 .44779 .55349 .45558 .56499 .4505 .55891 .44307 Mtetra
.68 .729 .887 r
.55891 .44307 .56499 .4505 .57655 .44605 .5705 .4388 Mtetra
.671 .732 .896 r
.5705 .4388 .57655 .44605 .58815 .44209 .58214 .43483 Mtetra
.664 .73 .899 r
.58214 .43483 .58815 .44209 .59981 .43851 .59383 .43107 Mtetra
.659 .724 .897 r
.59383 .43107 .59981 .43851 .61154 .43522 .60557 .42743 Mtetra
.656 .714 .891 r
.60557 .42743 .61154 .43522 .62331 .4321 .61737 .42388 Mtetra
.653 .702 .883 r
.61737 .42388 .62331 .4321 .63515 .42906 .62922 .42039 Mtetra
.65 .69 .874 r
.62922 .42039 .63515 .42906 .64704 .42602 .64112 .41697 Mtetra
.646 .68 .868 r
.64112 .41697 .64704 .42602 .65899 .42302 .65309 .41369 Mtetra
.637 .67 .865 r
.65309 .41369 .65899 .42302 .67101 .42025 .66512 .4107 Mtetra
.62 .659 .866 r
.66512 .4107 .67101 .42025 .68312 .41809 .67724 .40827 Mtetra
.594 .641 .867 r
.67724 .40827 .68312 .41809 .69535 .41703 .68947 .40672 Mtetra
.557 .613 .864 r
.68947 .40672 .69535 .41703 .70775 .41764 .70184 .40641 Mtetra
.512 .571 .852 r
.70184 .40641 .70775 .41764 .72036 .42037 .71438 .40766 Mtetra
.47 .522 .829 r
.71438 .40766 .72036 .42037 .73323 .42545 .72712 .41062 Mtetra
.443 .475 .797 r
.72712 .41062 .73323 .42545 .74638 .43279 .74007 .41525 Mtetra
.436 .44 .765 r
.74007 .41525 .74638 .43279 .75979 .44185 .75325 .42119 Mtetra
.448 .421 .736 r
.75325 .42119 .75979 .44185 .77342 .45165 .7666 .42776 Mtetra
.473 .417 .714 r
.7666 .42776 .77342 .45165 .78717 .46083 .78008 .43402 Mtetra
.506 .424 .698 r
.78008 .43402 .78717 .46083 .80089 .46784 .79357 .4389 Mtetra
.541 .439 .687 r
.79357 .4389 .80089 .46784 .81444 .47123 .80699 .44132 Mtetra
.578 .459 .681 r
.80699 .44132 .81444 .47123 .82768 .46992 .82022 .44048 Mtetra
.615 .485 .68 r
.82022 .44048 .82768 .46992 .84052 .46353 .83318 .43591 Mtetra
.653 .514 .682 r
.83318 .43591 .84052 .46353 .85292 .4524 .84583 .42764 Mtetra
.691 .548 .688 r
.84583 .42764 .85292 .4524 .86492 .43751 .85818 .41616 Mtetra
.727 .586 .697 r
.85818 .41616 .86492 .43751 .87665 .42028 .87028 .40237 Mtetra
.76 .625 .711 r
.87028 .40237 .87665 .42028 .88824 .40226 .88223 .38737 Mtetra
.785 .664 .729 r
.88223 .38737 .88824 .40226 .89983 .38481 .89413 .37231 Mtetra
.799 .698 .753 r
.89413 .37231 .89983 .38481 .91157 .36896 .90612 .35817 Mtetra
0 .197 .717 r
.30508 .57197 .31152 .58517 .32136 .59781 .315 .58286 Mtetra
.073 .234 .725 r
.315 .58286 .32136 .59781 .33134 .61057 .32504 .59384 Mtetra
.214 .302 .738 r
.32504 .59384 .33134 .61057 .34153 .6221 .33529 .60371 Mtetra
.36 .377 .743 r
.33529 .60371 .34153 .6221 .35199 .63096 .34578 .61119 Mtetra
.483 .443 .736 r
.34578 .61119 .35199 .63096 .36276 .6358 .35657 .61509 Mtetra
.577 .494 .725 r
.35657 .61509 .36276 .6358 .37385 .63567 .36765 .61456 Mtetra
.645 .533 .712 r
.36765 .61456 .37385 .63567 .38523 .63017 .379 .60924 Mtetra
.694 .563 .702 r
.379 .60924 .38523 .63017 .39683 .61954 .39057 .59937 Mtetra
.73 .587 .696 r
.39057 .59937 .39683 .61954 .40857 .60463 .40227 .58568 Mtetra
.755 .607 .693 r
.40227 .58568 .40857 .60463 .42038 .58674 .41405 .56929 Mtetra
.774 .624 .695 r
.41405 .56929 .42038 .58674 .43218 .56731 .42582 .55149 Mtetra
.786 .64 .7 r
.42582 .55149 .43218 .56731 .44392 .54775 .43756 .53353 Mtetra
.792 .655 .711 r
.43756 .53353 .44392 .54775 .45558 .52923 .44922 .51643 Mtetra
.793 .668 .725 r
.44922 .51643 .45558 .52923 .46716 .51249 .46081 .50091 Mtetra
.789 .68 .744 r
.46081 .50091 .46716 .51249 .47867 .49793 .47234 .48733 Mtetra
.779 .69 .766 r
.47234 .48733 .47867 .49793 .49012 .48557 .48381 .47576 Mtetra
.765 .699 .789 r
.48381 .47576 .49012 .48557 .50155 .47522 .49527 .46608 Mtetra
.748 .707 .813 r
.49527 .46608 .50155 .47522 .51297 .46657 .50672 .45801 Mtetra
.731 .715 .835 r
.50672 .45801 .51297 .46657 .52441 .4593 .51819 .45125 Mtetra
.714 .722 .856 r
.51819 .45125 .52441 .4593 .53587 .45313 .52968 .4455 Mtetra
.698 .729 .874 r
.52968 .4455 .53587 .45313 .54737 .44779 .54121 .4405 Mtetra
.685 .735 .889 r
.54121 .4405 .54737 .44779 .55891 .44307 .55279 .43603 Mtetra
.675 .74 .9 r
.55279 .43603 .55891 .44307 .5705 .4388 .56441 .43192 Mtetra
.668 .744 .907 r
.56441 .43192 .5705 .4388 .58214 .43483 .57608 .428 Mtetra
.665 .745 .91 r
.57608 .428 .58214 .43483 .59383 .43107 .58781 .42419 Mtetra
.663 .744 .91 r
.58781 .42419 .59383 .43107 .60557 .42743 .59958 .42041 Mtetra
.662 .74 .908 r
.59958 .42041 .60557 .42743 .61737 .42388 .6114 .41664 Mtetra
.661 .734 .903 r
.6114 .41664 .61737 .42388 .62922 .42039 .62328 .41287 Mtetra
.659 .726 .899 r
.62328 .41287 .62922 .42039 .64112 .41697 .63521 .40917 Mtetra
.654 .717 .895 r
.63521 .40917 .64112 .41697 .65309 .41369 .6472 .40561 Mtetra
.645 .707 .892 r
.6472 .40561 .65309 .41369 .66512 .4107 .65925 .40233 Mtetra
.631 .694 .89 r
.65925 .40233 .66512 .4107 .67724 .40827 .67138 .39949 Mtetra
.61 .675 .887 r
.67138 .39949 .67724 .40827 .68947 .40672 .6836 .39731 Mtetra
.582 .648 .88 r
.6836 .39731 .68947 .40672 .70184 .40641 .69594 .39603 Mtetra
.551 .611 .866 r
.69594 .39603 .70184 .40641 .71438 .40766 .70842 .39586 Mtetra
.521 .567 .843 r
.70842 .39586 .71438 .40766 .72712 .41062 .72105 .39692 Mtetra
.498 .524 .814 r
.72105 .39692 .72712 .41062 .74007 .41525 .73386 .39921 Mtetra
.487 .487 .783 r
.73386 .39921 .74007 .41525 .75325 .42119 .74684 .40255 Mtetra
.488 .462 .755 r
.74684 .40255 .75325 .42119 .7666 .42776 .75999 .40655 Mtetra
.498 .449 .733 r
.75999 .40655 .7666 .42776 .78008 .43402 .77327 .41067 Mtetra
.514 .446 .718 r
.77327 .41067 .78008 .43402 .79357 .4389 .78663 .41426 Mtetra
.536 .454 .71 r
.78663 .41426 .79357 .4389 .80699 .44132 .8 .41661 Mtetra
.562 .47 .708 r
.8 .41661 .80699 .44132 .82022 .44048 .81331 .41704 Mtetra
.596 .498 .713 r
.81331 .41704 .82022 .44048 .83318 .43591 .82648 .41495 Mtetra
.637 .537 .724 r
.82648 .41495 .83318 .43591 .84583 .42764 .83945 .40993 Mtetra
.688 .59 .74 r
.83945 .40993 .84583 .42764 .85818 .41616 .85216 .40189 Mtetra
.744 .652 .759 r
.85216 .40189 .85818 .41616 .87028 .40237 .86461 .39112 Mtetra
.796 .715 .775 r
.86461 .39112 .87028 .40237 .88223 .38737 .87685 .37836 Mtetra
.834 .768 .79 r
.87685 .37836 .88223 .38737 .89413 .37231 .88896 .36464 Mtetra
.849 .803 .805 r
.88896 .36464 .89413 .37231 .90612 .35817 .90107 .35106 Mtetra
.181 .312 .762 r
.2987 .55748 .30508 .57197 .315 .58286 .30871 .56632 Mtetra
.25 .326 .747 r
.30871 .56632 .315 .58286 .32504 .59384 .31885 .57522 Mtetra
.341 .362 .737 r
.31885 .57522 .32504 .59384 .33529 .60371 .32916 .58315 Mtetra
.434 .404 .727 r
.32916 .58315 .33529 .60371 .34578 .61119 .3397 .58902 Mtetra
.515 .446 .716 r
.3397 .58902 .34578 .61119 .35657 .61509 .35051 .59181 Mtetra
.582 .482 .706 r
.35051 .59181 .35657 .61509 .36765 .61456 .36158 .59082 Mtetra
.635 .513 .698 r
.36158 .59082 .36765 .61456 .379 .60924 .37289 .58574 Mtetra
.676 .54 .692 r
.37289 .58574 .379 .60924 .39057 .59937 .38441 .57676 Mtetra
.707 .563 .689 r
.38441 .57676 .39057 .59937 .40227 .58568 .39606 .5645 Mtetra
.731 .583 .689 r
.39606 .5645 .40227 .58568 .41405 .56929 .40777 .54992 Mtetra
.75 .602 .693 r
.40777 .54992 .41405 .56929 .42582 .55149 .4195 .53411 Mtetra
.763 .619 .701 r
.4195 .53411 .42582 .55149 .43756 .53353 .4312 .51813 Mtetra
.771 .637 .713 r
.4312 .51813 .43756 .53353 .44922 .51643 .44285 .50286 Mtetra
.775 .654 .729 r
.44285 .50286 .44922 .51643 .46081 .50091 .45444 .48892 Mtetra
.774 .671 .75 r
.45444 .48892 .46081 .50091 .47234 .48733 .46597 .47665 Mtetra
.767 .686 .774 r
.46597 .47665 .47234 .48733 .48381 .47576 .47747 .46614 Mtetra
.756 .7 .799 r
.47747 .46614 .48381 .47576 .49527 .46608 .48894 .45726 Mtetra
.741 .712 .825 r
.48894 .45726 .49527 .46608 .50672 .45801 .50042 .44982 Mtetra
.724 .722 .848 r
.50042 .44982 .50672 .45801 .51819 .45125 .51192 .44356 Mtetra
.706 .73 .869 r
.51192 .44356 .51819 .45125 .52968 .4455 .52344 .43821 Mtetra
.69 .737 .887 r
.52344 .43821 .52968 .4455 .54121 .4405 .53501 .43355 Mtetra
.676 .744 .902 r
.53501 .43355 .54121 .4405 .55279 .43603 .54662 .42939 Mtetra
.666 .751 .914 r
.54662 .42939 .55279 .43603 .56441 .43192 .55828 .42554 Mtetra
.66 .759 .923 r
.55828 .42554 .56441 .43192 .57608 .428 .56999 .42182 Mtetra
.66 .766 .928 r
.56999 .42182 .57608 .428 .58781 .42419 .58175 .41809 Mtetra
.663 .77 .93 r
.58175 .41809 .58781 .42419 .59958 .42041 .59356 .41425 Mtetra
.667 .771 .927 r
.59356 .41425 .59958 .42041 .6114 .41664 .60542 .41028 Mtetra
.67 .766 .922 r
.60542 .41028 .6114 .41664 .62328 .41287 .61732 .40622 Mtetra
.669 .757 .917 r
.61732 .40622 .62328 .41287 .63521 .40917 .62928 .40218 Mtetra
.664 .746 .911 r
.62928 .40218 .63521 .40917 .6472 .40561 .64129 .39826 Mtetra
.656 .733 .906 r
.64129 .39826 .6472 .40561 .65925 .40233 .65336 .3946 Mtetra
.644 .718 .902 r
.65336 .3946 .65925 .40233 .67138 .39949 .6655 .39131 Mtetra
.627 .7 .897 r
.6655 .39131 .67138 .39949 .6836 .39731 .67773 .38851 Mtetra
.607 .676 .889 r
.67773 .38851 .6836 .39731 .69594 .39603 .69005 .38637 Mtetra
.585 .645 .876 r
.69005 .38637 .69594 .39603 .70842 .39586 .70248 .385 Mtetra
.561 .608 .857 r
.70248 .385 .70842 .39586 .72105 .39692 .71504 .38453 Mtetra
.54 .569 .833 r
.71504 .38453 .72105 .39692 .73386 .39921 .72775 .385 Mtetra
.524 .532 .806 r
.72775 .385 .73386 .39921 .74684 .40255 .7406 .38642 Mtetra
.512 .502 .782 r
.7406 .38642 .74684 .40255 .75999 .40655 .75362 .38868 Mtetra
.505 .481 .764 r
.75362 .38868 .75999 .40655 .77327 .41067 .7668 .39163 Mtetra
.501 .469 .753 r
.7668 .39163 .77327 .41067 .78663 .41426 .78012 .39503 Mtetra
.501 .468 .752 r
.78012 .39503 .78663 .41426 .8 .41661 .79357 .39847 Mtetra
.509 .483 .763 r
.79357 .39847 .8 .41661 .81331 .41704 .80709 .40131 Mtetra
.532 .522 .79 r
.80709 .40131 .81331 .41704 .82648 .41495 .82058 .40267 Mtetra
.581 .6 .836 r
.82058 .40267 .82648 .41495 .83945 .40993 .83395 .40154 Mtetra
.669 .727 .893 r
.83395 .40154 .83945 .40993 .85216 .40189 .84707 .39707 Mtetra
.778 .877 .919 r
.84707 .39707 .85216 .40189 .86461 .39112 .85985 .38889 Mtetra
.85 .968 .875 r
.85985 .38889 .86461 .39112 .87685 .37836 .87231 .37737 Mtetra
.878 .989 .815 r
.87231 .37737 .87685 .37836 .88896 .36464 .88451 .3636 Mtetra
.892 .985 .799 r
.88451 .3636 .88896 .36464 .90107 .35106 .89659 .34903 Mtetra
.315 .388 .778 r
.29233 .54247 .2987 .55748 .30871 .56632 .30246 .54915 Mtetra
.359 .388 .755 r
.30246 .54915 .30871 .56632 .31885 .57522 .3127 .55586 Mtetra
.418 .403 .736 r
.3127 .55586 .31885 .57522 .32916 .58315 .32309 .56176 Mtetra
.48 .427 .721 r
.32309 .56176 .32916 .58315 .3397 .58902 .33369 .56594 Mtetra
.538 .454 .709 r
.33369 .56594 .3397 .58902 .35051 .59181 .34451 .56759 Mtetra
.587 .481 .7 r
.34451 .56759 .35051 .59181 .36158 .59082 .35557 .56612 Mtetra
.629 .505 .693 r
.35557 .56612 .36158 .59082 .37289 .58574 .36685 .56128 Mtetra
.663 .528 .689 r
.36685 .56128 .37289 .58574 .38441 .57676 .3783 .55323 Mtetra
.691 .549 .688 r
.3783 .55323 .38441 .57676 .39606 .5645 .38988 .54248 Mtetra
.713 .568 .69 r
.38988 .54248 .39606 .5645 .40777 .54992 .40153 .5298 Mtetra
.73 .587 .695 r
.40153 .5298 .40777 .54992 .4195 .53411 .4132 .51609 Mtetra
.744 .606 .705 r
.4132 .51609 .4195 .53411 .4312 .51813 .42485 .50223 Mtetra
.753 .625 .718 r
.42485 .50223 .4312 .51813 .44285 .50286 .43647 .48893 Mtetra
.757 .644 .736 r
.43647 .48893 .44285 .50286 .45444 .48892 .44804 .47673 Mtetra
.757 .663 .758 r
.44804 .47673 .45444 .48892 .46597 .47665 .45957 .4659 Mtetra
.753 .681 .782 r
.45957 .4659 .46597 .47665 .47747 .46614 .47108 .45653 Mtetra
.743 .698 .809 r
.47108 .45653 .47747 .46614 .48894 .45726 .48257 .44854 Mtetra
.729 .712 .835 r
.48257 .44854 .48894 .45726 .50042 .44982 .49408 .44178 Mtetra
.713 .724 .859 r
.49408 .44178 .50042 .44982 .51192 .44356 .5056 .43607 Mtetra
.694 .734 .881 r
.5056 .43607 .51192 .44356 .52344 .43821 .51716 .43123 Mtetra
.675 .743 .902 r
.51716 .43123 .52344 .43821 .53501 .43355 .52876 .4271 Mtetra
.656 .755 .922 r
.52876 .4271 .53501 .43355 .54662 .42939 .54041 .42351 Mtetra
.641 .77 .941 r
.54041 .42351 .54662 .42939 .55828 .42554 .55211 .42023 Mtetra
.634 .789 .956 r
.55211 .42023 .55828 .42554 .56999 .42182 .56386 .41699 Mtetra
.638 .809 .965 r
.56386 .41699 .56999 .42182 .58175 .41809 .57567 .41354 Mtetra
.652 .825 .967 r
.57567 .41354 .58175 .41809 .59356 .41425 .58752 .40968 Mtetra
.669 .83 .961 r
.58752 .40968 .59356 .41425 .60542 .41028 .59942 .40539 Mtetra
.683 .823 .951 r
.59942 .40539 .60542 .41028 .61732 .40622 .61135 .4008 Mtetra
.687 .806 .939 r
.61135 .4008 .61732 .40622 .62928 .40218 .62333 .39614 Mtetra
.683 .785 .927 r
.62333 .39614 .62928 .40218 .64129 .39826 .63536 .39161 Mtetra
.673 .762 .918 r
.63536 .39161 .64129 .39826 .65336 .3946 .64745 .38739 Mtetra
.659 .741 .911 r
.64745 .38739 .65336 .3946 .6655 .39131 .65961 .38356 Mtetra
.645 .721 .904 r
.65961 .38356 .6655 .39131 .67773 .38851 .67184 .38019 Mtetra
.629 .699 .896 r
.67184 .38019 .67773 .38851 .69005 .38637 .68415 .37732 Mtetra
.611 .673 .885 r
.68415 .37732 .69005 .38637 .70248 .385 .69656 .37503 Mtetra
.591 .643 .871 r
.69656 .37503 .70248 .385 .71504 .38453 .70908 .37343 Mtetra
.57 .61 .853 r
.70908 .37343 .71504 .38453 .72775 .385 .72172 .37264 Mtetra
.547 .575 .834 r
.72172 .37264 .72775 .385 .7406 .38642 .73451 .37283 Mtetra
.519 .541 .818 r
.73451 .37283 .7406 .38642 .75362 .38868 .74748 .37423 Mtetra
.485 .509 .807 r
.74748 .37423 .75362 .38868 .7668 .39163 .76065 .37706 Mtetra
.441 .483 .806 r
.76065 .37706 .7668 .39163 .78012 .39503 .77405 .38148 Mtetra
.381 .463 .819 r
.77405 .38148 .78012 .39503 .79357 .39847 .78771 .38733 Mtetra
.295 .457 .852 r
.78771 .38733 .79357 .39847 .80709 .40131 .80156 .39394 Mtetra
.159 .476 .896 r
.80156 .39394 .80709 .40131 .82058 .40267 .81552 .39998 Mtetra
0 .499 .823 r
.81552 .39998 .82058 .40267 .83395 .40154 .8294 .40363 Mtetra
.147 0 0 r
.8294 .40363 .83395 .40154 .84707 .39707 .84299 .40304 Mtetra
.07 0 0 r
.84299 .40304 .84707 .39707 .85985 .38889 .85611 .39705 Mtetra
0 0 0 r
.85611 .39705 .85985 .38889 .87231 .37737 .86871 .3857 Mtetra
.86871 .3857 .87231 .37737 .88451 .3636 .88085 .37029 Mtetra
.88085 .37029 .88451 .3636 .89659 .34903 .89274 .35293 Mtetra
.405 .445 .789 r
.28594 .52763 .29233 .54247 .30246 .54915 .29619 .53222 Mtetra
.432 .435 .763 r
.29619 .53222 .30246 .54915 .3127 .55586 .30653 .53683 Mtetra
.47 .439 .741 r
.30653 .53683 .3127 .55586 .32309 .56176 .31701 .54077 Mtetra
.513 .451 .724 r
.31701 .54077 .32309 .56176 .33369 .56594 .32766 .54334 Mtetra
.555 .468 .711 r
.32766 .54334 .33369 .56594 .34451 .56759 .33851 .54388 Mtetra
.594 .487 .702 r
.33851 .54388 .34451 .56759 .35557 .56612 .34956 .54194 Mtetra
.627 .506 .695 r
.34956 .54194 .35557 .56612 .36685 .56128 .3608 .53732 Mtetra
.656 .525 .692 r
.3608 .53732 .36685 .56128 .3783 .55323 .37219 .53015 Mtetra
.68 .544 .693 r
.37219 .53015 .3783 .55323 .38988 .54248 .3837 .52084 Mtetra
.7 .562 .696 r
.3837 .52084 .38988 .54248 .40153 .5298 .39527 .50999 Mtetra
.716 .581 .703 r
.39527 .50999 .40153 .5298 .4132 .51609 .40688 .49832 Mtetra
.728 .6 .713 r
.40688 .49832 .4132 .51609 .42485 .50223 .41848 .48651 Mtetra
.737 .619 .728 r
.41848 .48651 .42485 .50223 .43647 .48893 .43005 .47515 Mtetra
.742 .639 .746 r
.43005 .47515 .43647 .48893 .44804 .47673 .4416 .46466 Mtetra
.742 .659 .769 r
.4416 .46466 .44804 .47673 .45957 .4659 .45313 .45525 Mtetra
.738 .679 .793 r
.45313 .45525 .45957 .4659 .47108 .45653 .46465 .44702 Mtetra
.729 .697 .819 r
.46465 .44702 .47108 .45653 .48257 .44854 .47616 .43993 Mtetra
.715 .712 .846 r
.47616 .43993 .48257 .44854 .49408 .44178 .48769 .4339 Mtetra
.697 .725 .872 r
.48769 .4339 .49408 .44178 .5056 .43607 .49924 .42887 Mtetra
.673 .737 .899 r
.49924 .42887 .5056 .43607 .51716 .43123 .51082 .42479 Mtetra
.641 .751 .929 r
.51082 .42479 .51716 .43123 .52876 .4271 .52246 .42159 Mtetra
.601 .771 .961 r
.52246 .42159 .52876 .4271 .54041 .42351 .53415 .41912 Mtetra
.555 .798 .989 r
.53415 .41912 .54041 .42351 .55211 .42023 .5459 .41705 Mtetra
.515 .83 1 r
.5459 .41705 .55211 .42023 .56386 .41699 .55771 .41489 Mtetra
.506 .864 .988 r
.55771 .41489 .56386 .41699 .57567 .41354 .56958 .41208 Mtetra
.547 .9 .974 r
.56958 .41208 .57567 .41354 .58752 .40968 .58149 .40824 Mtetra
.619 .927 .97 r
.58149 .40824 .58752 .40968 .59942 .40539 .59342 .40333 Mtetra
.685 .928 .97 r
.59342 .40333 .59942 .40539 .61135 .4008 .60539 .39767 Mtetra
.717 .898 .961 r
.60539 .39767 .61135 .4008 .62333 .39614 .61738 .39175 Mtetra
.718 .854 .947 r
.61738 .39175 .62333 .39614 .63536 .39161 .62942 .38606 Mtetra
.702 .809 .932 r
.62942 .38606 .63536 .39161 .64745 .38739 .64152 .38088 Mtetra
.682 .773 .919 r
.64152 .38088 .64745 .38739 .65961 .38356 .65369 .37629 Mtetra
.664 .744 .91 r
.65369 .37629 .65961 .38356 .67184 .38019 .66593 .37229 Mtetra
.647 .72 .902 r
.66593 .37229 .67184 .38019 .68415 .37732 .67825 .3688 Mtetra
.63 .697 .893 r
.67825 .3688 .68415 .37732 .69656 .37503 .69065 .36583 Mtetra
.612 .673 .884 r
.69065 .36583 .69656 .37503 .70908 .37343 .70316 .36347 Mtetra
.588 .644 .873 r
.70316 .36347 .70908 .37343 .72172 .37264 .71578 .36191 Mtetra
.554 .611 .864 r
.71578 .36191 .72172 .37264 .73451 .37283 .72855 .36152 Mtetra
.503 .572 .859 r
.72855 .36152 .73451 .37283 .74748 .37423 .74152 .36283 Mtetra
.418 .524 .859 r
.74152 .36283 .74748 .37423 .76065 .37706 .75477 .36649 Mtetra
.27 .455 .858 r
.75477 .36649 .76065 .37706 .77405 .38148 .76835 .37303 Mtetra
0 .33 .814 r
.76835 .37303 .77405 .38148 .78771 .38733 .78232 .38255 Mtetra
0 .1 .578 r
.78232 .38255 .78771 .38733 .80156 .39394 .79665 .39426 Mtetra
.664 .112 0 r
.79665 .39426 .80156 .39394 .81552 .39998 .8112 .40624 Mtetra
.653 .172 .097 r
.8112 .40624 .81552 .39998 .8294 .40363 .8257 .41561 Mtetra
.551 .14 .216 r
.8257 .41561 .8294 .40363 .84299 .40304 .83983 .41932 Mtetra
.416 .063 .255 r
.83983 .41932 .84299 .40304 .85611 .39705 .8533 .41523 Mtetra
.257 0 .24 r
.8533 .41523 .85611 .39705 .86871 .3857 .86598 .40302 Mtetra
.069 0 .176 r
.86598 .40302 .86871 .3857 .88085 .37029 .87795 .38443 Mtetra
0 0 .052 r
.87795 .38443 .88085 .37029 .89274 .35293 .88947 .36251 Mtetra
.468 .493 .801 r
.27947 .51355 .28594 .52763 .29619 .53222 .28983 .51628 Mtetra
.483 .478 .775 r
.28983 .51628 .29619 .53222 .30653 .53683 .30028 .51901 Mtetra
.509 .474 .753 r
.30028 .51901 .30653 .53683 .31701 .54077 .31084 .5212 Mtetra
.54 .478 .735 r
.31084 .5212 .31701 .54077 .32766 .54334 .32155 .52232 Mtetra
.571 .487 .721 r
.32155 .52232 .32766 .54334 .33851 .54388 .33243 .52186 Mtetra
.601 .5 .711 r
.33243 .52186 .33851 .54388 .34956 .54194 .34348 .51948 Mtetra
.629 .515 .705 r
.34348 .51948 .34956 .54194 .3608 .53732 .35469 .51503 Mtetra
.653 .531 .702 r
.35469 .51503 .3608 .53732 .37219 .53015 .36603 .50862 Mtetra
.673 .547 .703 r
.36603 .50862 .37219 .53015 .3837 .52084 .37747 .50057 Mtetra
.69 .564 .707 r
.37747 .50057 .3837 .52084 .39527 .50999 .38897 .49135 Mtetra
.705 .582 .715 r
.38897 .49135 .39527 .50999 .40688 .49832 .40051 .4815 Mtetra
.716 .6 .726 r
.40051 .4815 .40688 .49832 .41848 .48651 .41206 .47155 Mtetra
.723 .62 .742 r
.41206 .47155 .41848 .48651 .43005 .47515 .4236 .46194 Mtetra
.728 .64 .761 r
.4236 .46194 .43005 .47515 .4416 .46466 .43513 .45299 Mtetra
.728 .66 .783 r
.43513 .45299 .4416 .46466 .45313 .45525 .44665 .44489 Mtetra
.724 .68 .807 r
.44665 .44489 .45313 .45525 .46465 .44702 .45817 .43772 Mtetra
.714 .697 .833 r
.45817 .43772 .46465 .44702 .47616 .43993 .4697 .43151 Mtetra
.698 .713 .86 r
.4697 .43151 .47616 .43993 .48769 .4339 .48124 .42628 Mtetra
.673 .726 .89 r
.48124 .42628 .48769 .4339 .49924 .42887 .49282 .42215 Mtetra
.63 .74 .927 r
.49282 .42215 .49924 .42887 .51082 .42479 .50443 .41926 Mtetra
.553 .754 .971 r
.50443 .41926 .51082 .42479 .52246 .42159 .51609 .4177 Mtetra
.406 .754 .994 r
.51609 .4177 .52246 .42159 .53415 .41912 .52783 .41733 Mtetra
.165 .68 .891 r
.52783 .41733 .53415 .41912 .5459 .41705 .53964 .4176 Mtetra
.048 0 0 r
.53964 .4176 .5459 .41705 .55771 .41489 .55153 .41752 Mtetra
.094 0 0 r
.55153 .41752 .55771 .41489 .56958 .41208 .56348 .41598 Mtetra
0 0 0 r
.56348 .41598 .56958 .41208 .58149 .40824 .57546 .41221 Mtetra
.57546 .41221 .58149 .40824 .59342 .40333 .58746 .40613 Mtetra
.491 .882 .709 r
.58746 .40613 .59342 .40333 .60539 .39767 .59945 .39842 Mtetra
.696 .982 .871 r
.59945 .39842 .60539 .39767 .61738 .39175 .61145 .39015 Mtetra
.765 .957 .934 r
.61145 .39015 .61738 .39175 .62942 .38606 .62348 .38229 Mtetra
.752 .885 .939 r
.62348 .38229 .62942 .38606 .64152 .38088 .63558 .37541 Mtetra
.719 .82 .927 r
.63558 .37541 .64152 .38088 .65369 .37629 .64774 .36965 Mtetra
.688 .773 .916 r
.64774 .36965 .65369 .37629 .66593 .37229 .65999 .36483 Mtetra
.664 .741 .907 r
.65999 .36483 .66593 .37229 .67825 .3688 .67232 .36074 Mtetra
.645 .718 .901 r
.67232 .36074 .67825 .3688 .69065 .36583 .68473 .35725 Mtetra
.625 .696 .895 r
.68473 .35725 .69065 .36583 .70316 .36347 .69724 .3544 Mtetra
.597 .671 .892 r
.69724 .3544 .70316 .36347 .71578 .36191 .70987 .35245 Mtetra
.548 .639 .893 r
.70987 .35245 .71578 .36191 .72855 .36152 .72266 .35196 Mtetra
.458 .59 .897 r
.72266 .35196 .72855 .36152 .74152 .36283 .73569 .35376 Mtetra
.279 .501 .892 r
.73569 .35376 .74152 .36283 .75477 .36649 .74906 .35891 Mtetra
0 .307 .797 r
.74906 .35891 .75477 .36649 .76835 .37303 .76289 .36835 Mtetra
.54 .02 0 r
.76289 .36835 .76835 .37303 .78232 .38255 .77725 .38239 Mtetra
.764 .252 0 r
.77725 .38239 .78232 .38255 .79665 .39426 .79213 .40008 Mtetra
.778 .322 .164 r
.79213 .40008 .79665 .39426 .8112 .40624 .80734 .41884 Mtetra
.715 .309 .278 r
.80734 .41884 .8112 .40624 .8257 .41561 .82254 .4346 Mtetra
.615 .252 .331 r
.82254 .4346 .8257 .41561 .83983 .41932 .83726 .44288 Mtetra
.483 .161 .344 r
.83726 .44288 .83983 .41932 .8533 .41523 .85108 .44042 Mtetra
.318 .038 .321 r
.85108 .44042 .8533 .41523 .86598 .40302 .86379 .42659 Mtetra
.118 0 .258 r
.86379 .42659 .86598 .40302 .87795 .38443 .87549 .40367 Mtetra
0 0 .143 r
.87549 .40367 .87795 .38443 .88947 .36251 .88655 .37591 Mtetra
.512 .537 .818 r
.27288 .50068 .27947 .51355 .28983 .51628 .28335 .50188 Mtetra
.521 .519 .794 r
.28335 .50188 .28983 .51628 .30028 .51901 .29389 .50307 Mtetra
.539 .511 .773 r
.29389 .50307 .30028 .51901 .31084 .5212 .30453 .50383 Mtetra
.562 .51 .755 r
.30453 .50383 .31084 .5212 .32155 .52232 .3153 .50374 Mtetra
.587 .514 .74 r
.3153 .50374 .32155 .52232 .33243 .52186 .32621 .50243 Mtetra
.611 .523 .729 r
.32621 .50243 .33243 .52186 .34348 .51948 .33726 .49963 Mtetra
.634 .533 .723 r
.33726 .49963 .34348 .51948 .35469 .51503 .34845 .49526 Mtetra
.654 .546 .719 r
.34845 .49526 .35469 .51503 .36603 .50862 .35975 .48942 Mtetra
.671 .559 .72 r
.35975 .48942 .36603 .50862 .37747 .50057 .37114 .48236 Mtetra
.686 .574 .724 r
.37114 .48236 .37747 .50057 .38897 .49135 .38259 .47446 Mtetra
.697 .591 .732 r
.38259 .47446 .38897 .49135 .40051 .4815 .39408 .46611 Mtetra
.707 .608 .744 r
.39408 .46611 .40051 .4815 .41206 .47155 .40558 .45771 Mtetra
.713 .627 .76 r
.40558 .45771 .41206 .47155 .4236 .46194 .41709 .44958 Mtetra
.716 .647 .779 r
.41709 .44958 .4236 .46194 .43513 .45299 .42861 .44195 Mtetra
.715 .666 .8 r
.42861 .44195 .43513 .45299 .44665 .44489 .44012 .43497 Mtetra
.71 .684 .823 r
.44012 .43497 .44665 .44489 .45817 .43772 .45165 .42875 Mtetra
.699 .701 .848 r
.45165 .42875 .45817 .43772 .4697 .43151 .46319 .42338 Mtetra
.676 .714 .877 r
.46319 .42338 .4697 .43151 .48124 .42628 .47475 .41906 Mtetra
.632 .725 .915 r
.47475 .41906 .48124 .42628 .49282 .42215 .48634 .41614 Mtetra
.534 .73 .964 r
.48634 .41614 .49282 .42215 .50443 .41926 .49797 .41506 Mtetra
.286 .679 .973 r
.49797 .41506 .50443 .41926 .51609 .4177 .50966 .41617 Mtetra
.201 0 0 r
.50966 .41617 .51609 .4177 .52783 .41733 .52143 .41932 Mtetra
.495 0 0 r
.52143 .41932 .52783 .41733 .53964 .4176 .53331 .42353 Mtetra
.532 .048 .054 r
.53331 .42353 .53964 .4176 .55153 .41752 .5453 .42703 Mtetra
.47 .039 .138 r
.5453 .42703 .55153 .41752 .56348 .41598 .55736 .42769 Mtetra
.35 0 .133 r
.55736 .42769 .56348 .41598 .57546 .41221 .56945 .42405 Mtetra
.164 0 .048 r
.56945 .42405 .57546 .41221 .58746 .40613 .58152 .41599 Mtetra
0 0 0 r
.58152 .41599 .58746 .40613 .59945 .39842 .59355 .4048 Mtetra
.59355 .4048 .59945 .39842 .61145 .39015 .60555 .39254 Mtetra
.752 .987 .77 r
.60555 .39254 .61145 .39015 .62348 .38229 .61756 .38106 Mtetra
.814 .969 .902 r
.61756 .38106 .62348 .38229 .63558 .37541 .62963 .37141 Mtetra
.773 .882 .925 r
.62963 .37141 .63558 .37541 .64774 .36965 .64178 .36379 Mtetra
.723 .81 .919 r
.64178 .36379 .64774 .36965 .65999 .36483 .65403 .35784 Mtetra
.685 .764 .912 r
.65403 .35784 .65999 .36483 .67232 .36074 .66636 .35307 Mtetra
.658 .735 .907 r
.66636 .35307 .67232 .36074 .68473 .35725 .67879 .34913 Mtetra
.634 .714 .905 r
.67879 .34913 .68473 .35725 .69724 .3544 .69132 .34596 Mtetra
.598 .69 .907 r
.69132 .34596 .69724 .3544 .70987 .35245 .70397 .34385 Mtetra
.531 .656 .915 r
.70397 .34385 .70987 .35245 .72266 .35196 .71681 .34352 Mtetra
.392 .588 .921 r
.71681 .34352 .72266 .35196 .73569 .35376 .72991 .34609 Mtetra
.094 .426 .87 r
.72991 .34609 .73569 .35376 .74906 .35891 .74343 .35297 Mtetra
0 .093 .597 r
.74343 .35297 .74906 .35891 .76289 .36835 .75751 .36545 Mtetra
.736 .224 0 r
.75751 .36545 .76289 .36835 .77725 .38239 .77226 .38407 Mtetra
.828 .36 .089 r
.77226 .38407 .77725 .38239 .79213 .40008 .78767 .40774 Mtetra
.815 .389 .231 r
.78767 .40774 .79213 .40008 .80734 .41884 .80354 .4332 Mtetra
.755 .362 .309 r
.80354 .4332 .80734 .41884 .82254 .4346 .81941 .45521 Mtetra
.654 .293 .348 r
.81941 .45521 .82254 .4346 .83726 .44288 .83469 .46787 Mtetra
.502 .18 .353 r
.83469 .46787 .83726 .44288 .85108 .44042 .84883 .46678 Mtetra
.292 .02 .318 r
.84883 .46678 .85108 .44042 .86379 .42659 .86155 .45098 Mtetra
.03 0 .233 r
.86155 .45098 .86379 .42659 .87549 .40367 .87297 .42339 Mtetra
0 0 .095 r
.87297 .42339 .87549 .40367 .88655 .37591 .88356 .38954 Mtetra
.541 .58 .843 r
.26615 .48936 .27288 .50068 .28335 .50188 .27669 .48947 Mtetra
.547 .564 .823 r
.27669 .48947 .28335 .50188 .29389 .50307 .28731 .48956 Mtetra
.561 .554 .804 r
.28731 .48956 .29389 .50307 .30453 .50383 .29802 .48928 Mtetra
.581 .551 .786 r
.29802 .48928 .30453 .50383 .3153 .50374 .30884 .48828 Mtetra
.604 .553 .771 r
.30884 .48828 .3153 .50374 .32621 .50243 .31978 .48626 Mtetra
.626 .558 .759 r
.31978 .48626 .32621 .50243 .33726 .49963 .33085 .48305 Mtetra
.645 .565 .75 r
.33085 .48305 .33726 .49963 .34845 .49526 .34204 .47861 Mtetra
.662 .574 .745 r
.34204 .47861 .34845 .49526 .35975 .48942 .35333 .47306 Mtetra
.675 .584 .745 r
.35333 .47306 .35975 .48942 .37114 .48236 .36469 .46665 Mtetra
.687 .595 .748 r
.36469 .46665 .37114 .48236 .38259 .47446 .3761 .45967 Mtetra
.695 .609 .756 r
.3761 .45967 .38259 .47446 .39408 .46611 .38756 .45242 Mtetra
.701 .624 .767 r
.38756 .45242 .39408 .46611 .40558 .45771 .39903 .4452 Mtetra
.705 .641 .782 r
.39903 .4452 .40558 .45771 .41709 .44958 .41052 .43822 Mtetra
.706 .658 .8 r
.41052 .43822 .41709 .44958 .42861 .44195 .42202 .43164 Mtetra
.704 .676 .819 r
.42202 .43164 .42861 .44195 .44012 .43497 .43354 .42558 Mtetra
.697 .692 .841 r
.43354 .42558 .44012 .43497 .45165 .42875 .44507 .42015 Mtetra
.681 .705 .866 r
.44507 .42015 .45165 .42875 .46319 .42338 .45662 .41558 Mtetra
.646 .715 .898 r
.45662 .41558 .46319 .42338 .47475 .41906 .46819 .41227 Mtetra
.561 .715 .944 r
.46819 .41227 .47475 .41906 .48634 .41614 .47979 .41092 Mtetra
.316 .657 .972 r
.47979 .41092 .48634 .41614 .49797 .41506 .49143 .41238 Mtetra
.284 0 0 r
.49143 .41238 .49797 .41506 .50966 .41617 .50313 .41734 Mtetra
.652 .116 0 r
.50313 .41734 .50966 .41617 .52143 .41932 .51494 .42564 Mtetra
.694 .249 .192 r
.51494 .42564 .52143 .41932 .53331 .42353 .52689 .43572 Mtetra
.651 .26 .291 r
.52689 .43572 .53331 .42353 .5453 .42703 .53899 .44456 Mtetra
.569 .212 .323 r
.53899 .44456 .5453 .42703 .55736 .42769 .5512 .44854 Mtetra
.447 .116 .309 r
.5512 .44854 .55736 .42769 .56945 .42405 .56343 .44512 Mtetra
.274 0 .246 r
.56343 .44512 .56945 .42405 .58152 .41599 .57561 .43407 Mtetra
.029 0 .109 r
.57561 .43407 .58152 .41599 .59355 .4048 .58768 .4177 Mtetra
0 0 0 r
.58768 .4177 .59355 .4048 .60555 .39254 .59967 .39953 Mtetra
.67 .875 .498 r
.59967 .39953 .60555 .39254 .61756 .38106 .61164 .38273 Mtetra
.854 .997 .785 r
.61164 .38273 .61756 .38106 .62963 .37141 .62367 .36905 Mtetra
.836 .937 .893 r
.62367 .36905 .62963 .37141 .64178 .36379 .63579 .35879 Mtetra
.766 .849 .913 r
.63579 .35879 .64178 .36379 .65403 .35784 .64803 .3513 Mtetra
.71 .787 .912 r
.64803 .3513 .65403 .35784 .66636 .35307 .66038 .34569 Mtetra
.671 .751 .91 r
.66038 .34569 .66636 .35307 .67879 .34913 .67283 .3413 Mtetra
.64 .727 .911 r
.67283 .3413 .67879 .34913 .69132 .34596 .68538 .3379 Mtetra
.596 .702 .917 r
.68538 .3379 .69132 .34596 .70397 .34385 .69806 .33573 Mtetra
.513 .663 .929 r
.69806 .33573 .70397 .34385 .71681 .34352 .71094 .33561 Mtetra
.333 .572 .927 r
.71094 .33561 .71681 .34352 .72991 .34609 .72412 .33885 Mtetra
0 .346 .821 r
.72412 .33885 .72991 .34609 .74343 .35297 .73776 .34715 Mtetra
.52 .024 0 r
.73776 .34715 .74343 .35297 .75751 .36545 .75203 .36209 Mtetra
.779 .289 0 r
.75203 .36209 .75751 .36545 .77226 .38407 .76708 .38435 Mtetra
.853 .397 .085 r
.76708 .38435 .77226 .38407 .78767 .40774 .78291 .41275 Mtetra
.853 .422 .2 r
.78291 .41275 .78767 .40774 .80354 .4332 .79927 .44351 Mtetra
.806 .394 .266 r
.79927 .44351 .80354 .4332 .81941 .45521 .81567 .47046 Mtetra
.702 .308 .298 r
.81567 .47046 .81941 .45521 .83469 .46787 .83139 .48655 Mtetra
.496 .138 .289 r
.83139 .48655 .83469 .46787 .84883 .46678 .84578 .48645 Mtetra
.142 0 .207 r
.84578 .48645 .84883 .46678 .86155 .45098 .85852 .46895 Mtetra
0 0 .047 r
.85852 .46895 .86155 .45098 .87297 .42339 .86974 .43751 Mtetra
0 0 0 r
.86974 .43751 .87297 .42339 .88356 .38954 .87997 .39868 Mtetra
.55 .625 .88 r
.25923 .4799 .26615 .48936 .27669 .48947 .26982 .47947 Mtetra
.554 .615 .868 r
.26982 .47947 .27669 .48947 .28731 .48956 .28048 .479 Mtetra
.57 .611 .854 r
.28048 .479 .28731 .48956 .29802 .48928 .29124 .47816 Mtetra
.595 .612 .839 r
.29124 .47816 .29802 .48928 .30884 .48828 .3021 .47658 Mtetra
.622 .614 .822 r
.3021 .47658 .30884 .48828 .31978 .48626 .31309 .47401 Mtetra
.647 .617 .806 r
.31309 .47401 .31978 .48626 .33085 .48305 .3242 .47033 Mtetra
.666 .619 .792 r
.3242 .47033 .33085 .48305 .34204 .47861 .33541 .46557 Mtetra
.68 .622 .783 r
.33541 .46557 .34204 .47861 .35333 .47306 .34671 .45994 Mtetra
.69 .625 .779 r
.34671 .45994 .35333 .47306 .36469 .46665 .35808 .45371 Mtetra
.696 .631 .779 r
.35808 .45371 .36469 .46665 .3761 .45967 .36949 .44716 Mtetra
.699 .638 .784 r
.36949 .44716 .3761 .45967 .38756 .45242 .38093 .44055 Mtetra
.701 .648 .794 r
.38093 .44055 .38756 .45242 .39903 .4452 .39239 .43409 Mtetra
.701 .661 .807 r
.39239 .43409 .39903 .4452 .41052 .43822 .40387 .4279 Mtetra
.699 .674 .822 r
.40387 .4279 .41052 .43822 .42202 .43164 .41537 .42208 Mtetra
.695 .688 .839 r
.41537 .42208 .42202 .43164 .43354 .42558 .42689 .4167 Mtetra
.684 .7 .859 r
.42689 .4167 .43354 .42558 .44507 .42015 .43843 .41193 Mtetra
.661 .709 .883 r
.43843 .41193 .44507 .42015 .45662 .41558 .45 .40809 Mtetra
.605 .711 .919 r
.45 .40809 .45662 .41558 .46819 .41227 .46158 .40586 Mtetra
.444 .679 .964 r
.46158 .40586 .46819 .41227 .47979 .41092 .47317 .40633 Mtetra
0 .436 .832 r
.47317 .40633 .47979 .41092 .49143 .41238 .4848 .41089 Mtetra
.658 .102 0 r
.4848 .41089 .49143 .41238 .50313 .41734 .4965 .42063 Mtetra
.775 .323 .175 r
.4965 .42063 .50313 .41734 .51494 .42564 .50832 .43542 Mtetra
.759 .368 .314 r
.50832 .43542 .51494 .42564 .52689 .43572 .52033 .45297 Mtetra
.703 .348 .371 r
.52033 .45297 .52689 .43572 .53899 .44456 .53255 .46865 Mtetra
.613 .283 .387 r
.53255 .46865 .53899 .44456 .5512 .44854 .54492 .47693 Mtetra
.479 .173 .368 r
.54492 .47693 .5512 .44854 .56343 .44512 .55732 .47378 Mtetra
.282 .005 .304 r
.55732 .47378 .56343 .44512 .57561 .43407 .56963 .45891 Mtetra
.007 0 .171 r
.56963 .45891 .57561 .43407 .58768 .4177 .58177 .43588 Mtetra
0 0 0 r
.58177 .43588 .58768 .4177 .59967 .39953 .59376 .41018 Mtetra
.688 .818 .371 r
.59376 .41018 .59967 .39953 .61164 .38273 .6057 .38667 Mtetra
.888 .974 .668 r
.6057 .38667 .61164 .38273 .62367 .36905 .61768 .36796 Mtetra
.892 .957 .835 r
.61768 .36796 .62367 .36905 .63579 .35879 .62977 .35444 Mtetra
.812 .876 .893 r
.62977 .35444 .63579 .35879 .64803 .3513 .642 .34508 Mtetra
.736 .806 .907 r
.642 .34508 .64803 .3513 .66038 .34569 .65435 .33851 Mtetra
.685 .763 .911 r
.65435 .33851 .66038 .34569 .67283 .3413 .66682 .33365 Mtetra
.646 .736 .915 r
.66682 .33365 .67283 .3413 .68538 .3379 .6794 .33001 Mtetra
.597 .71 .923 r
.6794 .33001 .68538 .3379 .69806 .33573 .69212 .32776 Mtetra
.506 .665 .934 r
.69212 .32776 .69806 .33573 .71094 .33561 .70503 .3277 Mtetra
.311 .561 .926 r
.70503 .3277 .71094 .33561 .72412 .33885 .71826 .33124 Mtetra
0 .319 .805 r
.71826 .33124 .72412 .33885 .73776 .34715 .73196 .34021 Mtetra
0 0 .499 r
.73196 .34021 .73776 .34715 .75203 .36209 .74633 .35631 Mtetra
.744 .273 0 r
.74633 .35631 .75203 .36209 .76708 .38435 .76152 .38033 Mtetra
.839 .385 0 r
.76152 .38033 .76708 .38435 .78291 .41275 .77754 .41104 Mtetra
.865 .419 .056 r
.77754 .41104 .78291 .41275 .79927 .44351 .79413 .44441 Mtetra
.85 .392 .086 r
.79413 .44441 .79927 .44351 .81567 .47046 .81077 .4738 Mtetra
.761 .266 .048 r
.81077 .4738 .81567 .47046 .83139 .48655 .82672 .4916 Mtetra
.344 0 0 r
.82672 .4916 .83139 .48655 .84578 .48645 .84126 .49199 Mtetra
.645 .852 .463 r
.84126 .49199 .84578 .48645 .85852 .46895 .85405 .47362 Mtetra
.93 .888 .477 r
.85405 .47362 .85852 .46895 .86974 .43751 .86521 .44025 Mtetra
.982 .861 .484 r
.86521 .44025 .86974 .43751 .87997 .39868 .87532 .39894 Mtetra
.516 .674 .936 r
.25208 .47262 .25923 .4799 .26982 .47947 .26268 .47233 Mtetra
.516 .68 .94 r
.26268 .47233 .26982 .47947 .28048 .479 .27335 .47199 Mtetra
.541 .695 .939 r
.27335 .47199 .28048 .479 .29124 .47816 .28412 .47116 Mtetra
.587 .712 .93 r
.28412 .47116 .29124 .47816 .3021 .47658 .29502 .46939 Mtetra
.638 .724 .91 r
.29502 .46939 .3021 .47658 .31309 .47401 .30605 .46639 Mtetra
.679 .724 .884 r
.30605 .46639 .31309 .47401 .3242 .47033 .31722 .4621 Mtetra
.705 .717 .858 r
.31722 .4621 .3242 .47033 .33541 .46557 .3285 .45666 Mtetra
.718 .705 .838 r
.3285 .45666 .33541 .46557 .34671 .45994 .33986 .45042 Mtetra
.721 .694 .824 r
.33986 .45042 .34671 .45994 .35808 .45371 .35128 .44376 Mtetra
.719 .686 .818 r
.35128 .44376 .35808 .45371 .36949 .44716 .36272 .43704 Mtetra
.714 .682 .818 r
.36272 .43704 .36949 .44716 .38093 .44055 .37418 .43052 Mtetra
.708 .683 .823 r
.37418 .43052 .38093 .44055 .39239 .43409 .38565 .42435 Mtetra
.702 .687 .832 r
.38565 .42435 .39239 .43409 .40387 .4279 .39714 .41857 Mtetra
.696 .694 .844 r
.39714 .41857 .40387 .4279 .41537 .42208 .40865 .41321 Mtetra
.687 .702 .858 r
.40865 .41321 .41537 .42208 .42689 .4167 .42018 .4083 Mtetra
.673 .709 .875 r
.42018 .4083 .42689 .4167 .43843 .41193 .43174 .40402 Mtetra
.641 .712 .899 r
.43174 .40402 .43843 .41193 .45 .40809 .44331 .4008 Mtetra
.557 .7 .935 r
.44331 .4008 .45 .40809 .46158 .40586 .4549 .39958 Mtetra
.296 .609 .954 r
.4549 .39958 .46158 .40586 .47317 .40633 .46649 .40186 Mtetra
0 .164 .592 r
.46649 .40186 .47317 .40633 .4848 .41089 .4781 .40957 Mtetra
.783 .284 .004 r
.4781 .40957 .4848 .41089 .4965 .42063 .48977 .42424 Mtetra
.83 .413 .251 r
.48977 .42424 .4965 .42063 .50832 .43542 .50158 .4458 Mtetra
.805 .432 .35 r
.50158 .4458 .50832 .43542 .52033 .45297 .51361 .47119 Mtetra
.748 .399 .392 r
.51361 .47119 .52033 .45297 .53255 .46865 .52592 .49416 Mtetra
.65 .321 .402 r
.52592 .49416 .53255 .46865 .54492 .47693 .53845 .50702 Mtetra
.484 .18 .374 r
.53845 .50702 .54492 .47693 .55732 .47378 .55103 .50418 Mtetra
.213 0 .284 r
.55103 .50418 .55732 .47378 .56963 .45891 .5635 .4852 Mtetra
0 0 .101 r
.5635 .4852 .56963 .45891 .58177 .43588 .57573 .45509 Mtetra
0 0 0 r
.57573 .45509 .58177 .43588 .59376 .41018 .58775 .42147 Mtetra
.834 .864 .416 r
.58775 .42147 .59376 .41018 .6057 .38667 .59967 .39094 Mtetra
.946 .948 .633 r
.59967 .39094 .6057 .38667 .61768 .36796 .61162 .36703 Mtetra
.929 .939 .784 r
.61162 .36703 .61768 .36796 .62977 .35444 .62369 .35016 Mtetra
.846 .878 .864 r
.62369 .35016 .62977 .35444 .642 .34508 .63591 .33891 Mtetra
.76 .814 .896 r
.63591 .33891 .642 .34508 .65435 .33851 .64828 .33138 Mtetra
.698 .77 .908 r
.64828 .33138 .65435 .33851 .66682 .33365 .66077 .32605 Mtetra
.652 .742 .915 r
.66077 .32605 .66682 .33365 .6794 .33001 .67338 .32217 Mtetra
.602 .715 .924 r
.67338 .32217 .6794 .33001 .69212 .32776 .68612 .31975 Mtetra
.513 .67 .934 r
.68612 .31975 .69212 .32776 .70503 .3277 .69906 .3195 Mtetra
.333 .567 .924 r
.69906 .3195 .70503 .3277 .71826 .33124 .7123 .32279 Mtetra
.015 .352 .828 r
.7123 .32279 .71826 .33124 .73196 .34021 .726 .33139 Mtetra
0 .056 .605 r
.726 .33139 .73196 .34021 .74633 .35631 .74034 .34701 Mtetra
0 0 .386 r
.74034 .34701 .74633 .35631 .76152 .38033 .75548 .37039 Mtetra
.689 .277 0 r
.75548 .37039 .76152 .38033 .77754 .41104 .77141 .40034 Mtetra
.692 .29 0 r
.77141 .40034 .77754 .41104 .79413 .44441 .78792 .4329 Mtetra
0 0 .385 r
.78792 .4329 .79413 .44441 .81077 .4738 .80448 .46159 Mtetra
0 .141 .687 r
.80448 .46159 .81077 .4738 .82672 .4916 .82038 .47893 Mtetra
.53 .587 .856 r
.82038 .47893 .82672 .4916 .84126 .49199 .83494 .47925 Mtetra
.835 .724 .743 r
.83494 .47925 .84126 .49199 .85405 .47362 .84781 .46121 Mtetra
.918 .745 .652 r
.84781 .46121 .85405 .47362 .86521 .44025 .85912 .42846 Mtetra
.944 .75 .61 r
.85912 .42846 .86521 .44025 .87532 .39894 .8694 .38793 Mtetra
.345 .692 .982 r
.24467 .46789 .25208 .47262 .26268 .47233 .25521 .46858 Mtetra
.287 .698 .973 r
.25521 .46858 .26268 .47233 .27335 .47199 .26583 .46919 Mtetra
.303 .738 .968 r
.26583 .46919 .27335 .47199 .28412 .47116 .27657 .46905 Mtetra
.409 .814 .98 r
.27657 .46905 .28412 .47116 .29502 .46939 .28749 .46753 Mtetra
.563 .884 .99 r
.28749 .46753 .29502 .46939 .30605 .46639 .29859 .46421 Mtetra
.69 .905 .972 r
.29859 .46421 .30605 .46639 .31722 .4621 .30986 .45906 Mtetra
.757 .882 .935 r
.30986 .45906 .31722 .4621 .3285 .45666 .32126 .45242 Mtetra
.778 .841 .9 r
.32126 .45242 .3285 .45666 .33986 .45042 .33274 .44485 Mtetra
.775 .801 .874 r
.33274 .44485 .33986 .45042 .35128 .44376 .34425 .437 Mtetra
.761 .768 .859 r
.34425 .437 .35128 .44376 .36272 .43704 .35578 .42938 Mtetra
.743 .743 .852 r
.35578 .42938 .36272 .43704 .37418 .43052 .3673 .42232 Mtetra
.725 .727 .852 r
.3673 .42232 .37418 .43052 .38565 .42435 .37881 .41592 Mtetra
.71 .719 .856 r
.37881 .41592 .38565 .42435 .39714 .41857 .39033 .41016 Mtetra
.697 .716 .864 r
.39033 .41016 .39714 .41857 .40865 .41321 .40186 .40496 Mtetra
.684 .717 .874 r
.40186 .40496 .40865 .41321 .42018 .4083 .41341 .4003 Mtetra
.665 .718 .889 r
.41341 .4003 .42018 .4083 .43174 .40402 .42499 .39632 Mtetra
.624 .714 .91 r
.42499 .39632 .43174 .40402 .44331 .4008 .43658 .39354 Mtetra
.517 .686 .943 r
.43658 .39354 .44331 .4008 .4549 .39958 .44817 .39307 Mtetra
.179 .534 .924 r
.44817 .39307 .4549 .39958 .46649 .40186 .45975 .39676 Mtetra
.523 0 0 r
.45975 .39676 .46649 .40186 .4781 .40957 .47134 .40692 Mtetra
.829 .355 .042 r
.47134 .40692 .4781 .40957 .48977 .42424 .48297 .42547 Mtetra
.871 .462 .248 r
.48297 .42547 .48977 .42424 .50158 .4458 .49474 .45239 Mtetra
.854 .477 .334 r
.49474 .45239 .50158 .4458 .51361 .47119 .50677 .48404 Mtetra
.805 .443 .37 r
.50677 .48404 .51361 .47119 .52592 .49416 .51912 .51287 Mtetra
.701 .347 .372 r
.51912 .51287 .52592 .49416 .53845 .50702 .53176 .52946 Mtetra
.461 .127 .313 r
.53176 .52946 .53845 .50702 .55103 .50418 .54449 .52686 Mtetra
0 0 .106 r
.54449 .52686 .55103 .50418 .5635 .4852 .55711 .50454 Mtetra
0 0 0 r
.55711 .50454 .5635 .4852 .57573 .45509 .56946 .46872 Mtetra
.896 .858 .409 r
.56946 .46872 .57573 .45509 .58775 .42147 .58155 .42874 Mtetra
.975 .896 .54 r
.58155 .42874 .58775 .42147 .59967 .39094 .59349 .39264 Mtetra
.982 .904 .652 r
.59349 .39264 .59967 .39094 .61162 .36703 .60545 .36462 Mtetra
.939 .89 .755 r
.60545 .36462 .61162 .36703 .62369 .35016 .61753 .34513 Mtetra
.86 .854 .835 r
.61753 .34513 .62369 .35016 .63591 .33891 .62976 .3324 Mtetra
.773 .809 .881 r
.62976 .3324 .63591 .33891 .64828 .33138 .64215 .32413 Mtetra
.707 .771 .903 r
.64215 .32413 .64828 .33138 .66077 .32605 .65467 .31844 Mtetra
.659 .746 .914 r
.65467 .31844 .66077 .32605 .67338 .32217 .66731 .31433 Mtetra
.61 .721 .924 r
.66731 .31433 .67338 .32217 .68612 .31975 .68008 .31164 Mtetra
.532 .678 .932 r
.68008 .31164 .68612 .31975 .69906 .3195 .69302 .31095 Mtetra
.386 .589 .924 r
.69302 .31095 .69906 .3195 .7123 .32279 .70624 .31344 Mtetra
.145 .417 .86 r
.70624 .31344 .7123 .32279 .726 .33139 .71987 .32071 Mtetra
0 .19 .722 r
.71987 .32071 .726 .33139 .74034 .34701 .73408 .33425 Mtetra
0 .012 .586 r
.73408 .33425 .74034 .34701 .75548 .37039 .74899 .35473 Mtetra
0 0 .529 r
.74899 .35473 .75548 .37039 .77141 .40034 .7646 .38103 Mtetra
0 0 .559 r
.7646 .38103 .77141 .40034 .78792 .4329 .78073 .4096 Mtetra
.011 .126 .639 r
.78073 .4096 .78792 .4329 .80448 .46159 .79692 .43463 Mtetra
.317 .311 .694 r
.79692 .43463 .80448 .46159 .82038 .47893 .81254 .44952 Mtetra
.56 .456 .693 r
.81254 .44952 .82038 .47893 .83494 .47925 .82699 .44926 Mtetra
.709 .546 .665 r
.82699 .44926 .83494 .47925 .84781 .46121 .83998 .43267 Mtetra
.793 .599 .639 r
.83998 .43267 .84781 .46121 .85912 .42846 .8516 .40298 Mtetra
.84 .634 .624 r
.8516 .40298 .85912 .42846 .8694 .38793 .86232 .36628 Mtetra
.18 0 0 r
.23693 .46599 .24467 .46789 .25521 .46858 .24733 .46863 Mtetra
.324 0 0 r
.24733 .46863 .25521 .46858 .26583 .46919 .25784 .47116 Mtetra
.321 0 0 r
.25784 .47116 .26583 .46919 .27657 .46905 .26851 .47252 Mtetra
.197 0 0 r
.26851 .47252 .27657 .46905 .28749 .46753 .27943 .47171 Mtetra
0 0 0 r
.27943 .47171 .28749 .46753 .29859 .46421 .29061 .46815 Mtetra
.396 .828 .675 r
.29061 .46815 .29859 .46421 .30986 .45906 .30203 .4618 Mtetra
.686 .979 .834 r
.30203 .4618 .30986 .45906 .32126 .45242 .31361 .45327 Mtetra
.815 .983 .888 r
.31361 .45327 .32126 .45242 .33274 .44485 .32529 .44351 Mtetra
.838 .928 .89 r
.32529 .44351 .33274 .44485 .34425 .437 .33698 .43355 Mtetra
.819 .867 .882 r
.33698 .43355 .34425 .437 .35578 .42938 .34865 .42419 Mtetra
.786 .816 .876 r
.34865 .42419 .35578 .42938 .3673 .42232 .36028 .41588 Mtetra
.754 .779 .874 r
.36028 .41588 .3673 .42232 .37881 .41592 .37186 .40871 Mtetra
.726 .755 .875 r
.37186 .40871 .37881 .41592 .39033 .41016 .38343 .40256 Mtetra
.703 .74 .88 r
.38343 .40256 .39033 .41016 .40186 .40496 .395 .39724 Mtetra
.684 .732 .887 r
.395 .39724 .40186 .40496 .41341 .4003 .40658 .3926 Mtetra
.661 .727 .898 r
.40658 .3926 .41341 .4003 .42499 .39632 .41818 .38873 Mtetra
.615 .716 .917 r
.41818 .38873 .42499 .39632 .43658 .39354 .42979 .38614 Mtetra
.498 .675 .944 r
.42979 .38614 .43658 .39354 .44817 .39307 .4414 .38601 Mtetra
.155 .501 .909 r
.4414 .38601 .44817 .39307 .45975 .39676 .45298 .3903 Mtetra
.499 0 0 r
.45298 .3903 .45975 .39676 .47134 .40692 .46455 .4015 Mtetra
.826 .358 0 r
.46455 .4015 .47134 .40692 .48297 .42547 .47615 .42171 Mtetra
.897 .479 .166 r
.47615 .42171 .48297 .42547 .49474 .45239 .48788 .45092 Mtetra
.905 .508 .244 r
.48788 .45092 .49474 .45239 .50677 .48404 .49987 .48528 Mtetra
.883 .482 .259 r
.49987 .48528 .50677 .48404 .51912 .51287 .51221 .51664 Mtetra
.796 .353 .194 r
.51221 .51664 .51912 .51287 .53176 .52946 .52489 .53483 Mtetra
.177 0 0 r
.52489 .53483 .53176 .52946 .54449 .52686 .53771 .53232 Mtetra
.928 .956 .636 r
.53771 .53232 .54449 .52686 .55711 .50454 .55044 .50854 Mtetra
.993 .873 .594 r
.55044 .50854 .55711 .50454 .56946 .46872 .5629 .47021 Mtetra
.991 .837 .592 r
.5629 .47021 .56946 .46872 .58155 .42874 .57509 .42748 Mtetra
.979 .825 .62 r
.57509 .42748 .58155 .42874 .59349 .39264 .58712 .38897 Mtetra
.957 .825 .671 r
.58712 .38897 .59349 .39264 .60545 .36462 .59914 .35918 Mtetra
.916 .824 .741 r
.59914 .35918 .60545 .36462 .61753 .34513 .61126 .33857 Mtetra
.851 .814 .813 r
.61126 .33857 .61753 .34513 .62976 .3324 .62354 .32523 Mtetra
.774 .791 .867 r
.62354 .32523 .62976 .3324 .64215 .32413 .63597 .31664 Mtetra
.709 .767 .897 r
.63597 .31664 .64215 .32413 .65467 .31844 .64852 .31079 Mtetra
.663 .748 .913 r
.64852 .31079 .65467 .31844 .66731 .31433 .6612 .30652 Mtetra
.619 .727 .924 r
.6612 .30652 .66731 .31433 .68008 .31164 .67399 .30353 Mtetra
.555 .691 .93 r
.67399 .30353 .68008 .31164 .69302 .31095 .68693 .30223 Mtetra
.446 .619 .924 r
.68693 .30223 .69302 .31095 .70624 .31344 .70011 .30355 Mtetra
.28 .49 .884 r
.70011 .30355 .70624 .31344 .71987 .32071 .71364 .30879 Mtetra
.099 .325 .799 r
.71364 .30879 .71987 .32071 .73408 .33425 .72763 .31917 Mtetra
0 .194 .71 r
.72763 .31917 .73408 .33425 .74899 .35473 .74221 .33517 Mtetra
0 .146 .663 r
.74221 .33517 .74899 .35473 .7646 .38103 .75736 .35586 Mtetra
.111 .179 .655 r
.75736 .35586 .7646 .38103 .78073 .4096 .77293 .37829 Mtetra
.274 .259 .66 r
.77293 .37829 .78073 .4096 .79692 .43463 .78856 .39772 Mtetra
.436 .349 .659 r
.78856 .39772 .79692 .43463 .81254 .44952 .80374 .40884 Mtetra
.565 .425 .65 r
.80374 .40884 .81254 .44952 .82699 .44926 .81802 .40766 Mtetra
.659 .484 .637 r
.81802 .40766 .82699 .44926 .83998 .43267 .83113 .39324 Mtetra
.724 .53 .628 r
.83113 .39324 .83998 .43267 .8516 .40298 .84316 .36817 Mtetra
.769 .566 .625 r
.84316 .36817 .8516 .40298 .86232 .36628 .85448 .33734 Mtetra
.59 .044 0 r
.22885 .46694 .23693 .46599 .24733 .46863 .23903 .47255 Mtetra
.606 .115 .061 r
.23903 .47255 .24733 .46863 .25784 .47116 .24934 .47799 Mtetra
.555 .097 .12 r
.24934 .47799 .25784 .47116 .26851 .47252 .25988 .48168 Mtetra
.449 .008 .107 r
.25988 .48168 .26851 .47252 .27943 .47171 .27078 .4821 Mtetra
.267 0 .018 r
.27078 .4821 .27943 .47171 .29061 .46815 .28206 .47833 Mtetra
0 0 0 r
.28206 .47833 .29061 .46815 .30203 .4618 .29368 .47038 Mtetra
.29368 .47038 .30203 .4618 .31361 .45327 .30553 .45921 Mtetra
.737 .966 .693 r
.30553 .45921 .31361 .45327 .32529 .44351 .31749 .44631 Mtetra
.864 .994 .815 r
.31749 .44631 .32529 .44351 .33698 .43355 .32945 .43328 Mtetra
.873 .945 .859 r
.32945 .43328 .33698 .43355 .34865 .42419 .34133 .4213 Mtetra
.837 .883 .875 r
.34133 .4213 .34865 .42419 .36028 .41588 .35311 .41103 Mtetra
.792 .829 .881 r
.35311 .41103 .36028 .41588 .37186 .40871 .3648 .40255 Mtetra
.75 .79 .885 r
.3648 .40255 .37186 .40871 .38343 .40256 .37644 .39564 Mtetra
.716 .763 .889 r
.37644 .39564 .38343 .40256 .395 .39724 .38806 .38992 Mtetra
.69 .747 .895 r
.38806 .38992 .395 .39724 .40658 .3926 .39968 .38511 Mtetra
.662 .735 .904 r
.39968 .38511 .40658 .3926 .41818 .38873 .41131 .38118 Mtetra
.617 .719 .919 r
.41131 .38118 .41818 .38873 .42979 .38614 .42295 .37852 Mtetra
.509 .675 .939 r
.42295 .37852 .42979 .38614 .4414 .38601 .43459 .37822 Mtetra
.226 .522 .916 r
.43459 .37822 .4414 .38601 .45298 .3903 .44619 .38214 Mtetra
0 .122 .647 r
.44619 .38214 .45298 .3903 .46455 .4015 .45777 .39265 Mtetra
.714 .261 0 r
.45777 .39265 .46455 .4015 .47615 .42171 .46937 .41175 Mtetra
.84 .423 0 r
.46937 .41175 .47615 .42171 .48788 .45092 .48107 .4394 Mtetra
.858 .46 0 r
.48107 .4394 .48788 .45092 .49987 .48528 .49302 .47192 Mtetra
.766 .379 0 r
.49302 .47192 .49987 .48528 .51221 .51664 .50531 .50155 Mtetra
0 .059 .624 r
.50531 .50155 .51221 .51664 .52489 .53483 .51795 .51863 Mtetra
.606 .567 .785 r
.51795 .51863 .52489 .53483 .53771 .53232 .53077 .51601 Mtetra
.822 .668 .692 r
.53077 .51601 .53771 .53232 .55044 .50854 .54355 .49316 Mtetra
.881 .693 .645 r
.54355 .49316 .55044 .50854 .5629 .47021 .55611 .45646 Mtetra
.902 .708 .631 r
.55611 .45646 .5629 .47021 .57509 .42748 .56842 .41554 Mtetra
.907 .723 .642 r
.56842 .41554 .57509 .42748 .58712 .38897 .58057 .37862 Mtetra
.898 .74 .677 r
.58057 .37862 .58712 .38897 .59914 .35918 .59269 .35001 Mtetra
.873 .758 .733 r
.59269 .35001 .59914 .35918 .61126 .33857 .6049 .33016 Mtetra
.825 .77 .8 r
.6049 .33016 .61126 .33857 .62354 .32523 .61724 .31726 Mtetra
.762 .769 .859 r
.61724 .31726 .62354 .32523 .63597 .31664 .62972 .3089 Mtetra
.705 .761 .895 r
.62972 .3089 .63597 .31664 .64852 .31079 .64233 .30314 Mtetra
.663 .75 .915 r
.64233 .30314 .64852 .31079 .6612 .30652 .65504 .29883 Mtetra
.626 .736 .926 r
.65504 .29883 .6612 .30652 .67399 .30353 .66786 .29559 Mtetra
.578 .708 .932 r
.66786 .29559 .67399 .30353 .68693 .30223 .68081 .29365 Mtetra
.501 .654 .928 r
.68081 .29365 .68693 .30223 .70011 .30355 .69395 .29369 Mtetra
.39 .559 .9 r
.69395 .29369 .70011 .30355 .71364 .30879 .70736 .29666 Mtetra
.275 .436 .841 r
.70736 .29666 .71364 .30879 .72763 .31917 .72113 .30345 Mtetra
.208 .332 .771 r
.72113 .30345 .72763 .31917 .74221 .33517 .73534 .3144 Mtetra
.22 .284 .717 r
.73534 .3144 .74221 .33517 .75736 .35586 .74999 .32876 Mtetra
.293 .29 .684 r
.74999 .32876 .75736 .35586 .77293 .37829 .76496 .34429 Mtetra
.392 .327 .664 r
.76496 .34429 .77293 .37829 .78856 .39772 .77998 .35746 Mtetra
.488 .374 .65 r
.77998 .35746 .78856 .39772 .80374 .40884 .79469 .36437 Mtetra
.57 .42 .638 r
.79469 .36437 .80374 .40884 .81802 .40766 .80875 .36212 Mtetra
.636 .462 .63 r
.80875 .36212 .81802 .40766 .83113 .39324 .82198 .35005 Mtetra
.686 .498 .627 r
.82198 .35005 .83113 .39324 .84316 .36817 .83444 .33005 Mtetra
.725 .531 .629 r
.83444 .33005 .84316 .36817 .85448 .33734 .84638 .30571 Mtetra
.714 .255 .16 r
.22046 .47022 .22885 .46694 .23903 .47255 .23033 .47965 Mtetra
.689 .271 .247 r
.23033 .47965 .23903 .47255 .24934 .47799 .24036 .4889 Mtetra
.628 .232 .274 r
.24036 .4889 .24934 .47799 .25988 .48168 .25072 .49565 Mtetra
.527 .142 .255 r
.25072 .49565 .25988 .48168 .27078 .4821 .26157 .49771 Mtetra
.359 0 .181 r
.26157 .49771 .27078 .4821 .28206 .47833 .27296 .49376 Mtetra
.085 0 .024 r
.27296 .49376 .28206 .47833 .29368 .47038 .28484 .48385 Mtetra
0 0 0 r
.28484 .48385 .29368 .47038 .30553 .45921 .29703 .46936 Mtetra
.678 .886 .517 r
.29703 .46936 .30553 .45921 .31749 .44631 .30936 .45251 Mtetra
.869 .984 .704 r
.30936 .45251 .31749 .44631 .32945 .43328 .32166 .43557 Mtetra
.91 .97 .798 r
.32166 .43557 .32945 .43328 .34133 .4213 .33381 .42024 Mtetra
.882 .92 .845 r
.33381 .42024 .34133 .4213 .35311 .41103 .3458 .40742 Mtetra
.831 .864 .87 r
.3458 .40742 .35311 .41103 .3648 .40255 .35764 .39721 Mtetra
.778 .817 .884 r
.35764 .39721 .3648 .40255 .37644 .39564 .36937 .38923 Mtetra
.733 .782 .892 r
.36937 .38923 .37644 .39564 .38806 .38992 .38106 .38291 Mtetra
.699 .759 .899 r
.38106 .38291 .38806 .38992 .39968 .38511 .39272 .37778 Mtetra
.669 .743 .906 r
.39272 .37778 .39968 .38511 .41131 .38118 .40439 .37363 Mtetra
.627 .724 .917 r
.40439 .37363 .41131 .38118 .42295 .37852 .41607 .37067 Mtetra
.54 .683 .931 r
.41607 .37067 .42295 .37852 .43459 .37822 .42774 .36978 Mtetra
.343 .569 .923 r
.42774 .36978 .43459 .37822 .44619 .38214 .43939 .37249 Mtetra
0 .301 .797 r
.43939 .37249 .44619 .38214 .45777 .39265 .45101 .3808 Mtetra
0 0 .552 r
.45101 .3808 .45777 .39265 .46937 .41175 .46264 .39638 Mtetra
0 0 .409 r
.46264 .39638 .46937 .41175 .48107 .4394 .47436 .41916 Mtetra
0 0 .439 r
.47436 .41916 .48107 .4394 .49302 .47192 .48628 .44596 Mtetra
0 .04 .575 r
.48628 .44596 .49302 .47192 .50531 .50155 .49852 .47023 Mtetra
.331 .289 .66 r
.49852 .47023 .50531 .50155 .51795 .51863 .51107 .48388 Mtetra
.583 .448 .662 r
.51107 .48388 .51795 .51863 .53077 .51601 .52382 .48099 Mtetra
.71 .531 .644 r
.52382 .48099 .53077 .51601 .54355 .49316 .53658 .46112 Mtetra
.777 .58 .633 r
.53658 .46112 .54355 .49316 .55611 .45646 .54919 .42957 Mtetra
.813 .614 .633 r
.54919 .42957 .55611 .45646 .56842 .41554 .5616 .39438 Mtetra
.832 .643 .647 r
.5616 .39438 .56842 .41554 .58057 .37862 .57388 .3625 Mtetra
.837 .673 .68 r
.57388 .3625 .58057 .37862 .59269 .35001 .58613 .33761 Mtetra
.825 .705 .732 r
.58613 .33761 .59269 .35001 .6049 .33016 .59844 .32017 Mtetra
.792 .733 .798 r
.59844 .32017 .6049 .33016 .61724 .31726 .61087 .30865 Mtetra
.743 .75 .858 r
.61087 .30865 .61724 .31726 .62972 .3089 .62342 .30103 Mtetra
.694 .755 .899 r
.62342 .30103 .62972 .3089 .64233 .30314 .63608 .29563 Mtetra
.658 .754 .921 r
.63608 .29563 .64233 .30314 .65504 .29883 .64884 .29143 Mtetra
.628 .747 .933 r
.64884 .29143 .65504 .29883 .66786 .29559 .66169 .28806 Mtetra
.593 .73 .939 r
.66169 .28806 .66786 .29559 .68081 .29365 .67466 .28561 Mtetra
.541 .692 .937 r
.67466 .28561 .68081 .29365 .69395 .29369 .68778 .2845 Mtetra
.471 .623 .918 r
.68778 .2845 .69395 .29369 .70736 .29666 .70109 .28537 Mtetra
.398 .531 .874 r
.70109 .28537 .70736 .29666 .72113 .30345 .71467 .2888 Mtetra
.354 .442 .813 r
.71467 .2888 .72113 .30345 .73534 .3144 .72856 .295 Mtetra
.358 .386 .754 r
.72856 .295 .73534 .3144 .74999 .32876 .74276 .30342 Mtetra
.401 .369 .709 r
.74276 .30342 .74999 .32876 .76496 .34429 .75719 .31251 Mtetra
.461 .379 .678 r
.75719 .31251 .76496 .34429 .77998 .35746 .77166 .31985 Mtetra
.523 .403 .657 r
.77166 .31985 .77998 .35746 .79469 .36437 .78595 .32282 Mtetra
.579 .431 .644 r
.78595 .32282 .79469 .36437 .80875 .36212 .79981 .3195 Mtetra
.627 .46 .637 r
.79981 .3195 .80875 .36212 .82198 .35005 .81314 .30948 Mtetra
.666 .489 .636 r
.81314 .30948 .82198 .35005 .83444 .33005 .82597 .29404 Mtetra
.698 .519 .642 r
.82597 .29404 .83444 .33005 .84638 .30571 .83846 .27562 Mtetra
.769 .354 .264 r
.21184 .47461 .22046 .47022 .23033 .47965 .22135 .48833 Mtetra
.735 .348 .319 r
.22135 .48833 .23033 .47965 .24036 .4889 .23105 .50183 Mtetra
.672 .3 .331 r
.23105 .50183 .24036 .4889 .25072 .49565 .24118 .51204 Mtetra
.566 .2 .306 r
.24118 .51204 .25072 .49565 .26157 .49771 .25197 .51599 Mtetra
.381 .022 .225 r
.25197 .51599 .26157 .49771 .27296 .49376 .26348 .51189 Mtetra
.06 0 .05 r
.26348 .51189 .27296 .49376 .28484 .48385 .27565 .49982 Mtetra
0 0 0 r
.27565 .49982 .28484 .48385 .29703 .46936 .28824 .48167 Mtetra
.751 .894 .497 r
.28824 .48167 .29703 .46936 .30936 .45251 .30099 .46043 Mtetra
.909 .968 .657 r
.30099 .46043 .30936 .45251 .32166 .43557 .31368 .43916 Mtetra
.94 .958 .748 r
.31368 .43916 .32166 .43557 .33381 .42024 .32615 .42013 Mtetra
.914 .92 .806 r
.32615 .42013 .33381 .42024 .3458 .40742 .33838 .40448 Mtetra
.862 .875 .846 r
.33838 .40448 .3458 .40742 .35764 .39721 .35038 .39231 Mtetra
.804 .831 .872 r
.35038 .39231 .35764 .39721 .36937 .38923 .36223 .38311 Mtetra
.751 .795 .888 r
.36223 .38311 .36937 .38923 .38106 .38291 .37398 .37609 Mtetra
.71 .769 .898 r
.37398 .37609 .38106 .38291 .39272 .37778 .3857 .37055 Mtetra
.678 .75 .906 r
.3857 .37055 .39272 .37778 .40439 .37363 .39741 .36608 Mtetra
.641 .731 .914 r
.39741 .36608 .40439 .37363 .41607 .37067 .40913 .3627 Mtetra
.578 .697 .923 r
.40913 .3627 .41607 .37067 .42774 .36978 .42085 .36096 Mtetra
.454 .617 .92 r
.42085 .36096 .42774 .36978 .43939 .37249 .43257 .36199 Mtetra
.242 .455 .867 r
.43257 .36199 .43939 .37249 .45101 .3808 .44426 .36727 Mtetra
.026 .247 .749 r
.44426 .36727 .45101 .3808 .46264 .39638 .45596 .37803 Mtetra
0 .125 .655 r
.45596 .37803 .46264 .39638 .47436 .41916 .46773 .39416 Mtetra
.069 .14 .631 r
.46773 .39416 .47436 .41916 .48628 .44596 .47966 .41322 Mtetra
.267 .236 .638 r
.47966 .41322 .48628 .44596 .49852 .47023 .49185 .43028 Mtetra
.448 .34 .639 r
.49185 .43028 .49852 .47023 .51107 .48388 .5043 .43936 Mtetra
.577 .421 .633 r
.5043 .43936 .51107 .48388 .52382 .48099 .51695 .43613 Mtetra
.661 .479 .628 r
.51695 .43613 .52382 .48099 .53658 .46112 .52964 .42026 Mtetra
.716 .523 .627 r
.52964 .42026 .53658 .46112 .54919 .42957 .54226 .39564 Mtetra
.752 .559 .634 r
.54226 .39564 .54919 .42957 .5616 .39438 .55474 .36822 Mtetra
.775 .593 .653 r
.55474 .36822 .5616 .39438 .57388 .3625 .56713 .34322 Mtetra
.786 .63 .688 r
.56713 .34322 .57388 .3625 .58613 .33761 .5795 .32348 Mtetra
.781 .671 .742 r
.5795 .32348 .58613 .33761 .59844 .32017 .59193 .30938 Mtetra
.757 .71 .808 r
.59193 .30938 .59844 .32017 .61087 .30865 .60445 .29982 Mtetra
.718 .739 .868 r
.60445 .29982 .61087 .30865 .62342 .30103 .61707 .29326 Mtetra
.677 .754 .909 r
.61707 .29326 .62342 .30103 .63608 .29563 .6298 .28843 Mtetra
.646 .761 .933 r
.6298 .28843 .63608 .29563 .64884 .29143 .64261 .28453 Mtetra
.622 .763 .947 r
.64261 .28453 .64884 .29143 .66169 .28806 .65551 .28122 Mtetra
.596 .755 .954 r
.65551 .28122 .66169 .28806 .67466 .28561 .66851 .27848 Mtetra
.564 .733 .955 r
.66851 .27848 .67466 .28561 .68778 .2845 .68162 .27655 Mtetra
.522 .688 .943 r
.68162 .27655 .68778 .2845 .70109 .28537 .69488 .27578 Mtetra
.48 .621 .911 r
.69488 .27578 .70109 .28537 .71467 .2888 .70833 .27652 Mtetra
.454 .545 .859 r
.70833 .27652 .71467 .2888 .72856 .295 .72198 .27885 Mtetra
.454 .483 .799 r
.72198 .27885 .72856 .295 .74276 .30342 .73584 .28241 Mtetra
.478 .448 .746 r
.73584 .28241 .74276 .30342 .75719 .31251 .74985 .28621 Mtetra
.515 .437 .707 r
.74985 .28621 .75719 .31251 .77166 .31985 .7639 .28875 Mtetra
.555 .443 .68 r
.7639 .28875 .77166 .31985 .78595 .32282 .77785 .28843 Mtetra
.594 .457 .664 r
.77785 .28843 .78595 .32282 .79981 .3195 .79157 .2841 Mtetra
.629 .477 .656 r
.79157 .2841 .79981 .3195 .81314 .30948 .80497 .27555 Mtetra
.66 .5 .656 r
.80497 .27555 .81314 .30948 .82597 .29404 .81807 .26361 Mtetra
.686 .527 .665 r
.81807 .26361 .82597 .29404 .83846 .27562 .831 .24981 Mtetra
.81 .412 .299 r
.20318 .47828 .21184 .47461 .22135 .48833 .21233 .49603 Mtetra
.777 .398 .339 r
.21233 .49603 .22135 .48833 .23105 .50183 .22168 .51358 Mtetra
.715 .343 .343 r
.22168 .51358 .23105 .50183 .24118 .51204 .23158 .52709 Mtetra
.598 .224 .305 r
.23158 .52709 .24118 .51204 .25197 .51599 .24229 .53286 Mtetra
.357 0 .188 r
.24229 .53286 .25197 .51599 .26348 .51189 .25393 .52865 Mtetra
0 0 0 r
.25393 .52865 .26348 .51189 .27565 .49982 .26638 .51454 Mtetra
.651 .826 .405 r
.26638 .51454 .27565 .49982 .28824 .48167 .27936 .49293 Mtetra
.898 .944 .585 r
.27936 .49293 .28824 .48167 .30099 .46043 .29254 .46756 Mtetra
.961 .944 .669 r
.29254 .46756 .30099 .46043 .31368 .43916 .30562 .44224 Mtetra
.959 .921 .725 r
.30562 .44224 .31368 .43916 .32615 .42013 .31842 .41973 Mtetra
.928 .894 .775 r
.31842 .41973 .32615 .42013 .33838 .40448 .33088 .40143 Mtetra
.88 .864 .82 r
.33088 .40143 .33838 .40448 .35038 .39231 .34305 .38743 Mtetra
.822 .831 .855 r
.34305 .38743 .35038 .39231 .36223 .38311 .35501 .37707 Mtetra
.766 .8 .88 r
.35501 .37707 .36223 .38311 .37398 .37609 .36684 .36935 Mtetra
.721 .775 .895 r
.36684 .36935 .37398 .37609 .3857 .37055 .37861 .3634 Mtetra
.687 .756 .904 r
.37861 .3634 .3857 .37055 .39741 .36608 .39037 .35859 Mtetra
.656 .739 .911 r
.39037 .35859 .39741 .36608 .40913 .3627 .40214 .35475 Mtetra
.612 .712 .916 r
.40214 .35475 .40913 .3627 .42085 .36096 .41392 .35212 Mtetra
.538 .658 .913 r
.41392 .35212 .42085 .36096 .43257 .36199 .4257 .35142 Mtetra
.423 .557 .885 r
.4257 .35142 .43257 .36199 .44426 .36727 .43748 .3536 Mtetra
.306 .425 .819 r
.43748 .3536 .44426 .36727 .45596 .37803 .44927 .35947 Mtetra
.261 .326 .742 r
.44927 .35947 .45596 .37803 .46773 .39416 .46112 .36892 Mtetra
.309 .301 .688 r
.46112 .36892 .46773 .39416 .47966 .41322 .47309 .38028 Mtetra
.404 .329 .658 r
.47309 .38028 .47966 .41322 .49185 .43028 .48526 .39023 Mtetra
.5 .375 .641 r
.48526 .39023 .49185 .43028 .5043 .43936 .49764 .39484 Mtetra
.579 .421 .632 r
.49764 .39484 .5043 .43936 .51695 .43613 .51018 .39127 Mtetra
.637 .462 .629 r
.51018 .39127 .51695 .43613 .52964 .42026 .52279 .37933 Mtetra
.681 .498 .632 r
.52279 .37933 .52964 .42026 .54226 .39564 .53537 .36156 Mtetra
.712 .532 .644 r
.53537 .36156 .54226 .39564 .55474 .36822 .54789 .34189 Mtetra
.734 .568 .667 r
.54789 .34189 .55474 .36822 .56713 .34322 .56037 .32383 Mtetra
.746 .61 .707 r
.56037 .32383 .56713 .34322 .5795 .32348 .57285 .30933 Mtetra
.744 .656 .763 r
.57285 .30933 .5795 .32348 .59193 .30938 .58537 .2987 Mtetra
.724 .702 .829 r
.58537 .2987 .59193 .30938 .60445 .29982 .59798 .29123 Mtetra
.689 .737 .888 r
.59798 .29123 .60445 .29982 .61707 .29326 .61068 .28589 Mtetra
.653 .759 .928 r
.61068 .28589 .61707 .29326 .6298 .28843 .62347 .28179 Mtetra
.623 .773 .952 r
.62347 .28179 .6298 .28843 .64261 .28453 .63635 .27837 Mtetra
.6 .781 .967 r
.63635 .27837 .64261 .28453 .65551 .28122 .64931 .27534 Mtetra
.58 .784 .976 r
.64931 .27534 .65551 .28122 .66851 .27848 .66236 .27264 Mtetra
.56 .778 .98 r
.66236 .27264 .66851 .27848 .68162 .27655 .6755 .27031 Mtetra
.54 .756 .976 r
.6755 .27031 .68162 .27655 .69488 .27578 .68875 .2685 Mtetra
.526 .714 .959 r
.68875 .2685 .69488 .27578 .70833 .27652 .70213 .26736 Mtetra
.521 .656 .92 r
.70213 .26736 .70833 .27652 .72198 .27885 .71564 .2669 Mtetra
.528 .595 .865 r
.71564 .2669 .72198 .27885 .73584 .28241 .72927 .26689 Mtetra
.545 .546 .806 r
.72927 .26689 .73584 .28241 .74985 .28621 .74301 .26676 Mtetra
.568 .517 .758 r
.74301 .26676 .74985 .28621 .7639 .28875 .75678 .26569 Mtetra
.594 .505 .724 r
.75678 .26569 .7639 .28875 .77785 .28843 .7705 .26279 Mtetra
.62 .506 .703 r
.7705 .26279 .77785 .28843 .79157 .2841 .7841 .25749 Mtetra
.644 .517 .693 r
.7841 .25749 .79157 .2841 .80497 .27555 .79754 .24972 Mtetra
.667 .534 .693 r
.79754 .24972 .80497 .27555 .81807 .26361 .81084 .24002 Mtetra
.687 .557 .703 r
.81084 .24002 .81807 .26361 .831 .24981 .82407 .2293 Mtetra
.85 .451 .287 r
.19468 .47909 .20318 .47828 .21233 .49603 .20353 .49983 Mtetra
.825 .438 .319 r
.20353 .49983 .21233 .49603 .22168 .51358 .21262 .52038 Mtetra
.769 .375 .309 r
.21262 .52038 .22168 .51358 .23158 .52709 .22232 .53636 Mtetra
.634 .216 .233 r
.22232 .53636 .23158 .52709 .24229 .53286 .23297 .54351 Mtetra
.224 0 0 r
.23297 .54351 .24229 .53286 .25393 .52865 .2447 .53922 Mtetra
.607 .857 .501 r
.2447 .53922 .25393 .52865 .26638 .51454 .25738 .52362 Mtetra
.93 .959 .648 r
.25738 .52362 .26638 .51454 .27936 .49293 .27069 .49946 Mtetra
.975 .919 .67 r
.27069 .49946 .27936 .49293 .29254 .46756 .28422 .47106 Mtetra
.971 .886 .688 r
.28422 .47106 .29254 .46756 .30562 .44224 .29762 .44277 Mtetra
.952 .866 .716 r
.29762 .44277 .30562 .44224 .31842 .41973 .31069 .41773 Mtetra
.923 .851 .754 r
.31069 .41773 .31842 .41973 .33088 .40143 .32336 .3975 Mtetra
.882 .837 .798 r
.32336 .3975 .33088 .40143 .34305 .38743 .33567 .38216 Mtetra
.83 .82 .839 r
.33567 .38216 .34305 .38743 .35501 .37707 .34773 .37093 Mtetra
.776 .8 .872 r
.34773 .37093 .35501 .37707 .36684 .36935 .35963 .36267 Mtetra
.73 .78 .893 r
.35963 .36267 .36684 .36935 .37861 .3634 .37145 .35635 Mtetra
.696 .764 .904 r
.37145 .35635 .37861 .3634 .39037 .35859 .38326 .35124 Mtetra
.669 .748 .91 r
.38326 .35124 .39037 .35859 .40214 .35475 .39508 .34696 Mtetra
.639 .728 .912 r
.39508 .34696 .40214 .35475 .41392 .35212 .40692 .34355 Mtetra
.596 .691 .909 r
.40692 .34355 .41392 .35212 .4257 .35142 .41877 .34136 Mtetra
.533 .627 .89 r
.41877 .34136 .4257 .35142 .43748 .3536 .43063 .34094 Mtetra
.467 .538 .846 r
.43063 .34094 .43748 .3536 .44927 .35947 .44252 .34276 Mtetra
.43 .455 .784 r
.44252 .34276 .44927 .35947 .46112 .36892 .45446 .34672 Mtetra
.441 .408 .726 r
.45446 .34672 .46112 .36892 .47309 .38028 .4665 .35179 Mtetra
.484 .4 .685 r
.4665 .35179 .47309 .38028 .48526 .39023 .47867 .35601 Mtetra
.536 .414 .661 r
.47867 .35601 .48526 .39023 .49764 .39484 .491 .35702 Mtetra
.586 .439 .648 r
.491 .35702 .49764 .39484 .51018 .39127 .50346 .35319 Mtetra
.627 .466 .645 r
.50346 .35319 .51018 .39127 .52279 .37933 .516 .34441 Mtetra
.661 .496 .65 r
.516 .34441 .52279 .37933 .53537 .36156 .52855 .33219 Mtetra
.687 .529 .666 r
.52855 .33219 .53537 .36156 .54789 .34189 .54109 .31886 Mtetra
.706 .566 .695 r
.54109 .31886 .54789 .34189 .56037 .32383 .55362 .30655 Mtetra
.715 .611 .739 r
.55362 .30655 .56037 .32383 .57285 .30933 .56618 .29647 Mtetra
.71 .66 .798 r
.56618 .29647 .57285 .30933 .58537 .2987 .57879 .28885 Mtetra
.688 .707 .862 r
.57879 .28885 .58537 .2987 .59798 .29123 .59148 .28329 Mtetra
.653 .744 .916 r
.59148 .28329 .59798 .29123 .61068 .28589 .60425 .27916 Mtetra
.615 .768 .953 r
.60425 .27916 .61068 .28589 .62347 .28179 .61711 .27593 Mtetra
.581 .785 .976 r
.61711 .27593 .62347 .28179 .63635 .27837 .63006 .2732 Mtetra
.552 .799 .99 r
.63006 .2732 .63635 .27837 .64931 .27534 .6431 .27074 Mtetra
.527 .809 .998 r
.6431 .27074 .64931 .27534 .66236 .27264 .65622 .26841 Mtetra
.508 .815 1 r
.65622 .26841 .66236 .27264 .6755 .27031 .66942 .26614 Mtetra
.503 .815 1 r
.66942 .26614 .6755 .27031 .68875 .2685 .6827 .26389 Mtetra
.515 .807 .998 r
.6827 .26389 .68875 .2685 .70213 .26736 .69607 .26167 Mtetra
.545 .782 .986 r
.69607 .26167 .70213 .26736 .71564 .2669 .70953 .25942 Mtetra
.58 .738 .951 r
.70953 .25942 .71564 .2669 .72927 .26689 .72305 .257 Mtetra
.609 .684 .896 r
.72305 .257 .72927 .26689 .74301 .26676 .73663 .25413 Mtetra
.629 .637 .84 r
.73663 .25413 .74301 .26676 .75678 .26569 .75023 .25044 Mtetra
.646 .607 .796 r
.75023 .25044 .75678 .26569 .7705 .26279 .76381 .24553 Mtetra
.661 .592 .767 r
.76381 .24553 .7705 .26279 .7841 .25749 .77734 .23921 Mtetra
.676 .59 .752 r
.77734 .23921 .7841 .25749 .79754 .24972 .7908 .23155 Mtetra
.69 .599 .749 r
.7908 .23155 .79754 .24972 .81084 .24002 .80421 .22291 Mtetra
.702 .616 .757 r
.80421 .22291 .81084 .24002 .82407 .2293 .81762 .21385 Mtetra
.886 .474 .219 r
.18655 .47527 .19468 .47909 .20353 .49983 .19525 .49726 Mtetra
.877 .465 .234 r
.19525 .49726 .20353 .49983 .21262 .52038 .20419 .51907 Mtetra
.835 .392 .173 r
.20419 .51907 .21262 .52038 .22232 .53636 .21379 .5361 Mtetra
.643 .097 0 r
.21379 .5361 .22232 .53636 .23297 .54351 .22441 .54384 Mtetra
.49 .898 .917 r
.22441 .54384 .23297 .54351 .2447 .53922 .2362 .53956 Mtetra
.912 .921 .809 r
.2362 .53956 .2447 .53922 .25738 .52362 .24901 .52337 Mtetra
.943 .851 .722 r
.24901 .52337 .25738 .52362 .27069 .49946 .2625 .49821 Mtetra
.942 .819 .694 r
.2625 .49821 .27069 .49946 .28422 .47106 .27623 .46863 Mtetra
.935 .806 .692 r
.27623 .46863 .28422 .47106 .29762 .44277 .28982 .43918 Mtetra
.923 .802 .709 r
.28982 .43918 .29762 .44277 .31069 .41773 .30305 .41317 Mtetra
.902 .804 .741 r
.30305 .41317 .31069 .41773 .32336 .3975 .31584 .39219 Mtetra
.871 .807 .784 r
.31584 .39219 .32336 .3975 .33567 .38216 .32825 .37632 Mtetra
.829 .806 .829 r
.32825 .37632 .33567 .38216 .34773 .37093 .34038 .3647 Mtetra
.781 .799 .868 r
.34038 .3647 .34773 .37093 .35963 .36267 .35234 .35615 Mtetra
.737 .787 .893 r
.35234 .35615 .35963 .36267 .37145 .35635 .36422 .34957 Mtetra
.704 .775 .907 r
.36422 .34957 .37145 .35635 .38326 .35124 .37608 .34416 Mtetra
.681 .762 .912 r
.37608 .34416 .38326 .35124 .39508 .34696 .38795 .33949 Mtetra
.66 .745 .913 r
.38795 .33949 .39508 .34696 .40692 .34355 .39984 .33543 Mtetra
.634 .72 .909 r
.39984 .33543 .40692 .34355 .41877 .34136 .41176 .33211 Mtetra
.6 .678 .895 r
.41176 .33211 .41877 .34136 .43063 .34094 .4237 .3298 Mtetra
.562 .618 .866 r
.4237 .3298 .43063 .34094 .44252 .34276 .43568 .32873 Mtetra
.534 .552 .82 r
.43568 .32873 .44252 .34276 .45446 .34672 .44771 .32882 Mtetra
.527 .5 .769 r
.44771 .32882 .45446 .34672 .4665 .35179 .45981 .32953 Mtetra
.542 .472 .726 r
.45981 .32953 .4665 .35179 .47867 .35601 .47201 .32977 Mtetra
.569 .466 .697 r
.47201 .32977 .47867 .35601 .491 .35702 .48432 .32833 Mtetra
.599 .475 .682 r
.48432 .32833 .491 .35702 .50346 .35319 .49674 .32433 Mtetra
.628 .492 .678 r
.49674 .32433 .50346 .35319 .516 .34441 .50922 .31773 Mtetra
.652 .517 .686 r
.50922 .31773 .516 .34441 .52855 .33219 .52175 .30936 Mtetra
.672 .548 .705 r
.52175 .30936 .52855 .33219 .54109 .31886 .5343 .30049 Mtetra
.685 .586 .739 r
.5343 .30049 .54109 .31886 .55362 .30655 .54688 .29229 Mtetra
.688 .631 .787 r
.54688 .29229 .55362 .30655 .56618 .29647 .5595 .28546 Mtetra
.676 .679 .845 r
.5595 .28546 .56618 .29647 .57879 .28885 .57218 .28017 Mtetra
.647 .722 .903 r
.57218 .28017 .57879 .28885 .59148 .28329 .58494 .27622 Mtetra
.604 .754 .949 r
.58494 .27622 .59148 .28329 .60425 .27916 .59778 .2733 Mtetra
.554 .775 .981 r
.59778 .2733 .60425 .27916 .61711 .27593 .61072 .27108 Mtetra
.501 .789 .997 r
.61072 .27108 .61711 .27593 .63006 .2732 .62375 .26929 Mtetra
.448 .797 .998 r
.62375 .26929 .63006 .2732 .6431 .27074 .63688 .26771 Mtetra
.398 .801 .984 r
.63688 .26771 .6431 .27074 .65622 .26841 .65009 .26612 Mtetra
.363 .802 .96 r
.65009 .26612 .65622 .26841 .66942 .26614 .66338 .26434 Mtetra
.355 .809 .941 r
.66338 .26434 .66942 .26614 .6827 .26389 .67674 .2622 Mtetra
.387 .83 .944 r
.67674 .2622 .6827 .26389 .69607 .26167 .69015 .25955 Mtetra
.461 .861 .968 r
.69015 .25955 .69607 .26167 .70953 .25942 .70361 .2563 Mtetra
.558 .879 .992 r
.70361 .2563 .70953 .25942 .72305 .257 .71711 .25234 Mtetra
.641 .862 .983 r
.71711 .25234 .72305 .257 .73663 .25413 .73062 .24757 Mtetra
.691 .816 .942 r
.73062 .24757 .73663 .25413 .75023 .25044 .74414 .24192 Mtetra
.714 .767 .894 r
.74414 .24192 .75023 .25044 .76381 .24553 .75764 .23532 Mtetra
.724 .731 .856 r
.75764 .23532 .76381 .24553 .77734 .23921 .77112 .22784 Mtetra
.729 .71 .833 r
.77112 .22784 .77734 .23921 .7908 .23155 .78458 .21967 Mtetra
.732 .702 .823 r
.78458 .21967 .7908 .23155 .80421 .22291 .79804 .21111 Mtetra
.732 .705 .824 r
.79804 .21111 .80421 .22291 .81762 .21385 .81154 .20253 Mtetra
.877 .45 .045 r
.1789 .46603 .18655 .47527 .19525 .49726 .18764 .4872 Mtetra
.859 .431 0 r
.18764 .4872 .19525 .49726 .20419 .51907 .19661 .50821 Mtetra
.701 .259 0 r
.19661 .50821 .20419 .51907 .21379 .5361 .20623 .5246 Mtetra
.042 .32 .805 r
.20623 .5246 .21379 .5361 .22441 .54384 .21686 .53202 Mtetra
.652 .645 .831 r
.21686 .53202 .22441 .54384 .2362 .53956 .22865 .52785 Mtetra
.805 .696 .745 r
.22865 .52785 .2362 .53956 .24901 .52337 .24146 .51221 Mtetra
.854 .71 .702 r
.24146 .51221 .24901 .52337 .2625 .49821 .25495 .48792 Mtetra
.874 .719 .686 r
.25495 .48792 .2625 .49821 .27623 .46863 .26868 .45938 Mtetra
.883 .73 .688 r
.26868 .45938 .27623 .46863 .28982 .43918 .28227 .43098 Mtetra
.883 .744 .705 r
.28227 .43098 .28982 .43918 .30305 .41317 .29552 .40587 Mtetra
.874 .763 .736 r
.29552 .40587 .30305 .41317 .31584 .39219 .30834 .38558 Mtetra
.855 .783 .78 r
.30834 .38558 .31584 .39219 .32825 .37632 .32078 .37014 Mtetra
.823 .799 .829 r
.32078 .37014 .32825 .37632 .34038 .3647 .33296 .35871 Mtetra
.783 .807 .872 r
.33296 .35871 .34038 .3647 .35234 .35615 .34497 .35013 Mtetra
.744 .805 .901 r
.34497 .35013 .35234 .35615 .36422 .34957 .3569 .34336 Mtetra
.714 .795 .915 r
.3569 .34336 .36422 .34957 .37608 .34416 .36881 .33763 Mtetra
.694 .783 .919 r
.36881 .33763 .37608 .34416 .38795 .33949 .38073 .33253 Mtetra
.678 .767 .918 r
.38073 .33253 .38795 .33949 .39984 .33543 .39268 .32789 Mtetra
.662 .747 .913 r
.39268 .32789 .39984 .33543 .41176 .33211 .40466 .32372 Mtetra
.642 .718 .903 r
.40466 .32372 .41176 .33211 .4237 .3298 .41668 .32013 Mtetra
.62 .678 .883 r
.41668 .32013 .4237 .3298 .43568 .32873 .42873 .31721 Mtetra
.6 .63 .853 r
.42873 .31721 .43568 .32873 .44771 .32882 .44083 .31491 Mtetra
.589 .585 .815 r
.44083 .31491 .44771 .32882 .45981 .32953 .45299 .31295 Mtetra
.591 .551 .778 r
.45299 .31295 .45981 .32953 .47201 .32977 .46523 .3108 Mtetra
.602 .534 .75 r
.46523 .3108 .47201 .32977 .48432 .32833 .47755 .30788 Mtetra
.618 .531 .734 r
.47755 .30788 .48432 .32833 .49674 .32433 .48995 .30379 Mtetra
.635 .541 .731 r
.48995 .30379 .49674 .32433 .50922 .31773 .50242 .29853 Mtetra
.651 .56 .74 r
.50242 .29853 .50922 .31773 .52175 .30936 .51494 .29252 Mtetra
.662 .589 .762 r
.51494 .29252 .52175 .30936 .5343 .30049 .52751 .28643 Mtetra
.666 .624 .798 r
.52751 .28643 .5343 .30049 .54688 .29229 .54012 .28087 Mtetra
.659 .665 .844 r
.54012 .28087 .54688 .29229 .5595 .28546 .55279 .27623 Mtetra
.635 .704 .896 r
.55279 .27623 .5595 .28546 .57218 .28017 .56553 .27266 Mtetra
.591 .736 .944 r
.56553 .27266 .57218 .28017 .58494 .27622 .57835 .27011 Mtetra
.529 .757 .98 r
.57835 .27011 .58494 .27622 .59778 .2733 .59127 .26842 Mtetra
.449 .764 .996 r
.59127 .26842 .59778 .2733 .61072 .27108 .60429 .2674 Mtetra
.353 .755 .983 r
.60429 .2674 .61072 .27108 .62375 .26929 .61742 .26685 Mtetra
.247 .728 .933 r
.61742 .26685 .62375 .26929 .63688 .26771 .63064 .26649 Mtetra
.152 .686 .849 r
.63064 .26649 .63688 .26771 .65009 .26612 .64397 .26604 Mtetra
.088 .647 .757 r
.64397 .26604 .65009 .26612 .66338 .26434 .65737 .26517 Mtetra
0 0 0 r
.65737 .26517 .66338 .26434 .67674 .2622 .67084 .26358 Mtetra
.67084 .26358 .67674 .2622 .69015 .25955 .68434 .26102 Mtetra
.199 .72 .696 r
.68434 .26102 .69015 .25955 .70361 .2563 .69787 .2573 Mtetra
.343 .819 .776 r
.69787 .2573 .70361 .2563 .71711 .25234 .71139 .25234 Mtetra
.515 .915 .872 r
.71139 .25234 .71711 .25234 .73062 .24757 .7249 .24617 Mtetra
.661 .961 .934 r
.7249 .24617 .73062 .24757 .74414 .24192 .73838 .23888 Mtetra
.747 .947 .945 r
.73838 .23888 .74414 .24192 .75764 .23532 .75184 .23067 Mtetra
.781 .906 .928 r
.75184 .23067 .75764 .23532 .77112 .22784 .76528 .22179 Mtetra
.788 .864 .906 r
.76528 .22179 .77112 .22784 .78458 .21967 .77872 .21255 Mtetra
.782 .833 .891 r
.77872 .21255 .78458 .21967 .79804 .21111 .79219 .20329 Mtetra
.772 .812 .885 r
.79219 .20329 .79804 .21111 .81154 .20253 .80571 .1943 Mtetra
.663 .283 0 r
.17173 .45185 .1789 .46603 .18764 .4872 .18068 .47034 Mtetra
0 0 .415 r
.18068 .47034 .18764 .4872 .19661 .50821 .18985 .48868 Mtetra
0 .096 .632 r
.18985 .48868 .19661 .50821 .20623 .5246 .19961 .50291 Mtetra
.375 .37 .726 r
.19961 .50291 .20623 .5246 .21686 .53202 .2103 .50923 Mtetra
.611 .511 .716 r
.2103 .50923 .21686 .53202 .22865 .52785 .22204 .50531 Mtetra
.722 .578 .692 r
.22204 .50531 .22865 .52785 .24146 .51221 .23471 .49129 Mtetra
.779 .617 .679 r
.23471 .49129 .24146 .51221 .25495 .48792 .24801 .46966 Mtetra
.812 .646 .676 r
.24801 .46966 .25495 .48792 .26868 .45938 .26154 .4443 Mtetra
.832 .672 .685 r
.26154 .4443 .26868 .45938 .28227 .43098 .27496 .41905 Mtetra
.844 .702 .706 r
.27496 .41905 .28227 .43098 .29552 .40587 .28806 .39667 Mtetra
.847 .736 .741 r
.28806 .39667 .29552 .40587 .30834 .38558 .3008 .37845 Mtetra
.839 .776 .79 r
.3008 .37845 .30834 .38558 .32078 .37014 .31322 .36438 Mtetra
.818 .812 .845 r
.31322 .36438 .32078 .37014 .33296 .35871 .3254 .35366 Mtetra
.785 .836 .891 r
.3254 .35366 .33296 .35871 .34497 .35013 .33745 .34525 Mtetra
.753 .842 .919 r
.33745 .34525 .34497 .35013 .3569 .34336 .34944 .33827 Mtetra
.729 .834 .93 r
.34944 .33827 .3569 .34336 .36881 .33763 .36142 .33209 Mtetra
.713 .819 .931 r
.36142 .33209 .36881 .33763 .38073 .33253 .37341 .32641 Mtetra
.7 .799 .927 r
.37341 .32641 .38073 .33253 .39268 .32789 .38543 .3211 Mtetra
.686 .777 .92 r
.38543 .3211 .39268 .32789 .40466 .32372 .39748 .31617 Mtetra
.671 .752 .911 r
.39748 .31617 .40466 .32372 .41668 .32013 .40956 .31167 Mtetra
.656 .723 .898 r
.40956 .31167 .41668 .32013 .42873 .31721 .42167 .3076 Mtetra
.641 .69 .88 r
.42167 .3076 .42873 .31721 .44083 .31491 .43384 .30392 Mtetra
.632 .657 .857 r
.43384 .30392 .44083 .31491 .45299 .31295 .44605 .30048 Mtetra
.628 .628 .832 r
.44605 .30048 .45299 .31295 .46523 .3108 .45833 .29704 Mtetra
.63 .609 .811 r
.45833 .29704 .46523 .3108 .47755 .30788 .47067 .29334 Mtetra
.636 .602 .798 r
.47067 .29334 .47755 .30788 .48995 .30379 .48309 .28921 Mtetra
.644 .606 .796 r
.48309 .28921 .48995 .30379 .50242 .29853 .49556 .28469 Mtetra
.65 .62 .806 r
.49556 .28469 .50242 .29853 .51494 .29252 .50809 .28002 Mtetra
.651 .642 .828 r
.50809 .28002 .51494 .29252 .52751 .28643 .52068 .27553 Mtetra
.643 .669 .86 r
.52068 .27553 .52751 .28643 .54012 .28087 .53332 .27157 Mtetra
.621 .697 .899 r
.53332 .27157 .54012 .28087 .55279 .27623 .54604 .26841 Mtetra
.579 .722 .941 r
.54604 .26841 .55279 .27623 .56553 .27266 .55883 .26618 Mtetra
.512 .737 .976 r
.55883 .26618 .56553 .27266 .57835 .27011 .57172 .26491 Mtetra
.413 .735 .992 r
.57172 .26491 .57835 .27011 .59127 .26842 .58471 .26457 Mtetra
.276 .705 .967 r
.58471 .26457 .59127 .26842 .60429 .2674 .59782 .26501 Mtetra
.111 .636 .878 r
.59782 .26501 .60429 .2674 .61742 .26685 .61105 .26601 Mtetra
0 .537 .729 r
.61105 .26601 .61742 .26685 .63064 .26649 .62439 .26726 Mtetra
.154 0 0 r
.62439 .26726 .63064 .26649 .64397 .26604 .63785 .26833 Mtetra
.203 0 0 r
.63785 .26833 .64397 .26604 .65737 .26517 .65139 .26878 Mtetra
.2 0 0 r
.65139 .26878 .65737 .26517 .67084 .26358 .66499 .26813 Mtetra
.153 0 0 r
.66499 .26813 .67084 .26358 .68434 .26102 .67861 .26602 Mtetra
.065 0 0 r
.67861 .26602 .68434 .26102 .69787 .2573 .69224 .26217 Mtetra
0 0 0 r
.69224 .26217 .69787 .2573 .71139 .25234 .70583 .2565 Mtetra
.70583 .2565 .71139 .25234 .7249 .24617 .71937 .24911 Mtetra
.446 .846 .653 r
.71937 .24911 .7249 .24617 .73838 .23888 .73285 .24026 Mtetra
.631 .955 .78 r
.73285 .24026 .73838 .23888 .75184 .23067 .74629 .23031 Mtetra
.751 .994 .861 r
.74629 .23031 .75184 .23067 .76528 .22179 .75969 .21972 Mtetra
.806 .981 .896 r
.75969 .21972 .76528 .22179 .77872 .21255 .7731 .20892 Mtetra
.818 .946 .907 r
.7731 .20892 .77872 .21255 .79219 .20329 .78653 .19834 Mtetra
.808 .908 .909 r
.78653 .19834 .79219 .20329 .80571 .1943 .80003 .18829 Mtetra
0 .012 .583 r
.1649 .43426 .17173 .45185 .18068 .47034 .1742 .44885 Mtetra
0 .106 .627 r
.1742 .44885 .18068 .47034 .18985 .48868 .18369 .46331 Mtetra
.247 .254 .67 r
.18369 .46331 .18985 .48868 .19961 .50291 .19368 .47444 Mtetra
.456 .378 .68 r
.19368 .47444 .19961 .50291 .2103 .50923 .20445 .47919 Mtetra
.59 .463 .675 r
.20445 .47919 .2103 .50923 .22204 .50531 .2161 .47571 Mtetra
.673 .519 .668 r
.2161 .47571 .22204 .50531 .23471 .49129 .22853 .46415 Mtetra
.726 .561 .667 r
.22853 .46415 .23471 .49129 .24801 .46966 .24148 .44653 Mtetra
.763 .598 .673 r
.24148 .44653 .24801 .46966 .26154 .4443 .25464 .42595 Mtetra
.789 .635 .69 r
.25464 .42595 .26154 .4443 .27496 .41905 .26772 .40549 Mtetra
.81 .678 .719 r
.26772 .40549 .27496 .41905 .28806 .39667 .28057 .38728 Mtetra
.824 .734 .765 r
.28057 .38728 .28806 .39667 .3008 .37845 .29313 .37225 Mtetra
.829 .8 .824 r
.29313 .37225 .3008 .37845 .31322 .36438 .30546 .36027 Mtetra
.815 .862 .883 r
.30546 .36027 .31322 .36438 .3254 .35366 .31763 .35062 Mtetra
.786 .9 .922 r
.31763 .35062 .3254 .35366 .33745 .34525 .32972 .34244 Mtetra
.761 .909 .94 r
.32972 .34244 .33745 .34525 .34944 .33827 .34179 .33507 Mtetra
.748 .898 .945 r
.34179 .33507 .34944 .33827 .36142 .33209 .35386 .32814 Mtetra
.739 .875 .943 r
.35386 .32814 .36142 .33209 .37341 .32641 .36595 .32155 Mtetra
.728 .846 .936 r
.36595 .32155 .37341 .32641 .38543 .3211 .37806 .31531 Mtetra
.714 .815 .928 r
.37806 .31531 .38543 .3211 .39748 .31617 .39019 .30949 Mtetra
.698 .786 .919 r
.39019 .30949 .39748 .31617 .40956 .31167 .40234 .30414 Mtetra
.682 .758 .909 r
.40234 .30414 .40956 .31167 .42167 .3076 .41452 .29925 Mtetra
.668 .733 .898 r
.41452 .29925 .42167 .3076 .43384 .30392 .42674 .29474 Mtetra
.657 .709 .886 r
.42674 .29474 .43384 .30392 .44605 .30048 .439 .29051 Mtetra
.651 .689 .872 r
.439 .29051 .44605 .30048 .45833 .29704 .45132 .28641 Mtetra
.648 .674 .861 r
.45132 .28641 .45833 .29704 .47067 .29334 .4637 .28232 Mtetra
.648 .667 .855 r
.4637 .28232 .47067 .29334 .48309 .28921 .47613 .2782 Mtetra
.647 .668 .856 r
.47613 .2782 .48309 .28921 .49556 .28469 .48863 .27408 Mtetra
.644 .675 .865 r
.48863 .27408 .49556 .28469 .50809 .28002 .50118 .27013 Mtetra
.633 .688 .884 r
.50118 .27013 .50809 .28002 .52068 .27553 .5138 .26656 Mtetra
.612 .703 .909 r
.5138 .26656 .52068 .27553 .53332 .27157 .52648 .26362 Mtetra
.573 .717 .94 r
.52648 .26362 .53332 .27157 .54604 .26841 .53923 .26154 Mtetra
.507 .723 .97 r
.53923 .26154 .54604 .26841 .55883 .26618 .55208 .26048 Mtetra
.402 .713 .986 r
.55208 .26048 .55883 .26618 .57172 .26491 .56503 .26054 Mtetra
.242 .668 .961 r
.56503 .26054 .57172 .26491 .58471 .26457 .57809 .26171 Mtetra
.034 .569 .854 r
.57809 .26171 .58471 .26457 .59782 .26501 .59129 .26387 Mtetra
.172 0 0 r
.59129 .26387 .59782 .26501 .61105 .26601 .60463 .26677 Mtetra
.315 0 0 r
.60463 .26677 .61105 .26601 .62439 .26726 .61811 .26999 Mtetra
.383 0 0 r
.61811 .26999 .62439 .26726 .63785 .26833 .63171 .27298 Mtetra
.394 0 0 r
.63171 .27298 .63785 .26833 .65139 .26878 .64541 .27511 Mtetra
.366 0 0 r
.64541 .27511 .65139 .26878 .66499 .26813 .65917 .27575 Mtetra
.307 0 0 r
.65917 .27575 .66499 .26813 .67861 .26602 .67294 .27436 Mtetra
.218 0 0 r
.67294 .27436 .67861 .26602 .69224 .26217 .68669 .27058 Mtetra
.098 0 0 r
.68669 .27058 .69224 .26217 .70583 .2565 .70037 .26431 Mtetra
0 0 0 r
.70037 .26431 .70583 .2565 .71937 .24911 .71397 .25572 Mtetra
.71397 .25572 .71937 .24911 .73285 .24026 .72747 .24519 Mtetra
.72747 .24519 .73285 .24026 .74629 .23031 .74089 .23328 Mtetra
.642 .931 .667 r
.74089 .23328 .74629 .23031 .75969 .21972 .75426 .22062 Mtetra
.766 .992 .782 r
.75426 .22062 .75969 .21972 .7731 .20892 .76761 .20784 Mtetra
.824 .996 .852 r
.76761 .20784 .7731 .20892 .78653 .19834 .78099 .19544 Mtetra
.834 .967 .889 r
.78099 .19544 .78653 .19834 .80003 .18829 .79444 .18383 Mtetra
.124 .231 .704 r
.1582 .41536 .1649 .43426 .1742 .44885 .16792 .42562 Mtetra
.237 .262 .684 r
.16792 .42562 .1742 .44885 .18369 .46331 .17778 .43584 Mtetra
.373 .325 .676 r
.17778 .43584 .18369 .46331 .19368 .47444 .18803 .44364 Mtetra
.49 .39 .669 r
.18803 .44364 .19368 .47444 .20445 .47919 .19888 .44679 Mtetra
.578 .445 .664 r
.19888 .44679 .20445 .47919 .2161 .47571 .21041 .44399 Mtetra
.64 .49 .663 r
.21041 .44399 .2161 .47571 .22853 .46415 .22252 .4354 Mtetra
.686 .53 .669 r
.22252 .4354 .22853 .46415 .24148 .44653 .23504 .42254 Mtetra
.722 .57 .683 r
.23504 .42254 .24148 .44653 .25464 .42595 .24772 .40768 Mtetra
.752 .618 .71 r
.24772 .40768 .25464 .42595 .26772 .40549 .26036 .39299 Mtetra
.78 .682 .756 r
.26036 .39299 .26772 .40549 .28057 .38728 .27285 .37987 Mtetra
.806 .773 .822 r
.27285 .37987 .28057 .38728 .29313 .37225 .28518 .36877 Mtetra
.813 .881 .895 r
.28518 .36877 .29313 .37225 .30546 .36027 .29739 .35934 Mtetra
.779 .957 .927 r
.29739 .35934 .30546 .36027 .31763 .35062 .30955 .3509 Mtetra
.737 .978 .918 r
.30955 .3509 .31763 .35062 .32972 .34244 .32171 .34281 Mtetra
.733 .98 .915 r
.32171 .34281 .32972 .34244 .34179 .33507 .33389 .33468 Mtetra
.754 .971 .927 r
.33389 .33468 .34179 .33507 .35386 .32814 .3461 .32651 Mtetra
.77 .945 .936 r
.3461 .32651 .35386 .32814 .36595 .32155 .35832 .31847 Mtetra
.767 .906 .937 r
.35832 .31847 .36595 .32155 .37806 .31531 .37055 .31083 Mtetra
.751 .863 .931 r
.37055 .31083 .37806 .31531 .39019 .30949 .38278 .30379 Mtetra
.729 .824 .924 r
.38278 .30379 .39019 .30949 .40234 .30414 .39502 .29744 Mtetra
.707 .79 .916 r
.39502 .29744 .40234 .30414 .41452 .29925 .40727 .29175 Mtetra
.688 .764 .909 r
.40727 .29175 .41452 .29925 .42674 .29474 .41955 .28661 Mtetra
.673 .743 .903 r
.41955 .28661 .42674 .29474 .439 .29051 .43186 .28188 Mtetra
.663 .728 .897 r
.43186 .28188 .439 .29051 .45132 .28641 .44422 .27743 Mtetra
.657 .717 .893 r
.44422 .27743 .45132 .28641 .4637 .28232 .45663 .27316 Mtetra
.651 .712 .892 r
.45663 .27316 .4637 .28232 .47613 .2782 .4691 .26906 Mtetra
.644 .71 .896 r
.4691 .26906 .47613 .2782 .48863 .27408 .48162 .26516 Mtetra
.632 .713 .905 r
.48162 .26516 .48863 .27408 .50118 .27013 .49421 .26162 Mtetra
.611 .717 .92 r
.49421 .26162 .50118 .27013 .5138 .26656 .50685 .25864 Mtetra
.576 .72 .941 r
.50685 .25864 .5138 .26656 .52648 .26362 .51957 .25644 Mtetra
.517 .719 .964 r
.51957 .25644 .52648 .26362 .53923 .26154 .53236 .25528 Mtetra
.418 .703 .981 r
.53236 .25528 .53923 .26154 .55208 .26048 .54526 .25536 Mtetra
.26 .655 .966 r
.54526 .25536 .55208 .26048 .56503 .26054 .55826 .25681 Mtetra
.033 .546 .87 r
.55826 .25681 .56503 .26054 .57809 .26171 .5714 .25968 Mtetra
.215 0 0 r
.5714 .25968 .57809 .26171 .59129 .26387 .5847 .26382 Mtetra
.398 0 0 r
.5847 .26382 .59129 .26387 .60463 .26677 .59815 .26893 Mtetra
.49 0 0 r
.59815 .26893 .60463 .26677 .61811 .26999 .61177 .27446 Mtetra
.517 0 0 r
.61177 .27446 .61811 .26999 .63171 .27298 .62553 .27971 Mtetra
.503 0 0 r
.62553 .27971 .63171 .27298 .64541 .27511 .6394 .28385 Mtetra
.459 0 .03 r
.6394 .28385 .64541 .27511 .65917 .27575 .65333 .28604 Mtetra
.391 0 .044 r
.65333 .28604 .65917 .27575 .67294 .27436 .66728 .28558 Mtetra
.297 0 .029 r
.66728 .28558 .67294 .27436 .68669 .27058 .68117 .28199 Mtetra
.176 0 0 r
.68117 .28199 .68669 .27058 .70037 .26431 .69497 .27514 Mtetra
.023 0 0 r
.69497 .27514 .70037 .26431 .71397 .25572 .70863 .26526 Mtetra
0 0 0 r
.70863 .26526 .71397 .25572 .72747 .24519 .72216 .25287 Mtetra
.72216 .25287 .72747 .24519 .74089 .23328 .73557 .23874 Mtetra
.567 .845 .505 r
.73557 .23874 .74089 .23328 .75426 .22062 .74889 .22369 Mtetra
.726 .951 .654 r
.74889 .22369 .75426 .22062 .76761 .20784 .76219 .20854 Mtetra
.821 .996 .767 r
.76219 .20854 .76761 .20784 .78099 .19544 .7755 .19396 Mtetra
.855 .991 .84 r
.7755 .19396 .78099 .19544 .79444 .18383 .78888 .18043 Mtetra
.313 .362 .753 r
.15142 .39712 .1582 .41536 .16792 .42562 .16153 .40341 Mtetra
.364 .355 .715 r
.16153 .40341 .16792 .42562 .17778 .43584 .17175 .40981 Mtetra
.437 .376 .692 r
.17175 .40981 .17778 .43584 .18803 .44364 .18224 .41469 Mtetra
.507 .409 .678 r
.18224 .41469 .18803 .44364 .19888 .44679 .19315 .4166 Mtetra
.567 .445 .673 r
.19315 .4166 .19888 .44679 .21041 .44399 .20453 .41475 Mtetra
.613 .48 .676 r
.20453 .41475 .21041 .44399 .22252 .4354 .2163 .40933 Mtetra
.65 .517 .688 r
.2163 .40933 .22252 .4354 .23504 .42254 .22835 .40145 Mtetra
.68 .561 .714 r
.22835 .40145 .23504 .42254 .24772 .40768 .24051 .39262 Mtetra
.709 .626 .763 r
.24051 .39262 .24772 .40768 .26036 .39299 .25265 .3841 Mtetra
.739 .733 .846 r
.25265 .3841 .26036 .39299 .27285 .37987 .26474 .37651 Mtetra
.745 .889 .945 r
.26474 .37651 .27285 .37987 .28518 .36877 .2768 .3697 Mtetra
.632 .96 .907 r
.2768 .3697 .28518 .36877 .29739 .35934 .28888 .36302 Mtetra
.487 .887 .738 r
.28888 .36302 .29739 .35934 .30955 .3509 .30104 .35574 Mtetra
.481 .868 .671 r
.30104 .35574 .30955 .3509 .32171 .34281 .3133 .3474 Mtetra
.58 .922 .716 r
.3133 .3474 .32171 .34281 .33389 .33468 .32565 .33797 Mtetra
.702 .981 .802 r
.32565 .33797 .33389 .33468 .3461 .32651 .33805 .32786 Mtetra
.783 .995 .872 r
.33805 .32786 .3461 .32651 .35832 .31847 .35047 .31768 Mtetra
.808 .965 .908 r
.35047 .31768 .35832 .31847 .37055 .31083 .36288 .30801 Mtetra
.796 .915 .92 r
.36288 .30801 .37055 .31083 .38278 .30379 .37525 .29925 Mtetra
.767 .865 .921 r
.37525 .29925 .38278 .30379 .39502 .29744 .3876 .29156 Mtetra
.735 .822 .918 r
.3876 .29156 .39502 .29744 .40727 .29175 .39993 .28492 Mtetra
.707 .789 .915 r
.39993 .28492 .40727 .29175 .41955 .28661 .41227 .27914 Mtetra
.686 .767 .913 r
.41227 .27914 .41955 .28661 .43186 .28188 .42464 .27401 Mtetra
.671 .752 .912 r
.42464 .27401 .43186 .28188 .44422 .27743 .43704 .26933 Mtetra
.66 .743 .912 r
.43704 .26933 .44422 .27743 .45663 .27316 .44949 .26497 Mtetra
.65 .739 .914 r
.44949 .26497 .45663 .27316 .4691 .26906 .46199 .26088 Mtetra
.638 .736 .919 r
.46199 .26088 .4691 .26906 .48162 .26516 .47454 .25712 Mtetra
.62 .734 .928 r
.47454 .25712 .48162 .26516 .49421 .26162 .48716 .25384 Mtetra
.59 .731 .942 r
.48716 .25384 .49421 .26162 .50685 .25864 .49984 .25127 Mtetra
.54 .724 .959 r
.49984 .25127 .50685 .25864 .51957 .25644 .51259 .24968 Mtetra
.456 .706 .975 r
.51259 .24968 .51957 .25644 .53236 .25528 .52542 .24936 Mtetra
.318 .663 .973 r
.52542 .24936 .53236 .25528 .54526 .25536 .53836 .25057 Mtetra
.102 .565 .912 r
.53836 .25057 .54526 .25536 .55826 .25681 .55142 .2535 Mtetra
0 .393 .74 r
.55142 .2535 .55826 .25681 .5714 .25968 .56464 .2582 Mtetra
.406 0 0 r
.56464 .2582 .5714 .25968 .5847 .26382 .57802 .26451 Mtetra
.541 0 0 r
.57802 .26451 .5847 .26382 .59815 .26893 .59159 .27204 Mtetra
.594 .05 0 r
.59159 .27204 .59815 .26893 .61177 .27446 .60534 .28014 Mtetra
.598 .087 .009 r
.60534 .28014 .61177 .27446 .62553 .27971 .61927 .2879 Mtetra
.569 .087 .071 r
.61927 .2879 .62553 .27971 .6394 .28385 .63332 .29428 Mtetra
.517 .058 .103 r
.63332 .29428 .6394 .28385 .65333 .28604 .64744 .29823 Mtetra
.44 .002 .109 r
.64744 .29823 .65333 .28604 .66728 .28558 .66157 .29884 Mtetra
.337 0 .09 r
.66157 .29884 .66728 .28558 .68117 .28199 .67562 .2955 Mtetra
.205 0 .045 r
.67562 .2955 .68117 .28199 .69497 .27514 .68954 .28805 Mtetra
.04 0 0 r
.68954 .28805 .69497 .27514 .70863 .26526 .70329 .27678 Mtetra
0 0 0 r
.70329 .27678 .70863 .26526 .72216 .25287 .71685 .26238 Mtetra
.71685 .26238 .72216 .25287 .73557 .23874 .73025 .2458 Mtetra
.567 .809 .426 r
.73025 .2458 .73557 .23874 .74889 .22369 .74353 .22811 Mtetra
.73 .923 .575 r
.74353 .22811 .74889 .22369 .76219 .20854 .75676 .21035 Mtetra
.834 .983 .699 r
.75676 .21035 .76219 .20854 .7755 .19396 .77 .19333 Mtetra
.878 .993 .789 r
.77 .19333 .7755 .19396 .78888 .18043 .7833 .17765 Mtetra
.414 .453 .792 r
.14438 .381 .15142 .39712 .16153 .40341 .1548 .38427 Mtetra
.431 .426 .753 r
.1548 .38427 .16153 .40341 .17175 .40981 .16529 .38784 Mtetra
.468 .424 .726 r
.16529 .38784 .17175 .40981 .18224 .41469 .17596 .39072 Mtetra
.511 .438 .71 r
.17596 .39072 .18224 .41469 .19315 .4166 .18688 .39203 Mtetra
.55 .46 .706 r
.18688 .39203 .19315 .4166 .20453 .41475 .19809 .3914 Mtetra
.58 .487 .713 r
.19809 .3914 .20453 .41475 .2163 .40933 .20954 .38912 Mtetra
.6 .522 .738 r
.20954 .38912 .2163 .40933 .22835 .40145 .22113 .38601 Mtetra
.61 .575 .79 r
.22113 .38601 .22835 .40145 .24051 .39262 .23276 .38299 Mtetra
.6 .675 .893 r
.23276 .38299 .24051 .39262 .25265 .3841 .24441 .38056 Mtetra
.485 .819 .999 r
.24441 .38056 .25265 .3841 .26474 .37651 .25608 .37855 Mtetra
0 0 0 r
.25608 .37855 .26474 .37651 .2768 .3697 .26786 .37613 Mtetra
.048 0 0 r
.26786 .37613 .2768 .3697 .28888 .36302 .27982 .37221 Mtetra
.007 0 0 r
.27982 .37221 .28888 .36302 .30104 .35574 .29201 .36589 Mtetra
0 0 0 r
.29201 .36589 .30104 .35574 .3133 .3474 .30442 .35684 Mtetra
.30442 .35684 .3133 .3474 .32565 .33797 .31701 .34543 Mtetra
.6 .89 .591 r
.31701 .34543 .32565 .33797 .33805 .32786 .32969 .33259 Mtetra
.769 .986 .745 r
.32969 .33259 .33805 .32786 .35047 .31768 .34238 .31945 Mtetra
.841 .995 .839 r
.34238 .31945 .35047 .31768 .36288 .30801 .35501 .30702 Mtetra
.842 .956 .886 r
.35501 .30702 .36288 .30801 .37525 .29925 .36757 .29596 Mtetra
.81 .903 .907 r
.36757 .29596 .37525 .29925 .3876 .29156 .38006 .28655 Mtetra
.767 .853 .915 r
.38006 .28655 .3876 .29156 .39993 .28492 .39249 .27874 Mtetra
.728 .815 .919 r
.39249 .27874 .39993 .28492 .41227 .27914 .4049 .27225 Mtetra
.697 .789 .921 r
.4049 .27225 .41227 .27914 .42464 .27401 .41732 .26675 Mtetra
.675 .773 .924 r
.41732 .26675 .42464 .27401 .43704 .26933 .42977 .26192 Mtetra
.66 .765 .928 r
.42977 .26192 .43704 .26933 .44949 .26497 .44226 .25752 Mtetra
.647 .761 .932 r
.44226 .25752 .44949 .26497 .46199 .26088 .4548 .25346 Mtetra
.633 .758 .938 r
.4548 .25346 .46199 .26088 .47454 .25712 .46739 .24976 Mtetra
.61 .753 .946 r
.46739 .24976 .47454 .25712 .48716 .25384 .48004 .24662 Mtetra
.571 .743 .958 r
.48004 .24662 .48716 .25384 .49984 .25127 .49276 .24431 Mtetra
.506 .724 .971 r
.49276 .24431 .49984 .25127 .51259 .24968 .50554 .24318 Mtetra
.396 .687 .977 r
.50554 .24318 .51259 .24968 .52542 .24936 .51841 .2436 Mtetra
.216 .609 .951 r
.51841 .2436 .52542 .24936 .53836 .25057 .53139 .2459 Mtetra
0 .462 .839 r
.53139 .2459 .53836 .25057 .55142 .2535 .5445 .2503 Mtetra
.327 0 0 r
.5445 .2503 .55142 .2535 .56464 .2582 .55778 .25685 Mtetra
.528 0 0 r
.55778 .25685 .56464 .2582 .57802 .26451 .57125 .26539 Mtetra
.628 .07 0 r
.57125 .26539 .57802 .26451 .59159 .27204 .58492 .27543 Mtetra
.66 .136 0 r
.58492 .27543 .59159 .27204 .60534 .28014 .59881 .28618 Mtetra
.653 .157 .059 r
.59881 .28618 .60534 .28014 .61927 .2879 .61289 .29656 Mtetra
.617 .145 .109 r
.61289 .29656 .61927 .2879 .63332 .29428 .62712 .3053 Mtetra
.557 .104 .132 r
.62712 .3053 .63332 .29428 .64744 .29823 .64143 .3111 Mtetra
.47 .035 .131 r
.64143 .3111 .64744 .29823 .66157 .29884 .65574 .31284 Mtetra
.351 0 .105 r
.65574 .31284 .66157 .29884 .67562 .2955 .66996 .30979 Mtetra
.196 0 .052 r
.66996 .30979 .67562 .2955 .68954 .28805 .68401 .30173 Mtetra
.004 0 0 r
.68401 .30173 .68954 .28805 .70329 .27678 .69784 .28902 Mtetra
0 0 0 r
.69784 .28902 .70329 .27678 .71685 .26238 .71145 .27251 Mtetra
.71145 .27251 .71685 .26238 .73025 .2458 .72485 .25339 Mtetra
.634 .829 .421 r
.72485 .25339 .73025 .2458 .74353 .22811 .7381 .23296 Mtetra
.781 .925 .554 r
.7381 .23296 .74353 .22811 .75676 .21035 .75126 .21247 Mtetra
.87 .974 .666 r
.75126 .21247 .75676 .21035 .77 .19333 .76443 .19291 Mtetra
.906 .984 .753 r
.76443 .19291 .77 .19333 .7833 .17765 .77767 .17501 Mtetra
.454 .527 .843 r
.13694 .36792 .14438 .381 .1548 .38427 .14755 .36952 Mtetra
.445 .493 .815 r
.14755 .36952 .1548 .38427 .16529 .38784 .15817 .3717 Mtetra
.459 .481 .794 r
.15817 .3717 .16529 .38784 .17596 .39072 .1689 .37381 Mtetra
.484 .486 .784 r
.1689 .37381 .17596 .39072 .18688 .39203 .17978 .37534 Mtetra
.506 .502 .786 r
.17978 .37534 .18688 .39203 .19809 .3914 .19082 .37616 Mtetra
.51 .525 .808 r
.19082 .37616 .19809 .3914 .20954 .38912 .20198 .37671 Mtetra
.473 .556 .859 r
.20198 .37671 .20954 .38912 .22113 .38601 .21317 .37775 Mtetra
.322 .586 .939 r
.21317 .37775 .22113 .38601 .23276 .38299 .22435 .37986 Mtetra
0 .44 .75 r
.22435 .37986 .23276 .38299 .24441 .38056 .23553 .383 Mtetra
.44 0 0 r
.23553 .383 .24441 .38056 .25608 .37855 .24681 .38627 Mtetra
.452 0 .017 r
.24681 .38627 .25608 .37855 .26786 .37613 .25832 .3881 Mtetra
.373 0 .077 r
.25832 .3881 .26786 .37613 .27982 .37221 .27017 .38678 Mtetra
.231 0 .047 r
.27017 .38678 .27982 .37221 .29201 .36589 .28242 .38112 Mtetra
.02 0 0 r
.28242 .38112 .29201 .36589 .30442 .35684 .29505 .37087 Mtetra
0 0 0 r
.29505 .37087 .30442 .35684 .31701 .34543 .30796 .35681 Mtetra
.30796 .35681 .31701 .34543 .32969 .33259 .32099 .34047 Mtetra
.767 .952 .629 r
.32099 .34047 .32969 .33259 .34238 .31945 .33401 .3236 Mtetra
.869 .994 .758 r
.33401 .3236 .34238 .31945 .35501 .30702 .34694 .30773 Mtetra
.883 .974 .836 r
.34694 .30773 .35501 .30702 .36757 .29596 .35974 .29386 Mtetra
.851 .929 .88 r
.35974 .29386 .36757 .29596 .38006 .28655 .37239 .28241 Mtetra
.8 .881 .905 r
.37239 .28241 .38006 .28655 .39249 .27874 .38494 .2733 Mtetra
.748 .842 .922 r
.38494 .2733 .39249 .27874 .4049 .27225 .39743 .26612 Mtetra
.705 .815 .933 r
.39743 .26612 .4049 .27225 .41732 .26675 .40991 .26037 Mtetra
.673 .801 .943 r
.40991 .26037 .41732 .26675 .42977 .26192 .4224 .25552 Mtetra
.654 .796 .951 r
.4224 .25552 .42977 .26192 .44226 .25752 .43493 .25118 Mtetra
.641 .795 .956 r
.43493 .25118 .44226 .25752 .4548 .25346 .44751 .24713 Mtetra
.626 .792 .962 r
.44751 .24713 .4548 .25346 .46739 .24976 .46015 .24339 Mtetra
.602 .783 .967 r
.46015 .24339 .46739 .24976 .48004 .24662 .47284 .24019 Mtetra
.557 .765 .975 r
.47284 .24019 .48004 .24662 .49276 .24431 .4856 .2379 Mtetra
.477 .732 .982 r
.4856 .2379 .49276 .24431 .50554 .24318 .49842 .23699 Mtetra
.342 .671 .976 r
.49842 .23699 .50554 .24318 .51841 .2436 .51133 .23793 Mtetra
.128 .557 .922 r
.51133 .23793 .51841 .2436 .53139 .2459 .52434 .24112 Mtetra
0 .371 .772 r
.52434 .24112 .53139 .2459 .5445 .2503 .5375 .24683 Mtetra
.426 0 0 r
.5375 .24683 .5445 .2503 .55778 .25685 .55083 .25512 Mtetra
.599 .029 0 r
.55083 .25512 .55778 .25685 .57125 .26539 .56436 .26576 Mtetra
.681 .138 0 r
.56436 .26576 .57125 .26539 .58492 .27543 .57813 .2782 Mtetra
.706 .19 0 r
.57813 .2782 .58492 .27543 .59881 .28618 .59214 .29151 Mtetra
.695 .201 .067 r
.59214 .29151 .59881 .28618 .61289 .29656 .60636 .30442 Mtetra
.657 .179 .108 r
.60636 .30442 .61289 .29656 .62712 .3053 .62075 .31544 Mtetra
.59 .127 .122 r
.62075 .31544 .62712 .3053 .64143 .3111 .63524 .32304 Mtetra
.488 .04 .112 r
.63524 .32304 .64143 .3111 .65574 .31284 .64972 .32589 Mtetra
.342 0 .073 r
.64972 .32589 .65574 .31284 .66996 .30979 .6641 .32311 Mtetra
.143 0 .002 r
.6641 .32311 .66996 .30979 .68401 .30173 .67828 .31446 Mtetra
0 0 0 r
.67828 .31446 .68401 .30173 .69784 .28902 .69221 .30035 Mtetra
.69221 .30035 .69784 .28902 .71145 .27251 .70587 .2818 Mtetra
.70587 .2818 .71145 .27251 .72485 .25339 .71928 .26021 Mtetra
.752 .885 .476 r
.71928 .26021 .72485 .25339 .7381 .23296 .73251 .23713 Mtetra
.859 .943 .577 r
.73251 .23713 .7381 .23296 .75126 .21247 .74563 .21401 Mtetra
.917 .967 .662 r
.74563 .21401 .75126 .21247 .76443 .19291 .75874 .19202 Mtetra
.935 .968 .733 r
.75874 .19202 .76443 .19291 .77767 .17501 .77192 .17197 Mtetra
.393 .582 .916 r
.12902 .35841 .13694 .36792 .14755 .36952 .13963 .36001 Mtetra
.321 .546 .912 r
.13963 .36001 .14755 .36952 .15817 .3717 .15021 .36256 Mtetra
.282 .536 .916 r
.15021 .36256 .15817 .3717 .1689 .37381 .16085 .36544 Mtetra
.271 .555 .929 r
.16085 .36544 .1689 .37381 .17978 .37534 .17161 .3681 Mtetra
.244 .578 .943 r
.17161 .3681 .17978 .37534 .19082 .37616 .1825 .37049 Mtetra
.112 .552 .916 r
.1825 .37049 .19082 .37616 .20198 .37671 .19345 .37321 Mtetra
0 .36 .695 r
.19345 .37321 .20198 .37671 .21317 .37775 .20437 .37723 Mtetra
.537 0 0 r
.20437 .37723 .21317 .37775 .22435 .37986 .21521 .38321 Mtetra
.64 .137 .036 r
.21521 .38321 .22435 .37986 .23553 .383 .22603 .39084 Mtetra
.635 .187 .169 r
.22603 .39084 .23553 .383 .24681 .38627 .23696 .39863 Mtetra
.578 .162 .216 r
.23696 .39863 .24681 .38627 .25832 .3881 .24823 .40423 Mtetra
.474 .078 .208 r
.24823 .40423 .25832 .3881 .27017 .38678 .26001 .4052 Mtetra
.305 0 .145 r
.26001 .4052 .27017 .38678 .28242 .38112 .27237 .39989 Mtetra
.05 0 .016 r
.27237 .39989 .28242 .38112 .29505 .37087 .28526 .38803 Mtetra
0 0 0 r
.28526 .38803 .29505 .37087 .30796 .35681 .29854 .37081 Mtetra
.607 .813 .404 r
.29854 .37081 .30796 .35681 .32099 .34047 .31199 .3504 Mtetra
.816 .942 .583 r
.31199 .3504 .32099 .34047 .33401 .3236 .32542 .32929 Mtetra
.905 .98 .705 r
.32542 .32929 .33401 .3236 .34694 .30773 .3387 .30958 Mtetra
.916 .969 .788 r
.3387 .30958 .34694 .30773 .35974 .29386 .35175 .29265 Mtetra
.883 .939 .848 r
.35175 .29265 .35974 .29386 .37239 .28241 .3646 .27907 Mtetra
.826 .903 .893 r
.3646 .27907 .37239 .28241 .38494 .2733 .37727 .26873 Mtetra
.761 .871 .928 r
.37727 .26873 .38494 .2733 .39743 .26612 .38984 .26111 Mtetra
.699 .85 .955 r
.38984 .26111 .39743 .26612 .40991 .26037 .40236 .25542 Mtetra
.651 .842 .974 r
.40236 .25542 .40991 .26037 .4224 .25552 .41489 .25087 Mtetra
.623 .845 .984 r
.41489 .25087 .4224 .25552 .43493 .25118 .42746 .24679 Mtetra
.613 .851 .989 r
.42746 .24679 .43493 .25118 .44751 .24713 .44009 .24278 Mtetra
.608 .852 .99 r
.44009 .24278 .44751 .24713 .46015 .24339 .45279 .23882 Mtetra
.593 .841 .992 r
.45279 .23882 .46015 .24339 .47284 .24019 .46554 .23519 Mtetra
.549 .812 .995 r
.46554 .23519 .47284 .24019 .4856 .2379 .47835 .23248 Mtetra
.46 .76 .994 r
.47835 .23248 .4856 .2379 .49842 .23699 .49122 .23132 Mtetra
.306 .671 .975 r
.49122 .23132 .49842 .23699 .51133 .23793 .50416 .23235 Mtetra
.071 .523 .899 r
.50416 .23235 .51133 .23793 .52434 .24112 .51721 .23606 Mtetra
0 .312 .731 r
.51721 .23606 .52434 .24112 .5375 .24683 .5304 .24274 Mtetra
.473 0 0 r
.5304 .24274 .5375 .24683 .55083 .25512 .54377 .25243 Mtetra
.633 .076 0 r
.54377 .25243 .55083 .25512 .56436 .26576 .55736 .26484 Mtetra
.711 .174 0 r
.55736 .26484 .56436 .26576 .57813 .2782 .5712 .27935 Mtetra
.737 .22 0 r
.5712 .27935 .57813 .2782 .59214 .29151 .5853 .29488 Mtetra
.729 .225 .033 r
.5853 .29488 .59214 .29151 .60636 .30442 .59964 .31001 Mtetra
.691 .195 .063 r
.59964 .31001 .60636 .30442 .62075 .31544 .61417 .32303 Mtetra
.618 .127 .065 r
.61417 .32303 .62075 .31544 .63524 .32304 .6288 .33221 Mtetra
.494 .01 .036 r
.6288 .33221 .63524 .32304 .64972 .32589 .64344 .33603 Mtetra
.295 0 0 r
.64344 .33603 .64972 .32589 .6641 .32311 .65796 .33349 Mtetra
.01 0 0 r
.65796 .33349 .6641 .32311 .67828 .31446 .67227 .32431 Mtetra
0 0 0 r
.67227 .32431 .67828 .31446 .69221 .30035 .6863 .30896 Mtetra
.595 .808 .403 r
.6863 .30896 .69221 .30035 .70587 .2818 .70002 .28861 Mtetra
.777 .898 .494 r
.70002 .28861 .70587 .2818 .71928 .26021 .71346 .26485 Mtetra
.881 .936 .563 r
.71346 .26485 .71928 .26021 .73251 .23713 .72669 .23944 Mtetra
.934 .95 .621 r
.72669 .23944 .73251 .23713 .74563 .21401 .7398 .21401 Mtetra
.956 .95 .674 r
.7398 .21401 .74563 .21401 .75874 .19202 .75288 .18989 Mtetra
.955 .941 .725 r
.75288 .18989 .75874 .19202 .77192 .17197 .76602 .16797 Mtetra
0 .469 .859 r
.12054 .35278 .12902 .35841 .13963 .36001 .13092 .35632 Mtetra
.348 0 0 r
.13092 .35632 .13963 .36001 .15021 .36256 .14122 .36135 Mtetra
.503 0 0 r
.14122 .36135 .15021 .36256 .16085 .36544 .15159 .36679 Mtetra
.521 0 0 r
.15159 .36679 .16085 .36544 .17161 .3681 .16215 .37158 Mtetra
.501 0 0 r
.16215 .37158 .17161 .3681 .1825 .37049 .17292 .37544 Mtetra
.51 0 0 r
.17292 .37544 .1825 .37049 .19345 .37321 .18381 .37918 Mtetra
.569 .082 .059 r
.18381 .37918 .19345 .37321 .20437 .37723 .19467 .38434 Mtetra
.638 .183 .155 r
.19467 .38434 .20437 .37723 .21521 .38321 .20539 .39212 Mtetra
.677 .251 .229 r
.20539 .39212 .21521 .38321 .22603 .39084 .216 .4024 Mtetra
.672 .267 .269 r
.216 .4024 .22603 .39084 .23696 .39863 .22672 .41332 Mtetra
.623 .228 .276 r
.22672 .41332 .23696 .39863 .24823 .40423 .23782 .42177 Mtetra
.514 .127 .244 r
.23782 .42177 .24823 .40423 .26001 .4052 .24956 .42447 Mtetra
.312 0 .153 r
.24956 .42447 .26001 .4052 .27237 .39989 .26205 .41917 Mtetra
0 0 0 r
.26205 .41917 .27237 .39989 .28526 .38803 .27524 .40548 Mtetra
.27524 .40548 .28526 .38803 .29854 .37081 .28893 .38495 Mtetra
.757 .885 .475 r
.28893 .38495 .29854 .37081 .31199 .3504 .30283 .36041 Mtetra
.901 .951 .604 r
.30283 .36041 .31199 .3504 .32542 .32929 .31668 .33503 Mtetra
.946 .959 .689 r
.31668 .33503 .32542 .32929 .3387 .30958 .33032 .31154 Mtetra
.941 .948 .757 r
.33032 .31154 .3387 .30958 .35175 .29265 .34365 .29171 Mtetra
.904 .933 .822 r
.34365 .29171 .35175 .29265 .3646 .27907 .35668 .2763 Mtetra
.841 .917 .886 r
.35668 .2763 .3646 .27907 .37727 .26873 .36946 .26521 Mtetra
.753 .903 .944 r
.36946 .26521 .37727 .26873 .38984 .26111 .38208 .25772 Mtetra
.647 .89 .984 r
.38208 .25772 .38984 .26111 .40236 .25542 .39463 .25274 Mtetra
.544 .878 .99 r
.39463 .25274 .40236 .25542 .41489 .25087 .40719 .24906 Mtetra
.483 .872 .969 r
.40719 .24906 .41489 .25087 .42746 .24679 .4198 .24561 Mtetra
.481 .883 .95 r
.4198 .24561 .42746 .24679 .44009 .24278 .43249 .2417 Mtetra
.519 .902 .95 r
.43249 .2417 .44009 .24278 .45279 .23882 .44527 .23721 Mtetra
.551 .908 .967 r
.44527 .23721 .45279 .23882 .46554 .23519 .45811 .23261 Mtetra
.541 .882 .987 r
.45811 .23261 .46554 .23519 .47835 .23248 .47099 .22874 Mtetra
.464 .818 .997 r
.47099 .22874 .47835 .23248 .49122 .23132 .48393 .22658 Mtetra
.304 .702 .977 r
.48393 .22658 .49122 .23132 .50416 .23235 .49692 .227 Mtetra
.06 .524 .894 r
.49692 .227 .50416 .23235 .51721 .23606 .51 .23061 Mtetra
0 .296 .728 r
.51 .23061 .51721 .23606 .5304 .24274 .52322 .23769 Mtetra
.471 0 0 r
.52322 .23769 .5304 .24274 .54377 .25243 .53662 .24825 Mtetra
.629 .085 0 r
.53662 .24825 .54377 .25243 .55736 .26484 .55025 .2619 Mtetra
.712 .181 0 r
.55025 .2619 .55736 .26484 .5712 .27935 .56413 .27791 Mtetra
.746 .225 0 r
.56413 .27791 .5712 .27935 .5853 .29488 .57829 .29509 Mtetra
.745 .226 0 r
.57829 .29509 .5853 .29488 .59964 .31001 .59271 .31187 Mtetra
.711 .186 0 r
.59271 .31187 .59964 .31001 .61417 .32303 .60733 .3264 Mtetra
.63 .091 0 r
.60733 .3264 .61417 .32303 .6288 .33221 .62208 .33676 Mtetra
.463 0 0 r
.62208 .33676 .6288 .33221 .64344 .33603 .63684 .34131 Mtetra
.145 0 0 r
.63684 .34131 .64344 .33603 .65796 .33349 .65148 .33895 Mtetra
0 0 0 r
.65148 .33895 .65796 .33349 .67227 .32431 .6659 .32935 Mtetra
.673 .916 .595 r
.6659 .32935 .67227 .32431 .6863 .30896 .68002 .31305 Mtetra
.853 .959 .62 r
.68002 .31305 .6863 .30896 .70002 .28861 .69382 .29132 Mtetra
.931 .953 .628 r
.69382 .29132 .70002 .28861 .71346 .26485 .70731 .2659 Mtetra
.963 .939 .64 r
.70731 .2659 .71346 .26485 .72669 .23944 .72058 .23872 Mtetra
.974 .925 .66 r
.72058 .23872 .72669 .23944 .7398 .21401 .7337 .21154 Mtetra
.972 .915 .688 r
.7337 .21154 .7398 .21401 .75288 .18989 .74679 .1858 Mtetra
.959 .904 .723 r
.74679 .1858 .75288 .18989 .76602 .16797 .75994 .16248 Mtetra
.626 .064 0 r
.11146 .35102 .12054 .35278 .13092 .35632 .12135 .35859 Mtetra
.709 .226 .098 r
.12135 .35859 .13092 .35632 .14122 .36135 .1311 .36836 Mtetra
.687 .251 .211 r
.1311 .36836 .14122 .36135 .15159 .36679 .14098 .37828 Mtetra
.63 .219 .246 r
.14098 .37828 .15159 .36679 .16215 .37158 .15125 .38619 Mtetra
.565 .166 .245 r
.15125 .38619 .16215 .37158 .17292 .37544 .16197 .39116 Mtetra
.523 .127 .231 r
.16197 .39116 .17292 .37544 .18381 .37918 .17303 .39427 Mtetra
.536 .136 .23 r
.17303 .39427 .18381 .37918 .19467 .38434 .18411 .39801 Mtetra
.598 .194 .248 r
.18411 .39801 .19467 .38434 .20539 .39212 .19501 .40475 Mtetra
.658 .257 .273 r
.19501 .40475 .20539 .39212 .216 .4024 .20568 .41505 Mtetra
.679 .282 .286 r
.20568 .41505 .216 .4024 .22672 .41332 .21636 .42701 Mtetra
.645 .246 .273 r
.21636 .42701 .22672 .41332 .23782 .42177 .22741 .43686 Mtetra
.528 .122 .215 r
.22741 .43686 .23782 .42177 .24956 .42447 .23917 .44045 Mtetra
.245 0 .062 r
.23917 .44045 .24956 .42447 .26205 .41917 .25181 .43485 Mtetra
0 0 0 r
.25181 .43485 .26205 .41917 .27524 .40548 .26529 .41943 Mtetra
.743 .888 .486 r
.26529 .41943 .27524 .40548 .28893 .38495 .27935 .39596 Mtetra
.92 .945 .596 r
.27935 .39596 .28893 .38495 .30283 .36041 .29367 .36782 Mtetra
.967 .936 .649 r
.29367 .36782 .30283 .36041 .31668 .33503 .30793 .33882 Mtetra
.969 .922 .693 r
.30793 .33882 .31668 .33503 .33032 .31154 .3219 .31224 Mtetra
.95 .914 .744 r
.3219 .31224 .33032 .31154 .34365 .29171 .33547 .29024 Mtetra
.911 .915 .809 r
.33547 .29024 .34365 .29171 .35668 .2763 .34865 .2738 Mtetra
.837 .926 .89 r
.34865 .2738 .35668 .2763 .36946 .26521 .3615 .26284 Mtetra
.694 .929 .967 r
.3615 .26284 .36946 .26521 .38208 .25772 .37413 .25647 Mtetra
.436 .859 .947 r
.37413 .25647 .38208 .25772 .39463 .25274 .38666 .25321 Mtetra
.169 .707 .773 r
.38666 .25321 .39463 .25274 .40719 .24906 .39922 .25128 Mtetra
0 0 0 r
.39922 .25128 .40719 .24906 .4198 .24561 .41186 .24902 Mtetra
.41186 .24902 .4198 .24561 .43249 .2417 .42463 .2453 Mtetra
.42463 .2453 .43249 .2417 .44527 .23721 .43752 .23988 Mtetra
.407 .848 .738 r
.43752 .23988 .44527 .23721 .45811 .23261 .45049 .23348 Mtetra
.507 .912 .861 r
.45049 .23348 .45811 .23261 .47099 .22874 .4635 .22743 Mtetra
.496 .89 .951 r
.4635 .22743 .47099 .22874 .48393 .22658 .47653 .22322 Mtetra
.359 .776 .978 r
.47653 .22322 .48393 .22658 .49692 .227 .48959 .22206 Mtetra
.114 .577 .916 r
.48959 .22206 .49692 .227 .51 .23061 .50272 .22471 Mtetra
0 .331 .767 r
.50272 .22471 .51 .23061 .52322 .23769 .51596 .23146 Mtetra
0 .106 .579 r
.51596 .23146 .52322 .23769 .53662 .24825 .52938 .24216 Mtetra
.577 .056 0 r
.52938 .24216 .53662 .24825 .55025 .2619 .54302 .25633 Mtetra
.668 .152 0 r
.54302 .25633 .55025 .2619 .56413 .27791 .55693 .27309 Mtetra
.709 .194 0 r
.55693 .27309 .56413 .27791 .57829 .29509 .57111 .29115 Mtetra
.711 .189 0 r
.57111 .29115 .57829 .29509 .59271 .31187 .58557 .30883 Mtetra
.671 .128 0 r
.58557 .30883 .59271 .31187 .60733 .3264 .60025 .32419 Mtetra
.555 0 0 r
.60025 .32419 .60733 .3264 .62208 .33676 .61506 .3352 Mtetra
.27 0 0 r
.61506 .3352 .62208 .33676 .63684 .34131 .6299 .34014 Mtetra
.274 .773 .882 r
.6299 .34014 .63684 .34131 .65148 .33895 .64463 .33785 Mtetra
.728 .983 .906 r
.64463 .33785 .65148 .33895 .6659 .32935 .65914 .328 Mtetra
.899 .977 .809 r
.65914 .328 .6659 .32935 .68002 .31305 .67335 .31114 Mtetra
.953 .937 .735 r
.67335 .31114 .68002 .31305 .69382 .29132 .68723 .28861 Mtetra
.97 .906 .696 r
.68723 .28861 .69382 .29132 .70731 .2659 .7008 .26224 Mtetra
.974 .885 .68 r
.7008 .26224 .70731 .2659 .72058 .23872 .71412 .23404 Mtetra
.971 .872 .681 r
.71412 .23404 .72058 .23872 .7337 .21154 .7273 .20586 Mtetra
.962 .864 .696 r
.7273 .20586 .7337 .21154 .74679 .1858 .74044 .17919 Mtetra
.947 .859 .72 r
.74044 .17919 .74679 .1858 .75994 .16248 .75363 .15505 Mtetra
.777 .323 .17 r
.10186 .3524 .11146 .35102 .12135 .35859 .11102 .36578 Mtetra
.767 .369 .3 r
.11102 .36578 .12135 .35859 .1311 .36836 .11996 .38225 Mtetra
.72 .349 .346 r
.11996 .38225 .1311 .36836 .14098 .37828 .12914 .39829 Mtetra
.65 .292 .351 r
.12914 .39829 .14098 .37828 .15125 .38619 .13903 .41006 Mtetra
.562 .209 .327 r
.13903 .41006 .15125 .38619 .16197 .39116 .14981 .41557 Mtetra
.48 .125 .287 r
.14981 .41557 .16197 .39116 .17303 .39427 .16127 .41612 Mtetra
.451 .085 .25 r
.16127 .41612 .17303 .39427 .18411 .39801 .17293 .41562 Mtetra
.508 .119 .238 r
.17293 .41562 .18411 .39801 .19501 .40475 .18436 .41813 Mtetra
.605 .197 .242 r
.18436 .41813 .19501 .40475 .20568 .41505 .1954 .42541 Mtetra
.668 .248 .238 r
.1954 .42541 .20568 .41505 .21636 .42701 .20628 .43589 Mtetra
.656 .217 .196 r
.20628 .43589 .21636 .42701 .22741 .43686 .21741 .44533 Mtetra
.504 .028 .059 r
.21741 .44533 .22741 .43686 .23917 .44045 .22925 .44879 Mtetra
0 0 0 r
.22925 .44879 .23917 .44045 .25181 .43485 .24204 .44264 Mtetra
.782 .969 .672 r
.24204 .44264 .25181 .43485 .26529 .41943 .25575 .42591 Mtetra
.954 .952 .687 r
.25575 .42591 .26529 .41943 .27935 .39596 .27012 .40044 Mtetra
.976 .904 .675 r
.27012 .40044 .27935 .39596 .29367 .36782 .28476 .36993 Mtetra
.973 .875 .678 r
.28476 .36993 .29367 .36782 .30793 .33882 .29932 .33864 Mtetra
.96 .863 .699 r
.29932 .33864 .30793 .33882 .3219 .31224 .31353 .31028 Mtetra
.939 .866 .74 r
.31353 .31028 .3219 .31224 .33547 .29024 .32727 .28737 Mtetra
.9 .887 .81 r
.32727 .28737 .33547 .29024 .34865 .2738 .34052 .27111 Mtetra
.806 .927 .915 r
.34052 .27111 .34865 .2738 .3615 .26284 .35337 .26153 Mtetra
.5 .888 .959 r
.35337 .26153 .3615 .26284 .37413 .25647 .36594 .25756 Mtetra
.052 0 0 r
.36594 .25756 .37413 .25647 .38666 .25321 .37841 .25729 Mtetra
.305 0 0 r
.37841 .25729 .38666 .25321 .39922 .25128 .39092 .25821 Mtetra
.309 0 0 r
.39092 .25821 .39922 .25128 .41186 .24902 .40358 .25783 Mtetra
.193 0 0 r
.40358 .25783 .41186 .24902 .42463 .2453 .41645 .2544 Mtetra
0 0 0 r
.41645 .2544 .42463 .2453 .43752 .23988 .4295 .24757 Mtetra
.4295 .24757 .43752 .23988 .45049 .23348 .44265 .23842 Mtetra
.462 .847 .629 r
.44265 .23842 .45049 .23348 .4635 .22743 .45583 .22899 Mtetra
.561 .935 .834 r
.45583 .22899 .4635 .22743 .47653 .22322 .46901 .22149 Mtetra
.486 .879 .962 r
.46901 .22149 .47653 .22322 .48959 .22206 .48217 .21762 Mtetra
.252 .684 .962 r
.48217 .21762 .48959 .22206 .50272 .22471 .49536 .21834 Mtetra
0 .419 .842 r
.49536 .21834 .50272 .22471 .51596 .23146 .50863 .22388 Mtetra
0 .182 .677 r
.50863 .22388 .51596 .23146 .52938 .24216 .52206 .23392 Mtetra
0 .016 .535 r
.52206 .23392 .52938 .24216 .54302 .25633 .53571 .24778 Mtetra
.553 .079 0 r
.53571 .24778 .54302 .25633 .55693 .27309 .54961 .26444 Mtetra
.585 .113 0 r
.54961 .26444 .55693 .27309 .57111 .29115 .56379 .28249 Mtetra
.562 .09 0 r
.56379 .28249 .57111 .29115 .58557 .30883 .57824 .3002 Mtetra
0 .006 .531 r
.57824 .3002 .58557 .30883 .60025 .32419 .59293 .31559 Mtetra
0 .207 .712 r
.59293 .31559 .60025 .32419 .61506 .3352 .60776 .32663 Mtetra
.154 .502 .909 r
.60776 .32663 .61506 .3352 .6299 .34014 .62263 .33157 Mtetra
.551 .731 .959 r
.62263 .33157 .6299 .34014 .64463 .33785 .63741 .32924 Mtetra
.774 .812 .884 r
.63741 .32924 .64463 .33785 .65914 .328 .65198 .31932 Mtetra
.871 .824 .8 r
.65198 .31932 .65914 .328 .67335 .31114 .66627 .30236 Mtetra
.913 .819 .741 r
.66627 .30236 .67335 .31114 .68723 .28861 .68024 .2797 Mtetra
.932 .813 .706 r
.68024 .2797 .68723 .28861 .7008 .26224 .6939 .25319 Mtetra
.939 .809 .689 r
.6939 .25319 .7008 .26224 .71412 .23404 .70732 .22484 Mtetra
.939 .808 .687 r
.70732 .22484 .71412 .23404 .7273 .20586 .7206 .19651 Mtetra
.934 .809 .697 r
.7206 .19651 .7273 .20586 .74044 .17919 .73382 .16971 Mtetra
.923 .811 .717 r
.73382 .16971 .74044 .17919 .75363 .15505 .7471 .14545 Mtetra
.826 .425 .288 r
.09194 .35509 .10186 .3524 .11102 .36578 .10024 .37503 Mtetra
.802 .437 .366 r
.10024 .37503 .11102 .36578 .11996 .38225 .10822 .39904 Mtetra
.753 .403 .391 r
.10822 .39904 .11996 .38225 .12914 .39829 .11661 .42186 Mtetra
.673 .329 .382 r
.11661 .42186 .12914 .39829 .13903 .41006 .1261 .43757 Mtetra
.553 .21 .34 r
.1261 .43757 .13903 .41006 .14981 .41557 .13703 .44287 Mtetra
.401 .056 .262 r
.13703 .44287 .14981 .41557 .16127 .41612 .14911 .43927 Mtetra
.282 0 .165 r
.14911 .43927 .16127 .41612 .17293 .41562 .16162 .43227 Mtetra
.295 0 .092 r
.16162 .43227 .17293 .41562 .18436 .41813 .17388 .428 Mtetra
.452 0 .058 r
.17388 .428 .18436 .41813 .1954 .42541 .18556 .42973 Mtetra
.599 .091 .014 r
.18556 .42973 .1954 .42541 .20628 .43589 .19685 .43644 Mtetra
.595 .037 0 r
.19685 .43644 .20628 .43589 .21741 .44533 .20822 .44374 Mtetra
.15 0 0 r
.20822 .44374 .21741 .44533 .22925 .44879 .22019 .44609 Mtetra
.715 .917 .963 r
.22019 .44609 .22925 .44879 .24204 .44264 .2331 .43928 Mtetra
.896 .865 .801 r
.2331 .43928 .24204 .44264 .25575 .42591 .24694 .42197 Mtetra
.927 .82 .721 r
.24694 .42197 .25575 .42591 .27012 .40044 .26147 .39586 Mtetra
.933 .799 .689 r
.26147 .39586 .27012 .40044 .28476 .36993 .27628 .36471 Mtetra
.931 .791 .683 r
.27628 .36471 .28476 .36993 .29932 .33864 .291 .33297 Mtetra
.924 .794 .699 r
.291 .33297 .29932 .33864 .31353 .31028 .30532 .30457 Mtetra
.908 .81 .739 r
.30532 .30457 .31353 .31028 .32727 .28737 .31911 .28231 Mtetra
.87 .848 .82 r
.31911 .28231 .32727 .28737 .34052 .27111 .33234 .26765 Mtetra
.727 .905 .958 r
.33234 .26765 .34052 .27111 .35337 .26153 .3451 .26076 Mtetra
.088 .644 .795 r
.3451 .26076 .35337 .26153 .36594 .25756 .35754 .2605 Mtetra
.451 0 0 r
.35754 .2605 .36594 .25756 .37841 .25729 .36986 .26444 Mtetra
.53 .035 .025 r
.36986 .26444 .37841 .25729 .39092 .25821 .38227 .26924 Mtetra
.466 .011 .086 r
.38227 .26924 .39092 .25821 .40358 .25783 .39494 .27139 Mtetra
.315 0 .056 r
.39494 .27139 .40358 .25783 .41645 .2544 .40792 .26838 Mtetra
.079 0 0 r
.40792 .26838 .41645 .2544 .4295 .24757 .42117 .25969 Mtetra
0 0 0 r
.42117 .25969 .4295 .24757 .44265 .23842 .43457 .24691 Mtetra
.43457 .24691 .44265 .23842 .45583 .22899 .44799 .23299 Mtetra
.672 .957 .727 r
.44799 .23299 .45583 .22899 .46901 .22149 .46136 .22107 Mtetra
.664 .966 .922 r
.46136 .22107 .46901 .22149 .48217 .21762 .47465 .21347 Mtetra
.462 .81 .998 r
.47465 .21347 .48217 .21762 .49536 .21834 .48792 .21136 Mtetra
.155 .544 .925 r
.48792 .21136 .49536 .21834 .50863 .22388 .50124 .21488 Mtetra
0 .293 .784 r
.50124 .21488 .50863 .22388 .52206 .23392 .51468 .22347 Mtetra
0 .123 .661 r
.51468 .22347 .52206 .23392 .53571 .24778 .52832 .23621 Mtetra
0 .032 .59 r
.52832 .23621 .53571 .24778 .54961 .26444 .54219 .25189 Mtetra
0 .009 .575 r
.54219 .25189 .54961 .26444 .56379 .28249 .55634 .26903 Mtetra
0 .049 .614 r
.55634 .26903 .56379 .28249 .57824 .3002 .57076 .28589 Mtetra
0 .154 .696 r
.57076 .28589 .57824 .3002 .59293 .31559 .58541 .30052 Mtetra
.099 .31 .787 r
.58541 .30052 .59293 .31559 .60776 .32663 .60021 .31095 Mtetra
.364 .471 .835 r
.60021 .31095 .60776 .32663 .62263 .33157 .61507 .31548 Mtetra
.578 .588 .827 r
.61507 .31548 .62263 .33157 .63741 .32924 .62986 .31301 Mtetra
.716 .655 .788 r
.62986 .31301 .63741 .32924 .65198 .31932 .64447 .30321 Mtetra
.798 .691 .747 r
.64447 .30321 .65198 .31932 .66627 .30236 .65882 .28661 Mtetra
.846 .712 .715 r
.65882 .28661 .66627 .30236 .68024 .2797 .67288 .26451 Mtetra
.874 .726 .695 r
.67288 .26451 .68024 .2797 .6939 .25319 .68665 .23868 Mtetra
.89 .737 .685 r
.68665 .23868 .6939 .25319 .70732 .22484 .7002 .21107 Mtetra
.898 .746 .685 r
.7002 .21107 .70732 .22484 .7206 .19651 .7136 .18347 Mtetra
.899 .756 .695 r
.7136 .18347 .7206 .19651 .73382 .16971 .72695 .15733 Mtetra
.893 .765 .714 r
.72695 .15733 .73382 .16971 .7471 .14545 .74035 .13364 Mtetra
.863 .482 .321 r
.0821 .35621 .09194 .35509 .10024 .37503 .08962 .38176 Mtetra
.843 .487 .38 r
.08962 .38176 .10024 .37503 .10822 .39904 .09674 .41219 Mtetra
.799 .45 .395 r
.09674 .41219 .10822 .39904 .11661 .42186 .10441 .44067 Mtetra
.715 .36 .374 r
.10441 .44067 .11661 .42186 .1261 .43757 .11359 .45939 Mtetra
.541 .173 .291 r
.11359 .45939 .1261 .43757 .13703 .44287 .12474 .46376 Mtetra
.193 0 .085 r
.12474 .46376 .13703 .44287 .14911 .43927 .1375 .45542 Mtetra
0 0 0 r
.1375 .45542 .14911 .43927 .16162 .43227 .15095 .44135 Mtetra
.507 .844 .562 r
.15095 .44135 .16162 .43227 .17388 .428 .16414 .42952 Mtetra
.436 .875 .852 r
.16414 .42952 .17388 .428 .18556 .42973 .17658 .42464 Mtetra
.162 .614 .934 r
.17658 .42464 .18556 .42973 .19685 .43644 .18839 .42639 Mtetra
.201 .488 .899 r
.18839 .42639 .19685 .43644 .20822 .44374 .20007 .43045 Mtetra
.48 .565 .864 r
.20007 .43045 .20822 .44374 .22019 .44609 .21221 .43105 Mtetra
.69 .636 .791 r
.21221 .43105 .22019 .44609 .2331 .43928 .22518 .42367 Mtetra
.792 .67 .729 r
.22518 .42367 .2331 .43928 .24694 .42197 .23904 .40667 Mtetra
.84 .687 .693 r
.23904 .40667 .24694 .42197 .26147 .39586 .25356 .38144 Mtetra
.864 .699 .677 r
.25356 .38144 .26147 .39586 .27628 .36471 .26835 .35154 Mtetra
.874 .711 .677 r
.26835 .35154 .27628 .36471 .291 .33297 .28304 .32129 Mtetra
.874 .726 .695 r
.28304 .32129 .291 .33297 .30532 .30457 .29732 .29464 Mtetra
.861 .75 .738 r
.29732 .29464 .30532 .30457 .31911 .28231 .31104 .27453 Mtetra
.814 .792 .832 r
.31104 .27453 .31911 .28231 .33234 .26765 .32415 .2627 Mtetra
.572 .824 .993 r
.32415 .2627 .33234 .26765 .3451 .26076 .33674 .2595 Mtetra
.327 0 0 r
.33674 .2595 .3451 .26076 .35754 .2605 .34898 .26376 Mtetra
.638 .117 0 r
.34898 .26376 .35754 .2605 .36986 .26444 .3611 .27262 Mtetra
.639 .175 .134 r
.3611 .27262 .36986 .26444 .38227 .26924 .37338 .28186 Mtetra
.544 .107 .161 r
.37338 .28186 .38227 .26924 .39494 .27139 .38602 .2869 Mtetra
.352 0 .106 r
.38602 .2869 .39494 .27139 .40792 .26838 .39912 .28438 Mtetra
.037 0 0 r
.39912 .28438 .40792 .26838 .42117 .25969 .41259 .2736 Mtetra
0 0 0 r
.41259 .2736 .42117 .25969 .43457 .24691 .42628 .25673 Mtetra
.666 .875 .499 r
.42628 .25673 .43457 .24691 .44799 .23299 .43998 .23776 Mtetra
.822 .983 .702 r
.43998 .23776 .44799 .23299 .46136 .22107 .45359 .22084 Mtetra
.822 .989 .872 r
.45359 .22084 .46136 .22107 .47465 .21347 .46705 .20896 Mtetra
.661 .878 .979 r
.46705 .20896 .47465 .21347 .48792 .21136 .48043 .20347 Mtetra
.377 .65 .964 r
.48043 .20347 .48792 .21136 .50124 .21488 .4938 .2044 Mtetra
.105 .408 .859 r
.4938 .2044 .50124 .21488 .51468 .22347 .50725 .21093 Mtetra
0 .238 .755 r
.50725 .21093 .51468 .22347 .52832 .23621 .52087 .22185 Mtetra
0 .151 .693 r
.52087 .22185 .52832 .23621 .54219 .25189 .53472 .23581 Mtetra
0 .132 .677 r
.53472 .23581 .54219 .25189 .55634 .26903 .54882 .25125 Mtetra
0 .168 .694 r
.54882 .25125 .55634 .26903 .57076 .28589 .56317 .26648 Mtetra
.102 .245 .727 r
.56317 .26648 .57076 .28589 .58541 .30052 .57775 .27963 Mtetra
.274 .343 .753 r
.57775 .27963 .58541 .30052 .60021 .31095 .59249 .28888 Mtetra
.439 .437 .76 r
.59249 .28888 .60021 .31095 .61507 .31548 .6073 .29266 Mtetra
.574 .512 .749 r
.6073 .29266 .61507 .31548 .62986 .31301 .62206 .28994 Mtetra
.673 .568 .729 r
.62206 .28994 .62986 .31301 .64447 .30321 .63668 .28042 Mtetra
.742 .607 .708 r
.63668 .28042 .64447 .30321 .65882 .28661 .65108 .2646 Mtetra
.789 .636 .692 r
.65108 .2646 .65882 .28661 .67288 .26451 .66522 .24367 Mtetra
.821 .659 .682 r
.66522 .24367 .67288 .26451 .68665 .23868 .67911 .21926 Mtetra
.843 .678 .678 r
.67911 .21926 .68665 .23868 .7002 .21107 .6928 .19317 Mtetra
.856 .695 .682 r
.6928 .19317 .7002 .21107 .7136 .18347 .70635 .16708 Mtetra
.862 .711 .693 r
.70635 .16708 .7136 .18347 .72695 .15733 .71986 .14233 Mtetra
.861 .726 .712 r
.71986 .14233 .72695 .15733 .74035 .13364 .73342 .11984 Mtetra
.9 .52 .298 r
.07276 .35284 .0821 .35621 .08962 .38176 .07984 .38118 Mtetra
.894 .532 .351 r
.07984 .38118 .08962 .38176 .09674 .41219 .08648 .41474 Mtetra
.869 .503 .352 r
.08648 .41474 .09674 .41219 .10441 .44067 .09378 .44582 Mtetra
.801 .397 .287 r
.09378 .44582 .10441 .44067 .11359 .45939 .10284 .46549 Mtetra
.463 0 0 r
.10284 .46549 .11359 .45939 .12474 .46376 .11422 .46838 Mtetra
.771 .996 .81 r
.11422 .46838 .12474 .46376 .1375 .45542 .12753 .45621 Mtetra
.927 .913 .784 r
.12753 .45621 .1375 .45542 .15095 .44135 .14171 .4367 Mtetra
.884 .827 .786 r
.14171 .4367 .15095 .44135 .16414 .42952 .15564 .41891 Mtetra
.768 .724 .812 r
.15564 .41891 .16414 .42952 .17658 .42464 .16872 .40841 Mtetra
.596 .575 .8 r
.16872 .40841 .17658 .42464 .18839 .42639 .18101 .40549 Mtetra
.504 .473 .755 r
.18101 .40549 .18839 .42639 .20007 .43045 .193 .40618 Mtetra
.548 .473 .722 r
.193 .40618 .20007 .43045 .21221 .43105 .20527 .40493 Mtetra
.642 .52 .699 r
.20527 .40493 .21221 .43105 .22518 .42367 .21824 .39727 Mtetra
.719 .566 .68 r
.21824 .39727 .22518 .42367 .23904 .40667 .232 .38139 Mtetra
.771 .6 .667 r
.232 .38139 .23904 .40667 .25356 .38144 .24635 .35838 Mtetra
.802 .626 .663 r
.24635 .35838 .25356 .38144 .26835 .35154 .26096 .33135 Mtetra
.819 .648 .67 r
.26096 .33135 .26835 .35154 .28304 .32129 .27546 .30421 Mtetra
.823 .668 .691 r
.27546 .30421 .28304 .32129 .29732 .29464 .28956 .28072 Mtetra
.807 .692 .737 r
.28956 .28072 .29732 .29464 .31104 .27453 .3031 .26385 Mtetra
.736 .721 .837 r
.3031 .26385 .31104 .27453 .32415 .2627 .31602 .25549 Mtetra
.364 .662 .971 r
.31602 .25549 .32415 .2627 .33674 .2595 .3284 .25624 Mtetra
.54 0 0 r
.3284 .25624 .33674 .2595 .34898 .26376 .3404 .26495 Mtetra
.737 .232 .025 r
.3404 .26495 .34898 .26376 .3611 .27262 .3523 .27846 Mtetra
.716 .248 .139 r
.3523 .27846 .3611 .27262 .37338 .28186 .36443 .29183 Mtetra
.6 .142 .138 r
.36443 .29183 .37338 .28186 .38602 .2869 .37703 .29952 Mtetra
.326 0 .028 r
.37703 .29952 .38602 .2869 .39912 .28438 .39023 .29744 Mtetra
0 0 0 r
.39023 .29744 .39912 .28438 .41259 .2736 .40393 .28473 Mtetra
.673 .866 .476 r
.40393 .28473 .41259 .2736 .42628 .25673 .4179 .2641 Mtetra
.884 .958 .619 r
.4179 .2641 .42628 .25673 .43998 .23776 .4319 .24049 Mtetra
.937 .966 .721 r
.4319 .24049 .43998 .23776 .45359 .22084 .44574 .21895 Mtetra
.903 .941 .824 r
.44574 .21895 .45359 .22084 .46705 .20896 .45939 .20301 Mtetra
.773 .86 .914 r
.45939 .20301 .46705 .20896 .48043 .20347 .47288 .19421 Mtetra
.544 .695 .938 r
.47288 .19421 .48043 .20347 .4938 .2044 .48631 .19241 Mtetra
.296 .493 .881 r
.48631 .19241 .4938 .2044 .50725 .21093 .49979 .19655 Mtetra
.128 .336 .801 r
.49979 .19655 .50725 .21093 .52087 .22185 .5134 .20522 Mtetra
.06 .251 .745 r
.5134 .20522 .52087 .22185 .53472 .23581 .5272 .2169 Mtetra
.071 .228 .72 r
.5272 .2169 .53472 .23581 .54882 .25125 .54124 .23005 Mtetra
.141 .249 .715 r
.54124 .23005 .54882 .25125 .56317 .26648 .55552 .24304 Mtetra
.246 .298 .719 r
.55552 .24304 .56317 .26648 .57775 .27963 .57001 .25418 Mtetra
.364 .359 .721 r
.57001 .25418 .57775 .27963 .59249 .28888 .58466 .26182 Mtetra
.475 .421 .717 r
.58466 .26182 .59249 .28888 .6073 .29266 .59939 .26458 Mtetra
.57 .475 .707 r
.59939 .26458 .6073 .29266 .62206 .28994 .6141 .26153 Mtetra
.645 .519 .695 r
.6141 .26153 .62206 .28994 .63668 .28042 .62871 .25243 Mtetra
.703 .556 .684 r
.62871 .25243 .63668 .28042 .65108 .2646 .64314 .2377 Mtetra
.747 .586 .676 r
.64314 .2377 .65108 .2646 .66522 .24367 .65736 .2184 Mtetra
.779 .612 .672 r
.65736 .2184 .66522 .24367 .67911 .21926 .67136 .19597 Mtetra
.803 .634 .673 r
.67136 .19597 .67911 .21926 .6928 .19317 .68519 .17202 Mtetra
.819 .655 .68 r
.68519 .17202 .6928 .19317 .70635 .16708 .69892 .14803 Mtetra
.828 .675 .693 r
.69892 .14803 .70635 .16708 .71986 .14233 .7126 .12523 Mtetra
.831 .694 .713 r
.7126 .12523 .71986 .14233 .73342 .11984 .72633 .10442 Mtetra
.923 .532 .199 r
.06422 .34327 .07276 .35284 .07984 .38118 .07136 .37053 Mtetra
.937 .564 .238 r
.07136 .37053 .07984 .38118 .08648 .41474 .0781 .40269 Mtetra
.926 .541 .167 r
.0781 .40269 .08648 .41474 .09378 .44582 .08551 .43218 Mtetra
.712 .295 0 r
.08551 .43218 .09378 .44582 .10284 .46549 .09472 .45019 Mtetra
.462 .519 .831 r
.09472 .45019 .10284 .46549 .11422 .46838 .10629 .45143 Mtetra
.756 .642 .734 r
.10629 .45143 .11422 .46838 .12753 .45621 .11985 .43747 Mtetra
.797 .645 .694 r
.11985 .43747 .12753 .45621 .14171 .4367 .13432 .41584 Mtetra
.778 .624 .689 r
.13432 .41584 .14171 .4367 .15564 .41891 .14858 .39542 Mtetra
.715 .576 .697 r
.14858 .39542 .15564 .41891 .16872 .40841 .162 .38186 Mtetra
.62 .502 .698 r
.162 .38186 .16872 .40841 .18101 .40549 .17459 .3758 Mtetra
.554 .445 .684 r
.17459 .3758 .18101 .40549 .193 .40618 .18679 .37385 Mtetra
.562 .44 .67 r
.18679 .37385 .193 .40618 .20527 .40493 .19915 .3711 Mtetra
.617 .471 .661 r
.19915 .3711 .20527 .40493 .21824 .39727 .21205 .36353 Mtetra
.676 .511 .655 r
.21205 .36353 .21824 .39727 .232 .38139 .22561 .3494 Mtetra
.723 .547 .652 r
.22561 .3494 .232 .38139 .24635 .35838 .23968 .32948 Mtetra
.755 .577 .655 r
.23968 .32948 .24635 .35838 .26096 .33135 .25397 .30632 Mtetra
.773 .601 .666 r
.25397 .30632 .26096 .33135 .27546 .30421 .26816 .28329 Mtetra
.776 .623 .69 r
.26816 .28329 .27546 .30421 .28956 .28072 .28199 .26374 Mtetra
.752 .641 .738 r
.28199 .26374 .28956 .28072 .3031 .26385 .2953 .25048 Mtetra
.651 .644 .83 r
.2953 .25048 .3031 .26385 .31602 .25549 .30801 .24549 Mtetra
.214 .494 .9 r
.30801 .24549 .31602 .25549 .3284 .25624 .32018 .24951 Mtetra
.576 .049 0 r
.32018 .24951 .3284 .25624 .3404 .26495 .33198 .26151 Mtetra
.779 .274 0 r
.33198 .26151 .3404 .26495 .3523 .27846 .3437 .27822 Mtetra
.773 .275 .025 r
.3437 .27822 .3523 .27846 .36443 .29183 .3557 .29432 Mtetra
.637 .103 0 r
.3557 .29432 .36443 .29183 .37703 .29952 .36827 .30372 Mtetra
.091 0 0 r
.36827 .30372 .37703 .29952 .39023 .29744 .38155 .3019 Mtetra
.75 .981 .739 r
.38155 .3019 .39023 .29744 .40393 .28473 .39542 .2879 Mtetra
.946 .959 .712 r
.39542 .2879 .40393 .28473 .4179 .2641 .40962 .26478 Mtetra
.968 .91 .7 r
.40962 .26478 .4179 .2641 .4319 .24049 .42385 .23807 Mtetra
.953 .88 .725 r
.42385 .23807 .4319 .24049 .44574 .21895 .4379 .21337 Mtetra
.905 .852 .779 r
.4379 .21337 .44574 .21895 .45939 .20301 .4517 .19452 Mtetra
.805 .799 .846 r
.4517 .19452 .45939 .20301 .47288 .19421 .46529 .18312 Mtetra
.632 .69 .886 r
.46529 .18312 .47288 .19421 .48631 .19241 .47879 .17893 Mtetra
.429 .54 .867 r
.47879 .17893 .48631 .19241 .49979 .19655 .49229 .18074 Mtetra
.278 .407 .814 r
.49229 .18074 .49979 .19655 .5134 .20522 .5059 .18697 Mtetra
.209 .328 .766 r
.5059 .18697 .5134 .20522 .5272 .2169 .51967 .19609 Mtetra
.212 .299 .736 r
.51967 .19609 .5272 .2169 .54124 .23005 .53365 .20659 Mtetra
.261 .306 .72 r
.53365 .20659 .54124 .23005 .55552 .24304 .54784 .21699 Mtetra
.335 .335 .71 r
.54784 .21699 .55552 .24304 .57001 .25418 .56224 .22578 Mtetra
.418 .374 .703 r
.56224 .22578 .57001 .25418 .58466 .26182 .57679 .23156 Mtetra
.498 .416 .694 r
.57679 .23156 .58466 .26182 .59939 .26458 .59142 .23313 Mtetra
.569 .456 .686 r
.59142 .23313 .59939 .26458 .6141 .26153 .60607 .22972 Mtetra
.628 .493 .678 r
.60607 .22972 .6141 .26153 .62871 .25243 .62065 .2211 Mtetra
.677 .525 .672 r
.62065 .2211 .62871 .25243 .64314 .2377 .63509 .20765 Mtetra
.716 .553 .668 r
.63509 .20765 .64314 .2377 .65736 .2184 .64938 .19026 Mtetra
.746 .579 .668 r
.64938 .19026 .65736 .2184 .67136 .19597 .66349 .17016 Mtetra
.77 .603 .672 r
.66349 .17016 .67136 .19597 .68519 .17202 .67747 .14872 Mtetra
.787 .626 .682 r
.67747 .14872 .68519 .17202 .69892 .14803 .69136 .12723 Mtetra
.798 .648 .696 r
.69136 .12723 .69892 .14803 .7126 .12523 .70522 .10672 Mtetra
.803 .67 .717 r
.70522 .10672 .7126 .12523 .72633 .10442 .71913 .08792 Mtetra
.835 .448 0 r
.05644 .32801 .06422 .34327 .07136 .37053 .06415 .35064 Mtetra
.806 .469 0 r
.06415 .35064 .07136 .37053 .0781 .40269 .07154 .37731 Mtetra
0 0 .323 r
.07154 .37731 .0781 .40269 .08551 .43218 .07954 .40148 Mtetra
.136 .149 .609 r
.07954 .40148 .08551 .43218 .09472 .45019 .08914 .41566 Mtetra
.524 .404 .658 r
.08914 .41566 .09472 .45019 .10629 .45143 .10083 .41534 Mtetra
.664 .497 .648 r
.10083 .41534 .10629 .45143 .11985 .43747 .11428 .40187 Mtetra
.711 .53 .643 r
.11428 .40187 .11985 .43747 .13432 .41584 .12857 .38161 Mtetra
.711 .533 .647 r
.12857 .38161 .13432 .41584 .14858 .39542 .14269 .36215 Mtetra
.675 .511 .656 r
.14269 .36215 .14858 .39542 .162 .38186 .1561 .34841 Mtetra
.615 .47 .661 r
.1561 .34841 .162 .38186 .17459 .3758 .16877 .34113 Mtetra
.568 .434 .658 r
.16877 .34113 .17459 .3758 .18679 .37385 .18106 .33763 Mtetra
.568 .429 .652 r
.18106 .33763 .18679 .37385 .19915 .3711 .19343 .33395 Mtetra
.604 .452 .648 r
.19343 .33395 .19915 .3711 .21205 .36353 .20623 .32679 Mtetra
.65 .485 .646 r
.20623 .32679 .21205 .36353 .22561 .3494 .21954 .31469 Mtetra
.69 .517 .648 r
.21954 .31469 .22561 .3494 .23968 .32948 .23327 .29817 Mtetra
.72 .546 .655 r
.23327 .29817 .23968 .32948 .25397 .30632 .24718 .27922 Mtetra
.737 .571 .668 r
.24718 .27922 .25397 .30632 .26816 .28329 .26101 .26055 Mtetra
.736 .592 .694 r
.26101 .26055 .26816 .28329 .28199 .26374 .27454 .24499 Mtetra
.704 .603 .741 r
.27454 .24499 .28199 .26374 .2953 .25048 .2876 .23504 Mtetra
.581 .579 .816 r
.2876 .23504 .2953 .25048 .30801 .24549 .30014 .23259 Mtetra
.183 .402 .841 r
.30014 .23259 .30801 .24549 .32018 .24951 .31217 .23845 Mtetra
0 0 .545 r
.31217 .23845 .32018 .24951 .33198 .26151 .32386 .25174 Mtetra
.679 .211 0 r
.32386 .25174 .33198 .26151 .3437 .27822 .33551 .26932 Mtetra
.666 .183 0 r
.33551 .26932 .3437 .27822 .3557 .29432 .34745 .28596 Mtetra
0 .162 .659 r
.34745 .28596 .3557 .29432 .36827 .30372 .36001 .29561 Mtetra
.53 .727 .964 r
.36001 .29561 .36827 .30372 .38155 .3019 .37332 .29375 Mtetra
.84 .806 .817 r
.37332 .29375 .38155 .3019 .39542 .2879 .38728 .27945 Mtetra
.901 .791 .729 r
.38728 .27945 .39542 .2879 .40962 .26478 .40159 .25581 Mtetra
.912 .779 .7 r
.40159 .25581 .40962 .26478 .42385 .23807 .41595 .22837 Mtetra
.902 .772 .709 r
.41595 .22837 .42385 .23807 .4379 .21337 .43011 .20275 Mtetra
.867 .762 .745 r
.43011 .20275 .4379 .21337 .4517 .19452 .44402 .18278 Mtetra
.794 .734 .797 r
.44402 .18278 .4517 .19452 .46529 .18312 .45769 .17002 Mtetra
.667 .667 .841 r
.45769 .17002 .46529 .18312 .47879 .17893 .47124 .16416 Mtetra
.509 .561 .844 r
.47124 .16416 .47879 .17893 .49229 .18074 .48477 .16396 Mtetra
.382 .457 .813 r
.48477 .16396 .49229 .18074 .5059 .18697 .49838 .16787 Mtetra
.318 .387 .775 r
.49838 .16787 .5059 .18697 .51967 .19609 .51213 .17438 Mtetra
.312 .354 .745 r
.51213 .17438 .51967 .19609 .53365 .20659 .52605 .18212 Mtetra
.344 .351 .723 r
.52605 .18212 .53365 .20659 .54784 .21699 .54017 .1898 Mtetra
.396 .366 .708 r
.54017 .1898 .54784 .21699 .56224 .22578 .55448 .19614 Mtetra
.456 .391 .696 r
.55448 .19614 .56224 .22578 .57679 .23156 .56892 .19997 Mtetra
.515 .42 .686 r
.56892 .19997 .57679 .23156 .59142 .23313 .58347 .20031 Mtetra
.57 .451 .678 r
.58347 .20031 .59142 .23313 .60607 .22972 .59804 .19651 Mtetra
.618 .48 .671 r
.59804 .19651 .60607 .22972 .62065 .2211 .61258 .18841 Mtetra
.659 .508 .668 r
.61258 .18841 .62065 .2211 .63509 .20765 .62703 .1763 Mtetra
.693 .534 .667 r
.62703 .1763 .63509 .20765 .64938 .19026 .64137 .16091 Mtetra
.721 .559 .669 r
.64137 .16091 .64938 .19026 .66349 .17016 .65558 .14326 Mtetra
.744 .583 .676 r
.65558 .14326 .66349 .17016 .67747 .14872 .66969 .12448 Mtetra
.761 .607 .687 r
.66969 .12448 .67747 .14872 .69136 .12723 .68374 .10561 Mtetra
.772 .63 .703 r
.68374 .10561 .69136 .12723 .70522 .10672 .69778 .08754 Mtetra
.778 .653 .725 r
.69778 .08754 .70522 .10672 .71913 .08792 .71186 .07088 Mtetra
0 0 .462 r
.04913 .30938 .05644 .32801 .06415 .35064 .05773 .32538 Mtetra
0 0 .476 r
.05773 .32538 .06415 .35064 .07154 .37731 .0661 .3443 Mtetra
.06 .079 .565 r
.0661 .3443 .07154 .37731 .07954 .40148 .07498 .36121 Mtetra
.361 .266 .611 r
.07498 .36121 .07954 .40148 .08914 .41566 .0851 .37053 Mtetra
.534 .381 .62 r
.0851 .37053 .08914 .41566 .10083 .41534 .09684 .36895 Mtetra
.623 .445 .621 r
.09684 .36895 .10083 .41534 .11428 .40187 .10995 .35747 Mtetra
.662 .477 .624 r
.10995 .35747 .11428 .40187 .12857 .38161 .12372 .34084 Mtetra
.669 .488 .632 r
.12372 .34084 .12857 .38161 .14269 .36215 .13739 .32471 Mtetra
.646 .479 .643 r
.13739 .32471 .14269 .36215 .1561 .34841 .15052 .31284 Mtetra
.606 .456 .652 r
.15052 .31284 .1561 .34841 .16877 .34113 .16309 .30582 Mtetra
.573 .434 .654 r
.16309 .30582 .16877 .34113 .18106 .33763 .17538 .30172 Mtetra
.572 .432 .652 r
.17538 .30172 .18106 .33763 .19343 .33395 .18772 .2976 Mtetra
.599 .449 .65 r
.18772 .2976 .19343 .33395 .20623 .32679 .20039 .29103 Mtetra
.635 .476 .65 r
.20039 .29103 .20623 .32679 .21954 .31469 .21345 .2809 Mtetra
.669 .505 .654 r
.21345 .2809 .21954 .31469 .23327 .29817 .22684 .2676 Mtetra
.694 .532 .663 r
.22684 .2676 .23327 .29817 .24718 .27922 .24037 .25258 Mtetra
.709 .556 .679 r
.24037 .25258 .24718 .27922 .26101 .26055 .25385 .23792 Mtetra
.705 .575 .706 r
.25385 .23792 .26101 .26055 .27454 .24499 .2671 .22584 Mtetra
.666 .58 .749 r
.2671 .22584 .27454 .24499 .2876 .23504 .27996 .21843 Mtetra
.542 .543 .806 r
.27996 .21843 .2876 .23504 .30014 .23259 .29239 .21733 Mtetra
.237 .388 .813 r
.29239 .21733 .30014 .23259 .31217 .23845 .30439 .22332 Mtetra
0 .126 .675 r
.30439 .22332 .31217 .23845 .32386 .25174 .3161 .23567 Mtetra
0 0 .57 r
.3161 .23567 .32386 .25174 .33551 .26932 .32779 .25161 Mtetra
0 .077 .635 r
.32779 .25161 .33551 .26932 .34745 .28596 .33979 .26646 Mtetra
.224 .322 .754 r
.33979 .26646 .34745 .28596 .36001 .29561 .35237 .27482 Mtetra
.564 .517 .761 r
.35237 .27482 .36001 .29561 .37332 .29375 .36568 .27263 Mtetra
.729 .605 .719 r
.36568 .27263 .37332 .29375 .38728 .27945 .37961 .25907 Mtetra
.801 .645 .689 r
.37961 .25907 .38728 .27945 .40159 .25581 .39391 .23695 Mtetra
.832 .668 .68 r
.39391 .23695 .40159 .25581 .41595 .22837 .40825 .21127 Mtetra
.837 .683 .692 r
.40825 .21127 .41595 .22837 .43011 .20275 .42244 .18711 Mtetra
.818 .69 .723 r
.42244 .18711 .43011 .20275 .44402 .18278 .43637 .16794 Mtetra
.767 .682 .769 r
.43637 .16794 .44402 .18278 .45769 .17002 .45008 .15516 Mtetra
.674 .643 .811 r
.45008 .15516 .45769 .17002 .47124 .16416 .46366 .1485 Mtetra
.555 .573 .827 r
.46366 .1485 .47124 .16416 .48477 .16396 .47722 .14679 Mtetra
.453 .494 .811 r
.47722 .14679 .48477 .16396 .49838 .16787 .49084 .14862 Mtetra
.397 .435 .783 r
.49084 .14862 .49838 .16787 .51213 .17438 .50457 .15268 Mtetra
.387 .402 .754 r
.50457 .15268 .51213 .17438 .52605 .18212 .51846 .15777 Mtetra
.406 .392 .731 r
.51846 .15777 .52605 .18212 .54017 .1898 .53252 .16282 Mtetra
.442 .397 .712 r
.53252 .16282 .54017 .1898 .55448 .19614 .54674 .16678 Mtetra
.486 .411 .698 r
.54674 .16678 .55448 .19614 .56892 .19997 .5611 .16872 Mtetra
.531 .431 .686 r
.5611 .16872 .56892 .19997 .58347 .20031 .57556 .16786 Mtetra
.574 .454 .678 r
.57556 .16786 .58347 .20031 .59804 .19651 .59006 .1637 Mtetra
.613 .478 .673 r
.59006 .1637 .59804 .19651 .61258 .18841 .60456 .15609 Mtetra
.647 .501 .671 r
.60456 .15609 .61258 .18841 .62703 .1763 .61901 .14528 Mtetra
.677 .525 .672 r
.61901 .14528 .62703 .1763 .64137 .16091 .63339 .13183 Mtetra
.703 .549 .676 r
.63339 .13183 .64137 .16091 .65558 .14326 .64769 .11656 Mtetra
.723 .572 .684 r
.64769 .11656 .65558 .14326 .66969 .12448 .66192 .10035 Mtetra
.739 .596 .697 r
.66192 .10035 .66969 .12448 .68374 .10561 .67612 .08406 Mtetra
.751 .62 .714 r
.67612 .08406 .68374 .10561 .69778 .08754 .69032 .06838 Mtetra
.757 .644 .736 r
.69032 .06838 .69778 .08754 .71186 .07088 .70457 .05382 Mtetra
.078 .214 .704 r
.04188 .29031 .04913 .30938 .05773 .32538 .05143 .29952 Mtetra
.15 .188 .646 r
.05143 .29952 .05773 .32538 .0661 .3443 .06084 .31063 Mtetra
.305 .248 .628 r
.06084 .31063 .0661 .3443 .07498 .36121 .07062 .32033 Mtetra
.445 .324 .621 r
.07062 .32033 .07498 .36121 .0851 .37053 .08127 .32498 Mtetra
.543 .385 .618 r
.08127 .32498 .0851 .37053 .09684 .36895 .09302 .32243 Mtetra
.602 .428 .618 r
.09302 .32243 .09684 .36895 .10995 .35747 .10572 .31338 Mtetra
.634 .456 .624 r
.10572 .31338 .10995 .35747 .12372 .34084 .11887 .30093 Mtetra
.641 .469 .635 r
.11887 .30093 .12372 .34084 .13739 .32471 .13199 .28882 Mtetra
.627 .469 .649 r
.13199 .28882 .13739 .32471 .15052 .31284 .14475 .27953 Mtetra
.6 .458 .66 r
.14475 .27953 .15052 .31284 .16309 .30582 .15715 .27344 Mtetra
.578 .447 .666 r
.15715 .27344 .16309 .30582 .17538 .30172 .16939 .26925 Mtetra
.579 .447 .666 r
.16939 .26925 .17538 .30172 .18772 .2976 .18169 .26497 Mtetra
.599 .461 .664 r
.18169 .26497 .18772 .2976 .20039 .29103 .19423 .25899 Mtetra
.628 .483 .665 r
.19423 .25899 .20039 .29103 .21345 .2809 .20707 .25057 Mtetra
.656 .507 .67 r
.20707 .25057 .21345 .2809 .22684 .2676 .22016 .23997 Mtetra
.678 .532 .68 r
.22016 .23997 .22684 .2676 .24037 .25258 .23337 .22824 Mtetra
.689 .556 .698 r
.23337 .22824 .24037 .25258 .25385 .23792 .24655 .21686 Mtetra
.683 .574 .726 r
.24655 .21686 .25385 .23792 .2671 .22584 .25957 .20746 Mtetra
.643 .576 .764 r
.25957 .20746 .2671 .22584 .27996 .21843 .2723 .20165 Mtetra
.534 .538 .805 r
.2723 .20165 .27996 .21843 .29239 .21733 .2847 .20076 Mtetra
.325 .421 .806 r
.2847 .20076 .29239 .21733 .30439 .22332 .29677 .20543 Mtetra
.105 .261 .741 r
.29677 .20543 .30439 .22332 .3161 .23567 .30863 .21507 Mtetra
.05 .188 .688 r
.30863 .21507 .3161 .23567 .32779 .25161 .32048 .22747 Mtetra
.182 .241 .689 r
.32048 .22747 .32779 .25161 .33979 .26646 .33261 .23881 Mtetra
.389 .352 .696 r
.33261 .23881 .33979 .26646 .35237 .27482 .34526 .24473 Mtetra
.559 .45 .687 r
.34526 .24473 .35237 .27482 .36568 .27263 .35854 .242 Mtetra
.668 .518 .672 r
.35854 .242 .36568 .27263 .37961 .25907 .37237 .22994 Mtetra
.732 .563 .664 r
.37237 .22994 .37961 .25907 .39391 .23695 .38653 .21083 Mtetra
.767 .596 .666 r
.38653 .21083 .39391 .23695 .40825 .21127 .40075 .18875 Mtetra
.781 .622 .683 r
.40075 .18875 .40825 .21127 .42244 .18711 .41485 .16783 Mtetra
.773 .64 .714 r
.41485 .16783 .42244 .18711 .43637 .16794 .42874 .15094 Mtetra
.737 .645 .757 r
.42874 .15094 .43637 .16794 .45008 .15516 .44245 .13923 Mtetra
.669 .627 .798 r
.44245 .13923 .45008 .15516 .46366 .1485 .45606 .13249 Mtetra
.58 .582 .819 r
.45606 .13249 .46366 .1485 .47722 .14679 .46964 .12976 Mtetra
.502 .526 .813 r
.46964 .12976 .47722 .14679 .49084 .14862 .48327 .12987 Mtetra
.457 .478 .792 r
.48327 .12987 .49084 .14862 .50457 .15268 .497 .13175 Mtetra
.445 .446 .766 r
.497 .13175 .50457 .15268 .51846 .15777 .51087 .13445 Mtetra
.456 .431 .743 r
.51087 .13445 .51846 .15777 .53252 .16282 .52489 .13709 Mtetra
.48 .429 .723 r
.52489 .13709 .53252 .16282 .54674 .16678 .53905 .1389 Mtetra
.512 .436 .707 r
.53905 .1389 .54674 .16678 .5611 .16872 .55333 .13912 Mtetra
.546 .448 .695 r
.55333 .13912 .5611 .16872 .57556 .16786 .56771 .13717 Mtetra
.58 .465 .687 r
.56771 .13717 .57556 .16786 .59006 .1637 .58216 .13267 Mtetra
.612 .484 .682 r
.58216 .13267 .59006 .1637 .60456 .15609 .59662 .1255 Mtetra
.641 .504 .68 r
.59662 .1255 .60456 .15609 .61901 .14528 .61107 .11586 Mtetra
.667 .525 .682 r
.61107 .11586 .61901 .14528 .63339 .13183 .62548 .10417 Mtetra
.689 .547 .688 r
.62548 .10417 .63339 .13183 .64769 .11656 .63985 .09106 Mtetra
.708 .57 .698 r
.63985 .09106 .64769 .11656 .66192 .10035 .65419 .0772 Mtetra
.722 .594 .712 r
.65419 .0772 .66192 .10035 .67612 .08406 .66852 .06326 Mtetra
.733 .618 .73 r
.66852 .06326 .67612 .08406 .69032 .06838 .68287 .04978 Mtetra
.739 .642 .752 r
.68287 .04978 .69032 .06838 .70457 .05382 .69726 .03715 Mtetra
.359 .42 .788 r
.03433 .27299 .04188 .29031 .05143 .29952 .04469 .27662 Mtetra
.37 .362 .72 r
.04469 .27662 .05143 .29952 .06084 .31063 .05499 .28135 Mtetra
.429 .357 .674 r
.05499 .28135 .06084 .31063 .07062 .32033 .06553 .28523 Mtetra
.498 .379 .648 r
.06553 .28523 .07062 .32033 .08127 .32498 .07662 .28615 Mtetra
.556 .409 .637 r
.07662 .28615 .08127 .32498 .09302 .32243 .08838 .2829 Mtetra
.596 .437 .636 r
.08838 .2829 .09302 .32243 .10572 .31338 .10072 .27588 Mtetra
.619 .459 .642 r
.10072 .27588 .10572 .31338 .11887 .30093 .11336 .26693 Mtetra
.626 .473 .655 r
.11336 .26693 .11887 .30093 .13199 .28882 .12598 .25822 Mtetra
.617 .479 .671 r
.12598 .25822 .13199 .28882 .14475 .27953 .13843 .25118 Mtetra
.599 .477 .685 r
.13843 .25118 .14475 .27953 .15715 .27344 .15068 .24599 Mtetra
.586 .474 .692 r
.15068 .24599 .15715 .27344 .16939 .26925 .16286 .24184 Mtetra
.589 .476 .693 r
.16286 .24184 .16939 .26925 .18169 .26497 .17512 .2375 Mtetra
.606 .487 .691 r
.17512 .2375 .18169 .26497 .19423 .25899 .18758 .23199 Mtetra
.629 .504 .692 r
.18758 .23199 .19423 .25899 .20707 .25057 .20025 .22487 Mtetra
.651 .525 .697 r
.20025 .22487 .20707 .25057 .22016 .23997 .21311 .21634 Mtetra
.668 .548 .708 r
.21311 .21634 .22016 .23997 .23337 .22824 .22607 .20711 Mtetra
.677 .57 .727 r
.22607 .20711 .23337 .22824 .24655 .21686 .23902 .19815 Mtetra
.67 .587 .753 r
.23902 .19815 .24655 .21686 .25957 .20746 .25188 .1906 Mtetra
.634 .589 .786 r
.25188 .1906 .25957 .20746 .2723 .20165 .26454 .18559 Mtetra
.549 .557 .815 r
.26454 .18559 .2723 .20165 .2847 .20076 .27698 .1841 Mtetra
.415 .474 .813 r
.27698 .1841 .2847 .20076 .29677 .20543 .2892 .1866 Mtetra
.294 .37 .771 r
.2892 .1866 .29677 .20543 .30863 .21507 .30127 .19267 Mtetra
.272 .315 .725 r
.30127 .19267 .30863 .21507 .32048 .22747 .31336 .20065 Mtetra
.348 .329 .696 r
.31336 .20065 .32048 .22747 .33261 .23881 .32569 .20776 Mtetra
.46 .379 .678 r
.32569 .20776 .33261 .23881 .34526 .24473 .33843 .2108 Mtetra
.561 .434 .665 r
.33843 .2108 .34526 .24473 .35854 .242 .35167 .20743 Mtetra
.636 .483 .657 r
.35167 .20743 .35854 .242 .37237 .22994 .36535 .19717 Mtetra
.688 .522 .657 r
.36535 .19717 .37237 .22994 .38653 .21083 .37931 .18169 Mtetra
.722 .556 .666 r
.37931 .18169 .38653 .21083 .40075 .18875 .39334 .16398 Mtetra
.738 .586 .686 r
.39334 .16398 .40075 .18875 .41485 .16783 .4073 .1471 Mtetra
.736 .611 .718 r
.4073 .1471 .41485 .16783 .42874 .15094 .42111 .13318 Mtetra
.711 .625 .76 r
.42111 .13318 .42874 .15094 .44245 .13923 .43479 .12311 Mtetra
.66 .621 .799 r
.43479 .12311 .44245 .13923 .45606 .13249 .4484 .11673 Mtetra
.596 .595 .821 r
.4484 .11673 .45606 .13249 .46964 .12976 .46201 .11334 Mtetra
.539 .556 .82 r
.46201 .11334 .46964 .12976 .48327 .12987 .47566 .11207 Mtetra
.504 .518 .804 r
.47566 .11207 .48327 .12987 .497 .13175 .4894 .11211 Mtetra
.492 .49 .782 r
.4894 .11211 .497 .13175 .51087 .13445 .50327 .11274 Mtetra
.498 .472 .759 r
.50327 .11274 .51087 .13445 .52489 .13709 .51726 .11332 Mtetra
.514 .465 .739 r
.51726 .11332 .52489 .13709 .53905 .1389 .53137 .11325 Mtetra
.536 .465 .723 r
.53137 .11325 .53905 .1389 .55333 .13912 .54561 .11199 Mtetra
.562 .472 .711 r
.54561 .11199 .55333 .13912 .56771 .13717 .55993 .1091 Mtetra
.588 .483 .702 r
.55993 .1091 .56771 .13717 .58216 .13267 .57433 .1043 Mtetra
.614 .498 .697 r
.57433 .1043 .58216 .13267 .59662 .1255 .58877 .09751 Mtetra
.638 .515 .696 r
.58877 .09751 .59662 .1255 .61107 .11586 .60321 .08886 Mtetra
.66 .534 .699 r
.60321 .08886 .61107 .11586 .62548 .10417 .61766 .07868 Mtetra
.68 .554 .706 r
.61766 .07868 .62548 .10417 .63985 .09106 .63209 .06742 Mtetra
.696 .576 .716 r
.63209 .06742 .63985 .09106 .65419 .0772 .64653 .05559 Mtetra
.709 .599 .731 r
.64653 .05559 .65419 .0772 .66852 .06326 .66097 .04368 Mtetra
.718 .622 .749 r
.66097 .04368 .66852 .06326 .68287 .04978 .67544 .0321 Mtetra
.723 .645 .771 r
.67544 .0321 .68287 .04978 .69726 .03715 .68996 .02114 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.9902 .57433 m
.98912 .5774 L
.97162 .6032 L
.9644 .60942 L
.9386 .62034 L
.9128 .62003 L
.887 .60818 L
.88051 .6032 L
.86331 .5774 L
.8612 .5684 L
.85954 .5516 L
.8612 .53911 L
.8648 .5258 L
.88656 .5 L
.887 .49971 L
.9128 .48762 L
.9386 .4873 L
.9644 .49847 L
.96639 .5 L
.98732 .5258 L
.9902 .53318 L
s
.4742 .02903 m
.5 .01628 L
.5258 .01587 L
.5516 .0275 L
.56172 .0356 L
.57481 .0614 L
.57564 .0872 L
.56597 .113 L
.5516 .12798 L
.5258 .13804 L
.5 .13775 L
.4742 .1264 L
.46204 .113 L
.45181 .0872 L
.45271 .0614 L
.46638 .0356 L
.4742 .02903 L
s
.8354 .74981 m
.8612 .74936 L
.887 .7571 L
.88915 .758 L
.9128 .77513 L
.91997 .7838 L
.93324 .8096 L
.93715 .8354 L
.93364 .8612 L
.92099 .887 L
.9128 .89711 L
.89221 .9128 L
.887 .91508 L
.8612 .92281 L
.8354 .92236 L
.8096 .91355 L
.80799 .9128 L
.7838 .89365 L
.77873 .887 L
.7659 .8612 L
.76232 .8354 L
.76631 .8096 L
.77975 .7838 L
.7838 .77861 L
.8096 .75855 L
.8108 .758 L
.8354 .74981 L
s
.0872 .6718 m
.113 .66385 L
.1388 .66297 L
.1646 .6689 L
.18766 .6806 L
.1904 .68317 L
.21245 .7064 L
.2162 .71038 L
.22504 .7322 L
.22981 .758 L
.22778 .7838 L
.21841 .8096 L
.2162 .81394 L
.19944 .8354 L
.1904 .84307 L
.1646 .8573 L
.15092 .8612 L
.1388 .86312 L
.113 .86222 L
.10777 .8612 L
.0872 .8545 L
.0614 .83713 L
.05955 .8354 L
.04012 .8096 L
.0356 .79914 L
.03132 .7838 L
.02942 .758 L
.03389 .7322 L
.0356 .72548 L
.04614 .7064 L
.0614 .68867 L
.07089 .6806 L
.0872 .6718 L
s
.2162 .08356 m
.242 .07401 L
.2678 .07408 L
.2936 .08382 L
.29945 .0872 L
.3194 .10816 L
.32191 .113 L
.33086 .1388 L
.33027 .1646 L
.31982 .1904 L
.3194 .19114 L
.2936 .21605 L
.29327 .2162 L
.2678 .22581 L
.242 .22589 L
.2162 .21627 L
.21607 .2162 L
.1904 .19193 L
.18953 .1904 L
.17909 .1646 L
.17849 .1388 L
.18744 .113 L
.1904 .10736 L
.20983 .0872 L
.2162 .08356 L
s
.7838 .08234 m
.8096 .07335 L
.8354 .07139 L
.8612 .07597 L
.88608 .0872 L
.887 .08822 L
.9128 .11222 L
.91338 .113 L
.92766 .1388 L
.93364 .1646 L
.93307 .1904 L
.9258 .2162 L
.9128 .23883 L
.90992 .242 L
.887 .26233 L
.88 .2678 L
.8612 .27434 L
.8354 .27896 L
.8096 .27699 L
.7838 .26795 L
.78348 .2678 L
.758 .24989 L
.7507 .242 L
.73488 .2162 L
.7322 .20899 L
.72759 .1904 L
.72701 .1646 L
.7322 .14138 L
.73309 .1388 L
.74697 .113 L
.758 .10034 L
.77451 .0872 L
.7838 .08234 L
s
.0614 .05682 m
.0872 .04559 L
.113 .04811 L
.13307 .0614 L
.1388 .06759 L
.14989 .0872 L
.15111 .113 L
.1388 .13758 L
.1378 .1388 L
.113 .15753 L
.0872 .15973 L
.0614 .14937 L
.04977 .1388 L
.03829 .113 L
.03916 .0872 L
.05536 .0614 L
.0614 .05682 L
s
.0872 .3106 m
.113 .31178 L
.13165 .3194 L
.1388 .32278 L
.15875 .3452 L
.1646 .36149 L
.16665 .371 L
.1653 .3968 L
.1646 .39937 L
.15438 .4226 L
.1388 .43804 L
.11441 .4484 L
.113 .44876 L
.0872 .44994 L
.07971 .4484 L
.0614 .4419 L
.03962 .4226 L
.0356 .41426 L
.03129 .3968 L
.03048 .371 L
.0356 .3466 L
.03615 .3452 L
.0614 .31982 L
.06246 .3194 L
.0872 .3106 L
s
.5 .44074 m
.5258 .44164 L
.5407 .4484 L
.5516 .45678 L
.5652 .4742 L
.57029 .5 L
.56342 .5258 L
.5516 .54403 L
.53395 .5516 L
.5258 .55462 L
.5 .55553 L
.48812 .5516 L
.4742 .54705 L
.45814 .5258 L
.45191 .5 L
.45649 .4742 L
.4742 .45344 L
.48137 .4484 L
.5 .44074 L
s
.5774 .84952 m
.6032 .84826 L
.629 .8602 L
.63042 .8612 L
.65042 .887 L
.65328 .9128 L
.64637 .9386 L
.629 .95872 L
.61309 .9644 L
.6032 .96557 L
.5774 .96504 L
.57305 .9644 L
.5516 .95419 L
.5405 .9386 L
.53236 .9128 L
.53584 .887 L
.5516 .86502 L
.55598 .8612 L
.5774 .84952 L
s
.2936 .85897 m
.3194 .84187 L
.3452 .84024 L
.371 .85072 L
.38276 .8612 L
.39464 .887 L
.39449 .9128 L
.38185 .9386 L
.371 .94798 L
.3452 .95866 L
.3194 .95698 L
.2936 .93972 L
.2926 .9386 L
.27809 .9128 L
.27788 .887 L
.29168 .8612 L
.2936 .85897 L
s
0 g
.03 w
.92651 .55375 Mdot
.51386 .0768 Mdot
.8498 .83607 Mdot
.12934 .76312 Mdot
.25468 .14999 Mdot
.8303 .17519 Mdot
.09483 .10258 Mdot
.09706 .38043 Mdot
.51104 .49828 Mdot
.59307 .90807 Mdot
.33637 .89944 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.57843 .89018 m
.59804 .88452 L
.61242 .89216 L
.61765 .90223 L
.618 .91176 L
.61765 .91292 L
.59804 .93097 L
.57843 .9255 L
.57067 .91176 L
.57642 .89216 L
.57843 .89018 L
s
.32353 .8736 m
.34314 .87447 L
.35834 .89216 L
.35505 .91176 L
.34314 .92118 L
.32353 .92038 L
.31285 .91176 L
.30785 .89216 L
.32353 .8736 L
s
.93137 .5389 m
.93219 .53922 L
.94147 .55882 L
.93137 .56943 L
.91176 .56089 L
.91099 .55882 L
.91176 .54798 L
.92087 .53922 L
.93137 .5389 L
s
.59804 .87127 m
.60463 .87255 L
.61765 .87878 L
.63022 .89216 L
.63285 .91176 L
.62352 .93137 L
.61765 .93695 L
.59804 .9455 L
.57843 .94253 L
.56591 .93137 L
.55882 .91843 L
.55731 .91176 L
.55882 .89749 L
.56087 .89216 L
.57843 .87488 L
.58497 .87255 L
.59804 .87127 L
s
.30392 .86959 m
.32353 .85885 L
.34314 .8601 L
.36119 .87255 L
.36275 .87433 L
.3718 .89216 L
.36983 .91176 L
.36275 .92224 L
.35078 .93137 L
.34314 .93433 L
.32353 .93365 L
.31804 .93137 L
.30392 .92057 L
.29764 .91176 L
.29358 .89216 L
.30155 .87255 L
.30392 .86959 L
s
.83333 .79872 m
.85294 .79599 L
.87255 .80221 L
.88376 .81373 L
.88986 .83333 L
.88681 .85294 L
.87255 .86747 L
.86292 .87255 L
.85294 .87493 L
.8365 .87255 L
.83333 .87126 L
.81469 .85294 L
.81373 .85076 L
.81073 .83333 L
.81373 .82158 L
.818 .81373 L
.83333 .79872 L
s
.93137 .5192 m
.9334 .51961 L
.95098 .52916 L
.9594 .53922 L
.96249 .55882 L
.95201 .57843 L
.95098 .57953 L
.93137 .59103 L
.91176 .5884 L
.90039 .57843 L
.89216 .56225 L
.89149 .55882 L
.89216 .54685 L
.89468 .53922 L
.91176 .5221 L
.9195 .51961 L
.93137 .5192 L
s
.5 .48758 m
.51961 .48547 L
.52635 .5 L
.51961 .51103 L
.5 .50897 L
.49569 .5 L
.5 .48758 L
s
.81373 .14353 m
.83333 .13903 L
.85155 .14706 L
.85294 .14817 L
.86677 .16667 L
.86606 .18627 L
.85294 .20219 L
.8476 .20588 L
.83333 .21089 L
.81373 .20637 L
.81296 .20588 L
.79684 .18627 L
.79609 .16667 L
.80906 .14706 L
.81373 .14353 L
s
.10784 .09188 m
.12416 .10784 L
.10784 .12049 L
.08993 .10784 L
.10784 .09188 L
s
.57843 .86323 m
.59804 .86046 L
.61765 .86568 L
.62913 .87255 L
.63725 .88413 L
.64104 .89216 L
.64302 .91176 L
.63725 .92892 L
.63619 .93137 L
.61765 .94914 L
.61235 .95098 L
.59804 .95458 L
.57843 .95215 L
.57549 .95098 L
.55882 .94086 L
.55269 .93137 L
.54647 .91176 L
.54908 .89216 L
.55882 .87667 L
.56305 .87255 L
.57843 .86323 L
s
.32353 .8489 m
.34314 .85047 L
.35016 .85294 L
.36275 .85921 L
.37466 .87255 L
.38149 .89216 L
.38025 .91176 L
.36896 .93137 L
.36275 .93645 L
.34314 .94485 L
.32353 .9443 L
.30392 .93486 L
.29966 .93137 L
.28625 .91176 L
.28431 .90518 L
.2826 .89216 L
.28431 .88017 L
.28693 .87255 L
.30392 .85459 L
.30844 .85294 L
.32353 .8489 L
s
.81373 .79053 m
.83333 .78014 L
.85294 .77779 L
.87255 .78221 L
.89086 .79412 L
.89216 .79542 L
.90355 .81373 L
.9078 .83333 L
.90541 .85294 L
.89484 .87255 L
.89216 .87571 L
.87255 .8895 L
.86395 .89216 L
.85294 .89389 L
.83542 .89216 L
.83333 .89165 L
.81373 .88202 L
.80404 .87255 L
.79412 .85325 L
.79402 .85294 L
.79163 .83333 L
.79412 .81961 L
.79606 .81373 L
.80951 .79412 L
.81373 .79053 L
s
.12745 .75386 m
.13399 .7549 L
.12745 .77249 L
.12475 .7549 L
.12745 .75386 L
s
.91176 .50746 m
.93137 .50552 L
.95098 .51208 L
.96158 .51961 L
.97059 .53523 L
.97165 .53922 L
.97311 .55882 L
.97059 .57295 L
.9686 .57843 L
.95098 .59668 L
.94772 .59804 L
.93137 .60339 L
.91176 .60168 L
.90346 .59804 L
.89216 .59098 L
.88365 .57843 L
.87795 .55882 L
.88013 .53922 L
.89216 .52004 L
.89258 .51961 L
.91176 .50746 L
s
.5 .46374 m
.51961 .46317 L
.53819 .48039 L
.53922 .48209 L
.54407 .5 L
.53922 .51436 L
.53551 .51961 L
.51961 .5319 L
.5 .53111 L
.48658 .51961 L
.48039 .50887 L
.47838 .5 L
.48039 .48769 L
.48394 .48039 L
.5 .46374 L
s
.79412 .12469 m
.81373 .11519 L
.83333 .11305 L
.85294 .11721 L
.87102 .12745 L
.87255 .12927 L
.88589 .14706 L
.89177 .16667 L
.89139 .18627 L
.88453 .20588 L
.87255 .22129 L
.86861 .22549 L
.85294 .23312 L
.83333 .23733 L
.81373 .23516 L
.79412 .22559 L
.79398 .22549 L
.7762 .20588 L
.77451 .20231 L
.76915 .18627 L
.76873 .16667 L
.77451 .14803 L
.77494 .14706 L
.79038 .12745 L
.79412 .12469 L
s
.22549 .11227 m
.2451 .11048 L
.26471 .11338 L
.28104 .12745 L
.28431 .13222 L
.28941 .14706 L
.28477 .16667 L
.28431 .16738 L
.26471 .1833 L
.2451 .1847 L
.22549 .17899 L
.21415 .16667 L
.20588 .15313 L
.20367 .14706 L
.20588 .1288 L
.20702 .12745 L
.22549 .11227 L
s
.08824 .07706 m
.10784 .07049 L
.12745 .07793 L
.13927 .08824 L
.14706 .09767 L
.15188 .10784 L
.15036 .12745 L
.14706 .13 L
.12745 .14136 L
.10784 .14106 L
.08824 .13411 L
.07835 .12745 L
.07068 .10784 L
.07513 .08824 L
.08824 .07706 L
s
.59804 .85113 m
.61039 .85294 L
.61765 .85503 L
.63725 .86691 L
.64232 .87255 L
.65251 .89216 L
.65375 .91176 L
.64754 .93137 L
.63725 .94659 L
.63247 .95098 L
.61765 .95934 L
.59804 .96421 L
.57843 .96228 L
.55882 .95235 L
.55706 .95098 L
.54195 .93137 L
.53922 .92354 L
.53707 .91176 L
.53922 .89226 L
.53924 .89216 L
.5493 .87255 L
.55882 .86322 L
.57843 .85349 L
.58065 .85294 L
.59804 .85113 L
s
.30392 .84241 m
.32353 .83854 L
.34314 .84044 L
.36275 .84873 L
.36908 .85294 L
.38235 .8675 L
.38486 .87255 L
.39096 .89216 L
.3898 .91176 L
.38235 .92886 L
.38089 .93137 L
.36275 .94751 L
.35453 .95098 L
.34314 .95393 L
.32353 .95346 L
.31467 .95098 L
.30392 .94623 L
.28665 .93137 L
.28431 .93025 L
.27546 .91176 L
.2713 .89216 L
.27384 .87255 L
.28431 .85419 L
.28623 .85294 L
.30392 .84241 L
s
.81373 .77143 m
.83333 .76365 L
.85294 .76163 L
.87255 .76504 L
.89181 .77451 L
.89216 .77493 L
.91084 .79412 L
.91176 .79497 L
.92027 .81373 L
.92362 .83333 L
.9217 .85294 L
.91397 .87255 L
.91176 .8764 L
.89798 .89216 L
.89216 .89656 L
.87255 .90635 L
.85294 .90984 L
.83333 .90811 L
.81373 .90074 L
.80086 .89216 L
.79412 .88573 L
.78468 .87255 L
.77699 .85294 L
.77534 .83333 L
.77902 .81373 L
.78883 .79412 L
.79412 .7872 L
.80847 .77451 L
.81373 .77143 L
s
.10784 .71404 m
.12745 .70944 L
.14706 .71249 L
.15415 .71569 L
.16667 .72354 L
.17569 .73529 L
.18296 .7549 L
.18288 .77451 L
.17493 .79412 L
.16667 .80391 L
.14845 .81373 L
.14706 .81421 L
.12745 .81688 L
.11176 .81373 L
.10784 .81243 L
.08824 .79784 L
.08556 .79412 L
.0767 .77451 L
.07612 .7549 L
.08338 .73529 L
.08824 .72783 L
.10326 .71569 L
.10784 .71404 L
s
.91176 .49571 m
.93137 .49414 L
.95098 .49941 L
.95251 .5 L
.97059 .51354 L
.97375 .51961 L
.9814 .53922 L
.98339 .55882 L
.97827 .57843 L
.97059 .59543 L
.96807 .59804 L
.95098 .60985 L
.93137 .61564 L
.91176 .61456 L
.89216 .60561 L
.88317 .59804 L
.87255 .58231 L
.87119 .57843 L
.86672 .55882 L
.86857 .53922 L
.87255 .52836 L
.8772 .51961 L
.89216 .50449 L
.90029 .5 L
.91176 .49571 L
s
.5 .45489 m
.51961 .45431 L
.53508 .46078 L
.53922 .46155 L
.55262 .48039 L
.556 .5 L
.55098 .51961 L
.53922 .53478 L
.52846 .53922 L
.51961 .54208 L
.5 .54151 L
.49357 .53922 L
.48039 .53286 L
.47132 .51961 L
.46604 .5 L
.46963 .48039 L
.48039 .46259 L
.48707 .46078 L
.5 .45489 L
s
.06863 .36113 m
.08824 .34681 L
.10784 .34694 L
.12742 .36275 L
.12745 .36281 L
.13225 .38235 L
.12745 .39683 L
.12405 .40196 L
.10784 .41555 L
.08824 .41609 L
.07028 .40196 L
.06863 .39968 L
.06207 .38235 L
.06744 .36275 L
.06863 .36113 L
s
.79412 .10093 m
.81373 .09427 L
.83333 .09266 L
.85294 .09575 L
.87255 .10424 L
.87829 .10784 L
.89216 .12033 L
.89771 .12745 L
.90795 .14706 L
.91176 .16194 L
.9124 .16667 L
.9121 .18627 L
.91176 .18846 L
.90698 .20588 L
.8958 .22549 L
.89216 .22997 L
.87428 .2451 L
.87255 .24611 L
.85294 .25462 L
.83333 .25773 L
.81373 .2561 L
.79412 .24942 L
.7859 .2451 L
.77451 .23621 L
.76472 .22549 L
.7549 .20921 L
.75366 .20588 L
.74845 .18627 L
.74813 .16667 L
.75264 .14706 L
.7549 .1406 L
.7628 .12745 L
.77451 .11413 L
.78203 .10784 L
.79412 .10093 L
s
.08824 .06353 m
.10784 .06157 L
.12745 .06649 L
.13293 .06863 L
.14706 .07554 L
.16312 .08824 L
.16667 .09038 L
.18627 .09733 L
.20588 .09863 L
.22549 .09583 L
.2451 .09428 L
.26471 .09664 L
.28431 .10574 L
.28726 .10784 L
.30277 .12745 L
.30392 .13049 L
.30759 .14706 L
.30484 .16667 L
.30392 .16909 L
.29378 .18627 L
.28431 .19419 L
.26471 .20248 L
.2451 .20324 L
.22549 .19752 L
.20782 .18627 L
.20588 .18485 L
.18627 .16688 L
.18607 .16667 L
.16667 .15597 L
.14706 .15284 L
.12745 .15322 L
.10784 .15203 L
.08964 .14706 L
.08824 .14665 L
.06863 .13342 L
.06473 .12745 L
.05742 .10784 L
.06019 .08824 L
.06863 .07587 L
.07752 .06863 L
.08824 .06353 L
s
.55882 .85213 m
.57843 .84379 L
.59804 .84164 L
.61765 .84482 L
.63611 .85294 L
.63725 .85389 L
.65627 .87255 L
.65686 .87347 L
.66407 .89216 L
.66465 .91176 L
.65884 .93137 L
.65686 .93607 L
.64551 .95098 L
.63725 .95852 L
.61765 .96937 L
.61388 .97059 L
.59804 .97343 L
.57843 .9718 L
.57397 .97059 L
.55882 .96385 L
.54347 .95098 L
.53922 .94663 L
.5318 .93137 L
.52748 .91176 L
.52936 .89216 L
.53796 .87255 L
.53922 .87056 L
.55748 .85294 L
.55882 .85213 L
s
.30392 .83021 m
.32353 .8282 L
.34314 .83058 L
.35225 .83333 L
.36275 .83796 L
.38218 .85294 L
.38235 .85311 L
.39515 .87255 L
.40038 .89216 L
.39941 .91176 L
.39183 .93137 L
.38235 .94415 L
.37483 .95098 L
.36275 .9576 L
.34314 .96319 L
.32353 .96278 L
.30392 .95646 L
.29399 .95098 L
.28431 .94288 L
.27468 .93137 L
.26471 .91358 L
.26416 .91176 L
.25942 .89216 L
.25973 .87255 L
.26471 .85655 L
.26697 .85294 L
.28431 .83737 L
.29175 .83333 L
.30392 .83021 L
s
.81373 .75453 m
.83333 .74802 L
.85294 .74609 L
.87255 .74873 L
.89045 .7549 L
.89216 .75656 L
.91176 .77149 L
.91465 .77451 L
.92831 .79412 L
.93137 .7986 L
.93578 .81373 L
.93854 .83333 L
.93695 .85294 L
.93137 .87104 L
.93072 .87255 L
.91865 .89216 L
.91176 .89971 L
.89633 .91176 L
.89216 .91408 L
.87255 .92188 L
.85294 .9248 L
.83333 .92335 L
.81373 .91737 L
.80236 .91176 L
.79412 .90597 L
.77948 .89216 L
.77451 .88624 L
.76688 .87255 L
.76067 .85294 L
.75963 .83333 L
.76309 .81373 L
.77122 .79412 L
.77451 .7884 L
.78556 .77451 L
.79412 .76667 L
.81286 .7549 L
.81373 .75453 L
s
.10784 .68806 m
.12745 .68506 L
.14706 .68707 L
.16667 .69458 L
.16947 .69608 L
.18627 .70954 L
.19147 .71569 L
.20265 .73529 L
.20588 .74519 L
.20794 .7549 L
.20878 .77451 L
.20588 .79113 L
.20496 .79412 L
.19406 .81373 L
.18627 .82174 L
.16762 .83333 L
.16667 .83374 L
.14706 .83991 L
.12745 .8414 L
.10784 .83822 L
.09303 .83333 L
.08824 .82955 L
.06988 .81373 L
.06863 .81236 L
.05766 .79412 L
.05212 .77451 L
.05172 .7549 L
.05638 .73529 L
.06738 .71569 L
.06863 .71407 L
.08824 .69678 L
.0888 .69608 L
.10784 .68806 L
s
.48039 .45195 m
.5 .44394 L
.51961 .4435 L
.53922 .45035 L
.55254 .46078 L
.55882 .46601 L
.56348 .48039 L
.56641 .5 L
.56213 .51961 L
.55882 .52811 L
.54908 .53922 L
.53922 .54605 L
.51961 .55306 L
.5 .55263 L
.48039 .54449 L
.47326 .53922 L
.46078 .52211 L
.45997 .51961 L
.45571 .5 L
.45867 .48039 L
.46078 .47206 L
.46975 .46078 L
.48039 .45195 L
s
.06863 .3357 m
.08824 .32769 L
.10784 .32744 L
.12745 .33522 L
.13704 .34314 L
.14706 .36142 L
.14751 .36275 L
.15003 .38235 L
.14706 .39715 L
.14543 .40196 L
.13042 .42157 L
.12745 .42366 L
.10784 .43243 L
.08824 .43276 L
.06863 .42491 L
.06361 .42157 L
.04918 .40196 L
.04902 .40151 L
.0446 .38235 L
.04768 .36275 L
.04902 .35947 L
.05916 .34314 L
.06863 .3357 L
s
.79412 .08059 m
.81373 .07528 L
.83333 .07396 L
.85294 .07648 L
.87255 .08315 L
.88252 .08824 L
.89216 .09497 L
.90598 .10784 L
.91176 .11485 L
.91962 .12745 L
.92758 .14706 L
.9312 .16667 L
.93095 .18627 L
.92681 .20588 L
.9182 .22549 L
.91176 .23551 L
.90364 .2451 L
.89216 .25541 L
.87789 .26471 L
.87255 .26723 L
.85294 .27391 L
.83333 .27642 L
.81373 .2751 L
.79412 .26977 L
.78244 .26471 L
.77451 .25973 L
.757 .2451 L
.7549 .24285 L
.74238 .22549 L
.73529 .21084 L
.73378 .20588 L
.72959 .18627 L
.7293 .16667 L
.7329 .14706 L
.73529 .13875 L
.74086 .12745 L
.75461 .10784 L
.7549 .10751 L
.77451 .09064 L
.77805 .08824 L
.79412 .08059 L
s
.5 .05555 m
.51961 .05185 L
.53922 .06778 L
.53964 .06863 L
.53922 .08734 L
.53883 .08824 L
.51961 .10276 L
.5 .09903 L
.4903 .08824 L
.48941 .06863 L
.5 .05555 L
s
.06863 .06085 m
.08824 .05234 L
.10784 .05092 L
.12745 .05466 L
.14706 .0627 L
.15806 .06863 L
.16667 .0723 L
.18627 .07959 L
.20588 .08149 L
.22549 .0802 L
.2451 .07932 L
.26471 .08133 L
.28431 .08806 L
.28469 .08824 L
.30392 .10208 L
.30887 .10784 L
.31963 .12745 L
.32325 .14706 L
.32111 .16667 L
.31268 .18627 L
.30392 .19773 L
.29473 .20588 L
.28431 .21172 L
.26471 .21808 L
.2451 .2188 L
.22549 .21427 L
.20811 .20588 L
.20588 .20424 L
.18627 .18959 L
.18212 .18627 L
.16667 .17619 L
.14706 .16915 L
.12992 .16667 L
.12745 .1664 L
.10784 .16381 L
.08824 .15848 L
.06863 .14734 L
.06826 .14706 L
.05205 .12745 L
.04902 .11955 L
.0466 .10784 L
.04873 .08824 L
.04902 .08736 L
.05959 .06863 L
.06863 .06085 L
s
.9902 .58567 m
.97962 .59804 L
.97059 .61041 L
.96159 .61765 L
.95098 .62245 L
.93137 .62776 L
.91176 .62718 L
.89216 .62002 L
.88786 .61765 L
.87255 .6033 L
.8687 .59804 L
.85921 .57843 L
.85565 .55882 L
.85722 .53922 L
.86447 .51961 L
.87255 .50739 L
.87972 .5 L
.89216 .49147 L
.91176 .48413 L
.93137 .48288 L
.95098 .48727 L
.97059 .49863 L
.97174 .5 L
.98667 .51961 L
.9902 .52383 L
s
.59804 .83186 m
.61285 .83333 L
.61765 .83433 L
.63725 .84141 L
.6552 .85294 L
.65686 .8542 L
.67165 .87255 L
.67647 .88242 L
.67871 .89216 L
.67728 .91176 L
.67647 .91752 L
.67115 .93137 L
.65893 .95098 L
.65686 .95358 L
.63725 .97043 L
.63707 .97059 L
.61765 .97945 L
.59804 .98302 L
.57843 .98157 L
.55882 .97474 L
.55121 .97059 L
.53922 .96057 L
.53131 .95098 L
.52121 .93137 L
.51961 .92602 L
.51753 .91176 L
.51905 .89216 L
.51961 .88968 L
.52652 .87255 L
.53922 .85535 L
.54172 .85294 L
.55882 .841 L
.57843 .83383 L
.5809 .83333 L
.59804 .83186 L
s
.83333 .73193 m
.85294 .7298 L
.87255 .73162 L
.88932 .73529 L
.89216 .73799 L
.91176 .75039 L
.91721 .7549 L
.93137 .77057 L
.9342 .77451 L
.945 .79412 L
.95098 .81213 L
.95124 .81373 L
.95357 .83333 L
.95222 .85294 L
.95098 .85921 L
.94698 .87255 L
.93715 .89216 L
.93137 .90036 L
.92089 .91176 L
.91176 .91936 L
.89216 .93084 L
.89144 .93137 L
.87255 .93734 L
.85294 .93982 L
.83333 .93859 L
.81373 .93357 L
.80771 .93137 L
.79412 .92433 L
.77667 .91176 L
.77451 .90989 L
.75855 .89216 L
.7549 .88757 L
.74835 .87255 L
.74306 .85294 L
.743 .83333 L
.74677 .81373 L
.75409 .79412 L
.7549 .79236 L
.76591 .77451 L
.77451 .7643 L
.78465 .7549 L
.79412 .74807 L
.81373 .73783 L
.81746 .73529 L
.83333 .73193 L
s
.08824 .67235 m
.10784 .6658 L
.12745 .66347 L
.14706 .66505 L
.16667 .67073 L
.17898 .67647 L
.18627 .68132 L
.20313 .69608 L
.20588 .69918 L
.2172 .71569 L
.22549 .73445 L
.22575 .73529 L
.23068 .7549 L
.2331 .77451 L
.23384 .79412 L
.23135 .81373 L
.22623 .83333 L
.2451 .83338 L
.24557 .83333 L
.26471 .82478 L
.28431 .81968 L
.30392 .81697 L
.32353 .81694 L
.34314 .82008 L
.36275 .82715 L
.3741 .83333 L
.38235 .83982 L
.39466 .85294 L
.40196 .86341 L
.40548 .87255 L
.41004 .89216 L
.4092 .91176 L
.40281 .93137 L
.40196 .93325 L
.38866 .95098 L
.38235 .95659 L
.36275 .9679 L
.35445 .97059 L
.34314 .97273 L
.32353 .97237 L
.31488 .97059 L
.30392 .96691 L
.28431 .95549 L
.2789 .95098 L
.26471 .93533 L
.26214 .93137 L
.25168 .91176 L
.2451 .8944 L
.24476 .89216 L
.24252 .87255 L
Mistroke
.23875 .85294 L
.22549 .83387 L
.20588 .84413 L
.18627 .85202 L
.18362 .85294 L
.16667 .85827 L
.14706 .86214 L
.12745 .86304 L
.10784 .86048 L
.08824 .85387 L
.08613 .85294 L
.06863 .84214 L
.0586 .83333 L
.04902 .8222 L
.04353 .81373 L
.03466 .79412 L
.03038 .77451 L
.03007 .7549 L
.03368 .73529 L
.04173 .71569 L
.04902 .70399 L
.05558 .69608 L
.06863 .68408 L
.07982 .67647 L
.08824 .67235 L
Mfstroke
.48039 .43995 m
.5 .43333 L
.51961 .43294 L
.53922 .43865 L
.54467 .44118 L
.55882 .45253 L
.56537 .46078 L
.57454 .48039 L
.57694 .5 L
.57343 .51961 L
.56271 .53922 L
.55882 .54378 L
.53922 .55786 L
.537 .55882 L
.51961 .56357 L
.5 .56321 L
.48506 .55882 L
.48039 .55668 L
.46078 .54099 L
.45936 .53922 L
.44865 .51961 L
.44515 .5 L
.4476 .48039 L
.45683 .46078 L
.46078 .45545 L
.47792 .44118 L
.48039 .43995 L
s
.06863 .318 m
.08824 .31164 L
.10784 .31096 L
.12745 .31618 L
.14066 .32353 L
.14706 .32977 L
.15676 .34314 L
.16409 .36275 L
.16568 .38235 L
.16198 .40196 L
.1517 .42157 L
.14706 .42726 L
.12911 .44118 L
.12745 .44194 L
.10784 .44833 L
.08824 .44856 L
.06863 .44275 L
.06505 .44118 L
.04902 .4291 L
.04263 .42157 L
.03249 .40196 L
.02941 .38672 L
.02914 .38235 L
.02941 .3744 L
.03141 .36275 L
.04006 .34314 L
.04902 .33178 L
.05846 .32353 L
.06863 .318 L
s
.79412 .061 m
.81373 .05656 L
.83333 .05545 L
.85294 .05757 L
.87255 .06311 L
.88531 .06863 L
.89216 .0726 L
.91176 .08737 L
.91269 .08824 L
.92937 .10784 L
.93137 .1108 L
.94016 .12745 L
.94673 .14706 L
.94978 .16667 L
.94957 .18627 L
.94608 .20588 L
.93901 .22549 L
.93137 .23962 L
.92758 .2451 L
.91176 .26303 L
.90994 .26471 L
.89216 .27781 L
.8801 .28431 L
.87255 .28732 L
.85294 .29285 L
.83333 .29496 L
.81373 .29383 L
.79412 .28938 L
.78042 .28431 L
.77451 .2812 L
.7549 .26827 L
.75068 .26471 L
.73529 .24818 L
.73302 .2451 L
.72156 .22549 L
.71569 .21075 L
.71444 .20588 L
.71088 .18627 L
.71056 .16667 L
.71352 .14706 L
.71569 .13799 L
.72007 .12745 L
.73097 .10784 L
.73529 .10187 L
.74774 .08824 L
.7549 .08201 L
.77451 .06917 L
.77545 .06863 L
.79412 .061 L
s
.48039 .04438 m
.5 .03255 L
.51961 .03089 L
.53922 .03689 L
.55342 .04902 L
.55882 .05987 L
.56182 .06863 L
.56181 .08824 L
.55882 .09671 L
.5528 .10784 L
.53922 .11831 L
.51961 .12402 L
.5 .12218 L
.48039 .11061 L
.47779 .10784 L
.46716 .08824 L
.46699 .06863 L
.47646 .04902 L
.48039 .04438 L
s
.06863 .04862 m
.08824 .0417 L
.10784 .04046 L
.12745 .04363 L
.14451 .04902 L
.14706 .05011 L
.16667 .05796 L
.18627 .06401 L
.20588 .06605 L
.22549 .06542 L
.2451 .0649 L
.26471 .06661 L
.27743 .06863 L
.28431 .07202 L
.30392 .0827 L
.31088 .08824 L
.32353 .1021 L
.32714 .10784 L
.3356 .12745 L
.33847 .14706 L
.33649 .16667 L
.32956 .18627 L
.32353 .19695 L
.31624 .20588 L
.30392 .21698 L
.29019 .22549 L
.28431 .22782 L
.26471 .23312 L
.2451 .23397 L
.22549 .23055 L
.21092 .22549 L
.20588 .22251 L
.18627 .20971 L
.18111 .20588 L
.16667 .19545 L
.14922 .18627 L
.14706 .18543 L
.12745 .17987 L
.10784 .17568 L
.08824 .17006 L
.0793 .16667 L
.06863 .16055 L
.05268 .14706 L
.04902 .14344 L
.04042 .12745 L
.03576 .10784 L
.03746 .08824 L
.04629 .06863 L
.04902 .06473 L
.06783 .04902 L
Mistroke
.06863 .04862 L
Mfstroke
.9902 .60621 m
.97769 .61765 L
.97059 .62494 L
.95098 .63577 L
.94703 .63725 L
.93137 .64084 L
.91176 .64089 L
.89609 .63725 L
.89216 .63549 L
.87255 .62163 L
.86844 .61765 L
.85487 .59804 L
.85294 .59506 L
.84735 .57843 L
.84442 .55882 L
.84583 .53922 L
.85192 .51961 L
.85294 .51725 L
.86415 .5 L
.87255 .49137 L
.88803 .48039 L
.89216 .47852 L
.91176 .47238 L
.93137 .47137 L
.95098 .47523 L
.96468 .48039 L
.97059 .48462 L
.98669 .5 L
.9902 .50238 L
s
.46078 .43998 m
.48039 .42769 L
.5 .42207 L
.51961 .42172 L
.53922 .42657 L
.55882 .43778 L
.5629 .44118 L
.5784 .46078 L
.57843 .46079 L
.58587 .48039 L
.58792 .5 L
.58492 .51961 L
.57843 .53684 L
.57625 .53922 L
.55882 .55863 L
.55861 .55882 L
.53922 .56985 L
.51961 .57474 L
.5 .57443 L
.48039 .56885 L
.46319 .55882 L
.46078 .55669 L
.44579 .53922 L
.44118 .53295 L
.43713 .51961 L
.43419 .5 L
.43626 .48039 L
.44118 .46262 L
.44381 .46078 L
.45941 .44118 L
.46078 .43998 L
s
.06863 .30099 m
.08824 .29537 L
.10784 .294 L
.12745 .29711 L
.14457 .30392 L
.14706 .30591 L
.16488 .32353 L
.16667 .32611 L
.17511 .34314 L
.1802 .36275 L
.18115 .38235 L
.17795 .40196 L
.16991 .42157 L
.16667 .4271 L
.15507 .44118 L
.14706 .44805 L
.12745 .45923 L
.12321 .46078 L
.10784 .46431 L
.08824 .46446 L
.07157 .46078 L
.06863 .45975 L
.04902 .44918 L
.03939 .44118 L
.02941 .4296 L
.02459 .42157 L
.01675 .40196 L
.01395 .38235 L
.01587 .36275 L
.02273 .34314 L
.02941 .33143 L
.03598 .32353 L
.04902 .31189 L
.06152 .30392 L
.06863 .30099 L
s
.77451 .04751 m
.79412 .04066 L
.81373 .03688 L
.83333 .03592 L
.85294 .03774 L
.87255 .04245 L
.88954 .04902 L
.89216 .05036 L
.91176 .06218 L
.92007 .06863 L
.93137 .07929 L
.93915 .08824 L
.95098 .10556 L
.95225 .10784 L
.96117 .12745 L
.96674 .14706 L
.96935 .16667 L
.96917 .18627 L
.96618 .20588 L
.9602 .22549 L
.95098 .24481 L
.95081 .2451 L
.93707 .26471 L
.93137 .27112 L
.91702 .28431 L
.91176 .28829 L
.89216 .30016 L
.8843 .30392 L
.87255 .3081 L
.85294 .31279 L
.83333 .31457 L
.81373 .31357 L
.79412 .30974 L
.77677 .30392 L
.77451 .30286 L
.7549 .29234 L
.74365 .28431 L
.73529 .2771 L
.72354 .26471 L
.71569 .25446 L
.70978 .2451 L
.7003 .22549 L
.69608 .2138 L
.6942 .20588 L
.691 .18627 L
.69052 .16667 L
.69283 .14706 L
.69608 .13255 L
.69825 .12745 L
.70741 .10784 L
Mistroke
.71569 .09484 L
.72084 .08824 L
.73529 .07298 L
.74028 .06863 L
.7549 .05796 L
.77109 .04902 L
.77451 .04751 L
Mfstroke
.48039 .02462 m
.5 .01716 L
.51961 .0156 L
.53922 .0204 L
.55715 .02941 L
.55882 .03101 L
.57321 .04902 L
.57843 .06111 L
.58036 .06863 L
.5809 .08824 L
.57843 .09876 L
.57442 .10784 L
.55882 .1261 L
.55726 .12745 L
.53922 .13672 L
.51961 .14065 L
.5 .13914 L
.48039 .1318 L
.47324 .12745 L
.46078 .11631 L
.45553 .10784 L
.44858 .08824 L
.44902 .06863 L
.45615 .04902 L
.46078 .04104 L
.472 .02941 L
.48039 .02462 L
s
.10784 .02937 m
.10868 .02941 L
.12745 .03203 L
.14706 .03746 L
.16667 .0439 L
.18627 .04883 L
.18743 .04902 L
.20588 .05068 L
.22549 .0503 L
.2451 .04993 L
.26471 .05142 L
.28431 .05598 L
.30392 .06458 L
.31064 .06863 L
.32353 .07865 L
.33271 .08824 L
.34314 .10255 L
.34567 .10784 L
.35253 .12745 L
.35464 .14706 L
.35255 .16667 L
.34648 .18627 L
.34314 .19386 L
.33566 .20588 L
.32353 .22021 L
.31774 .22549 L
.30392 .23516 L
.28431 .24416 L
.28143 .2451 L
.26471 .24887 L
.2451 .2501 L
.22549 .24802 L
.21226 .2451 L
.20588 .24218 L
.18627 .23138 L
.17749 .22549 L
.16667 .21695 L
.15017 .20588 L
.14706 .20402 L
.12745 .19495 L
.10784 .18897 L
.09767 .18627 L
.08824 .18291 L
.06863 .17364 L
.0576 .16667 L
.04902 .15928 L
.03859 .14706 L
.02941 .13058 L
.02848 .12745 L
.02451 .10784 L
Mistroke
.02593 .08824 L
.02941 .07672 L
.03315 .06863 L
.04872 .04902 L
.04902 .04876 L
.06863 .03629 L
.08824 .03047 L
.09844 .02941 L
.10784 .02937 L
Mfstroke
.0098 .78239 m
.0123 .79412 L
.01936 .81373 L
.02941 .83156 L
.03068 .83333 L
.04813 .85294 L
.04902 .85374 L
.06863 .8679 L
.07715 .87255 L
.08824 .87704 L
.10784 .88239 L
.12745 .88457 L
.14706 .88411 L
.16667 .88179 L
.18627 .87923 L
.20588 .88039 L
.22247 .89216 L
.22549 .89615 L
.23611 .91176 L
.2451 .92803 L
.24759 .93137 L
.26334 .95098 L
.26471 .95243 L
.28431 .96833 L
.28771 .97059 L
.30392 .97802 L
.32353 .98277 L
.34314 .98308 L
.36275 .97886 L
.38061 .97059 L
.38235 .9693 L
.40196 .95186 L
.40264 .95098 L
.41453 .93137 L
.42075 .91176 L
.4215 .89216 L
.41696 .87255 L
.40723 .85294 L
.40196 .84525 L
.39067 .83333 L
.38235 .82667 L
.36275 .81521 L
.36007 .81373 L
.34314 .80833 L
.32353 .80415 L
.30392 .8014 L
.28431 .79769 L
.27588 .79412 L
.26471 .7834 L
.26027 .77451 L
Mistroke
.25427 .7549 L
.24871 .73529 L
.2451 .72476 L
.24125 .71569 L
.23032 .69608 L
.22549 .68936 L
.214 .67647 L
.20588 .66925 L
.18751 .65686 L
.18627 .65621 L
.16667 .64786 L
.14706 .64322 L
.12745 .64191 L
.10784 .64382 L
.08824 .64912 L
.07098 .65686 L
.06863 .65828 L
.04902 .67246 L
.04471 .67647 L
.02941 .69471 L
.0285 .69608 L
.01796 .71569 L
.0115 .73529 L
.0098 .74385 L
Mfstroke
.9902 .62461 m
.97465 .63725 L
.97059 .64045 L
.95098 .65082 L
.93406 .65686 L
.93137 .65701 L
.91176 .6596 L
.89582 .65686 L
.89216 .65529 L
.87255 .64027 L
.8661 .63725 L
.85294 .62052 L
.85085 .61765 L
.84077 .59804 L
.83465 .57843 L
.83333 .57103 L
.83227 .55882 L
.83333 .54044 L
.83352 .53922 L
.83882 .51961 L
.84889 .5 L
.85294 .49429 L
.86608 .48039 L
.87255 .47542 L
.89216 .46465 L
.90431 .46078 L
.91176 .45941 L
.93137 .4587 L
.94572 .46078 L
.95098 .46217 L
.97059 .47043 L
.98302 .48039 L
.9902 .48469 L
s
.61906 .9902 m
.63725 .98258 L
.65522 .97059 L
.65686 .9692 L
.67382 .95098 L
.67647 .94794 L
.68525 .93137 L
.69608 .91188 L
.69611 .91176 L
.70324 .89216 L
.71569 .87792 L
.72842 .89216 L
.73529 .899 L
.74946 .91176 L
.7549 .91647 L
.77451 .93137 L
.77451 .93137 L
.79412 .94273 L
.81373 .95048 L
.81541 .95098 L
.83333 .95476 L
.85294 .95582 L
.87255 .95368 L
.88585 .95098 L
.89216 .94814 L
.91176 .9386 L
.92247 .93137 L
.93137 .92384 L
.94267 .91176 L
.95098 .90033 L
.95565 .89216 L
.9639 .87255 L
.96841 .85294 L
.96959 .83333 L
.96757 .81373 L
.96224 .79412 L
.95336 .77451 L
.95098 .77034 L
.94039 .7549 L
.93137 .74458 L
.92236 .73529 L
.91176 .72798 L
.89368 .71569 L
.89216 .7151 L
.87255 .71299 L
.85294 .71105 L
.83333 .71379 L
.82452 .71569 L
.81373 .71989 L
.79412 .72915 L
Mistroke
.78406 .73529 L
.77451 .74251 L
.76137 .7549 L
.7549 .76242 L
.74639 .77451 L
.73579 .79412 L
.73529 .79508 L
.72836 .81373 L
.72276 .83333 L
.71658 .85294 L
.71569 .85674 L
.69608 .86517 L
.68144 .85294 L
.67647 .84934 L
.65686 .83721 L
.64872 .83333 L
.63725 .8285 L
.61765 .82316 L
.59804 .8213 L
.57843 .82323 L
.55882 .82946 L
.55071 .83333 L
.53922 .84135 L
.52722 .85294 L
.51961 .86262 L
.51462 .87255 L
.50795 .89216 L
.5064 .91176 L
.51003 .93137 L
.51858 .95098 L
.51961 .95281 L
.53461 .97059 L
.53922 .97447 L
.55882 .9863 L
.56932 .9902 L
Mfstroke
.48039 .41442 m
.5 .40966 L
.51961 .40933 L
.53922 .41342 L
.55765 .42157 L
.55882 .42241 L
.57843 .43911 L
.58016 .44118 L
.59235 .46078 L
.59804 .47469 L
.59875 .48039 L
.60039 .5 L
.59804 .51915 L
.59793 .51961 L
.59046 .53922 L
.57843 .55713 L
.57688 .55882 L
.55882 .57383 L
.55153 .57843 L
.53922 .58299 L
.51961 .58708 L
.5 .58682 L
.48039 .58219 L
.47063 .57843 L
.46078 .57229 L
.44508 .55882 L
.44118 .55437 L
.43156 .53922 L
.42417 .51961 L
.42158 .5 L
.42343 .48039 L
.42997 .46078 L
.44118 .44238 L
.4422 .44118 L
.46078 .42431 L
.46465 .42157 L
.48039 .41442 L
s
.06863 .02282 m
.08824 .01785 L
.10784 .01684 L
.12745 .01899 L
.14706 .02342 L
.16667 .02866 L
.16981 .02941 L
.18627 .03263 L
.20588 .03407 L
.22549 .03368 L
.2451 .03332 L
.26471 .03458 L
.28431 .03844 L
.30392 .0455 L
.31121 .04902 L
.32353 .05647 L
.33913 .06863 L
.34314 .07219 L
.35701 .08824 L
.36275 .09517 L
.36934 .10784 L
.37318 .12745 L
.3742 .14706 L
.37121 .16667 L
.36531 .18627 L
.36275 .19292 L
.35589 .20588 L
.34314 .224 L
.34183 .22549 L
.32353 .24245 L
.31993 .2451 L
.30392 .25442 L
.28431 .26223 L
.27734 .26471 L
.26471 .26686 L
.2451 .26904 L
.22549 .26929 L
.20588 .26731 L
.18627 .26519 L
.18469 .26471 L
.16667 .25449 L
.15777 .2451 L
.14706 .2336 L
.13818 .22549 L
.12745 .21776 L
.10784 .20753 L
.10418 .20588 L
.08824 .19805 L
.06863 .18858 L
.06333 .18627 L
Mistroke
.04902 .17591 L
.03862 .16667 L
.02941 .15582 L
.02374 .14706 L
.01532 .12745 L
.01196 .10784 L
.01314 .08824 L
.01917 .06863 L
.02941 .05136 L
.03139 .04902 L
.04902 .03301 L
.0543 .02941 L
.06863 .02282 L
Mfstroke
.0098 .42958 m
.01754 .44118 L
.02941 .45478 L
.0362 .46078 L
.04902 .46936 L
.06863 .47818 L
.07647 .48039 L
.08824 .48227 L
.10784 .48224 L
.11927 .48039 L
.12745 .47802 L
.14706 .4688 L
.1587 .46078 L
.16667 .45348 L
.17717 .44118 L
.18627 .42648 L
.18851 .42157 L
.19507 .40196 L
.19797 .38235 L
.19771 .36275 L
.19468 .34314 L
.18919 .32353 L
.18627 .31549 L
.18115 .30392 L
.16853 .28431 L
.16667 .28242 L
.14706 .27337 L
.12745 .27421 L
.10784 .27393 L
.08824 .2769 L
.06863 .28236 L
.06296 .28431 L
.04902 .29184 L
.03233 .30392 L
.02941 .30663 L
.01511 .32353 L
.0098 .33158 L
s
.9902 .19683 m
.98872 .20588 L
.98365 .22549 L
.97575 .2451 L
.97059 .25498 L
.96456 .26471 L
.95098 .28239 L
.94926 .28431 L
.93137 .30121 L
.92798 .30392 L
.91176 .31488 L
.89531 .32353 L
.89216 .32484 L
.87255 .33154 L
.85294 .33552 L
.83333 .33694 L
.81373 .33594 L
.79412 .33254 L
.77451 .32664 L
.76658 .32353 L
.7549 .31785 L
.73529 .30562 L
.733 .30392 L
.71569 .28877 L
.71143 .28431 L
.69608 .2648 L
.69602 .26471 L
.6848 .2451 L
.67669 .22549 L
.67647 .22492 L
.67124 .20588 L
.66797 .18627 L
.66681 .16667 L
.66808 .14706 L
.67248 .12745 L
.67647 .11388 L
.67962 .10784 L
.69184 .08824 L
.69608 .082 L
.70774 .06863 L
.71569 .06056 L
.72919 .04902 L
.73529 .04449 L
.7549 .03246 L
.76091 .02941 L
.77451 .02374 L
.79412 .0179 L
.81373 .01465 L
.83333 .01383 L
.85294 .01539 L
Mistroke
.87255 .01942 L
.89216 .02614 L
.89957 .02941 L
.91176 .03592 L
.9309 .04902 L
.93137 .0494 L
.95098 .06807 L
.95147 .06863 L
.96622 .08824 L
.97059 .0954 L
.97695 .10784 L
.98446 .12745 L
.9892 .14706 L
.9902 .15354 L
Mfstroke
.9902 .64432 m
.97452 .65686 L
.97059 .65911 L
.95098 .67214 L
.94683 .67647 L
.93137 .69426 L
.93115 .69608 L
.93137 .70016 L
.93798 .71569 L
.95098 .73524 L
.95102 .73529 L
.9637 .7549 L
.97059 .76732 L
.97407 .77451 L
.98155 .79412 L
.98609 .81373 L
.98782 .83333 L
.9868 .85294 L
.98294 .87255 L
.97591 .89216 L
.97059 .9029 L
.96516 .91176 L
.95098 .92991 L
.9496 .93137 L
.93137 .94736 L
.92626 .95098 L
.91176 .95933 L
.89216 .96738 L
.88262 .97059 L
.87255 .9722 L
.85294 .97407 L
.83333 .97314 L
.81859 .97059 L
.81373 .9694 L
.79412 .96282 L
.77451 .95357 L
.77014 .95098 L
.7549 .94254 L
.73529 .93306 L
.71569 .93305 L
.69608 .94881 L
.69353 .95098 L
.67647 .96902 L
.67472 .97059 L
.65686 .98506 L
.64905 .9902 L
s
.9902 .4665 m
.97983 .46078 L
.97059 .45454 L
.95098 .44713 L
.93137 .44357 L
.91176 .44391 L
.89216 .44849 L
.87255 .45758 L
.86711 .46078 L
.85294 .47274 L
.84576 .48039 L
.83333 .4983 L
.83243 .5 L
.82419 .51961 L
.81965 .53922 L
.81845 .55882 L
.82035 .57843 L
.82512 .59804 L
.83235 .61765 L
.83333 .61879 L
.84156 .63725 L
.85027 .65686 L
.849 .67647 L
.83333 .69207 L
.81728 .69608 L
.81373 .69789 L
.79412 .70774 L
.78027 .71569 L
.77451 .71959 L
.75512 .73529 L
.7549 .7355 L
.73763 .7549 L
.73529 .75803 L
.72467 .77451 L
.71569 .79024 L
.71381 .79412 L
.70233 .81373 L
.69608 .81809 L
.67647 .82318 L
.65686 .81903 L
.63726 .81373 L
.63725 .81372 L
.61765 .81021 L
.59804 .80909 L
.57843 .81094 L
.56337 .81373 L
.55882 .81638 L
.53922 .82655 L
.5299 .83333 L
.51961 .84291 L
Mistroke
.51176 .85294 L
.5 .8713 L
.49945 .87255 L
.4928 .89216 L
.49143 .91176 L
.49525 .93137 L
.5 .94495 L
.50407 .95098 L
.51775 .97059 L
.51961 .97276 L
.53922 .9894 L
.54034 .9902 L
Mfstroke
.0098 .68193 m
.01375 .67647 L
.02941 .65872 L
.03137 .65686 L
.04902 .64288 L
.05792 .63725 L
.06863 .63175 L
.08824 .62419 L
.10784 .6197 L
.12745 .6181 L
.14706 .61929 L
.16667 .62328 L
.18627 .63021 L
.20052 .63725 L
.20588 .64052 L
.22549 .65525 L
.22727 .65686 L
.24502 .67647 L
.2451 .67657 L
.2576 .69608 L
.26471 .71068 L
.2668 .71569 L
.2741 .73529 L
.28193 .7549 L
.28431 .75941 L
.29708 .77451 L
.30392 .77921 L
.32353 .78748 L
.34314 .79357 L
.34492 .79412 L
.36275 .8014 L
.38235 .8119 L
.38523 .81373 L
.40196 .82748 L
.40745 .83333 L
.42157 .85212 L
.42187 .85294 L
.42927 .87255 L
.43424 .89216 L
.43336 .91176 L
.42666 .93137 L
.42157 .94639 L
.41804 .95098 L
.40196 .96921 L
.40039 .97059 L
.38235 .98313 L
.36651 .9902 L
s
.0098 .8443 m
.01622 .85294 L
.02941 .86746 L
.035 .87255 L
.04902 .88319 L
.06431 .89216 L
.06863 .89421 L
.08824 .90163 L
.10784 .90609 L
.12745 .90801 L
.14706 .9079 L
.16667 .90677 L
.18627 .90681 L
.20437 .91176 L
.20588 .91255 L
.22549 .92915 L
.22773 .93137 L
.24497 .95098 L
.2451 .95114 L
.26471 .96942 L
.26621 .97059 L
.28431 .98239 L
.30272 .9902 L
s
.55844 .0098 m
.55882 .01021 L
.57843 .02662 L
.58118 .02941 L
.594 .04902 L
.59804 .05825 L
.60059 .06863 L
.60182 .08824 L
.59831 .10784 L
.59804 .1105 L
.58597 .12745 L
.57843 .13552 L
.56079 .14706 L
.55882 .14803 L
.53922 .15497 L
.51961 .15765 L
.5 .15636 L
.48039 .15101 L
.47111 .14706 L
.46078 .14105 L
.44452 .12745 L
.44118 .1246 L
.43316 .10784 L
.4271 .08824 L
.42909 .06863 L
.43608 .04902 L
.44118 .03875 L
.44846 .02941 L
.46078 .01829 L
.47052 .0098 L
s
.48039 .39817 m
.5 .39425 L
.51961 .39394 L
.53922 .39724 L
.55438 .40196 L
.55882 .40441 L
.57843 .41726 L
.58338 .42157 L
.59804 .43868 L
.59959 .44118 L
.60915 .46078 L
.61455 .48039 L
.61603 .5 L
.61369 .51961 L
.60739 .53922 L
.59804 .55703 L
.59674 .55882 L
.57878 .57843 L
.57843 .57871 L
.55882 .59152 L
.54417 .59804 L
.53922 .59923 L
.51961 .60249 L
.5 .60229 L
.48039 .59864 L
.47802 .59804 L
.46078 .59033 L
.44302 .57843 L
.44118 .57682 L
.42514 .55882 L
.42157 .55365 L
.41455 .53922 L
.40842 .51961 L
.40622 .5 L
.40784 .48039 L
.41335 .46078 L
.42157 .44333 L
.42302 .44118 L
.43946 .42157 L
.44118 .42002 L
.46078 .40625 L
.46872 .40196 L
.48039 .39817 L
s
.0098 .29794 m
.02407 .28431 L
.02941 .28034 L
.04902 .26685 L
.05214 .26471 L
.06863 .25473 L
.08094 .2451 L
.08115 .22549 L
.06863 .21342 L
.05911 .20588 L
.04902 .19629 L
.03557 .18627 L
.02941 .17991 L
.01797 .16667 L
.0098 .15389 L
s
.9902 .75385 m
.98149 .73529 L
.97406 .71569 L
.97435 .69608 L
.98659 .67647 L
.9902 .67199 L
s
.0098 .63804 m
.01062 .63725 L
.02941 .62155 L
.03488 .61765 L
.04902 .60908 L
.06863 .59937 L
.0716 .59804 L
.08824 .59312 L
.10784 .58912 L
.12745 .58778 L
.14706 .58918 L
.16667 .59296 L
.184 .59804 L
.18627 .59896 L
.20588 .60774 L
.22308 .61765 L
.22549 .61927 L
.2451 .63466 L
.24791 .63725 L
.26471 .65552 L
.26576 .65686 L
.2791 .67647 L
.28431 .68581 L
.28931 .69608 L
.29767 .71569 L
.30392 .73046 L
.30614 .73529 L
.31928 .7549 L
.32353 .7592 L
.34314 .77237 L
.34769 .77451 L
.36275 .78256 L
.38235 .79313 L
.38412 .79412 L
.40196 .80704 L
.40974 .81373 L
.42157 .82551 L
.42678 .83333 L
.44118 .85042 L
.44294 .85294 L
.45868 .87255 L
.46078 .87402 L
.47138 .87255 L
.48039 .86321 L
.48916 .85294 L
.5 .84033 L
.50719 .83333 L
.51961 .82182 L
.53071 .81373 L
.53922 .8089 L
Mistroke
.55882 .80034 L
.57843 .79519 L
.58554 .79412 L
.59804 .79322 L
.61765 .79343 L
.63298 .79412 L
.63725 .79496 L
.65686 .79594 L
.66965 .79412 L
.67647 .79156 L
.69536 .77451 L
.69608 .77341 L
.70927 .7549 L
.71569 .74578 L
.72398 .73529 L
.73529 .72276 L
.74263 .71569 L
.7549 .70537 L
.76735 .69608 L
.77451 .69136 L
.79412 .67764 L
.79553 .67647 L
.81183 .65686 L
.81367 .63725 L
.81004 .61765 L
.80565 .59804 L
.80234 .57843 L
.80103 .55882 L
.80217 .53922 L
.806 .51961 L
.81258 .5 L
.81373 .49725 L
.82283 .48039 L
.83333 .46547 L
.83712 .46078 L
.85294 .44555 L
.8578 .44118 L
.87255 .43458 L
.89216 .42431 L
.90341 .42157 L
.91176 .42081 L
.92941 .42157 L
.93137 .42185 L
.95098 .42658 L
.97059 .4342 L
.98346 .44118 L
.9902 .44452 L
Mfstroke
.0098 .464 m
.02737 .48039 L
.02941 .48187 L
.04902 .49397 L
.06118 .5 L
.06863 .50164 L
.08824 .50509 L
.10784 .5052 L
.12745 .50178 L
.13748 .5 L
.14706 .4947 L
.16667 .48194 L
.16884 .48039 L
.18627 .46302 L
.18815 .46078 L
.20134 .44118 L
.20588 .43251 L
.2102 .42157 L
.21572 .40196 L
.2186 .38235 L
.2194 .36275 L
.21914 .34314 L
.22006 .32353 L
.22549 .30925 L
.2306 .30392 L
.2451 .29597 L
.26471 .29029 L
.28431 .28491 L
.28629 .28431 L
.30392 .27759 L
.32353 .2676 L
.32824 .26471 L
.34314 .25347 L
.35214 .2451 L
.36275 .2332 L
.36842 .22549 L
.38062 .20588 L
.38235 .20282 L
.38978 .18627 L
.40067 .16667 L
.40196 .1652 L
.42157 .15304 L
.44118 .15827 L
.46078 .16615 L
.46216 .16667 L
.48039 .17245 L
.5 .17639 L
.51961 .17762 L
.53922 .17612 L
.55882 .17211 L
Mistroke
.57667 .16667 L
.57843 .16613 L
.59804 .15941 L
.61765 .15827 L
.62696 .16667 L
.63575 .18627 L
.63725 .19282 L
.64115 .20588 L
.6472 .22549 L
.65448 .2451 L
.65686 .25064 L
.66393 .26471 L
.67614 .28431 L
.67647 .28479 L
.69213 .30392 L
.69608 .30804 L
.71341 .32353 L
.71569 .32528 L
.73529 .33841 L
.74379 .34314 L
.7549 .3484 L
.77451 .35586 L
.79412 .36126 L
.79955 .36275 L
.81373 .36463 L
.83333 .36602 L
.85294 .36521 L
.87255 .36357 L
.87658 .36275 L
.89216 .35726 L
.91176 .34765 L
.92161 .34314 L
.93137 .33646 L
.9485 .32353 L
.95098 .32136 L
.9688 .30392 L
.97059 .30193 L
.98453 .28431 L
.9902 .27574 L
Mfstroke
.9902 .91444 m
.97934 .93137 L
.97059 .94217 L
.96223 .95098 L
.95098 .96098 L
.93788 .97059 L
.93137 .97466 L
.91176 .98451 L
.89576 .9902 L
s
.80276 .9902 m
.79412 .98739 L
.77451 .97977 L
.7549 .97109 L
.75371 .97059 L
.73529 .96474 L
.71569 .96618 L
.70623 .97059 L
.69608 .97707 L
.67774 .9902 L
s
.51544 .9902 m
.5 .97442 L
.49882 .97059 L
.48233 .95098 L
.48039 .94877 L
.46078 .93194 L
.44118 .95003 L
.43989 .95098 L
.42196 .97059 L
.42157 .97203 L
.40196 .98862 L
.39963 .9902 L
s
.0098 .88801 m
.01431 .89216 L
.02941 .90417 L
.04104 .91176 L
.04902 .91618 L
.06863 .92496 L
.08824 .93108 L
.08909 .93137 L
.10784 .93476 L
.12745 .93642 L
.14706 .93657 L
.16667 .9363 L
.18627 .93791 L
.20588 .94492 L
.21717 .95098 L
.22549 .95865 L
.2403 .97059 L
.2451 .97493 L
.26471 .98893 L
.2668 .9902 L
s
.9902 .07469 m
.98623 .06863 L
.97082 .04902 L
.97059 .04877 L
.95098 .02993 L
.95035 .02941 L
.93137 .01563 L
.92149 .0098 L
s
.73879 .0098 m
.73529 .01173 L
.71569 .02418 L
.70869 .02941 L
.69608 .03914 L
.68526 .04902 L
.67647 .05504 L
.65686 .0674 L
.63725 .06394 L
.62443 .04902 L
.61765 .03956 L
.60897 .02941 L
.59804 .01686 L
.59139 .0098 L
s
.43919 .0098 m
.42158 .02941 L
.42157 .02942 L
.40899 .04902 L
.40196 .05422 L
.38235 .06325 L
.36275 .05499 L
.34975 .04902 L
.34314 .04271 L
.32353 .03143 L
.31956 .02941 L
.30392 .02265 L
.28431 .01679 L
.26471 .01362 L
.2451 .01265 L
.22549 .01311 L
.20588 .01372 L
.18627 .013 L
.16667 .01033 L
.16341 .0098 L
s
.0098 .05284 m
.01225 .04902 L
.0288 .02941 L
.02941 .02885 L
.04902 .01487 L
.05943 .0098 L
s
.46078 .37997 m
.48039 .37374 L
.5 .37022 L
.51961 .36975 L
.53922 .37235 L
.55882 .37785 L
.57159 .38235 L
.57843 .38625 L
.59804 .4002 L
.60011 .40196 L
.61745 .42157 L
.61765 .42184 L
.62781 .44118 L
.63544 .46078 L
.63725 .46761 L
.63884 .48039 L
.63959 .5 L
.63806 .51961 L
.63725 .52671 L
.63305 .53922 L
.62427 .55882 L
.61765 .57075 L
.61181 .57843 L
.59804 .59329 L
.59262 .59804 L
.57843 .60769 L
.55968 .61765 L
.55882 .61791 L
.53922 .62321 L
.51961 .62602 L
.5 .62588 L
.48039 .62283 L
.46148 .61765 L
.46078 .61731 L
.44118 .60677 L
.42842 .59804 L
.42157 .59203 L
.40928 .57843 L
.40196 .56865 L
.39701 .55882 L
.38858 .53922 L
.3835 .51961 L
.38235 .51074 L
.38201 .5 L
.38235 .48811 L
.38331 .48039 L
.3881 .46078 L
.39609 .44118 L
.40196 .4296 L
.40767 .42157 L
Mistroke
.42157 .40553 L
.42538 .40196 L
.44118 .39028 L
.45447 .38235 L
.46078 .37997 L
Mfstroke
.44118 .20172 m
.46078 .20133 L
.48039 .20406 L
.49256 .20588 L
.5 .20661 L
.51961 .20799 L
.53922 .20858 L
.55882 .20938 L
.57843 .21358 L
.59463 .22549 L
.59804 .23058 L
.60659 .2451 L
.6159 .26471 L
.61765 .26839 L
.62599 .28431 L
.63725 .30313 L
.63778 .30392 L
.65243 .32353 L
.65686 .32873 L
.67075 .34314 L
.67647 .34836 L
.69442 .36275 L
.69608 .36392 L
.71569 .37635 L
.72658 .38235 L
.73529 .38655 L
.7549 .39519 L
.77063 .40196 L
.77451 .40323 L
.79412 .41458 L
.80049 .42157 L
.8027 .44118 L
.79629 .46078 L
.79412 .46783 L
.78902 .48039 L
.7825 .5 L
.77742 .51961 L
.77451 .53642 L
.77432 .53922 L
.77336 .55882 L
.77362 .57843 L
.77451 .59804 L
.77451 .59815 L
.77452 .61765 L
.77451 .61783 L
.77006 .63725 L
.75559 .65686 L
.7549 .65757 L
.73529 .67477 L
.7332 .67647 L
Mistroke
.71569 .69227 L
.71179 .69608 L
.69608 .71314 L
.69397 .71569 L
.67799 .73529 L
.67647 .73705 L
.65754 .7549 L
.65686 .75532 L
.63725 .76361 L
.61765 .76668 L
.59804 .76856 L
.57843 .7711 L
.56012 .77451 L
.55882 .77496 L
.53922 .78253 L
.51961 .79235 L
.5167 .79412 L
.5 .8054 L
.48742 .81373 L
.48039 .81791 L
.46078 .82047 L
.44858 .81373 L
.44118 .80808 L
.42467 .79412 L
.42157 .79094 L
.40196 .77476 L
.40165 .77451 L
.38235 .76036 L
.37598 .7549 L
.36275 .74307 L
.35651 .73529 L
.34478 .71569 L
.34314 .71205 L
.33612 .69608 L
.32754 .67647 L
.32353 .66808 L
.31741 .65686 L
.30486 .63725 L
.30392 .63594 L
.28895 .61765 L
.28431 .61268 L
.2688 .59804 L
.26471 .59463 L
.2451 .57984 L
.24309 .57843 L
.22549 .56737 L
.21294 .55882 L
.20588 .55388 L
.19158 .53922 L
.19121 .51961 L
Mistroke
.20217 .5 L
.20588 .49307 L
.21496 .48039 L
.22549 .46268 L
.22652 .46078 L
.23547 .44118 L
.24252 .42157 L
.2451 .41258 L
.24727 .40196 L
.25066 .38235 L
.25436 .36275 L
.26192 .34314 L
.26471 .33881 L
.28371 .32353 L
.28431 .32317 L
.30392 .3134 L
.32353 .30445 L
.32463 .30392 L
.34314 .29312 L
.35601 .28431 L
.36275 .27887 L
.37788 .26471 L
.38235 .25993 L
.39448 .2451 L
.40196 .23547 L
.40869 .22549 L
.42157 .21189 L
.42991 .20588 L
.44118 .20172 L
Mfstroke
.0098 .57843 m
.02759 .55882 L
.02941 .55546 L
.03031 .53922 L
.02941 .537 L
.01693 .51961 L
.0098 .51 L
s
.0098 .25672 m
.01687 .2451 L
.02365 .22549 L
.01516 .20588 L
.0098 .19438 L
s
.9902 .40525 m
.98751 .40196 L
.97446 .38235 L
.97912 .36275 L
.9902 .34695 L
s
.9902 .97311 m
.97117 .9902 L
s
.47523 .9902 m
.46078 .98485 L
.44299 .9902 L
s
.0098 .94285 m
.02295 .95098 L
.02941 .95444 L
.04902 .96344 L
.06863 .97032 L
.06949 .97059 L
.08824 .97519 L
.10784 .9782 L
.12745 .97958 L
.14706 .97978 L
.16667 .97978 L
.18627 .98145 L
.20588 .98688 L
.21527 .9902 L
s
.38315 .0098 m
.38235 .01001 L
.36304 .0098 L
s
.0098 .01476 m
.01524 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`00000000000000018000003_oo
ool5o`0000Wooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05Oooool3o`0000_ooooo2000000<ooooo`;o00003_oo
ool00`00003oooooooooo`3?ooooo`002Oooool01@00003ooooooooooooooooo000000D06ATI0_l0
000403<c<`/000006@0c<c<3000001P06ATI00@0000003<c<`0c<c<0<c<c0_l0000404a<C0So0000
1@1<C4`00ol00000<c<c03<c<`0303<c<`03o`00000I6AT06ATI01<06ATI00?o000003<c<`0c<c<0
200c<c<4000000P0C4a<1@00000903<c<`;o0000200I6AT4ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooo`@06ATI0_l0000303<c<`<000002`1<C4`4000001P0<c<c
0`00000D01TI6@050000000c<c<0<c<c03<c<ol00000101<C4`2o`0000P0IVIV0ol0000304a<C003
o`00000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT0400I6AT2o`0000P0<c<c0`00000A04a<C080
00002@0c<c<00ol000006ATI01TI6@0501TI6@Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo0`0I6AT01?l00000<c<c03<c<`0c<c<2000000<0C4a<0P0000000ol0
0000000000000003000000L0C4a<00Co000000000000000000005`0c<c<00`00003o00000000000@
01TI6@050000000c<c<0<c<c03<c<ol00000101<C4`00ol00000IVIV06IVIP0306IVIPGo00000`1V
IVH2o`000080C4a<0_l0000403<c<`03o`00000I6AT06ATI00h06ATI00?o000003<c<`0c<c<01`0c
<c<00`000000C4a<04a<C00D04a<C003o`0000000000000000L0<c<c00?o000001TI6@0I6AT0100I
6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00Go
000003<c<`0c<c<00000o`00000204a<C0800000201VIVH3000000P0C4a<4@00000903<c<`800000
3P0I6AT01@000000<c<c03<c<`0c<c?o000000<0C4a<00Co000006IVIP1VIVH0IVIV0ol0000507mo
O`05o`00001VIVH0IVIV06IVI_l000000`1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT0
6ATI00d06ATI00?o000003<c<`0c<c<01P0c<c<00`00003o000004a<C00704a<C0P000002P1<C4`2
000000H0<c<c00?o000001TI6@0I6AT00`0I6AT4ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?ooooooooooooooo`806ATI00Co000003<c<`0c<c<000000`1<C4`010000000IVIV06IV
IP1VIVH7000000<0IVIV1000000E04a<C0<00000200c<c<00`0000006ATI01TI6@0:01TI6@050000
000c<c<0<c<c03<c<ol000000`1<C4`01Ol00000IVIV06IVIP1VIVKo000000T0Ogmo00Go000006IV
IP1VIVH0IVIVo`00000304a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT02`0I6AT0
0ol00000<c<c03<c<`0503<c<`8000001P1<C4`4000000P0IVIV1@00000704a<C0030000000c<c<0
<c<c00@0<c<c00?o000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0600000?ooooooooooooooo`0I6AWo00000P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV
0P00000707moO`<00000101VIVH3000001D0C4a<00<00000o`00000c<c<01@0c<c<00`0000006ATI
01TI6@0901TI6@030000000c<c<0<c<c0080<c<c00Go000004a<C01<C4`0C4a<o`00000206IVIP03
o`00001oOgl0Ogmo00T0Ogmo00Co000006IVIP1VIVKo00000`1<C4`00ol00000<c<c03<c<`0303<c
<`03o`00000I6AT06ATI00T06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<
C003o`0000000000IVIV0100IVIV0P00000604a<C0030000000c<c<0<c<c00@0<c<c00Co000001TI
6@0I6AT06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01@00003ooooooooooooooooo
00000080<c<c00P0000004a<C01<C4co00000000001VIVH00000o`000080Ogmo1ol0000307moO`04
o`00000000000000000000<0IVIV4P00000504a<C08000001@0c<c<2000000P06ATI00?o000003<c
<`0c<c<00P0c<c<01Ol00000C4a<04a<C01<C4co00000080IVIV00?o000007moO`1oOgl00`1oOgl3
o`0000D0Ogmo00Co000006IVIP1VIVKo00000`1<C4`00ol00000<c<c03<c<`0303<c<`03o`00000I
6AT06ATI00L06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C00300000?l0
0000IVIV01<0IVIV0P00000504a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool303<c<`060000001<
C4`0C4a<0000001VIVH000000P1oOgl2o`0000L0VIVI0ol0000407moO`<000004P1VIVH3000000@0
C4a<0P00000503<c<`<000000`0I6AT2000000D0<c<c00Go000004a<C01<C4`0C4a<o`00000206IV
IP04o`00001oOgl0Ogmo07moO`;o00000`2IVIT00ol00000Ogmo07moO`0207moO`04o`00001VIVH0
IVIVo`0000@0C4a<00?o000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0401TI6@;o00001`0c
<c<00`000000C4a<04a<C00204a<C0<000001`1VIVH;o`0000H0IVIV00<0000004a<C01<C4`00`1<
C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo0P0c<c<01`000000C4a<04a<C0000000IVIV0000001o
Ogl00_l0000209VIV@Oo00000`2IVIT3o`0000@0Ogmo1000000206IVIPP000001`1VIVH00`00003o
000004a<C00304a<C0030000000c<c<0<c<c00D0<c<c0`00000603<c<`05o`00001<C4`0C4a<04a<
C?l000000P1VIVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00<0VIVI00?o000007mo
O`1oOgl00P1oOgl01?l00000IVIV06IVI_l0000304a<C003o`00000c<c<0<c<c00@0<c<c0ol00000
0`0I6AWo0000o`00000703<c<`800000101<C4`00`000000IVIV06IVIP0406IVIPCo00002`1oOgl3
o`0000@0IVIV0P00000404a<C0030000000c<c<0<c<c00@0<c<c00?o0000ooooooooool00_ooool0
0`00003oooooooooo`3?ooooo`002Oooool01P00003oooooooooooooool0<c<c00000080C4a<00D0
000006IVI_l00000Ogmoo`00000209VIV@;o00000`2c/k<3o`0000030;>c/ol0003o000000;o0000
0P2IVIT00ol00000Ogmo07moO`0507moO`800000201oOgl300000003o`00001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0=03<c<`04o`00001<C4`0C4a<o`0000<0
IVIV00Go000007moO`1oOgl0Ogmoo`00000709VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH0
1?l00000C4a<04a<C?l0000903<c<`03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0206IVIP?o00004P1oOgl00ol00000IVIV06IVIP0306IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<01Ol0003oooooooooooooool000000=7ooooo
0009ooooo`0800000?ooooooooooooooo`0c<c<0000004a<C?l0000206IVIP050000001oOgoo0000
09VIVOl00000102c/k<01Ol00000c<c<0<c<c03<c<co000000@0/k>c00?o000009VIV@2IVIT00ol0
000B07moO`800000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00`0<c<c00Co
000004a<C01<C4co00000`1VIVH01Ol00000Ogmo07moO`1oOgoo000000L0VIVI00Go000007moO`1o
Ogl0Ogmoo`00000306IVIP04o`00001<C4`0C4a<o`000140<c<c00<0000004a<C01<C4`00`1<C4`0
0ol00000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo00D0Ogmo2_l0000507moO`;o0000101VIVH0
1@000000C4a<04a<C01<C4`0000000H0<c<c00Go0000oooooooooooooooo0000003Aooooo`002Ooo
ool02000003oooooooooooooool0<c<c0000001<C4`000000P1VIVH01@00003o000009VIV@2IVIWo
00000080/k>c0_l000050<c<c0;o00000`2c/k<00ol00000VIVI09VIV@0209VIVA;o00000P1oOgl2
000000<0IVIV00D0000004a<C01<C4`0C4a<0000000>03<c<`04o`00001<C4`0C4a<o`0000<0IVIV
00Go000007moO`1oOgl0Ogmoo`00000709VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH01?l0
0000C4a<04a<C?l0000@03<c<`030000001<C4`0C4a<00@0C4a<00D0000006IVIP1VIVH0IVIVo`00
000507moO`?o00002P2IVIT00ol00000Ogmo07moO`0407moO`03o`00001VIVH0IVIV0080IVIV00D0
000004a<C01<C4`0C4a<0000000503<c<`Cooooo00<00000ooooooooool0coooool000Wooooo00L0
0000oooooooooooooooo0000001<C4`000000080IVIV00D0000007moOol00000VIVIo`0000020;>c
/`03o`00003<c<`0c<c<00L0c<c<00Go00000;>c/`2c/k<0/k>co`00000E09VIV@05o`00001oOgl0
Ogmo07moOol000000`1VIVH01@000000C4a<04a<C01<C4`0000000d0<c<c00Co000004a<C01<C4co
00000`1VIVH01Ol00000Ogmo07moO`1oOgoo000000L0VIVI00Go000007moO`1oOgl0Ogmoo`000003
06IVIP05o`00001<C4`0C4a<04a<C?l000003`0c<c<00`000000C4a<04a<C00304a<C0050000001V
IVH0IVIV06IVI_l000001@1oOgl00ol00000VIVI09VIV@0<09VIV@;o00001@1oOgl01Ol00000IVIV
06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<4ooooo`0300000?oooooooooo08_o
oooo0_l00012ooooo`002Oooool01`00003oooooooooooooool0000004a<C00000000P1VIVH01`00
0000Ogmoo`00002IVIWo00000;>c/ol000001@3<c<`00ol00000c<c<0<c<c0030<c<c004o`00002c
/k<0/k>c0;>c/`?o00004P2IVIT2o`0000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C003
o`00000c<c<0<c<c00X0<c<c00Co000004a<C01<C4co00000`1VIVH01Ol00000Ogmo07moO`1oOgoo
000000H0VIVI0_l0000307moO`05o`00001VIVH0IVIV06IVI_l000000`1<C4`00ol00000<c<c03<c
<`0<03<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIVo`00000407moO`;o0000
1`2IVIT5o`0000D0VIVI0_l0000407moO`05o`00001VIVH0IVIV06IVIP000000101<C4`01?l00000
<c<c03<c<`0c<c<4ooooo`0300000?oooooooooo08Sooooo0ol000000ooooooo0000ooooo`11oooo
o`002Oooool01`00003oooooooooooooool0000004a<C00000000P1VIVH01`000000Ogmoo`00002I
VIWo00000;>c/ol00000103<c<`00ol00000i^KVo`0000050<c<c003o`00002c/k<0/k>c00<0/k>c
4Ol0000309VIV@;o00000P1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c
<c<02@0c<c<01?l00000C4a<04a<C?l0000306IVIP03o`00001oOgl0Ogmo0080Ogmo0ol0000209VI
V@03o`00001oOgl0Ogmo00<0Ogmo00Co000006IVIP1VIVKo0000101<C4`00ol00000<c<c03<c<`0<
03<c<`030000001<C4`0C4a<0080C4a<00Go000006IVIP1VIVH0IVIVo`00000407moO`03o`00002I
VIT0VIVI00@0VIVI0ol000050;>c/`?o0000102IVIT00ol00000Ogmo07moO`0207moO`04o`00001V
IVH0IVIV000000D0C4a<00<0000003<c<`0c<c<01?ooool00`00003oooooooooo`26ooooo`;o0000
1?ooool2o`00047ooooo0009ooooo`0?00000?ooooooooooooooo`000000C4a<0000001VIVH00000
07moOol00000VIVIo`00002c/k?o000000@0c<c<00Go00000>KViP3Vi^H0i^KVo`0000040<c<c003
o`00002c/k<0/k>c01@0/k>c00?o000009VIV@2IVIT00P2IVIT01?l00000Ogmo07moOol0000306IV
IP04o`00001<C4`0C4a<000000`0<c<c00Co000004a<C01<C4co00000`1VIVH00ol00000Ogmo07mo
O`0407moO`;o00001P1oOgl01?l00000IVIV06IVI_l0000304a<C003o`00000c<c<0<c<c00`0<c<c
00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVKo000000@0Ogmo00?o000009VIV@2I
VIT00P2IVIT3o`0000/0/k>c0_l0000309VIV@03o`00001oOgl0Ogmo0080Ogmo00Co000006IVIP1V
IVH00000101<C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo08?ooooo0ol00006oooo
o`03o`000?oooooo0000043ooooo0009ooooo`0?00000?ooooooooooooooo`000000C4a<0000001V
IVH0000007moOol00000VIVIo`00002c/k?o000000<0c<c<0_l000030>KViP;o0000103<c<`00ol0
0000/k>c0;>c/`0<0;>c/`Co0000102c/k<2o`0000<0VIVI00Co000007moO`1oOgl000000P1VIVH0
1@000000C4a<04a<C01<C4`0000000/0<c<c00Go000004a<C01<C4`0C4a<o`00000306IVIP03o`00
001oOgl0Ogmo00T0Ogmo0_l0000306IVIP05o`00001<C4`0C4a<04a<C?l000003@0c<c<00`000000
C4a<04a<C00204a<C0050000001VIVH0IVIV06IVI_l00000101oOgl01?l00000VIVI09VIV@2IVIT2
o`000100/k>c00Go000009VIV@2IVIT0VIVIo`00000407moO`05o`00001VIVH0IVIVo`0000000000
0`1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo083ooooo0ol00009ooooo`03o`00
0?oooooo0000043ooooo0009ooooo`0?00000?ooooooooooooooo`000000C4a<0000001VIVH00000
07moOol00000VIVIo`00002c/k?o000000D0c<c<00?o00000>KVi_l000001P3<c<`00ol00000/k>c
0;>c/`090;>c/`?o0000103<c<`3o`0000<0/k>c00Co000009VIV@2IVIWo00000P1oOgl010000000
IVIV06IVIP00000304a<C0030000000c<c<0<c<c00T0<c<c00Go000004a<C01<C4`0C4a<o`000004
06IVIP03o`00001oOgl0Ogmo00L0Ogmo00?o000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C002
04a<C003o`00000c<c<0<c<c00/0<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1V
IVKo000000<0Ogmo00Go000009VIV@2IVIT0VIVIo`0000050;>c/`P000001P2c/k<01Ol00000VIVI
09VIV@2IVIWo000000<0Ogmo00Go000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c?ooooo
00?ooooo00<00000ooooooooool0O_ooool2o`0000_ooooo00D0^JG5o`000?ooooooooooo`00000o
ooooo`002Oooool04000003oooooooooooooool0<c<c0000001<C4`0000006IVIP000000Ogmoo`00
002IVIWo00000;>c/ol000050<c<c003o`00003<c<`0c<c<00D0c<c<00?o00000;>c/`2c/k<0202c
/k<00ol00000c<c<0<c<c0080<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01?l00000Ogmo
07moO`00000206IVIP050000001<C4`0C4a<04a<C00000002`0c<c<01?l00000C4a<04a<C01<C4`2
o`0000<0IVIV00?o000007moO`1oOgl0101oOgl2o`0000@0IVIV00?o000004a<C01<C4`00P1<C4`0
0ol00000<c<c03<c<`0<03<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01Ol00000Ogmo07mo
O`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0060<c<c0<00000
102c/k<01Ol00000VIVI09VIV@2IVIWo00000080Ogmo00?o000006IVIP1VIVH00P1VIVH01@000000
C4a<04a<C01<C4`0000000Cooooo00<00000ooooooooool0Noooool3o`0000cooooo0P2iYLD01Ol0
003ooooooooooooooooo000003kooooo0009ooooo`0>00000?ooooooooooooooo`0c<c<0000004a<
C0000000IVIV0000001oOgoo000009VIVOl000020;>c/`03o`00003<c<`0c<c<00X0c<c<00?o0000
0;>c/`2c/k<01`2c/k<00ol00000c<c<0<c<c00:0<c<c005o`00002c/k<0/k>c0;>c/ol000000P2I
VIT00ol00000Ogmo0000000206IVIP050000001<C4`0C4a<04a<C00000002`0c<c<2o`0000@0C4a<
00Co000006IVIP1VIVH0IVIV1_l0000406IVIP;o0000101<C4`00ol00000<c<c03<c<`0<03<c<`03
0000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVKo00000`1oOgl01Ol00000VIVI09VIV@2IVIWo
000000@0/k>c0_l0000<0<c<c003o`00002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVIo`00
000207moO`05o`00001VIVH0IVIV06IVIP0000000`1<C4`00`00003oooooooooo`02ooooo`030000
0?oooooooooo07Wooooo0_l0000>ooooo`<0^JG500Go0000ooooooooooooooooo`00000nooooo`00
2Oooool03P00003oooooooooooooool0<c<c0000001<C4co000006IVIP000000Ogmoo`00002IVIWo
00000`2c/k<00ol00000c<c<0<c<c0070<c<c0;o00002@2c/k<00ol00000c<c<0<c<c00;0<c<c005
o`00002c/k<0/k>c0;>c/ol000000P2IVIT00ol00000Ogmo0000000206IVIP050000001<C4`0C4a<
04a<C00000003@0c<c<00ol00000C4a<04a<C00204a<C0;o00002@1VIVH2o`0000D0C4a<00?o0000
03<c<`0c<c<03@0c<c<01@000000C4a<04a<C01<C4co000000<0IVIV00Go000007moO`1oOgl0Ogmo
o`00000309VIV@03o`00002c/k<0/k>c0080/k>c00<000000<c<c03<c<`02`3<c<`00`000000/k>c
0;>c/`020;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01Ol00000IVIV06IVIP1VIVH00000
00<0C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`1fooooo`?o00003oooool20;NO
_`80^JG500?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`002Oooool02000003o
ooooooooooooool0<c<c0000001<C4`000000P1VIVH010000000Ogmoo`00002IVIT2o`000080/k>c
0ol000040<c<c0;o00002`2c/k<00ol00000c<c<0<c<c00;0<c<c005o`00002c/k<0/k>c0;>c/ol0
00000P2IVIT00ol00000Ogmo0000000206IVIP050000001<C4`0C4a<04a<C00000003P0c<c<00ol0
0000C4a<04a<C00304a<C003o`00001VIVH0IVIV00@0IVIV0_l0000504a<C0;o0000400c<c<01@00
0000C4a<04a<C01<C4`0000000<0IVIV00Co000007moO`1oOgoo00000`2IVIT00ol00000/k>c0;>c
/`020;>c/`030000003<c<`0c<c<00d0c<c<00<000000;>c/`2c/k<00P2c/k<01?l00000VIVI09VI
VOl0000307moO`04o`00001VIVH0IVIV000000<0C4a<00<00000ooooooooool00_ooool00`00003o
ooooooooo`1dooooo`;o00004?ooool00`2eVK/0]ino0;NO_`020;NO_`030;VUaOl00000_JC000?o
oooo00?o0000ooooooooool0>oooool000Wooooo00@00000oooooooooooooooo0P0c<c<00`000000
C4a<0000000206IVIP030000001oOgoo00000080VIVI0_l000030;>c/`Co00003@2c/k<00ol00000
c<c<0<c<c00<0<c<c004o`00002c/k<0/k>co`000080VIVI00Co000007moO`1oOgl000000P1VIVH0
10000000C4a<04a<C000000?03<c<`03o`00001<C4`0C4a<00<0C4a<1_l0000604a<C003o`00000c
<c<0<c<c00l0<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVKo00000080Ogmo
00Go000009VIV@2IVIT0VIVIo`0000030;>c/`030000003<c<`0c<c<00<0c<c<1ol000050<c<c005
0000002c/k<0/k>c0;>c/ol000000`2IVIT01?l00000Ogmo07moOol0000306IVIP050000001<C4`0
C4a<04a<C00000000oooool00`00003oooooooooo`1aooooo`?o00004Oooool20;FI^`@0]ino00<0
_JC0o`00002mY<001?ooool00ol0003oooooooooo`0jooooo`002Oooool01000003ooooooooooooo
ool203<c<`080000001<C4`0C4a<0000001VIVKo00000000001oOgl2o`000080VIVI0ol0000A0;>c
/`03o`00003<c<`0c<c<00`0c<c<00Co00000;>c/`2c/k?o00000P2IVIT01?l00000Ogmo07moO`00
000206IVIP040000001<C4`0C4a<00000100<c<c0_l0000<04a<C0?o00004P0c<c<00`000000C4a<
04a<C00204a<C0040000001VIVH0IVIVo`0000<0Ogmo00Co000009VIV@2IVIWo00000`2c/k<00`00
0000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`00`3<c<`01@00
0000/k>c0;>c/`2c/k?o00000080VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP050000001<
C4`0C4a<04a<C?l000000oooool00`00003oooooooooo`1^ooooo`?o00004_ooool00`2bTkL0]IVk
0;FI^`020;FI^`80]ino0P2kW[X00ol00000_JC0ooooo`04ooooo`03o`000?oooooooooo03Wooooo
0009ooooo`0700000?ooooooooooooooool00000<c<c0000000304a<C0040000001VIVH0IVIV0000
0080Ogmo0_l0000309VIV@[o00001`2c/k<00ol00000c<c<0<c<c00<0<c<c004o`00002c/k<0/k>c
o`000080VIVI00Co000007moO`1oOgl000000P1VIVH010000000C4a<04a<C000000703<c<`@00000
1`0c<c<3o`0000H0C4a<0ol0000E03<c<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVKo
00000`1oOgl01?l00000VIVI09VIVOl000030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KV
iP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0030<c<c0050000002c/k<0/k>c0;>c/ol000000P2IVIT0
1Ol00000Ogmo07moO`1oOgoo00000080IVIV00D0000004a<C01<C4`0C4a<o`000003ooooo`030000
0?oooooooooo06cooooo0_l0000Dooooo`80/Y>g102eVK/01`2gWkl0^ijj0;^N^P2kW[X0_JC0o`00
0031Y;`01?ooool00ol0003oooooooooo`0iooooo`002Oooool01@00003ooooooooooooooooo0000
0080<c<c0P00000204a<C0030000001VIVH0IVIV008000000P1oOgl3o`0000X0VIVI0ol000050;>c
/`03o`00003<c<`0c<c<00X0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@03o`00001oOgl0
00000080IVIV00D0000004a<C01<C4`0C4a<0000000503<c<`800000100I6AT3000000L0<c<c1_l0
000:03<c<`L000001`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00Co000007moO`1oOgoo
00000P2IVIT01Ol00000/k>c0;>c/`2c/k<0000000D0c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol0
0000c<c<0<c<c0030<c<c0040000002c/k<0/k>co`0000<0VIVI00Co000007moO`1oOgoo00000`1V
IVH00`000000C4a<04a<C004ooooo`0300000?oooooooooo06Wooooo0ol0000Eooooo`@0/Y>g0P2e
VK/00`2hV;H0^ijj0;^N^P020;^N^P040<6T_?l00000`JBl0<6T_0Cooooo00?o0000ooooooooool0
>?ooool000Wooooo00H00000oooooooooooooooo01TI6Ol0000303<c<`040000001<C4`0C4a<o`00
00<0IVIV0P00000307moO`Oo00001P2IVIT2o`0000@0/k>c00?o00000<c<c03<c<`02@3<c<`01Ol0
0000/k>c0;>c/`2c/k?o00000080VIVI00?o000007moO`0000000P1VIVH01@000000C4a<04a<C01<
C4`0000000@0<c<c00<0000001TI6@0I6AT01`0I6AT400000100<c<c0`00000701TI6@030000000c
<c<0<c<c00@0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP04o`00001oOgl0Ogmoo`000080
VIVI00Go00000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00T0i^KV00?o00000<c<
c03<c<`00P3<c<`00`000000/k>c0;>c/`02o`000080VIVI00Co000007moO`1oOgoo00000`1VIVH0
0`000000C4a<04a<C004ooooo`0300000?oooooooooo06Oooooo0_l0000Gooooo`80[Xfd0`2bTkL0
102eVK/0^9Rf0;RH]P2hV;H20;^N^P030<2N]P31Y;co00000080`JBl1Oooool00ol0003ooooooooo
o`0gooooo`002Oooool01P00003oooooooooooooool06ATIo`0000@0<c<c00@0000004a<C01<C4`0
0000101VIVH3000000L0Ogmo0ol0000409VIV@03o`00002c/k<0/k>c0080/k>c00?o00000<c<c03<
c<`0203<c<`2o`0000<0/k>c00Ko000009VIV@2IVIWo000007moO`00000206IVIP050000001<C4`0
C4a<04a<C0000000100c<c<00`0000006ATI01TI6@0;01TI6@<000002@0c<c<4000000X06ATI00<0
000003<c<`0c<c<0100c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00Co000007moO`1oOgoo
00000P2IVIT01Ol00000/k>c0;>c/`2c/k<0000000@0c<c<00?o00000>KViP3Vi^H02@3Vi^H00ol0
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/ol000000P2IVIT01?l00000Ogmo07moOol0
000306IVIP030000001<C4`0C4a<00Cooooo00<00000ooooooooool0I?ooool3o`0001Oooooo00@0
Z8Rb0:j=]02^SK@0[Xfd0`2bTkL40;RH]P060;^N^P30W[H0`9jf0<2N]_l00000`JBl0P37YkT4oooo
o`03o`000?oooooooooo03Oooooo0009ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c
<`0c<c<00P0c<c<00`000000C4a<04a<C003000000@0IVIV0`00000707moO`;o00000`2IVIT00ol0
0000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00H0c<c<00?o00000;>c/`2c/k<00`2c/k<00ol0
0000VIVIo`00000207moO`040000001VIVH0IVIV000000<0C4a<00D0000003<c<`0c<c<0<c<c0000
000A01TI6@T000003`0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000
0`1VIVH01?l00000Ogmo07moOol0000209VIV@05o`00002c/k<0/k>c0;>c/`000000103<c<`00ol0
0000i^KV0>KViP090>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>co`000002
09VIV@04o`00001oOgl0Ogmoo`0000<0IVIV00<0000004a<C01<C4`01?ooool00`00003ooooooooo
o`1Rooooo`;o00006Oooool20:R8/P<0[Xfd0`2bTkL0102eTK80^9Rf0;RH]P2hV;H40<2N]P04o`00
0037YkT0ajNi0<NW^@Gooooo00?o0000ooooooooool0=_ooool000Wooooo00@00000oooooooooooo
oooo0`0I6AT00ol00000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<0P00000506IVIP<0
00001P1oOgl01Ol00000VIVI09VIV@2IVIWo000000@0/k>c0ol000020<c<c0?o00001@2c/k<01_l0
0000VIVI09VIVOl00000Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<0000000403<c<`030000
000I6AT06ATI02L06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000<0
IVIV00Co000007moO`1oOgoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k<0000000@0c<c<00?o0000
0>KViP3Vi^H02@3Vi^H00ol00000c<c<0<c<c0020<c<c0040000002c/k<0/k>co`0000<0VIVI00Co
000007moO`1oOgoo00000`1VIVH00`000000C4a<04a<C004ooooo`0300000?oooooooooo05oooooo
0ol0000Jooooo`@0Z8Rb0`2^SK@00`2bTkL0]I6b0;FA/P030;RH]P050;fH/P30W[H0`9jf0<2N]_l0
00000`37YkT6ooooo`03o`000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`@0
6ATI0_l0000303<c<`0300000?l00000000000<0C4a<00?o00000000000000000P00000306IVIP<0
0000101oOgl2o`000080VIVI0ol000040;>c/`;o00001P2c/k<2o`000080VIVI00Co000007moO`1o
Ogl000000P1VIVH01Ol00000C4a<04a<C01<C4co000000<0<c<c00<0000001TI6@0I6AT0:@0I6AT0
0ol00000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01?l00000Ogmo07mo
Ool0000209VIV@05o`00002c/k<0/k>c0;>c/`000000103<c<`00ol00000i^KV0>KViP090>KViP03
o`00003<c<`0c<c<0080c<c<00@000000;>c/`2c/k?o00000`2IVIT01?l00000Ogmo07moOol00003
06IVIP030000001<C4`0C4a<00Cooooo00<00000ooooooooool0GOooool2o`0001cooooo0P2SPk83
0:R8/P80[Xfd00<0/8b`0;FA/P2eTK800P2eTK800`2hV;H0_IRb0;fH/P030<2N]P05o`000037YkT0
ajNi0<NW^@3=ZkL01Oooool00ol0003oooooooooo`0eooooo`002Oooool01@00003ooooooooooooo
oooo000000D06ATI00?o000003<c<`0c<c<00`0c<c<2000000H0C4a<0P00000406IVIP030000001o
Ogl0Ogmo00<0Ogmo00?o000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`070;>c/`;o0000102I
VIT01?l00000Ogmo07moO`00000206IVIP040000001<C4`0C4a<000000@0<c<c00<0000001TI6@0I
6AT0:@0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01?l0
0000Ogmo07moOol0000209VIV@05o`00002c/k<0/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KV
iP080>KViP03o`00003<c<`0c<c<0080c<c<00@000000;>c/`2c/k?o00000`2IVIT01?l00000Ogmo
07moOol0000306IVIP030000001<C4`0C4a<00Cooooo00<00000ooooooooool0F_ooool3o`0001co
oooo00@0WGnb0:>3/P2SPk80Xh>b0`2XR;800`2^SK@0/8b`0;2</0040;FA/P@0_IRb00D0`9jf0<FQ
/ol00000aJ6c0<NW^@020<f[]`Kooooo00?o0000ooooooooool0=?ooool000Wooooo00D00000oooo
ooooooooooooo`00000601TI6@03o`00000c<c<0<c<c00@0<c<c0P00000604a<C08000000`1VIVH3
000000<0Ogmo00?o000009VIV@2IVIT00P2IVIT3o`0000D0/k>c00?o000009VIV@2IVIT00P2IVIT2
o`000080Ogmo00Co000006IVIP1VIVH000000`1<C4`01@000000<c<c03<c<`0c<c<0000002`06ATI
00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00Go000007moO`1o
Ogl0Ogmoo`00000209VIV@05o`00002c/k<0/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KViP06
0>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>co`00000209VIV@05o`00001o
Ogl0Ogmo07moOol000000P1VIVH01@000000C4a<04a<C01<C4co000000?ooooo00<00000oooooooo
ool0Eoooool3o`0001cooooo00@0UW^c09eo/P2MOk80WGnb0`2SPk830:R8/P@0/8b`0P2eTK800`2i
TZl0_IRb0;fH/P020;fH/P80aJ6c00?o00000<FQ/`3=ZkL00P3=ZkL7ooooo`03o`000?oooooooooo
03?ooooo0009ooooo`0600000?ooooooooooooooo`00003o00001P0I6AT00ol00000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00D0C4a<0P00000406IVIP040000001oOgl0Ogmo07moO`?o0000102I
VIT5o`0000<0VIVI0_l0000307moO`040000001VIVH0IVIV000000<0C4a<00H0000003<c<`0c<c<0
<c<co`000000000701TI6@/0000000?o000001TI6@0I6AT05`0I6AT00`000000<c<c03<c<`0303<c
<`050000001<C4`0C4a<04a<C00000000P1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Go
00000;>c/`2c/k<0/k>c000000060<c<c0?o00000P3Vi^H3o`0000D0c<c<00D000000;>c/`2c/k<0
/k>co`00000209VIV@05o`00001oOgl0Ogmo07moOol000000P1VIVH01@000000C4a<04a<C01<C4`0
000000?ooooo00<00000ooooooooool0EOooool2o`0000gooooo00@0RHkA0864c@21Q<d0PHC=0P1m
OLP7ooooo`0308Ug^@2?N;H0SgRf00<0UW^c102MOk830:>3/P030:R8/P2ZQZh0ZXJ^00<0/8b`00@0
]I6b0;VB[`2iTZl0^I:_0`2mV;820<FQ/`03o`000035XK<0cJ^g0080cJ^g00<0e;6fooooooooool0
1?ooool00ol0003oooooooooo`0cooooo`002Oooool01P00003oooooooooooooool00000o`0000L0
6ATI00?o000003<c<`0c<c<01@0c<c<00ol0000000000000000604a<C0030000001VIVH0IVIV0080
IVIV00?o00000000001oOgl00`1oOgl00ol00000VIVI09VIV@0709VIV@;o0000101oOgl01@000000
IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c<c<0<c<c0000000701TI6@03o`0000000000
000001P000002`0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1V
IVH01?l00000Ogmo07moOol0000309VIV@05o`00002c/k<0/k>c0;>c/`000000203<c<`2o`0000L0
c<c<00<000000;>c/`2c/k<00P2c/k<01?l00000VIVI09VIVOl0000307moO`04o`00001VIVH0IVIV
000000<0C4a<00D00000oooooooooooooooo0000001Dooooo`?o00002_ooool0102XW/`0V9SB09RH
dP2HV=8208V>d@<0PHC=0P1mOLP307mh`P80PgNm0`29MkT308mh]P<0UW^c0`2MOk820:>3/P040:B1
[P2ZQZh0ZXJ^0:Z6[P<0/8b`102iTZl20;fH/P80`Y^_00D0aJ6co`00003<YK80c:Fb0<f[]`030=Ba
]PKooooo00?o0000ooooooooool0<_ooool000Wooooo00H00000oooooooooooooooo00000?l00008
01TI6@03o`00000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo0080Ogmo0ol0000509VIV@03o`00001oOgl0Ogmo0080Ogmo0P000003
06IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0501TI6Ah000002P0I
6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01?l00000Ogmo
07moOol0000309VIV@03o`00002c/k<0/k>c0080/k>c00<000000<c<c03<c<`03@3<c<`00`000000
/k>c0;>c/`020;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01Ol00000IVIV06IVIP1VIVH0
000000<0C4a<00D00000oooooooooooooooo0000001Booooo`;o00002oooool0102fWl80Z9k<0:RN
c02XW/`309RHdP80RHkA0`21Q<d207emb080OgS20`23Mkd308Ug^@80SgRf0`2FNk<309eo/P030:>3
/P2TPJh0Y86^00<0ZXJ^0`2`S;001@2cS:d0^I:_0;VB[`2iTZl0_IRb00<0`Y^_00D0aJ6co`00003<
YK80c:Fb0<f[]`030=Ba]PKooooo00?o0000ooooooooool0<_ooool000Wooooo00@00000oooooooo
oooooooo0P0000000ol000006ATI01TI6@0601TI6@03o`00000c<c<0<c<c00L0<c<c00<0000004a<
C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo1Ol0000407mo
O`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`01@000000<c<c03<c<`0c<c<0
000000H06ATI8000000901TI6@030000000c<c<0<c<c00<0<c<c00@0000004a<C01<C4`00000101V
IVH01?l00000Ogmo07moOol0000309VIV@03o`00002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0
2`3<c<`00ol00000/k>c0;>c/`030;>c/`04o`00002IVIT0VIVIo`0000<0Ogmo00Co000006IVIP1V
IVH000000`1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo04gooooo0ol0000<oooo
o`<0]Yo20`2XW/`209RHdP80RHkA0`21Q<d207emb0<0OgS20P23Mkd308Ug^@80SgRf0`2FNk<209eo
/P0309ak[P2TPJh0Y86^0080Y86^0`2ZQZh00`2`S;00/hb]0;><[@030;VB[`@0`Y^_00@0c:Fbo`00
003<YK80c:Fb103D/KH00`3L^KKoooooooooo`04ooooo`03o`000?oooooooooo037ooooo0009oooo
o`0400000?ooooooooooooooo`80000000?o000001TI6@0I6AT01`0I6AT00ol00000<c<c03<c<`07
03<c<`8000001@1<C4`2000000@0IVIV00?o00000000000000002@1oOgl200000003o`00001VIVH0
IVIV0080IVIV00H0000004a<C01<C4`0C4a<00000?l0000303<c<`030000000I6AT06ATI00@06ATI
8@0000000ol000006ATI01TI6@0701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0
C4a<0000000306IVIP04o`00001oOgl0Ogmoo`0000<0VIVI00?o00000;>c/`2c/k<00`2c/k<20000
00X0c<c<0P0000040;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01Ol00000IVIV06IVIP1V
IVH0000000<0C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`1;ooooo`;o00003_oo
ool40;JO`P80Z9k<00<0Zj3<09BDd@2DU=400P20Q]0307AjbP80LG;40`1dK[h308=g_@80RGNi0`2?
N;H00`2FNk<0U7N_09ak[P0209ak[P@0Y86^0P2ZQZh0102]QZ`0/hb]0;><[@2cS:d30;VB[`060;jE
[@32Vjl0`Y^_0<:K[`3<YK;o00000P3<YK800`3C[;40e;6f0=Ba]P020=bi]POooooo00?o0000oooo
ooooool0<?ooool000Wooooo00@00000oooooooooooooooo0P0000000ol000006ATI01TI6@0701TI
6@03o`00000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`0101<C4`2000000D0IVIV2@00000606IV
IP050000001<C4`0C4a<04a<C0000000100c<c<00ol000006ATI01TI6@0501TI6B<00000200I6AT0
0`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01Ol00000Ogmo07mo
O`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c0<00000
102c/k<2o`0000<0VIVI00Go000007moO`1oOgl0Ogmoo`00000306IVIP050000001<C4`0C4a<04a<
C00000001?ooool00`00003oooooooooo`18ooooo`?o00004?ooool0102lW;L0]Yo20;JO`P2fWl84
0:^Pc080U9CA0P20Q]0207AjbP<0LG;40P1dK[h307Y]^@80Pfnd0`2;L[4309Ag[`<0W7^^0`2TPJh0
0`2ZQZh0[HJ/0:f6[0040;><[@030;VB[`2nUJd0_YF]0080`Y^_0P39X:h01Ol00000c:Fb0=>//@3C
[;40e;6f00<0g;Vf00<0i<>fooooooooool01?ooool00ol0003oooooooooo`0`ooooo`002Oooool0
1P00003oooooooooooooool00000o`0000X06ATI00?o000003<c<`0c<c<02P0c<c<00`000000C4a<
04a<C00504a<C0030000001VIVH0IVIV00h0IVIV0`00000304a<C0030000000c<c<0<c<c0080<c<c
00<0000001TI6@0I6AT01@0I6ATT000000T06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<
04a<C01<C4`0000000<0IVIV00Go000007moO`1oOgl0Ogmoo`00000309VIV@;o00001@2c/k<60000
00H0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00H00000
04a<C01<C4`0C4a<0000000c<c<4ooooo`0300000?oooooooooo04Gooooo0ol0000Booooo`<0_9bg
00<0]Yo20;bU`@2lYL400`2[X<`209BDd@<0P8K@0P1dN/X2075ba080M6jn0`1jKKT308=_]080Rg:a
0`2DMjl309ak[P80Y86^00<0YH2[0:f6[02]QZ`00P2]QZ`30;><[@@0_YF]00@0`Y^_0<VP[P39X:ko
00000`3C[;430=bi]P80i<>f1oooool00ol0003oooooooooo`0_ooooo`002Oooool01P00003ooooo
ooooooooool00000o`0000X06ATI00?o000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00504a<
C00400000?l000000000000000T0IVIV0`00000404a<C0800000100c<c<00`0000006ATI01TI6@05
01TI6@03o`0000000000000002<00000200I6AT00ol00000<c<c03<c<`0203<c<`030000001<C4`0
C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000307moO`03o`00002IVIT0VIVI0080VIVI0_l0
000>0;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmoo`00000306IVIP030000
001<C4`0C4a<0080C4a<00<0000003<c<oooool00oooool00`00003oooooooooo`13ooooo`;o0000
5?ooool40;bL]`<0_:G10P2[X<`00`2/Y<l0SY;C08jBd`0307=nc`80IFo80P1aL/@307A^_P<0NVfi
0P23Kk@308]b/@80U7N_0`2LNjh00`2TPJh0YH2[0:F0Z`040:f6[080/hb]00<0^8n[0;jE[@2nUJd0
0P2nUJd30<VP[P05o`00003C[;40djba0=>//@3L][400P3L^KH20>C3]P030>c?]ooooooooooo00Go
oooo00?o0000ooooooooool0;_ooool000Wooooo00H00000oooooooooooooooo00000?l0000901TI
6@03o`00000c<c<0<c<c00`0<c<c00<0000004a<C01<C4`02@1<C4`9000000H0C4a<00<0000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0501TI6BH00000200I6AT00`000000<c<c03<c<`0203<c
<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000407moO`03o`00002IVIT0
VIVI00<0VIVI0ol000090;>c/`;o0000102IVIT00ol00000Ogmo07moO`0207moO`05o`00001VIVH0
IVIV06IVIP000000101<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo043ooooo0ol0
000Eooooo`80_9J_0P2lW;L01035XkH0_:G10;bU`@2lYL440:bTc`80SY;C0`1cO/l0101UKlP0HfK1
06=V`@1SI/4207A^_P<0NVfi0P23Kk@308]b/@<0U7N_0P2LNjh30:F0Z`@0[HJ/00@0/hb]0;R?Z`2h
Sj/0^8n[0`2nUJd30<VP[P03o`00003C[;40djba00<0g;Ja00D0g;Vf0>C3]P3/ckL0k<ng0?;K^006
ooooo`03o`000?oooooooooo02kooooo0009ooooo`0500000?ooooooooooooooool00000200I6AT2
o`000100<c<c0P00000E04a<C0<000001@0c<c<2000000L06ATI:000000701TI6@030000000c<c<0
<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVKo000000@0Ogmo00?o
000009VIV@2IVIT01@2IVIT3o`0000<0/k>c0ol0000409VIV@;o0000101oOgl01Ol00000IVIV06IV
IP1VIVH0000000@0C4a<00<0000003<c<`0c<c<01?ooool00`00003oooooooooo`0nooooo`;o0000
5oooool30;bF[`040;bL]`35XkH0aJ>f0<FS]P80_:G100@0a:k40:bTc`2/Y<l0[:C?0`2>T]<207=n
c`80IFo80P1SI/4206MT^`<0NVfi0`23Kk@208]b/@<0U7N_00<0W7^^09aj[02LNZ`00`2UP:/30:f6
[0@0^8n[0P2nUJd20<FJ[0050<VP[P3AYjko00000=6W[P3C[;400`3L][420>C3]P80k<ng0P3bfkP6
ooooo`03o`000?oooooooooo02gooooo0009ooooo`0400000?ooooooooooooooo`P06ATI00?o0000
03<c<`0c<c<04P0c<c<200000140C4a<00?o00000000000c<c<01P0c<c<00`0000006ATI01TI6@06
01TI6BT00000200I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<00000
06IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`;o0000202IVIT3o`0000H0VIVI00?o0000
07moO`1oOgl00`1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<01?ooool00`00003oooooooooo`0kooooo`?o00006?ooool40;bF[`@0aJ>f00D0_:G1
0<B^a034[/@0a:k40:bTc`020:ZZe`80PXoH0P1QM=02055SaP80HfK10P1WI;/3075U]P<0O6Vb00<0
Rg:a08M^[`2BM:d00P2BM:d309aj[0<0YH2[0P2]QZ`00`2aR:X0^8n[0;R?Z`020;R?Z`080;jE[@35
VZ`0aIZ/0<FJ[039X:h0dJN^o`00003AYjh40=bf/@030>K1/@3T`kH0k<ng00<0l]^h00<0mNNioooo
ooooool01?ooool00ol0003oooooooooo`0/ooooo`002Oooool01000003oooooooooooooool601TI
6@;o00005`0c<c<6000000H0C4a<1@00000603<c<`0300000?l00000000000L06ATI00<00000o`00
00000000:@00000801TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`00`00
0000IVIV06IVIP0206IVIP;o0000101oOgl2o`0000`0VIVI0ol0000407moO`;o0000101VIVH00ol0
0000C4a<04a<C00204a<C0040000000c<c<0<c<c03<c<`Cooooo00<00000ooooooooool0>Oooool2
o`0001_ooooo00@0^8jZ0;bF[`2lUZl0_9J_1035XkH30<B^a0030<^kc02ZZ]L0ZZ[G0080ZZ[G0P22
SmP2065dd080DF?60P1SI/4206MT^`80LFFf0`1lJK8308M^[`80TWB]0`2LNZ`30:F0Z`030:f6[02a
R:X0/HRZ00@0^8n[1035VZ`20=6W[P03o`00003AYjh0fk6^0080g;Ja0P3V`K420>c?]`<0l]^h00<0
mNNi0?C`^@3_mk/01?ooool00ol0003oooooooooo`0/ooooo`002Oooool01000003ooooooooooooo
ool501TI6@03o`00000c<c<0<c<c00P0<c<c2_l0000;03<c<`H000002P0c<c<00`0000006ATI01TI
6@0701TI6Bd00000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<0
000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0307moO`?o00001P2IVIT3o`0000H0Ogmo00?o
000006IVIP1VIVH00P1VIVH2000000@0C4a<00<0000003<c<`0c<c<00P0c<c<4ooooo`0300000?oo
oooooooo03Kooooo0ol0000Looooo`80^8jZ0P2lUZl20<NO[P80aJ>f0P3A/;T01034[/@0bk_<0<^k
c03;^l`20:ZZe`030:6`hP1]R]d0KH[M0080HGC@0P1AHlH204mJ_P80IfBk0P1aIKH307aY/P<0Qfj_
0P2BM:d409aj[080YH2[102aR:X30;R?Z`@0aIZ/0P3AYjh01?l00000fk6^0=^a[P3L][430>K1/@05
0>o?/P3/ckL0l]^h0?;K^03eikT00P3dl;T00`3_mk/0io_00>3nb@03ooooo`03o`000?oooooooooo
02_ooooo0009ooooo`0400000?ooooooooooooooo`@06ATI00?o000003<c<`0c<c<01@0c<c<4o`00
00X0C4a<00?o000003<c<`0c<c<05P0c<c<2000000T06ATI;`00000801TI6@030000000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`00P1<C4`2000000@0IVIV00?o000007moO`1oOgl01@1oOgl6o`00
00L0Ogmo0_l0000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00`0c<c<01Ol0
003oooooooooooooool0000003Gooooo0ol0000:ooooo`0308b>d01ZNM00JWW@017ooooo102hSZX0
102lUZl0ain^0<NO[P35XkH30=6`^@050=g3_P3;^l`0bk_<0<^kc03>c=P00`2Q/>801@1]R]d0AfS@
04MXd017J=00DF?60080CeZn0`1HFKT2075U]P<0O6Vb0P27KZl3099d[@<0W7Z/00<0YH2[0:R2Z`2X
PZ/00`2aR:X20;R?Z`80_YB[0P35VZ`20<fR[0040=6W[_l00000fk6^0=^a[P<0i/6a0P3_ck800`3f
gK80l]^h0?GW^@020?C`^@040>og^`3Wnl00h?k90=[me`80eOOS00?oooooo`000?ooool0;?ooool0
00Wooooo00@00000oooooooooooooooo0P0I6AT2o`0000D0<c<c0ol0000?04a<C0;o00004P0c<c<0
1000003o000000000000000:01TI6@03o`0000000000000002h00000200I6AT00`000000<c<c03<c
<`0303<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH4o`0000h0Ogmo0_l0
000506IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00`0c<c<00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo037ooooo0_l0000;ooooo`050::Fb@2<S]00S8k@08b>d01ZNM00
0`1;G/D=ooooo`030;25Z02hSZX0^8jZ0080^8jZ0`37Wjh40=6`^@80gL>n00@0bk_<0<k<f03>c=P0
c/cH0P2Q/>8206f:g@80AfS@00@0=E?4055SaP1?F[h0CeZn0P1HFKT00`1UGKD0LFFf07aY/P0207aY
/P<0Qfj_0P2BM:d209aj[00409ijZ`2XPZ/0Z8:[0:R2Z`<0/HRZ00D0^8n[0;jDZ`2nU:/0_YB[0<FJ
[0030<fR[0060=6W[P3K/Jko00000=^a[P3U_Zl0i/6a0`3_ck80203fgK80n>Z`0?Cc[03dl;T0koNk
0>Ok`03Po/T0f_gG0P3Emn<20<kXj003ooooool0003ooooo02_ooooo0009ooooo`0400000?oooooo
ooooooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00A04a<C003o`00000c
<c<0<c<c00`0<c<c1000000=01TI6C800000200I6AT00`000000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH01@1VIVH3o`0000T0Ogmo0_l0000506IVIP8000001@1<
C4`00`000000<c<c03<c<`0403<c<`0300000?oooooooooo00;ooooo00<00000ooooooooool0;_oo
ool3o`0000_ooooo00@0ZiK00::Fb@2RU/T0XYK90`2<S]000`1ZNM00Bek504]Na@0204E@^@[ooooo
0`2`QJP30;R>ZP<0ain^00<0eZja0=6`^@3A/;T00`3M`kh30<k<f0030<GLj@2;/O00Rk7`0080BgkQ
0`17J=000`0eDl@0CeZn04mJ_P0205QI^@80IEfe0`1lJK8308M^[`80TWB]00<0W7Z/09ijZ`2NNZ/0
0`2XPZ/30;68ZP@0_YB[00@0aIZ/0<fR[03=XZ`0cJ:/0P3K/Jh01?l00000iKj_0>Fn[`3V`K420>o?
/P80m]fb00P0n>Z`0?Cc[03ZmjT0g_VZ0=Gk/P3Bo/@0d_kJ0=Ggh`80c^SX00@0aLoRoooooooooooo
0000:oooool000Wooooo00H00000oooooooooooooooo01TI6Ol0000403<c<`;o0000101<C4`8o`00
00T0C4a<00?o000003<c<`0c<c<02@0c<c<2000000l06ATI=@00000801TI6@030000000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`00`1<C4`2000000P0IVIV2Ol0000606IVIP030000001<C4`0C4a<
00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATIooooo`03ooooo`0300000?oooooooooo
02cooooo0_l0000<ooooo`@0ZiK00P2RU/T208b>d00408R9cP1CJlh0Df_>04]Na@80AE2i00<0FEBb
ooooooooool01_ooool40;25Z080^8jZ0P34V:X01@37Wjh0eZja0=J^/@3F[[40dK2i00<0gL>n00<0
im[70<k<f035g>T00P35g>T208^al080BgkQ0P0PE/d0100eDl@0=Tbl03I<_00fC;`205QI^@0406EM
]@1dI;80M6Bb07AT/P<0Pf^_0P2ALjd309ijZ`@0Z8:[0P2aR:X0102gSJ/0_YB[0;jDZ`2nU:/40<fR
[0030=N][@3K/Jko00000080iKj_0P3`cZl00`3_ck80m]fb0?SZ/0020?Cc[0070>[gZ@3NnJX0eO^b
0=;na03Bo]X0dO;X0<kXj0030<G?hP03ooooool0003ooooo02[ooooo0009ooooo`0500000?oooooo
ooooooooool00000100c<c<00ol00000C4a<04a<C00204a<C0;o0000201VIVH3o`0000H0C4a<00?o
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0=01TI6CL000002@0I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH04`1VIVH00ol00000C4a<04a<
C00404a<C003o`00000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01?ooool00`00003ooooooooo
o`0Yooooo`?o00003Oooool20:fA^P<0ZiK000<0XYK90:BC``28RLh00`28RLh0101CJlh06T:m04]N
a@15D;T205UD/PKooooo00<0XW^X0;25Z02`QJP00P2`QJP01@2hSZX0a9RZ0<BHZP34V:X0ain^00<0
eZja0`3M`kh20>OJa`80io3B00<0aMcY0:WPnP2Yh?X00P1PY_H201YXf`03021Fc@0?@;h0=E?40080
=Tbl00@0@Tjh05QI^@1UGKD0IEfe0P1dI;8308=[[`<0TG>]0`2NNZ/30:R2Z`030;68ZP2gSJ/0]hf[
00<0_YB[00<0aib/0<fR[03=XZ`00`3G[Jd00ol00000iKj_0>Fn[`020?3>[`090?SO[P3fgK80n>Z`
0?Cc[03ZmjT0g_VZ0=Gk/P3Bo/@0d_kJ0080dO;X00@0b=GT0<G?hP35cn80^kCB0_ooool00ol0003o
ooooooooo`0Xooooo`002Oooool01000003oooooooooooooool303<c<`;o00000`1<C4`2o`0000d0
IVIV0_l0000504a<C003o`00000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0300I6ATj000000T0
6ATI00<0000003<c<`0c<c<0100c<c<2000000D0C4a<00@00000o`00000000000000301VIVH50000
00D0C4a<0P00000603<c<`0400000?l000006ATI01TI6@Cooooo00<00000ooooooooool09oooool2
o`0000kooooo00<0Zhbe0:fA^P2]TKX00P2]TKX00`2[U/00[Y:i0:BC``020:BC``<0R8W>00<0Df_>
01Y2_@0J@[d00P15D;T00`1IE;80MF6]07EQ[@0308m_ZP80XW^X102`QJP40<BHZP@0eZja00<0i/Fe
0=g3_P3Wf/L00P3Wf/L0103Wl=80d_gO0=;mg`2Yh?X207K?o`809h_/00@06VSK000l`@0PE/d03d2n
0P0fC;`2049>^080IEfe0P1dI;8308=[[`<0TG>]0`2NNZ/20:R2Z`040:f6[02gSJ/0]hf[0;N=Z`80
_YB[0P37W:`20<fR[0<0ejf]00?o00000>Fn[`3`cZl00P3`cZl01`3hgjh0nNbX0?SZ/03dlj`0j_NY
0;[/T`34oLP00P3>nnD0103Al^P0b=GT0<SEi02k/m830;^ddP;ooooo00?o0000ooooooooool09ooo
ool000Wooooo00@00000oooooooooooooooo0`0c<c<00ol00000C4a<04a<C002o`0000@0IVIV2?l0
000506IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI
6@0:01TI6Cd000002P0I6AT00`000000<c<c03<c<`0503<c<`8000001`1<C4`6000000<0IVIV0`00
000904a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT00P0I6AT4ooooo`0300000?oo
oooooooo02Cooooo0ol0000>ooooo`040:J6/P2[S;D0Zhbe0:^<]@80[I6j00@0/8jb0:jB^@2^T[T0
[Y:i0`2TTl<02028RLh0RX_>03aSd01CJlh06T:m00``/015D;T0FEBb0P1eHJd308m_ZP<0XW^X0`2`
QJP40<BHZP030=B[[P3F[[40eZja0080i/Fe0P3chKT01@3Wf/L0io3B0=;mg`3BoMl0ZOO/00<0O>7f
00L0@:of02N;k000BlP06VSK000l`@0?@;h04SZh0080=Tbl00<0@Tjh05EE]@1EEKD00`1dI;8308=[
[`80TG>]0`2NNZ/00`2XPZ/0[HJ/0:f6[0040;N=Z`050;jDZ`37W:`0aib/0<NL[03=XZ`00`3G[Jd0
1?l00000iKj_0?3>[`3`cZl20?SO[P050?W/Z03_lih0fo6C0<O/S@2jk9<00P3>nnD20<WMi`060<SE
i02k/m80^k?B0;^cdP2k]=80/ig10_ooool00ol0003oooooooooo`0Wooooo`002Oooool01000003o
ooooooooooooool203<c<`04o`00001<C4`0C4a<o`0000<0IVIV0ol0000807moO`?o00000`1VIVH0
0ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AU0
000000X06ATI00<0000003<c<`0c<c<01P0c<c<2000000/0C4a<0`00000:04a<C08000001`0c<c<0
0`0000006ATI01TI6@0301TI6@Cooooo00<00000ooooooooool08_ooool2o`00013ooooo0P2VQ[83
0:^<]@030:fA^P2`S[80/8jb00<0[Y:i0P2TTl<01P2ZU;l0RX_>08Z;cP2:Rlh0?6?@01Y2_@80332`
0P1IE;80101eHJd0SfnZ08m_ZP2?KjX30:9kZ080/8FX0P2kT:T20<BHZP80e:^^00@0eZja0>K5]@3V
aKD0i/Fe0P3chKT00`3_mkP0d_^c0:cd^P0208o_e@80O>7f0P1Ka_X0200MTnX006_G001;b000?<40
02Ja00m0_P0B>[P0=Tbl0P12C[P205EE]@80M6Bb0`23Jjl3095c[@80WWZ[102]QZ`30;N=Z`@0aib/
0`3G[Jd0103S_:oo00000>Fn[`3`cZl20?SO[P80nNbX00@0ko>N0=_aT`2jk9<0`?kL0P37ind00`39
gNL0^[GE0;^cdP020;^cdP040;2I_`2cWL40/ig10;>M`@;ooooo00?o0000ooooooooool09_ooool0
00Wooooo00H00000oooooooooooooooo03<c<ol0000204a<C005o`00001VIVH0IVIV06IVI_l00000
3P1oOgl01Ol00000IVIV06IVIP1VIVKo000000<0C4a<00?o000003<c<`0c<c<00`0c<c<00`000000
6ATI01TI6@0801TI6D40000000?o000001TI6@0I6AT0200I6AT00ol00000<c<c03<c<`0703<c<`03
0000001<C4`0C4a<0180C4a<0P0000000ol00000<c<c03<c<`0603<c<`030000000I6AT06ATI00@0
6ATI1?ooool00`00003oooooooooo`0Oooooo`?o00004?ooool00`2QPK40YXJb0:J6/P020:J6/P80
Zhbe102`S[820:jB^@@0ZYBo0P2:Rlh01P0lHm00022/01Y2_@0<<;00;Sf`05UD/P80MF6]0`2?KjX2
0:9kZ0050;25Z02kT:T0^i2Y0;^@Z@34V:X00`3DZjh00`3Yak<0i/Fe0>K5]@030??Q^@040>og^02/
m;X0PNWL087Yg080O^?c0P1fdOl204fcnP0500n6i000E<@002j]000OZ@009[400P0B>[P2049>^080
EEFe0P1[Gk<308=[[`<0TG>]00<0WWZ[0:1n[@2POZd00`2]QZ`20;N=Z`030;nF[@37W:`0aib/0080
aib/00P0dZR^0=N][@3S_:l0hkb_o`00003`ck00l<j_0?SO[P80nNbX00@0ko>N0=_aT`2TkZX0`?kL
0P37ind01@2i^m/0^[GE0;Zee@2j]MD0^k?B0080/9Vo0`2cWL43ooooo`03o`000?oooooooooo02Go
oooo0009ooooo`0600000?ooooooooooooooo`0c<c?o00000P1<C4`01Ol00000IVIV06IVIP1VIVKo
000000<0Ogmo2?l0000407moO`04o`00001VIVH0IVIVo`0000<0C4a<00?o000003<c<`0c<c<00`0c
<c<00`0000006ATI01TI6@0701TI6D@000002P0I6AT2000000P0<c<c00?o00000000000000003`1<
C4`2000000X0<c<c00<0000001TI6@0I6AT01@0I6AT4ooooo`0300000?oooooooooo01cooooo0ol0
000Aooooo`0309]l/02QPK40XH6a00@0YXJb0P2[S;D40;2>/P030:jB^@2dTk@0]9>d00<0ZYBo00H0
RX_>09BDd00^I]L0;VKG000P[00<<;0202hm/080MF6]0`2?KjX20:9kZ0@0^i2Y00@0a9RZ0=B[[P3D
Zjh0e:^^0P3Yak<01@3VaKD0ln6i0??Q^@3_mkP0J=Vl0080SNSg0P2:hO`208c?oP80ML;n0`1>ZoT0
1@0BQNH004^j000OZ@009[404SZh008093ng0P1EEKD206]O/`<0OfZa0`2AM:l30:1n[@<0[HJ/00@0
]hf[0;nF[@2oUZd0_iJ]0P37W:`20=:X[P080=N][@3S_:l0hkb_o`00003`ck00nN:^0?SO[P3ik:P2
0>ocWP040:;DJ`2ol_40_o;a0<OWk@<0^K_K00<0^[GE0:fG`02`VKl00`2`VKl20;>M`@?ooooo00?o
0000ooooooooool09Oooool000Wooooo00D00000ooooooooooooooooo`00000204a<C005o`00001V
IVH0IVIV06IVI_l000000P1oOgl2o`0000P0VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP05
o`00001<C4`0C4a<04a<C?l000001@0c<c<00`0000006ATI01TI6@0601TI6DH000002`0I6AT00`00
0000<c<c03<c<`0803<c<`L000000`1<C4`5000000/0<c<c00<0000001TI6@0I6AT01P0I6AT4oooo
o`0300000?oooooooooo01[ooooo0_l0000Booooo`0309Ii/@2KO;00Vgb`00<0XH6a0`2VQ[800`2[
S;D0[HR^0:f8[P030;2>/P@0]9>d00<0ZYBo0;BJ_@2DU=000P2DU=0202iVe`80332`00<0;Sf`06=J
/P1SF[800`2?KjX00`2RNjP0ZhB/0:^4[0030;^@Z@<0e:^^0`3Yak<0103gj;<0ln6i0>;eWP2Zggl2
09_Jo@<0UmOm00<0S<on08k3n@2>`oT00P1j^o/305N[n@04022>k000Ck/002Ja018j^0<093ng0P1E
EKD206]O/`80OfZa0`2AM:l30:1n[@<0[HJ/102oUZd01037W:`0dZR^0=:X[P3BZ:h30>>l[`04o`00
003`ck00nN:^0?K`X`80hNn@00@0`>9i0:Wfk`2ol_40]/CT0`2i^m/0102YUl@0[IO00:fG`02]Ul03
0;2I_`030;>M`@2_S[<0[hjc00?ooooo00?o0000ooooooooool09?ooool000Wooooo00@00000oooo
oooooooooooo0`1<C4`01?l00000IVIV06IVI_l0000207moO`03o`00002IVIT0VIVI00T0VIVI00Go
000007moO`1oOgl0Ogmoo`00000206IVIP05o`00001<C4`0C4a<04a<C?l00000100c<c<00`000000
6ATI01TI6@0501TI6DP000002`0I6AT2000000l0<c<c0`00000>03<c<`8000002@0I6AT4ooooo`03
00000?oooooooooo01Oooooo0ol0000Aooooo`@0UWVa0`2KO;020:61/@80YXJb00@0Yh6[0:f8[P2]
R:h0[HR^0P2`S[800`2eSZd0]9>d0;BC]0020;BC]0<0]9Zm0`2DU=0202iVe`0400``/00^?K00HeZb
06=J/P<0Sg>_0`2[Q:`30;^@Z@030<fU/03DZjh0e:^^00<0jLNc00D0mnRc0>;eWP3RmIh0W=Wm09_J
o@030:3:mP80V/Sg00<0S/?i09:nm@21^OP00`21^OP206F_nP0403NKl`00G/D002Ja018j^08093ng
00@0?Tbh05EE]@1[Gk<0Jenc0P1oJ[44095d[`<0X7j]0P2]QZ`0102cSZl0_iJ]0;nF[@2oUZd40=:X
[P040=ni/@3S_:oo0000o`000080nN:^00@0m_2S0>7_T03Qki00ZOK_0P2`d?420;K4i0030;Vkf`2Y
Ul@0ZIO400<0[IO00P2`VKl0102ZR;40[hjc0:n>/`2_S[<4ooooo`03o`000?oooooooooo02?ooooo
0009ooooo`0400000?ooooooooooooooo`80C4a<00Co000006IVIP1VIVKo00000P1oOgl00ol00000
VIVI09VIV@0209VIV@D00000102IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV00Co000004a<
C01<C4co0000100c<c<00`0000006ATI01TI6@0401TI6@03o`0000000000000004H0000000?o0000
01TI6@0I6AT02P0I6AT2000001X0<c<c1000000;01TI6@05o`000?ooooooooooooooo`0000006?oo
ool2o`00017ooooo00<0VGZ_09Ii/@2FNK40102FNK4209]l/080XH6a0`2WPJ/30:f8[P040;2>/P2e
SZd0]Hj]0;F>[@80]9>d00@0_9Na0;BJ_@2dV[d0]9Zm102VY=@203IniP80;Sf`0P1SF[8208mc[`<0
ZhB/0P2kT:T30<fU/0030=B[[P3Yak<0jLNc0080mnRc00@0h_FN09cIo@2Tbo@0Y<_d0P2Pb_H0102R
`_00W<3b09c0lP2L`?8209:nm@80PKWh00L0R[We07Bdn@1d]?T0M;Ci056Yn@0029L0026]008093ng
0P0nC;P206]O/`<0OfZa0`2AM:l30:1n[@030:f6[02cSZl0/hj_00<0_iJ]00<0bJ:a0=:X[P3BZ:h0
0ol00000103S_:oo00000?WR[P3fl:<20>7_T0040:CLn`2`d?40/=3a0:6Se`80YI_;102YUl@20:fG
`0<0ZXRa0`2_S[<4ooooo`03o`000?oooooooooo02?ooooo0009ooooo`0400000?oooooooooooooo
o`80C4a<00Co000006IVIP1VIVKo00000P1oOgl01Ol00000VIVI09VIV@2IVIT0000000D0/k>c00D0
000009VIV@2IVIT0VIVIo`00000307moO`04o`00001VIVH0IVIVo`000080C4a<00?o000003<c<`0c
<c<00P0c<c<00`0000006ATI01TI6@0401TI6D`00000300I6AT3000001H0<c<c00<0000001TI6@0I
6AT03@0I6AT01Ol0003oooooooooooooool0000001Sooooo00?o0000ooooool000003_ooool00`2M
NZ/0VGZ_09Uj[`0609Ii/@80Vgb`00<0XH6a0:1kZP2PNjX00`2WPJ/20:f8[P@0]Hj]00@0]9>d0;bG
/@2lUk40_9Na0P2dV[d02030Y;`0YZCD0:JTe02VY=@0_;SF05fYn0004j80;Sf`0P1SF[8308mc[`<0
ZhB/00@0^i2Y0<fU/03=YK00cJF`0P3Yak<20?OX/`040>;eWP2Wbo<0Yl_c0:C;m0<0YL;^0P2R`_00
0`2L`?80W[_]09jkk@0309Nkl@80R[We00D0M;Ci08BhmP24^?H0Q;Sf0002T`02000[/@0302@o]`0n
C;P0GE^h0080GE^h0P1oJ[43095d[`80X7j]00@0YHBa0;>>[`2cSZl0/hj_0P2oUZd01039X[7o0000
o`000?l000030=ni/@80l<n`00Go00000?K`X`3Qki00000009^_i@040:6Se`80YI_;0`2YUl@00`2]
Ul00Y8Ba0:B4/@030:Z8/@80[hjc00<0[hJZooooooooool00_ooool00ol0003oooooooooo`0Roooo
o`002Oooool01P00003oooooooooooooool0C4a<o`000080IVIV00Co000007moO`1oOgoo00000`2I
VIT00`000000/k>c0;>c/`050;>c/`050000002IVIT0VIVI09VIVOl000000`1oOgl01?l00000IVIV
06IVI_l0000204a<C005o`00000c<c<0<c<c03<c<`0000001@0I6AU>000000h06ATI0`00000A03<c
<`8000003`0I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo01Kooooo00Co0000oooo
oooooooo00002oooool00`2PNJL0WGZ[09ejZ`0309Uj[`D0UWVa00<0Vgb`09UfZ@2PNjX00P2PNjX3
0:N1Z`80[HR^00@0/HRY0;F>[@2eSZd0]Hj]102lUk401@2dV[d0`:Bl0<2T_030Y;`0YZCD00<0_;SF
00@0GJWh000CXP1SF[80HeZb0`2?Ljl20:^4[0030;ZJ^03=YK00cJF`0080cJF`00H0i/Zj0>W7/`3g
j;<0mnRc0:c=l@2Wbo<20:S3k@80YL;^00D0Y[gY0:>lj`2S_>/0Xkc[09jkk@020:6fi`<0W;O[0P2C
^?0208BhmP0309:gl021^OP000:C008002^a0P0nC;P205eK^080NF^g0P2AM:l0102ANK@0YHBa0:F4
/@2UQ;430;>>[`?o00000P39X[401@3BZ:h0gkVa0=ni/@3O^K40k]2d0080nN:^00?o00000000002D
_?<00P2K[nD30:6Se`80YI_;0P2YUl@0102NPK<0Y8Ba0:B4/@2TQ;430:Z8/@030:n>/`2_QZX0[hJZ
00Cooooo00?o0000ooooooooool08_ooool000Wooooo00P00000oooooooooooooooo04a<C?l00000
IVIVo`000080Ogmo0_l0000209VIV@03o`00002c/k<0/k>c00L0/k>c0P00000209VIV@04o`00001o
Ogl0Ogmoo`000080IVIV00Co000004a<C01<C4co00000`0c<c<00`0000006ATI01TI6@0301TI6E00
00003`0I6AT01000003o000000000000000903<c<`0400000?l000000000000001006ATI00?o0000
00000?ooool00oooool00`00003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000002?oo
ool00`2NMJ@0X7VW0:1iY`0309ejZ`80VGZ_102FNK400`2DLZX0VGJY09UfZ@030:1kZP<0Yh6[00<0
[HR^0;68Z@2aR:T00`2eSZd0102lTZ/0_9Na0;bG/@2lUk440<2T_0<0_;SF0P3@b]@0102Bd_h0>E;1
03UB`@1SF[8208mc[`030:^4[02jV[P0^YZh00<0cJF`0P3Vb[X20?;e]P040:cMN@2/aN`0[<G/0:S3
k@80Z;kY0`2V_NT00`2S_>/0Y;GU0:6fi`030:6fi`0309bgj`2R/>80W;?X0080W;?X0`2B]o001@21
^OP000:C000[/@0J?[X0?Tbh0080GE^h0P1iJkL4095i]080YHBa0ol000000`2cSZl0bJ:a0<VR/@02
0<VR/@<0gkVa0P3^d;@01@3hik80k_>P0<KUO_l00000QiSM0080Rh_>0`2AQ<8209R1^@<0WX6c0`2T
Q;430:Z8/@<0[hJZ1Oooool00ol0003oooooooooo`0Qooooo`002Oooool02000003ooooooooooooo
ool0C4a<o`00001VIVKo00000P1oOgl01Ol00000VIVI09VIV@2IVIT0000000T0/k>c00D0000009VI
V@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIVo`000080C4a<00Go000003<c<`0c<c<0<c<c
0000000501TI6E4000004P0I6AT9000001@06ATI00?o000000000?ooool00oooool00`00003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool209ieY0<0X7VW
0P2MNZ/209Uj[`80UWVa00<0Tg:Z09AbZP2DLZX00P2IMZT40:1kZP80Yh6[0`2aR:T20;F>[@80_9:[
0`2lUk400`36Wk00`:Bl0<2T_0020<ja_0060;bheP3@b]@0d<[D0=3:e03NfM4001>R0P0iD/400`2?
Ljl0T8C20;ZJ^0030;ZJ^0040<fU/03Vb[X0i/Zj0>K:^P80l_Ff00@0//W[0:c5k02[`>T0Zl3Y0`2X
_^T00`2V_NT0Y[KT0:Jfi0020:Bei@80XKKW00D0Y:cM0::`hP2R/>80X[3R09bcj0020:B[g0<0W[;V
00@0U;S`000[/@0J?[X06Sjj0`1MFkP207U[]`80TGVd0ol00000102UQ;40/hj_0;>>[`2mVkD40<VR
/@030=Rf]`3O^K40k]2d0080k]2d00@0n>Nb0>kcX025Yn_o00000P27V=d208^;cP80THC20`2HPKT3
09j1/`<0Y8Ba00<0ZXRa0:QoY`2_QZX00`2_QZX5ooooo`03o`000?oooooooooo023ooooo0009oooo
o`0800000?ooooooooooooooo`1<C4co000006IVI_l0000207moO`05o`00002IVIT0VIVI09VIV@00
00002@2c/k<01@000000VIVI09VIV@2IVIWo00000080Ogmo00Co000006IVIP1VIVKo00000P1<C4`0
1Ol00000<c<c03<c<`0c<c<0000000D06ATI;@00000501TI6B000000;P0I6AT00ol000000000oooo
o`03ooooo`0300000?oooooooooo01Gooooo00Co000005][b@1NG;P0GUbh0oooool01Ol0003ooooo
ooooooooool0V6nR00<0WWFT0`2PNJL209ejZ`0309Uj[`2IMJP0Tg:Z0080Tg:Z0P2DLZX309UfZ@<0
X7^Z00<0Yh6[0:^1Y`2aR:T00`2aR:T01@2eSZd0_9:[0;bBZ`2lTZ/0_9Na0080aYn`00@0`:Bl0<ja
_03>/K`0c[6l0P3L_k`0103@b]@0g]WA0=kId@3Vhll203UB`@<0T8C20`2jV[P00`3=YK00i/Zj0>K:
^P020?;e]P040;;9j`2_a>T0[lCY0:_0j@80ZK[U0`2X]n@00`2V]^@0YJ[J0:F[f`020:F[f`<0Y:cM
00<0X[3R0:JTd`2TZm`00`2TZm`01@2N/^H0Z:[H0::di@2E700002^a00806Sjj0P1MFkP01@1iJkOo
0000o`000?l00000TGVd00<0YHBa00@0/hj_0;fK]@2mVkD0_I^e0P39X[420=Rf]`060=ni/@3^d;@0
k]2d0?SW/P3^lj00a^En0P1dRm/01?l00000QiSM08^;cP2;Rlh30964`P80V86i0`2NPK<20:B4/@04
0:5jY`2XOjL0Z7nW0:QoY`<0[hJZ1Oooool00ol0003oooooooooo`0Pooooo`002Oooool01@00003o
oooooooooooooooo00000080IVIV00Co000007moO`1oOgoo00000P2IVIT00`000000/k>c0;>c/`09
0;>c/`040000002IVIT0VIVIo`000080Ogmo00Co000006IVIP1VIVKo00000P1<C4`01Ol00000<c<c
03<c<`0c<c<0000000@06ATI:000000>01TI6Al00000;00I6AT00ol000000000ooooo`03ooooo`03
00000?oooooooooo01Gooooo00Co000005][b@1NG;P0GUbh0P1]Fj`2ooooo`04o`00002>J:<0V6nR
09Q_XP@0WWFT0P2PNJL00`2MNZ/0X7RV09UeZ00209UeZ080Tg:Z0`2DLZX209UfZ@80X7^Z00@0XWVV
0:^1Y`2[PJL0Zh6W0`2aR:T40;bBZ`<0aYn`00@0dZ^`0<ja_03>/K`0c[6l0P3L_k`00`3Xckd0g]WA
0>KSc`020>KSc`0403UB`@2@Q<80T8C20924`P<0^YZh0P3Gc]401P3Vb[X0l_Ff0;C9jP2dbNX0[lCY
0:bni`@0ZK[U00<0Z;OT0:F/g02UZ]X00P2UZ]X30:F[f`030:B/g@2VW/h0YZCC0080YZCC0P2TZm`0
1P2ZWl`0Z:[H0:RZf02XZ]P0X[CU08lG00806Sjj0ol000000`1iJkL0TGVd095i]002095i]080YHBa
102mVkD01P39X[40f;Jg0=Rf]`3H][L0jM6m0>k@]080n>Nb00H0k_>P07ZNj@1dRm/0M8_K07Akc?l0
000307Yb_P80THC20`2HPKT209j1/`030:B4/@2QNZL0XGZW00<0Z7nW0P2_QZX00`2bQ:Cooooooooo
o`04ooooo`03o`000?oooooooooo01oooooo0009ooooo`0500000?ooooooooooooooool000000P1V
IVH01?l00000Ogmo07moOol0000209VIV@030000002c/k<0/k>c00T0/k>c00@0000009VIV@2IVIWo
00000P1oOgl01?l00000IVIV06IVI_l0000204a<C005o`00000c<c<0<c<c03<c<`000000100I6ATU
000001@06ATI00?o00000000000000006@0000000ol0000000000000000Y01TI6@03o`000000003o
oooo00?ooooo00<00000ooooooooool05Oooool01?l0003ooooo05][b@1NG;P206eK[080Of6U0P2>
J:<209Q_XP@0WWFT0P2PNJL20:1hYP<0VGFX0`2CLZX209AbZP80VGJY00<0X7^Z0:9iYP2RNJH00`2[
PJL20;68Z@030;R;Y`2lTZ/0_9:[0080_9:[0`36Wk020=:[/0050<ja_03L_k`0g;nl0=bo_03Xckd0
0P3`gKd0103Vhll0jN[?0>O^dP0iD/430924`P070;ZJ^03Gc]40elkA0=O>d@2onkd0_=;[0;C9jP02
0;33j080[;kW0P2Y^^D01P2V/=l0YJcL0:F/g02U[=`0YJ[J0::Jc0<0Y9_;0`2VW/h00`2VY=<0ZIK3
0:VF``030:ZOc0030:RZf02`XLT0[JgH00?o000000<06Sjj04IG`01`Kl800P1`Kl83095i]0030:F4
/@2/TKX0[96j00<0_I^e103H][L0103YdKd0lnnl0??__03hik8206F7g`<0FW7@00@0M7_<o`00001j
L[h0NW:n0P23Kk@308ia[P80V7BY0`2QNZL30:QoY`040:n6ZP2bQ:@0/XBT0;:4Y0Kooooo00?o0000
ooooooooool07_ooool000Wooooo00D00000ooooooooooooooooo`00000206IVIP04o`00001oOgl0
Ogmoo`000080VIVI00<000000;>c/`2c/k<02@2c/k<010000000VIVI09VIVOl0000207moO`04o`00
001VIVH0IVIVo`000080C4a<00Go000003<c<`0c<c<0<c<c0000000401TI6B<000006@0I6ATN0000
02L06ATI00?o000000000?ooool00oooool00`00003oooooooooo`0Eooooo`03o`000?ooool04cJd
0080GUbh00<0KE^/07mQY@1oHJD00P2>J:<309Q_XP<0WWFT0P2PNJL20:1hYP<0VGFX0`2CLZX209Ab
ZP0309UfZ@2ILZH0XWVV0080XWVV0`2[PJL0102aR:T0^8^W0;R;Y`2hRjL20;bBZ`80aIVZ00@0aYn`
0=:[/03BZk00dZ^`0`3L_k`20>S?_@80l=fm00@0lnVn0?3b`@3`l/40j_S90P2@Q<801P27^_H0elkA
0=O>d@3Gc]40_o^m0;cBj`80]<[Z00<0/<?X0:^ki@2[^nD00`2X]N820:J`g`030:F/g02QVll0XY[<
0080XY[<0`2TVl/00`2VW/h0YXnm0:VF``030:VF``030:ZOc02_U[d0/:7900;o000000@0[JgH0;FX
c02?5`0002Nb0P16El02071_`P<0TX>o0`2/TKX30;fK]@030<b`_`3H][L0f;Jg0080jM6m0P3ckk`0
103JmIh0HhoV06F7g`1UQml205Yad00405]R`Ol00000NW:n07Yb_P<0Pfnd0P2>LJh309QdZ@<0XGZW
0P2XOjL40;:4Y0Kooooo00?o0000ooooooooool07_ooool000Wooooo00H00000oooooooooooooooo
04a<C?l0000206IVIP04o`00001oOgl0Ogmoo`000080VIVI00<000000;>c/`2c/k<01`2c/k<01Ol0
0000VIVI09VIV@2IVIWo00000080Ogmo00?o000006IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c
<c<0000000D06ATI8@00000701TI6@ko00001`0I6ATO000002H06ATI00?o0000ooooooooool00_oo
ool00`00003oooooooooo`0Eooooo`06o`000?oooooooooo02H`Y@1NG;P0KE^/0P1oHJD308iXX`80
V6nR0`2NMJ@00`2PNJL0Y7RR0:1hYP020:1hYP<0VGFX0P2CLZX0102DLZX0TVjV09UbYP2ILZH40:9i
YP80Zh6W102hRjL01@2lTZ/0aIVZ0<FIZP35VJX0aYn`00<0dZ^`00@0gkVa0=bo_03Xckd0j<nm0`3`
gKd01P3cjKh0l?;10>[hb@3Zn<T0h_WF0=OdhP80Qk[f00H0elkA0;[Bk02jd^`0^];/0;C:jP2^`^P4
0:^ki@040:RehP2QZ=/0X:3D0:2Pe0<0XI_?0`2RV/`00`2TVl/0XXZk0:J?_@020:J?_@80ZIK300@0
[8bdo`000?l0003o00000P2`XLT0102gW;d0]JS<0;FXc0009k8201U?b@80L6o20`2BPkl40:bA^P06
0;fK]@3</;l0c;2o0<b`_`3H][L0jM6m0`3ckk`01020Ynd0HhoV04I_e`16KmL205Yad080Ff;100?o
000007Yb_P1jL[h00P23Kk@208ia[P<0V7BY0`2QNZL20:QoY`@0/XBT1oooool00ol0003ooooooooo
o`0Mooooo`002Oooool01P00003oooooooooooooool0C4a<o`000080IVIV00Co000007moO`1oOgoo
00000P2IVIT2000000P0/k>c00D0000009VIV@2IVIT0VIVIo`00000207moO`03o`00001VIVKo0000
0080C4a<00Go000003<c<`0c<c<0<c<c0000000501TI6B0000001`0I6AT00ol00000<c<c03<c<`0<
03<c<`03o`00000I6AT06ATI00D06ATI7P0000000ol0000000000000000T01TI6@05o`000?oooooo
ooooooooo`0000005_ooool01?l0003oooooooooooooool202H`Y@80KE^/0P1oHJD208iXX`80V6nR
0P2NMJ@0102RM9l0Y7RR0:AhXP2TN:820:1hYP80VGFX00<0VgBV099_Y`2BKjL00P2BKZH209UbYP@0
XWVV0P2[PJL40;R;Y`040;bBZ`35VJX0aIVZ0<FIZP<0dZ^`0P3O^K420>c;/P050>S?_@3`gKd0l=fm
0??Y_P3`l/400P3Zn<T0103RnMH0eoCR0=OdhP3;j^/30<3LkP030;[Bk02bbN/0[/;X0080[/;X0P2[
^nD0102T/>40XJSK0:6Xf`2QZ=/20:2Pe080XI_?0P2RV/`00`2NQk/0XXZk0:::^`030:J?_@?o0000
0`2_U[d01`2`XLT0]ibm0;NL_@2gW;d0]JS<0;jW``009k800P0IClT2071_`P<0TX>o0P2/TKX00`2g
YlT0c;2o0<b`_`020<b`_`040=kBc03YdKd0lnnl0??__080LYk/0P17ON802016KmL0=EC503EDa@1J
LM00Ff;106IN]Ol00000NW:n0P23Kk@308ia[P80V7BY0`2QNZL00`2XOjL0ZWfR0:YmXP030;:4Y0So
oooo00?o0000ooooooooool07?ooool000Wooooo00H00000oooooooooooooooo04a<C?l0000206IV
IP04o`00001oOgl0Ogmoo`0000@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@02
09VIV@06o`00001oOgl0Ogmoo`00001VIVKo00000P1<C4`01Ol00000<c<c03<c<`0c<c<0000000D0
6ATI7`0000000ol000006ATI01TI6@0301TI6@;o0000100c<c<8o`0000@0<c<c0_l0000501TI6B<0
00008P0I6AT01Ol0003oooooooooooooool0000001Kooooo00So0000oooooooooooooooo01<f]00V
<:D0CSnP06eK[080Of6U0P2>J:<209Q_XP0309ieY02RM9l0XWBO00<0Y7RR0P2PN:H00`2IMJP0VgBV
09]dYP02099_Y`80TVjV0`2ILZH30:9iYP030:^1Y`2`Q:D0^8^W00<0^8^W1035VJX00`3AYJ/0dZ^`
0=ni/@020=ni/@80k<^b00@0mMbb0?3M_@3hk;40l_F`0P3Wn[@01@3No/80eokF0<kgj03>mnP0a>O_
0080`=c^0P2fd>d20;;9j`030:k2j02W^ND0YkWU00<0Y;3Q0P2QZ=/0102PX=@0Uhg709Z8_`2JR;l3
09j7^`80XXZk0ol000040:b<]080[iJm102gW;d30;jW``806Do90P1MN=D309:3_`040:bA^P2gYlT0
]jO90;NWb@80c;2o0P3Nd/`00`3Vn/l0lnnl08R]kP0306:Fk00304MmhP0IDl`06E?<0080=EC50P1K
H/400`1VG[Go000008=_]00208=_]080SW6^0`2HM:T20:5jY`<0ZWfR0`2bQ:@00`2iQj7ooooooooo
o`05ooooo`03o`000?oooooooooo01cooooo0009ooooo`0600000?ooooooooooooooo`1<C4co0000
0P1VIVH01Ol00000Ogmo07moO`1oOgoo000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000
VIVI09VIV@0209VIV@04o`00001oOgl0Ogmoo`000080IVIV00Co000004a<C01<C4co00000`0c<c<0
0`0000006ATI01TI6@0201TI6B000000100I6AT2o`0000<0<c<c0ol0000804a<C0;o0000100c<c<0
0ol000006ATI01TI6@0301TI6B<000008@0I6AT4ooooo`0300000?oooooooooo01Cooooo00?o0000
ooooooooool00_ooool00`0V<:D0CSnP04hoX00207mQY@80SVRS00<0V6nR09Y]WP2RM9l00P2RM9l3
0:AhXP80X7RV0`2KM:H2099_Y`<0TVjV0P2ILZH20:9iYP040:IlY@2`Q:D0/8BU0;24Y@<0^8^W0`35
VJX20=6UZ`030=:[/03O^K40gkVa00<0k<^b00L0mMbb0?S//@3hk;40l_F`0>Oj]03No/80eokF0080
c_OX00H0a>O_0;[Hk`2jf>l0^]S_0;K@k@2_a^/30:_0j@<0YkWU00@0Y;3Q09VQfP2FUM00UYG@0P2G
SLL309Z8_`0609j7^ol0003o0000o`00002RR[/0YXnm0P2VQ:l30:b<]0030:nF_@2dT;40]92a0080
]ibm0P2nW;@20;jW``040<N[_@00=;H06Do905ehe@<0TiKC102gYlT00`3</;l0g];<0=kBc0020>Kj
c`030:cZV028[Nh0R:g^0080HYK/0P0UJ]`201UCc00503EDa@0hB;L0Ff;106IN]Ol000000`1fHJd2
08ia[P<0V7BY00<0XGZW0:1eX`2ZOJ800P2ZOJ820;:4Y080^HNQ2?ooool00ol0003oooooooooo`0K
ooooo`002Oooool01000003oooooooooooooool204a<C004o`00001VIVH0IVIVo`000080Ogmo00?o
000009VIV@2IVIT00`2IVIT4000000@0VIVI00Oo000007moO`1oOgl0Ogmoo`00001VIVKo00000080
C4a<00Go000003<c<`0c<c<0<c<c0000000501TI6Al00000100I6AT00ol00000<c<c03<c<`0203<c
<`03o`00001<C4`0C4a<00/0C4a<0_l0000303<c<`03o`00000I6AT06ATI00<06ATI8P00000C01TI
6@<000002`0I6AT4ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00`0V
<:D0CSnP04hoX002075BWP0408iXX`2;HYh0VVfN09Y]WP<0XWBO0`2TN:800`2PN:H0YGZT09]dYP03
09]dYP80TVnW0P2BKZH209UbYP030:9iYP2VO:D0YWbU00<0/8BU0P2hRjL20<6CY`050<FIZP3AYJ/0
dJF[0=6UZ`3O]Zd00P3O^K420>c;/P80mMbb00@0n>ba0?;e/03Wn[@0a?>Q0P38o]l01@35lNl0_Moa
0;gOl@2mgo40^]S_0080/lc]0P2_a^/00`2[`>T0Y;OW0:Bgi`0209j]hP<0VJ7J0P2FUM0209N=a`?o
00000P2NQk/00`2RR[/0X7f]0:J4[`020:J4[`<0[8bd0`2dT;401@2gW;d0_Ybd0;jL]02nW;@0_ZO3
0080aj^m00@0b[_<000d]P1MN=D0GGSE0`2CU]<20;NWb@80a/oR00@0g];<0>Kjc`3Vn/l0[>ZH0P2J
]n`308>[k`0505FAk00UJ]`0032h01UCc00eE<D00P0hB;L206IN]@03o`00001fHJd0MV6]0080QFNX
0P2HM:T0102DKZ@0X7FS0:1eX`2PMJ<30:YmXP030;:4Y02iQj40^HNQ00Wooooo00?o0000oooooooo
ool06_ooool000Wooooo00@00000oooooooooooooooo0P1<C4`00ol00000IVIV06IVIP02o`000080
Ogmo0ol0000709VIV@?o00000`1oOgl01?l00000IVIV06IVI_l0000204a<C005o`00000c<c<0<c<c
03<c<`0000001@0I6ATN000000D06ATI00?o000003<c<`0c<c<00_l0000404a<C0X000000P1<C4`0
1Ol00000<c<c03<c<`0c<c?o000000D06ATI8P00000>01TI6@<0000000Co000003<c<`0c<c<0<c<c
1P00000501TI6@Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`809S2U
00<0CSnP075BWP1aDYh00P2;HYh209Y]WP<0XWBO0`2TN:820:EjY0@0VgBV0P2BKjL2099^YP80VG:V
0`2VO:D30;24Y@050;R;Y`31TjL0`I>W0<6CY`35VJX00`3AYJ/20=nf[@050=ni/@3/bk80mMbb0?GL
/P3hk;400P3bmK001@34lj40/o_=0<7hk@31n>d0_nGa0080_Moa0P2fdNh00`2cc>d0[LC[0:Voj@03
0:Voj@80Y;OW0P2N[N8209VQfP0409JEd?l0003o0000o`0000<0VXRo00@0WXNk09Ui[P2POJd0X7f]
102VQ:l00`2/S;@0[hNZ0;B@/@020;B@/@@0_Ybd0`37Zkd00`3C];/0b[_<02N0j00202N0j080TiKC
00H0]jO90<K?hP36cn80a/oR0;[ki`3Vn/l20:JmjP0309Zgk02H]N`0PJ[_0080PJ[_0P1?Snd01003
F]<0032h01UCc00eE<D203Q8]`80IUje00Co000007IQ[@25IjP0QFNX0`2DKZ@30:1eX`<0ZWfR00@0
/XBT0;V7X@2iQj40^HNQ2?ooool00ol0003oooooooooo`0Jooooo`002Oooool01@00003ooooooooo
oooooooo00000080C4a<00Go000006IVIP1VIVH0IVIVo`00000407moO`;o0000102IVIT00ol00000
Ogmo07moO`0207moO`;o00000P1VIVH01Ol00000C4a<04a<C01<C4co000000<0<c<c00<0000001TI
6@0I6AT00`0I6ATL00000003o`00000I6AT06ATI00<06ATI00Co000003<c<`0c<c?o00000`1<C4`3
000000X0IVIV0P0000000`1<C4co000003<c<`0203<c<`03o`00000I6AT06ATI00806ATI8P00000<
01TI6@8000003@0c<c<2000000<06ATI1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooo
oooo00?ooooo00@09S2U04hoX01aDYh0LE:N0P2;HYh209Y]WP<0XWBO0P2TN:80102[O:40YGZT0:Ej
Y02UNZ@309]dYP80TVnW0P2BKZH00`2ILZH0VW>U0:IlY@030:IlY@80/8BU1031TjL30=6UZ`<0gkJ]
00P0k/Z^0>c;/P3eg;80mMbb0?S//@3VliX0d?6E0;?kc@80`OS]00H0_nGa0;[EkP2jeNh0^]G^0;KA
kP2ab>/30:g4j`80ZKoY00<0X[SX09V]i@2I[ND00P2?W]d3o`00000308Ioa02:N;T0RWRi00<0TGNb
0P2INJh30:1m[@80YXB_00@0ZGjV0:n7ZP2_QjX0[hNZ0P2dT;401P2kTJX0_Ybd0;jL]02nW;@0bJ6`
0<N[_@80dkBk0P3O`[/202N0j0@0SK_e00@0a/oR0;[ki`2baNP0[l?Y0`2U_>X209Rek0<0PJ[_0P1?
Snd00`003YX0032h000a]@0203Q8]`0404]:[`1VG[Go000007IQ[@80QFNX0`2DKZ@30:1eX`<0ZWfR
102iQj49ooooo`03o`000?oooooooooo01Wooooo0009ooooo`0500000?ooooooooooooooool00000
0`1<C4`01Ol00000IVIV06IVIP1VIVKo000000D0Ogmo1?l0000407moO`05o`00001VIVH0IVIV06IV
I_l000000`1<C4`01Ol00000<c<c03<c<`0c<c<0000000D06ATI7P00000401TI6@04o`00000c<c<0
<c<co`0000<0C4a<00@0000006IVIP1VIVH0IVIV2?l0000406IVIP03o`00001<C4co000000<0<c<c
00?o000001TI6@0I6AT00P0I6ATQ000000X06ATI0P00000A03<c<`80000000<06ATIooooooooool0
0_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00@0001i04hoX01>?j00
LE:N0P2;HYh309Y]WP80XWBO00<0Y7RR0:]lX@2[O:400`2UNZ@309]dYP04099_Y`2AKjP0TFfV095]
YP80VW>U102VO:D20;24Y@050;V<YP31TjL0`I>W0<6CY`3=X:T00P3AYJ/30=nf[@040>k:[P3igjd0
nMn]0?O_YP80i_>J0P2kn^X20<;Xl080`=O[00<0^]G^0;K;jP2fbnX00P2ab>/0102]a>/0Z;kY0:Rn
j@2X_^T20::hj0?o000000@0SikM08R=d@28SM40QWo40`2:N;T2095g/P<0VGV^0P2POJd00`2VQ:l0
ZGjV0:UnYP030:n7ZP050;B@/@2kTJX0^i6Z0;^AZP2nW;@00P39XK030=>d^`80gl:k0`3Id=0208fk
m@0304K5h@32d>D0[l?Y00<0[l?Y00<0YKcZ0:>jj@2H/nX00P2H/nX308>Yk@0405FBk@00F=8000jJ
0003UP80>4Rg0P1;BZl00`1fHJgo000007IQ[@0208EWZ080U6jT102PMJ<20:YmXP@0^HNQ2Oooool0
0ol0003oooooooooo`0Iooooo`002Oooool01P00003oooooooooooooool0<c<co`0000<0C4a<0_l0
000206IVIPCo00001P1oOgl3o`0000<0IVIV00Go000004a<C01<C4`0C4a<o`00000403<c<`03o`00
000I6AT06ATI00<06ATI7@00000401TI6@04o`00000c<c<0<c<co`000080C4a<0_l0000206IVIP;o
00000`1oOgl4o`00000407moOol0003o0000o`000080IVIV00@0000004a<C?l0003o00000P0c<c<0
0ol000006ATI01TI6@0201TI6B0000002@0I6AT00`000000<c<c03<c<`0803<c<`D000001P0c<c<0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
100007T0CSnP04hoX01aDYh308]RWP80VVfN0P2RM9l40:]lX@80YGZT0P2KM:H00`2MN:T0TFnX095_
Z002095]YP<0VW>U0`2VO:D00`2`Q:D0^HbV0;V<YP020<6CY`80cJ2Y0P3AYJ/20=nf[@80k/Z^0P3i
gjd00`3gkjH0i_>J0;cjj`020<WVk0030<;Xl030en/0`=O[0080_/kV00<0]/_Z0;C6j02^`nT00P2^
`nT20:Rnj@030:>jjOl0003o00000080R:3S0P1gRMP206idb080QWo40P2:N;T3095g/P80VGV^0P2P
OJd30:UnYP<0[hNZ102kTJX30<VQ/0030=J/[P3C];/0gl:k0080gl:k00<0j]:m0=W@d03Lf]D00P3H
h=d00`32d>D0_<kX0;c>j0020:o3j@80Zl3X0P2S^^T00`2H/nX0VK3X08NWjP0208NWjP80I9K[00<0
05SB000>VP000iH00P0hB;L0101;BZl0I5>Y07IQ[Ol0000208EWZ0<0U6jT0`2PMJ<00`2ZOJ80[gnP
0:moX0030;V7X@[ooooo00?o0000ooooooooool06?ooool000Wooooo00@00000oooooooooooooooo
0P0c<c<00ol00000C4a<04a<C00204a<C0;o0000101VIVH6o`0000@0IVIV0_l0000304a<C003o`00
000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT00`0I6ATM000000@06ATI00Co000003<c<`0c<c?o
00000P1<C4`010000000IVIV06IVI_l0000207moO`?o0000102IVIT01ol00000Ogmo07moO`1oOgoo
000006IVIP0000000P1<C4`01?l00000<c<c03<c<ol0000401TI6B000000200I6AT00ol00000<c<c
03<c<`0303<c<`H000001@1<C4`3000000@0<c<c00Go0000oooooooooooooooo0000000Eooooo`03
o`000?oooooooooo00Gooooo00<03aB@04hoX01aDYh00`2;HYh209Y]WP80XWBO102[O:420:EjY0<0
WGRY0P2AKjP2095]YP<0VW>U0`2VO:D30;V<YP80`I>W0`3=X:T30=nf[@060>k:[P3igjd0nMn]0?O_
YP3VliX0Vm1W0P39i^`20<SFi0040<S>g`2nc^H0_/kV0;k>iP<0]<KX00<0[/?Y0:^oj?l000000_l0
00000`2S^^T0V;3X09R`j00208RPh`80MhWH00<0KWC8071X^@1`J;T00P2:N;T3095g/P80VGV^00<0
X7f]0:1gY@2YOZH00`2YOZH20:n7ZP@0^i6Z0P39XK020=J/[P<0gl:k0P3Zd[d00`3`hl40kO380=SP
g@020<oPi0060;c>j02ebNT0]LWY0;G9j@2[`>P0Z;cX0`2R]^L209V`j0<0QjOZ0P1TU^/01@0HKMh0
00>F0003UP0hB;L0BdZ_0080I5>Y00<0MV6]o`000025IjP00`2DKZ@30:1eX`<0[gnP0P2iQj420<B@
W`Kooooo00D0i?c<ooooooooooooooooo`00000Iooooo`002Oooool01000003oooooooooooooool3
03<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH02@1VIVH2o`0000@0C4a<00?o0000
03<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0301TI6Ah000000`0I6AT01?l00000<c<c03<c<ol0
000204a<C0050000001VIVH0IVIVo`00001oOgl00_l0000309VIV@Co000000<0VIVIo`000?l00000
0P1oOgl00ol00000IVIV0000000204a<C004o`00000c<c<0<c<co`0000<06ATI8000000701TI6@03
0000000c<c<0<c<c0080<c<c0P00000>04a<C08000000P0c<c<4ooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool01Oooool200lDT004075BWP2;HYh0Rf:N08]RWP80VVfN00<0XWBO0:Uj
W`2[O:400`2[O:420:EjY0<0WGRY0`2AKjP2095]YP80VW>U0P2VO:D00`2]PZL0^HbV0;V<YP020;V<
YP040<6CY`3=X:T0cJ2Y0<fPZ@80gkJ]0P3^bZh20?WO[@060?O_YP2Kd6L0d=cR0=3LhP3AcmP0b=KT
0`38c]l0102nc^H0_<WT0;c9i02da^P3o`0000030:^oj02W_NT0W;KZ0080W;KZ00<0RJSY06b>hP1/
S^800P1>K=400`1^M<P0L6Ri071X^@0307]V[`80TGNb00<0VGV^09I`Y@2PMjD00P2PMjD30:UnYP03
0:n7ZP2fR:@0]XRT0080^i6Z0P36UjL01@39XK00eZb^0=J/[P3U_Jd0gl:k00<0j]:m00@0l>?10>g`
b03Tm=D0cn3T0P34fNT20;G9j@80[l?Y0P2X_>P00`2R]^L0Wk;U09R[i00209R[i080S:?T0P1eUnD2
04N0i0040003UP009JT0BdZ_04]:[`80I5>Y00?o000008EWZ025IjP00P2DKZ@20:1eX`040:9fX@2_
Oj00[gnP0:moX080^HNQ0P34T9l6ooooo`050>Clc03IcLkoooooooooool000006Oooool000Wooooo
00@00000oooooooooooooooo0`0c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV00L0
IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0203<c<`030000000I6AT06ATI00@0
6ATI7@00000401TI6@04o`00000c<c<0<c<co`000080C4a<00D0000006IVI_l00000Ogmoo`000002
09VIV@?o0000102c/k<02ol00000VIVI09VIVOl00000Ogmoo`00001VIVH0000004a<C000003o0000
0080<c<c00?o000001TI6@0I6AT00P0I6ATN000000L06ATI00<0000003<c<`0c<c<00P0c<c<00ol0
0000C4a<04a<C00404a<C0Ko00001P1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo
01?ooooo00?o0000ooooooooool01Oooool00`0007T03aB@075BWP0308]RWP80VVfN0`2YNYl30:]l
X@030:EjY02/PZL0WGRY00<0WGRY0P2AKjP2095]YP80VW>U00<0YWbU0:f2Y`2]PZL0102iS:H40<fP
Z@090=fb[@3O]Zd0k/Z^0>k:[P3igjd0mnnV0<7RN@3Dc=80d=cR0080dLoH0P3Bc=@00`38c]l0alcN
0<O<gP03o`0000040;[7i02b`nL0[l7W0:o1i`80YkgY00@0W;KZ09>bk01dWN/0M9g[0P1/S^800`1>
K=40@U>m06idb002071X^@80NfJ_0P29JJT209I`Y@<0X7NU0`2YOZH0102_QjX0]XRT0;J8Y02kTJX3
0<JGY`040<VQ/03F[:h0iKf]0>Fm[@80m=>[00L0j]:m0?3S`@3]l<P0kO380>Cde@3Fkn@0a=WY0080
^Lo[0P2_`nT0102Y_NP0YKOV0:FgiP2U]nH209nbi@<0V:_T0P2<Xn@207FGi@0304N0i000068000>F
0080BdZ_0P1TDjT00`1lGjKo000007aOYP0209A^Y0030:1eX`2RMZ40XWJQ00@0[gnP00<0^HNQ0<B@
W`34T9l01Oooool00`0000d0fLg>0=W=cP03ooooo`03o`000?oooooooooo01Kooooo0009ooooo`05
00000?ooooooooooooooo`0000000`0c<c<3o`0000@0C4a<2_l0000404a<C0;o0000100c<c<00`00
00006ATI01TI6@0401TI6Ah000000`0I6AT03?l00000<c<c03<c<ol00000C4a<o`0000000000IVIV
o`00001oOgoo000009VIV@;o000000<0/k>co`000?l000000ol000020;>c/`03o`00002IVIT0VIVI
00?o000000D0IVIV0000001<C4`0C4a<o`00000203<c<`05o`00000I6AT06ATI01TI6Ol000007000
00000ol000006ATI01TI6@0401TI6@030000000c<c<0<c<c0080<c<c0P00000204a<C0Co00001P1V
IVH4o`0000<0C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00<03aB@05a4W02;HYh00P2;HYh00`2JKIh0Wg6N0:UjW`020:UjW`<0ZgbQ0`2/
PZL309ehZ@80TFnX0P2AKJH00`2JLjD0WGRY0:f2Y`030:f2Y`<0^HbV0`3=X:T20=fb[@80k/b`0P3i
gjd01@3[lIP0e<cB0=C<dP3Fa/X0dLoH0080d/cD00D0e<kDo`000?l0003o00000<K<g`020;[7i080
^<KU00<0[l7W0:foi`2T^nT00P2T^nT209>bk080M9g[00@0?GCM04i/d@1>K=40@U>m0P1`J;T207]V
[`80RFVY0P2FL:D30:1gY@<0ZGjV0`2fR:@0102kTJX0aYNW0<JGY`36UjL20=J/[P80iKf]0P3ddj/0
1@3kijH0l>?10>g`b03Tm=D0e^oT0080aN7/00<0^Lo[0;35jP2`aNX00`2Y_NP0102U]nH0XK;T09b/
hP2L[>8309JTg`80SIcM0P20T]/206^6f`030000HP0L;JL0BdZ_0080I5>Y0P1lGjH00ol00000TF^S
095[X`030:9fX@@0[gnP0`34T9l4ooooo`0300003@3Ea<X0fLg>0080c;;00oooool00ol0003ooooo
ooooo`0Eooooo`002Oooool01P00003oooooooooooooool06ATI000000D0<c<c0_l0000>04a<C0;o
00001@0c<c<00`0000006ATI01TI6@0501TI6Ah000000`0I6AT01_l00000<c<c03<c<ol00000C4a<
00000080IVIV00Go000007moOol00000VIVIo`0000020;>c/`03o`00003<c<`0c<c<0080c<c<00Co
00000;>c/`2c/k?o00000P2IVIT2o`00000506IVIP000000C4a<04a<C?l000000P0c<c<00ol00000
6ATI01TI6@0201TI6Ad000001P0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<0_l0000606IV
IPGo00000`1VIVH2o`000080C4a<00Go0000oooooooooooooooo0000000Dooooo`03o`000?oooooo
oooo00Oooooo00<03aB@05a4W028HIh00P28HIh209maWP<0ZGZO0P2[O:40102fR:D0[8:W0:b2Y`2/
PZL309ehZ@80TFnX00@0TFfV08m`Z`2MN:T0WGRY102]PZL20;V<YP80aIVZ00@0cJ2Y0=fb[@3M/Zd0
gK:]0P3^c;00103iij`0jo6H0=C<dP3Dc=820=K6bP070=[8aol0003o0000o`00003Dc]@0e=7F0<K<
g`030<C<h@030;S6i@2ea>D0]LCU0080[KoW00<0Y;_Y0:2ijP2P^NX00P2:[^h205NAk00303edg@06
?kl0@U>m0080Cdf`0P1kIZl208UYZ@<0UW2U0`2PMjD20:UnYP<0]XRT1036UjL00`3DY:D0eZb^0>Fm
[@030?CCZ`060?_WYP3blZ80hoV[0=[ob03@n>H0aN7/0P2hdNd00`2`aNX0ZKkX0:Vnj0030:FhiP80
XK;T0P2L[>8309JTg`80SIcM0P20T]/206^6f`03000UZ@0L;JL0BdZ_0080I5>Y0P1lGjH00ol00000
TF^S0:9fX@030:9fX@<0[gnP0`34T9l3ooooo`80000=00@0eLC:0<bb`03<//00c;;00oooool00ol0
003oooooooooo`0Eooooo`002Oooool01000003oooooooooooooool201TI6@030000000c<c<0<c<c
00@0<c<c00?o000004a<C01<C4`02@1<C4`2o`0000H0<c<c00<0000001TI6@0I6AT01@0I6ATN0000
00<06ATI00Ko000003<c<`0c<c?o000004a<C000000206IVIP05o`00001oOgoo000009VIVOl00000
0P2c/k<00ol00000c<c<0<c<c0040<c<c004o`00002c/k<0/k>co`000080VIVI0_l000001@1VIVH0
000004a<C01<C4co00000080<c<c00Co000001TI6@0I6AT06ATI7@00000501TI6@050000000c<c<0
<c<c03<c<ol000000P1<C4`00ol00000IVIV06IVIP0306IVIP?o00001@1oOgl3o`000080IVIV00?o
000004a<C?ooool00oooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00<0
3aB@05a4W028HIh00P28HIh209maWP<0ZGZO00<0ZgbQ0;J8Y@2fR:D00`2/PZL209ehZ@0309j0/P2=
LJl0SG6_0080Sg2[0P2MN:T40:f2Y`050;V<YP35VJX0aIVZ0<FIZP3=X:T00P3M/Zd30>k</0040?WW
[031hWT0e<cB0=K6bP?o00000P3Nc/P00`3Dc]@0e=7F0=CAeP020=;DfP050<C<h@30bn<0`<_S0;G4
i@2b`^H00`2[_^L30:2ijP80RZk^0P1GTN`00`00CL`01Sno049C_@0204m=/080NfJ_0P29JJT209I`
Y@<0X7NU00<0ZGjV0:ioX@2fR:@00P2fR:@00`30Sj80aYNW0<JGY`020=BTY@80iKf]0P3ddj/20?_W
YP030?;bXP3JolP0d?SV0080`>;`00<0^=7]0:k5j`2Y_^P00`2Y_^P0102U^>H0XK;U09b/hP2L[>82
09NTgP<0TIcJ0P2<TmD208B:d@<0O8;>0P0L;JL206ACZ@80O5nV00?o0000095[X`2AJj<00`2RMZ43
0:moX0<0a92O00@0ej:Oooooo`000000000=0P3Ea<X01038ZKX0c;;00<bb`039Z;P3ooooo`03o`00
0?oooooooooo01Cooooo0009ooooo`0400000?ooooooooooooooo`<06ATI0P00000503<c<`_o0000
1P0c<c<00ol00000000001TI6@0601TI6Al000000`0I6AT03?l00000<c<c03<c<ol00000C4a<0000
001VIVKo000007moOol00000VIVIo`000080/k>c00?o00000<c<c03<c<`01P3<c<`03?l00000/k>c
0;>c/ol00000VIVIo`00001oOgoo000006IVIP000000C4a<o`000080<c<c00Co000001TI6@0I6AT0
6ATI7000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00ol00000IVIV06IVIP04o`00
00<0Ogmo1Ol0000307moO`04o`00001VIVH0IVIVo`0000Cooooo00<00000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`0300lDT01LA9`0R66N0080R66N0`2OLIh20:UjW`@0]XRU0P2/PZL3
09j0/P80SG6_0P2?L:/309ehZ@<0[H:W1035VJX30=fb[@80k/b`00<0nNN/0>_aV?l000000_l00000
0`3Fa/X0f/S70=[8a`020=k>b0050>7Fc03DdMH0d]CJ0=;DfP3=e=l00`30bn<30;;2iP040:^ni`2Y
_>L0ZKcW0:Vli`80WKS[0P22[?00100iQNX001nU00Ho_`007jL204m=/00406MDZ01kIZl0RFVY08UY
Z@80UW2U0P2PMjD01@2SMZ40[WnQ0:ioX@2^Oj40]XRT0080`8nR0P36UjL20=BTY@030>RiY03U_Jd0
m=>[0080nnNV00D0l_:R0:_OO`30o<D0`oC_0<3Rl0020;??kP80[/G[0P2Y_^P20:Fhi`80XK;U0P2L
[>8209NTgP<0TIcJ0P2<TmD208B:d@80O8;>0P0L;JL01`16@ZP0I5>Y07aOYP1lGjH0TF^So`00002A
Jj<00`2RMZ420:moX0030;V7X034T9l0a92O0080ej:O00@000000140;@0000d0eLC:0P38ZKX00`3<
//00bJRh0<VX^004ooooo`03o`000?oooooooooo01?ooooo0009ooooo`0400000?oooooooooooooo
o`D06ATI0P00000C03<c<`030000000I6AT06ATI00H06ATI7`0000001Ol000006ATI01TI6@0I6AWo
00000080<c<c00_o000004a<C0000000IVIVo`00001oOgoo000009VIVOl00000/k>co`0000020<c<
c0Go00000P3<c<`03?l00000/k>c0;>c/ol00000VIVIo`00001oOgoo000006IVIP000000C4a<o`00
0080<c<c00Co000001TI6@0I6AT06ATI7000000501TI6@070000000c<c<0<c<c03<c<`000000C4a<
o`00000206IVIP03o`00001oOgl0Ogmo0080Ogmo0ol0000509VIV@;o00000P1oOgl2o`00000306IV
I_l0003ooooo00;ooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`0405a4
W028HIh0R66N08QQWP<0Wg6N0P2YNYl40;J8Y@80[8:W00D0]i>b09j0/P2NP;80WX2b08ea[`0308m`
Z`80WGRY0P2]PZL00`2hT:h0aIVZ0<FIZP020<FIZP030=N_/@3M/Zd0k/b`0080k/b`0_l000001@3B
^l<0f;bm0=Rl_@3O`k`0f/S700<0g/k800<0hMK<0>7Md@3Be=X00`3=e=l01030bn<0^lST0;_8i02b
`^H30;2oi@030:Vli`2Y^^D0WKOZ0080WKOZ0P1o[?401@0WP>P001nU00Ho_`007jL0Cdf`0080IeBX
0P29JJT209I`Y@030:1gY@2SMZ40XgJQ00<0[WnQ00D0]XRT0<2?XP30Sj80`8nR0<JGY`020=BTY@03
0>RiY03jdih0m=>[0080nnNV00<0/=5N0<3la@33m>l00P2gf_800`2ccnh0[<?[0:Rmj@020:Rmj@80
YKSW00<0X;?U09^]h`2K[N<00P2EYN0208nKf`<0RY7E0P26R<h208>0b0<0PG_300@072fW04I2Z016
@ZP0I5>Y0P1lGjH00`2AJj?o00000:9fX@020:9fX@050:moX02iQj00^HNP0;V7X034T9l00P3GXYl2
0140;@0400006038ZKX0b:Vj0<RY^P<0bJRh00D0cJRdooooooooooooooooo`00000Eooooo`002Ooo
ool01000003oooooooooooooool701TI6@800000400c<c<00`0000006ATI01TI6@0601TI6B400000
0`0I6AT02Ol00000<c<c03<c<ol00000C4a<0000001VIVKo000007moO`02o`000080/k>c00Co0000
0<c<c03<c<co00000`3Vi^H03ol00000c<c<0<c<c03<c<co00000;>c/ol00000VIVIo`00001oOgoo
000006IVIP000000C4a<o`00000203<c<`04o`00000I6AT06ATI01TI6A/000001@0I6AT01`000000
<c<c03<c<`0c<c<0000004a<C?l000000P1VIVH00ol00000Ogmo07moO`03o`0000<0VIVI1Ol00002
09VIV@;o00000P1oOgl00ol0003oooooooooo`02ooooo`0300000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool205a4W080R66N0`2OLIh00`2YNYl0]XNT0;J8Y@030;J8Y@030:b2Y`2gTk80
]i>b00<0WX2b0P2=LJl208m`Z`80WGRY00@0[H:W0;R@[P2hT:h0^92^0P35VJX20=N_/@060=fb[Ol0
003o0000o`00003iij`0d[_30`3H_;d0103O`k`0i/fm0>K=_@3Nc/P20>7Fc0040>7Md@3LgmP0g=oH
0<gDg`80am7R00<0^lST0;O3h`2g`n<00P2`_nD01P2_^n<0ZK[U0:Vji@2Y^^D0WKOZ09nfj0<0Q:oa
00@0;HS/0000S@007jL0Cdf`0P1WE:P207mOY00309I`Y@2DJj40XgJQ0080XgJQ0`2^Oj40102fR:@0
`8nR0<2?XP30Sj820=BTY@80j;VT00D0n]>N0?WURP3iiHX0eMeZ0;;kgP020;OUmP030;OJlP2^b>d0
[/S]0080[<?[00<0Z;gY0:BgiP2T]nH00`2P/nD209^]h`80UJGP0P2?Vm/308ZAe@80QXS>0P23P<P2
085k``040000S`0L;JL0AT:X04I2Z080O5nV0P2AJj<00ol00000XWJQ0:9fX@040;V7X0070<B@W`3G
XYl0ej:O0?6oW00A02d0000H0<:O]P020<RY^P040<JQ/P39Z;P0cJRd0<fX]0Cooooo00?o0000oooo
ooooool04_ooool000Wooooo00@00000oooooooooooooooo2@0I6AT00ol00000<c<c03<c<`0903<c
<`@000002@0I6AT00ol0000000000000000N000000<06ATI00Wo000003<c<`0c<c?o000004a<C000
0000IVIVo`00001oOgl00_l000020;>c/`04o`00003<c<`0c<c<o`0000@0i^KV00ko00000<c<c03<
c<co00000;>c/ol00000VIVIo`00001oOgoo000006IVIP000000C4a<o`000080<c<c00Co000001TI
6@0I6AT06ATI6`00000401TI6@070000000c<c<0<c<c00000?l00000C4a<o`00000206IVIP04o`00
001oOgl0Ogmoo`000080VIVI1?l000050;>c/`;o00000P2IVIT01?l00000Ogmo07moOol00003oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool205a4W080R66N0`2OLIh00`2Y
NYl0]XNT0;J7Y0030;J8Y@<0]i>b0`2NP;8208ea[`80Sg2[00<0WGRY0:B5/P2hT:h00`2hT:h00`35
VJX0ejnao`000002o`0000040>gA^03^c;00m?>_0<n]^0<0f;bm0P3O`k`20>K=_@030>cI`@3Qe/`0
hMgA00<0g=oH00D0e=gN0<OAhP2ob^80_l[R0;O3h`030;>mh@80[k_S00<0ZK[U0:Zgh`2Z]n<00P2O
]^P02024[o40S[?_08jck`1;Vo@001nW014SX@1?CK00IeBX0P1oGj@209A[X@@0XgJQ0P2^Oj440<2?
XP80e:BU0P3X^J@00`3jdih0nNF:0?WURP020:o]n0050;OUmP2_c_00[lk`0:k8k@2Y_^T00`2W^nL0
0`2T]nH0XK7S0:6ah`0209b/h`80U:GQ0P2=W=d308FAe`80OhK@0P1lO<P208>0b0<0PG_300D072fW
04I2Z016@ZP0KeVX07aOYP02095[X`03o`00002RMZ40XWJQ00@0^HNP0`3GXYl01@3a_i`0nmak0000
0032WkH0b:Vj0080aZ6b00<0bJRh0<fX]03=Z;@01?ooool00ol0003oooooooooo`0Booooo`002Ooo
ool01000003oooooooooooooool:01TI6@/000003@0I6ATQ000000<06ATI00Wo000003<c<`0c<c?o
000004a<C0000000IVIVo`00001oOgl00_l000020;>c/`04o`00003<c<`0c<c<o`0000@0i^KV00ko
00000<c<c03<c<co00000;>c/ol00000VIVIo`00001oOgoo000006IVIP000000C4a<o`000080<c<c
00Co000001TI6@0I6AT06ATI6`00000401TI6@040000000c<c<0<c<c00000080C4a<00Ko000006IV
IP1VIVKo000007moOol0000209VIV@03o`00002c/k<0/k>c0080/k>c1?l000030;>c/`03o`00002I
VIWo00000080Ogmo00Go0000oooooooooooooooo0000000Dooooo`03o`000?oooooooooo00Sooooo
00@08RJK05a4W028HIh0R66N0P2OLIh0102YOjD0]XNT0;J7Y02fQj@20;J8Y@030<NO/02gTk80]i>b
0080]i>b00H0WX2b09RCc021NL40PGW108m`Z`2<NKP30:B5/P80^92^0ol000020=N_/@80kM6h0P3d
ljl00`3?[KP0f;>d0=Rl_@020=o3_0<0i/fm00H0k=W10>gTaP3Yjlh0jN_>0=cOf03DgMh20<[Dh@06
0;o:hP2i`Ml0^L7O0;W1g`2c_N40/[OM0`2_]ml00`2Z]n<0[;GO0:BfiP020:BfiP<0S[?_00@0002=
000OY`1?CK00IeBX0P1oGj@309A[X@<0XgJQ0P2^Oj430<2?XP80d9fR00L0e:BU0>RiY03jdih0n]>N
0?WURP000000ZmCf0080[];c00<0[lk`0:_1jP2[`NX00P2Y_^T00`2W^nL0YKCT0:Fdi0030:6ah`80
W:cS0P2DYN4208fLg@<0QI7G0P1oQ]00101lO<P0O7K107af`@1lM/42085k``030000S`16@ZP0AT:X
0080KeVX0`2AJj<00ol00000Z7^S0:QkX`030;V7X080ej:O0P3a_i`00`3kg7/0`Ynf0<:O]P030<JQ
/P<0cJRd00<0djfbooooooooool00_ooool00ol0003oooooooooo`0Aooooo`002Oooool01@00003o
oooooooooooooooo000002006ATI8P00000301TI6@09o`00000c<c<0<c<co`00001<C4`0000006IV
I_l00000Ogmo00;o00000P2c/k<00ol00000c<c<0<c<c005o`000080c<c<00co00000;>c/`2c/k?o
000009VIVOl00000Ogmoo`00001VIVH0000004a<C?l0000203<c<`04o`00000I6AT06ATI01TI6A/0
0000100I6AT010000000<c<c03<c<`00000204a<C005o`00001VIVKo000007moOol000000P2IVIT0
0ol00000/k>c0;>c/`03o`0000@0c<c<00So00000;>c/`2c/k<0/k>co`00002IVIWo000007moO`Co
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`808RJK0P28HIh00`2OLIh0
ZGnU0:UoY@030;J7Y0040;J8Y@37Wk00ain`0<NO/080]i>b00<0a;W?09RCc02HTl`00P21NL4208ai
^080Y8Fb0ol00000102hT:h0bZ^j0=N_/@3G[k430>gA^0040?Cc[`3?[KP0f;>d0=Rc]080h[jd00<0
gl>l0>K=_@3VcKd00P3/fL401P3]i<H0jN_>0>7[f03QjmP0e^;O0<[Dh@<0`LOO00<0^L7O0;Fhf`2b
]md00P2b]md00`2_]ml0[k?K0:beg`020:beg`040:BfiP2Y]N80ZKGR0:VehP80V[K[00D001nW014S
X@1WE:P0IeBX07mOY00309A[X@<0XgJQ00<0[WnQ0;N5X030Sj800P30Sj820=2MXP80j;VT00D0n]>N
0?WURP000000ZmCf0:[5k@030:_4k0030:_1jP2X^NH0YkOU0080YkOU00<0YKCT0:>[g@2NZ=d00P2N
Z=d209RTg@80SYcM0P23T]X307R5e080LGW<0P1lO<P207af`@80Og:k00<0Pg:g04I2Z016@ZP00P1_
FJP3091/YP030:QkXol00000Z7^S00<0^HNP0P3GXYl20?6oW0040?_LN`32WkH0`Ynf0<:I[P80aZ6b
00@0bZ6^0<fX]03C[K80djfb1Oooool00ol0003oooooooooo`0@ooooo`002Oooool01@00003ooooo
oooooooooooo000002006ATI8P00000301TI6@0>o`00000c<c<0<c<co`00001<C4`0000006IVI_l0
0000Ogmoo`00002IVIWo00000;>c/ol000090<c<c003o`00002c/k<0/k>c00;o000000L0Ogmoo`00
001VIVH0IVIV0000001<C4co00000080<c<c00Co000001TI6@0I6AT06ATI6P00000401TI6@040000
000c<c<0<c<c00000080C4a<00So000006IVIP1VIVKo000007moOol00000VIVIo`000080/k>c00?o
00000<c<c03<c<`01P3<c<`2o`000080/k>c00?o000009VIVOl000001?ooool00`00003ooooooooo
o`0Aooooo`03o`000?oooooooooo00[ooooo00<08RJK08IWZ026IjP00`2YOjD30;J7Y0@0ain`00@0
]i>b0<Bic`34^Ll0a;W?0P2HTl`00`21NL40S7Vho`000002o`0000040:B5/P2hT:h0^92^0;R@[P80
bZ^j00H0ejna0>gA^03]dKP0m?>_0<VR/03?[KP20=Rc]080h[jd00H0k<fe0>K=_@3/fL40k=W10>gT
aP3Yjlh20>7[f080e^;O0`31aml01@2i^]X0]KSK0;Fhf`2e^=/0/[OM0080/[7H0P2_/m/01P2/]Ml0
[k?K0:ncf`2_/m/0ZKGR0:jdg@80YKOU00D0001X014SX@1WE:P0IeBX07mOY00309A[X@<0XgJQ00@0
[WnQ0;N5X02gQJ00`8nR0`3@WJ820>RiY0030?[CWP3iiHX0ZLG^00<0Z/G]00<0ZlC/0:Vki`2Y^nL0
0P2X^NH00`2W]nD0YJkN0:>[g@020:>[g@<0WZSM0P2HY=d208jLg@80Pi;J0`1hQM@00`1aNL`0Kg33
06m```0207af`@80Og:k0P23L[L204I2Z00406mIZ02@K:H0T6bV091/YP80Z7^S00?o00000;V7X02i
Qj000P3;VJ<01@3GXYl0lKnL0?6oW0000000`Ynf0080`YV^00<0aZ6b0<ZQ[P3:XJh00`3C[K800`3M
][7oooooooooo`02ooooo`03o`000?oooooooooo013ooooo0009ooooo`0600000?oooooooooooooo
o`00003o00007P0I6ATS000000<06ATI00Wo000003<c<`0c<c?o000004a<C0000000IVIVo`00001o
Ogl00ol000020;>c/`03o`00003<c<`0c<c<00D0c<c<0_l000020;>c/`;o000000L0Ogmoo`00001V
IVH0IVIV0000001<C4co00000080<c<c00Go000001TI6@0I6AT06ATIo`00000I000000@06ATI00@0
000003<c<`0c<c<000000P1<C4`01ol00000IVIVo`00001oOgoo000009VIVOl000000P2c/k<00ol0
0000c<c<0<c<c006o`0000<0c<c<00?o00000;>c/ol000000P2IVIT01Ol0003oooooooooooooool0
000001?ooooo00?o0000ooooooooool02_ooool00`0R9Y/0QVNX08IWZ0040:UoY@80]XNT00D0c:Fa
0<NO/037Wk00ain`0>;Cb@030<Bic`0409RCc?l0003o0000o`000080S7Vh0`2TQK801`2hT:h0bZ^j
0<Z[^P3:ZkX0iMg=0>gA^038n:`00P39X[020=Rc]0<0h[jd00D0k<fe0??M]`3cgKL0mN^i0?3e_`02
0>Shc0050=oaf`3Fh]l0bM3P0<W@h031aml00`2i^]X00`2e^=/0/joD0;:af0020;:af0<0/K3F0P2_
/m/02@2b/ML0[[CM0:jdg@2^]=d0YKOU0:ffh00A8j40A3bS06MDZ00207mOY080U6^Q0`2SMZ430;N5
X0050<2?XP3@WJ80d9fR0=2MXP3V]J400P3jdih0102YaNh0ZKkX0:Vnj02Y_^P20:Vmj0030:Vki`2W
/n80Y[3O0080Y[3O0P2U[]h00`2SZmd0X9gA09fKdP0209fKdP80UISD0P29T]H207V7e@<0JGW@0P1a
NL`0101_L<<0LV^l079[_01lM/4207mb^`0308=b]`028:<0AT:X0080KeVX0`2@K:H0102XNj?o0000
0:QkX`2iQj020<^IX`040=NRW`3a_i`0lKnL0;ZF/P<0`YV^0`3:XJh0103AYj`0djfb0=ff/@3M][45
ooooo`03o`000?oooooooooo00oooooo0009ooooo`0600000?ooooooooooooooo`00003o00007P0I
6ATS000000<06ATI00So000003<c<`0c<c?o000004a<C0000000IVIVo`000080Ogmo00?o000009VI
VOl000000P2c/k<00ol00000c<c<0<c<c0030<c<c009o`00002c/k<0/k>c0;>c/ol00000VIVIo`00
001oOgoo00000080IVIV00<0000004a<C?l000000P0c<c<01?l000006ATI01TI6@0I6ATJ000000@0
6ATI00@0000003<c<`0c<c<000000P1<C4`01ol00000IVIVo`00001oOgoo000009VIVOl000000P2c
/k<00ol00000c<c<o`0000060>KViP06o`00003<c<`0c<c<o`00002c/k?o00000P2IVIT01Ol0003o
ooooooooooooool0000001?ooooo00?o0000ooooooooool02_ooool00`0R9Y/0QVNX08IWZ0040:Uo
Y@030;J7Y03<YK40c:Fa00<0ain`0P3RdlT3o`00000306oOfP0YWNl0<gcV0080S7Vh0P2TQK800`2`
X/X0bZ^j0<Z[^P020<Z[^P030>GMc@38n:`0b?R/0080bJ:`00@0e:b_0=Rc]03R_[@0h[jd0P3/cKD2
0??M]`070?G[^@3`mKl0j?S<0>Shc03OlM/0dMgQ0<W@h0030;jnfP030;VjfP2e[]80/joD0080/joD
00@0/[7H0;:/dP2b[=80/K3F0P2d[M430;:ae`050:jdg@2b/mT0/[?I0:ffh00007000P14?:<207mO
Y0<0U6^Q0P2SMZ430;N5X0080<2?XP3@WJ80d9fR0=2MXP3V]J40oMJG0?WURP2Z_^P20:Vnj0040:Ri
i@2W]^@0YkKT0:Nfi080Yk?R00@0Y[3O0:>Se@2RWm80XYoB0`2PWM4309fKdP80UISD0P29T]H207V7
e@80JGW@0P1OK<P0101_L<<0LV^l079[_01bJk`207mb^`80Pg:g00<0AT:X06mIZ01_FJP00`2@K:H2
0:QkX`04o`00002iQj00biVS0<^IX`80lKnL00<0nmak0;^AZ`32VJh00P32VJh20<ZQ[P80dJN/00@0
djfb0=ff/@3M][40j<>`0oooool3o`00013ooooo0009ooooo`0400000?ooooooooooooooo`800000
00?o000001TI6@0I6AT06`0I6ATT000000<06ATI00So000003<c<`0c<c?o000004a<C0000000IVIV
o`000080Ogmo00Go000009VIVOl0003o00000;>c/`05o`0000<0/k>c00Go000009VIVOl00000Ogmo
o`00000206IVIP030000001<C4co00000080<c<c00?o000001TI6@0I6AT00P0I6ATI000000@06ATI
00@0000003<c<`0c<c<000000P1<C4`01ol00000IVIVo`00001oOgoo000009VIVOl000000P2c/k<0
0ol00000c<c<o`0000080>KViP;o000000D0c<c<o`00002c/k?o000009VIV@04ooooo`0300000?oo
oooooooo017ooooo00?o0000ooooooooool02_ooool2028VV`80QVNX0`2YOjD01@2fQj@0c:Fa0<bU
/@3<YK40ain`00?o000000@07c^d03a3[`1_H;40Kf2a0P21J:d00`0cO>H0NY3M0;2RbP030;2RbP80
bZ^j0P3UgLd00`38n:`0bJ:`0<VR/0020=B/[`80h[jd0P3/cKD20??M]`060?G[^@3`mKl0j?S<0>Sh
c03OlM/0dMgQ0`32a=/00`2n_]X0]ZkA0;F^dP020;F^dP040;>_e02cZLh0/jW>0;:/dP80]:S<0`2d
[M402`2b/ML0]JoB0;F_dP2b/mT0][;E0;:fg00006P04B>Q04@lX`1bEj<0OenT00<0U6^Q00<0XgJQ
0:UjX02gQJ000P2gQJ030=2MXP80i[FQ00<0oMJG0000002Y^^H00P2Y^^H20:Rii@040:Nfi02T[Md0
XjOI0:>Wf@<0Xj?E0P2RWm800`2PWM40WXg209b=``0209b=``80UXc70P29R<`207AmcP<0JGW@00<0
Gfc805iS`01_L<<00P1bJk`207UZ]P80Pg:g00<00R2S06mIZ01_FJP00`2@K:H30:QkX`06o`00003;
VJ<0biVS0>^nYP3a_i`000000P2kTJ/01032VJh0aYZ[0<JJZ`3:XJh20=6W[080gKJa0P3X`k000`3c
djoo0000o`000002ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooo
o`<0000000?o000001TI6@0I6AT06P0I6ATT000000<06ATI00Co000003<c<`0c<c?o00000P1<C4`0
0ol00000IVIVo`00000207moO`04o`00002IVIT0VIVIo`0000D0/k>c0ol000001`2IVIWo000007mo
O`1oOgoo000006IVIP0000000P1<C4`01?l00000<c<c03<c<ol0000301TI6AX00000100I6AT01000
0000<c<c03<c<`00000204a<C00;o`00001VIVKo000007moOol00000VIVIo`00002c/k?o00000<c<
c?l00000103Vi^H3o`0000@0i^KV00Go00000<c<c?l00000/k>co`000004ooooo`0300000?oooooo
oooo017ooooo00?o0000ooooooooool02oooool00`0R9Y/0QVNX08IWZ0030:UoY@<0c:Fa0_l00000
1@3RdlWoooooooooo`000iD0?4>_0080Ge>]0P21J:d2095a[00507Z@g@2`X/X0/:;:0;2RbP3:ZkX0
0P3UgLd20<>I[0060<VR/03D[:l0e:b_0=B/[`3R^[00h[jd0P3/cKD01@3cgKL0mN^i0?G[^@3Nnk@0
gOk@0080e^gS0P36cMl00`32a=/0^:oA0;J^d@020;J^d@030;F^dP2cYL/0/jW>0080/jW>102dZ<`0
0`2d[M40]j[<0;F_dP020;F_dP<0][;E00<0/[KL014SX@14?:<00P1bEj<209A[X@0309=[XP2YNZ00
ZGZP00<0]hFP00<0aYBR0=2MXP3@WJ800P3V]J401@3meYL0Zk_U0:VjiP2Y^^H0Z;GR00<0Y[;Q0P2T
[Md20:>Wf@040:>Se@2MTLL0WXk309j>``<0WXg20`2LSL<209J<a`80RHS<0P1dOLh205a]c00305m/
b01NHl00GV?00080LV^l0P1iJ[H2085//P040;5:001ACk40DDna06mIZ0<0T6bV0P2XNj<00`3;VJ?o
00000<^IX`020>^nYP<0^i6[00@0`YV^0<JJZ`36VZ/0bZ6^0P3AYj`01P3L/J/0gKJa0>S3/03X`k00
lm>_0?[TZP?ooooo00?o0000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo0`00
00000ol000006ATI01TI6@0J01TI6B@000000`0I6AT01?l00000<c<c03<c<ol0000204a<C0040000
001VIVH0IVIVo`000080Ogmo0_l000000`2IVIWo0000o`000003o`0000<0VIVI00Co000007moOol0
003o00000P1VIVH010000000C4a<04a<C?l0000203<c<`04o`00000I6AT06ATI01TI6AX00000100I
6AT010000000<c<c03<c<`00000204a<C00;o`00001VIVKo000007moOol00000VIVIo`00002c/k?o
00000<c<c?l000000`3Vi^H01?l00000oooo0?ooool000040>KViP05o`00003<c<co00000;>c/ol0
00001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00<08RJK08IWZ026
IjP00P2YOjD01P31Y;_o0000o`000?l00000c:Fa0>gYb0Cooooo00<000>E05mC[@1ODjd00P1mHj/0
1@2ALJ`0Tg6Y0:=mZ@0V0000/:;:0080]n[f00D0[hN[0;RA[P33VJ`0`iV/0<VR/0020=B/[`80h[Z`
0P3_c[401`3hh[00m_6[0?KaZ`3XmjP0_?Na0=3kh`3FkN<00P36cMl01P2h/M80^:oA0;R_d@2h[m40
]ZkA0;:Sb0<0/jG;00<0/jW>0;BTb02dY<P00P2dZ<`01@2gYLL0]j[<0;NZc02gZ/`0]JoB0080^Jk>
00D0][;E0;Zbd@2j/]40001`04@lX`02079GX`<0Tf^R0`2YNZ000`2gQJ00aYBR0<JDXP020=2MXP03
0>JeX@3meYL0oMJG0080ZkOR0`2X]N80102V/^40X:KJ09jNe02NW]@209fGc@<0WI770P2NS/<309j=
`P80W8g300@0UXc709V3^@2>PL00SX700`1gN<L0101LKL`0BUg405m/b01NHl0206AP^@03079[_01i
J[H0PFbb0080PFbb00<00R2S055?/@1ACk400`2@K:H0102XNj<0]H^Z0<^IXol000030>^nYP<0^i6[
0`36VZ/20=6W[080g;6[00T0gKJa0>S3/03cdjl0lm>_0?[TZP3Sl980cNf=0;kh/_l000004?ooool0
00Wooooo00@00000oooooooooooooooo0`0000000ol000006ATI01TI6@0K01TI6B<00000100I6AT0
1?l00000<c<c03<c<ol0000204a<C0040000001VIVH0IVIVo`0000<0Ogmo00?o000009VIV@2IVIT0
102IVIT2o`00000307moOol00000IVIV0080IVIV00@0000004a<C01<C4co00000P0c<c<01?l00000
6ATI01TI6@0I6ATK000000@06ATI00@0000003<c<`0c<c<000000P1<C4`02ol00000IVIVo`00001o
Ogoo000009VIVOl00000/k>co`00003<c<co00000080i^KV00?o00000?ooo`3oool00P3oool02Ol0
0000i^KV0>KViP3Vi^Ko00000<c<c?l00000/k>co`000004ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool03Oooool208IWZ0?o000000<0`JBk0<bU/@3<YK400P3]jLP4ooooo`030003
U@0l@jl0Ge>]0080OF>[0P2CLJT30:=mZ@<0[hN[0`33VJ`00`3?YJd0e:b_0=B/[`020>:j/080klja
00D0n>:`0?KaZ`3XmjP0_?Na0=3kh`020<OGiP060<K=g`2h/M80^;7B0;RadP2h[m40/Z770`2bXlP0
0`2cYL/0/io40;BTb0020;BTb0@0]jG700D0]j[<0;ZXb02jZ<P0^Jk>0;b]b`030;Zbd@040;Zfe@14
?:<0A3bS079GX`<0Tf^R0`2YNZ000`2gQJ00aYBR0<JDXP020=2MXP030>JeX@3meYL0[[KN00<0ZkOR
00<0Z;GR0:F]g@2PY]X00P2PY]X209jNe080WIO=0P2MTLL209j>``80WXg200<0W82d09f2]@2MP[D0
0P2IPkT308j1`080MgS700<0E6K705a]c01:GL@00P1NHl0206AP^@80NFZf0P21K;800`000680DDna
055?/@0308md/@<0]H^Z00@0biVSo`00003[_ZH0jkjV0`2kTJ/30<JJZ`070<jQZ@3AYj`0g;6[0=ba
Z`3Y`:X0j<>`0??C[`020?[TZP050>?`TP3=kHd0`_kDooooool000003oooool000Wooooo00@00000
oooooooooooooooo0`0000000ol000006ATI01TI6@0L01TI6B<00000100I6AT01?l00000<c<c03<c
<ol0000204a<C0040000001VIVH0IVIVo`0000<0Ogmo1_l0000207moO`05o`00001VIVH0IVIV06IV
IP0000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000<06ATI6`00000401TI6@060000000c<c<0
<c<c0000001<C4co00000P1VIVH2o`00000409VIVOl00000/k>co`000080c<c<00Co00000>KViP3V
i^Ko0000103oool02Ol00000i^KV0>KViP3Vi^Ko00000<c<c?l00000/k>co`000004ooooo`030000
0?oooooooooo013ooooo00?o0000ooooooooool03?ooool3o`0000@0`JBk00<0c:Fa0>gYb03]jLP0
1Oooool00`000iD001^P05mC[@0207eSZ`80Tg6Y0`2SOJT20:n7Z`040;V?ZP33VJ`0`iV/0<>I[080
cjF]00P0e:b_0>:j/03_c[40klja0?SR/03flJ/0`>Ao00000080`N7_00H0amOV0;NdeP2g]=H0]kCF
0;RadP2`WlL30;:Qa`030;:Sb02aVl40/io40080/io400<0]:C80;JP`P2fX<800`2gYLL30;ZXb0<0
_:g;00H0^[;A0;jbc`2n//l000ZC04@lX`1bEj<309=[XP<0ZGZP00@0]hFP0<JDXP36U:80aYBR0P3V
]J400`3meYL0[jkG0:Z`g0030:Z`g080YJgM0P2PY]X0102NW]@0Thc909B4`02DQ<0209J0^@80VWne
0`2LP;@309f2]@80VH>i0P2>PL0307Mha`0405AVa`1:GL@0AUBm04ID_@80I62i0P1_H[@3085//P80
DDna0`2?M;430;F;ZP040<^IX`3[_ZKo00000;>:ZP80^i6[0P30TjP01036VZ/0cZ6Y0<jQZ@3AYj`2
0=baZ`060>W0ZP3gdjL0lm>_0?[TZP3Sl980cNf=0oooool00ol0003oooooooooo`0=ooooo`002Ooo
ool01000003oooooooooooooool300000003o`00000I6AT06ATI01h06ATI8@00000401TI6@04o`00
000c<c<0<c<c03<c<`;o000000@0C4a<000000000000IVIV0ol0000607moO`;o00000P1VIVH20000
0080C4a<00?o000003<c<`0c<c<00_l0000301TI6A`00000100I6AT01P000000<c<c03<c<`000000
C4a<o`000080IVIV0_l00000102IVIWo00000;>c/ol000020<c<c003o`00003Vi^H0i^KV00;o0000
103oool02?l00000i^KV0>KVi_l00000c<c<o`00002c/k?o00001?ooool00`00003oooooooooo`0@
ooooo`03o`000?oooooooooo00Wooooo0ol00003ooooo`0507J4e031Y;/0`JBk0<6T^`35o/l02?oo
ool010000iD0Ge>]05mC[@1mHj/309=aZ@80XgfY00D0[hN[0;V?ZP2iSjX0^HnZ0<>I[0030<nU[@80
h[Z`00<0klja0?SR/03hh[000P30i7l00`2`ioP0`N7_0;Bgf`020;Bgf`030;NdeP2^WlP0/9o70080
/9o70P2bXLL30;6K`@030;>Oa02dVkh0]9^n00<0]Z3200@0]jG70;ZS`P2jXl80^ZS80P2mZ<@0202l
[L/0`:k80<2^b02n//l0`K?<0000L014?:<0LUNS102CJj820:UjX0@0aYBR0P3V]J400`3meYL0[jkG
0:n^e`020:Z`g0030:RWeP2NX]L0WZ;G0080UiOB0P2CS<T209B4`080UX2i0`2JOkD309b0]080WH:e
0P2IPkT00`2>PL00UWff085g_`02085g_`0305AVa`0cCl40BUg40080AUBm00<0I62i06mR]01_H[@0
0P1kIk000`21K;80RW2_055?/@0308md/@<0]H^Z0P3[_ZH01?l00000/hZZ0;>:ZP2kTJ/20<2CZ003
0<JJZ`3>XJT0cZ6Y0080g;6[0P3Y`:X0103gdjL0o>FK0?[TZP000004ooooo`03o`000?oooooooooo
00gooooo0009ooooo`0400000?ooooooooooooooo`80000000?o000001TI6@0I6AT08@0I6ATO0000
00D06ATI00?o000003<c<`0c<c<00P0c<c<01?l00000C4a<04a<C000000306IVIPKo00000P1VIVH2
000000<0C4a<00Co000003<c<`0c<c?o00001@0I6ATL000000@06ATI00H0000003<c<`0c<c<00000
04a<C?l0000206IVIP;o000000@0VIVIo`00002c/k?o00000P3<c<`00ol00000i^KV0>KViP020>KV
iP;o000000<0ooooo`00003Vi^H00P3Vi^H01Ol00000c<c<o`00002c/k?o000000Cooooo00<00000
ooooooooool04?ooool00ol0003oooooooooo`06ooooo`?o00002?ooool00`31Y;_oooooooooo`08
ooooo`030:U8000o@J/0Ge>]0080OF>[0P2CLJT20:=mZ@@0^HnZ00L0`iV/0<nU[@3?YJd0cjF]0=nh
[`3R^[00klja0080n>:`00<0`>Ao0;3Wn02]^N800P2]^N800`2d]m/0ZYk:0:jOb0020:jOb080/9o7
00<0/Z770:nH_`2_V;l00P2aVl440;BK_P030;JP`P2iW[d0^Z?20080^Z?20`2mZ<@30<2^b0040<B_
aP31/l`0`K?<000:T`80LUNS0`2CJj820:UjX0@0aYBR00@0hK6U0?gFU`2bZLl0[jkG0P2`Y/h30:RW
eP80WZ;G0P2GUm8209><b@80U8C00P2FP;T209Yo]@<0W82d00@0WH:e09mkZ`2NOJl0WWf_0P2FOKH3
085g_`0305ITa@1DI/L0<do10080AUBm00@0CU>g06AP^@1_H[@0Kf:d0P1kIk000`2:L:l0DDna055?
/@0308md/@80]H^Z00D0eKVn0>^nYP3[_ZKo00000;>:ZP030<2CZ0<0cZ6Y00<0fJbY0=baZ`3Y`:X0
0P3gdjL00`3liI/0`]IQ00000004ooooo`03o`000?oooooooooo00gooooo0009ooooo`0600000?oo
ooooooooooooo`00003o00009P0I6ATN000000D06ATI00?o000003<c<`0c<c<00P0c<c<00ol00000
C4a<04a<C003000000H0IVIV0P00000404a<C004o`00000c<c<0<c<co`0000D06ATI00?o00000000
000000006P00000401TI6@040000000c<c<0<c<c00000080C4a<00_o000006IVI_l00000Ogmoo`00
002IVIWo00000;>c/ol00000c<c<o`0000060>KViP05o`00003Vi^H0i^KV0>KVi_l000000P3<c<`2
o`00000309VIVOoooooooooo00;ooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`03
ooooo`?o00005oooool203m1Z`80OF>[0P2CLJT00`2SOJT0[8B[0;V?ZP030;V?ZP<0cjF]0P3O^:l0
1@3adK40nN^[0?W[Z`30i7l0U[K^0080XkWX00<0[KWR0:FMcP2ZW/X00P2ZW/X20:jOb0030;2Oa`2/
UKh0[iRo0080[iRo00<0/I_10;:G^`2bUk/00P2dVkh01@2gVKT0^Ijm0;VN_@2iW[d0^Z?20080_J>n
00@0_JS40<6Y`P31ZL80`:k80`34[lH01031/l`000ZC079GX`1bEj<309=[XP80ZGZP0`36U:820>6a
Y@030?kOV02cWl@0/io400<0/:K>00@0Z:OF0:FNc`2DU=00U9C@0P28QLT208Ei_P80U8C00P2FP;T3
09Yo]@0409b0]02LMjT0Wg^[09mkZ`80WWf_0`2FOKH3085g_`0405ITa@0cCl409D:i04ID_@80CU>g
0P1_H[@207]W/080R6f]00@0DDna08md/@2?M;40SgBa0P2eRjX20=Fi_P80/hZZ00Co00000<2CZ030
TjP0`9>X0P3>XJT20=V/Z@030=baZ`3Y`:X0mm>W0080o>FK00<00000ooooooooool00oooool00ol0
003oooooooooo`0=ooooo`002Oooool01@00003ooooooooooooooooo000002P06ATI7@0000000ol0
00006ATI01TI6@0301TI6@;o00000`0c<c<2o`0000<0C4a<1P00000304a<C0?o00000P0c<c<00ol0
00006ATI01TI6@0301TI6Ah00000100I6AT010000000<c<c03<c<`00000204a<C009o`00001VIVKo
000007moOol00000VIVIo`00002c/k?o00000080c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol00000
c<c<0<c<c002o`00000309VIVOoooooooooo00;ooooo00<00000ooooooooool03oooool01?l0003o
ooooooooooooool3o`0001[ooooo00H001^P03m1Z`1dH:h0M62^09=aZ@2GMZ`30:b4Z`<0^HnZ00<0
aif]0<nU[@3O^:l00P3O^:l01@3adK40nN^[0?W[Z`000000V9cF0080WigB0`2UWLh20:ZNbP030:jO
b02YT[h0[9Fn0080[9Fn00<0[iRo0:nB^@2bUk/00P2bUk/0102dVkh0]iVi0;NI^@2gVKT20;VN_@<0
_J>n0`31ZL830<B_aP050<N`a033//T000ZC05A9Z01bEj<00`2CJj800`2YNZ00]HNT0;F7Y0020<JD
XP80hK6U00H0o]nH0;>Oa02cWl@0/io40;2VcP2aW/D30:FNc`80U9C@00<0R8G908Ei_P25NKh00P29
Lk@208mb[P<0UWB[0P2LMjT309mkZ`80WWf_0P2FOKH3085g_`0805ITa@0LA;d0<do102E2^@16E;d0
CU>g05mH/`1_H[@207]W/0<0R6f]0`2?M;402@2eRjX0eKVn0=Fi_P3E^Kh0ZX:Y0;>:ZP2hS:So0000
0<2CZ0020<RJZ0030<jQZ@3I[:T0fJbY0080jL2Z00<0mm>W0?cUV`3[ih401_ooool00ol0003ooooo
ooooo`0=ooooo`002Oooool01000003ooooooooooooooolY01TI6@03o`0000000000000001`00000
1P0I6AT00ol00000<c<c03<c<`0203<c<`?o00001P1<C4`3o`0000@0<c<c00?o000001TI6@0I6AT0
100I6ATN000000@06ATI00@0000003<c<`0c<c<000000P1<C4`02Ol00000IVIVo`00001oOgoo0000
09VIVOl00000/k>co`0000030<c<c003o`00003Vi^H0i^KV00@0i^KV0_l000020<c<c004o`00002c
/k?o000009VIV@Cooooo00<00000ooooooooool03oooool4o`0001kooooo00<0?d6[07AP[P1dH:h0
0P2GMZ`30:b4Z`80^HnZ0P37WJd0103?YJd0gkR_0=nh[`3adK420?W[Z`040000002HW=H0V9cF09RL
eP80WigB0P2UWLh00`2ZW/X0YI2o0:VB_P020:VB_P80[9Fn0`2_T[T20;:G^`@0]iVi00<0^Ijm0;bN
^P2lW[X00P2mXkh01@31Y;`0`JW20<6Y`P36Zkl0a:o600<0ak3400<0`k;905A9Z01DBJP00P2CJj80
1@2ELZT0]HNT0;F7Y02eQj@0aYBR00<0hK6U00@0]9Nj0;>Oa02cWl@0]YRi0`2aW/D0102UW/l0XIK9
08J5b`26QL/208R5b@0308Ei_P29Lk@0RG>d00<0Sg:^0P2FM:/209agZ@<0Wg^[0P2NOJl00`2FOKH0
XGn^08ml^P0208ml^P80HF_600@074Bm02E2^@0U@[T0CU>g0P1OF;<00`1_H[@0NfN`07]W/00208Q]
[@0309AdZ`27U]/0QiKK00<0eKVn0P2ZPZT20;R<Z005o`000030TjP0b9ZX0<RJZ03>XJT00P3I[:T0
1@3Y_JP0mm>W0?OCY`3liI/0000000Kooooo00?o0000ooooooooool03Oooool000Wooooo00@00000
oooooooooooooooo400I6AT;000001006ATI7P00000601TI6@03o`00000c<c<0<c<c00@0<c<c1_l0
000603<c<`03o`00000I6AT06ATI00@06ATI7`00000401TI6@040000000c<c<0<c<c00000080C4a<
00Go000006IVIP1VIVKo000007moO`02o`000080/k>c00Co00000<c<c03<c<`0c<c<0ol000020>KV
iP07o`00003<c<`0c<c<0<c<c?l00000/k>co`00000209VIV@05o`000?ooooooooooooooo`000000
4Oooool2o`00023ooooo0P0o@J/00`1dH:h0UgJ/09Mf[0030:b4Z`040;V?ZP37WJd0aif]0<NM[@80
gkR_0P3adK420?W[Z`80TIcJ00@0V9cF09B=b@2JSLD0VXg50P2PS/830:F@_`80ZI:n00<0[9Fn0:^?
^02_T[T00P2_T[T00`2bUk/0]9Bg0;BD]`030;NI^@<0_9jj00@0_J>n0<6T_031Y;`0`JW20P36Zkl0
1`39[[h0ak340<N`a037/<@0a:o6000:T`1DBJP00`2ELZT30;F7Y0050<JDXP3Q/JD0hK6U0?kOV02d
UkX0102fV;T00`2aW/D0/iZn0:6Fb@020:6Fb@0308J5b`1cL<40Lg310080QGVn0P29Lk@208mb[P80
UWB[0`2LMjT209mkZ`0309im[`2UOJP0XGn^0080XGn^0`2?O;X0101QJlH02Sfm000Y/00U@[T204iC
]`80GeRc0P1kIk0208Q][@80U7B[0P27U]/0103E^Kh0ZX:Y0:Z2Z@2^QJP30;R<Z003o`000038VZP0
b9ZX0080fJbY0P3Y_JP00`3ie:<0n^F>0?cUV`08ooooo`03o`000?oooooooooo00cooooo0009oooo
o`0400000?ooooooooooooooo`d06ATI0`00000;03<c<`<000003`0I6ATM000000H06ATI0ol0000=
03<c<`;o00001P0I6AT00ol0000000000000000M000000D06ATI00@0000003<c<`0c<c<000000P1<
C4`01ol00000IVIVo`00001oOgoo000009VIVOl000000P2c/k<2o`0000@0c<c<0_l000030<c<c006
o`00002c/k<0/k>co`00002IVIWo00001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01gooooo00@001RQ03m1Z`1dH:h0M62^0P2GMZ`20:b4Z`@0aif]00H0f[Fc0=nh[`3adK40lM6a
0>keY@00000208n=c@<0U8g90P2JSLD20:2>`P80YI2o00<0ZI:n0:N;^02[SkP00P2[SkP20:nB^@@0
]9Bg00<0]iVi0;ZI]P2jVKH00P2lW[X30<6T_0<0aZ^o0P39[[h01037/<@0b:o10<R_`@002Y<205A9
Z080UG:Y0`2eQj@30>6aY@030?kOV02dUkX0]I2`00<0]YRi0`2cV[h20:6Fb@80QXG;00<0Lg31079U
]@1bIKD00P29Lk@208mb[P<0UWB[0P2LMjT209mkZ`<0YGfX0P2QOjh308ml^P80HF_600@02Sfm000Y
/00U@[T0CU>g0P1OF;<2079Q/0<0R6f]0P2DM:/20:1kZP030:Z2Z@2^QJP0[XFX00<0^8bX00D0b9ZX
o`000038VZP0e:JX0=V/Z@020>VmZ0030?WDX`3jiHh0d=IO00Sooooo00?o0000ooooooooool03?oo
ool000Wooooo00@00000oooooooooooooooo2@0I6AT01000003o000000000000000A03<c<`03o`00
00000000000000`06ATI00?o00000000000000006P0000000ol00000000001TI6@0601TI6@?o0000
1P0c<c<4o`0000H06ATI8P00000501TI6@040000000c<c<0<c<c00000080C4a<00?o000006IVI_l0
00000P1oOgl01?l00000VIVIo`000?l000020;>c/`03o`00003<c<`0c<c<00@0c<c<0_l000001P2c
/k?o0000o`00002IVIWo000007moO`Cooooo00<00000ooooooooool04_ooool00ol0003ooooooooo
o`0Mooooo`03000HX@1dH:h0M62^0080UgJ/0P2/Q:/00`2hTk40aif]0<NM[@020=Ze/`80lMVh0P3^
mJD208b@dP80Shg=0P2DSLT209Z=a@80X8k200<0YI2o0::8^@2WRkP00P2WRkP20:^?^0030:nB^@2`
T;@0/92d00<0]9Bg0`2jVKH0102lW[X0`9ng0<2O]`31Y;`20<JW^P040<J[_`39[[h0bJjn0<V^_P<0
b:o100<0`:Jo05A9Z01DBJP00`2ELZT20;F7Y0040=:[/@3Q/JD0hK6U0;BG^P<0]I2`00<0]YRi0;ZE
/P2jUK800P2cV[h209fBb080KgC800<0Lg31079U]@1bIKD00P1lI:d308mb[P80UWB[0P2LMjT00`2O
Nj/0XgVT0:EmZ0020:EmZ0<0XGn^00@0Sgbj0:65]P1eNLT0MGW90P0:?Kd01000:K00;D6d05mH/`1O
F;<2079Q/0<0Q6^^0P2DM:/00`2PNjX0XgfY0:j5Z0030:j5Z080^8bX0P38VZP01Ol00000e:JX0=V/
Z@3Y_JP0nMBS0080n^F>2Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooo
ooooool801TI6@030000000c<c<0<c<c01H0<c<c00<0000001TI6@0I6AT02`0I6ATO000000P06ATI
1_l0000901TI6B<000001@0I6AT010000000<c<c03<c<`00000204a<C005o`00001VIVH0IVIVo`00
001oOgl00_l0000209VIV@;o000000<0/k>co`000?l000001?l000020;>c/`07o`00002IVIT0VIVI
09VIVOl00000Ogmoo`000003ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool07Ooo
ool205mN^@80UgJ/00<0[8B[0;RC/@2hTk400P37WJd20=Ze/`80lMVh00@0k_FU08>9d@25Q</0QHC;
0P29P/D208n2`@80UX>m0P2LQKX30::8^@80Yh^h00<0Zhnh0:b</`2`T;@00`2`T;@00`2dU;L0]iBc
0;ND/`020;ZI]P<0`9ng0`36YkX01P3;ZkT0bJjn0<V^_P39[[h0c:nm0<R_`@80aJVm00<000nO05A9
Z02ELZT00P2ELZT01@2eQj@0dZ^a0=:[/@3BZk40o]nH00@0]I2`0`2jUK800`2cV[h0^9^j0;RK^P02
09fBb00406mdb01AEkX0Lg31079U]@80O6B]0`28J:L209IdZ`0409agZ@2LLj@0XgVT0:=iY0<0YGfX
0`2QOjh30:65]P0607Eib@00?l8003o2000Y/00]@K@0A4^d0P1OF;<2079Q/080Q6^^0P2EM:`30:=m
Z@<0[XFX00H0^8bX0<2CZ030TjP0b9ZXo`00003DYZP20>VmZ0030?WDX`3jiHh0d=IO00Wooooo00?o
0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo1P0I6AT2000001X0<c<c0`00
000;01TI6B0000004`0I6ATU000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C004o`00
001VIVH0IVIVo`000080Ogmo00Go000009VIV@2IVIT0VIVIo`0000060;>c/`;o00000P2IVIT2o`00
000307moOol0003ooooo00?ooooo00<00000ooooooooool05?ooool2o`0001gooooo0P1OG[T209b2
]`@0^9>a00D0aif]0=Ze/`3afKP0lMVh0>keY@02ooooo`0308>9d@25Q</0QHC;0080RH;500<0Sh;1
09J3_@2FPkd00`2LQKX20::8^@030:N;^02WQk<0[8bc0080[8bc0P2`T;@01@2cSk80]iBc0;ND/`2g
U;<0^YVf0080_Y^d0P30WkL00`35XkH0aZNj0<JW^P020<^[^@030<V^_P3<[kd0c:nm00<0aJVm00<0
^IVg000?W`1DBJP00P2ELZT01P2eQj@0dZ^a0=:[/@3BZk40kOBR0;::Z`<0]I2`0`2jUK830;RK^P05
09fBb02GTL`0Aek706mdb01AEkX00P1bIKD0101lI:d0R6RW08QXY`28J:L209=^Y@80W7>T0`2SNJ@3
0:EmZ0030:5o[P2]QJX0[HFZ0080XHFf0P1eNLT2000o`P04000Y/00]@K@0A4^d05mH/`80LV6`0P24
Jjh309Ed[080XgfY0`2^QJP02`2hS:P0`9>X0<2CZ038VZP0e:JXo`00003V^ZT0jKfX0?WDX`3jiHh0
d=IO00Wooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo100I6AT2
000000d0<c<c1000000>03<c<`03o`00000I6AT06ATI00T06ATI00?o00000000000000007`00000<
01TI6BT000001@0I6AT01@000000<c<c03<c<`0c<c?o000000<0C4a<00Co000006IVIP1VIVKo0000
0P1oOgl01?l00000VIVI09VIV@2IVIT6o`000080VIVI0_l0000207moO`03o`00001VIVKooooo00?o
oooo00<00000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`0305mN^@2LP[L0W8:g00@0
^9>a0P3J]K<20?7I^0?ooooo00<0Mgk=08F4b`25Q</00P29P/D208n2`@80UX>m0P2LQKX0102RR;T0
XH>d0:N7/`2WQk<30:b</`030;2@]02cSk80/hnb00<0]iBc0`2nVk@01030WkL0aJ>f0<FS]P36YkX3
0<^[^@<0c:nm00P0c:fk0<FY_@2nW[P0_Yjh0;VI]`003il0UG:Y09^Ab0@0dZ^a0P2bRZ/20;F@/080
^HnZ0P2jUK800`30V:h0^9^j0;RK^P0309NAc00404MNa`1AEkX0E4j^079U]@80O6B]0P28J:L209=^
Y@80W7>T0`2SNJ@20:EmZ0060:f1Y02]QJX0[HFZ0:f5ZP2QQKH0]9Be0`2@TM000`00C</000^L000U
[00204A;]080LV6`0P24Jjh309Ed[080XgfY0`2^QJP30<2CZ0<0e:JX00Co00000?[GY03jiHh0n^F>
2_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool301TI6@03o`00
000c<c<0<c<c00X0<c<c0`00000404a<C0H000002@0c<c<2000000T06ATI9@00000601TI6B`00000
1@0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<o`000080IVIV0_l0000207moO`?o
00001P2IVIT2o`0000@0Ogmo00?o000006IVI_ooool00oooool00`00003oooooooooo`0Gooooo`03
o`000?oooooooooo01[ooooo0P1OG[T209b2]`80^9>a0P3>/[h00`3J]K<0lMVh0?7I^004ooooo`04
07Mnc@1kN/H0PWW0089i`080RWZl0P2FPkd0102LQKX0VGnf0:63]02QPk@30:N7/`80[8bc102cSk82
0;ND/`<0_Y^d0`35XkH30<^[^@80cjji00<0c:nm0<b]^`3<[K/00`2nW[P00`2iVKL000nO09^Ab002
09^Ab080dZ^a00D0kOBR0;::Z`2bRZ/0/XZ[0;F@/0020;V?ZP040;ZE/P30V:h0`9R^0;RK^P80_j6j
0P2GTL`01017G/L0DENj05A>[P1DCZh207aT[@80R6RW0P2CKZD309acY080XgVT00<0YGfX0:f1Y02]
PJ@00`2]QJX30;BD]@04092Ad02a]]`0/KKL001Sc08002F/00@0A4^d065J/`1QF[<0LV6`0P24Jjh2
09Ed[0<0XgfY00<0[XFX0;F;ZP30TjP00P30TjP01`3=X:X0e:JX0>JjZ@3V^ZWo00000?;VPP000000
2_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool201TI6@030000
000c<c<0<c<c00L0<c<c1000000=04a<C08000002@0c<c<00`0000006ATI01TI6@0701TI6EH00000
1@0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<o`0000@0IVIV00?o000007moO`1o
Ogl00P1oOgl6o`0000@0Ogmo0_l0000206IVIP05o`000?ooooooooooooooo`0000006_ooool00ol0
003oooooooooo`0Jooooo`0400YAcP2LP[L0W8:g0;RC/@<0c[:n0P3Yjll5ooooo`80Mgk=00@0Ng[6
089i`02:N[`0RWZl0P2BO;P209Uo]P<0XH>d0P2WQk<00`2/S;<0[X^a0:j;/@030;>?/P030;ND/`2j
U[40^YJa0080_Y^d00D0`ijc0<FS]P35XkH0bZNf0<^[^@030<n^^@<0c:fk00<0aZJi0;jN^02nW[P0
0P2`Rjh010003il0Vi7809^Ab03BZk420:n4Y`<0/XZ[0`2iSjX30<2H[P<0_j6j0P2=UmT01P00<[T0
Aek7055G^P1DCZh0JEFX07aT[@<0R6RW00@0TfjU09acY02LLj@0W7>T0P2SNJ@40:f1Y080[HFZ0`2d
U;D01`3=ZkL0/KKL0=CYi03DjNCooooo000U[014Bk@00`1QF[<208A[[P<0UGB/0P2SOJT30;F;ZP04
0<2CZ03=X:X0cJ2Z0<fPZP80i[ZY00?o00000?;VP_ooool02oooool00ol0003oooooooooo`0;oooo
o`002Oooool01P00003oooooooooooooool06ATI000000L0<c<c0`00000C04a<C0800000200c<c<0
0ol000006ATI01TI6@0701TI6E@000001`0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0
C4a<o`0000@0IVIV00?o000007moO`1oOgl02@1oOgl2o`0000<0IVIV00?o0000ooooooooool00_oo
ool00`00003oooooooooo`0Iooooo`;o00006oooool30:JUe0<0c[:n00<0jN_?ooooooooool01?oo
ool206Mab@0306i_``22NL00PWW00080RWZl00@0TWbh09Uo]P2IOkH0VGnf0P2QPk@00`2WQk<0YhJa
0:j;/@020:j;/@<0/hnb0`2jU[40102nVk@0`ijc0<>N/`35XkH20<ZW]P060=2]]P3?[[T0cjji0<n^
^@3A/;T0c:fk0P36Y[T00`2nW[P0/hna0;2;[P020;2;[P0309^Ab02_RZh0[hBW0080[hBW0P2bRZ/0
102fR:D0^HnZ0;V?ZP2iSjX30<2H[P040<^P[02oXKX0bZno0<Z__`80SIOI00H003:i014_[@1DCZh0
E4j^06UEZ01lI:d208QXY`80TfjU0P2LLj@20:=iY0@0[H6T00<0[HFZ0;^?Z02kSjP00P2dU;D0203=
ZkL0jlff0=CYi02cbU7ooooo0000RP009J`0A4^d0P1QF[<207eY/P<0UGB/00<0XgfY0:N2[02eRjX0
0P2eRjX01030TjP0cJ2Z0<fPZP3=X:X20>JjZ@030?;VP_l0003ooooo00_ooooo00?o0000oooooooo
ool02oooool000Wooooo00D00000oooooooooooooooo0000000703<c<`030000001<C4`0C4a<01H0
C4a<00?o00000000000000001P0c<c<00`0000006ATI01TI6@0701TI6E<000001`0I6AT00`000000
<c<c03<c<`0203<c<`040000001<C4`0C4a<04a<C0?o00000P1VIVH;o`000080IVIV0ol000000`1<
C4coooooooooo`02ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool30:JU
e0030<jb_P3Yjloooooo00Oooooo0P1WLLT207Q`_@80RWZl0P2BO;P209Uo]P040:63]02PPK40YhJa
0:N6/@@0[X^a00<0/hnb0;JA/02jU[400P2jU[430<>N/`<0bZNf0P3@[KH00`3?[[T0dK2i0=6`^@03
0<JV^@<0/hna0P2`Rjh00`2_RZh0Zh6V0:n4Y`020:n4Y`050;::Z`2fR:D0]XRU0;J8Y@2iSjX00P30
TZH00`30V:h0bj2/0<^P[0030<Z__`040=[9b@1_Y?4003:i014_[@80E4j^0P1YEJP208QXY`80TfjU
0P2LLj@00`2SNJ@0Z7^R0:QkXP030:f1Y0040:f5ZP2kSjP0^hnX0;BD]@80cJ^g00<0jlff0?S]WOoo
ool00_ooool0100008X04SBb065J/`1QF[<207eY/P<0U7N_0P2WPZ`30;F;ZP@0cJ2Z00D0h;N^0?[G
Y03biX;oooooo`00000;ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
ooooo`H0<c<c00<00000o`00001<C4`01`1<C4`;000000T0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0601TI6E<000001`0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0
C4a<00@0C4a<00?o000006IVIP1VIVH02P1VIVH2o`0000@0C4a<00Go0000oooooooooooooooo0000
000Nooooo`03o`000?oooooooooo01Wooooo00<0YZGDooooooooool02Oooool2051Sa`0406i_``1h
L;d0Pg>i08=c^@80SWNf00@0VGnf09Ql/`2PPK40X86a0`2WQ[420:j;/@040;2</02fTK00]Y6`0;JA
/080^YJa00D0_iZa0<>N/`33W[<0bJ>c0<ZW]P030=2]]P<0dK2i00<0cjni0<JV^@36Y[T00`2cSk42
0;2;[P<0Zh6V0P2_Q:L40;J8Y@040;V?ZP30TZH0`9:V0<2H[P80bj2/00T0fJn]0<Z__`3JbLT0f/W9
0>G_e00@U>4003:i014_[@1DCZh00P1YEJP207mPY080TfjU0P2LLj@30:QkXP<0[H6T0`2kSjP20<f[
]`80jlff00<0/lYAooooooooool00_ooool0100B=;80@4ji065J/`1QF[<207eY/P80U7N_0`2WPZ`2
0;F;ZP030<6H[P3=X:X0cJ2Z0080h;N^00D0n]NT0?;VP_ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00_ooooo0009ooooo`0400000?ooooooooooooooo`@0<c<c0P00000604a<C0@000002`1V
IVH3000000L0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6E400000200I
6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH01`1V
IVH2o`0000D0C4a<00?o0000ooooooooool00_ooool00`00003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00<0D6?705]S`@1hL;d00P23LkT208ig]P80V7bc0`2PPK420:N6/@030:j;/@2`
S;00/8b`00<0]Y6`00@0^YJa0;nJ/@2oV[40`ijc0P39Xk<30=2]]P80e;:g00@0dK2i0<n_^@3?[kT0
aZJi0P2kV[H20;>?/@030;2;[P2XOjL0Zh6V0080Zh6V0P2_Q:L0102`PZ<0]XRU0;J8Y@2fR:D30<2B
YP80bj2/0P3I[jd02P3/ajd0f/W90>G_e03Ukm@0T^N[098M000007/072ZS05A>[P1YEJP207mPY080
TV^R00<0W7>T09mcX@2XNj800P2XNj830:f1Y0<0^hnX00@0d::X0<f[]`3[cKH0n>fM1_ooool00`0B
=;80@4ji065J/`0207eY/P<0U7N_0P2WPZ`00`2eRjX0`IR^0<6H[P020<fPZP80h;N^00D0g>=eoooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
ooooo`<0<c<c00<0000004a<C01<C4`0101<C4`00ol00000000006IVIP0A06IVIP<000001@1<C4`0
0`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATIC`00000901TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`3o`000080IVIV1?l0000604a<C003o`00000c<c?o
oooo00?ooooo00<00000ooooooooool07_ooool2o`0002Gooooo00@0D6?705]S`@1KHl40N72m0P23
LkT0102>MkH0V7bc09Ql/`2HO;<20:21/@80YhJa102`S;020;JA/0<0_iZa0`39Xk<00`3?Zk@0d:ff
0=Bb]`020=Bb]`<0cjni0`2kV[H0102cSk40Yh6[0:QoY`2XOjL30:^1YP030:n4Y`2`PZ<0/8:S00<0
]XRU0`30TZH0203;VjD0bj2/0=V_[@3I[jd0k<N]0?_TY`3Ukm@0/]Q[0_ooool0100007/072ZS01`Z
X`1YEJP207mPY080TV^R0`2OLj430:QkXP040:f1Y02iRJ<0^HVS0;^?Z080d::X00<0k<2U0>_=]P3h
kId01_ooool00`000YD0@4ji041>^@0207eY/P<0U7N_0P2WPZ`01@2eRjX0`IR^0<6H[P31V:h0cJ2Z
0080h;N^00<0g>=eooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00_ooooo0009ooooo`0400000?ooooooooooooooo`<0<c<c00?o000004a<C01<C4`00`1<C4`20000
00P0IVIV1000000:06IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0601TI6Dd000002`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<
00L0C4a<0_l0000804a<C0;o00000P0c<c<4ooooo`0300000?oooooooooo023ooooo00?o0000oooo
ooooool08_ooool0100^Cl<0D6?705]S`@1[Ik`208=c^@80SWNf0P2HO;<20:21/@030:N6/@2YQk00
ZHN`00<0/8b`00<0]Y6`0;^E/02kUK000P2oV[401@36Wk40bJ>c0<n[]03?Zk@0e[>f00<0e;:g00@0
ekNi0<n_^@37Z;X0ajRj0P2kV[H20:N1Z`<0Z7nW0P2[PJH30;22X`80]XRU0P2lRj801@30TZH0bi^U
0<^KY@3;X:`0fJn]0080k<N]00<0nnBW0>O]R_ooool00oooool01@0007/072ZS06UEZ01YEJP0Of2T
0080TV^R0`2OLj430:QkXP040:f1Y02iRJ<0^HVS0;^?Z080d::X00<0k<2U0?gPROooool01oooool0
1@000YD0@4ji06mY^`1_JK/0OFVb0080U7N_00<0Yh:/0:n>/`31V:h00`31V:h20>2g[P030?SLZooo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool0
1000003oooooooooooooool203<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH01@1V
IVH3000000@0Ogmo1000000706IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c
<c<00`0000006ATI01TI6@0601TI6D/000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00l0C4a<0_l0000403<c<`Cooooo00<00000ooooooooool08Oooool00ol0003ooooooooo
o`0Rooooo`0302i?``1KHl40Ff?10080NVfh0P2>MkH209Ql/`030:21/@2QPK40ZHN`0080ZHN`0`2`
S;030;^E/0040;nJ/@36Wk40aYna0<VS/`80cj^d0P3F/kH00`3D/[L0ekNi0=Ng^@030<NX^P040;^J
]P2/R[80Yh6[0:N1Z`<0Z7nW0P2[PJH40;22X`040;J8Y@2lRj80_8^R0<2BYP80bi^U0P3I[jd00`3/
ajd0nnBW0?_TY`05ooooo`050=AY000L:Z<0ASjT06UEZ01oH:@00`2BJj8209mcX@<0Z7^R0`2iRJ<0
1@2kSjP0d::X0=2RZ03/`:D0oN2900Wooooo00H0@4ji06mY^`1_JK/0KfVk09Ag[`2DO[T30:n>/`<0
`IR^00<0e;:g0>2g[P3LhgD01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo0009ooooo`0600000?ooooooooooooooo`0c<c<000001@1<C4`00ol00000IVIV06IVIP0306IV
IP<000002`1oOgl3000000D0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c
<`030000000I6AT06ATI00H06ATIB@0000000ol000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`03`1<C4`00ol00000<c<c03<c<`0403<c<`05o`000?oooooooooo
ooooo`0000009?ooool00ol0003oooooooooo`0Qooooo`0502i?``0oDkl0?e>o06]W_01jKKP00P29
M;D209Ik/`80XH6a102YQk000`2`S;00]92`0;^E/0020;^E/0<0aYna0P3?Zk@30=Jc]P<0ekNi00<0
eKVm0<NX^P2hW;/00`2/R[820:N1Z`80Z7nW00<0Zh6V0:YlXP2ZO:800`2`PZ<0102fR:D0_8^R0;b;
XP30TZH20<^KY@050=b[Y03I[jd0k<N]0?_TY`3WkHX01_ooool00`0007/0ASjT06UEZ00207mPY080
TV^R0P2OLj430:QkXP<0^HVS0P3@XZP20>c0Y@0300000?oooooooooo00Sooooo00<0@4ji06mY^`1_
JK/00P2DO[T30:n>/`80`IR^0P3D/[L00`3biKkoooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool000Wooooo00D00000oooooooooooooooo0000000504a<C003
0000001VIVH0IVIV0080IVIV0P00000A07moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`00P1<C4`2000000@0<c<c00?o000001TI6@0I6AT01P0I6AU9000000T06ATI0P00000803<c<`03
0000001<C4`0C4a<00l0C4a<00?o000003<c<`0c<c<0100c<c<01Ol0003oooooooooooooool00000
02Gooooo00?o0000ooooooooool08?ooool01@00<[L0;To303mC_`1GG;`0NVfh0080RGBe0P2FNk<3
0:61/@80ZHN`00@0[HZa0;B@/02dT;00]92`0P2kUK001@31Vk40aYna0<JO/@3=Z;<0cj^d00<0e[>f
00@0gKfi0=Ng^@3E^Kd0eKVm0P2hW;/30:b:/P80Yh6[0P2XOjL30:YlXP<0/8:S0`2lRj830<^KY@04
0=b[Y03ba:40k<N]0?_TY`Sooooo00@072ZS04HnY01oH:@0Of2T0P2BJj8309mcX@030:QkXP2bPZ40
^HVS0080^HVS0P3@XZP00`3/`:D0oN29ooooo`0:ooooo`03000/]@1_JK/0KfVk00<0U7ji0`2_S[<0
1031V:h0e;:g0=Bb]`3biKh9ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool000Wooooo00D00000ooooooooooooooooo`00000404a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl01P1oOgl4o`0000P0Ogmo0P00000406IVIP030000001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0501TI6DP00000200I6AT2000000X0<c<c00<0
000004a<C01<C4`03P1<C4`00ol00000<c<c03<c<`0503<c<`05o`000?ooooooooooooooo`000000
9_ooool2o`00027ooooo00D003:g03mC_`1GG;`0Eebl07Y]^00208Ud]@80UW^c0P2QPK400`2YQk00
[HZa0:f:/@030;B@/0040;^E/031Vk40`I^a0<JO/@80cJRc0`3F/kH20=fm^@<0eKVm00<0cKK40;RL
^`2hW;/00P2/R[820:N1Z`030:QoY`2SN:@0ZWbR0080ZWbR0`2`PZ<30;b;XP80bi^U0P3LZj@00`3b
a:40o]n=0<k@E008ooooo`0401`ZX`16?Z@0Of2T07mPY080TV^R0`2OLj40102XNj80/X:Q0;:2X@2i
RJ<20<bJX`030=2RZ03/`:D0oN2900cooooo0P14I]000`1_JK/0U7ji09An^@020:n>/`030;jYa03D
/[L0e;:g0080l^Fn2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009
ooooo`0400000?ooooooooooooooo`@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07mo
O`0407moO`?o0000102IVIT4o`0000H0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6AU6000000P06ATI00<0
000003<c<`0c<c<02@0c<c<00`000000C4a<04a<C00>04a<C003o`00000c<c<0<c<c00D0<c<c00?o
0000ooooooooool00_ooool00`00003oooooooooo`0Vooooo`03o`000?oooooooooo01oooooo00@0
4S^i03mC_`1GG;`0KfNj0P29M;D209Ik/`030:61/@2RPk80[HZa00<0[HZa0P2dT;030<6K/@<0cJRc
0`3F/kH20=fm^@040>77_P3E^Kd0cKK40<ffa080^9bk00@0[8Zb09Qi[`2LMZL0W7JW0P2SN:@30:Yl
XP80/8:S00H0]HFQ0;b;XP2lRj80_8^R0<NDX@3;VjD20=b[Y0030?;4X@3nghgooooo00Sooooo00@0
001f04HnY01`EjD0Of2T0`2BJj8209mcX@<0/X:Q00<0^HVS0<bJX`3<VZ<00P3/`:D00`00003ooooo
ooooo`0;ooooo`80A6K@0P2DO[T01P2_S[<0_ZW40;jYa02nZL@0e;:g0?;U_P_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool304a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl3o`0000/0VIVI0_l0000507mo
O`03o`00001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c
<`030000000I6AT06ATI00D06ATIA00000000ol000006ATI01TI6@0601TI6@03o`00000c<c<0<c<c
00H0<c<c00Co00000000000000000000401<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AWo
oooo00?ooooo00<00000ooooooooool09oooool00ol0003oooooooooo`0Oooooo`03018k^@1GG;`0
Eebl0080Pg:g0P2DNk@30::3/P<0[HZa0P2dT;030<6K/@030<VT/`3=Z;<0e[>f0080e[>f0P3M_KT2
0>77_P030>7Ab03=]/@0]Zg@0080WXVl0P2HNJl209afY`80XgRT102ZO:80102`PZ<0]HFQ0;F5X@2l
Rj820<NDX@050<^KY@3LZj@0l/BQ0?;4X@3>d5@02_ooool00`16?Z@0L5NU071GY@03099[XP0309mc
X@2TN:80/X:Q0080/X:Q00D0^HVS0<bJX`3<VZ<0j[ZR0?gPR@0?ooooo`0306L0002ATm40TI?A00<0
_ZW400<0eNoT0?;U__ooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[o
oooo0009ooooo`0400000?ooooooooooooooo`<0C4a<00<0000006IVIP1VIVH00P1VIVH01@000000
Ogmo07moO`1oOgoo00000100VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI
6D<000002@0I6AT00`000000<c<c03<c<`0503<c<`800000501<C4`00ol00000<c<c03<c<`0503<c
<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0Noooo
o`04018k^@0fCK`0=Tfl06mW^P80Pg:g0P2DNk@20::3/P<0[HZa00@0]92`0;ZF/P2jU[80`I^a0P39
Y;<01P3=Z;<0e[>f0=Jc]P3F/kH0gl6j0=fm^@80hLNn00<0hM780;J]d02f[M000P2NRK`209Qi[`80
W7JW0`2SN:@30:YlXP040;22X`2eQJ40]HFQ0;b;XP80aiBQ0P3LZj@00`3ba:40o]n=0<k@E00:oooo
o`030008TP1`EjD0L5NU00<0T6ZS0P2TN:830;:2X@<0c9ZS00<0j[ZR0?[MO?ooool04?ooool2096C
d@030;jYa03Ekn@0eNoT00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`002Oooool01000003oooooooooooooool204a<C0030000001VIVH0IVIV0080IVIV00D0000007mo
O`1oOgl0Ogmoo`00000B09VIV@05o`00001oOgl0Ogmo07moO`0000001@1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AU1000000P06ATI0P00
000503<c<`<000005P1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AWooooo00?ooooo00<0
0000ooooooooool0:Oooool2o`0001oooooo00<04S^i03I=_01LH;h00P23L[L209Ak]0<0XX>b00<0
[HZa0;6@/`2jU[800P2jU[800`31Vk40bJBc0<VT/`030=Jc]P80gl6j00<0j=:o0>77_P3QdLP00P3G
g]d20;J]d080WXVl0P2HNJl209afY`80XgRT0`2ZO:830;F5X@030;b;XP37U:40aiBQ0080g:^T00<0
l/BQ0?kOSOooool02_ooool00`0007H0ASjT071GY@03091ZX`80Y7RR0`2bPZ430<bJX`030>ZjXP3j
gGcooooo017ooooo0P1D_oX00`3EknCoooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo0P1<C4`01@000000IVIV06IV
IP1VIVH0000000<0Ogmo00?o000009VIV@2IVIT0102IVIT8o`0000H0VIVI00Go000007moO`1oOgl0
Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00`000000
6ATI01TI6@0601TI6Ch0000000?o000001TI6@0I6AT01P0I6AT00`000000<c<c03<c<`0403<c<`03
0000001<C4`0C4a<00D0C4a<2P00000904a<C003o`00000c<c<0<c<c00<0<c<c00?o000001TI6@0I
6AT01?ooool00`00003oooooooooo`0[ooooo`03o`000?oooooooooo01cooooo00@001>S03I=_01L
H;h0G62n0P23L[L209Ak]0030::3/P2UR;H0/I2c0080/I2c0P2jU[830<VT/`030=>a]`3F/kH0gl6j
0080gl6j00D0j=:o0>gVa`3Ro<l0emkM09OSo@0207>BhP80WXVl0P2HNJl209afY`80XgRT0P2ZO:80
102/OJ40]HFQ0;F5X@2eQJ430<NDX@040=VVX@3LZj@0l/BQ0<k@E0cooooo00<0ASjT071GY@1`EjD0
0P2@JZ<30:AhXP80/X:Q0P3<VZ<20>ZjXROooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`002Oooool01P00003oooooooooooooool0C4a<000000<0IVIV00<0000007moO`1o
Ogl00P1oOgl00ol00000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00H0/k>c0_l0000509VIV@05
o`00001oOgl0Ogmo07moO`000000101VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00<00000
01TI6@0I6AT01@0I6AT00ol0000000000000000l000000L06ATI00<0000003<c<`0c<c<00`0c<c<0
0`00003o000004a<C00304a<C0@000002P1VIVH3000000H0C4a<00?o000003<c<`0c<c<00`0c<c<0
0ol000006ATI01TI6@04ooooo`0300000?oooooooooo02cooooo00?o0000ooooooooool07?ooool0
0`00<KH0=Tfl05aP_P0207]a_080Tgji0P2UR;H30;6@/`040;ZF/P32X;D0`Z2e0<VT/`80dk6g0P3O
a;d01@3O`KX0j=:o0>SB_`3]i/L0T>Zg00?ooooo00<0Li;R06i[_P1^Jkh00P2HNJl209afY`80XgRT
00<0ZWbR0:amX@2/OJ400`2eQJ430<NDX@030=VVX@3ba:40o]n=00gooooo00<000RB071GY@1`EjD0
0P2@JZ<30:AhXP060;:2X@32TJ<0`Y6S0<bJX`3Z^Z80n]el:?ooool01Ol0003ooooooooooooooooo
000000_ooooo0009ooooo`0600000?ooooooooooooooo`1<C4`000000`1VIVH00`000000Ogmo07mo
O`0207moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<02@2c/k<00ol00000VIVI09VI
V@0209VIV@05o`00001oOgl0Ogmo07moO`000000101VIVH01Ol00000C4a<04a<C01<C4`0000000D0
<c<c00<0000001TI6@0I6AT01@0I6ATn000000L06ATI00?o000003<c<`0c<c<00`0c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV00l0IVIV00<0000004a<C01<C4`00`1<C4`00ol00000
<c<c03<c<`0303<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0;Oooool00ol0003o
ooooooooo`0Looooo`04000a]P1LH;h0G62n07]a_080Tgji0`2UR;H20;6@/`<0`Z2e0`3C/KL20=o4
_@030>_L``3Xd[l0kNK700Kooooo00@0Li;R06i[_P1lIJh0O6F^0P2LMZL00`2SN:@0WgFS0:amX@03
0:amX@80]HFQ0P37U:420=VVX@030?C5W@3fgGKooooo00cooooo00<000RB071GY@1`EjD00`2@JZ<2
0:AhXP060;:2X@32TJ<0`Y6S0<bJX`3Z^Z80n]el:Oooool01?l0003oooooooooool0000;ooooo`00
2Oooool01@00003oooooooooooooool0000000<0IVIV00<0000007moO`1oOgl00P1oOgl00ol00000
VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00/0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol00000
Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c
<`03o`00000I6AT06ATI00D06ATI?000000701TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00P1<C4`2000000P0IVIV1?l0000706IVIP800000101<C4`00ol00000<c<c03<c<`0303<c
<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0;_ooool2o`0001cooooo00<0002;03MD
a00gE<@00P1kLK`209=n^@80YHRf00<0/I2c0;RJ^@2hV[T00P32X;D0103=[k/0dk6g0=o4_@3Oa;d2
0>_L``030>kea?oooooooooo00Gooooo00@000F:06i[_P1lIJh0O6F^0P2?K:H209meX`@0[7fQ00@0
]HFQ0;n=X@2oSJ40aiBQ0P3IYZ400`3daId0m]efooooo`0=ooooo`0304Y4Z01`EjD0T6ZS0080T6ZS
0P2TN:800`2bPZ40`Y6S0<:AX`020>ZjXR_ooooo00?o0000ooooool000002oooool000Wooooo00D0
0000oooooooooooooooo0000000306IVIP050000001oOgl0Ogmo07moOol00000102IVIT00ol00000
/k>c0;>c/`0=0;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmo0000000306IV
IP050000001<C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0601TI6CT0000000?o0000
01TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0303<c<`040000001<C4`0C4a<04a<C08000001@1V
IVH5o`0000@0Ogmo1?l0000506IVIP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00`0c
<c<00ol0003oooooooooo`02ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool06_oo
ool0100008/0=eC406aaaP1/LLH209=n^@030:F8]P2YT[d0^9Zi0080^9Zi00D0`Z2e0<f_^`3=[k/0
g<K40=o4_@030>_L``Wooooo0P1^Jkh00`1lIJh0SfbV08m/YP0309meX`<0[7fQ00@0]HFQ0;n=X@2o
SJ40aiBQ0P3IYZ400`3daIgoooooooooo`0=ooooo`030008TP1:A:P0L5NU0080T6ZS0P2TN:830<:A
X`030>>eY`3jgGcooooo02[ooooo00?o0000ooooool000002oooool000Wooooo00D00000oooooooo
oooooooo0000000306IVIP050000001oOgl0Ogmo07moOol00000102IVIT00ol00000/k>c0;>c/`0=
0;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmo0000000306IVIP050000001<
C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0601TI6CX000001`0I6AT00`000000<c<c
03<c<`0303<c<`040000001<C4`0C4a<000000D0IVIV0_l0000=07moO`;o0000101VIVH01@000000
C4a<04a<C01<C4co000000D0<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo01[ooooo00<003Jl03MDa01/LLH00P2AQL<30:VB_@80^9Zi0`3=[k/0103L
a/@0j^O<0>[Wc03[g<<:ooooo`030005RP1^Jkh0O6F^00<0SfbV0P2OMJ<30:amX@030;F5X@2oSJ40
_hfQ0080fJJQ00<0m<FM0?KMM_ooool03oooool204Y4Z080T6ZS0P2TN:830<:AX`030>>eY`3YgVko
oooo02_ooooo00?o0000ooooool000002_ooool000Wooooo00D00000oooooooooooooooo00000003
06IVIP050000001oOgl0Ogmo07moOol000000`2IVIT00ol00000/k>c0;>c/`0>0;>c/`03o`00002I
VIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmo0000000306IVIP030000001<C4`0C4a<0080C4a<
00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6CL00000200I6AT00`000000<c<c
03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1VIVH2o`0000@0Ogmo1ol0000607moO`03
o`00001VIVH0IVIV0080IVIV00D0000004a<C01<C4`0C4a<o`00000503<c<`05o`000?oooooooooo
ooooo`000000=?ooool00ol0003oooooooooo`0Jooooo`03000f_01/LLH0K7760080THG30P2YT[d0
102hV[T0`j_20<>[`P3=[k/20=c6a080j^O<00<0gOjnooooooooool02Oooool00`005j@0O6F^07aU
[P0208m/YP80WgFS0`2/OJ430;n=X@80fJJQ00<0m<FM0?KMM_ooool03oooool204Y4Z080S6j[00@0
Y7RR0;24Y`32TJ<0`Y6S0P3S]JL^ooooo`;o00002_ooool000Wooooo00@00000oooooooooooooooo
0`1VIVH01@000000Ogmo07moO`1oOgoo000000@0VIVI00?o00000;>c/`2c/k<01@2c/k<2o`0000P0
/k>c00Go000009VIV@2IVIT0VIVIo`00000407moO`050000001VIVH0IVIV06IVIP0000000`1<C4`0
0`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00L06ATI=@00000901TI6@030000000c<c<0
<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP03o`00001oOgl0Ogmo0080Ogmo0_l0
000709VIV@?o0000101oOgl00ol00000IVIV06IVIP0206IVIP050000001<C4`0C4a<04a<C?l00000
100c<c<01Ol0003oooooooooooooool0000003Gooooo0_l0000Kooooo`80B7;H0P2AQL<00`2YT[d0
/:C<0<>[`P020<>[`P050=;9d@3La/@0j^O<0>[Wc03Mo[h03?ooool00`005j@0O6F^07aU[P0208m/
YP80WgFS0`2/OJ430;n=X@80fJJQ00<0m<FMooooooooool04?ooool00`1:A:P0S6j[08a^Z`030;24
Y`030<:AX`3S]JL0hkFW02gooooo0ol0000:ooooo`002Oooool01000003oooooooooooooool306IV
IP050000001oOgl0Ogmo07moOol000000`2IVIT00ol00000/k>c0;>c/`060;>c/`03o`00003<c<co
000000L0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgl0000000<0IVIV00<0
000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`03o`0000000000000000L06ATI<`00
000901TI6@060000000c<c<0<c<c03<c<`00003o00000`1<C4`00ol00000IVIV06IVIP02o`0000<0
Ogmo0_l0000<09VIV@;o00000`1oOgl2o`0000<0IVIV00D0000004a<C01<C4`0C4a<o`00000303<c
<`Cooooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0Iooooo`0304Qbf02<UML0S9GG
00<0/:C<00<0`j_20=;9d@3BbM400P3LmMd?ooooo`04000GY01lIJh0SfbV08m/YP<0WgFS00<0[7fQ
0;>4X`2oSJ400P2oSJ400`3CXJ<0fJJQ0?C5W@0Booooo`0304Y4Z02<KZ/0S6j[00<0/8BW00<0`Y6S
0>>eY`3S]JL0:Oooool4o`0000gooooo0009ooooo`0400000?ooooooooooooooo`<0IVIV00D00000
07moO`1oOgl0Ogmoo`00000309VIV@03o`00002c/k<0/k>c00H0/k>c00?o00000<c<c?l000001`2c
/k<00ol00000VIVI09VIV@0209VIV@05o`00001oOgl0Ogmo07moO`0000000`1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01P0I6AT_000000X06ATI
00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00?o000007moO`1o
Ogl00P1oOgl00ol00000VIVI09VIV@0209VIV@Wo00000`2IVIT00ol00000Ogmo07moO`0207moO`04
o`00001VIVH0IVIV000000<0C4a<00Co000003<c<`0c<c<0<c<c1?ooool00`00003oooooooooo`0f
ooooo`03o`000?oooooooooo01Wooooo00@005K808bEe`2<UML0/:C<0P2jbNH00`3BbM40g?GM0=ce
g@0Aooooo`0403i1[02?K:H0SfbV08m/YP80WgFS00@0[7fQ0;>4X`2cQ:<0_hfQ0P3CXJ<00`3daId0
m]efooooo`0Booooo`0304Y4Z02<KZ/0/8BW0080/8BW0P3S]JLWooooo`?o00004Oooool000Wooooo
00@00000oooooooooooooooo0`1VIVH01@000000Ogmo07moO`1oOgoo000000<0VIVI00?o00000;>c
/`2c/k<01P2c/k<2o`0000P0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgl0
000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT0
6ATI00L06ATI:@00000=01TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000
000306IVIP03o`00001oOgl0Ogmo00;o00000`2IVIT2o`0000T0/k>c0_l0000209VIV@03o`00001o
Ogl0Ogmo0080Ogmo00Co000006IVIP1VIVH000000`1<C4`00ol00000<c<c03<c<`04ooooo`030000
0?oooooooooo03Oooooo00?o0000ooooooooool06_ooool207:cn@030;[9iP2Olnh0Wo?^01Cooooo
0`1lHZX00`2OMJ<0WgNV0;>4X`020;>4X`040;n=X@3CXJ<0dj6S0?G9XACooooo00<0BTBX08a^Z`2<
KZ/00P2`Q:L00`3?[[P0hkFWooooo`0Rooooo`Co00005?ooool000Wooooo00@00000oooooooooooo
oooo0`1VIVH01@000000Ogmo07moO`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<01P2c/k<00ol0
0000/k>c0;>c/`070;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmo00000004
06IVIP030000001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<2000000P06ATI8@00000C
01TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP04o`00001o
Ogl0Ogmoo`0000<0VIVI0_l0000=0;>c/`03o`00002IVIT0VIVI00;o00000P1oOgl01Ol00000IVIV
06IVIP1VIVKo00000080C4a<00?o000003<c<`0c<c<01?ooool00`00003oooooooooo`0hooooo`;o
00007_ooool00ol0003oooooooooo`0Booooo`0303i1[01lHZX0O6:Z0080WgNV0`2cQ:<0102oSJ40
dj6S0=>QX`3ebJ4Eooooo`80S6j[0P2`Q:L20<n^^1oooooo1?l0000Hooooo`002Oooool01000003o
ooooooooooooool306IVIP050000001oOgl0Ogmo07moOol000000`2IVIT00ol00000/k>c0;>c/`0@
0;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmo0000000406IVIP030000001<
C4`0C4a<00D0C4a<0`00000603<c<`030000000I6AT06ATI00L06ATI6@00000H01TI6@030000000c
<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP04o`00001oOgl0Ogmoo`000080
VIVI00?o00000;>c/`2c/k<00P2c/k<7o`0000@0/k>c00Go000009VIV@2IVIT0VIVIo`00000207mo
O`05o`00001VIVH0IVIV06IVIP0000000P1<C4`00ol00000<c<c03<c<`04ooooo`0300000?oooooo
oooo03[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`80O6:Z0P2OMjH3
0;>4X`<0dj6S00<0mLVQooooooooool04oooool207R3dP040;24Y`3?[[P0cjjh0<n^^1_ooooo1?l0
000Looooo`002Oooool01@00003oooooooooooooool000000080IVIV00D0000007moO`1oOgl0Ogmo
o`00000409VIV@03o`00002c/k<0/k>c00l0/k>c00Go000009VIV@2IVIT0VIVIo`00000407moO`03
0000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01`1<C4`2000000D0<c<c0`00000701TI6AH0
00006@0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01?l0
0000Ogmo07moOol0000209VIV@04o`00002c/k<0/k>c0;>c/`;o00001`3<c<`2o`0000<0/k>c00Go
000009VIV@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIV000000<0C4a<00?o000003<c<ooo
ool00oooool00`00003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04oooool207aRZP<0WgNV0P2cQ:<20=>QX`030?G9XOoooooooooo01Gooooo00@0N8?B0<n^^03?
[[P0cjjh6Oooool3o`00023ooooo0009ooooo`0500000?ooooooooooooooo`0000000`1VIVH01@00
0000Ogmo07moO`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<03P2c/k<00ol00000VIVI09VIV@02
09VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C008
04a<C08000001P0c<c<00`00003o000001TI6@0501TI6A40000000?o00000000000I6AT02P0I6AT7
000000P06ATI00<0000003<c<`0c<c<0100c<c<01Ol00000C4a<04a<C01<C4`000000080IVIV00Co
000007moO`1oOgoo00000`2IVIT01?l00000/k>c0;>c/ol0000;0<c<c0;o00000P2c/k<01?l00000
VIVI09VIVOl0000207moO`05o`00001VIVH0IVIV06IVIP0000000P1<C4`00ol00000<c<cooooo`03
ooooo`0300000?oooooooooo03cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0C
ooooo`0303i1[01lHZX0O6:Z0080WgNV0P2cQ:<20=>QX`030?G9XOoooooooooo01Oooooo00<0cjjh
ooooooooool05?ooool4o`0002?ooooo0009ooooo`0500000?ooooooooooooooo`0000000`1VIVH0
1@000000Ogmo07moO`1oOgoo000000@0VIVI0_l0000=0;>c/`;o0000102IVIT00ol00000Ogmo07mo
O`0207moO`030000001VIVH0IVIV00D0IVIV00@00000o`00000000000000201<C4`3000000@0<c<c
0P00000501TI6@03o`0000000000000000h000002@0I6AT4000000L0<c<c00?o0000000000000000
100000000ol00000<c<c03<c<`0403<c<`050000001<C4`0C4a<04a<C00000000P1VIVH01Ol00000
Ogmo07moO`1oOgoo00000080VIVI00Co00000;>c/`2c/k?o0000103<c<`6o`0000@0c<c<00Co0000
0;>c/`2c/k?o00000P2IVIT2o`00000507moOol00000IVIV06IVIP0000000`1<C4`00ol0003ooooo
ooooo`02ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oooooooooo01Cooooo
0P1lHZX209mgYP050;>4X`35V:T0aIRY0=>QX`3ebJ40;?ooool4o`0002Oooooo0009ooooo`050000
0?ooooooooooooooo`0000000`1VIVH01@000000Ogmo07moO`1oOgoo000000H0VIVI00?o00000;>c
/`2c/k<0202c/k<2o`0000H0VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0906IV
IPL00000101<C4`2000000@0<c<c00<0000001TI6@0I6AT0100I6AT=000000L06ATI1000000I03<c
<`050000001<C4`0C4a<04a<C00000000P1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Co
00000;>c/`2c/k?o00000`3<c<`00ol00000i^KV0>KViP040>KViP05o`00003<c<`0c<c<0<c<c?l0
00000P2c/k<01ol00000VIVI09VIV@2IVIWo000007moOol000000P1VIVH01@000000C4a<04a<C01<
C4co000000Cooooo00<00000ooooooooool0?oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Cooooo00D0<TFf07aRZP2OMjH0WgNV0;>4X`020<FHZ@030?G9XOoooooooooo02Oooooo
1?l0000[ooooo`002Oooool01P00003oooooooooooooool0C4a<000000<0IVIV00D0000007moO`1o
Ogl0Ogmoo`00000609VIV@03o`00002c/k<0/k>c00H0/k>c00?o000009VIV@2IVIT01@2IVIT00ol0
0000Ogmo07moO`0307moO`030000001VIVH0IVIV0100IVIV1000000204a<C08000000`0c<c<00ol0
00006ATI01TI6@0401TI6@/000001P0I6AT2000000L0<c<c2000000=03<c<`050000001<C4`0C4a<
04a<C00000000P1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Co00000;>c/`2c/k?o0000
0`3<c<`00ol00000i^KV0>KViP060>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01ol00000
VIVI09VIV@2IVIWo000007moOol000000P1VIVH01@000000C4a<04a<C01<C4co000000?ooooo00<0
0000ooooooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00@0
001@0395]P2OMjH0XXFd0`35V:T00`3cfKCoooooooooo`0Tooooo`?o0000;oooool000Wooooo00H0
0000oooooooooooooooo04a<C000000406IVIP040000001oOgl0Ogmo07moO`;o00001@2IVIT3o`00
0080/k>c0ol0000709VIV@03o`00001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0501VIVH20000
0080C4a<00@0000003<c<`0c<c<0<c<c0P00000501TI6@03o`0000000000000000@0000000?o0000
01TI6@0I6AT01@0I6AT00ol00000<c<c03<c<`0303<c<`04o`00000000000000000000P0C4a<1000
000803<c<`03o`00001<C4`0C4a<0080C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l00000VIVI
09VIVOl000020;>c/`05o`00003<c<`0c<c<0<c<c?l000002P3Vi^H01Ol00000c<c<0<c<c03<c<co
00000080/k>c00Ko000009VIV@2IVIWo000007moOol0000206IVIP050000001<C4`0C4a<04a<C?l0
00000oooool00`00003oooooooooo`11ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05_ooool00`0bAKH0XXFd0::5]0030<FHZ@030??I]?oooooooooo023ooooo1?l0000booooo`00
2Oooool01P00003oooooooooooooool0C4a<000000@0IVIV00<0000007moO`1oOgl00`1oOgl00ol0
0000VIVI09VIV@0509VIV@;o00002P2IVIT00ol00000Ogmo07moO`0407moO`030000001VIVH0IVIV
00D0IVIV3`00000206IVIP80000000<0C4a<0000000c<c<00`0c<c<00`0000006ATI01TI6@0501TI
6@@000001`0I6AT010000000<c<c03<c<`0c<c<3000000@0C4a<1@00000704a<C0<000000`0c<c<2
000000D0C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l00000VIVI09VIVOl000020;>c/`04o`00
003<c<`0c<c<o`0000/0i^KV00Go00000<c<c03<c<`0c<c<o`0000020;>c/`06o`00002IVIT0VIVI
o`00001oOgoo00000P1VIVH01@000000C4a<04a<C01<C4co000000?ooooo00<00000ooooooooool0
@_ooool2o`0001?ooooo00?o0000ooooooooool05_ooool01P0bAKH0XXFd0::5]02RQK@0aIRY0??I
]1oooooo1?l0000fooooo`002Oooool01000003oooooooooooooool204a<C0030000001VIVH0IVIV
0080IVIV00<0000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0>09VIV@;o00001`1oOgl00`00
0000IVIV06IVIP0206IVIP<000003`1oOgl01`000000IVIV06IVIP1VIVH0000004a<C0000000100c
<c<00`0000006ATI01TI6@0>01TI6@030000000c<c<0<c<c00800000101<C4`3000000D0IVIV0`00
000704a<C0<000001`1<C4`010000000IVIV06IVI_l0000207moO`04o`00002IVIT0VIVIo`000080
/k>c00Co00000<c<c03<c<co0000303Vi^H01?l00000c<c<0<c<c?l000020;>c/`06o`00002IVIT0
VIVIo`00001oOgoo00000P1VIVH01@000000C4a<04a<C01<C4co000000?ooooo00<00000oooooooo
ool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00D0<TFf0::5]02R
QK@0aIRY0??I]00Kooooo`Co0000>_ooool000Wooooo00@00000oooooooooooooooo0`1<C4`01Ol0
0000IVIV06IVIP1VIVH0000000H0Ogmo00?o000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`06
07moO`040000001VIVH0IVIV06IVIP8000001`1oOgl9o`0000<0Ogmo00@0000006IVIP1VIVH00000
0P1<C4`01Ol00000<c<c03<c<`0c<c<0000000l06ATI00D0000003<c<`0c<c<0<c<c0000000204a<
C0<00000101VIVH3o`0000@0IVIV0`00000=04a<C0070000001VIVH0IVIV06IVI_l00000Ogmoo`00
000209VIV@04o`00002c/k<0/k>co`0000<0c<c<00?o00000>KViP3Vi^H02P3Vi^H01Ol00000c<c<
0<c<c03<c<co00000080/k>c00?o000009VIVOl000000P1oOgl01?l00000IVIV06IVIP00000204a<
C005o`000?ooooooooooooooo`000000Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Sooooo0P2RQK@00`35V:T0lmVdooooo`0Fooooo`Co0000?_ooool000Wooooo00@00000oooo
oooooooooooo0`1<C4`00`000000IVIV06IVIP0206IVIP800000101oOgl6o`0000H0VIVI0ol00007
07moO`H000001P1oOgl3o`0000<0VIVI1?l0000209VIV@Co00000P0000001@1VIVH0000004a<C01<
C4`000000080<c<c00<0000001TI6@0I6AT02`0I6AT200000080<c<c0P0000000`1<C4`000000000
000306IVIPCo00000`1oOgl4o`0000<0IVIV00<00000o`00000000002P1<C4`01`000000IVIV06IV
IP1VIVKo000007moOol000000P2IVIT01?l00000/k>c0;>c/ol000030<c<c003o`00003Vi^H0i^KV
00/0i^KV00Co00000<c<c03<c<co00000P2c/k<00ol00000VIVIo`00000207moO`04o`00001VIVH0
IVIV00000080C4a<00Go0000oooooooooooooooo00000018ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0<?ooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooo`@0C4a<
00<0000006IVIP1VIVH00`1VIVH2000000P0Ogmo1_l0000707moO`<000000P1VIVH00`000000Ogmo
07moO`0607moO`04o`00002IVIT0VIVI09VIV@?o0000102c/k<4o`000080VIVI00Go000007moO`00
0000IVIV0000000204a<C0040000000c<c<0<c<c000000/06ATI00D0000003<c<`0c<c<0<c<c0000
000204a<C0030000001VIVH0IVIV00_o00000`1oOgl3o`0000<0IVIV0P00000804a<C0070000001V
IVH0IVIV06IVI_l00000Ogmoo`00000209VIV@04o`00002c/k<0/k>co`0000<0c<c<00?o00000>KV
iP3Vi^H02`3Vi^H01?l00000c<c<0<c<c?l000020;>c/`03o`00002IVIWo00000080Ogmo00Co0000
06IVIP1VIVH000000P1<C4`01Ol0003oooooooooooooool0000004Wooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wooooo00D00000oooooooooooooooo
o`00000404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl04@1oOgl00`000000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00Go000009VIV@2IVIT0VIVIo`0000030;>c/`Co
0000102c/k<02?l00000VIVI09VIVOl00000Ogmo0000001VIVH000000P1<C4`010000000<c<c03<c
<`00000:01TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP04o`00001oOgl0Ogmo
o`0000P0VIVI0ol0000307moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0101<C4`0
0`000000IVIV06IVIP0206IVIP04o`00001oOgl0Ogmoo`000080VIVI00Co00000;>c/`2c/k?o0000
0P3<c<`00ol00000i^KV0>KViP0:0>KViP04o`00003<c<`0c<c<o`000080/k>c00Co000009VIV@2I
VIWo00000P1oOgl00ol00000IVIV0000000304a<C005o`000?ooooooooooooooo`000000B_ooool2
o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0600000?oooooooooo
ooooo`0c<c?o0000101<C4`00ol00000000006IVIP0406IVIP0400000?l000000000000000`0Ogmo
0P0000000ol00000IVIV06IVIP0606IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT0
0_l000020;>c/`;o0000103<c<`4o`0000090;>c/ol00000VIVI09VIVOl00000Ogmo0000001VIVKo
00000080C4a<00@0000003<c<`0c<c<00000200I6AT020000000<c<c03<c<`0c<c<0000004a<C000
0000IVIV0_l00000101oOgoo0000o`00002IVIT:o`00000309VIVOl0003o00000080Ogmo00?o0000
06IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00Co0000
07moO`1oOgoo00000P2IVIT01?l00000/k>c0;>c/ol000020<c<c0;o00002`3Vi^H01?l00000c<c<
0<c<c?l000020;>c/`04o`00002IVIT0VIVIo`000080Ogmo00?o000006IVIP0000000`1<C4`01Ol0
003oooooooooooooool0000004cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0T
ooooo`Co0000COooool000Wooooo00H00000oooooooooooooooo03<c<ol0000604a<C0030000001V
IVH0IVIV00H0IVIV0`00000607moO`<000002`1VIVH00`000000Ogmo07moO`0207moO`04o`00002I
VIT0VIVIo`0000<0/k>c00?o00000<c<c?l000001Ol000020<c<c009o`00002c/k?o000009VIVOl0
0000Ogmo0000001VIVH000000080C4a<00@0000003<c<`0c<c<000001`0I6AT01@000000<c<c03<c
<`0c<c<000000080C4a<00D0000006IVI_l00000Ogmoo`00000209VIV@04o`00002c/k<0/k>c0;>c
/`Go00000P2c/k<00ol00000VIVIo`00000207moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<
C01<C4`00`00000406IVIP04o`00001oOgl0Ogmoo`000080VIVI00Co00000;>c/`2c/k?o0000103<
c<`00ol00000i^KV0>KViP070>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01_l00000VIVI
09VIVOl00000Ogmoo`000080IVIV00D0000004a<C01<C4`0C4a<o`000003ooooo`0300000?oooooo
oooo04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`?o0000DOooool0
00Wooooo00@00000oooooooooooooooo0P0c<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0
IVIV00P0IVIV1P00000>06IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIVOl000000`2c/k<0
0ol00000c<c<o`0000060>KViP03o`00003<c<co00000080/k>c00Wo000009VIVOl00000Ogmo0000
001VIVH0000004a<C00000000`0c<c<00`0000006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c
<`0000000P1<C4`01@000000IVIVo`00001oOgoo00000080VIVI00?o00000;>c/`2c/k<00_l00005
0<c<c006o`00002c/k<0/k>co`00002IVIWo00000P1oOgl00ol00000IVIV06IVIP0306IVIP800000
1`1VIVH01?l00000Ogmo07moOol0000209VIV@04o`00002c/k<0/k>co`0000D0c<c<00?o00000>KV
iP3Vi^H01@3Vi^H01Ol00000c<c<0<c<c03<c<co000000<0/k>c00?o000009VIVOl000000P1oOgl0
1?l00000IVIV06IVIP00000304a<C005o`000?ooooooooooooooo`000000C_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0001Dooooo`002Oooool01000003ooooooooo
ooooool303<c<`03o`00001<C4`0C4a<00@0C4a<0P00000M06IVIP040000001oOgl0Ogmoo`000080
VIVI00Ko00000;>c/`2c/k?o00000<c<c?l000080>KViP03o`00003<c<co00000080/k>c0_l00000
101oOgl0000006IVIP00000204a<C0050000000c<c<0<c<c03<c<`0000000`0I6AT01@000000<c<c
03<c<`0c<c?o000000<0C4a<00@0000006IVI_l0003o00000P2IVIT01?l00000/k>c0;>c/ol00003
0<c<c0;o00000`3<c<`01_l00000/k>c0;>c/ol00000VIVIo`000080Ogmo00?o000006IVIP1VIVH0
2`1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Co00000;>c/`2c/k?o00001@3<c<`00ol0
0000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00Co00000;>c/`2c/k?o00000P2IVIT0
1?l00000Ogmo07moOol0000206IVIP040000001<C4`0C4a<o`0000Cooooo00<00000ooooooooool0
COooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`0005Sooooo0009ooooo`0400000?oo
ooooooooooooo`@0<c<c0ol0000504a<C0D00000601VIVH01P000000Ogmo07moOol00000VIVIo`00
0080/k>c00?o00000<c<c?l000000`3Vi^H5o`000080i^KV00go00000<c<c?l00000/k>co`00002I
VIWo000007moO`000000IVIV0000001<C4`0000000@0<c<c0_l000000`000000<c<c03<c<`0203<c
<`0;0000001<C4`0C4a<0000001VIVKo000007moOol00000VIVIo`00002c/k<00_l00000103<c<co
0000o`000?l000020>KViP;o00000P3<c<`01_l00000/k>c0;>c/ol00000VIVIo`000080Ogmo00?o
000006IVIP1VIVH01@1VIVH00`000000IVIV06IVIP0206IVIP05o`00001oOgl0Ogmo07moOol00000
0P2IVIT00ol00000/k>c0;>c/`02o`0000@0c<c<1_l000030<c<c0;o00000P2c/k<2o`000080VIVI
00Co000007moO`1oOgoo00000P1VIVH010000000C4a<04a<C?l00004ooooo`0300000?oooooooooo
04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wo
oooo00@00000oooooooooooooooo1`0c<c<00ol00000C4a<04a<C00704a<C0<000001P1VIVH:0000
00D0IVIV00P0000007moO`1oOgoo000009VIVOl00000/k>co`000080c<c<00Co00000>KViP3Vi^Ko
0000103oool04?l00000i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIVOl00000Ogmo0000001V
IVH0000004a<C000000;03<c<`0>0000001<C4`0C4a<0000001VIVKo000007moOol00000VIVIo`00
002c/k?o00000<c<c?l000070>KViP;o000000H0c<c<o`00002c/k?o000009VIVOl0000307moO`03
o`00001VIVH0IVIV00<0IVIV0P00000506IVIP04o`00001oOgl0Ogmoo`0000<0VIVI00Co00000;>c
/`2c/k<0/k>c0_l0000:0<c<c003o`00002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVIo`00
000207moO`04o`00001VIVH0IVIV00000080C4a<00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo
0009ooooo`0500000?ooooooooooooooool000001`0c<c<00ol00000C4a<04a<C00904a<C0H00000
2P1<C4`00`000000IVIV06IVIP0206IVIP0:0000001oOgl0Ogmoo`00002IVIWo00000;>c/ol00000
c<c<o`000080i^KV00?o00000?ooo`3oool0103oool04?l00000i^KV0>KVi_l00000c<c<o`00002c
/k?o000009VIVOl00000Ogmo0000001VIVH0000004a<C000000903<c<`0>0000001<C4`0C4a<0000
001VIVKo000007moOol00000VIVIo`00002c/k?o00000<c<c?l000030>KViPCo00000`3Vi^H01ol0
0000c<c<o`00002c/k?o000009VIVOl000000P1oOgl00ol00000IVIV06IVIP0206IVIP040000001<
C4`0C4a<000000D0IVIV00Co000007moO`1oOgoo00000`2IVIT00ol00000/k>c0;>c/`020;>c/`;o
00001`3<c<`00ol00000/k>c0;>c/`020;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01?l0
0000IVIV06IVIP00000204a<C003o`00000c<c?ooooo00?ooooo00<00000ooooooooool0DOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`002Oooool01000
003oooooooooooooool2o`0000L0<c<c0ol0000I04a<C005o`00001VIVH0IVIV06IVIP0000000P1o
Ogl02Ol00000VIVIo`00002c/k?o00000<c<c?l00000i^KVo`0000080?ooo`03o`00003Vi^H0i^KV
00;o000000X0/k>co`00002IVIWo000007moO`000000IVIV0000001<C4`000002@0c<c<01`000000
C4a<04a<C0000000IVIVo`00001oOgl00_l00000102c/k?o00000<c<c?l000020>KViP;o0000103o
ool01?l00000i^KV0>KViP3Vi^H2o`0000070;>c/ol00000VIVI09VIVOl00000Ogmoo`00000306IV
IP030000001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00P1VIVH01?l00000Ogmo07moO`1oOgl2
o`000080VIVI00?o00000;>c/`2c/k<00`2c/k<7o`0000@0/k>c00?o000009VIV@2IVIT00_l00002
07moO`04o`00001VIVH0IVIV000000<0C4a<00?o000003<c<oooool00oooool00`00003ooooooooo
o`1Booooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000Ioooool000Wooooo00@00000
oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`0703<c<`;o0000601<C4`010000000IVIV06IV
IP00000207moO`09o`00002IVIWo00000;>c/ol00000c<c<o`00003Vi^Ko000000P0oooo00?o0000
0>KViP3Vi^H00_l000002P2c/k?o000009VIVOl00000Ogmo0000001VIVH0000004a<C000000903<c
<`070000001<C4`0C4a<0000001VIVKo000007moO`02o`0000040;>c/ol00000c<c<o`000080i^KV
00?o00000?ooo`3oool00`3oool01?l00000i^KV0>KViP3Vi^H2o`0000070;>c/ol00000VIVI09VI
VOl00000Ogmoo`00000306IVIP030000001<C4`0C4a<00<0C4a<0P00000306IVIP03o`00001oOgl0
Ogmo0080Ogmo00Co000009VIV@2IVIWo00003@2c/k<2o`000080VIVI00Go000007moO`1oOgl0Ogmo
o`00000206IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<oooool00oooool00`00003ooooo
ooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`002Oooool01000003ooooo
ooooooooool301TI6@;o00002@0c<c<6o`0001<0C4a<00@0000006IVIP1VIVH000000P1oOgl01?l0
0000VIVIo`000?l000020<c<c003o`00003Vi^Ko000000L0oooo00co00000>KVi_l00000c<c<o`00
002c/k?o000009VIVOl00000000006IVIP00000204a<C0030000000c<c<0<c<c00L0<c<c00D00000
04a<C01<C4`0000006IVIP02o`00000809VIVOl00000/k>co`00003<c<co00000>KVi_l000070?oo
o`0<o`00003Vi^H0i^KVo`00003<c<co00000;>c/ol00000VIVIo`00001oOgoo00000P1VIVH00`00
0000C4a<04a<C00604a<C0050000001VIVH0IVIV06IVI_l00000101oOgl00ol00000VIVI09VIV@03
o`0000P0/k>c0_l0000309VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH01@000000C4a<04a<
C01<C4co00000080<c<c1?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo
0ol0001_ooooo`002Oooool01000003oooooooooooooool501TI6@;o00003@0c<c<?o`0000D0C4a<
00<0000006IVIP0000000P1oOgl02Ol00000VIVIo`00002c/k?o00000<c<c?l00000i^KVo`000007
0?ooo`0<o`00003Vi^Ko00000<c<c?l00000/k>co`00002IVIWo00000000001VIVH000000P1<C4`0
0`000000<c<c03<c<`0703<c<`050000001<C4`0C4a<0000001VIVH00_l00000202IVIWo00000;>c
/ol00000c<c<o`00003Vi^Ko00001`3oool03?l00000i^KV0>KVi_l00000c<c<o`00002c/k?o0000
09VIVOl00000Ogmoo`000080IVIV00<0000004a<C01<C4`01`1<C4`01?l00000IVIV06IVIP1VIVH2
o`0000<0Ogmo0_l0000309VIV@So0000102IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00D0
000004a<C01<C4`0C4a<o`00000303<c<`Cooooo00<00000ooooooooool0E_ooool2o`000003oooo
ool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooooooo1`0I6AT2o`0001T0<c<c
0_l0000404a<C0030000001VIVH000000080Ogmo00Oo000009VIVOl00000/k>co`00003<c<co0000
0080i^KV00?o00000?ooo`3oool00`3oool03Ol00000i^KV0>KVi_l00000c<c<o`00002c/k?o0000
09VIVOl00000000006IVIP0000000P1<C4`00`000000<c<c03<c<`0703<c<`050000001<C4`0C4a<
0000001VIVH00_l00000202IVIWo00000;>c/ol00000c<c<o`00003Vi^Ko00001`3oool03?l00000
i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIVOl00000Ogmoo`000080IVIV00<0000004a<C01<
C4`0201<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo0080Ogmo0_l0000:09VIV@?o
00000`1oOgl00ol00000IVIV06IVIP0206IVIP050000001<C4`0C4a<04a<C?l000000`0c<c<01Ol0
003oooooooooooooool0000005Wooooo0_l0001fooooo`002Oooool01000003oooooooooooooool9
01TI6@03o`00000c<c<0<c<c01P0<c<c00?o000004a<C01<C4`00P1<C4`01`000000IVIV0000001o
Ogoo000009VIVOl000000P2c/k<00ol00000c<c<o`0000020>KViPGo00000P3Vi^H03Ol00000c<c<
o`00002c/k?o000009VIVOl00000Ogmo0000001VIVH0000004a<C00000002P0c<c<01@000000C4a<
04a<C0000000IVIV00;o000000H0VIVIo`00002c/k?o00000<c<c?l000020>KViP03o`00003oool0
oooo00<0oooo00Co00000>KViP3Vi^Ko00000P3<c<`02Ol00000/k>co`00002IVIWo000007moOol0
0000IVIV0000000<04a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00`1oOgl2o`00
00D0VIVI0ol0000407moO`;o0000101VIVH01@000000C4a<04a<C01<C4co000000@0<c<c00Go0000
oooooooooooooooo0000003Aooooo`002Oooool01000003oooooooooooooool:01TI6@?o0000600c
<c<01ol00000C4a<04a<C01<C4co000006IVIP0000000P1oOgl01Ol00000VIVIo`00002c/k?o0000
0080c<c<00?o00000>KViP3Vi^H01@3Vi^H02ol00000c<c<0<c<c?l00000/k>co`00002IVIWo0000
0000001VIVH000000080C4a<00<0000003<c<`0c<c<02@0c<c<01P000000C4a<0000001VIVKo0000
07moO`;o00000P2c/k<2o`000080i^KV0ol000020?ooo`0=o`00003Vi^H0i^KV0>KVi_l00000c<c<
o`00002c/k?o000009VIVOl00000Ogmoo`00000206IVIP030000001<C4`0C4a<00/0C4a<00<00000
06IVIP1VIVH00P1VIVH2o`0000D0Ogmo1Ol0000607moO`03o`00001VIVH0IVIV0080IVIV0P000003
04a<C003o`00000c<c<0<c<c0080<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003oooooooooooooool=01TI6@Co00005@0c<c<01ol00000C4a<04a<C01<
C4`0000006IVIP0000000P1oOgl3o`0000040;>c/ol00000c<c<0<c<c0Oo00000P3<c<`02ol00000
/k>co`00002IVIWo000007moO`000000IVIV0000001<C4`0000000D0<c<c0_l0000503<c<`0=0000
001<C4`0000006IVI_l00000Ogmoo`00002IVIWo00000;>c/ol00000c<c<o`0000040>KViP;o0000
0`3Vi^H03?l00000c<c<o`000?l00000/k>co`00002IVIWo000007moOol00000IVIV000000@0C4a<
1_l0000504a<C0800000101VIVH4o`0000T0Ogmo0ol0000306IVIP800000101<C4`00ol00000<c<c
03<c<`0203<c<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo4@0I6ATAo`0000D0<c<c00Wo000004a<C01<C4`0C4a<0000001VIVKo0000
07moOol000000P2IVIT00ol00000/k>co`000002o`0000H0c<c<0_l000002`2c/k?o000009VIV@2I
VIWo000007moO`000000IVIV0000001<C4`0000000@0<c<c00Co000001TI6@0I6AWo0000100c<c<0
1`000000C4a<0000001VIVKo000007moOol000000P2IVIT2o`000080c<c<00?o00000>KViP3Vi^H0
103Vi^H2o`0000030<c<c?l00000/k>c0080/k>c0_l0000207moO`03o`00001VIVH0000000<0C4a<
00?o000003<c<`0c<c<0100c<c<2o`0000D0C4a<0P00000606IVIPWo0000101VIVH2000000D0C4a<
00?o000003<c<`0c<c<00`0c<c<00ol000006ATIooooo`03ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooo`;o0000800I6AT2o`0000@0<c<c00So000004a<C01<C4`0
C4a<0000001VIVH0000007moO`;o000000<0VIVIo`00002c/k<00P2c/k<6o`000080/k>c00So0000
09VIVOl0003o000007moO`000000IVIV00000080C4a<00D0000003<c<`0c<c<0<c<co`00000401TI
6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`01@000000IVIVo`00001oOgoo00000080VIVI2_l0
00020<c<c004o`00002c/k<0/k>c0;>c/`;o00000P1oOgl00ol00000IVIV0000000304a<C003o`00
000c<c<0<c<c00L0<c<c0_l0000504a<C0<000003`1VIVH00`000000C4a<04a<C00404a<C003o`00
000c<c<0<c<c0080<c<c0_l0000201TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo0P0000000ol000006ATI01TI6@0O01TI6@03o`00000c<c<0<c<c0080<c<c
00Oo000004a<C01<C4`0C4a<o`00001VIVH000000080Ogmo1Ol000050;>c/`?o000000L0VIVIo`00
001oOgl0Ogmoo`00001VIVH000000080C4a<00D00000o`00000c<c<0<c<co`00000601TI6@05o`00
000c<c<0<c<c03<c<`0000000P1<C4`00ol00000IVIVo`000002o`000080VIVI00Co00000;>c/`2c
/k?o0000103<c<`3o`0000030;>c/ol0003o000000;o00000P1oOgl01?l00000IVIVo`0000000002
04a<C003o`00000c<c<0<c<c00X0<c<c00?o000004a<C01<C4`01@1<C4`3000000T0IVIV00<00000
o`0000000000101<C4`3o`0000@0<c<c00?o000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<000000_l0000P01TI6@03o`00000c<c<0
<c<c0080<c<c00?o000004a<C01<C4`00P0000000`1VIVKo00000000000207moO`;o000000<0VIVI
o`000?l000000ol0000309VIV@04o`00001oOgl0000000000080IVIV00Co000004a<C01<C4`00000
0`0c<c<00ol000006ATI01TI6@0401TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`00`000000
IVIVo`00000207moO`03o`00002IVIWo000000Oo00000`2c/k<01ol00000VIVI09VIV@2IVIWo0000
07moOol000000P1VIVH01@000000C4a<04a<C01<C4co000000d0<c<c0_l0000804a<C0T000001P1<
C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00<06ATI1?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool5000000;o00007`0I6AT00ol00000<c<c03<c
<`0203<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH200000080Ogmo00?o000009VIV@2IVIT0
102IVIT2o`00008000000`1VIVH010000000C4a<04a<C000000303<c<`03o`00000I6AT06ATI00H0
6ATI00Go000003<c<`0c<c<0<c<c0000000204a<C0060000001VIVKo0000o`00001oOgoo00000`2I
VIT3o`0000<0/k>c0_l0000209VIV@;o000000D0Ogmoo`00001VIVH0IVIV0000000304a<C003o`00
000c<c<0<c<c00h0<c<c0_l0000C04a<C0;o00001P0c<c<00ol000006ATI01TI6@0401TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1`000003o`0001d06ATI
00?o000003<c<`0c<c<00P0c<c<01Ol00000C4a<04a<C01<C4co000000<0IVIV0P0000000`1oOgoo
0000o`000004o`00000307moOol00000IVIV00<0IVIV00@0000004a<C01<C4`000000`0c<c<00ol0
00006ATI01TI6@0801TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`01@000000IVIV06IVI_l0
0000Ogmo00?o00000`2IVIT3o`000080VIVI0_l0000207moO`04o`00001VIVH0IVIV000000<0C4a<
00?o000003<c<`0c<c<00P0c<c<7o`0000P0<c<c0ol0000=04a<C0?o00001`0c<c<00ol000006ATI
01TI6@0501TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
2P000003o`0001/06ATI00?o000003<c<`0c<c<00P0c<c<2o`000080C4a<0`00000206IVIP030000
0?l00000000000D000000P1VIVH01000003o00000000001<C4`200000080<c<c0_l0000<01TI6@05
o`00000c<c<0<c<c03<c<`0000000P1<C4`01?l00000IVIV06IVI_l0000307moO`So000000D0Ogmo
o`000?l0003o000006IVIP020000000404a<C?l0003o0000o`0000<0<c<c0_l0000701TI6@?o0000
200c<c<7o`000080C4a<1?l0000903<c<`03o`00000I6AT06ATI00H06ATI00Go0000oooooooooooo
oooo0000003Aooooo`002Oooool01000003oooooooooooooool=000000[o00004P0I6AT2o`0000@0
<c<c00?o000004a<C01<C4`00P1<C4`3000000H0IVIV0`00000304a<C0050000000c<c<0<c<c03<c
<ol000003P0I6AT2o`0000<0<c<c00@0000004a<C000000000000P1VIVH3o`0000H0Ogmo0ol00003
06IVIP040000001<C4`0C4a<o`0000@0<c<c0_l0000<01TI6@03o`00000c<c<0<c<c00`0<c<c0_l0
000:03<c<`?o0000200I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?oooooooooooooooaL000002ol0000901TI6@;o00000`0c<c<3o`0000@0C4a<1P00
000404a<C08000000`0c<c<00ol000006ATI01TI6@0501TI6@Co00001P0I6AT01Ol00000<c<c03<c
<`0c<c<000000080C4a<0P00000306IVIPKo0000101VIVH200000080C4a<00?o000003<c<`0c<c<0
0P0c<c<00ol000006ATI01TI6@0=01TI6@?o0000500c<c<3o`0000X06ATI00?o000000000?ooool0
0oooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooolR000000?o0000
200I6AT00ol00000<c<c03<c<`0303<c<`;o00002P1<C4`2000000@0<c<c00?o000001TI6@0I6AT0
100I6AT2o`0000@0000000?o000001TI6@0I6AT0100I6AT01?l00000<c<c03<c<`0c<c<2o`000080
C4a<0`00000806IVIP8000000`1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI0140
6ATI0ol0000@03<c<`03o`00000I6AT06ATI00X06ATI00?o00000000000000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo0009oooookKo00004Ooooonf000000[ooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool01000
003oooooooooool00006ooooo`8000004_ooool00ol0000000000000000:ooooo`@000004oooool4
000000Wooooo00<00000ooooooooool00_ooool2000000oooooo0P000004ooooo`03o`000?oooooo
oooo01Kooooo0P0000000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0E_ooool8o`00oeCooooo00?o0000oooo
ooooool03oooool00`00003oooooo`000005ooooo`8000001Oooool8000000[ooooo2P000004oooo
o`L000006Oooool01@00003oooooooooooooool0000000Gooooo20000006ooooo`0300000?oooooo
oooo00;ooooo00?o0000ooooooooool05?ooool00`00003oooooooooo`08ooooo`l000002oooool0
0ol000000000ooooo`0:ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05Cooooo0_l00?l8ooooo`?o003oDOooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo
00?ooooo0P000004ooooo`<000002?ooool7000001Sooooo0`00000Eooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`06ooooo`<000001?ooool01@00
003oooooooooooooool0000001Gooooo00<00000ooooooooool01oooool2000000oooooo10000009
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0Doooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04kooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool01Oooool2000000Wooooo00?o0000ooooooooool06?ooool00`00003oooooooooo`0Aoooo
o`0300000?oooooooooo00;ooooo00@00000oooooooooooooooo0P00000<ooooo`0300000?oooooo
oooo00;ooooo00Go0000oooooooooooooooo0000000Cooooo`03o`000?oooooooooo00Oooooo00<0
0000ooooooooool04oooool2000000Sooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool0COooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00Ko0000
ooooooooooooooooo`0000000004ooooo`@0000000?ooooo00000000000010000005oooooa@00000
1oooool00`00003o00000000000?ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooo
oooo00000003ooooo`P000001?ooool01@00003oooooooooooooool0000000Cooooo0P00000?oooo
o`8000001oooool00`00003o00000000000Hooooo`8000001oooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo057ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo00oooooo00D00000oooooooo
oooooooo00000003ooooo`0400000?ooooooooooooooo`<000000oooool5000000?ooooo1000000E
ooooo`<000001oooool00`00003oooooooooo`0<ooooo`0500000?ooooooooooooooool000000ooo
ool01@00003oooooooooooooool0000000Sooooo0P000003ooooo`0400000?oooooooooo000000Ko
oooo00<00000ooooooooool02oooool00`00003oooooooooo`05ooooo`8000002_ooool;000000So
oooo0P000006ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool03?ooool50000od3ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000000oooool00`00003o
ooooooooo`02000000?ooooo0`000005ooooo`<000001?ooool3000001Gooooo00<00000o`000?oo
ool01Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00;ooooo00@00000oooooooo
ool000000oooool00ol0003oooooooooo`09ooooo`0500000?ooooooooooooooo`0000000_ooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`06ooooo`@000002oooool4000000Kooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00Wooooo0`000?l5ooooo`<0003o??ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
04_ooooo00?o0000ooooooooool03oooool00`00003ooooo00000002ooooo`05o`000000003ooooo
ooooo`0000000_ooool2o`00000400000?ooooooooooooooo`D000000oooool00ol0000000000000
0004oooooa8000001Oooool3000000Cooooo00?o00000000000000002?ooool00ol0003ooooooooo
o`02ooooo`0500000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0;ooooo`050000
0?ooooooooooooooo`0000000_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Oo
oooo0P000006ooooo`0300000?l0003ooooo00Gooooo0_l000000`00003oooooooooo`0Aooooo`80
00001Oooool2000000Gooooo00<00000o`000?ooool00oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00<0003oooooooooool0
>Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool0
3oooool00`00003oooooo`000002ooooo`0700000?ooooooooooooooo`00003ooooo00000003oooo
o`<000001Oooool2000000Cooooo00<00000ooooooooool04oooool2000000Kooooo00<00000oooo
ooooool01?ooool2000000Cooooo0P000005ooooo`0500000?ooooooooooooooo`0000000_ooool0
1000003oooooooooooooool6000000Cooooo00D00000oooooooooooooooo00000002ooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool01Oooool2000000Oooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`05ooooo`P000002Oooool2000000Gooooo00<00000ooooooooool0
0oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0gooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo00;ooooo00H00000ooooooooool00000ooooo`000002ooooo`8000000oooool5000000;o
oooo0P000003ooooo`<000005?ooool2000000Cooooo00<00000ooooooooool01_ooool01000003o
oooo000000000007ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo0000
0005ooooo`8000000oooool01@00003oooooooooooooool0000000;ooooo00<00000ooooooooool0
0oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
1?ooool2000000Gooooo0`000008ooooo`<000002?ooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo00?ooooo00D00000oooooooooooooooo0000000:ooooo`002Oooool00ol0003ooooo
ooooo`07ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0=_ooool00ol00?oooooo
ooooo`07ooooo`?o00002Oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo00oooooo
00D00000oooooooooooooooo00000002ooooo`0300000?ooool0000000;ooooo00<00000oooooooo
ool00`000005ooooo`04o`000?ooooooooooooooo`8000001?oooolA000000Gooooo00?o0000oooo
ooooool00_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00D00000oooo
oooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000002?ooool01?l0003ooooooooo
o`000003ooooo`0400000?oooooooooo000000Kooooo1@000009ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool00oooool2000000kooooo0`000005ooooo`0300000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01@00003oooooooooooooool0000000[ooooo0009ooooo`03
o`000?oooooooooo00Kooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`0fooooo`03
o`00oooooooooooo00Kooooo1Ol00008ooooo`03o`00oooooooooooo02Kooooo2P000?lJooooo`03
o`000?oooooooooo00oooooo00T00000oooooooooooooooo00000?ooool00000ooooool000000_oo
ool01000003oooooooooo`000003ooooo`Go000000Cooooo00000000000000000_ooool00ol00000
00000000000Booooo`03o`0000000000000000?ooooo0`000002ooooo`03o`000000003ooooo00ko
oooo00@00000ooooooooool000000oooool01@00003oooooooooooooool0000000Sooooo00D00000
oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000004_ooool00`00003ooooo
ooooo`02ooooo`03o`000000003ooooo00?ooooo0P00000Cooooo`03o`0000000000000000?ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`0400000?oooooooooo000000[o
oooo0009ooooo`03o`000?oooooooooo00Gooooo00<0003oooooooooool03oooool00`000?oooooo
ooooo`0=ooooo`[o003o7_ooool00ol00?ooooooooooo`06ooooo`Go00002?ooool00ol00?oooooo
ooooo`0Tooooo`80003o2_ooool30000oaOooooo00?o0000ooooooooool03oooool01P00003ooooo
ooooooooool00000o`0000;ooooo00H00000ooooooooool00000ooooool00002ooooo`;o00001Ooo
ool01?l0003oooooooooooooool2000000?ooooo0P00000Cooooo`8000001?ooool01@00003ooooo
ooooooooool0000000kooooo00@00000ooooooooool000000oooool01@00003oooooooooooooool0
000000Sooooo00D00000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`000000
4Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
1Oooool;000000Kooooo00D00000oooooooooooooooo00000005ooooo`0300000?oooooooooo00?o
oooo00?o0000ooooo`0000002_ooool000Wooooo00?o0000ooooooooool01Oooool00`000?oooooo
ooooo`0?ooooo`030000oooooooooooo00[ooooo0ol00?l:ooooo`;o003o7?ooool00ol00?oooooo
ooooo`06ooooo`Go00002?ooool00ol00?ooooooooooo`0Rooooo`80003o3oooool20000oaGooooo
00?o0000ooooooooool03oooool02000003oooooooooo`00003ooooo00000?ooool000000_ooool0
0`00003ooooo00000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`02oooooa4000001?ooool01Ol0003oooooooooooooool0000000Cooooo00<0
0000ooooooooool02_ooool01@00003oooooooooooooool0000000?ooooo00D00000oooooooooooo
oooo00000008ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0
0000013ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`8000001Oooool3
000000_ooooo0`000004ooooo`0400000?ooooooooooooooo`8000001?ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0003o
ooooooooool04Oooool00`000?ooooooooooo`08ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`07ooooo`?o00002Oooool00ol00?ooooooooooo`0P
ooooo`80003o4oooool20000oa?ooooo00?o0000ooooooooool03oooool03000003oooooooooo`00
003ooooo00000?ooool00000ooooo`00003ooooo000000;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o000000000?ooool00_ooool0
1@00003oooooooooooooool0000000Cooooo00?o0000ooooooooool02Oooool01@00003ooooooooo
ooooool0000000?ooooo00D00000oooooooooooooooo00000007ooooo`0300000?l0003ooooo00;o
oooo00@00000ooooooooool000000oooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`03ooooo`8000004Oooool00ol0
003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Co
oooo00<0003oooooooooool01_ooool3o`0000Sooooo00<0003oooooooooool02?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Oooooo`030000oooooooooooo01Gooooo00<0003oooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`0<00000?oooooooooo00000?ooool00000ooooo`00003ooooo00000?ooool0
00000_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool01?l0003oooooooooooooool30000
00[ooooo10000006ooooo`0500000?ooooooooooooooo`0000000_ooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00Sooooo00D00000oooooooooooooooo00000003ooooo`0500000?oo
ooooooooooooo`0000001_ooool00`00003oooooooooo`03ooooo`0400000?oooooooooo000000?o
oooo00<00000ooooooooool03Oooool01@00003ooooooooooooooooo000000Gooooo00<00000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`X000001Oooool01@00003oooooooooooooool0
000000Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0003oooooooooool01Oooool5o`00
00Oooooo00<0003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Oooooo`030000oooooooooooo
01Oooooo00<0003oooooooooool03oooool00ol0003oooooooooo`0?ooooo`0<00000?oooooooooo
00000?ooool00000ooooo`00003ooooo00000?ooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`X000001?ooool4
000000?ooooo00D00000oooooooooooooooo00000002ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool02?ooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool0
0_ooool3000000;ooooo00<00000ooooooooool00oooool01@00003oooooooooooooool0000000?o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool00_ooool01000003oooooooooooooool3000000[ooooo0P000004oooo
o`0500000?ooooooooooooooo`0000001?ooool01@00003oooooooooooooool0000000Gooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`05
ooooo`Go00001oooool00`000?ooooooooooo`06ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01oooooo00<0003o
ooooooooool06?ooool00`000?ooooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00<00000
ooooo`0000000_ooool02@00003ooooo00000?ooool00000ooooo`00003oooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo00Sooooo00D00000oooooooooooooooo00000003ooooo`0300000?oooooooooo00Cooooo0P00
0006ooooo`0500000?ooooooooooooooo`0000000_ooool00`00003oooooooooo`0=ooooo`050000
0?ooooooooooooooo`0000001?ooool00`00003oooooooooo`02ooooo`0500000?oooooooooooooo
o`0000003oooool00ol0003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000001?ooool0
1Ol0003oooooooooooooool0000000Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool01?ooool00`000?ooooooooooo`05ooooo`Go00001oooool00`000?ooooooooooo`05
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01kooooo00<0003oooooooooool06_ooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`0000000_ooool02@00003ooooo00000?oo
ool00000ooooo`00003oooooo`000002ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool02_ooool6o`0000Gooooo00D00000oooooooooooooooo00000002ooooo`0500000?oooooooooo
ooooo`0000000oooool00`00003oooooooooo`08ooooo`0500000?ooooooooooooooo`0000000ooo
ool00`00003o00000000000;ooooo`0500000?ooooooooooooooo`0000000oooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo00;ooooo00D00000ooooooooooooooooo`000003ooooo`03
o`000000003ooooo00;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`02ooooo`05
o`000?ooooooooooooooo`0000000oooool00`00003oooooooooo`02ooooo`0500000?oooooooooo
ooooo`0000002_ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`06oooo
o`?o00002?ooool00`000?ooooooooooo`04ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01kooooo00<0003ooooo
ooooool06oooool00`000?ooooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00<00000oooo
o`0000000_ooool02@00003ooooo00000?ooool00000ooooo`00003oooooo`000004ooooo`;o0000
00?oooooo`000?ooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo
0ol00003ooooo`0400000?oooooooooo000000;ooooo00D00000oooooooooooooooo00000003oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool00_ooool00ol000000000ooooo`03oooo
o`0300000?oooooooooo00Oooooo00D00000oooooooooooooooo00000004ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool01@00003oooooooooooooool0000000?ooooo00D0
0000ooooooooooooooooo`000005ooooo`[o00001?ooool00`00003oooooooooo`02ooooo`040000
0?oooooooooo000000?ooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool00000
00[ooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0003oooooooooool04Oooool00`000?oo
ooooooooo`04ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo01oooooo00<0003oooooooooool06oooool00`000?oo
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00X00000ooooooooool00000ooooo`00003o
oooo00000?ooool000000_ooool00`00003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooo`00
00000_ooool01000003oooooooooo`000003ooooo`0500000?ooooooooooooooo`0000002_ooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo0`000003ooooo`<000000oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool00_ooool0
1@00003oooooooooooooool0000000?ooooo00D00000oooooooooooooooo00000005ooooo`03o`00
0?oooooooooo00Sooooo0_l00003ooooo`05o`000?ooooooooooooooo`0000000oooool01@00003o
ooooooooooooool0000000Cooooo00@00000ooooooooool000002_ooool000Wooooo00?o0000oooo
ooooool01Oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00Cooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Hooooo`;o003o2oooool2o`00ob7ooooo00<0003ooooo
ooooool07Oooool00`000?ooooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00P00000oooo
ooooool00000ooooo`00003ooooo000000;ooooo00Co0000ooooo`00003ooooo0_l0000;ooooo`03
o`000?oooooooooo00Oooooo0_l0000<ooooo`05o`000?ooooooooooooooool000000_ooool01000
003oooooooooo`000002ooooo`0500000?ooooooooooooooo`0000002oooool00`00003ooooooooo
o`03ooooo`0300000?oooooooooo00Cooooo0`000004ooooo`8000001?ooool00`00003ooooooooo
o`0=ooooo`0500000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000?o
oooo00<00000ooooooooool00_ooool2o`0000gooooo00Go0000oooooooooooooooo00000003oooo
o`0500000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0?
ooooo`030000oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0J
ooooo`;o003o1_ooool3o`00ob?ooooo00<0003oooooooooool07_ooool00`000?ooooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo00P00000ooooooooool00000ooooool0003ooooo000000;o
oooo00@00000oooooooooooo00000_ooool2o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo
00_ooooo00Go0000oooooooooooooooo00000002ooooo`0400000?oooooooooo000000;ooooo00D0
0000oooooooooooooooo0000000<ooooo`0300000?oooooooooo00?ooooo00?o0000000000000000
2Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00gooooo00D00000oooooooooooo
ooooo`000003ooooo`0500000?ooooooooooooooo`0000000oooool00`00003oooooooooo`02oooo
o`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooo00000003ooooo`0500000?oooooo
ooooooooo`0000000oooool01@00003oooooooooooooool0000000;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`0=ooooo`030000oooo
oooooooo00Cooooo00?o003oooooooooool02_ooool3o`0000cooooo00?o003oooooooooool06ooo
ool6o`00obGooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0:ooooo`03o`000?oo
oooooooo00oooooo00H00000ooooooooool00000ooooo`000002ooooo`0400000?oooooooooo0000
00;ooooo00@00000oooooooooooooooo0_l00004ooooo`;o00002oooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooo`0000000_ooool01000003oooooooooo`000002ooooo`050000
0?ooooooooooooooo`0000003Oooool00`00003oooooooooo`05ooooo`<000000oooool3000000Go
oooo0P00000@ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0
000000?ooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`Co00001Oooool0
0ol0003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003ooooooooo
ooooool0000000?ooooo00@00000ooooooooool000002_ooool000Wooooo00?o0000ooooooooool0
1oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Gooooo00?o003oooooooooool0
2Oooool5o`0000_ooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0Qooooo`030000
oooooooooooo00[ooooo00?o0000ooooooooool03oooool01`00003oooooooooooooool00000oooo
o`0000000_ooool00`00003ooooo00000003ooooo`0300000?oooooooooo00;ooooo1?l0000=oooo
o`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooo00000002ooooo`0300000?ooool0
000000;ooooo00D00000oooooooooooooooo0000000>ooooo`8000002?ooool3000000Kooooo0P00
000Aooooo`0500000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000?o
oooo00D00000ooooooooooooooooo`000005ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000?ooooo00L0
0000oooooooooooooooo00000?ooool0000000[ooooo0009ooooo`03o`000?oooooooooo00Sooooo
0P000?l:ooooo`030000oooooooooooo00Kooooo00?o003oooooooooool02Oooool5o`0000_ooooo
00?o003oooooooooool0AOooool00`000?ooooooooooo`0Qooooo`030000oooooooooooo00[ooooo
00?o0000ooooooooool03oooool01@00003oooooooooooooool0000000;ooooo00@00000oooooooo
oooo00000P0000000ol000000000ooooo`03000001;ooooo00?o0000ooooooooool03?ooool01Ol0
003oooooooooooooool0000000;ooooo00<00000ooooo`0000000_ooool01@00003ooooooooooooo
ool00000013ooooo1@00000:ooooo`8000004oooool01@00003oooooooooooooool0000000?ooooo
00D00000oooooooooooooooo00000002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo00000003
ooooo`0400000?oooooooooo000000?ooooo00L00000ooooooooooooooooo`000?ooool0000000[o
oooo0009ooooo`03o`000?oooooooooo00[ooooo0`000?l6ooooo`030000oooooooooooo00Oooooo
00?o003oooooooooool02Oooool5o`0000_ooooo00?o003oooooooooool0AOooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo00Wooooo00?o0000ooooooooool03oooool00`00003ooooo
00000002ooooo`04o`000?oooooooooo000000?ooooo00@00000ooooooooool000000oooool=0000
00Gooooo00?o0000ooooooooool03?ooool01Ol0003oooooooooooooool0000000;ooooo00<00000
ooooo`0000000_ooool01@00003oooooooooooooool0000000Kooooo1000000;ooooo`<000000ooo
ool4000001Gooooo00D00000oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`00
00000_ooool01@00003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooo`0000000oooool01000003oooooooooo`00
0003ooooo`0700000?ooooooooooooooool0003ooooo0000000:ooooo`002Oooool00ol0003ooooo
ooooo`0=ooooo`H0003o2_ooool00ol00?ooooooooooo`0:ooooo`?o00003?ooool00ol00?oooooo
ooooo`14ooooo`030000oooooooooooo02?ooooo00<0003oooooooooool02Oooool00ol0003ooooo
ooooo`0?ooooo`0300000?ooool0000000?ooooo00<00000ooooooooool00P000002ooooo`030000
0?oooooooooo00<000003Oooool2000000Cooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooo`000002ooooo`0400000?oooooooooo000000;ooooo00@00000ooooooooool000001_ooool0
0`00003oooooooooo`02ooooo`@000002_ooool3000000_ooooo1@0000000ol0003oooooooooo`06
ooooo`0500000?ooooooooooooooo`0000000oooool01000003oooooooooo`000002ooooo`050000
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`0500000?ooooooooooooooo`0000000_ooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01gooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@oooooaT0okK16oooool00`00
0?ooooooooooo`0?ooooo`?o00004Oooool00`000?ooooooooooo`09ooooo`03o`000?oooooooooo
00oooooo00@00000ooooooooool000000oooool01@00003oooooooooooooool0000000;ooooo00?o
000000000?ooool00_ooool500000003o`0000000000000000Oooooo00<00000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`;o00000_ooool01?l0003oooooooooo`000002ooooo`040000
0?oooooooooo000000;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`@0
okK100Co00000000000000000000403o]/401000003o0000000000000006ooooo`0300000?oooooo
oooo00Gooooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000;ooooo
00D00000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`000003ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000001Ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooooooool03OoooolO0?nf`ASooooo00<0003oooooooooool03_ooool5
o`00013ooooo00<0003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`0400000?oooooo
oooo000000Cooooo00D00000oooooooooooooooo00000003ooooo`<000002?ooool3000000Cooooo
00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00@00000ooooooooool000000_ooool01000003oooooooooo`000002ooooo`0300000?oooooooooo
00?ooooo00<00000ooooooooool02`3o]/43000000X0okK10`0000040?nf`@Kooooo00<00000oooo
ooooool01Oooool01@00003oooooooooooooool0000000?ooooo00@00000ooooooooool000000_oo
ool01@00003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00@00000ooooooooool000000oooool01000003oooooooooo`000005
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0;ooooobD0okK15Oooool00`000?ooooooooooo`0>oooo
o`Go00004?ooool00`000?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo00D00000oooo
oooooooooooo00000004ooooo`8000000_ooool3000000?ooooo10000007ooooo`8000000oooool0
0`00003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
1000003oooooooooo`000002ooooo`0400000?oooooooooo000000;ooooo00<00000ooooooooool0
0_ooool00`000000okK10?nf`@0?0?nf`@X000002P3o]/44ooooo`0300000?oooooooooo00Cooooo
00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000;ooooo00D00000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
0003ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000001Oooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool02?ooool[0?nf`A?ooooo00<0003oooooooooool03Oooool5o`00013ooooo
00<0003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo
0P000004ooooo`0300000?oooooooooo00;ooooo0P000005ooooo`<000001_ooool01@00003ooooo
ooooooooool0000000Cooooo0ol00002ooooo`?o00001Oooool01000003oooooooooo`000002oooo
o`0400000?oooooooooo000000;ooooo00@00000oooooooooooooooo0P3o]/400`000000okK10?nf
`@0V0?nf`@03ooooo`00003ooooo00Gooooo00D00000oooooooooooooooo00000003ooooo`040000
0?oooooooooo000000;ooooo00D00000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`000003ooooo`0400000?oooooooooo000000?ooooo00@0
0000ooooooooool000001Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Nooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01Ooooola0?nf`A3ooooo00<0
003oooooooooool03_ooool3o`00017ooooo00<0003oooooooooool02Oooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00_ooool00`00003o00000000
0003ooooo`D000000oooool3000000Cooooo00L00000o`000?oooooooooo00000?l00000000000Co
oooo0_l00006ooooo`8000000oooool01000003oooooooooo`000002ooooo`04o`000?oooooooooo
o`0000@0okK100<000000?nf`@3o]/40:@3o]/400ol0003oooooooooo`03ooooo`0500000?oooooo
ooooooooo`0000000oooool01000003oooooooooo`000002ooooo`0500000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000000oooool01000
003oooooooooo`000003ooooo`0400000?oooooooooo000000Gooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool07oooool2o`00oaGooooo0_l00?l5ooooocL0okK13Oooool0
0`000?ooooooooooo`0Rooooo`030000oooooooooooo00Wooooo00?o0000ooooooooool03oooool0
0`00003ooooo00000005ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01Oooool2
000000Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo00Oooooo0P000004ooooo`0800000?ooooooooooooooo`00003ooooo00000?ooool20?nf`@03
0000003o]/40okK10080okK100<000000?nf`@3o]/40:@3o]/4010000000okK10?nf`@3o]/42oooo
o`0500000?ooooooooooooooo`0000000oooool01000003oooooooooo`000002ooooo`0500000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Go0000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000_ooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02oooooc/0okK13?ooool00`000?oo
ooooooooo`0Rooooo`030000oooooooooooo00Wooooo00?o0000ooooooooool03oooool00`00003o
oooo00000006ooooo`8000001Oooool3000000Kooooo0P000003ooooo`<000000oooool00`00003o
ooooooooo`02ooooo`<000001Oooool00`00003oooooooooo`02ooooo`8000000_ooool200000003
ooooo`3o]/4000000080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@0Z0?nf`@03
0000003o]/40okK10080okK100?ooooo00000?ooool00oooool01000003oooooooooo`000003oooo
o`0400000?oooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo00000003ooooo`0400000?oo
oooooooo000000?ooooo00L00000ooooooooooooooooo`000?ooool0000000[ooooo0009ooooo`03
o`000?oooooooooo02;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooocd0
okK12oooool00`000?ooooooooooo`0Qooooo`030000oooooooooooo00[ooooo00?o0000oooooooo
ool03oooool01000003oooooooooo`000007ooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool01Oooool2000000Cooooo00L00000oooooooooooooooo00000?l00000000000Cooooo1@00
0003ooooo`8000000oooool01@00003oooooooooo`3o]/4000000080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@050?nf`@`0000000?o00000?nf`@3o]/40603o]/400`000000okK1
0?nf`@020?nf`@0300000?oooooooooo00;ooooo00@00000ooooooooool000000oooool01000003o
ooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`?o00001Oooool01Ol0
003oooooooooooooool0000000?ooooo00@00000ooooooooool000000oooool01`00003ooooooooo
ooooool00000ooooo`0000002_ooool000Wooooo00?o0000ooooooooool08oooool00ol00?oooooo
ooooo`0=ooooo`04o`00oooooooooooooooood80okK12?ooool00`000?ooooooooooo`0Qooooo`03
0000oooooooooooo00[ooooo00?o0000ooooooooool03oooool01000003oooooooooo`000008oooo
o`0300000?oooooooooo00Gooooo00?o000000000?ooool01_ooool00`00003oooooooooo`02oooo
o`03o`000000003ooooo00?ooooo00<00000ooooooooool01oooool2000000Cooooo00<00000oooo
o`3o]/400P3o]/4010000000okK10?nf`@0000040?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/402`3o]/4>000000`0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@02
ooooo`0400000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`05o`000?ooooooooooooooo`0000000oooool01000003o
ooooooooo`000003ooooo`0700000?ooooooooooooooo`00003ooooo0000000:ooooo`002Oooool0
0ol0003oooooooooo`0Tooooo`;o003o2oooool2o`00o`;oooooAP3o]/47ooooo`03o`00oooooooo
oooo01oooooo00<0003oooooooooool02oooool00ol0003oooooooooo`0?ooooo`0400000?oooooo
oooo000000Wooooo00<00000ooooooooool01_ooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00?ooooo00<00000ooooooooool00_ooool3000000Gooooo00<00000ooooooooool00ooo
ool00`000000okK10?nf`@020?nf`@040000003o]/40okK1000000@0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@0I0?nf`@<000002@3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK100@00000ooooooooool000000oooool01@00003oooooooooooooool00000
00Cooooo00?o0000ooooooooool03_ooool01Ol0003oooooooooooooool0000000?ooooo00D00000
oooooooooooooooo00000003ooooo`0700000?ooooooooooooooo`00003ooooo0000000:ooooo`00
2Oooool00ol0003oooooooooo`0Vooooo`?o003o1_ooool2o`00o`?oooooB03o]/46ooooo`030000
oooooooooooo01oooooo00<0003oooooooooool02oooool00ol0003oooooooooo`0?ooooo`050000
0?ooooooooooooooo`0000002Oooool00`00003oooooooooo`06ooooo`8000001_ooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo00Cooooo1@000005ooooo`030000003o]/40okK10080
okK100Go00000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/407@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK10080okK100D000000?nf
`@3o]/40okK100000003ooooo`0500000?ooooooooooooooo`0000000oooool00`00003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01@00003ooooooooo
ooooool0000000;ooooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo0000
00[ooooo0009ooooo`03o`000?oooooooooo02Wooooo1_l00?l4ooooodX0okK11_ooool00`000?oo
ooooooooo`0Mooooo`030000oooooooooooo00cooooo00?o0000ooooooooool03oooool01@00003o
ooooooooooooool0000000[ooooo00<00000ooooooooool01oooool2000000Gooooo0P000004oooo
o`03o`0000000000000000Wooooo100000030?nf`@8000000`3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/407`3o]/400ol00000okK10?nf`@060?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@00003oooooooooooooool0
000000;ooooo00D00000oooooooooooooooo00000005ooooo`;o00002_ooool2o`0000Cooooo00Go
0000oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`0000000oooool01000003o
ooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0boooood`0okK11_ooool00`000?oo
ooooooooo`0Looooo`030000oooooooooooo00cooooo00?o0000ooooooooool03oooool01@00003o
ooooooooooooool0000000[ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`04oooo
o`8000001Oooool9000000?ooooo0`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
0080okK100?o00000?nf`@3o]/401@3o]/400`000000okK10?nf`@0O0?nf`@030000003o]/40okK1
00H0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/7ooooo
ooooo`0000000oooool01@00003oooooooooooooool0000000Kooooo00?o0000ooooooooool01?oo
ool3o`0000Cooooo0P000004ooooo`0400000?oooooooooo000000Cooooo00D00000oooooooooooo
oooo00000002ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo033ooooo
D03o]/44ooooo`030000oooooooooooo01_ooooo00?o003oooooooooool03Oooool00ol0003ooooo
ooooo`0?ooooo`0400000?oooooooooo000000_ooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`05ooooo`0300000?oooooooooo00cooooo0P3o]/43000000@0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@040?nf`@8000008`3o]/400`000000okK10?nf`@060?nf`@03
0000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`Oooool00000
00?ooooo00@00000oooooooooooooooo0P000005ooooo`Ko00001_ooool00`00003oooooooooo`02
ooooo`8000000_ooool00ol0003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0_oooooe80okK11?ooool0
0`000?ooooooooooo`0Iooooo`80003o3oooool00ol0003oooooooooo`0?ooooo`0400000?oooooo
oooo000000_ooooo00<00000ooooooooool02oooool00`00003oooooooooo`05ooooo`0400000?l0
00000000000000Wooooo0`0000040?nf`@80000000?o00000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK102@0okK100<000000?nf`@3o]/401@3o]/400ol00000okK1
0?nf`@030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400oooool00000ooooo`02ooooo`03
00000?oooooooooo00;ooooo0P00000>ooooo`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool00_ooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0^oooooe@0okK11?ooool00ol00?l0
003oooooo`0Gooooo`030000oooooooooooo00oooooo00?o0000ooooooooool03oooool01000003o
ooooooooo`00000:ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02Oooool90000
00H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK1
02@0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK1
0?nf`@000000103o]/400ol0003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo0`000009
ooooo`<000000oooool00`00003oooooooooo`03ooooo`0500000?ooooooooooooooo`0000000ooo
ool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02goooooEP3o]/45ooooo`030000oooooooooooo01Cooooo00<0003oooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`0300000?ooool0000000Wooooo0P00000@ooooo`8000004?ooool6
0?nf`@8000001@3o]/42000000L0okK100<000000?nf`@3o]/409@3o]/400`000000okK10?nf`@06
0?nf`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000040?nf`@0300000?oo
oooooooo00;ooooo00<00000ooooooooool01Oooool3000000?ooooo0`000005ooooo`0300000?oo
oooooooo00?ooooo00D00000oooooooooooooooo00000003ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?oooomH0?nf`@Gooooo00<0
003oooooooooool04_ooool00`000?ooooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00<0
0000ooooo`0000002?ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo00cooooo1@3o
]/42000000H0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@0W0?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK10080okK100<00000ooooooooool00_ooool2000000Sooooo0`000007ooooo`0300000?oo
oooooooo00?ooooo00D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:ooooomJ0?nf`@Gooooo00<0
003oooooooooool04?ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool01Oooool00`00003o00000000000Fooooo`0300000?l00000000000@000001_oo
ool500000003o`00003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf
`@0X0?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10080okK100<00000ooooooooool00oooool2000000gooooo0P00
00000ol0003oooooooooo`02ooooo`8000000oooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:_oooomK
0?nf`@Kooooo0`000?l=ooooo`80003o5Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool07_ooool6000000/0okK10P0000000ol00000okK10?nf`@06
0?nf`@030000003o]/40okK102T0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK100<0okK100L000000?nf`@3o]/40okK1ooooool00000000000Gooooo
0`000008ooooo`8000001Oooool2000000Cooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02[oooooG03o
]/48ooooo`D0003o1?ooool40000oaOooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`03ooooo`0300000?oooooooooo00Kooooo3`00000?ooooo`T0okK10`00000:0?nf`@030000003o
]/40okK102X0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100<0okK100@000000?nf`@3o]/40okK10_ooool00`00003oooooooooo`05ooooo`P00000
1_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool0
0oooool00`00003ooooo0000000:ooooo`002Oooool00ol0003oooooooooo`0Yoooooeh0okK13?oo
ool40000oa_ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Gooooo00?o000000000?ooool03_ooool00`00003oooooooooo`0;ooooo`T0okK100<0
00000?nf`@3o]/402@3o]/42000002h0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/42ooooo`0300000?oo
oooooooo017ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00<00000ooooo`0000002_ooool000Wooooo00?o0000ooooooooool0:?oooomP
0?nf`B[ooooo00?o0000ooooooooool03oooool01@00003ooooooooooooooooo000000Kooooo0P00
000Booooo`03o`000?oooooooooo00Wooooo1`3o]/400`00003o00000000000:0?nf`@800000<03o
]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100@0okK10P0000030?nf`@<000000P3o
]/42ooooo`03o`0000000000000000<000002Oooool300000003o`000?oooooooooo00;ooooo0P00
00000ol0003oooooooooo`02ooooo`8000001Oooool01000003oooooooooo`00000:ooooo`002Ooo
ool00ol0003oooooooooo`0Wooooof80okK1:Oooool00ol0003oooooooooo`0?ooooo`0400000?oo
oooooooo000000Cooooo0`000007ooooo`D000002?ooool00`00003oooooooooo`08ooooo`@0okK1
1000000;0?nf`@800000<P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100D0okK1
00<000000?nf`@3o]/400`3o]/42000000030?nf`Ooooooooooo00Gooooo2@000006ooooo`800000
1_ooool00`00003oooooooooo`04ooooo`0500000?ooooooooooooooo`0000002_ooool000Wooooo
00?o0000ooooooooool09_oooomS0?nf`BWooooo00?o0000ooooooooool03oooool00`00003ooooo
00000004ooooo`0300000?oooooooooo00Gooooo0`000005ooooo`<000001_ooool00`00003ooooo
ooooo`06ooooo`80okK10`00000>0?nf`@030000003o]/40okK103<0okK100<000000?nf`@3o]/40
1`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100@0okK100<00000ooooooooool0
4oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
0_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Vooooof@0okK1:?oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool4000000_ooooo00?o000000000?ooool01?ooool00`00003oooooooooo`05ooooo`030?nf`@00
0000okK100h0okK10P00000g0?nf`@030000003o]/40okK100L0okK100?o00000?nf`@3o]/401@3o
]/42000000D0okK10`00000@ooooo`8000001_ooool2000000Kooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0<ooooo`D0003o5?oooomV
0?nf`BOooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo00;ooooo00<00000ooooooooool00_ooool8000000Cooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`04ooooo`030?nf`Ol00000okK100d0okK10P00000i0?nf`@030000003o]/40
okK100P0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@040?nf`@03ooooo`000000
0000008000002Oooool3000000Oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo0`000?l5oooo
o`@0003o3ooooomW0?nf`BOooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02oooo
o`0500000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`06ooooo`8000000oooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo0P3o]/400`000000okK10?nf`@0:
0?nf`@800000?03o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100H0okK100<00000
0?nf`@3o]/400`3o]/45ooooo`T000002?ooool2000000Oooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`030000oooooooooooo
00[ooooo00?o003oooooooooool03?oooomX0?nf`BKooooo00?o0000ooooooooool03oooool01@00
003oooooooooooooool0000000?ooooo00@00000oooooooooooooooo0P00000;ooooo`0500000?oo
ooooooooooooo`0000001?ooool00`00003oooooooooo`02ooooo`030?nf`@000000okK100X0okK1
0P00000o0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/401P3o]/42000000@0okK1
5?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02?ooool00`000?ooooooooooo`0;ooooo`030000oooo
oooooooo00[oooooJ@3o]/4Vooooo`03o`000?oooooooooo00oooooo00@00000oooooooooooo0000
0_ooool2000000;ooooo0P000003ooooo`L000001?ooool01Ol0003oooooooooooooool0000000?o
oooo00@00000oooooooooooooooo0P3o]/400`000000okK10?nf`@070?nf`@800000@P3o]/400ol0
0000okK10?nf`@080?nf`@800000203o]/401000003o000000000000000Aooooo`80000000?o0000
ooooooooool01_ooool00`00003o0000ooooo`07ooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Oooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`09oooo
ofX0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooo000000;ooooo00D00000oooo
oooooooooooo00000004ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00_ooool0
1000003oooooooooo`000003ooooo`0400000?ooooooooooooooo`80okK100<000000?nf`@3o]/40
1P3o]/400`000000okK10?nf`@130?nf`@030000003o]/40okK100T0okK10P00000:0?nf`@@00000
2Oooool4000000Wooooo0P00000:ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00Kooooo00<0003oooooooooool03oooool00`000?ooooooooooo`07ooooof`0okK19?oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00@00000ooooooooool00000
0oooool2000000Wooooo0P000002ooooo`0500000?ooooooooooooooo`0000000oooool00`00003o
oooo0?nf`@020?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40A@3o]/400`000000
okK10?nf`@0:0?nf`@8000002P3o]/42ooooo`T000003?ooool00`00003oooooooooo`0:ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo00<0003oooooooooool0
4Oooool00`000?ooooooooooo`05ooooofd0okK19?ooool00ol0003oooooooooo`0?ooooo`050000
0?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0000000gooooo00@00000oooo
ooooool000000oooool01000003oooooooooo`0000040?nf`@030000003o]/40okK100@0okK100?o
00000?nf`@3o]/40A`3o]/400ol00000okK10?nf`@0;0?nf`@800000203o]/4Eooooo`0300000?l0
003ooooo00cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool0
0`000?ooooooooooo`0Cooooo`030000oooooooooooo00CoooooKP3o]/4Sooooo`03o`000?oooooo
oooo00oooooo00D00000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`000000
0oooool6000000Cooooo00@00000ooooooooool000000oooool01000003oooooooooo`0000040?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40B03o]/42000000d0okK10`0000060?nf
`A;ooooo0P00000=ooooo`0300000?ooool0000000[ooooo0009ooooo`03o`000?oooooooooo00Co
oooo00<0003oooooooooool04oooool00`000?ooooooooooo`03ooooofl0okK18oooool00ol0003o
ooooooooo`0?ooooo`0500000?ooooooooooooooo`0000000_ooool01000003oooooooooo`000003
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00_ooool01000003oooooooooo`00
0002ooooo`0400000?oooooooooo000000@0okK100<000000?nf`@3o]/40103o]/400`000000okK1
0?nf`@1:0?nf`@030000003o]/40okK100d0okK10`0000030?nf`A3ooooo0P00000?ooooo`030000
0?ooool0000000[ooooo0009ooooo`03o`000?oooooooooo00Cooooo00<0003oooooooooool05?oo
ool00`000?ooooooooooo`02ooooog00okK18_ooool00ol0003oooooooooo`0?ooooo`0400000?oo
oooooooo000000;ooooo00@00000ooooooooool000000oooool00ol0003oooooooooo`06ooooo`80
00000oooool00ol0003ooooo00000003ooooo`0400000?ooool0okK1000000<0okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@1<0?nf`@030000003o]/40okK100l0okK100@00000o`00
003o]/40okK13Oooool20000013ooooo00@00000ooooooooool000002_ooool000Wooooo00?o0000
ooooooooool00oooool00`000?ooooooooooo`0Eooooo`04o`00ooooooooooooooooog80okK18Ooo
ool00ol0003oooooooooo`0?ooooo`0400000?oooooooooo000000;ooooo00@00000oooooooooooo
00000_ooool00ol0003oooooooooo`08ooooo`0500000?ooooooooooooooo`0000000_ooool01000
003oooooooooo`0000020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`000000okK10?nf
`@1=0?nf`@8000004@3o]/4=00000003o`000000003ooooo013ooooo00D00000oooooooooooooooo
0000000:ooooo`002Oooool00ol0003oooooooooo`03ooooo`030000oooooooooooo00Oooooo0ol0
000;ooooo`030000oooooooooooo07<0okK18Oooool00ol0003oooooooooo`0?ooooo`0400000?oo
oooooooo000000;ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`08ooooo`05
00000?ooooooooooooooo`0000000_ooool01000003oooooooooo`0000020?nf`@050000003o]/40
okK10?nf`@0000001@3o]/400`000000okK10?nf`@0X0?nf`@`000006`3o]/400`000000okK10?nf
`@0A0?nf`Agooooo00D00000oooooooooooooooo0000000:ooooo`002Oooool00ol0003ooooooooo
o`03ooooo`030000oooooooooooo00Kooooo1Ol0000:ooooo`030000oooooooooooo07@0okK18?oo
ool00ol0003oooooooooo`0?ooooo`0600000?oooooooooo00000?ooool000000_ooool01000003o
ooooooooo`00000<ooooo`0400000?oooooooooo000000;ooooo00@00000ooooooooool000000P3o
]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/409@3o]/44000000`0okK1
0P00000J0?nf`@8000004P3o]/4Kooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool00oooool00`000?ooooooooooo`06ooooo`Go00002_oo
ool00`000?oooooo0?nf`@1d0?nf`B3ooooo00?o0000ooooooooool03oooool01P00003ooooooooo
o`00003oooooo`0000;ooooo00@00000ooooooooool000003?ooool01000003oooooooooo`000002
ooooo`0400000?ooool0okK100000080okK100D000000?nf`@3o]/40okK1000000040?nf`@030000
003o]/40okK10280okK10_l000000`000000okK10?nf`@0@0?nf`@8000006P3o]/4200000100okK1
6oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00?ooooo00<0003oooooooooool01_ooool5o`0000[ooooo00<0003oooooo`3o]/40=P3o
]/470?ooocL0okK18?ooool00ol0003oooooooooo`0?ooooo`0600000?oooooooooo00000?oooooo
00000_ooool01000003oooooooooo`00000<ooooo`0400000?oooooooooo000000;ooooo00@00000
ooooo`3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/40
8@3o]/400`000000okK10?nf`@030?nf`@L0oooo2`3o]/42000001X0okK10P00000>0?nf`A_ooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`03ooooo`030000oooooooooooo00Oooooo0ol0000;ooooo`030000ooooool0okK10380okK13`3o
oold0?nf`Aoooooo00?o0000ooooooooool03oooool01P00003oooooooooo`00003ooooo000000;o
oooo00D00000oooooooooooooooo0000000:ooooo`0500000?ooooooooooooooo`0000000_ooool0
1000003ooooo0?nf`@0000020?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK1
0?nf`@0O0?nf`@8000000P3o]/460?ooo`P0000000<0oooo0?nf`@3o]/401`3o]/400`000000okK1
0?nf`@0I0?nf`@8000003@3o]/4Kooooo`0500000?ooooooooooooooo`0000002_ooool000Wooooo
00?o0000ooooooooool00oooool00`000?ooooooooooo`0Eooooo`030000o`3o]/40okK10300okK1
4`3ooolb0?nf`Aoooooo00?o0000ooooooooool03oooool01000003oooooooooo`000002ooooo`04
00000?oooooooooo000000?ooooo00<00000ooooooooool01oooool02_l0003ooooooooooooooooo
0000ooooo`00003ooooo0?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`00
0000okK10?nf`@0N0?nf`@030000003o]/40okK100D0oooo0`0000080?ooo`<00000203o]/400ol0
0000okK10?nf`@0J0?nf`@8000002`3o]/4Looooo`0400000?oooooooooo000000[ooooo0009oooo
o`03o`000?oooooooooo00?ooooo00<0003oooooooooool05Oooool00`000?l0okK10?nf`@0^0?nf
`AL0oooo<03o]/4Oooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000000_ooool0
1000003oooooooooo`000003ooooo`03o`000000003ooooo00Kooooo0P000002ooooo`0700000?oo
oooooooo00000?ooool0okK1000000020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`00
0000okK10?nf`@0L0?nf`@03o`0000000000okK100D0oooo0P00000>0?ooo`03o`00000000000000
00H0okK100<000000?nf`@3o]/406`3o]/400ol000000000000000080?nf`Agooooo00<00000oooo
o`0000002_ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0Cooooo`03
0000ooooool0okK102h0okK16P3oool_0?nf`Akooooo00?o0000ooooooooool03oooool01000003o
ooooooooo`000002ooooo`0500000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00;ooooo00L00000ooooooooool00000ooooo`3o]/4000000080okK1
00D000000?nf`@3o]/40okK1000000050?nf`@030000003o]/40okK101`0okK100<000000?nf`@3o
ool00`3oool2000000D0oooo200000060?ooo`030000003o]/40okK100@0okK100<000000?nf`@3o
]/407@3o]/42000000L0okK17_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`04ooooo`030000oooooooooooo01?ooooo00<0003o0?nf`@3o]/40;@3o]/4L0?ooobh0okK1
7_ooool00ol0003oooooooooo`0?ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003o
ooooooooooooool0000000Cooooo1@000004ooooo`0700000?oooooooooo00000?ooool0okK10000
00020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`000000okK10?nf`@0L0?nf`@030000
003o]/40oooo00<0oooo00<000000?ooo`3oool00P3oool3000000P0oooo100000030?ooo`030000
003o]/40okK100@0okK100<000000?nf`@3o]/407P3o]/400ol00000okK10?nf`@040?nf`Akooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?oooooooooo
o`0Cooooo`030000o`3o]/40okK102`0okK17P3oool]0?nf`Akooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`02ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool0
2Oooool02?l0003ooooooooooooooooo0000ooooo`3o]/7o00000P3o]/401@000000okK10?nf`@3o
]/40000000D0okK100?o00000?nf`@3o]/406`3o]/400`000000okK10?ooo`030?ooo`040000003o
ool0oooo0?ooo`8000000`3oool8000000@0oooo00Ko00000?ooo`3oool0ooooo`00000000050?nf
`@030000003o]/40okK101h0okK100<000000?nf`@3o]/400`3o]/4;ooooo`T000002_ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`04ooooo`80003o4_ooool20000o`03
ooooo`3o]/40okK102/0okK1803oool/0?nf`Akooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`02ooooo`0400000?oooooooooo000000Cooooo00?o00000000000000001_ooool20000
00;ooooo0P000002ooooo`050000003o]/40okK10?nf`Ol000000`3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK101/0okK100<000000?ooo`3oool00`3oool010000000oooo0?ooool0
00020?ooo`<00000203oool3000000030?ooo`000000000000<0oooo00<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@0N0?nf`@030000003o]/40okK100<0okK12Oooool2000000Wooooo0`00
0007ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo00<0003o
ooooooooool03_ooool010000?ooooooooooooooool]0?nf`B00oooo;03o]/4Nooooo`03o`000?oo
oooooooo00oooooo00<00000ooooo`0000000_ooool01000003oooooooooooooool2000000Gooooo
1P000003ooooo`0300000?oooooooooo00;ooooo00D000000?nf`@3o]/40okK1000000020?nf`@03
0000003o]/40okK100@0okK100<000000?nf`@3o]/406P3o]/400`000000okK10?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo200000030?ooo`040000003oool0
oooo000000<0oooo00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0M0?nf`@030000003o
]/40okK100<0okK12?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00`000?ooooooooooo`0;
ooooo`80003o1?ooool[0?nf`B<0oooo:`3o]/4Nooooo`03o`000?oooooooooo00oooooo00<00000
ooooo`0000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00[ooooo00<00000
ooooooooool00_ooool01@000000okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@0K0?nf`@030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000000P0oooo00D00000o`00003oool0ooooo`0000020?oo
o`050000003oool0oooo0?ooool00000103o]/400`000000okK10?nf`@0M0?nf`@030000003o]/40
okK100<0okK11_ooool20000013ooooo0`000003ooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Sooooo0`000?l8ooooo`80003o1_oooolZ0?nf`A40oooo2@000?l;0?oo
ob/0okK17Oooool00ol0003oooooooooo`0?ooooo`0400000?oooooooooo000000?ooooo0P000003
ooooo`0400000?l000000000000000Kooooo0P000004ooooo`05o`000?ooool0okK10?nf`@000000
103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK101X0okK100H000000?ooo`3oool0
ooooo`00000000020?ooo`060000003oool0ooooo`00003oool000000_l000000`3oool000000000
0005000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?nf`@03
0000003o]/40okK101`0okK100<000000?nf`@3o]/40103o]/43ooooo`8000001_ooool8000000Oo
oooo00Co0000ooooooooool000002_ooool000Wooooo00?o0000ooooooooool02oooool20000o`03
o`00o`000?l0003o00<0003o1oooool[0?nf`@l0oooo0P000?l90?ooo`030000o`3oool0oooo00P0
oooo:`3o]/4Mooooo`03o`000?oooooooooo00oooooo00D00000oooooooooooooooo00000004oooo
o`8000001Oooool6000000Cooooo0P0000001?ooool0okK10?nf`@0000040?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/406P3o]/401@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000okK10?nf`@030?nf`@030000003o]/40okK1
01`0okK100<000000?nf`@3o]/40103o]/400oooool00000o`000005ooooo`<000002?ooool40000
00Cooooo00?o0000ooooo`0000002_ooool000Wooooo00?o0000ooooooooool06_oooolZ0?nf`@l0
oooo00?o003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooobX0okK17Oooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo00;ooooo0P000004ooooo`8000002oooool2000000?o
oooo00<0okK10000003o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK101X0
okK100D000000?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool2
000000030?ooo`000000000000H0000000D0oooo000000000000ooooo`0000020?ooo`030000003o
ool000000080oooo00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0J0?nf`@030000003o
]/40okK100D0okK100<00000ooooooooool01?ooool00`00003oooooooooo`0=ooooo`8000001?oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobX0okK13`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo:P3o]/4Mooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool01?ooool00`00003oooooooooo`03ooooo`<000001Oooool2
00000003o`000?oooooooooo00?ooooo00?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK101X0okK100<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo00?o00000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`06o`00
003oool0ooooo`00003oool000000P3oool00`000000oooo000000020?ooo`030000003o]/40okK1
0080okK100<000000?nf`@3o]/406P3o]/400`000000okK10?nf`@040?nf`@0300000?oooooooooo
00?ooooo00<00000o`000?ooool00oooool00`00003o00000000000500000003o`000?oooooooooo
00?ooooo0P000002ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[o
oooo:@3o]/4?0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0203ooolY0?nf`Ago
oooo00?o0000ooooooooool03oooool00`00003ooooo00000005ooooo`0300000?oooooooooo00Go
oooo1@000007ooooo`030000003o]/40okK100<0okK100?o00000?nf`@3o]/40103o]/400ol00000
okK10?nf`@0J0?nf`@030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooool00002
0?ooo`8000000P3oool00ol00000oooo0?ooo`05o`0000<0oooo00<000000?ooo`3oool00P000002
0?ooo`030000003oool000000080oooo00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@0J
0?nf`@030000003o]/40okK100@0okK100?o0000ooooooooool00_ooool01000003ooooooooooooo
ool3000000Wooooo0`000004ooooo`0300000?ooool0000000[ooooo0009ooooo`03o`000?oooooo
oooo01[ooooo:@3o]/4>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool01`3ooolY
0?nf`Agooooo00?o0000ooooooooool03oooool01000003oooooooooo`000005ooooo`8000003ooo
ool200000003ooooo`3o]/40okK10080okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@0J0?nf`@030000003oool0oooo0080oooo00L000000?ooo`3oool000000?ooo`000000oooo0080
00000`3oool010000000oooo0?ooool000040?ooo`04o`00003oool0oooo00000080oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000@0okK100<000000?nf`@3o]/406P3o
]/400`000000okK10?nf`@040?nf`@0500000?ooooooooooooooo`0000000oooool00`00003ooooo
ooooo`05ooooo`@000001?ooool2000000Cooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06_oooolY0?nf`@d0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`060?ooobT0okK17Oooool00ol0003oooooooooo`0?ooooo`0500000?ooooooooooooooo`000000
1_ooool2000000_ooooo0P000003ooooo`<0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@0J0?nf`@030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`8000000P3oool010000000oooo0?ooool000060?ooo`04o`00003oool0oooo00000080oooo0P00
00020?ooo`030000003ooooo00000080oooo00D000000?nf`@3o]/40okK10000000L0?nf`@030000
003o]/40okK100<0okK100D000000?nf`Oooooooooooo`000003ooooo`0300000?oooooooooo00;o
oooo10000004ooooo`<000000oooool01@00003oooooooooooooool0000000[ooooo0009ooooo`03
o`000?oooooooooo01[ooooo:@3o]/4=0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01P3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02ooooo`80
00001_ooool00ol0000000000000000600000003o`000000003ooooo00Cooooo00<0okK1o`000000
00001`3o]/400`000000okK10?nf`@0K0?nf`@030000003oool0oooo0080oooo00`000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`03o`00003oool0oooo00H0
oooo0_l000002P3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000
003o]/40okK10080okK100<000000?nf`@3o]/40603o]/400`000000okK10?nf`@030?nf`@050000
003o]/40okK1ooooo`0000000_ooool01000003o0000ooooooooool3000000Cooooo10000003oooo
o`05o`000?ooooooooooooooool000000_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0JooooobP0okK13P3oool00`000?l0oooo0?ooo`050?ooo`?o0000203oool00`00
0?l0oooo0?ooo`070?ooobP0okK13?ooool8o`00o`Wooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`04ooooo`8000005?ooool00`000000okK10?nf`@060?nf`@030000003o]/40okK1
01`0okK100?o00000?ooo`3oool00P3oool03P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003ooooo00000P3oool5o`0000<0oooo00_o00000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003o]/40okK10080okK100<000000?nf
`@3o]/40603o]/400`000000okK10?nf`@030?nf`@070000003o]/40okK1ooooo`00003ooooo0000
0003ooooo`0400000?ooooooooooooooo`@000001?ooool300000003ooooo`00003ooooo00;ooooo
00?o0000ooooo`0000002_ooool000Wooooo00?o0000ooooooooool06_oooolX0?nf`@d0oooo00<0
003o0?ooo`3oool01@3oool5o`0000P0oooo00<0003o0?ooo`3oool01P3ooolX0?nf`@Wooooo0ol0
0?l8ooooo`;o003o1oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool04?ooool00`000000okK10?nf`@060?nf`@030000003o]/40okK101d0okK100<0
00000?ooo`3oool00P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003ooooo00000P3oool01Ol00000oooo0?ooo`3ooooo000000<0oooo00_o00000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o]/40okK10080okK1
00<000000?nf`@3o]/40603o]/400`000000okK10?nf`@020?nf`@070000003o]/40okK10?nf`@00
003ooooo00000003ooooo`0300000?oooooooooo008000001?ooool4000000?ooooo00<00000oooo
o`0000001?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0IooooobT0
okK13@3oool00`000?l0oooo0?ooo`050?ooo`Go0000203oool00`000?l0oooo0?ooo`060?ooobP0
okK12?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00gooooo0P0000090?nf`@03
0000003o]/40okK101d0okK100<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`06
0000003oool000000000003oool000000P3oool01?l00000oooo0?ooool000040?ooo`04o`00003o
ool0ooooo`000080oooo0P000000103oool000000?ooo`0000020?ooo`030000003oool0000000@0
okK100<000000?nf`@3o]/405`3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf
`Ol000000_ooool01000003oooooooooo`000002ooooo`0400000?ooooooooooooooo`<000001?oo
ool01`00003o0000oooooooooooo0000ooooo`0000000oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0IooooobT0okK13@3oool00`000?l0oooo0?ooo`050?ooo`Go0000
203oool00`000?l0oooo0?ooo`060?ooobP0okK12?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00?ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`08ooooo`l00000
0_ooool90?nf`@030000003o]/40okK101d0okK100<000000?ooo`3oool00P3oool00`000000oooo
000000020?ooo`060000003oool000000000003oool000000P3oool01?l00000oooo0?ooool00004
0?ooo`04o`00003oool0ooooo`000080oooo0P000000103oool000000?ooo`0000020?ooo`030000
003oool0000000@0okK100<000000?nf`@3o]/405`3o]/400`000000okK10?nf`@020?nf`@05o`00
003o]/40okK10?nf`@0000000_ooool00`00003ooooo00000002ooooo`0300000?ooool000000080
00002?ooool2000000;ooooo00H00000ooooool0003o0000ooooo`00000:ooooo`002Oooool00ol0
003oooooooooo`0IooooobT0okK13@3oool00`000?l0oooo0?ooo`060?ooo`?o00002@3oool00`00
0?l0oooo0?ooo`060?ooobP0okK11oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool03oooool00`00003ooooo0000000Iooooo`T0okK100<000000?nf
`@3o]/407@3o]/400ol00000oooo0?ooo`020?ooo`030000003oool000000080oooo00H000000?oo
o`00000000000?ooo`0000020?ooo`03o`00003oool0oooo00?o00000P3oool01?l00000oooo0?oo
ool000020?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo000000040?nf`@03
0000003o]/40okK101L0okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/400000
00;ooooo00D00000ooooo`00003oooooo`000002ooooo`0300000?oooooooooo00Oo00000oooool0
0`00003ooooo00000004ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01Wooooo:@3o]/4=0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01P3ooolX0?nf
`@Kooooo00?o003oooooooooool04?ooool01Ol00?oooooooooooooooooo0000017ooooo00<00000
ooooo`0000006Oooool80?nf`@030000003o]/40okK101h0okK100<000000?ooo`3oool00P3oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003ooooo00001@3o
ool2o`0000<0oooo00_o00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003o]/40okK10?nf`@0000006@3o]/400`000000okK10?nf`@020?nf`@0<0000003o
]/40okK10?nf`@000000okK1ooooo`00003ooooo00000?ooool000000_ooool01000003oooooo`00
0?l00007ooooo`?o000000Coooooo`000?ooool000000oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0JooooobP0okK13P3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00L0oooo:03o]/45ooooo`03o`00oooooooooooo01;ooooo00Co003ooooooooooooo
00004Oooool01000003oooooooooo`00000Iooooo`H0okK100<000000?nf`@3o]/407`3o]/400`00
0000oooo0?ooo`020?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000P3oool00ol00000oooo0?ooo`050?ooo`;o00000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`050000003o]/40okK10?nf`Ol000006@3o]/400`000000
okK10?nf`@020?nf`@040000003o]/40okK100000080okK100D00000ooooo`00003ooooo00000002
ooooo`0300000?oooooo000000Cooooo1Ol00003ooooo`05o`000?ooool00000ooooool000000_oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobP0okK13P3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo:03o]/44ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooool000004Oooool01000003oooooooooo`00000Iooooo`H0okK100<0
00000?nf`@3o]/407`3o]/400`000000oooo0?ooo`020?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000ooooo`000080oooo00@000000?ooo`3ooooo00001@3oool00ol00000oooo0?oo
o`020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?nf
`@3o]/40okK10000000I0?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/4000000P3o
]/401@00003ooooo00000?ooool0000000;ooooo00<00000ooooool000000oooool00ol0003ooooo
ooooo`03ooooo`06o`000?ooooooooooo`000?ooool000000_ooool00ol0003ooooo0000000:oooo
o`002Oooool00ol0003oooooooooo`0JooooobT0okK13@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00H0oooo:@3o]/44ooooo`03o`00oooooooooooo01Cooooo00?o003oooooool0
00004Oooool01@00003oooooooooooooool0000001Sooooo1P3o]/400`000000okK10?nf`@0O0?nf
`@030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool01Ol000040?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`040000003oool0oooo000000<0okK100<000000?nf`@3o]/405P3o]/400`00
0000okK10?nf`@030?nf`@040000003o]/40okK100000080okK100T00000ooooo`00003ooooo0000
0?ooool00000ooooool000000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooo`00
000000001?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobT0
okK13P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo:@3o]/44ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooool000004Oooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo01Gooooo1P3o]/400`000000okK10?nf`@0P0?nf`@030000003oool0oooo0080
oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00@000000?ooo`3oool00000
203oool2000000090?ooo`000000oooo0?ooo`000000ooooo`00003oool000000080oooo00<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@0F0?nf`@03o`00003o]/40okK10080okK100@00000
0?nf`@3o]/4000000P3o]/401@00003ooooo00000?ooool0000000;ooooo00<00000ooooool00000
0_ooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooo`000?ooool000000oooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobT0okK13`3oool00`000?l0
oooo0?ooo`0;0?ooo`80003o2P3ooolY0?nf`@Cooooo00?o003oooooooooool01oooool3o`0000co
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo1P3o]/400`000000okK10?nf`@0P0?nf`@030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo000000000000oooo00000080oooo00<00000o`00000000001@00
00020?ooo`06o`00003oool00000o`00003oool000000P3oool010000000oooo0?ooo`0000040?nf
`@030000003o]/40okK101H0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@000002
0?nf`@0900000?ooool00000ooooo`00003ooooo00000?oooooo000000;ooooo00Co0000oooooooo
oooooooo1?l00003ooooo`05o`000?ooooooooooo`00000000000oooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0JooooobT0okK1403oool20000o`X0oooo00<0003o0?oo
o`3oool02P3ooolY0?nf`@Cooooo00?o003oooooooooool01_ooool5o`0000_ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo01Cooooo1`3o]/400`00
0000okK10?nf`@0O0?nf`@030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00<000000?ooool000000P0000060?ooo`<0000000D0oooo0000003oool0oooo
000000030?ooo`040000003oool0oooo000000@0okK100<000000?nf`@3o]/405P3o]/400`000000
okK10?nf`@020?nf`@040000003o]/40okK100000080okK100/00000ooooo`00003ooooo00000?oo
ool00000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003oooooooooool00000000000?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool06_oooolZ0?nf`A40oooo0P000?l30?ooo`D0003o303ooolZ0?nf`@?ooooo00?o003ooooo
ooooool01oooool5o`0000_ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02oooo
o`0300000?oooooooooo01Gooooo203o]/4200000200okK100<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`3oool6000000<0oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000040?nf`@030000003o]/40okK1
01L0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@0000020?nf`@0;00000?ooool0
0000ooooo`00003ooooo00000?oooooo0000ooooool000000oooool00ol0003oooooooooo`02oooo
o`09o`000?ooooooooooooooool0003oooooo`000?ooool0000000;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool06_oooolZ0?nf`A<0oooo0`000?lA0?ooobX0okK10ooo
ool00ol00?ooooooooooo`07ooooo`Go00002oooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool05Oooool:0?nf`@030000003o]/40okK101d0okK100<0
oooo0000003oool00`3oool03Ol00000oooo0?ooo`3ooooo00000?ooo`00003o00000000003oool0
0000o`00000000001P3oool200000004o`00003oool0000000000080oooo00H00000o`00003oool0
oooo0000003oool30?nf`@030000003o]/40okK101P0okK100<000000?nf`@3o]/400P3o]/401000
0000okK10?nf`@0000020?nf`@0;00000?ooool00000ooooo`00003ooooo00000?oooooo0000oooo
ool000000oooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`00
0?ooool0000000;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_oo
ool[0?nf`BD0oooo:`3o]/44ooooo`03o`00oooooooooooo00Oooooo0ol0000<ooooo`03o`000?oo
oooooooo00oooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0Eooooo`/0okK100<0
00000?nf`@3o]/407@3o]/400`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool0oooo1P0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000okK10?nf`@020?nf`@030000003o]/40okK101P0okK100<000000?nf`@3o]/400P3o]/401000
0000okK10?nf`@0000020?nf`@0;00000?ooool00000ooooo`00003ooooo00000?oooooo0000oooo
ool000000oooool3o`000003ooooool0003ooooo00?ooooo00Go0000ooooool0003ooooo00000002
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo;03o]/4S0?oo
ob/0okK11?ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00D00000oooo
oooooooooooo0000000Iooooo`/0okK10P00000N0?nf`@030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000103oool3000000H0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3o]/400P3o]/400`000000okK10?nf`@0I0?nf`@030000003o]/40okK10080okK100@0
00000?nf`@3o]/4000000P3o]/402`00003ooooo00000?ooool00000ooooo`00003oooooo`000?oo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`0400000?oo
oooooooo000000[ooooo0009ooooo`03o`000?oooooooooo01_ooooo;03o]/4R0?ooob/0okK11Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo0000017ooooo00@00000ooooooooool00000
6_ooool=0?nf`@030000003o]/40okK101/0okK100<000000?ooo`3oool0103oool00`000000oooo
0?ooo`02000000D0oooo1P0000050?ooo`03o`00003oool0oooo0080oooo00<000000?ooo`3o]/40
0`3o]/400`000000okK10?nf`@0I0?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/40
00000P3o]/401@00003ooooo00000?ooool0000000;ooooo00D00000ooooool0003oooooo`00000:
ooooo`05o`000?oooooo0000ooooo`0000000oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Kooooobd0okK1803oool/0?nf`@Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooo`00000Aooooo`0300000?ooool0000001_ooooo3P3o]/42000001`0okK100<00000
0?ooo`3oool00`3oool00ol0000000000?ooo`020?ooo`D000002@3oool2000000<0oooo0P000000
103oool0okK10?nf`@3o]/42000001`0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf
`@0000020?nf`@0500000?ooool00000ooooo`0000000_ooool00`00003oooooo`000002ooooo`03
o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?ooool0000000?ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool06oooool^0?nf`Ah0oooo;@3o]/45ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooool000004Oooool00`00003oooooooooo`0Cooooo`@00000
1?ooool@0?nf`@030000003o]/40okK101X0okK100<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`T000000`3oool200000080oooo0`3o]/400`000000okK10?nf`@0L0?nf`@030000
003o]/40okK10080okK100@000000?nf`@3o]/4000000P3o]/401@00003ooooo00000?ooool00000
00;ooooo00<00000ooooool000000oooool00ol0003oooooooooo`02ooooo`;o00000oooool02?l0
003oooooooooo`00003ooooo00000?ooool000002_ooool000Wooooo00?o0000ooooooooool06ooo
ool_0?nf`A`0oooo;P3o]/46ooooo`03o`00oooooooooooo01;ooooo00Co003ooooooooooooo0000
4Oooool00`00003oooooooooo`0<ooooo`L000001?ooool7000000h0okK100<000000?nf`@3o]/40
6P3o]/42000000D0oooo0`00000>0?ooo`8000000`3oool30?nf`@03o`00003o]/40okK101d0okK1
00<000000?nf`@3o]/400`3o]/402`000000okK10?nf`@000000okK1ooooo`00003ooooo00000?oo
ool0000000;ooooo00@00000ooooool0003o00000_ooool4o`0000Cooooo00Ko0000ooooooooool0
0000ooooo`000002ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01co
oooo;`3o]/4I0?oooc00okK11oooool00ol00?ooooooooooo`0@ooooo`05o`00oooooooooooooooo
ool000004Oooool00`00003oooooooooo`09ooooo`<000004?ooool20?nf`@03o`00000000000000
00`0okK100<00000o`00003o]/406`3o]/400`000000oooo0?ooo`050?ooo`0400000?l000000000
000000H0oooo100000030?ooo`@0okK100<000000?nf`@3o]/407P3o]/400`000000okK10?nf`@03
0?nf`@0<0000003o]/40okK10000003o]/7ooooo00000?ooool00000o`000?ooool000000_ooool0
0`00003oooooooooo`02o`0000Gooooo0ol000001Oooool0000000000?ooool0000000?ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07?oooola0?nf`AD0oooo<@3o]/49
ooooo`03o`00oooooooooooo00gooooo0_l00?l4ooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool01oooool2000001?ooooo1@3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40
okK101/0okK100<000000?ooo`3oool0203oool6000000D0oooo1@3o]/400`000000okK10?nf`@0O
0?nf`@030000003o]/40okK100<0okK100@000000?nf`@3o]/4000000_ooool01000003ooooooooo
o`000002ooooo`03o`000?ooool0000000Cooooo1Ol00003ooooo`0400000?oooooooooo000000Co
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07?oooolc0?nf`A40oooo
<`3o]/4:ooooo`;o003o2oooool2o`00o`Kooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`05ooooo`8000005Oooool60?nf`@8000002`3o]/400`000000okK10?nf`@0K0?nf`@800000
4@3oool50?nf`@8000008P3o]/400`000000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@00
00000_ooool01000003oooooooooo`000002ooooo`0300000?ooool00000008000001_ooool30000
00;ooooo00L00000oooooooooooooooo00000?ooool0000000[ooooo0009ooooo`03o`000?oooooo
oooo01gooooo=03o]/4=0?ooocD0okK13?ooool3o`00o`Kooooo0_l00?l8ooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Fooooo`L0okK100<00000
0?nf`@3o]/402@3o]/400`000000okK10?nf`@0L0?nf`@030000003o]/40oooo00`0oooo1@3o]/42
000002@0okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000;ooooo00@0
0000ooooooooool000000oooool01000003oooooooooooooool6000000Gooooo00@00000oooooooo
ool000000_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0MooooocP0
okK11@3ooolh0?nf`A3ooooo1_l00?l:ooooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool00_ooool00ol000000000ooooo`0:ooooo``000000_ooool80?nf`@03o`0000000000okK100T0
okK100?o00000?nf`@3o]/40703o]/401@00003o0000000000000000okK100D0oooo1`3o]/420000
02H0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@02ooooo`0400000?oooooooooo
000000;ooooo00@00000oooooooooooooooo0P00000:ooooo`80000000?ooooo0000000000000ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0MooooogD0okK18?ooool0
0ol0003oooooooooo`0?ooooo`0500000?ooooooooooooooo`0000002_ooool3000000cooooo0`00
00090?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/407`3o]/4=000002P0okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@02ooooo`0500000?ooooooooooooooo`000000
0_ooool00ol000000000ooooo`02ooooo`8000001Oooool300000003ooooo`000000000000;ooooo
0P0000000oooool00000ooooo`09ooooo`002Oooool00ol0003oooooooooo`0Nooooog@0okK18?oo
ool00ol0003oooooooooo`0?ooooo`0400000?oooooooooo000000Sooooo0`00000Booooo`<00000
1`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK10580okK100<000000?nf`@3o]/40
1@3o]/400`000000okK1ooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool00`00003o
ooooooooo`02ooooo`D000000oooool01@00003oooooooooooooool0000000?ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool07_oooomc0?nf`B7ooooo00?o0000oooooooo
ool03oooool00`00003ooooo00000007ooooo`8000005Oooool30?nf`@03o`00003o]/40okK100D0
okK100?o00000000003o]/40203o]/400`000000okK10?nf`@1A0?nf`@030000003o]/40okK100D0
okK100<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0600000?oooooooooooooo
o`00003o00000P000005ooooo`80000000Go0000ooooooooooooooooo`000004ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01ooooooLP3o]/4Qooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0:ooooo`P000001?ooool3
0?nf`@8000001P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK10540okK100<00000
0?nf`@3o]/401@3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool5000000Cooooo0P000005ooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo023oooooL03o]/4Rooooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`04ooooo`L000002?ooool2000000?ooooo103o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40C`3o]/400`00
0000okK10?nf`@060?nf`@0300000?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00
003oooooooooo`0;ooooo`0300000?oooooooooo00;ooooo0P0000000oooool00000ooooo`09oooo
o`002Oooool00ol0003oooooooooo`0Pooooofl0okK18oooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0?ooooo`80
000000?ooooo0?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100H0
okK100<000000?nf`@3o]/40C`3o]/400`000000okK10?nf`@050?nf`@03ooooo`00003ooooo00Co
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`08ooooo`8000001?ooool01@00003o
ooooooooooooool0000000[ooooo0009ooooo`03o`000?oooooooooo027oooooKP3o]/4Sooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool00_ooool00ol000000000ooooo`04ooooo`80
00005?ooool2000000D0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@03
0000003o]/40okK104`0okK10P0000080?nf`@03ooooo`00003ooooo00Gooooo00<00000oooooooo
ool01?ooool00`00003o00000000000500000003o`000000003ooooo00?ooooo00<00000o`000?oo
ool00oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Aooooo`Wo003o
1ooooom]0?nf`BCooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool01Oooool;000000Kooooo00<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40
BP3o]/400`000000okK10?nf`@070?nf`@03ooooo`00003ooooo00Kooooo00<00000ooooooooool0
4Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00kooooo0ol00?l9ooooo`?o003o1?oooom]0?nf`BCooooo00?o0000ooooooooool03ooo
ool01@00003oooooooooooooool0000000Gooooo00<00000ooooooooool01?ooool2000000_ooooo
0P000004ooooo`030?nf`@000000000000@0okK100<000000?nf`@3o]/40103o]/400`000000okK1
0?nf`@060?nf`@030000003o]/40okK104P0okK100<000000?nf`@3o]/40203o]/400`00003ooooo
ooooo`06ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool01Oooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0<ooooo`;o003o3oooool2o`00o`?oooooK03o
]/4Tooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000001?ooool00`00003o0000
ooooo`04ooooo`;o00003oooool2000000?ooooo0P3o]/400`000000okK10?nf`@020?nf`@800000
1@3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK104H0okK10P00000:0?nf`@030000
0?oooooooooo00Oooooo00<00000ooooooooool03_ooool00`00003o0000ooooo`04ooooo`;o0000
00?ooooo00000?ooool02Oooool000Wooooo00?o0000ooooooooool02_ooool2o`00oa?ooooo00Co
003oooooooooooooooooJP3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooool00000
1Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo017ooooo00H00000oooooooooooo
oooo0?nf`@0000040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`00
0000okK10?nf`@150?nf`@030000003o]/40okK100T0okK100<00000o`000?ooool01oooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo00Cooooo00@00000ooooooooool000002_ooool0
00Wooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
06T0okK19_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool00_ooool2000000Sooooo1`000006ooooo`0300000?oooooooooo0080okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100H0okK100<000000?nf
`@3o]/40@`3o]/400`000000okK10?nf`@080?nf`@8000002Oooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo00Cooooo00D00000oooooooooooooooo0000000:ooooo`002Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0J03o]/4Voooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool00oooool00`00003oooooooooo`02oooo
o`0300000?oooooooooo00Cooooo10000007ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool00P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/401P3o]/400`000000okK10?nf`@120?nf`@03o`00003o]/40okK100P0okK100<000000?nf
`@3o]/401oooool20000017ooooo00<00000ooooooooool01Oooool01@00003oooooooooooooool0
000000[ooooo0009ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool06?ooool00ol0
0?oooooo0?nf`@1V0?nf`BOooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02oooo
o`0300000?oooooooooo00;ooooo00<00000ooooooooool00oooool2000000cooooo00?o00000000
000000001?ooool00ol0003ooooo0?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK10440okK100<000000?nf
`@3o]/401`3o]/400ol00000okK10?nf`@04ooooo`80000000?o000000000?ooool04Oooool00ol0
003oooooooooo`05ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00ooooool0okK106D0
okK19oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00D00000oooooooo
ooooooooo`000005ooooo`0300000?oooooooooo00oooooo00D00000oooooooooooooooo00000002
ooooo`80okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100H0okK100<000000?nf`@3o]/40@03o]/400`000000okK10?nf`@070?nf`@040000003o]/40
okK10?nf`@?ooooo00<00000ooooooooool05?ooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`0Looooo`03o`00ooooool0okK106<0okK1:?ooool00ol0003oooooooooo`0?
ooooo`0500000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Gooooo10000008ooooo`0400000?oooooooooo000000?ooooo0P3o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/401P3o]/400`000000okK1
0?nf`@0n0?nf`@030000003o]/40okK100H0okK10P0000030?nf`@;ooooo0P00000Gooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0HP3o
]/4Yooooo`03o`000?oooooooooo00oooooo00D00000oooooooooooooooo00000003ooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00ol000000000ooooo`03ooooo`030000
0?l0003ooooo00Gooooo00D00000oooooooooooooooo00000003ooooo`030?nf`@000000okK100<0
okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK103d0
okK100?o00000?nf`@3o]/401P3o]/400`000000okK10?nf`@020?nf`@;ooooo00<00000oooooooo
ool01Oooool<000000Oooooo00<00000ooooooooool01?ooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
7Oooool01?l00?oooooooooooooooomP0?nf`B[ooooo00?o0000ooooooooool03oooool01000003o
ooooooooo`000004ooooo`0500000?ooooooooooooooool000001Oooool00`00003o0000ooooo`07
ooooo`8000001Oooool01@00003oooooooooooooool0000000?ooooo00<0okK10000003o]/400P3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/40?@3o
]/400`000000okK10?nf`@050?nf`@030000003o]/40okK10080okK100?ooooo00000?l000001?oo
ool4000000cooooo00?o000000000?ooool01Oooool00`00003oooooooooo`03ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo05l0okK1:oooool00ol0003oooooooooo`0?
ooooo`0400000?oooooooooo000000Cooooo00D00000oooooooooooooooo00000004ooooo`030000
0?oooooooooo00[ooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0000000?o
oooo00<0okK1o`00003o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100H0
okK100<000000?nf`@3o]/40>`3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK10080
okK100?ooooo00000?ooool01?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`1N0?nf`B_ooooo00?o0000ooooooooool03oooool00`00003ooooo00000004ooooo`050000
0?ooooooooooooooo`0000001?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00;o
oooo00D00000oooooooooooooooo00000003ooooo`030000003o]/40okK10080okK100<000000?nf
`@3o]/400`3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK103T0okK100<000000?nf
`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@0300000?oooooooooo00;ooooo0P000005oooo
o`/000001?ooool2000000Cooooo00<00000ooooooooool00oooool01@00003oooooooooooooool0
000000[ooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08?ooool01?l0
0?oooooooooooooooomL0?nf`Bcooooo00?o0000ooooooooool03oooool00`00003ooooo00000003
ooooo`0500000?ooooooooooooooo`0000001?ooool00ol0003oooooooooo`0>ooooo`0300000?oo
oooooooo00;ooooo00D00000oooooooooooooooo00000003ooooo`030000003o]/40okK10080okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK103H0okK1
00<00000o`00003o]/401P3o]/400`000000okK10?nf`@030?nf`@0400000?ooooooooooooooo`80
00001Oooool2000000_ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00;ooooo00D00000oooooooooooooooo0000000:ooooo`002Oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool00_oooomJ0?nf`Bgo
oooo00?o0000ooooooooool03oooool00`00003ooooo00000003ooooo`0500000?oooooooooooooo
o`0000001?ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00;ooooo00D00000oooo
oooooooooooo00000003ooooo`030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@080?nf`@03o`00003o]/40okK103D0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@030?nf`@0500000?ooooooooooooooo`0000001Oooool00`00003o0000oooo
o`0<ooooo`8000001?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D0
0000oooooooooooooooo0000000:ooooo`002Oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool00_oooomH0?nf`Bkooooo00?o0000ooooooooool03ooo
ool00`00003ooooo00000003ooooo`0500000?ooooooooooooooo`0000001?ooool00`00003ooooo
ooooo`0>ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000003ooooo`03
00000?ooool0okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@070?nf`@03
0000003o]/40okK103@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@03
00000?oooooooooo00;ooooo00@00000oooooooooooooooo0P000004ooooo`X000000oooool20000
00?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0400000?oooooooooo
000000[ooooo0009ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool03_ooool3o`00
017ooooo00?o003oooooooooool00ooooomE0?nf`A3ooooo2_l00?lFooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool00oooool01000003oooooooooo`000004ooooo`0300000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool01@00003oooooooooooooool0000000Cooooo00H0
0000oooooooooooooooo00000?ooool30?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/401`3o]/400`000000okK10?nf`@0b0?nf`@030000003o]/40okK100H0okK100H000000?nf`@3o
]/40okK1ooooo`000004ooooo`0500000?ooooooooooooooo`0000001?ooool2000000[ooooo00<0
0000ooooooooool00_ooool01Ol0003oooooooooooooool0000000?ooooo00<00000ooooooooool0
0oooool00`00003ooooo0000000:ooooo`002Oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo00gooooo1Ol0000@ooooo`03o`00oooooooooooo00CoooooD`3o]/4>ooooo`?o003o2_oo
ool4o`00oa;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`03ooooo`0400000?oo
oooooooo000000Cooooo00<00000ooooooooool01_ooool2o`0000Sooooo00<00000ooooooooool0
0_ooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00P3o]/400`000000
okK10?nf`@040?nf`@03o`0000000000okK100L0okK100<000000?nf`@3o]/40;P3o]/43000000P0
okK100H000000?nf`@3o]/40okK1ooooo`000004ooooo`03o`000?oooooooooo008000000oooool0
0`00003o0000ooooo`0<ooooo`8000000oooool01@00003oooooooooooooool0000000?ooooo00<0
0000ooooooooool01?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`02
ooooo`03o`00oooooooooooo00gooooo1Ol0000@ooooo`03o`00oooooooooooo00KoooooD03o]/4>
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo00?ooooo00@00000ooooooooool000001?ooool00`00003ooooooooo
o`06ooooo`;o00002?ooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`000000
0oooool00`00003oooooooooo`02ooooo`030?nf`@000000okK100H0okK100<000000?nf`@3o]/40
1P3o]/400ol0000000000?nf`@0Z0?nf`@<000002`3o]/400`000000okK10?nf`@02ooooo`050000
0?ooooooooooooooo`0000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;o
oooo2P000003ooooo`0500000?ooooooooooooooo`0000000oooool01000003oooooooooo`000006
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool03Oooool5o`00013ooooo00?o003oooooooooool01ooooom>0?nf`@kooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool00oooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo0000
0004ooooo`0300000?oooooooooo00;ooooo00<0okK10000003o]/401P3o]/400`000000okK10?nf
`@070?nf`@8000008P3o]/47000000d0okK100<000000?nf`@3o]/400_ooool01@00003ooooooooo
ooooool0000000?ooooo00<00000ooooooooool00P000003ooooo`8000002_ooool01@00003ooooo
ooooooooool0000000?ooooo00Go0000oooooooooooooooo00000002ooooo`03o`000?oooooooooo
00?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0=ooooo`?o00004?ooool00ol00?ooooooooooo`09oooood`0okK13_ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`03ooooo`0500000?ooooooooooooooo`0000000oooool00`00003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0
000000Cooooo00<00000ooooooooool00oooool00`3o]/7o00000?nf`@060?nf`@03o`0000000000
000000P0okK100<000000?nf`@3o]/40603o]/4700000180okK10P0000020?nf`@;ooooo00D00000
oooooooooooooooo00000003ooooo`0400000?oooooooooo000000?ooooo0_l0000=ooooo`050000
0?ooooooooooooooo`0000000oooool01000003oooooooooool00003ooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo00[oooooBP3o]/4>ooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00?o
oooo00D00000oooooooooooooooo00000003ooooo`0300000?oooooooooo013ooooo00<00000oooo
ooooool00_ooool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool01?ooool0
103o]/4000000000000000070?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/405P3o
]/400`000000okK10?nf`@0F0?nf`@040000003o]/40okK10?nf`@?ooooo00D00000oooooooooooo
oooo00000003ooooo`0400000?oooooooooo000000;ooooo00<00000ooooooooool00_ooool7o`00
00Gooooo00@00000ooooooooool000000oooool01000003oooooooooo`000003ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00coooooAP3o]/4?ooooo`03o`00oooooooo
oooo01Kooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0
000000?ooooo00D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo00oooooo00D0
0000oooooooooooooooo00000004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
1Oooool20?nf`@<000001@3o]/43000000H0okK100<000000?nf`@3o]/404P3o]/43000001P0okK1
00<000000?nf`@3o]/401?ooool01@00003oooooooooooooool0000000?ooooo00@00000oooooooo
ool000000_ooool01000003oooooooooooooool2o`0000Oooooo0ol00003ooooo`0400000?oooooo
oooo000000?ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`0=oooood@0okK14?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00cooooo00?o0000ooooooooool03oooool00`00003ooooo00000003ooooo`0300000?oo
oooooooo00;ooooo00D00000oooooooooooooooo0000000@ooooo`0300000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo
103o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/40
3`3o]/400ol0000000000?nf`@0I0?nf`@030000003o]/40okK100Cooooo00?o0000ooooooooool0
0_ooool01000003oooooooooo`000002ooooo`0500000?ooooooooooooooo`0000000_ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooo`0000000_ooool01000003oooooooooo`00
0002ooooo`0500000?ooooooooooooooo`0000000oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03ooo
oom00?nf`A7ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00oooooo00<00000ooooo`0000000oooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00;ooooo0P00000=ooooo`8000001?ooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Gooooo00@00000o`000000000000001Oooool30?nf`@<000001@3o]/42000000D0okK1
00?o00000000003o]/40303o]/42000000T0okK10P0000000ol0000000000000000600000003o`00
00000000000000@0000000?o00000?nf`Oooool01Oooool01@00003oooooooooooooool0000000;o
oooo00Co0000oooooooooooo00000oooool01000003oooooooooool00006ooooo`Co00001?ooool0
1Ol0003oooooooooooooool0000000;ooooo00@00000ooooooooool000000_ooool01000003ooooo
ooooo`000003ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Boooooc`0okK14oooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03oooool00`00003ooooo
00000003ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`08ooooo`8000001_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Wooooo
200000030?nf`@<00000103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100T0okK1
00<000000?nf`@3o]/401P3o]/4300000180okK12?ooool01@00003oooooooooooooool0000000;o
oooo00@00000ooooooooool000000oooool01000003oooooooooool00003ooooo`?o00001?ooool2
o`0000;ooooo00Go0000oooooooooooooooo00000002ooooo`0400000?oooooooooo000000;ooooo
00@00000ooooooooool000000oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool04ooooolj0?nf`A?ooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo
00@00000ooooooooool000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00?o
oooo00<00000ooooooooool04Oooool3000000<0okK100<000000?nf`@3o]/400P3o]/400ol00000
okK10?nf`@040?nf`@030000003o]/40okK100H0okK10P0000060?nf`@<000001`3o]/44000000T0
okK12?ooool01@00003oooooooooooooool0000000;ooooo00@00000ooooooooool000000oooool0
1000003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000
0oooool01000003oooooooooo`000002ooooo`0400000?oooooooooo000000;ooooo00@00000oooo
ooooool000002_ooool000Wooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo01Oooooo=@3o]/4Eooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`0?ooooo`0500000?ooooooooooooooo`0000000oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo0`000002ooooo`<000001oooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo01Cooooo00H00000o`00003o]/40okK1o`00
000000030?nf`@030000003o]/40okK100@0okK100?o00000000003o]/40103o]/400ol00000okK1
0?nf`@050?nf`@030000003o]/40okK100<0okK100?o00000000000000000P0000040?nf`@L00000
2Oooool00ol0003oooooooooo`02ooooo`0400000?oooooooooo000000;ooooo00@00000oooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo00000_oo
ool01000003oooooooooo`000002ooooo`0400000?oooooooooo000000;ooooo00@00000oooooooo
ool000002_ooool000Wooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01[ooooo;`3o]/4Hooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`0?ooooo`0500000?ooooooooooooooo`0000000oooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00Kooooo0P00000:ooooo`0300000?oooooooooo
00Cooooo00<00000ooooooooool01Oooool>000000?ooooo00D000000?nf`@3o]/40okK100000003
0?nf`@030000003o]/40okK100D0okK11@0000070?nf`@030000003o]/40okK10080okK10P00000=
0?nf`@?ooooo10000002ooooo`<000001Oooool01000003oooooooooo`000002ooooo`0400000?oo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`00
00;ooooo00@00000ooooooooool000000_ooool01000003oooooooooo`000002ooooo`0400000?oo
oooooooo000000[ooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`0NooooobT0okK16_ooool00ol00?ooooooooooo`0;ooooo`?o00003_oo
ool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00_oo
ool01@00003oooooooooooooool0000000Gooooo00<00000ooooooooool03oooool2000000Oooooo
00<00000ooooooooool00_ooool3000000kooooo0P000002ooooo`0500000?oooooooooo0?nf`@00
00000`3o]/400`000000okK10?nf`@0?0?nf`@030000003o]/40okK10080okK100@000000?nf`@3o
]/40okK130000007ooooo`8000002?ooool01000003oooooooooo`000002ooooo`0400000?oooooo
oooo000000;ooooo00Co0000oooooooooooo00003?ooool01?l0003oooooooooool00002ooooo`04
00000?oooooooooo000000;ooooo00@00000ooooooooool000000_ooool01000003oooooooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool08_oooolS0?nf`Agooooo00?o003oooooooooool02_ooool5o`0000gooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00cooooo0P000008
ooooo`0400000?ooooooooooooooo`8000001oooool:000000;ooooo0P0000000oooool000000000
0002ooooo`04o`00003o]/40okK100000100okK100@000000?nf`@3o]/40okK10P0000020?nf`@03
o`0000000000okK100<0okK110000004ooooo`8000003_ooool01000003oooooooooo`000002oooo
o`0400000?oooooooooo000000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?oo
ooooooooo`0000;ooooo00H00000ooooooooool00000ooooo`000002ooooo`0700000?oooooooooo
ooooo`00003ooooo0000000:ooooo`002Oooool00ol0003oooooooooo`08ooooo`;o003o5oooool0
0ol00?ooooooooooo`0Voooooad0okK18?ooool00ol00?ooooooooooo`0:ooooo`Go00003Oooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`02ooooo`8000001?ooool00ol00000000000000009ooooo`8000002Oooool5
000000Kooooo0`00000:ooooo`8000000_ooool01?l0003oooooooooo`000002ooooo`0400000?oo
oooooooo000000d0okK10P0000020?nf`@8000000P3o]/4200000080okK110000004ooooo`04o`00
000000000000000000;ooooo0`00000;ooooo`0400000?oooooooooo000000;ooooo00@00000oooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo0000
0_ooool01P00003oooooooooo`00003ooooo000000;ooooo00L00000oooooooooooooooo00000?oo
ool0000000[ooooo0009ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Booooo`P0003o3ooooolG0?nf`B?ooooo00?o003oooooooooool02_ooool5
o`0000gooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool00oooool2000000Gooooo2@000009ooooo`80000000?ooooo
00000?ooool01oooool01000003oooooooooooooool:000000;ooooo0P0000001oooool00000oooo
ooooool00000ooooo`0000000oooool00`00003ooooo0?nf`@090?nf`@050000003o]/40okK10?nf
`@0000000P3o]/42000000040?nf`@0000000000000000Cooooo10000004ooooo`8000000oooool0
0`00003oooooooooo`08ooooo`0400000?oooooooooo000000;ooooo00@00000ooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00000_ooool01P00
003oooooooooo`00003ooooo000000;ooooo00L00000oooooooooooooooo00000?ooool0000000[o
oooo0009ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool04Oooool2o`00oa?ooooo
0P000?l8ooooo`80003o5_ooool40?nf`@kooooo10000?lKooooo`03o`00oooooooooooo00_ooooo
0ol0000>ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03oooool00`00003ooooo
o`000005ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool04_ooool2000000Cooooo
00<00000ooooooooool01?ooool01@00003oooooooooooooool0000000[ooooo0P000002ooooo`03
00000?ooool0000000;ooooo00<00000ooooo`0000000oooool00`00003oooooooooo`07ooooo`08
0?nf`@000000okK10?nf`Oooool00000ooooo`000002ooooo`0400000?ooooooooooooooo`@00000
1?ooool4000000;ooooo0P000002ooooo`0300000?oooooooooo00Kooooo00D00000oooooooooooo
oooo00000003ooooo`0400000?oooooooooo000000;ooooo00Co0000oooooooooooo00003?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00<00000ooooo`0000000_ooool01000003ooooooooo
o`000002ooooo`0400000?oooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo00cooooo
00?o003oooooooooool03Oooool3o`00oaCooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`0Qooooo`@0003o1?ooool20000oa[ooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`09ooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000001Oooool2000000Go
oooo0P00000>ooooo`80000000?o000000000?ooool01_ooool00`00003oooooooooo`02ooooo`05
00000?ooooooooooooooo`0000000oooool;o`00000500000?ooool00000ooooo`0000000_ooool0
0ol0003ooooo00000003ooooo`0300000?oooooooooo00Kooooo00L00000oooooooooooooooo0000
0?ooool0000000;ooooo00H00000oooooooooooo000000000?ooool8000000?ooooo00D00000oooo
ooooooooooooo`000002ooooo`0300000?l0003ooooo00Gooooo00Go0000oooooooooooooooo0000
0003ooooo`0400000?oooooooooo000000;ooooo00Co0000oooooooooooo00003?ooool01Ol0003o
oooooooooooooooo000000;ooooo00<00000ooooo`0000000_ooool01?l0003oooooooooo`000002
ooooo`0400000?oooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo00gooooo0ol00?l:
ooooo`;o003o5_ooool00ol00?ooooooooooo`0<ooooo`030000oooooooooooo01oooooo00<0003o
ooooooooool02?ooool00`000?ooooooooooo`0Gooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`0400000?oooooooooo000000Oooooo00<0
0000ooooooooool01?ooool2000000Wooooo0`00000;ooooo`0300000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04o`0000Cooooo00Co000000000?ooool0
00000_ooool01@00003ooooo00000?ooool0000000?ooooo00<00000ooooooooool01Oooool00`00
003oooooooooo`02ooooo`0300000?ooool0000000;ooooo00Co0000ooooo`00003ooooo0P000008
ooooo`8000000_ooool01000003oooooooooo`000004ooooo`0400000?ooooooooooooooo`800000
1?ooool01@00003oooooooooooooool0000000;ooooo00@00000oooooooooooo00000oooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000_ooool00`00003ooooo00000002
ooooo`0400000?oooooooooo000000;ooooo00@00000ooooooooool000002_ooool000Wooooo00?o
0000ooooooooool04?ooool:o`00oaSooooo00?o003oooooooooool03Oooool00`000?oooooooooo
o`0Looooo`03o`00o`000?oooooo00_ooooo00<0003oooooooooool05_ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03oooool01@00003ooooooooo
ooooool0000000Oooooo00<00000ooooooooool01Oooool9000000kooooo00<00000ooooooooool0
0_ooool01000003oooooooooo`000002ooooo`04o`000?oooooo0000o`0000Cooooo0_l00002oooo
o`05o`000?ooool00000ooooo`0000000_ooool2000000;ooooo00D00000oooooooooooooooo0000
0005ooooo`0300000?oooooooooo00;ooooo00<00000ooooo`0000000_ooool01@00003ooooo0000
0?ooool0000000;ooooo1ol00003ooooo`0600000?oooooooooo00000?ooool000001Oooool00`00
003ooooo00000006ooooo`0500000?ooooooooooooooo`0000000_ooool01000003oooooooooool0
0004ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002ooooo`040000
0?oooooooooo000000;ooooo00@00000ooooooooool000000_ooool01000003oooooooooo`00000:
ooooo`002Oooool00ol0003oooooooooo`0booooo`030000oooooooooooo00gooooo00<0003ooooo
ooooool07?ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo01Gooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00@00000oooo
ooooool000000_ooool01P00003oooooooooool0003oooooo`0000Sooooo00ko0000oooooooooooo
0000ooooool0003ooooo00000?ooool00000ooooo`00003ooooo000000Cooooo00D00000oooooooo
oooooooo00000004ooooo`0:00000?oooooooooo00000?ooool00000ooooo`00003ooooo000000;o
oooo00?o0000ooooooooool01Oooool3o`000007ooooool0003oooooooooo`00003ooooo00000005
ooooo`0300000?oooooooooo00Kooooo00D00000oooooooooooooooo00000002ooooo`0400000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00Ko0000ooooooooool0
0000ooooo`000002ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000002_oo
ool000Wooooo00?o0000ooooooooool0<Oooool00`000?ooooooooooo`0?ooooo`030000oooooooo
oooo01[ooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo00?ooooo0P000006ooooo`8000007?ooool01000003oooooooooo`000002ooooo`0300000?oo
oooo000000;ooooo00Co0000oooooooooooooooo1?l00002ooooo`;o000000Goooooo`000?ooool0
0000ooooo`0200000005ooooo`00003oooooooooo`0000001?ooool3000000Cooooo00X00000oooo
ooooool00000ooooo`00003oooooo`000?ooool000000_ooool00ol0003oooooo`000007o`0000;o
oooo00?o0000ooooo`0000000_ooool00`00003ooooo0000000=ooooo`0500000?oooooooooooooo
o`0000000_ooool01000003oooooooooool00005ooooo`Ko00001?ooool2o`0000;ooooo00Co0000
ooooooooool000000_ooool01000003oooooooooo`000003ooooo`0400000?oooooooooo000000[o
oooo0009ooooo`03o`000?oooooooooo033ooooo00<0003oooooooooool04?ooool00`000?oooooo
ooooo`0Iooooo`030000oooooooooooo013ooooo00<0003oooooooooool05?ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`05ooooo`0300000?oooooooooo00Gooooo0`00000=ooooo`L000001Oooool01000003ooooo
ooooo`000002ooooo`0300000?l0003ooooo00;ooooo00Co0000oooooooooooo00001?ooool02Ol0
003oooooooooool0003oooooo`000?ooool00000ooooo`0200000005ooooo`00003oooooooooo`00
00002oooool03P00003oooooooooo`00003ooooo00000?ooool00000ooooo`00003oooooo`000?oo
oooo00002?ooool01Ol0003oooooo`000?ooool0000000;ooooo00<00000ooooo`0000001oooool2
000000Cooooo00D00000oooooooooooooooo00000003ooooo`0400000?ooooooooooo`0000gooooo
00Co0000oooooooooooooooo0P000002ooooo`0400000?oooooooooo000000;ooooo00D00000oooo
oooooooooooo00000002ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02oooooo00<0003oooooooooool04_ooool00`000?ooooooooooo`0Gooooo`030000oooooooooooo
01;ooooo00<0003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00_ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`06ooooo`<000001oooool=0000
00Oooooo00<00000ooooooooool00_ooool02000003oooooooooo`00003ooooo00000?oooooo0000
0_ooool01?l0003oooooooooool00006ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02
00000004ooooo`00003ooooo000000;ooooo00<00000ooooooooool01oooool03P00003ooooooooo
o`00003ooooo00000?ooool00000ooooo`00003oooooo`000?oooooo00001?ooool4o`0000;ooooo
00Go0000ooooool0003ooooo00000002ooooo`0300000?oooooo000000Gooooo00@00000oooooooo
ool000001?ooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00ol00009
ooooo`05o`000?ooooooooooooooo`0000000oooool01000003oooooooooo`000002ooooo`050000
0?ooooooooooooooo`0000000oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo00Oooooo0ol00008ooooo`030000oooooooooooo01Oooooo
00<0003oooooooooool04_ooool00`000?ooooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool03?ooool00ol0003oooooooooo`0?ooooo`0400000?oooooo0000000000So
oooo00?o0000ooooooooool06Oooool01Ol0003oooooooooooooool0000000;ooooo00L00000oooo
o`00003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool01_ooool01_l0003oooooo`00
0?oooooo0000ooooo`80000000Cooooo00000?ooool000000_ooool00`00003oooooooooo`07oooo
o`0=00000?oooooooooo00000?ooool00000ooooo`00003ooooo00000?l0003oooooo`000002oooo
o`?o00001?ooool02_l0003oooooooooool0003oooooo`000?ooool00000ooooo`000002ooooo`05
00000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`02ooooo`0500000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`Co000000?oooooo`000?l000000_l00003
ooooo`05o`000?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0000000;ooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0_ooooo`030000oooooooooooo00Kooooo1Ol00007ooooo`030000oooooooooooo01Oooooo00<0
003oooooooooool01_ooool3o`0000Wooooo00<0003oooooooooool05Oooool2o`00oaCooooo0_l0
0?l?ooooo`03o`000?oooooooooo00oooooo00@00000ooooooooool000002Oooool3000001Wooooo
00@00000oooooooooooo00000_ooool01`00003ooooo00000?oooooo0000ooooool000000_ooool0
0ol0003oooooooooo`06ooooo`06o`000?oooooo0000ooooool0003ooooo0P0000001?ooool00000
ooooo`000002ooooo`0300000?oooooooooo00Oooooo00d00000ooooooooool00000ooooo`00003o
oooo00000?ooool00000o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool02_l0003o
ooooooooool0003oooooo`000?ooool00000ooooo`000002ooooo`0500000?ooooooooooooooo`00
00001?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D00000oooooooo
oooooooo00000007ooooo`03o`000?oooooooooo00?ooooo0P000004ooooo`0400000?oooooooooo
000000?ooooo00@00000ooooooooool000001?ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0_ooooo`030000oooooooooooo00Kooooo1Ol00007ooooo`030000oooooooo
oooo01Kooooo00<0003oooooooooool01_ooool5o`0000Sooooo00<0003oooooooooool05oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool03oooool0
1@00003oooooooooooooool0000000_ooooo0`00000Fooooo`0400000?oooooooooo000000;ooooo
00L00000ooooo`00003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool01_ooool01_l0
003oooooo`000?oooooo0000ooooo`80000000Cooooo00000?ooool000000_ooool00`00003ooooo
ooooo`07ooooo`0=00000?oooooooooo00000?ooool00000ooooo`00003ooooo00000?l0003ooooo
o`000002ooooo`03o`000?oooooooooo00Gooooo00Wo0000ooooool0003oooooo`000?ooool00000
ooooo`0000000_ooool01@00003oooooooooooooool0000000Gooooo0P000003ooooo`0300000?oo
oooooooo00;ooooo00@00000oooooooooooooooo0`000009ooooo`0300000?oooooooooo00;ooooo
0P000002ooooo`0500000?ooooooooooooooo`0000000_ooool00`00003oooooooooo`03ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02oooooo00<0003oooooooooool0
1_ooool5o`0000Oooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`06ooooo`Go0000
2?ooool00`000?ooooooooooo`0Hooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo0`00000;oooooa800000
1Oooool01000003oooooooooo`000002ooooo`0400000?ooool00000o`0000;ooooo00Co0000oooo
oooooooo00001_ooool01ol0003oooooooooool0003oooooo`000?ooool00P0000001_ooool00000
ooooo`00003ooooo000000[ooooo00D00000ooooooooool00000ooooo`0200000008ooooo`00003o
ooooo`000?oooooo0000ooooool00008ooooo`09o`000?oooooo0000ooooool0003ooooo00000?oo
ool0000000;ooooo00@00000ooooooooool000002?ooool01@00003oooooooooooooool0000000Co
oooo00<00000ooooooooool00oooool4000000;ooooo0`000004ooooo`0300000?oooooooooo00;o
oooo00@00000ooooooooool000000oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo02oooooo00<0003oooooooooool01oooool3o`0000So
oooo00<0003oooooooooool05_ooool00`000?ooooooooooo`06ooooo`Go00002?ooool00`000?oo
ooooooooo`0Iooooo`;o003o3Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`8000001?ooool03000003o
ooooooooo`00003ooooo00000?ooool00000ooooool0003oooooo`0000;ooooo0_l00005ooooo`07
o`000?ooooooooooo`000?oooooo0000ooooo`0200000006ooooo`00003ooooo00000?ooool00000
2_ooool01@00003oooooooooo`00003ooooo0080000000Sooooo00000?oooooo0000ooooool0003o
ooooo`0000Oooooo0_l000002?oooooo0000ooooool0003ooooo00000?ooool000000_ooool01?l0
003oooooooooo`000009ooooo`04o`000?ooooooooooooooo`8000000oooool00ol000000000oooo
o`06ooooo`8000001?ooool200000004o`000?ooooooooooooooo`8000000_ooool00`00003ooooo
ooooo`02ooooo`0700000?ooooooooooooooo`00003ooooo0000000:ooooo`002Oooool00ol0003o
ooooooooo`0_ooooo`030000oooooooooooo01;ooooo00<0003oooooooooool05_ooool00`000?oo
ooooooooo`07ooooo`?o00002Oooool00`000?ooooooooooo`0Kooooo`?o003o1oooool3o`00oaCo
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`06ooooo`<000006oooool01@00003o
ooooooooooooool0000000;ooooo00T00000ooooo`00003ooooo00000?oooooo0000ooooool00000
1?ooool3o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0003ooooo0P0000001_ooool0
0000ooooo`00003ooooo000000[ooooo00D00000ooooooooool00000ooooo`0200000006ooooo`00
003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`03ooooo`0=o`000?oooooooooooooo
ool0003oooooo`000?ooool00000ooooo`00003ooooo00000003ooooo`0300000?oooooooooo00So
oooo0P000003ooooo`8000000oooool3000000Wooooo00<00000ooooooooool00_ooool2000000?o
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`0300000?ooool0000000[o
oooo0009ooooo`03o`000?oooooooooo033ooooo00<0003oooooooooool04?ooool00`000?oooooo
ooooo`0Hooooo`030000oooooooooooo01;ooooo00<0003oooooooooool07_ooool7o`00oaOooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`09ooooo`@000006?ooool01@00003ooooo
ooooooooool0000000;ooooo00P00000ooooo`00003ooooo00000?oooooo0000ooooo`?o00001?oo
ool00ol0003oooooooooo`02o`000003ooooool0003ooooo0080000000Kooooo00000?ooool00000
ooooo`00000<ooooo`0:00000?ooool00000ooooo`00003ooooo00000?ooool00000ooooo`;o0000
0oooool3o`000003ooooool0003ooooo00;ooooo00Oo0000ooooool0003ooooo00000?ooool00000
00;ooooo00@00000ooooooooool000003Oooool00`00003oooooooooo`02ooooo`8000001?ooool9
000000?ooooo0P000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool0
1000003oooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0aooooo`030000oooooooo
oooo00oooooo00<0003oooooooooool06?ooool00`000?ooooooooooo`0Aooooo`030000oooooooo
oooo03gooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0=ooooo`<000005_ooool0
1`00003oooooooooool000000000ooooo`0000000_ooool200000003o`000?oooooo000000?ooooo
00?o0000ooooooooool00_ooool2o`0000;ooooo00_o0000ooooo`00003ooooo00000?oooooo0000
ooooo`00003ooooo0000000<ooooo`0<00000?ooool00000ooooo`00003ooooo00000?oooooo0000
ooooool0003ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Wo0000ooooool0003ooooo
00000?oooooo0000ooooo`0000000_ooool00`00003oooooooooo`0=ooooo`8000001?ooool00`00
003oooooooooo`0;ooooo`8000001Oooool01?l0003oooooooooooooool2000000Cooooo00D00000
oooooooooooooooo0000000:ooooo`002Oooool00ol0003oooooooooo`0aooooo`030000oooooooo
oooo00oooooo00<0003oooooooooool06?ooool00`000?ooooooooooo`0Aooooo`030000oooooooo
oooo03gooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0@ooooo`h000002?ooool0
1@00003oooooooooooooool0000000;ooooo00?o0000ooooo`0000000_ooool01000003oooooo`00
0?l00002ooooo`Co00000_ooool2o`00000;ooooo`00003oooooooooo`00003ooooo00000?ooool0
0000ooooo`0000001Oooool2000000Gooooo00/00000ooooo`00003ooooo00000?ooool00000oooo
o`00003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`07o`000?ooool0
0000ooooo`00003ooooo00000002ooooo`0300000?oooooooooo00;ooooo1`000006ooooo`030000
0?oooooooooo00;ooooo00?o00000000000000002Oooool00`00003oooooooooo`04ooooo`050000
0?ooooooooooooooo`0000001Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03;ooooo0P000?l=ooooo`80003o7?ooool00`000?oooooo
ooooo`0@ooooo`030000oooooooooooo03gooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`0Nooooo`@000001Oooool01@00003oooooooooooooool0000000;ooooo00<00000ooooo`00
00000_ooool00`00003oooooooooo`02o`0000Cooooo0_l00002ooooo`0:00000?oooooooooo0000
0?ooool00000ooooo`00003ooooo000000Gooooo00@00000ooooooooool000001?ooool02`00003o
ooooooooo`00003ooooo00000?ooool00000ooooo`00003ooooo00;o00000_ooool3o`000003oooo
ool0003o000000?ooooo00?o0000ooooo`0000000_ooool2000000;ooooo00<00000ooooooooool0
0_ooool00`00003oooooooooo`05ooooo`8000001Oooool00`00003oooooooooo`04ooooo`T00000
1Oooool2000000?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Cooooo0P000?l9ooooo`80003o7_oo
ool00`000?ooooooooooo`0?ooooo`030000oooooooooooo03kooooo00?o0000ooooooooool03ooo
ool01000003ooooo00000000000Qooooo`8000001?ooool01@00003oooooooooooooool0000000;o
oooo0`000002ooooo`8000000_ooool4o`0000;ooooo0P000002ooooo`03o`000?ooool0000000;o
oooo00<00000ooooool000001?ooool00`00003oooooooooo`02ooooo`0500000?oooooooooooooo
ool000000_ooool00`00003ooooo00000002ooooo`0300000?ooool0000000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00D00000oooo
o`00003ooooo00000004ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool00oooool3
000000oooooo0P000004ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0fooooo`030000oooooooooooo
00Cooooo0P000?lQooooo`030000oooooooooooo00gooooo00<0003oooooooooool0?oooool00ol0
003oooooooooo`0?ooooo`0500000?ooooooooooooooool000008_ooool2000000?ooooo0P000002
ooooo`0500000?oooooooooo00000?ooool00P000002ooooo`D0000000?ooooo0000000000000_oo
ool200000003ooooool0003ooooo008000000_ooool01@00003oooooooooooooool0000000Kooooo
00D00000oooooooooooooooo00000002ooooo`0700000?ooool00000ooooool000000000ooooo`02
00000003ooooool0003o000000;o00000_ooool3o`000003ooooo`00003ooooo0080000000Gooooo
00000?ooooooooooo`000002ooooo`0300000?l0003ooooo00_ooooo00<00000o`00000000001Ooo
ool3000000Wooooo00<00000o`00000000001Oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=oooool6
0000obCooooo0`000?l:ooooo`80003o@_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo00;ooooo0`00000Qooooo`0300000?oooooooooo00;ooooo00L00000ooooooooool00000oooo
ool00000000000;ooooo0`000004ooooo`0300000?ooool000000080000000Gooooo00000000003o
oooo00000003ooooo`0500000?ooooooooooooooo`0000001oooool01@00003oooooooooooooool0
000000;ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`02000000?ooooo0_l0
0003ooooo`<000000_ooool01000003oooooooooo`000002ooooo`0300000?oooooooooo00oooooo
0P000006ooooo`T000001oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0I?ooool20000o`Gooooo0`00
0?m4ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool01Oooool3000001oooooo00<0
0000ooooooooool00_ooool01000003oooooooooo`000002ooooo`8000000oooool6000000?ooooo
00@00000ooooooooool000000oooool01@00003oooooooooooooool0000000Wooooo00D00000oooo
oooooooooooo00000002ooooo`0400000?oooooooooo000000;ooooo0P000002ooooo`T000000ooo
ool01000003oooooooooo`000002ooooo`0300000?oooooooooo01;ooooo0`00000@ooooo`<00000
1_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06Gooooo00?o003o0000o`000?l00`000?m7ooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool02?ooool2000001kooooo00<00000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`8000002?ooool2000000;ooooo00D00000ooooooooooooooooo`000003ooooo`03
00000?oooooooooo00Wooooo00D00000oooooooooooooooo00000002ooooo`0400000?oooooooooo
000000?ooooo00<00000ooooooooool01_ooool01Ol0003oooooooooooooool0000000;ooooo00@0
0000oooooooooooo00001_ooool00ol00000000000000004000000_ooooo00<00000ooooooooool0
2oooool00ol000000000ooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo00[ooooo1P00000Iooooo`8000000_ooool2000000;ooooo0`000002ooooo`P000000ooo
ool00`00003o0000ooooo`02000000?ooooo00<00000ooooooooool02oooool01000003ooooooooo
ooooool200000003ooooool0000000000080000000Go000000000?ooool00000o`000006000000;o
oooo0P000002ooooo`0300000?l0003ooooo008000001?ooool2000000Oooooo00@00000o`000000
000000002?ooool00ol0000000000000000:000000Kooooo10000008ooooo`0300000?ooool00000
00[ooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`0@ooooo`h000003Oooool01@00003oooooooooooooool0000000Cooooo0`000006oooo
o`@000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00gooooo00<00000oooo
ooooool00_ooool01@00003oooooooooooooool0000000;ooooo0P000005ooooo`@000000_ooool2
000000;ooooo00<00000ooooooooool00_ooool2000000gooooo0P00000Hooooo`0300000?oooooo
oooo00Wooooo00@00000ooooooooool000002_ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo01kooooo1000000:ooooo`0400000?oooooo
ooooooooo`<000001?ooool6000000Cooooo0P000004ooooo`0300000?oooooooooo00Gooooo1000
0006ooooo`0300000?oooooooooo00;ooooo00@00000oooooooooooooooo0P000002ooooo`D00000
1?ooool2000000;ooooo0P000004ooooo`0300000?oooooooooo00oooooo0P00000Dooooo`800000
2oooool01@00003oooooooooooooool0000000[ooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`0Rooooo`<000002?ooool00ol0003ooooo
ooooo`03ooooo`8000002_ooool2000000Cooooo0_l00006ooooo`8000001?ooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`06ooooo`8000000oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo01;ooooo
00<00000o`000?ooool03oooool2000000cooooo00<00000ooooooooool00_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooooonfo`00017ooooo]P00000:
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0380952 0.518711 0.000741294 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07393 -24 -4.5 ]
[-0.0125 .07393 0 4.5 ]
[-0.0125 .22219 -24 -4.5 ]
[-0.0125 .22219 0 4.5 ]
[-0.0125 .37045 -24 -4.5 ]
[-0.0125 .37045 0 4.5 ]
[-0.0125 .51871 -6 -4.5 ]
[-0.0125 .51871 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .07393 m
1 .07393 L
s
0 .22219 m
1 .22219 L
s
0 .37045 m
1 .37045 L
s
0 .51871 m
1 .51871 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(5)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(10)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(15)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(20)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(25)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07393 m
.00625 .07393 L
s
[(-600)] -0.0125 .07393 1 0 Mshowa
0 .22219 m
.00625 .22219 L
s
[(-400)] -0.0125 .22219 1 0 Mshowa
0 .37045 m
.00625 .37045 L
s
[(-200)] -0.0125 .37045 1 0 Mshowa
0 .51871 m
.00625 .51871 L
s
[(0)] -0.0125 .51871 1 0 Mshowa
.125 Mabswid
0 .111 m
.00375 .111 L
s
0 .14806 m
.00375 .14806 L
s
0 .18513 m
.00375 .18513 L
s
0 .25926 m
.00375 .25926 L
s
0 .29632 m
.00375 .29632 L
s
0 .33339 m
.00375 .33339 L
s
0 .40752 m
.00375 .40752 L
s
0 .44458 m
.00375 .44458 L
s
0 .48165 m
.00375 .48165 L
s
0 .03687 m
.00375 .03687 L
s
0 .55578 m
.00375 .55578 L
s
0 .59284 m
.00375 .59284 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07393 m
1 .07393 L
s
.99375 .22219 m
1 .22219 L
s
.99375 .37045 m
1 .37045 L
s
.99375 .51871 m
1 .51871 L
s
.125 Mabswid
.99625 .111 m
1 .111 L
s
.99625 .14806 m
1 .14806 L
s
.99625 .18513 m
1 .18513 L
s
.99625 .25926 m
1 .25926 L
s
.99625 .29632 m
1 .29632 L
s
.99625 .33339 m
1 .33339 L
s
.99625 .40752 m
1 .40752 L
s
.99625 .44458 m
1 .44458 L
s
.99625 .48165 m
1 .48165 L
s
.99625 .03687 m
1 .03687 L
s
.99625 .55578 m
1 .55578 L
s
.99625 .59284 m
1 .59284 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.0619 .33063 L
.1 .3789 L
.1381 .4145 L
.17619 .44679 L
.21429 .46864 L
.25238 .48132 L
.29048 .48941 L
.32857 .49593 L
.36667 .50219 L
.40476 .50925 L
.44286 .51882 L
.48095 .53446 L
.51905 .56277 L
.55714 .58497 L
.59524 .58894 L
.63333 .59186 L
.67143 .59425 L
.70952 .59629 L
.74762 .59801 L
.78571 .59945 L
.82381 .60062 L
.8619 .60155 L
.9 .60229 L
.9381 .60287 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.0619 .33063 Mdot
.1 .3789 Mdot
.1381 .4145 Mdot
.17619 .44679 Mdot
.21429 .46864 Mdot
.25238 .48132 Mdot
.29048 .48941 Mdot
.32857 .49593 Mdot
.36667 .50219 Mdot
.40476 .50925 Mdot
.44286 .51882 Mdot
.48095 .53446 Mdot
.51905 .56277 Mdot
.55714 .58497 Mdot
.59524 .58894 Mdot
.63333 .59186 Mdot
.67143 .59425 Mdot
.70952 .59629 Mdot
.74762 .59801 Mdot
.78571 .59945 Mdot
.82381 .60062 Mdot
.8619 .60155 Mdot
.9 .60229 Mdot
.9381 .60287 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002kooooo0ol0000/ooooo`?o0000
1?ooool2o`0002Sooooo0ol00003ooooo`?o0000:?ooool5o`0000?ooooo0_l0000Wooooo`Go0000
0_ooool3o`0000Cooooo000Oooooo`04o`000?ooooooooooo`0002cooooo00Go0000oooooooooooo
ooooo`00000/ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002Oooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo007ooooo000Oooooo`04o`000?ooooooooooo`00033ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo007ooooo000O
ooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Xooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool001oooooo00Co0000oooooooooooo
0000;?ooool4o`0002gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xoooo
o`04o`000?ooooooooooooooo`Co0000:?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00009_ooool01_l0003ooooooooooooooooo0000ooooo`Co00001?ooool001oo
oooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool01?l0
003oooooooooool0000Wooooo`;o00000oooool00ol0003oooooooooo`0Yooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Vooooo`07o`000?ooooooooooooooool0
003oooooo`000007ooooo`008?ooool2o`0002gooooo1Ol0000/ooooo`03o`000?oooooooooo00?o
oooo0_l0000Yooooo`04o`000?ooooooooooooooo`Go0000:?ooool3o`0000Cooooo0_l0000Xoooo
o`?o00000_ooool5o`0000?ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo000Koooooooo00001Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03
00000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo0ooo000_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
0oooool1o`00007ooooo000Kooooo`04o`000?ooooooooooooooo`Goo`00;_ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0dooooo`7o00000Oooool001_ooooo00Co0000oooooooooooooooo1Ooo000^ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo03Cooooo0Ol00001ooooo`006oooool01?l0003oooooooooooooool5ool002kooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo0ooo
000_ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0doooo
o`7o00000Oooool001_ooooo0_l00005ooooo`03o`000?oooooooooo02gooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0<oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0]ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0]ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02gooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0dooooo`7o00000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool000Go000000?oooooo`000?ooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool2o`0000H0001o00?o00000000O`0007l0m`0007l2o`00007ooooo0006ooooo`Co0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001oooo
o`001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=?ooool1o`00007ooooo0007ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0
001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool000Sooooo0_l00004
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^oooo
o`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02_ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0:oooool00`0007ooooooooooo`0_ooooo`030000Oooooooo
oooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool0
01_ooooo0_l00007ooooo`03o`000?oooooooooo02_ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<oooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0[ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02_ooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0d
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zoooo
o`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02[ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0:_ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo03Cooooo0Ol00001ooooo`006oooool2o`0000Sooooo00?o0000ooooooooool0:_ooool0
0`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0cooooo`;o00000Oooool001_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Zooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:_ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Yooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0doooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02Wooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:Oooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Ooo
ool001_ooooo0_l00009ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<oooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Xooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Sooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0X
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Sooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^oooo
o`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo0008ooooo`?o
00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0:?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool000Wooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00
007ooooo0005o`000003ooooool0003o000000?o00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0X
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`001_ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0000/0001o
00?o00000000O`0007l0lP0007l2o`00007ooooo0007ooooo`03o`000?oooooo000000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02ko
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool000Sooooo
0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00
007ooooo0009ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Wooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0doooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool2o`0000cooooo00?o0000ooooooooool0
9_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0cooooo`;o00000Oooool001_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Vooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Kooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0V
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Gooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^oooo
o`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o
00000Oooool001_ooooo0_l0000=ooooo`03o`000?oooooooooo02Gooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
<oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Ooo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;ooo
ool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Uooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool0
0`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Uooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Cooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00cooooo0ooo000Uooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0;ooooo`Goo`009?ooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0doooo
o`7o00000Oooool001_ooooo0_l0000<ooooo`Goo`009?ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0cooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool02oooool5ool002Cooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo0ooo000Uooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02;ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Co
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool07oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0
001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool000Kooooo1Ol00003
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0N
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01gooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo
0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l0000F0000O`04o`000?oo003oo`00ool00>H0001o0_l00001oooo
o`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo1Ooo000Jooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooo
oooo03Cooooo0Ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Gooooo
1Ooo000Jooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`001_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Gooooo1Ooo000Jooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001oooo
o`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Fooooo`?o
o`0000?o0000ooooooooool06?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02ko
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00<0
001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Dooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=?ooool1o`00007ooooo000Kooooo`;o00008?ooool01?l0003oo`00ool00?oo000Aooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03?ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Oooooo`Goo`00
4?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool07ooo
ool5ool0013ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo01oooooo1Ooo000@ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool0
0`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Pooooo`?oo`0000?oooooo`000?ooool03_ooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0doooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00_ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02_ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0:?ooool01?l0003oo`00ool00?oo0008ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo03Cooooo0Ol00001ooooo`006oooool2o`0002Wooooo1Ooo0007ooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooo
oooo03?ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Xooooo`Goo`001oooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0:?ooool5ool00003
o`000?oooooooooo00Cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo02Wooooo0ooo0002ooooo`03o`000?oooooooooo00?ooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02oooooo0_l00003ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0aooooo`;o00000ooo000`
ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0d
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0<_ooool5ool002oooooo00<0001ooooo
ooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0booooo`Goo`00;oooool00`0007ooooooooooo`0^ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo03;ooooo1Ooo0003o`0000?ooooo0ooo000Vooooo`030000Oooooooooooo02kooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0<oooool3ool000Cooooo0_l00005ool002Gooooo00<0001oooooooooool0;_oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool2
o`0003Gooooo00<0001oooooooooool01Oooool5ool00003o`000?oooooooooo00?ooooo0ooo000L
ooooo`030000Oooooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0c
ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0=?ooool00`0007ooooooooooo`05oooo
o`Goo`0000?oooooo`000?l000000_l00005ool001_ooooo00<0001oooooooooool0;_ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0dooooo`030000Oooooooooooo00Kooooo0ooo0006ooooo`Goo`0000?o0000oooooooo
ool00oooool3ool001;ooooo00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0dooooo`030000
Oooooooooooo00oooooo1Ooo00000ooooooo0000o`000002o`0000Goo`001_ooool3ool000Sooooo
00<0001oooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0dooooo`030000Oooooooooooo013ooooo0ooo
0006ooooo`Goo`000ol00002ooooo`Goo`001oooool00`0007ooooooooooo`0^ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo03Cooooo00<0001oooooooooool06Oooool5ool000?ooooo0_l00005ool00003o`000?oooooo
oooo00?ooooo0ooo000_ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo03Cooooo00<0001oooooooooool06_ooool3ool0
00Kooooo1Ooo00000ooooooo0000o`000002o`0000Goo`00;_ooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo03Cooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000oooooooo
ool0=?ooool00`0007ooooooooooo`0Tooooo`?oo`001_ooool5ool002kooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0dooooo`030000Oooooooooooo02gooooo1Ooo0003o`0000?o
oooo0ooo000Uooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool00`0007oo
ooooooooo`0^ooooo`?oo`001?ooool2o`0000Goo`009?ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03Cooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`;o
0000K`0007l5ool008`0001o0_l00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03Cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`05ooooo`Go
o`000_l0000Rooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=?ooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo00Kooooo0ooo0003ooooo`;o00000_ooool3ool001_o
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001Cooooo
0_l00005ooooo`03o`000?oooooooooo03Cooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0>ooooo`03o`000?oo003oo`0000?oo`006_ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo03Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0dooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool03oooool5ool001[ooooo00<0001oooooooooool0;ooo
ool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0=?ooool0
0`0007ooooooooooo`0_ooooo`030000Oooooooooooo00oooooo1Ooo000Jooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
03Cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0@ooooo`?oo`0000?oooooo`00
0?l000006?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0dooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool05_ooool00ol0003oooooooooo`0Eooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo03Cooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo0_l0000eooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool06?ooool01?l0003oo`00ool00?oo000Booooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0<oooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo03Cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0Hooooo`Goo`004Ooo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0dooooo`030000Oooooooooooo02oooooo00<0001oooooooooool06?ooool5
ool0017ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0=?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
01Sooooo1Ooo00000ol0003oooooooooo`0>ooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo03Cooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0Iooooo`?oo`000_ooool2o`0000kooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
=?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo023ooooo00?o0000ooooooooool0
2oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0dooooo`030000Oooooooooooo02oooooo00<0001oooooooooool08Ooo
ool2o`0000?oo`002?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0dooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool08_ooool5ool000Kooooo0ooo000`ooooo`030000Oooooooooooo03Cooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0dooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool08_ooool5ool000?o00000_ooool5ool000Kooooo0ooo0007ooooo`?oo`007?ooool00`00
07ooooooooooo`0dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0=?ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo02;ooooo1Ooo0003ooooo`;o00001Ooo0003o`0000;o
oooo1Ooo0005ooooo`Goo`001_ooool3ool000Oooooo0ooo0008ooooo`030000Oooooooooooo03Co
oooo0Ol00001ooooo`006oooool2o`0003Gooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0Sooooo`?oo`001_ooool5ool000?ooooo0_l00005ool000Go00001Ooo0003o`0000;ooooo
1Ooo0005ooooo`Goo`001_ooool3ool000Oooooo0ooo0006ooooo`?oo`001oooool3ool001Oooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`0dooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0;Oooool3ool000Kooooo1Ooo0005ooooo`Goo`000oooool2o`0000Goo`001Ol0
0005ool000?o00000_ooool5ool000Gooooo1Ooo0004ooooo`Goo`001Oooool5ool000Kooooo0ooo
0007ooooo`?oo`001?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo03Cooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0^ooooo`030000Oooooooooooo00Kooooo0ooo0007
ooooo`?oo`001_ooool5ool000Gooooo1Ooo0003ooooo`;o00001Ooo0005o`0000Goo`001?l00005
ool000Go00001Ooo0005o`0000Goo`000ol00002ooooo`Goo`000oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo03Cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0^oooo
o`030000Oooooooooooo01[ooooo0ooo0007ooooo`?oo`001_ooool5ool000Gooooo1Ooo0004oooo
o`Goo`001Oooool5ool000Gooooo1Ooo0003ooooo`;o00001Ooo0003ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0=?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02ko
oooo00<0001oooooooooool0;_ooool3ool000Oooooo0ooo0006ooooo`?oo`001oooool3ool000Ko
oooo1Ooo0005ooooo`Goo`000oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
0ooo0007ooooo`?oo`001?ooool1o`00007ooooo000Koooooooo00001Ol00001ooooo`00oooooolQ
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.37982, -774.365, \
0.101107, 5.19589}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(scalar2\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #4: blue class, full covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes full covariance matrices", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 9;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[data2, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data2, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.25`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.27869 .98077 m
.27229 .96154 L
.26923 .95116 L
.26697 .94231 L
.26269 .92308 L
.2593 .90385 L
.25682 .88462 L
.25524 .86538 L
.25455 .84615 L
.25472 .82692 L
.25574 .80769 L
.25754 .78846 L
.26008 .76923 L
.26328 .75 L
.26703 .73077 L
.26923 .72052 L
.27123 .71154 L
.27567 .69231 L
.2801 .67308 L
.28425 .65385 L
.28786 .63462 L
.28846 .6313 L
.2907 .61538 L
.29269 .59615 L
.29387 .57692 L
.2944 .55769 L
.29449 .53846 L
.29432 .51923 L
.29404 .5 L
.29372 .48077 L
.2934 .46154 L
.29309 .44231 L
.29281 .42308 L
.29257 .40385 L
.29237 .38462 L
.29224 .36538 L
.29222 .34615 L
.29236 .32692 L
.29269 .30769 L
.29327 .28846 L
.29416 .26923 L
.29541 .25 L
.29708 .23077 L
.29922 .21154 L
.30189 .19231 L
.30514 .17308 L
.30769 .16007 L
.30903 .15385 L
.31362 .13462 L
.31896 .11538 L
.32512 .09615 L
.32692 .09099 L
.33218 .07692 L
.3402 .05769 L
.34615 .0448 L
.34927 .03846 L
.3595 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.27869 .98077 m
.27229 .96154 L
.26923 .95116 L
.26697 .94231 L
.26269 .92308 L
.2593 .90385 L
.25682 .88462 L
.25524 .86538 L
.25455 .84615 L
.25472 .82692 L
.25574 .80769 L
.25754 .78846 L
.26008 .76923 L
.26328 .75 L
.26703 .73077 L
.26923 .72052 L
.27123 .71154 L
.27567 .69231 L
.2801 .67308 L
.28425 .65385 L
.28786 .63462 L
.28846 .6313 L
.2907 .61538 L
.29269 .59615 L
.29387 .57692 L
.2944 .55769 L
.29449 .53846 L
.29432 .51923 L
.29404 .5 L
.29372 .48077 L
.2934 .46154 L
.29309 .44231 L
.29281 .42308 L
.29257 .40385 L
.29237 .38462 L
.29224 .36538 L
.29222 .34615 L
.29236 .32692 L
.29269 .30769 L
.29327 .28846 L
.29416 .26923 L
.29541 .25 L
.29708 .23077 L
.29922 .21154 L
.30189 .19231 L
.30514 .17308 L
.30769 .16007 L
.30903 .15385 L
.31362 .13462 L
.31896 .11538 L
Mistroke
.32512 .09615 L
.32692 .09099 L
.33218 .07692 L
.3402 .05769 L
.34615 .0448 L
.34927 .03846 L
.3595 .01923 L
Mfstroke
.2 g
.79078 .98077 m
.79766 .96154 L
.80337 .94231 L
.80769 .92427 L
.80793 .92308 L
.8113 .90385 L
.81358 .88462 L
.81475 .86538 L
.81475 .84615 L
.81347 .82692 L
.8108 .80769 L
.80769 .79284 L
.80657 .78846 L
.80061 .76923 L
.79266 .75 L
.78846 .74156 L
.78242 .73077 L
.76947 .71154 L
.76923 .71122 L
.75321 .69231 L
.75 .68901 L
.73253 .67308 L
.73077 .67166 L
.71154 .65786 L
.7051 .65385 L
.69231 .64691 L
.67308 .63826 L
.66323 .63462 L
.65385 .63179 L
.63462 .62724 L
.61538 .62432 L
.59615 .62293 L
.57692 .623 L
.55769 .62446 L
.53846 .62725 L
.51923 .6313 L
.50647 .63462 L
.5 .63674 L
.48077 .64382 L
.46154 .65232 L
.45839 .65385 L
.44231 .66279 L
.42611 .67308 L
.42308 .67524 L
.40385 .69033 L
.40155 .69231 L
.38462 .70872 L
.38198 .71154 L
.36605 .73077 L
.36538 .73167 L
.35305 .75 L
.34615 .76198 L
.34242 .76923 L
.33389 .78846 L
.32715 .80769 L
.32692 .80841 L
.32215 .82692 L
.31867 .84615 L
.31663 .86538 L
.31597 .88462 L
.31666 .90385 L
.31866 .92308 L
.32197 .94231 L
.32657 .96154 L
.32692 .96276 L
.33266 .98077 L
F
0 g
.79078 .98077 m
.79766 .96154 L
.80337 .94231 L
.80769 .92427 L
.80793 .92308 L
.8113 .90385 L
.81358 .88462 L
.81475 .86538 L
.81475 .84615 L
.81347 .82692 L
.8108 .80769 L
.80769 .79284 L
.80657 .78846 L
.80061 .76923 L
.79266 .75 L
.78846 .74156 L
.78242 .73077 L
.76947 .71154 L
.76923 .71122 L
.75321 .69231 L
.75 .68901 L
.73253 .67308 L
.73077 .67166 L
.71154 .65786 L
.7051 .65385 L
.69231 .64691 L
.67308 .63826 L
.66323 .63462 L
.65385 .63179 L
.63462 .62724 L
.61538 .62432 L
.59615 .62293 L
.57692 .623 L
.55769 .62446 L
.53846 .62725 L
.51923 .6313 L
.50647 .63462 L
.5 .63674 L
.48077 .64382 L
.46154 .65232 L
.45839 .65385 L
.44231 .66279 L
.42611 .67308 L
.42308 .67524 L
.40385 .69033 L
.40155 .69231 L
.38462 .70872 L
.38198 .71154 L
.36605 .73077 L
.36538 .73167 L
Mistroke
.35305 .75 L
.34615 .76198 L
.34242 .76923 L
.33389 .78846 L
.32715 .80769 L
.32692 .80841 L
.32215 .82692 L
.31867 .84615 L
.31663 .86538 L
.31597 .88462 L
.31666 .90385 L
.31866 .92308 L
.32197 .94231 L
.32657 .96154 L
.32692 .96276 L
.33266 .98077 L
Mfstroke
.3 g
.73692 .98077 m
.74184 .96154 L
.74504 .94231 L
.74659 .92308 L
.74654 .90385 L
.7449 .88462 L
.74167 .86538 L
.73679 .84615 L
.73077 .82844 L
.73017 .82692 L
.72148 .80769 L
.71154 .78994 L
.7106 .78846 L
.69693 .76923 L
.69231 .76358 L
.67975 .75 L
.67308 .74366 L
.65751 .73077 L
.65385 .7281 L
.63462 .71592 L
.62637 .71154 L
.61538 .70653 L
.59615 .69954 L
.57692 .69471 L
.56125 .69231 L
.55769 .69195 L
.53846 .6912 L
.52 .69231 L
.51923 .69239 L
.5 .69563 L
.48077 .70099 L
.46154 .70862 L
.45541 .71154 L
.44231 .71891 L
.42506 .73077 L
.42308 .73234 L
.40385 .74992 L
.40377 .75 L
.3877 .76923 L
.38462 .77357 L
.37531 .78846 L
.36573 .80769 L
.36538 .80849 L
.35857 .82692 L
.35343 .84615 L
.35014 .86538 L
.34855 .88462 L
.34859 .90385 L
.35021 .92308 L
.35339 .94231 L
.35815 .96154 L
.36455 .98077 L
F
0 g
.73692 .98077 m
.74184 .96154 L
.74504 .94231 L
.74659 .92308 L
.74654 .90385 L
.7449 .88462 L
.74167 .86538 L
.73679 .84615 L
.73077 .82844 L
.73017 .82692 L
.72148 .80769 L
.71154 .78994 L
.7106 .78846 L
.69693 .76923 L
.69231 .76358 L
.67975 .75 L
.67308 .74366 L
.65751 .73077 L
.65385 .7281 L
.63462 .71592 L
.62637 .71154 L
.61538 .70653 L
.59615 .69954 L
.57692 .69471 L
.56125 .69231 L
.55769 .69195 L
.53846 .6912 L
.52 .69231 L
.51923 .69239 L
.5 .69563 L
.48077 .70099 L
.46154 .70862 L
.45541 .71154 L
.44231 .71891 L
.42506 .73077 L
.42308 .73234 L
.40385 .74992 L
.40377 .75 L
.3877 .76923 L
.38462 .77357 L
.37531 .78846 L
.36573 .80769 L
.36538 .80849 L
.35857 .82692 L
.35343 .84615 L
.35014 .86538 L
.34855 .88462 L
.34859 .90385 L
.35021 .92308 L
.35339 .94231 L
Mistroke
.35815 .96154 L
.36455 .98077 L
Mfstroke
.4 g
.70454 .98077 m
.7095 .96154 L
.71154 .95283 L
.71239 .94231 L
.71337 .92308 L
.71253 .90385 L
.71154 .89138 L
.70987 .88462 L
.70533 .86538 L
.69882 .84615 L
.69231 .8312 L
.69015 .82692 L
.67887 .80769 L
.67308 .79938 L
.6644 .78846 L
.65385 .77705 L
.64551 .76923 L
.63462 .76036 L
.61933 .75 L
.61538 .74771 L
.59615 .73833 L
.57692 .7317 L
.57441 .73077 L
.55769 .72763 L
.53846 .72594 L
.51923 .72657 L
.5 .72959 L
.49454 .73077 L
.48077 .73518 L
.46154 .74364 L
.45039 .75 L
.44231 .7555 L
.42574 .76923 L
.42308 .77183 L
.40851 .78846 L
.40385 .79488 L
.39585 .80769 L
.38652 .82692 L
.38462 .83165 L
.37988 .84615 L
.37553 .86538 L
.37321 .88462 L
.37278 .90385 L
.37417 .92308 L
.37735 .94231 L
.38237 .96154 L
.38462 .96788 L
.38936 .98077 L
F
0 g
.70454 .98077 m
.7095 .96154 L
.71154 .95283 L
.71239 .94231 L
.71337 .92308 L
.71253 .90385 L
.71154 .89138 L
.70987 .88462 L
.70533 .86538 L
.69882 .84615 L
.69231 .8312 L
.69015 .82692 L
.67887 .80769 L
.67308 .79938 L
.6644 .78846 L
.65385 .77705 L
.64551 .76923 L
.63462 .76036 L
.61933 .75 L
.61538 .74771 L
.59615 .73833 L
.57692 .7317 L
.57441 .73077 L
.55769 .72763 L
.53846 .72594 L
.51923 .72657 L
.5 .72959 L
.49454 .73077 L
.48077 .73518 L
.46154 .74364 L
.45039 .75 L
.44231 .7555 L
.42574 .76923 L
.42308 .77183 L
.40851 .78846 L
.40385 .79488 L
.39585 .80769 L
.38652 .82692 L
.38462 .83165 L
.37988 .84615 L
.37553 .86538 L
.37321 .88462 L
.37278 .90385 L
.37417 .92308 L
.37735 .94231 L
.38237 .96154 L
.38462 .96788 L
.38936 .98077 L
s
.5 g
.67901 .98077 m
.68445 .96154 L
.68749 .94231 L
.68833 .92308 L
.68708 .90385 L
.68375 .88462 L
.67826 .86538 L
.67308 .85193 L
.67041 .84615 L
.65978 .82692 L
.65385 .81814 L
.64567 .80769 L
.63462 .79581 L
.62659 .78846 L
.61538 .77974 L
.59842 .76923 L
.59615 .76807 L
.57692 .75993 L
.55769 .75481 L
.53846 .7525 L
.51923 .75293 L
.5 .75616 L
.48077 .76244 L
.46654 .76923 L
.46154 .77226 L
.44231 .78664 L
.44031 .78846 L
.42318 .80769 L
.42308 .80783 L
.41118 .82692 L
.40385 .84323 L
.40279 .84615 L
.39728 .86538 L
.39421 .88462 L
.39334 .90385 L
.39456 .92308 L
.39784 .94231 L
.40324 .96154 L
.40385 .96314 L
.41096 .98077 L
F
0 g
.67901 .98077 m
.68445 .96154 L
.68749 .94231 L
.68833 .92308 L
.68708 .90385 L
.68375 .88462 L
.67826 .86538 L
.67308 .85193 L
.67041 .84615 L
.65978 .82692 L
.65385 .81814 L
.64567 .80769 L
.63462 .79581 L
.62659 .78846 L
.61538 .77974 L
.59842 .76923 L
.59615 .76807 L
.57692 .75993 L
.55769 .75481 L
.53846 .7525 L
.51923 .75293 L
.5 .75616 L
.48077 .76244 L
.46654 .76923 L
.46154 .77226 L
.44231 .78664 L
.44031 .78846 L
.42318 .80769 L
.42308 .80783 L
.41118 .82692 L
.40385 .84323 L
.40279 .84615 L
.39728 .86538 L
.39421 .88462 L
.39334 .90385 L
.39456 .92308 L
.39784 .94231 L
.40324 .96154 L
.40385 .96314 L
.41096 .98077 L
s
.6 g
.65632 .98077 m
.6626 .96154 L
.66602 .94231 L
.66689 .92308 L
.66536 .90385 L
.66144 .88462 L
.65496 .86538 L
.65385 .86267 L
.64557 .84615 L
.63462 .82961 L
.63252 .82692 L
.61538 .80875 L
.6142 .80769 L
.59615 .79434 L
.58587 .78846 L
.57692 .78449 L
.55769 .77836 L
.53846 .77554 L
.51923 .77591 L
.5 .77956 L
.48077 .7869 L
.47761 .78846 L
.46154 .79879 L
.45115 .80769 L
.44231 .81726 L
.43506 .82692 L
.42436 .84615 L
.42308 .84892 L
.41741 .86538 L
.41346 .88462 L
.41212 .90385 L
.41318 .92308 L
.41663 .94231 L
.42254 .96154 L
.42308 .96277 L
.43124 .98077 L
F
0 g
.65632 .98077 m
.6626 .96154 L
.66602 .94231 L
.66689 .92308 L
.66536 .90385 L
.66144 .88462 L
.65496 .86538 L
.65385 .86267 L
.64557 .84615 L
.63462 .82961 L
.63252 .82692 L
.61538 .80875 L
.6142 .80769 L
.59615 .79434 L
.58587 .78846 L
.57692 .78449 L
.55769 .77836 L
.53846 .77554 L
.51923 .77591 L
.5 .77956 L
.48077 .7869 L
.47761 .78846 L
.46154 .79879 L
.45115 .80769 L
.44231 .81726 L
.43506 .82692 L
.42436 .84615 L
.42308 .84892 L
.41741 .86538 L
.41346 .88462 L
.41212 .90385 L
.41318 .92308 L
.41663 .94231 L
.42254 .96154 L
.42308 .96277 L
.43124 .98077 L
s
.7 g
.63434 .98077 m
.63462 .98021 L
.64196 .96154 L
.64602 .94231 L
.64706 .92308 L
.64529 .90385 L
.64069 .88462 L
.63462 .86863 L
.63299 .86538 L
.62151 .84615 L
.61538 .83826 L
.60464 .82692 L
.59615 .81978 L
.57692 .80776 L
.57683 .80769 L
.55769 .80041 L
.53846 .79706 L
.51923 .79748 L
.5 .80184 L
.4856 .80769 L
.48077 .81081 L
.46154 .82613 L
.46077 .82692 L
.44622 .84615 L
.44231 .85318 L
.43726 .86538 L
.43216 .88462 L
.43022 .90385 L
.43112 .92308 L
.43481 .94231 L
.44146 .96154 L
.44231 .96318 L
.45155 .98077 L
F
0 g
.63434 .98077 m
.63462 .98021 L
.64196 .96154 L
.64602 .94231 L
.64706 .92308 L
.64529 .90385 L
.64069 .88462 L
.63462 .86863 L
.63299 .86538 L
.62151 .84615 L
.61538 .83826 L
.60464 .82692 L
.59615 .81978 L
.57692 .80776 L
.57683 .80769 L
.55769 .80041 L
.53846 .79706 L
.51923 .79748 L
.5 .80184 L
.4856 .80769 L
.48077 .81081 L
.46154 .82613 L
.46077 .82692 L
.44622 .84615 L
.44231 .85318 L
.43726 .86538 L
.43216 .88462 L
.43022 .90385 L
.43112 .92308 L
.43481 .94231 L
.44146 .96154 L
.44231 .96318 L
.45155 .98077 L
s
.8 g
.61107 .98077 m
.61538 .97362 L
.62097 .96154 L
.62611 .94231 L
.62747 .92308 L
.62545 .90385 L
.61995 .88462 L
.61538 .87391 L
.61047 .86538 L
.59615 .84702 L
.59532 .84615 L
.57692 .83148 L
.56991 .82692 L
.55769 .82249 L
.53846 .81848 L
.51923 .81909 L
.5 .82463 L
.49462 .82692 L
.48077 .83638 L
.47072 .84615 L
.46154 .8591 L
.45829 .86538 L
.45141 .88462 L
.44863 .90385 L
.44933 .92308 L
.45341 .94231 L
.46122 .96154 L
.46154 .96204 L
.47365 .98077 L
F
0 g
.61107 .98077 m
.61538 .97362 L
.62097 .96154 L
.62611 .94231 L
.62747 .92308 L
.62545 .90385 L
.61995 .88462 L
.61538 .87391 L
.61047 .86538 L
.59615 .84702 L
.59532 .84615 L
.57692 .83148 L
.56991 .82692 L
.55769 .82249 L
.53846 .81848 L
.51923 .81909 L
.5 .82463 L
.49462 .82692 L
.48077 .83638 L
.47072 .84615 L
.46154 .8591 L
.45829 .86538 L
.45141 .88462 L
.44863 .90385 L
.44933 .92308 L
.45341 .94231 L
.46122 .96154 L
.46154 .96204 L
.47365 .98077 L
s
.9 g
.58177 .98077 m
.59615 .96342 L
.59725 .96154 L
.6046 .94231 L
.60664 .92308 L
.60425 .90385 L
.59718 .88462 L
.59615 .88253 L
.58426 .86538 L
.57692 .85839 L
.55769 .84648 L
.55689 .84615 L
.53846 .84147 L
.51923 .84254 L
.50813 .84615 L
.5 .85029 L
.48324 .86538 L
.48077 .86857 L
.47296 .88462 L
.46872 .90385 L
.46911 .92308 L
.47392 .94231 L
.48077 .9573 L
.48378 .96154 L
.5 .97747 L
.50138 .98077 L
F
0 g
.58177 .98077 m
.59615 .96342 L
.59725 .96154 L
.6046 .94231 L
.60664 .92308 L
.60425 .90385 L
.59718 .88462 L
.59615 .88253 L
.58426 .86538 L
.57692 .85839 L
.55769 .84648 L
.55689 .84615 L
.53846 .84147 L
.51923 .84254 L
.50813 .84615 L
.5 .85029 L
.48324 .86538 L
.48077 .86857 L
.47296 .88462 L
.46872 .90385 L
.46911 .92308 L
.47392 .94231 L
.48077 .9573 L
.48378 .96154 L
.5 .97747 L
.50138 .98077 L
s
.2 g
.87198 .01923 m
.88322 .03846 L
.88462 .04125 L
.89144 .05769 L
.89714 .07692 L
.90069 .09615 L
.9023 .11538 L
.90214 .13462 L
.90033 .15385 L
.89693 .17308 L
.89199 .19231 L
.88555 .21154 L
.88462 .21403 L
.87762 .23077 L
.86817 .25 L
.86538 .25514 L
.85716 .26923 L
.84615 .28609 L
.8445 .28846 L
.83005 .30769 L
.82692 .31153 L
.81353 .32692 L
.80769 .3331 L
.79443 .34615 L
.78846 .35153 L
.77157 .36538 L
.76923 .36712 L
.75 .37991 L
.74183 .38462 L
.73077 .38987 L
.71154 .39689 L
.69231 .40087 L
.67308 .40176 L
.65385 .39957 L
.63462 .39437 L
.61538 .3862 L
.61224 .38462 L
.59615 .375 L
.58277 .36538 L
.57692 .3606 L
.56122 .34615 L
.55769 .3425 L
.54407 .32692 L
.53846 .31966 L
.53007 .30769 L
.51923 .28966 L
.51858 .28846 L
.50922 .26923 L
.50179 .25 L
.5 .24461 L
.49611 .23077 L
.4921 .21154 L
.4897 .19231 L
.4889 .17308 L
.48968 .15385 L
.4921 .13462 L
.49623 .11538 L
.5 .10227 L
.50216 .09615 L
.51005 .07692 L
.51923 .05928 L
.52016 .05769 L
.53282 .03846 L
.53846 .03113 L
.54857 .01923 L
F
0 g
.87198 .01923 m
.88322 .03846 L
.88462 .04125 L
.89144 .05769 L
.89714 .07692 L
.90069 .09615 L
.9023 .11538 L
.90214 .13462 L
.90033 .15385 L
.89693 .17308 L
.89199 .19231 L
.88555 .21154 L
.88462 .21403 L
.87762 .23077 L
.86817 .25 L
.86538 .25514 L
.85716 .26923 L
.84615 .28609 L
.8445 .28846 L
.83005 .30769 L
.82692 .31153 L
.81353 .32692 L
.80769 .3331 L
.79443 .34615 L
.78846 .35153 L
.77157 .36538 L
.76923 .36712 L
.75 .37991 L
.74183 .38462 L
.73077 .38987 L
.71154 .39689 L
.69231 .40087 L
.67308 .40176 L
.65385 .39957 L
.63462 .39437 L
.61538 .3862 L
.61224 .38462 L
.59615 .375 L
.58277 .36538 L
.57692 .3606 L
.56122 .34615 L
.55769 .3425 L
.54407 .32692 L
.53846 .31966 L
.53007 .30769 L
.51923 .28966 L
.51858 .28846 L
.50922 .26923 L
.50179 .25 L
.5 .24461 L
Mistroke
.49611 .23077 L
.4921 .21154 L
.4897 .19231 L
.4889 .17308 L
.48968 .15385 L
.4921 .13462 L
.49623 .11538 L
.5 .10227 L
.50216 .09615 L
.51005 .07692 L
.51923 .05928 L
.52016 .05769 L
.53282 .03846 L
.53846 .03113 L
.54857 .01923 L
Mfstroke
1 g
.51923 .87166 m
.53846 .86939 L
.55769 .87673 L
.56817 .88462 L
.57692 .90158 L
.57782 .90385 L
.58116 .92308 L
.57692 .94225 L
.57692 .94231 L
.56053 .96154 L
.55769 .96223 L
.53846 .96447 L
.51992 .96154 L
.51923 .96127 L
.50022 .94231 L
.5 .94078 L
.49364 .92308 L
.49396 .90385 L
.5 .8892 L
.50314 .88462 L
F
0 g
.51923 .87166 m
.53846 .86939 L
.55769 .87673 L
.56817 .88462 L
.57692 .90158 L
.57782 .90385 L
.58116 .92308 L
.57692 .94225 L
.57692 .94231 L
.56053 .96154 L
.55769 .96223 L
.53846 .96447 L
.51992 .96154 L
.51923 .96127 L
.50022 .94231 L
.5 .94078 L
.49364 .92308 L
.49396 .90385 L
.5 .8892 L
.50314 .88462 L
.51923 .87166 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.654 .749 .919 r
.39899 .59869 .40511 .60409 .41535 .60123 .40926 .59583 Mtetra
.654 .749 .92 r
.40926 .59583 .41535 .60123 .42563 .59838 .41956 .59297 Mtetra
.653 .75 .921 r
.41956 .59297 .42563 .59838 .43594 .59553 .4299 .59012 Mtetra
.652 .75 .922 r
.4299 .59012 .43594 .59553 .4463 .5927 .44029 .58728 Mtetra
.65 .75 .923 r
.44029 .58728 .4463 .5927 .4567 .58989 .45071 .58448 Mtetra
.648 .75 .924 r
.45071 .58448 .4567 .58989 .46714 .58712 .46118 .58171 Mtetra
.644 .75 .926 r
.46118 .58171 .46714 .58712 .47762 .58442 .47169 .57903 Mtetra
.638 .75 .93 r
.47169 .57903 .47762 .58442 .48815 .58184 .48224 .57648 Mtetra
.628 .749 .934 r
.48224 .57648 .48815 .58184 .49872 .57945 .49283 .57413 Mtetra
.612 .747 .941 r
.49283 .57413 .49872 .57945 .50933 .57735 .50347 .57211 Mtetra
.587 .742 .95 r
.50347 .57211 .50933 .57735 .51998 .5757 .51415 .57058 Mtetra
.544 .732 .962 r
.51415 .57058 .51998 .5757 .5307 .57469 .52489 .56975 Mtetra
.473 .711 .974 r
.52489 .56975 .5307 .57469 .54147 .57458 .53568 .56991 Mtetra
.349 .664 .973 r
.53568 .56991 .54147 .57458 .55231 .57567 .54655 .57139 Mtetra
.139 .56 .925 r
.54655 .57139 .55231 .57567 .56324 .57832 .55751 .57455 Mtetra
0 .36 .766 r
.55751 .57455 .56324 .57832 .57428 .58286 .56858 .57976 Mtetra
.473 0 0 r
.56858 .57976 .57428 .58286 .58545 .58959 .57979 .58734 Mtetra
.67 .12 0 r
.57979 .58734 .58545 .58959 .59678 .59869 .59116 .59746 Mtetra
.765 .256 0 r
.59116 .59746 .59678 .59869 .60829 .61015 .60273 .61011 Mtetra
.804 .331 .097 r
.60273 .61011 .60829 .61015 .62001 .62371 .6145 .62498 Mtetra
.817 .369 .173 r
.6145 .62498 .62001 .62371 .63192 .63881 .62648 .64146 Mtetra
.813 .382 .22 r
.62648 .64146 .63192 .63881 .64403 .65457 .63867 .65856 Mtetra
.797 .375 .244 r
.63867 .65856 .64403 .65457 .6563 .66981 .65102 .67502 Mtetra
.767 .347 .251 r
.65102 .67502 .6563 .66981 .66866 .6832 .66346 .68939 Mtetra
.717 .291 .237 r
.66346 .68939 .66866 .6832 .68104 .69336 .67593 .70021 Mtetra
.628 .192 .194 r
.67593 .70021 .68104 .69336 .69336 .69911 .68832 .70619 Mtetra
.463 .016 .101 r
.68832 .70619 .69336 .69911 .70551 .69962 .70054 .7065 Mtetra
.149 0 0 r
.70054 .7065 .70551 .69962 .71744 .69456 .71252 .70084 Mtetra
0 0 0 r
.71252 .70084 .71744 .69456 .7291 .6842 .72421 .68951 Mtetra
.716 .906 .54 r
.72421 .68951 .7291 .6842 .74048 .6693 .73561 .67338 Mtetra
.891 .959 .622 r
.73561 .67338 .74048 .6693 .75161 .651 .74675 .65372 Mtetra
.952 .95 .656 r
.74675 .65372 .75161 .651 .76254 .63066 .75768 .63198 Mtetra
.969 .932 .678 r
.75768 .63198 .76254 .63066 .77336 .6096 .76849 .6096 Mtetra
.968 .916 .701 r
.76849 .6096 .77336 .6096 .78413 .58901 .77926 .58781 Mtetra
.957 .904 .727 r
.77926 .58781 .78413 .58901 .79494 .56979 .79007 .56756 Mtetra
.94 .894 .756 r
.79007 .56756 .79494 .56979 .80585 .55251 .80098 .54943 Mtetra
.916 .885 .788 r
.80098 .54943 .80585 .55251 .8169 .53744 .81204 .53368 Mtetra
.886 .875 .82 r
.81204 .53368 .8169 .53744 .82811 .5246 .82327 .52032 Mtetra
.852 .864 .849 r
.82327 .52032 .82811 .5246 .83951 .5138 .83468 .50914 Mtetra
.817 .851 .874 r
.83468 .50914 .83951 .5138 .85107 .50476 .84627 .49981 Mtetra
.784 .838 .893 r
.84627 .49981 .85107 .50476 .86279 .49712 .85802 .49196 Mtetra
.755 .826 .907 r
.85802 .49196 .86279 .49712 .87464 .49054 .8699 .48523 Mtetra
.732 .815 .916 r
.8699 .48523 .87464 .49054 .8866 .48472 .8819 .47929 Mtetra
.716 .808 .922 r
.8819 .47929 .8866 .48472 .89866 .47939 .89399 .47387 Mtetra
.706 .802 .925 r
.89399 .47387 .89866 .47939 .91078 .47437 .90616 .46876 Mtetra
.7 .798 .926 r
.90616 .46876 .91078 .47437 .92298 .4695 .91839 .46382 Mtetra
.698 .796 .926 r
.91839 .46382 .92298 .4695 .93522 .4647 .93067 .45895 Mtetra
.697 .794 .925 r
.93067 .45895 .93522 .4647 .94751 .4599 .943 .45409 Mtetra
.697 .793 .924 r
.943 .45409 .94751 .4599 .95984 .45508 .95537 .44919 Mtetra
.698 .792 .923 r
.95537 .44919 .95984 .45508 .97221 .45021 .96778 .44425 Mtetra
.654 .749 .92 r
.39284 .59326 .39899 .59869 .40926 .59583 .40312 .59039 Mtetra
.653 .749 .92 r
.40312 .59039 .40926 .59583 .41956 .59297 .41345 .58752 Mtetra
.652 .749 .921 r
.41345 .58752 .41956 .59297 .4299 .59012 .42382 .58467 Mtetra
.651 .75 .922 r
.42382 .58467 .4299 .59012 .44029 .58728 .43423 .58183 Mtetra
.649 .75 .923 r
.43423 .58183 .44029 .58728 .45071 .58448 .44468 .57902 Mtetra
.647 .75 .925 r
.44468 .57902 .45071 .58448 .46118 .58171 .45517 .57626 Mtetra
.643 .75 .927 r
.45517 .57626 .46118 .58171 .47169 .57903 .4657 .57359 Mtetra
.636 .749 .93 r
.4657 .57359 .47169 .57903 .48224 .57648 .47628 .57106 Mtetra
.626 .748 .935 r
.47628 .57106 .48224 .57648 .49283 .57413 .4869 .56876 Mtetra
.609 .745 .941 r
.4869 .56876 .49283 .57413 .50347 .57211 .49756 .5668 Mtetra
.581 .739 .951 r
.49756 .5668 .50347 .57211 .51415 .57058 .50827 .56537 Mtetra
.536 .727 .962 r
.50827 .56537 .51415 .57058 .52489 .56975 .51903 .56469 Mtetra
.459 .702 .972 r
.51903 .56469 .52489 .56975 .53568 .56991 .52986 .56506 Mtetra
.33 .648 .968 r
.52986 .56506 .53568 .56991 .54655 .57139 .54075 .56684 Mtetra
.116 .535 .916 r
.54075 .56684 .54655 .57139 .55751 .57455 .55174 .5704 Mtetra
0 .334 .759 r
.55174 .5704 .55751 .57455 .56858 .57976 .56283 .57614 Mtetra
.475 0 0 r
.56283 .57614 .56858 .57976 .57979 .58734 .57407 .58435 Mtetra
.668 .124 0 r
.57407 .58435 .57979 .58734 .59116 .59746 .58547 .59523 Mtetra
.767 .256 0 r
.58547 .59523 .59116 .59746 .60273 .61011 .59707 .60874 Mtetra
.812 .331 .048 r
.59707 .60874 .60273 .61011 .6145 .62498 .60888 .62455 Mtetra
.83 .369 .119 r
.60888 .62455 .6145 .62498 .62648 .64146 .62091 .64196 Mtetra
.831 .381 .158 r
.62091 .64196 .62648 .64146 .63867 .65856 .63315 .65995 Mtetra
.818 .37 .171 r
.63315 .65995 .63867 .65856 .65102 .67502 .64555 .67717 Mtetra
.789 .332 .158 r
.64555 .67717 .65102 .67502 .66346 .68939 .65805 .69209 Mtetra
.731 .252 .109 r
.65805 .69209 .66346 .68939 .67593 .70021 .67057 .70318 Mtetra
.604 .087 0 r
.67057 .70318 .67593 .70021 .68832 .70619 .68301 .70914 Mtetra
.289 0 0 r
.68301 .70914 .68832 .70619 .70054 .7065 .69528 .70912 Mtetra
.344 .793 .645 r
.69528 .70912 .70054 .7065 .71252 .70084 .7073 .70284 Mtetra
.798 .996 .775 r
.7073 .70284 .71252 .70084 .72421 .68951 .71902 .6907 Mtetra
.929 .97 .749 r
.71902 .6907 .72421 .68951 .73561 .67338 .73045 .67362 Mtetra
.96 .926 .72 r
.73045 .67362 .73561 .67338 .74675 .65372 .74161 .65297 Mtetra
.965 .894 .705 r
.74161 .65297 .74675 .65372 .75768 .63198 .75257 .63028 Mtetra
.961 .874 .704 r
.75257 .63028 .75768 .63198 .76849 .6096 .7634 .60703 Mtetra
.953 .861 .712 r
.7634 .60703 .76849 .6096 .77926 .58781 .77419 .5845 Mtetra
.941 .854 .728 r
.77419 .5845 .77926 .58781 .79007 .56756 .78502 .56363 Mtetra
.924 .85 .751 r
.78502 .56363 .79007 .56756 .80098 .54943 .79596 .54501 Mtetra
.903 .847 .779 r
.79596 .54501 .80098 .54943 .81204 .53368 .80705 .52891 Mtetra
.876 .844 .809 r
.80705 .52891 .81204 .53368 .82327 .52032 .81832 .51528 Mtetra
.846 .839 .838 r
.81832 .51528 .82327 .52032 .83468 .50914 .82977 .5039 Mtetra
.814 .832 .864 r
.82977 .5039 .83468 .50914 .84627 .49981 .84139 .49442 Mtetra
.782 .824 .885 r
.84139 .49442 .84627 .49981 .85802 .49196 .85318 .48647 Mtetra
.755 .815 .9 r
.85318 .48647 .85802 .49196 .8699 .48523 .8651 .47966 Mtetra
.733 .808 .911 r
.8651 .47966 .8699 .48523 .8819 .47929 .87714 .47365 Mtetra
.717 .802 .917 r
.87714 .47365 .8819 .47929 .89399 .47387 .88927 .46817 Mtetra
.707 .798 .921 r
.88927 .46817 .89399 .47387 .90616 .46876 .90148 .463 Mtetra
.701 .795 .923 r
.90148 .463 .90616 .46876 .91839 .46382 .91375 .458 Mtetra
.699 .793 .923 r
.91375 .458 .91839 .46382 .93067 .45895 .92607 .45307 Mtetra
.698 .791 .922 r
.92607 .45307 .93067 .45895 .943 .45409 .93844 .44814 Mtetra
.699 .79 .921 r
.93844 .44814 .943 .45409 .95537 .44919 .95085 .44318 Mtetra
.699 .789 .92 r
.95085 .44318 .95537 .44919 .96778 .44425 .9633 .43818 Mtetra
.653 .749 .92 r
.38663 .58778 .39284 .59326 .40312 .59039 .39694 .5849 Mtetra
.652 .749 .92 r
.39694 .5849 .40312 .59039 .41345 .58752 .4073 .58203 Mtetra
.651 .749 .921 r
.4073 .58203 .41345 .58752 .42382 .58467 .41769 .57917 Mtetra
.65 .749 .922 r
.41769 .57917 .42382 .58467 .43423 .58183 .42812 .57633 Mtetra
.648 .75 .923 r
.42812 .57633 .43423 .58183 .44468 .57902 .4386 .57352 Mtetra
.646 .75 .925 r
.4386 .57352 .44468 .57902 .45517 .57626 .44912 .57077 Mtetra
.641 .749 .927 r
.44912 .57077 .45517 .57626 .4657 .57359 .45968 .56811 Mtetra
.635 .748 .93 r
.45968 .56811 .4657 .57359 .47628 .57106 .47028 .56559 Mtetra
.624 .747 .935 r
.47028 .56559 .47628 .57106 .4869 .56876 .48092 .56331 Mtetra
.606 .743 .942 r
.48092 .56331 .4869 .56876 .49756 .5668 .49161 .5614 Mtetra
.577 .736 .95 r
.49161 .5614 .49756 .5668 .50827 .56537 .50235 .56004 Mtetra
.53 .722 .961 r
.50235 .56004 .50827 .56537 .51903 .56469 .51313 .55946 Mtetra
.453 .694 .97 r
.51313 .55946 .51903 .56469 .52986 .56506 .52398 .55998 Mtetra
.324 .636 .964 r
.52398 .55998 .52986 .56506 .54075 .56684 .5349 .56196 Mtetra
.117 .524 .913 r
.5349 .56196 .54075 .56684 .55174 .5704 .54591 .56578 Mtetra
0 .333 .773 r
.54591 .56578 .55174 .5704 .56283 .57614 .55702 .57184 Mtetra
.444 0 0 r
.55702 .57184 .56283 .57614 .57407 .58435 .56828 .58044 Mtetra
.639 .101 0 r
.56828 .58044 .57407 .58435 .58547 .59523 .57971 .59176 Mtetra
.748 .234 0 r
.57971 .59176 .58547 .59523 .59707 .60874 .59132 .60574 Mtetra
.803 .311 0 r
.59132 .60574 .59707 .60874 .60888 .62455 .60316 .62202 Mtetra
.827 .35 .025 r
.60316 .62202 .60888 .62455 .62091 .64196 .61521 .63987 Mtetra
.832 .359 .049 r
.61521 .63987 .62091 .64196 .63315 .65995 .62747 .65822 Mtetra
.819 .34 .036 r
.62747 .65822 .63315 .65995 .64555 .67717 .63989 .67567 Mtetra
.781 .278 0 r
.63989 .67567 .64555 .67717 .65805 .69209 .65242 .69065 Mtetra
.682 .135 0 r
.65242 .69065 .65805 .69209 .67057 .70318 .66496 .70163 Mtetra
.393 0 0 r
.66496 .70163 .67057 .70318 .68301 .70914 .67743 .7073 Mtetra
.278 .749 .941 r
.67743 .7073 .68301 .70914 .69528 .70912 .68972 .70684 Mtetra
.746 .925 .95 r
.68972 .70684 .69528 .70912 .7073 .70284 .70177 .70001 Mtetra
.878 .896 .84 r
.70177 .70001 .7073 .70284 .71902 .6907 .71352 .68727 Mtetra
.916 .859 .77 r
.71352 .68727 .71902 .6907 .73045 .67362 .72498 .66961 Mtetra
.928 .833 .731 r
.72498 .66961 .73045 .67362 .74161 .65297 .73618 .64842 Mtetra
.931 .818 .713 r
.73618 .64842 .74161 .65297 .75257 .63028 .74718 .62528 Mtetra
.929 .81 .707 r
.74718 .62528 .75257 .63028 .7634 .60703 .75806 .60169 Mtetra
.924 .807 .712 r
.75806 .60169 .7634 .60703 .77419 .5845 .7689 .57892 Mtetra
.915 .807 .726 r
.7689 .57892 .77419 .5845 .78502 .56363 .77979 .5579 Mtetra
.902 .809 .746 r
.77979 .5579 .78502 .56363 .79596 .54501 .79079 .5392 Mtetra
.885 .812 .771 r
.79079 .5392 .79596 .54501 .80705 .52891 .80193 .52306 Mtetra
.863 .814 .8 r
.80193 .52306 .80705 .52891 .81832 .51528 .81325 .50942 Mtetra
.836 .815 .829 r
.81325 .50942 .81832 .51528 .82977 .5039 .82476 .49805 Mtetra
.807 .813 .856 r
.82476 .49805 .82977 .5039 .84139 .49442 .83644 .48859 Mtetra
.778 .809 .878 r
.83644 .48859 .84139 .49442 .85318 .48647 .84827 .48064 Mtetra
.752 .804 .894 r
.84827 .48064 .85318 .48647 .8651 .47966 .86024 .47382 Mtetra
.732 .8 .906 r
.86024 .47382 .8651 .47966 .87714 .47365 .87232 .46779 Mtetra
.717 .796 .913 r
.87232 .46779 .87714 .47365 .88927 .46817 .8845 .46228 Mtetra
.707 .793 .918 r
.8845 .46228 .88927 .46817 .90148 .463 .89675 .45708 Mtetra
.702 .79 .92 r
.89675 .45708 .90148 .463 .91375 .458 .90906 .45203 Mtetra
.699 .789 .92 r
.90906 .45203 .91375 .458 .92607 .45307 .92143 .44705 Mtetra
.699 .788 .92 r
.92143 .44705 .92607 .45307 .93844 .44814 .93383 .44206 Mtetra
.699 .788 .919 r
.93383 .44206 .93844 .44814 .95085 .44318 .94629 .43704 Mtetra
.7 .787 .918 r
.94629 .43704 .95085 .44318 .9633 .43818 .95878 .43197 Mtetra
.653 .748 .92 r
.38038 .58225 .38663 .58778 .39694 .5849 .39072 .57937 Mtetra
.652 .749 .921 r
.39072 .57937 .39694 .5849 .4073 .58203 .4011 .57649 Mtetra
.651 .749 .921 r
.4011 .57649 .4073 .58203 .41769 .57917 .41152 .57363 Mtetra
.649 .749 .922 r
.41152 .57363 .41769 .57917 .42812 .57633 .42198 .57079 Mtetra
.648 .749 .924 r
.42198 .57079 .42812 .57633 .4386 .57352 .43248 .56798 Mtetra
.645 .749 .925 r
.43248 .56798 .4386 .57352 .44912 .57077 .44302 .56522 Mtetra
.64 .749 .927 r
.44302 .56522 .44912 .57077 .45968 .56811 .45361 .56256 Mtetra
.633 .748 .93 r
.45361 .56256 .45968 .56811 .47028 .56559 .46423 .56006 Mtetra
.622 .745 .935 r
.46423 .56006 .47028 .56559 .48092 .56331 .4749 .55779 Mtetra
.604 .741 .941 r
.4749 .55779 .48092 .56331 .49161 .5614 .48562 .5559 Mtetra
.576 .733 .949 r
.48562 .5559 .49161 .5614 .50235 .56004 .49638 .55457 Mtetra
.529 .717 .959 r
.49638 .55457 .50235 .56004 .51313 .55946 .50719 .55405 Mtetra
.453 .688 .966 r
.50719 .55405 .51313 .55946 .52398 .55998 .51806 .55463 Mtetra
.33 .63 .961 r
.51806 .55463 .52398 .55998 .5349 .56196 .529 .55669 Mtetra
.141 .524 .917 r
.529 .55669 .5349 .56196 .54591 .56578 .54003 .5606 Mtetra
0 .352 .802 r
.54003 .5606 .54591 .56578 .55702 .57184 .55116 .56676 Mtetra
0 .14 .615 r
.55116 .56676 .55702 .57184 .56828 .58044 .56243 .57547 Mtetra
.573 .049 0 r
.56243 .57547 .56828 .58044 .57971 .59176 .57387 .58687 Mtetra
.693 .182 0 r
.57387 .58687 .57971 .59176 .59132 .60574 .58549 .60089 Mtetra
.756 .261 0 r
.58549 .60089 .59132 .60574 .60316 .62202 .59733 .61715 Mtetra
.783 .297 0 r
.59733 .61715 .60316 .62202 .61521 .63987 .60938 .6349 Mtetra
.781 .296 0 r
.60938 .6349 .61521 .63987 .62747 .65822 .62163 .65304 Mtetra
.743 .25 0 r
.62163 .65304 .62747 .65822 .63989 .67567 .63405 .67017 Mtetra
.633 .127 0 r
.63405 .67017 .63989 .67567 .65242 .69065 .64657 .68474 Mtetra
0 .133 .632 r
.64657 .68474 .65242 .69065 .66496 .70163 .65911 .69523 Mtetra
.154 .497 .907 r
.65911 .69523 .66496 .70163 .67743 .7073 .67157 .70038 Mtetra
.563 .7 .933 r
.67157 .70038 .67743 .7073 .68972 .70684 .68387 .6994 Mtetra
.747 .75 .855 r
.68387 .6994 .68972 .70684 .70177 .70001 .69594 .69214 Mtetra
.824 .756 .788 r
.69594 .69214 .70177 .70001 .71352 .68727 .70772 .67907 Mtetra
.86 .754 .745 r
.70772 .67907 .71352 .68727 .72498 .66961 .71923 .66123 Mtetra
.878 .752 .719 r
.71923 .66123 .72498 .66961 .73618 .64842 .73048 .64001 Mtetra
.888 .752 .707 r
.73048 .64001 .73618 .64842 .74718 .62528 .74155 .61697 Mtetra
.892 .755 .704 r
.74155 .61697 .74718 .62528 .75806 .60169 .7525 .59359 Mtetra
.891 .759 .709 r
.7525 .59359 .75806 .60169 .7689 .57892 .76342 .5711 Mtetra
.887 .765 .722 r
.76342 .5711 .7689 .57892 .77979 .5579 .77439 .55039 Mtetra
.878 .772 .741 r
.77439 .55039 .77979 .5579 .79079 .5392 .78547 .53202 Mtetra
.865 .78 .766 r
.78547 .53202 .79079 .5392 .80193 .52306 .79669 .51617 Mtetra
.846 .787 .794 r
.79669 .51617 .80193 .52306 .81325 .50942 .80809 .50279 Mtetra
.823 .792 .823 r
.80809 .50279 .81325 .50942 .82476 .49805 .81966 .49162 Mtetra
.798 .795 .849 r
.81966 .49162 .82476 .49805 .83644 .48859 .8314 .48231 Mtetra
.772 .795 .872 r
.8314 .48231 .83644 .48859 .84827 .48064 .84329 .47446 Mtetra
.748 .794 .89 r
.84329 .47446 .84827 .48064 .86024 .47382 .85532 .46771 Mtetra
.729 .791 .902 r
.85532 .46771 .86024 .47382 .87232 .46779 .86745 .46171 Mtetra
.715 .789 .91 r
.86745 .46171 .87232 .46779 .8845 .46228 .87967 .4562 Mtetra
.707 .787 .914 r
.87967 .4562 .8845 .46228 .89675 .45708 .89197 .45098 Mtetra
.702 .786 .917 r
.89197 .45098 .89675 .45708 .90906 .45203 .90432 .4459 Mtetra
.7 .785 .917 r
.90432 .4459 .90906 .45203 .92143 .44705 .91673 .44087 Mtetra
.699 .785 .917 r
.91673 .44087 .92143 .44705 .93383 .44206 .92918 .43583 Mtetra
.7 .784 .917 r
.92918 .43583 .93383 .44206 .94629 .43704 .94167 .43076 Mtetra
.701 .784 .916 r
.94167 .43076 .94629 .43704 .95878 .43197 .9542 .42563 Mtetra
.652 .748 .92 r
.37409 .57669 .38038 .58225 .39072 .57937 .38445 .5738 Mtetra
.651 .748 .921 r
.38445 .5738 .39072 .57937 .4011 .57649 .39485 .57091 Mtetra
.65 .749 .921 r
.39485 .57091 .4011 .57649 .41152 .57363 .4053 .56804 Mtetra
.649 .749 .922 r
.4053 .56804 .41152 .57363 .42198 .57079 .41578 .56519 Mtetra
.647 .749 .924 r
.41578 .56519 .42198 .57079 .43248 .56798 .42631 .56238 Mtetra
.644 .749 .925 r
.42631 .56238 .43248 .56798 .44302 .56522 .43688 .55962 Mtetra
.64 .748 .927 r
.43688 .55962 .44302 .56522 .45361 .56256 .44749 .55696 Mtetra
.633 .747 .93 r
.44749 .55696 .45361 .56256 .46423 .56006 .45814 .55445 Mtetra
.622 .744 .934 r
.45814 .55445 .46423 .56006 .4749 .55779 .46884 .55219 Mtetra
.604 .739 .94 r
.46884 .55219 .4749 .55779 .48562 .5559 .47958 .5503 Mtetra
.576 .731 .948 r
.47958 .5503 .48562 .5559 .49638 .55457 .49036 .54896 Mtetra
.531 .714 .956 r
.49036 .54896 .49638 .55457 .50719 .55405 .5012 .54843 Mtetra
.46 .684 .963 r
.5012 .54843 .50719 .55405 .51806 .55463 .51209 .54898 Mtetra
.349 .63 .958 r
.51209 .54898 .51806 .55463 .529 .55669 .52305 .55099 Mtetra
.182 .534 .924 r
.52305 .55099 .529 .55669 .54003 .5606 .5341 .55483 Mtetra
0 .386 .837 r
.5341 .55483 .54003 .5606 .55116 .56676 .54525 .56086 Mtetra
0 .204 .696 r
.54525 .56086 .55116 .56676 .56243 .57547 .55652 .56937 Mtetra
0 .033 .539 r
.55652 .56937 .56243 .57547 .57387 .58687 .56796 .58048 Mtetra
.582 .093 0 r
.56796 .58048 .57387 .58687 .58549 .60089 .57958 .59411 Mtetra
.645 .167 0 r
.57958 .59411 .58549 .60089 .59733 .61715 .5914 .60986 Mtetra
.657 .191 0 r
.5914 .60986 .59733 .61715 .60938 .6349 .60343 .62696 Mtetra
.616 .164 0 r
.60343 .62696 .60938 .6349 .62163 .65304 .61566 .64435 Mtetra
0 0 .485 r
.61566 .64435 .62163 .65304 .63405 .67017 .62804 .66065 Mtetra
0 .107 .658 r
.62804 .66065 .63405 .67017 .64657 .68474 .64053 .67436 Mtetra
.091 .334 .808 r
.64053 .67436 .64657 .68474 .65911 .69523 .65304 .68402 Mtetra
.406 .509 .851 r
.65304 .68402 .65911 .69523 .67157 .70038 .66548 .68845 Mtetra
.604 .602 .823 r
.66548 .68845 .67157 .70038 .68387 .6994 .67777 .68696 Mtetra
.714 .646 .781 r
.67777 .68696 .68387 .6994 .69594 .69214 .68984 .67941 Mtetra
.775 .669 .746 r
.68984 .67941 .69594 .69214 .70772 .67907 .70165 .66632 Mtetra
.812 .682 .721 r
.70165 .66632 .70772 .67907 .71923 .66123 .71321 .64872 Mtetra
.835 .692 .706 r
.71321 .64872 .71923 .66123 .73048 .64001 .72453 .62798 Mtetra
.849 .701 .699 r
.72453 .62798 .73048 .64001 .74155 .61697 .73568 .60558 Mtetra
.857 .71 .699 r
.73568 .60558 .74155 .61697 .7525 .59359 .74674 .58293 Mtetra
.86 .72 .706 r
.74674 .58293 .7525 .59359 .76342 .5711 .75776 .56121 Mtetra
.86 .73 .719 r
.75776 .56121 .76342 .5711 .77439 .55039 .76884 .54126 Mtetra
.854 .742 .738 r
.76884 .54126 .77439 .55039 .78547 .53202 .78002 .52358 Mtetra
.844 .753 .762 r
.78002 .52358 .78547 .53202 .79669 .51617 .79134 .50833 Mtetra
.829 .764 .79 r
.79134 .50833 .79669 .51617 .80809 .50279 .80283 .49543 Mtetra
.81 .773 .819 r
.80283 .49543 .80809 .50279 .81966 .49162 .81448 .48465 Mtetra
.787 .779 .845 r
.81448 .48465 .81966 .49162 .8314 .48231 .82629 .47562 Mtetra
.764 .782 .868 r
.82629 .47562 .8314 .48231 .84329 .47446 .83825 .46797 Mtetra
.742 .783 .886 r
.83825 .46797 .84329 .47446 .85532 .46771 .85033 .46134 Mtetra
.725 .783 .898 r
.85033 .46134 .85532 .46771 .86745 .46171 .86251 .4554 Mtetra
.713 .783 .907 r
.86251 .4554 .86745 .46171 .87967 .4562 .87479 .44992 Mtetra
.705 .782 .911 r
.87479 .44992 .87967 .4562 .89197 .45098 .88713 .4447 Mtetra
.701 .782 .914 r
.88713 .4447 .89197 .45098 .90432 .4459 .89953 .4396 Mtetra
.7 .781 .915 r
.89953 .4396 .90432 .4459 .91673 .44087 .91197 .43454 Mtetra
.91197 .43454 .91673 .44087 .92918 .43583 .92447 .42946 Mtetra
.7 .781 .914 r
.92447 .42946 .92918 .43583 .94167 .43076 .937 .42433 Mtetra
.702 .781 .913 r
.937 .42433 .94167 .43076 .9542 .42563 .94957 .41915 Mtetra
.651 .748 .92 r
.36775 .57107 .37409 .57669 .38445 .5738 .37814 .56817 Mtetra
.651 .748 .921 r
.37814 .56817 .38445 .5738 .39485 .57091 .38856 .56528 Mtetra
.65 .748 .922 r
.38856 .56528 .39485 .57091 .4053 .56804 .39903 .56241 Mtetra
.648 .748 .922 r
.39903 .56241 .4053 .56804 .41578 .56519 .40954 .55955 Mtetra
.646 .748 .924 r
.40954 .55955 .41578 .56519 .42631 .56238 .42009 .55673 Mtetra
.643 .748 .925 r
.42009 .55673 .42631 .56238 .43688 .55962 .43069 .55397 Mtetra
.639 .748 .927 r
.43069 .55397 .43688 .55962 .44749 .55696 .44133 .5513 Mtetra
.632 .746 .93 r
.44133 .5513 .44749 .55696 .45814 .55445 .45201 .54878 Mtetra
.622 .743 .934 r
.45201 .54878 .45814 .55445 .46884 .55219 .46273 .5465 Mtetra
.605 .738 .939 r
.46273 .5465 .46884 .55219 .47958 .5503 .4735 .54458 Mtetra
.578 .729 .946 r
.4735 .54458 .47958 .5503 .49036 .54896 .48431 .5432 Mtetra
.537 .712 .953 r
.48431 .5432 .49036 .54896 .5012 .54843 .49517 .54259 Mtetra
.472 .683 .958 r
.49517 .54259 .5012 .54843 .51209 .54898 .50608 .54304 Mtetra
.375 .633 .955 r
.50608 .54304 .51209 .54898 .52305 .55099 .51706 .54488 Mtetra
.235 .55 .93 r
.51706 .54488 .52305 .55099 .5341 .55483 .52812 .54847 Mtetra
.055 .428 .87 r
.52812 .54847 .5341 .55483 .54525 .56086 .53928 .55414 Mtetra
0 .279 .771 r
.53928 .55414 .54525 .56086 .55652 .56937 .55057 .56217 Mtetra
0 .135 .659 r
.55057 .56217 .55652 .56937 .56796 .58048 .562 .57265 Mtetra
0 .026 .569 r
.562 .57265 .56796 .58048 .57958 .59411 .5736 .58547 Mtetra
0 0 .523 r
.5736 .58547 .57958 .59411 .5914 .60986 .5854 .60024 Mtetra
0 0 .529 r
.5854 .60024 .5914 .60986 .60343 .62696 .59739 .61622 Mtetra
0 .015 .586 r
.59739 .61622 .60343 .62696 .61566 .64435 .60957 .63236 Mtetra
0 .124 .673 r
.60957 .63236 .61566 .64435 .62804 .66065 .6219 .64738 Mtetra
.079 .265 .752 r
.6219 .64738 .62804 .66065 .64053 .67436 .63433 .65984 Mtetra
.311 .395 .788 r
.63433 .65984 .64053 .67436 .65304 .68402 .64678 .66841 Mtetra
.49 .49 .784 r
.64678 .66841 .65304 .68402 .66548 .68845 .65918 .67201 Mtetra
.611 .551 .762 r
.65918 .67201 .66548 .68845 .67777 .68696 .67145 .67002 Mtetra
.689 .589 .738 r
.67145 .67002 .67777 .68696 .68984 .67941 .68352 .66236 Mtetra
.741 .615 .718 r
.68352 .66236 .68984 .67941 .70165 .66632 .69537 .64957 Mtetra
.776 .634 .704 r
.69537 .64957 .70165 .66632 .71321 .64872 .70698 .63261 Mtetra
.8 .649 .696 r
.70698 .63261 .71321 .64872 .72453 .62798 .71838 .6128 Mtetra
.816 .663 .693 r
.71838 .6128 .72453 .62798 .73568 .60558 .72964 .59152 Mtetra
.827 .676 .696 r
.72964 .59152 .73568 .60558 .74674 .58293 .74081 .57009 Mtetra
.833 .689 .704 r
.74081 .57009 .74674 .58293 .75776 .56121 .75196 .54958 Mtetra
.835 .703 .718 r
.75196 .54958 .75776 .56121 .76884 .54126 .76316 .53076 Mtetra
.832 .717 .738 r
.76316 .53076 .76884 .54126 .78002 .52358 .77446 .51408 Mtetra
.824 .731 .762 r
.77446 .51408 .78002 .52358 .79134 .50833 .78589 .49967 Mtetra
.812 .744 .789 r
.78589 .49967 .79134 .50833 .80283 .49543 .79748 .48747 Mtetra
.795 .756 .817 r
.79748 .48747 .80283 .49543 .81448 .48465 .80922 .47721 Mtetra
.775 .765 .844 r
.80922 .47721 .81448 .48465 .82629 .47562 .82111 .46856 Mtetra
.755 .771 .866 r
.82111 .46856 .82629 .47562 .83825 .46797 .83314 .46118 Mtetra
.736 .774 .883 r
.83314 .46118 .83825 .46797 .85033 .46134 .84528 .45472 Mtetra
.721 .776 .896 r
.84528 .45472 .85033 .46134 .86251 .4554 .85752 .44889 Mtetra
.71 .776 .904 r
.85752 .44889 .86251 .4554 .87479 .44992 .86985 .44346 Mtetra
.704 .777 .909 r
.86985 .44346 .87479 .44992 .88713 .4447 .88223 .43825 Mtetra
.701 .777 .911 r
.88223 .43825 .88713 .4447 .89953 .4396 .89468 .43313 Mtetra
.699 .777 .912 r
.89468 .43313 .89953 .4396 .91197 .43454 .90717 .42804 Mtetra
.7 .778 .912 r
.90717 .42804 .91197 .43454 .92447 .42946 .91971 .42292 Mtetra
.701 .778 .911 r
.91971 .42292 .92447 .42946 .937 .42433 .93228 .41776 Mtetra
.702 .778 .911 r
.93228 .41776 .937 .42433 .94957 .41915 .9449 .41253 Mtetra
.651 .747 .92 r
.36136 .56541 .36775 .57107 .37814 .56817 .37177 .5625 Mtetra
.65 .747 .921 r
.37177 .5625 .37814 .56817 .38856 .56528 .38223 .5596 Mtetra
.649 .748 .922 r
.38223 .5596 .38856 .56528 .39903 .56241 .39272 .55672 Mtetra
.648 .748 .922 r
.39272 .55672 .39903 .56241 .40954 .55955 .40326 .55386 Mtetra
.646 .748 .924 r
.40326 .55386 .40954 .55955 .42009 .55673 .41383 .55103 Mtetra
.643 .748 .925 r
.41383 .55103 .42009 .55673 .43069 .55397 .42446 .54826 Mtetra
.639 .747 .927 r
.42446 .54826 .43069 .55397 .44133 .5513 .43512 .54557 Mtetra
.632 .745 .929 r
.43512 .54557 .44133 .5513 .45201 .54878 .44583 .54304 Mtetra
.622 .742 .933 r
.44583 .54304 .45201 .54878 .46273 .5465 .45657 .54072 Mtetra
.607 .737 .937 r
.45657 .54072 .46273 .5465 .4735 .54458 .46737 .53875 Mtetra
.582 .728 .943 r
.46737 .53875 .4735 .54458 .48431 .5432 .4782 .53729 Mtetra
.545 .712 .949 r
.4782 .53729 .48431 .5432 .49517 .54259 .48909 .53656 Mtetra
.489 .684 .953 r
.48909 .53656 .49517 .54259 .50608 .54304 .50003 .53681 Mtetra
.407 .64 .951 r
.50003 .53681 .50608 .54304 .51706 .54488 .51103 .53837 Mtetra
.293 .57 .934 r
.51103 .53837 .51706 .54488 .52812 .54847 .5221 .54155 Mtetra
.151 .471 .893 r
.5221 .54155 .52812 .54847 .53928 .55414 .53327 .54668 Mtetra
.001 .353 .828 r
.53327 .54668 .53928 .55414 .55057 .56217 .54456 .55396 Mtetra
0 .239 .754 r
.54456 .55396 .55057 .56217 .562 .57265 .55598 .5635 Mtetra
0 .154 .693 r
.55598 .5635 .562 .57265 .5736 .58547 .56757 .57517 Mtetra
0 .112 .664 r
.56757 .57517 .5736 .58547 .5854 .60024 .57933 .58857 Mtetra
0 .118 .669 r
.57933 .58857 .5854 .60024 .59739 .61622 .59127 .60301 Mtetra
0 .169 .699 r
.59127 .60301 .59739 .61622 .60957 .63236 .60339 .61752 Mtetra
.096 .25 .733 r
.60339 .61752 .60957 .63236 .6219 .64738 .61565 .6309 Mtetra
.263 .339 .754 r
.61565 .6309 .6219 .64738 .63433 .65984 .62801 .64184 Mtetra
.411 .417 .755 r
.62801 .64184 .63433 .65984 .64678 .66841 .64039 .64914 Mtetra
.527 .478 .745 r
.64039 .64914 .64678 .66841 .65918 .67201 .65274 .65184 Mtetra
.612 .522 .729 r
.65274 .65184 .65918 .67201 .67145 .67002 .66497 .64942 Mtetra
.673 .556 .714 r
.66497 .64942 .67145 .67002 .68352 .66236 .67704 .64184 Mtetra
.717 .581 .702 r
.67704 .64184 .68352 .66236 .69537 .64957 .68892 .62962 Mtetra
.749 .601 .693 r
.68892 .62962 .69537 .64957 .70698 .63261 .70059 .61366 Mtetra
.772 .619 .689 r
.70059 .61366 .70698 .63261 .71838 .6128 .71209 .59517 Mtetra
.789 .635 .69 r
.71209 .59517 .71838 .6128 .72964 .59152 .72345 .5754 Mtetra
.801 .65 .695 r
.72345 .5754 .72964 .59152 .74081 .57009 .73475 .55556 Mtetra
.809 .665 .704 r
.73475 .55556 .74081 .57009 .75196 .54958 .74604 .53659 Mtetra
.812 .681 .719 r
.74604 .53659 .75196 .54958 .76316 .53076 .75737 .5192 Mtetra
.811 .697 .739 r
.75737 .5192 .76316 .53076 .77446 .51408 .76881 .50376 Mtetra
.806 .713 .763 r
.76881 .50376 .77446 .51408 .78589 .49967 .78036 .4904 Mtetra
.795 .729 .79 r
.78036 .4904 .78589 .49967 .79748 .48747 .79206 .47901 Mtetra
.781 .742 .818 r
.79206 .47901 .79748 .48747 .80922 .47721 .8039 .46939 Mtetra
.763 .753 .844 r
.8039 .46939 .80922 .47721 .82111 .46856 .81587 .4612 Mtetra
.745 .761 .865 r
.81587 .4612 .82111 .46856 .83314 .46118 .82797 .45414 Mtetra
.729 .766 .882 r
.82797 .45414 .83314 .46118 .84528 .45472 .84018 .44788 Mtetra
.716 .769 .894 r
.84018 .44788 .84528 .45472 .85752 .44889 .85248 .44218 Mtetra
.707 .771 .902 r
.85248 .44218 .85752 .44889 .86985 .44346 .86485 .43681 Mtetra
.702 .772 .906 r
.86485 .43681 .86985 .44346 .88223 .43825 .87729 .43162 Mtetra
.7 .773 .908 r
.87729 .43162 .88223 .43825 .89468 .43313 .88978 .4265 Mtetra
.699 .773 .909 r
.88978 .4265 .89468 .43313 .90717 .42804 .90231 .42139 Mtetra
.7 .774 .909 r
.90231 .42139 .90717 .42804 .91971 .42292 .91489 .41623 Mtetra
.701 .774 .909 r
.91489 .41623 .91971 .42292 .93228 .41776 .92751 .41102 Mtetra
.702 .775 .908 r
.92751 .41102 .93228 .41776 .9449 .41253 .94017 .40575 Mtetra
.65 .747 .92 r
.35493 .55969 .36136 .56541 .37177 .5625 .36537 .55678 Mtetra
.65 .747 .921 r
.36537 .55678 .37177 .5625 .38223 .5596 .37584 .55387 Mtetra
.649 .747 .922 r
.37584 .55387 .38223 .5596 .39272 .55672 .38636 .55098 Mtetra
.647 .747 .922 r
.38636 .55098 .39272 .55672 .40326 .55386 .39692 .54811 Mtetra
.645 .747 .923 r
.39692 .54811 .40326 .55386 .41383 .55103 .40753 .54527 Mtetra
.643 .747 .925 r
.40753 .54527 .41383 .55103 .42446 .54826 .41818 .54248 Mtetra
.639 .746 .926 r
.41818 .54248 .42446 .54826 .43512 .54557 .42887 .53978 Mtetra
.633 .745 .929 r
.42887 .53978 .43512 .54557 .44583 .54304 .4396 .53722 Mtetra
.623 .742 .932 r
.4396 .53722 .44583 .54304 .45657 .54072 .45037 .53486 Mtetra
.609 .736 .936 r
.45037 .53486 .45657 .54072 .46737 .53875 .46119 .53282 Mtetra
.588 .727 .94 r
.46119 .53282 .46737 .53875 .4782 .53729 .47206 .53125 Mtetra
.555 .712 .945 r
.47206 .53125 .4782 .53729 .48909 .53656 .48297 .53034 Mtetra
.507 .687 .948 r
.48297 .53034 .48909 .53656 .50003 .53681 .49393 .53033 Mtetra
.44 .648 .947 r
.49393 .53033 .50003 .53681 .51103 .53837 .50495 .53151 Mtetra
.35 .59 .935 r
.50495 .53151 .51103 .53837 .5221 .54155 .51604 .53417 Mtetra
.242 .511 .907 r
.51604 .53417 .5221 .54155 .53327 .54668 .52722 .53857 Mtetra
.13 .419 .863 r
.52722 .53857 .53327 .54668 .54456 .55396 .53851 .54492 Mtetra
.038 .33 .813 r
.53851 .54492 .54456 .55396 .55598 .5635 .54992 .55328 Mtetra
0 .264 .77 r
.54992 .55328 .55598 .5635 .56757 .57517 .56148 .56352 Mtetra
0 .232 .744 r
.56148 .56352 .56757 .57517 .57933 .58857 .5732 .57526 Mtetra
.041 .237 .737 r
.5732 .57526 .57933 .58857 .59127 .60301 .58509 .58788 Mtetra
.135 .271 .74 r
.58509 .58788 .59127 .60301 .60339 .61752 .59714 .60047 Mtetra
.25 .323 .743 r
.59714 .60047 .60339 .61752 .61565 .6309 .60933 .61197 Mtetra
.365 .378 .741 r
.60933 .61197 .61565 .6309 .62801 .64184 .6216 .62122 Mtetra
.466 .429 .733 r
.6216 .62122 .62801 .64184 .64039 .64914 .63392 .62716 Mtetra
.548 .472 .722 r
.63392 .62716 .64039 .64914 .65274 .65184 .6462 .62897 Mtetra
.612 .507 .71 r
.6462 .62897 .65274 .65184 .66497 .64942 .6584 .6262 Mtetra
.661 .535 .7 r
.6584 .6262 .66497 .64942 .67704 .64184 .67046 .61887 Mtetra
.699 .559 .692 r
.67046 .61887 .67704 .64184 .68892 .62962 .68236 .60744 Mtetra
.728 .579 .688 r
.68236 .60744 .68892 .62962 .70059 .61366 .6941 .59275 Mtetra
.75 .597 .686 r
.6941 .59275 .70059 .61366 .71209 .59517 .70569 .57586 Mtetra
.767 .614 .689 r
.70569 .57586 .71209 .59517 .72345 .5754 .71718 .5579 Mtetra
.78 .631 .696 r
.71718 .5579 .72345 .5754 .73475 .55556 .72861 .5399 Mtetra
.788 .648 .707 r
.72861 .5399 .73475 .55556 .74604 .53659 .74004 .52271 Mtetra
.792 .665 .723 r
.74004 .52271 .74604 .53659 .75737 .5192 .75152 .50693 Mtetra
.792 .683 .743 r
.75152 .50693 .75737 .5192 .76881 .50376 .76309 .49289 Mtetra
.788 .7 .768 r
.76309 .49289 .76881 .50376 .78036 .4904 .77477 .48068 Mtetra
.779 .717 .794 r
.77477 .48068 .78036 .4904 .79206 .47901 .78657 .47022 Mtetra
.766 .732 .821 r
.78657 .47022 .79206 .47901 .8039 .46939 .79851 .46128 Mtetra
.751 .744 .846 r
.79851 .46128 .8039 .46939 .81587 .4612 .81058 .4536 Mtetra
.736 .753 .866 r
.81058 .4536 .81587 .4612 .82797 .45414 .82275 .44688 Mtetra
.722 .759 .882 r
.82275 .44688 .82797 .45414 .84018 .44788 .83502 .44085 Mtetra
.711 .763 .893 r
.83502 .44085 .84018 .44788 .85248 .44218 .84738 .43528 Mtetra
.704 .765 .9 r
.84738 .43528 .85248 .44218 .86485 .43681 .8598 .42998 Mtetra
.7 .767 .904 r
.8598 .42998 .86485 .43681 .87729 .43162 .87229 .42481 Mtetra
.698 .769 .906 r
.87229 .42481 .87729 .43162 .88978 .4265 .88482 .4197 Mtetra
.698 .77 .907 r
.88482 .4197 .88978 .4265 .90231 .42139 .8974 .41456 Mtetra
.699 .77 .907 r
.8974 .41456 .90231 .42139 .91489 .41623 .91003 .40938 Mtetra
.701 .771 .906 r
.91003 .40938 .91489 .41623 .92751 .41102 .92269 .40413 Mtetra
.702 .771 .906 r
.92269 .40413 .92751 .41102 .94017 .40575 .93539 .39882 Mtetra
.65 .746 .92 r
.34845 .55393 .35493 .55969 .36537 .55678 .35891 .551 Mtetra
.649 .747 .921 r
.35891 .551 .36537 .55678 .37584 .55387 .36941 .54808 Mtetra
.648 .747 .921 r
.36941 .54808 .37584 .55387 .38636 .55098 .37996 .54518 Mtetra
.647 .747 .922 r
.37996 .54518 .38636 .55098 .39692 .54811 .39054 .5423 Mtetra
.645 .747 .923 r
.39054 .5423 .39692 .54811 .40753 .54527 .40117 .53945 Mtetra
.642 .746 .924 r
.40117 .53945 .40753 .54527 .41818 .54248 .41185 .53665 Mtetra
.639 .746 .926 r
.41185 .53665 .41818 .54248 .42887 .53978 .42256 .53392 Mtetra
.633 .744 .928 r
.42256 .53392 .42887 .53978 .4396 .53722 .43332 .53132 Mtetra
.625 .741 .93 r
.43332 .53132 .4396 .53722 .45037 .53486 .44413 .52891 Mtetra
.613 .736 .934 r
.44413 .52891 .45037 .53486 .46119 .53282 .45497 .52678 Mtetra
.594 .728 .937 r
.45497 .52678 .46119 .53282 .47206 .53125 .46586 .52508 Mtetra
.566 .714 .941 r
.46586 .52508 .47206 .53125 .48297 .53034 .4768 .52396 Mtetra
.526 .691 .943 r
.4768 .52396 .48297 .53034 .49393 .53033 .48779 .52364 Mtetra
.472 .657 .942 r
.48779 .52364 .49393 .53033 .50495 .53151 .49883 .52438 Mtetra
.402 .609 .933 r
.49883 .52438 .50495 .53151 .51604 .53417 .50994 .52642 Mtetra
.321 .546 .913 r
.50994 .52642 .51604 .53417 .52722 .53857 .52114 .52999 Mtetra
.24 .473 .881 r
.52114 .52999 .52722 .53857 .53851 .54492 .53242 .53527 Mtetra
.175 .403 .844 r
.53242 .53527 .53851 .54492 .54992 .55328 .54383 .54228 Mtetra
.143 .35 .809 r
.54383 .54228 .54992 .55328 .56148 .56352 .55536 .55092 Mtetra
.15 .322 .782 r
.55536 .55092 .56148 .56352 .5732 .57526 .56705 .56083 Mtetra
.194 .319 .764 r
.56705 .56083 .5732 .57526 .58509 .58788 .57888 .57145 Mtetra
.264 .338 .752 r
.57888 .57145 .58509 .58788 .59714 .60047 .59086 .58198 Mtetra
.345 .369 .742 r
.59086 .58198 .59714 .60047 .60933 .61197 .60297 .59148 Mtetra
.426 .405 .732 r
.60297 .59148 .60933 .61197 .6216 .62122 .61516 .59897 Mtetra
.499 .44 .721 r
.61516 .59897 .6216 .62122 .63392 .62716 .62739 .60354 Mtetra
.561 .471 .71 r
.62739 .60354 .63392 .62716 .6462 .62897 .63962 .6045 Mtetra
.612 .499 .701 r
.63962 .6045 .6462 .62897 .6584 .6262 .65178 .60148 Mtetra
.653 .523 .693 r
.65178 .60148 .6584 .6262 .67046 .61887 .66383 .59453 Mtetra
.685 .545 .688 r
.66383 .59453 .67046 .61887 .68236 .60744 .67576 .58406 Mtetra
.712 .564 .686 r
.67576 .58406 .68236 .60744 .6941 .59275 .68756 .57082 Mtetra
.732 .582 .687 r
.68756 .57082 .6941 .59275 .70569 .57586 .69925 .5557 Mtetra
.749 .6 .692 r
.69925 .5557 .70569 .57586 .71718 .5579 .71085 .53969 Mtetra
.761 .617 .7 r
.71085 .53969 .71718 .5579 .72861 .5399 .72242 .52368 Mtetra
.769 .635 .712 r
.72242 .52368 .72861 .5399 .74004 .52271 .73399 .50838 Mtetra
.774 .653 .729 r
.73399 .50838 .74004 .52271 .75152 .50693 .74562 .49431 Mtetra
.775 .672 .75 r
.74562 .49431 .75152 .50693 .76309 .49289 .75732 .48173 Mtetra
.771 .691 .774 r
.75732 .48173 .76309 .49289 .77477 .48068 .76912 .47073 Mtetra
.764 .709 .8 r
.76912 .47073 .77477 .48068 .78657 .47022 .78104 .46121 Mtetra
.752 .724 .826 r
.78104 .46121 .78657 .47022 .79851 .46128 .79308 .45299 Mtetra
.739 .737 .849 r
.79308 .45299 .79851 .46128 .81058 .4536 .80523 .44582 Mtetra
.726 .746 .868 r
.80523 .44582 .81058 .4536 .82275 .44688 .81748 .43945 Mtetra
.715 .753 .882 r
.81748 .43945 .82275 .44688 .83502 .44085 .82981 .43364 Mtetra
.706 .758 .892 r
.82981 .43364 .83502 .44085 .84738 .43528 .84222 .42821 Mtetra
.701 .761 .898 r
.84222 .42821 .84738 .43528 .8598 .42998 .8547 .42298 Mtetra
.698 .763 .902 r
.8547 .42298 .8598 .42998 .87229 .42481 .86723 .41784 Mtetra
.697 .765 .904 r
.86723 .41784 .87229 .42481 .88482 .4197 .87982 .41272 Mtetra
.698 .766 .904 r
.87982 .41272 .88482 .4197 .8974 .41456 .89244 .40757 Mtetra
.699 .767 .904 r
.89244 .40757 .8974 .41456 .91003 .40938 .90511 .40236 Mtetra
.7 .767 .904 r
.90511 .40236 .91003 .40938 .92269 .40413 .91781 .39708 Mtetra
.702 .768 .903 r
.91781 .39708 .92269 .40413 .93539 .39882 .93056 .39173 Mtetra
.65 .746 .92 r
.34193 .5481 .34845 .55393 .35891 .551 .35241 .54517 Mtetra
.649 .746 .921 r
.35241 .54517 .35891 .551 .36941 .54808 .36294 .54224 Mtetra
.648 .746 .921 r
.36294 .54224 .36941 .54808 .37996 .54518 .3735 .53933 Mtetra
.646 .746 .922 r
.3735 .53933 .37996 .54518 .39054 .5423 .38412 .53643 Mtetra
.645 .746 .923 r
.38412 .53643 .39054 .5423 .40117 .53945 .39477 .53357 Mtetra
.642 .746 .924 r
.39477 .53357 .40117 .53945 .41185 .53665 .40547 .53075 Mtetra
.639 .745 .925 r
.40547 .53075 .41185 .53665 .42256 .53392 .41622 .528 Mtetra
.634 .744 .927 r
.41622 .528 .42256 .53392 .43332 .53132 .427 .52536 Mtetra
.627 .741 .929 r
.427 .52536 .43332 .53132 .44413 .52891 .43783 .52289 Mtetra
.616 .736 .932 r
.43783 .52289 .44413 .52891 .45497 .52678 .44871 .52066 Mtetra
.6 .728 .935 r
.44871 .52066 .45497 .52678 .46586 .52508 .45963 .5188 Mtetra
.577 .716 .937 r
.45963 .5188 .46586 .52508 .4768 .52396 .47059 .51746 Mtetra
.545 .696 .939 r
.47059 .51746 .4768 .52396 .48779 .52364 .4816 .5168 Mtetra
.502 .667 .937 r
.4816 .5168 .48779 .52364 .49883 .52438 .49267 .51706 Mtetra
.448 .627 .929 r
.49267 .51706 .49883 .52438 .50994 .52642 .5038 .51843 Mtetra
.388 .576 .914 r
.5038 .51843 .50994 .52642 .52114 .52999 .51501 .52111 Mtetra
.329 .517 .889 r
.51501 .52111 .52114 .52999 .53242 .53527 .5263 .52524 Mtetra
.283 .461 .859 r
.5263 .52524 .53242 .53527 .54383 .54228 .5377 .53084 Mtetra
.261 .415 .828 r
.5377 .53084 .54383 .54228 .55536 .55092 .54922 .5378 Mtetra
.268 .387 .8 r
.54922 .5378 .55536 .55092 .56705 .56083 .56087 .54581 Mtetra
.3 .379 .777 r
.56087 .54581 .56705 .56083 .57888 .57145 .57265 .55437 Mtetra
.35 .386 .758 r
.57265 .55437 .57888 .57145 .59086 .58198 .58457 .56281 Mtetra
.409 .403 .742 r
.58457 .56281 .59086 .58198 .60297 .59148 .59659 .57033 Mtetra
.468 .426 .728 r
.59659 .57033 .60297 .59148 .61516 .59897 .60871 .57609 Mtetra
.523 .45 .716 r
.60871 .57609 .61516 .59897 .62739 .60354 .62087 .57934 Mtetra
.571 .474 .706 r
.62087 .57934 .62739 .60354 .63962 .6045 .63303 .57953 Mtetra
.612 .497 .698 r
.63303 .57953 .63962 .6045 .65178 .60148 .64516 .57636 Mtetra
.646 .518 .692 r
.64516 .57636 .65178 .60148 .66383 .59453 .65721 .56988 Mtetra
.675 .537 .689 r
.65721 .56988 .66383 .59453 .67576 .58406 .66916 .56046 Mtetra
.699 .555 .688 r
.66916 .56046 .67576 .58406 .68756 .57082 .68102 .54872 Mtetra
.718 .573 .691 r
.68102 .54872 .68756 .57082 .69925 .5557 .6928 .53544 Mtetra
.733 .591 .697 r
.6928 .53544 .69925 .5557 .71085 .53969 .70452 .52142 Mtetra
.745 .609 .707 r
.70452 .52142 .71085 .53969 .72242 .52368 .71622 .50741 Mtetra
.753 .627 .72 r
.71622 .50741 .72242 .52368 .73399 .50838 .72793 .49401 Mtetra
.758 .646 .738 r
.72793 .49401 .73399 .50838 .74562 .49431 .73969 .48164 Mtetra
.759 .666 .759 r
.73969 .48164 .74562 .49431 .75732 .48173 .75152 .47052 Mtetra
.756 .685 .783 r
.75152 .47052 .75732 .48173 .76912 .47073 .76345 .4607 Mtetra
.749 .703 .808 r
.76345 .4607 .76912 .47073 .78104 .46121 .77548 .45211 Mtetra
.739 .719 .832 r
.77548 .45211 .78104 .46121 .79308 .45299 .78761 .44458 Mtetra
.728 .732 .853 r
.78761 .44458 .79308 .45299 .80523 .44582 .79984 .43791 Mtetra
.717 .741 .871 r
.79984 .43791 .80523 .44582 .81748 .43945 .81215 .43188 Mtetra
.708 .748 .883 r
.81215 .43188 .81748 .43945 .82981 .43364 .82455 .42629 Mtetra
.702 .753 .892 r
.82455 .42629 .82981 .43364 .84222 .42821 .83702 .42098 Mtetra
.698 .757 .897 r
.83702 .42098 .84222 .42821 .8547 .42298 .84955 .41582 Mtetra
.696 .759 .9 r
.84955 .41582 .8547 .42298 .86723 .41784 .86213 .41071 Mtetra
.696 .761 .902 r
.86213 .41071 .86723 .41784 .87982 .41272 .87476 .40559 Mtetra
.697 .762 .902 r
.87476 .40559 .87982 .41272 .89244 .40757 .88743 .40042 Mtetra
.698 .763 .902 r
.88743 .40042 .89244 .40757 .90511 .40236 .90014 .39519 Mtetra
.7 .764 .902 r
.90014 .39519 .90511 .40236 .91781 .39708 .91289 .38988 Mtetra
.701 .765 .901 r
.91289 .38988 .91781 .39708 .93056 .39173 .92567 .38449 Mtetra
.649 .745 .92 r
.33535 .54222 .34193 .5481 .35241 .54517 .34586 .53928 Mtetra
.648 .745 .92 r
.34586 .53928 .35241 .54517 .36294 .54224 .35641 .53634 Mtetra
.647 .746 .921 r
.35641 .53634 .36294 .54224 .3735 .53933 .367 .53341 Mtetra
.646 .746 .922 r
.367 .53341 .3735 .53933 .38412 .53643 .37764 .53051 Mtetra
.644 .746 .923 r
.37764 .53051 .38412 .53643 .39477 .53357 .38833 .52763 Mtetra
.642 .745 .924 r
.38833 .52763 .39477 .53357 .40547 .53075 .39905 .52479 Mtetra
.639 .745 .925 r
.39905 .52479 .40547 .53075 .41622 .528 .40982 .52201 Mtetra
.635 .743 .926 r
.40982 .52201 .41622 .528 .427 .52536 .42064 .51933 Mtetra
.629 .741 .928 r
.42064 .51933 .427 .52536 .43783 .52289 .43149 .51679 Mtetra
.62 .736 .93 r
.43149 .51679 .43783 .52289 .44871 .52066 .4424 .51446 Mtetra
.606 .729 .932 r
.4424 .51446 .44871 .52066 .45963 .5188 .45334 .51245 Mtetra
.588 .718 .934 r
.45334 .51245 .45963 .5188 .47059 .51746 .46434 .51086 Mtetra
.562 .702 .934 r
.46434 .51086 .47059 .51746 .4816 .5168 .47538 .50987 Mtetra
.529 .677 .932 r
.47538 .50987 .4816 .5168 .49267 .51706 .48647 .50963 Mtetra
.488 .644 .926 r
.48647 .50963 .49267 .51706 .5038 .51843 .49762 .51032 Mtetra
.443 .602 .913 r
.49762 .51032 .5038 .51843 .51501 .52111 .50885 .5121 Mtetra
.399 .554 .893 r
.50885 .5121 .51501 .52111 .5263 .52524 .52015 .51509 Mtetra
.366 .507 .867 r
.52015 .51509 .5263 .52524 .5377 .53084 .53155 .51928 Mtetra
.349 .466 .838 r
.53155 .51928 .5377 .53084 .54922 .5378 .54305 .52458 Mtetra
.353 .439 .81 r
.54305 .52458 .54922 .5378 .56087 .54581 .55467 .53072 Mtetra
.376 .425 .785 r
.55467 .53072 .56087 .54581 .57265 .55437 .56641 .53729 Mtetra
.411 .424 .763 r
.56641 .53729 .57265 .55437 .58457 .56281 .57827 .54371 Mtetra
.454 .432 .744 r
.57827 .54371 .58457 .56281 .59659 .57033 .59023 .54933 Mtetra
.498 .446 .729 r
.59023 .54933 .59659 .57033 .60871 .57609 .60227 .55347 Mtetra
.541 .463 .717 r
.60227 .55347 .60871 .57609 .62087 .57934 .61437 .55552 Mtetra
.579 .481 .707 r
.61437 .55552 .62087 .57934 .63303 .57953 .62648 .55503 Mtetra
.613 .499 .7 r
.62648 .55503 .63303 .57953 .64516 .57636 .63857 .55178 Mtetra
.642 .517 .695 r
.63857 .55178 .64516 .57636 .65721 .56988 .65062 .54582 Mtetra
.667 .535 .693 r
.65062 .54582 .65721 .56988 .66916 .56046 .6626 .53746 Mtetra
.688 .552 .694 r
.6626 .53746 .66916 .56046 .68102 .54872 .67452 .52722 Mtetra
.706 .569 .698 r
.67452 .52722 .68102 .54872 .6928 .53544 .68638 .51572 Mtetra
.72 .587 .706 r
.68638 .51572 .6928 .53544 .70452 .52142 .69821 .50362 Mtetra
.731 .605 .716 r
.69821 .50362 .70452 .52142 .71622 .50741 .71003 .49154 Mtetra
.739 .624 .731 r
.71003 .49154 .71622 .50741 .72793 .49401 .72187 .47995 Mtetra
.743 .644 .749 r
.72187 .47995 .72793 .49401 .73969 .48164 .73375 .46919 Mtetra
.744 .663 .771 r
.73375 .46919 .73969 .48164 .75152 .47052 .74571 .45944 Mtetra
.742 .683 .794 r
.74571 .45944 .75152 .47052 .76345 .4607 .75774 .45074 Mtetra
.736 .701 .818 r
.75774 .45074 .76345 .4607 .77548 .45211 .76987 .44301 Mtetra
.727 .716 .84 r
.76987 .44301 .77548 .45211 .78761 .44458 .78209 .43613 Mtetra
.718 .728 .859 r
.78209 .43613 .78761 .44458 .79984 .43791 .7944 .42992 Mtetra
.709 .738 .874 r
.7944 .42992 .79984 .43791 .81215 .43188 .80679 .42419 Mtetra
.702 .745 .885 r
.80679 .42419 .81215 .43188 .82455 .42629 .81925 .4188 Mtetra
.698 .75 .892 r
.81925 .4188 .82455 .42629 .83702 .42098 .83177 .41361 Mtetra
.695 .753 .896 r
.83177 .41361 .83702 .42098 .84955 .41582 .84434 .40851 Mtetra
.694 .756 .899 r
.84434 .40851 .84955 .41582 .86213 .41071 .85697 .40342 Mtetra
.695 .757 .9 r
.85697 .40342 .86213 .41071 .87476 .40559 .86964 .3983 Mtetra
.696 .759 .9 r
.86964 .3983 .87476 .40559 .88743 .40042 .88236 .39312 Mtetra
.698 .76 .9 r
.88236 .39312 .88743 .40042 .90014 .39519 .89511 .38786 Mtetra
.699 .761 .9 r
.89511 .38786 .90014 .39519 .91289 .38988 .90791 .38252 Mtetra
.701 .762 .899 r
.90791 .38252 .91289 .38988 .92567 .38449 .92074 .3771 Mtetra
.649 .745 .919 r
.32873 .53629 .33535 .54222 .34586 .53928 .33926 .53333 Mtetra
.648 .745 .92 r
.33926 .53333 .34586 .53928 .35641 .53634 .34984 .53037 Mtetra
.647 .745 .921 r
.34984 .53037 .35641 .53634 .367 .53341 .36046 .52744 Mtetra
.646 .745 .922 r
.36046 .52744 .367 .53341 .37764 .53051 .37112 .52452 Mtetra
.644 .745 .922 r
.37112 .52452 .37764 .53051 .38833 .52763 .38183 .52162 Mtetra
.642 .745 .923 r
.38183 .52162 .38833 .52763 .39905 .52479 .39258 .51876 Mtetra
.64 .744 .924 r
.39258 .51876 .39905 .52479 .40982 .52201 .40338 .51596 Mtetra
.636 .743 .925 r
.40338 .51596 .40982 .52201 .42064 .51933 .41422 .51323 Mtetra
.631 .74 .927 r
.41422 .51323 .42064 .51933 .43149 .51679 .42511 .51063 Mtetra
.623 .737 .928 r
.42511 .51063 .43149 .51679 .4424 .51446 .43604 .5082 Mtetra
.612 .731 .93 r
.43604 .5082 .4424 .51446 .45334 .51245 .44701 .50603 Mtetra
.597 .721 .931 r
.44701 .50603 .45334 .51245 .46434 .51086 .45803 .50421 Mtetra
.577 .707 .931 r
.45803 .50421 .46434 .51086 .47538 .50987 .4691 .50288 Mtetra
.551 .687 .929 r
.4691 .50288 .47538 .50987 .48647 .50963 .48023 .50216 Mtetra
.521 .659 .923 r
.48023 .50216 .48647 .50963 .49762 .51032 .4914 .5022 Mtetra
.487 .625 .911 r
.4914 .5022 .49762 .51032 .50885 .5121 .50265 .50313 Mtetra
.455 .585 .894 r
.50265 .50313 .50885 .5121 .52015 .51509 .51396 .50502 Mtetra
.43 .545 .872 r
.51396 .50502 .52015 .51509 .53155 .51928 .52536 .50788 Mtetra
.416 .509 .846 r
.52536 .50788 .53155 .51928 .54305 .52458 .53686 .51161 Mtetra
.418 .482 .819 r
.53686 .51161 .54305 .52458 .55467 .53072 .54846 .51601 Mtetra
.432 .465 .793 r
.54846 .51601 .55467 .53072 .56641 .53729 .56017 .52072 Mtetra
.458 .458 .771 r
.56017 .52072 .56641 .53729 .57827 .54371 .57198 .52528 Mtetra
.489 .459 .751 r
.57198 .52528 .57827 .54371 .59023 .54933 .58388 .52918 Mtetra
.522 .467 .735 r
.58388 .52918 .59023 .54933 .60227 .55347 .59587 .53186 Mtetra
.555 .478 .723 r
.59587 .53186 .60227 .55347 .61437 .55552 .60791 .53284 Mtetra
.586 .491 .713 r
.60791 .53284 .61437 .55552 .62648 .55503 .61998 .53178 Mtetra
.615 .506 .707 r
.61998 .53178 .62648 .55503 .63857 .55178 .63204 .52851 Mtetra
.64 .521 .703 r
.63204 .52851 .63857 .55178 .65062 .54582 .64409 .52307 Mtetra
.661 .537 .702 r
.64409 .52307 .65062 .54582 .6626 .53746 .6561 .51572 Mtetra
.68 .553 .704 r
.6561 .51572 .6626 .53746 .67452 .52722 .66807 .50688 Mtetra
.696 .57 .709 r
.66807 .50688 .67452 .52722 .68638 .51572 .68001 .49703 Mtetra
.709 .587 .717 r
.68001 .49703 .68638 .51572 .69821 .50362 .69193 .4867 Mtetra
.719 .606 .729 r
.69193 .4867 .69821 .50362 .71003 .49154 .70386 .47638 Mtetra
.726 .625 .745 r
.70386 .47638 .71003 .49154 .72187 .47995 .71581 .46645 Mtetra
.73 .644 .763 r
.71581 .46645 .72187 .47995 .73375 .46919 .72782 .45716 Mtetra
.731 .664 .784 r
.72782 .45716 .73375 .46919 .74571 .45944 .73988 .44865 Mtetra
.728 .683 .806 r
.73988 .44865 .74571 .45944 .75774 .45074 .75202 .44095 Mtetra
.723 .7 .828 r
.75202 .44095 .75774 .45074 .76987 .44301 .76424 .434 Mtetra
.716 .715 .848 r
.76424 .434 .76987 .44301 .78209 .43613 .77655 .42769 Mtetra
.708 .727 .864 r
.77655 .42769 .78209 .43613 .7944 .42992 .78892 .42188 Mtetra
.702 .736 .877 r
.78892 .42188 .7944 .42992 .80679 .42419 .80138 .41643 Mtetra
.697 .742 .886 r
.80138 .41643 .80679 .42419 .81925 .4188 .81389 .41121 Mtetra
.694 .747 .892 r
.81389 .41121 .81925 .4188 .83177 .41361 .82646 .40611 Mtetra
.693 .75 .896 r
.82646 .40611 .83177 .41361 .84434 .40851 .83909 .40105 Mtetra
.693 .752 .897 r
.83909 .40105 .84434 .40851 .85697 .40342 .85176 .39598 Mtetra
.694 .754 .898 r
.85176 .39598 .85697 .40342 .86964 .3983 .86448 .39085 Mtetra
.695 .756 .898 r
.86448 .39085 .86964 .3983 .88236 .39312 .87724 .38565 Mtetra
.697 .757 .898 r
.87724 .38565 .88236 .39312 .89511 .38786 .89004 .38037 Mtetra
.699 .758 .898 r
.89004 .38037 .89511 .38786 .90791 .38252 .90287 .37501 Mtetra
.701 .759 .897 r
.90287 .37501 .90791 .38252 .92074 .3771 .91575 .36956 Mtetra
.648 .744 .919 r
.32206 .53029 .32873 .53629 .33926 .53333 .33261 .52731 Mtetra
.648 .744 .92 r
.33261 .52731 .33926 .53333 .34984 .53037 .34321 .52435 Mtetra
.647 .744 .92 r
.34321 .52435 .34984 .53037 .36046 .52744 .35386 .5214 Mtetra
.645 .744 .921 r
.35386 .5214 .36046 .52744 .37112 .52452 .36455 .51846 Mtetra
.644 .744 .922 r
.36455 .51846 .37112 .52452 .38183 .52162 .37528 .51555 Mtetra
.642 .744 .923 r
.37528 .51555 .38183 .52162 .39258 .51876 .38606 .51267 Mtetra
.64 .743 .924 r
.38606 .51267 .39258 .51876 .40338 .51596 .39689 .50983 Mtetra
.637 .742 .925 r
.39689 .50983 .40338 .51596 .41422 .51323 .40776 .50707 Mtetra
.632 .74 .926 r
.40776 .50707 .41422 .51323 .42511 .51063 .41867 .5044 Mtetra
.626 .737 .927 r
.41867 .5044 .42511 .51063 .43604 .5082 .42963 .50188 Mtetra
.618 .732 .928 r
.42963 .50188 .43604 .5082 .44701 .50603 .44063 .49956 Mtetra
.606 .724 .929 r
.44063 .49956 .44701 .50603 .45803 .50421 .45169 .49753 Mtetra
.59 .712 .928 r
.45169 .49753 .45803 .50421 .4691 .50288 .46279 .49588 Mtetra
.571 .696 .926 r
.46279 .49588 .4691 .50288 .48023 .50216 .47394 .49472 Mtetra
.548 .673 .92 r
.47394 .49472 .48023 .50216 .4914 .5022 .48514 .49416 Mtetra
.522 .645 .911 r
.48514 .49416 .4914 .5022 .50265 .50313 .49641 .4943 Mtetra
.498 .612 .896 r
.49641 .4943 .50265 .50313 .51396 .50502 .50774 .4952 Mtetra
.479 .578 .876 r
.50774 .4952 .51396 .50502 .52536 .50788 .51915 .49685 Mtetra
.468 .546 .853 r
.51915 .49685 .52536 .50788 .53686 .51161 .53065 .49917 Mtetra
.467 .52 .828 r
.53065 .49917 .53686 .51161 .54846 .51601 .54223 .502 Mtetra
.477 .501 .804 r
.54223 .502 .54846 .51601 .56017 .52072 .55392 .50506 Mtetra
.494 .49 .781 r
.55392 .50506 .56017 .52072 .57198 .52528 .5657 .50798 Mtetra
.517 .487 .762 r
.5657 .50798 .57198 .52528 .58388 .52918 .57756 .51036 Mtetra
.542 .489 .746 r
.57756 .51036 .58388 .52918 .59587 .53186 .5895 .51177 Mtetra
.568 .496 .733 r
.5895 .51177 .59587 .53186 .60791 .53284 .6015 .51184 Mtetra
.593 .505 .724 r
.6015 .51184 .60791 .53284 .61998 .53178 .61353 .51031 Mtetra
.617 .517 .718 r
.61353 .51031 .61998 .53178 .63204 .52851 .62558 .50705 Mtetra
.638 .53 .714 r
.62558 .50705 .63204 .52851 .64409 .52307 .63763 .50211 Mtetra
.657 .544 .714 r
.63763 .50211 .64409 .52307 .6561 .51572 .64966 .49568 Mtetra
.674 .559 .717 r
.64966 .49568 .6561 .51572 .66807 .50688 .66168 .48808 Mtetra
.688 .575 .723 r
.66168 .48808 .66807 .50688 .68001 .49703 .67369 .47969 Mtetra
.699 .592 .732 r
.67369 .47969 .68001 .49703 .69193 .4867 .6857 .47093 Mtetra
.709 .61 .745 r
.6857 .47093 .69193 .4867 .70386 .47638 .69773 .46216 Mtetra
.715 .629 .761 r
.69773 .46216 .70386 .47638 .71581 .46645 .70978 .45367 Mtetra
.718 .649 .779 r
.70978 .45367 .71581 .46645 .72782 .45716 .72189 .44565 Mtetra
.719 .668 .799 r
.72189 .44565 .72782 .45716 .73988 .44865 .73405 .43822 Mtetra
.716 .686 .82 r
.73405 .43822 .73988 .44865 .75202 .44095 .74628 .43139 Mtetra
.712 .702 .839 r
.74628 .43139 .75202 .44095 .76424 .434 .75859 .42511 Mtetra
.706 .716 .856 r
.75859 .42511 .76424 .434 .77655 .42769 .77097 .41929 Mtetra
.7 .726 .87 r
.77097 .41929 .77655 .42769 .78892 .42188 .78341 .41382 Mtetra
.696 .734 .881 r
.78341 .41382 .78892 .42188 .80138 .41643 .79592 .40859 Mtetra
.692 .74 .888 r
.79592 .40859 .80138 .41643 .81389 .41121 .80849 .40351 Mtetra
.691 .744 .892 r
.80849 .40351 .81389 .41121 .82646 .40611 .82111 .39848 Mtetra
.691 .747 .895 r
.82111 .39848 .82646 .40611 .83909 .40105 .83379 .39346 Mtetra
.691 .75 .896 r
.83379 .39346 .83909 .40105 .85176 .39598 .84651 .3884 Mtetra
.693 .752 .897 r
.84651 .3884 .85176 .39598 .86448 .39085 .85927 .38326 Mtetra
.695 .753 .897 r
.85927 .38326 .86448 .39085 .87724 .38565 .87207 .37804 Mtetra
.697 .754 .896 r
.87207 .37804 .87724 .38565 .89004 .38037 .88491 .37274 Mtetra
.698 .755 .896 r
.88491 .37274 .89004 .38037 .90287 .37501 .89779 .36735 Mtetra
.7 .756 .895 r
.89779 .36735 .90287 .37501 .91575 .36956 .91071 .36188 Mtetra
.648 .743 .919 r
.31533 .52423 .32206 .53029 .33261 .52731 .32592 .52124 Mtetra
.647 .743 .92 r
.32592 .52124 .33261 .52731 .34321 .52435 .33654 .51826 Mtetra
.646 .744 .92 r
.33654 .51826 .34321 .52435 .35386 .5214 .34721 .51529 Mtetra
.645 .744 .921 r
.34721 .51529 .35386 .5214 .36455 .51846 .35793 .51234 Mtetra
.644 .743 .921 r
.35793 .51234 .36455 .51846 .37528 .51555 .36869 .50941 Mtetra
.642 .743 .922 r
.36869 .50941 .37528 .51555 .38606 .51267 .3795 .50651 Mtetra
.64 .743 .923 r
.3795 .50651 .38606 .51267 .39689 .50983 .39035 .50364 Mtetra
.637 .742 .924 r
.39035 .50364 .39689 .50983 .40776 .50707 .40124 .50083 Mtetra
.634 .74 .925 r
.40124 .50083 .40776 .50707 .41867 .5044 .41218 .49811 Mtetra
.629 .738 .926 r
.41218 .49811 .41867 .5044 .42963 .50188 .42317 .4955 Mtetra
.622 .733 .926 r
.42317 .4955 .42963 .50188 .44063 .49956 .43421 .49305 Mtetra
.613 .727 .927 r
.43421 .49305 .44063 .49956 .45169 .49753 .44529 .49083 Mtetra
.601 .717 .926 r
.44529 .49083 .45169 .49753 .46279 .49588 .45642 .4889 Mtetra
.586 .704 .924 r
.45642 .4889 .46279 .49588 .47394 .49472 .4676 .48735 Mtetra
.569 .686 .919 r
.4676 .48735 .47394 .49472 .48514 .49416 .47883 .48627 Mtetra
.551 .663 .911 r
.47883 .48627 .48514 .49416 .49641 .4943 .49012 .48571 Mtetra
.533 .636 .898 r
.49012 .48571 .49641 .4943 .50774 .4952 .50148 .48574 Mtetra
.518 .607 .882 r
.50148 .48574 .50774 .4952 .51915 .49685 .5129 .48633 Mtetra
.509 .579 .862 r
.5129 .48633 .51915 .49685 .53065 .49917 .52441 .48744 Mtetra
.507 .555 .839 r
.52441 .48744 .53065 .49917 .54223 .502 .53599 .48892 Mtetra
.512 .535 .817 r
.53599 .48892 .54223 .502 .55392 .50506 .54766 .49056 Mtetra
.524 .522 .795 r
.54766 .49056 .55392 .50506 .5657 .50798 .55942 .49208 Mtetra
.54 .515 .777 r
.55942 .49208 .5657 .50798 .57756 .51036 .57126 .49317 Mtetra
.56 .514 .761 r
.57126 .49317 .57756 .51036 .5895 .51177 .58317 .49351 Mtetra
.58 .517 .748 r
.58317 .49351 .5895 .51177 .6015 .51184 .59513 .49283 Mtetra
.6 .523 .739 r
.59513 .49283 .6015 .51184 .61353 .51031 .60715 .49092 Mtetra
.62 .532 .733 r
.60715 .49092 .61353 .51031 .62558 .50705 .61918 .48769 Mtetra
.638 .543 .73 r
.61918 .48769 .62558 .50705 .63763 .50211 .63124 .48319 Mtetra
.654 .555 .731 r
.63124 .48319 .63763 .50211 .64966 .49568 .6433 .47755 Mtetra
.669 .569 .734 r
.6433 .47755 .64966 .49568 .66168 .48808 .65536 .47101 Mtetra
.681 .585 .741 r
.65536 .47101 .66168 .48808 .67369 .47969 .66743 .46387 Mtetra
.691 .602 .751 r
.66743 .46387 .67369 .47969 .6857 .47093 .67951 .45644 Mtetra
.699 .619 .764 r
.67951 .45644 .6857 .47093 .69773 .46216 .69162 .44897 Mtetra
.705 .638 .779 r
.69162 .44897 .69773 .46216 .70978 .45367 .70377 .44169 Mtetra
.707 .656 .797 r
.70377 .44169 .70978 .45367 .72189 .44565 .71596 .43475 Mtetra
.707 .674 .816 r
.71596 .43475 .72189 .44565 .73405 .43822 .72822 .42821 Mtetra
.705 .691 .834 r
.72822 .42821 .73405 .43822 .74628 .43139 .74053 .4221 Mtetra
.701 .705 .85 r
.74053 .4221 .74628 .43139 .75859 .42511 .75291 .41636 Mtetra
.697 .717 .865 r
.75291 .41636 .75859 .42511 .77097 .41929 .76535 .41094 Mtetra
.693 .727 .876 r
.76535 .41094 .77097 .41929 .78341 .41382 .77786 .40575 Mtetra
.69 .734 .884 r
.77786 .40575 .78341 .41382 .79592 .40859 .79042 .4007 Mtetra
.689 .739 .889 r
.79042 .4007 .79592 .40859 .80849 .40351 .80305 .39572 Mtetra
.688 .743 .893 r
.80305 .39572 .80849 .40351 .82111 .39848 .81572 .39075 Mtetra
.689 .745 .894 r
.81572 .39075 .82111 .39848 .83379 .39346 .82843 .38575 Mtetra
.69 .748 .895 r
.82843 .38575 .83379 .39346 .84651 .3884 .8412 .38068 Mtetra
.692 .749 .895 r
.8412 .38068 .84651 .3884 .85927 .38326 .854 .37553 Mtetra
.694 .751 .895 r
.854 .37553 .85927 .38326 .87207 .37804 .86685 .37029 Mtetra
.696 .752 .895 r
.86685 .37029 .87207 .37804 .88491 .37274 .87973 .36497 Mtetra
.698 .753 .894 r
.87973 .36497 .88491 .37274 .89779 .36735 .89266 .35955 Mtetra
.699 .754 .894 r
.89266 .35955 .89779 .36735 .91071 .36188 .90563 .35406 Mtetra
.648 .743 .919 r
.30856 .51811 .31533 .52423 .32592 .52124 .31917 .5151 Mtetra
.647 .743 .919 r
.31917 .5151 .32592 .52124 .33654 .51826 .32982 .5121 Mtetra
.646 .743 .92 r
.32982 .5121 .33654 .51826 .34721 .51529 .34052 .50912 Mtetra
.645 .743 .92 r
.34052 .50912 .34721 .51529 .35793 .51234 .35126 .50615 Mtetra
.644 .743 .921 r
.35126 .50615 .35793 .51234 .36869 .50941 .36205 .5032 Mtetra
.642 .742 .922 r
.36205 .5032 .36869 .50941 .3795 .50651 .37288 .50027 Mtetra
.64 .742 .922 r
.37288 .50027 .3795 .50651 .39035 .50364 .38376 .49738 Mtetra
.638 .741 .923 r
.38376 .49738 .39035 .50364 .40124 .50083 .39468 .49454 Mtetra
.635 .74 .924 r
.39468 .49454 .40124 .50083 .41218 .49811 .40565 .49176 Mtetra
.631 .738 .925 r
.40565 .49176 .41218 .49811 .42317 .4955 .41667 .48907 Mtetra
.626 .734 .925 r
.41667 .48907 .42317 .4955 .43421 .49305 .42773 .48651 Mtetra
.619 .729 .925 r
.42773 .48651 .43421 .49305 .44529 .49083 .43884 .48412 Mtetra
.61 .722 .925 r
.43884 .48412 .44529 .49083 .45642 .4889 .45 .48195 Mtetra
.599 .711 .923 r
.45 .48195 .45642 .4889 .4676 .48735 .46121 .48007 Mtetra
.586 .697 .919 r
.46121 .48007 .4676 .48735 .47883 .48627 .47248 .47854 Mtetra
.573 .679 .912 r
.47248 .47854 .47883 .48627 .49012 .48571 .48379 .4774 Mtetra
.559 .657 .902 r
.48379 .4774 .49012 .48571 .50148 .48574 .49517 .47669 Mtetra
.548 .633 .888 r
.49517 .47669 .50148 .48574 .5129 .48633 .50662 .47641 Mtetra
.541 .609 .871 r
.50662 .47641 .5129 .48633 .52441 .48744 .51813 .4765 Mtetra
.538 .587 .852 r
.51813 .4765 .52441 .48744 .53599 .48892 .52973 .47685 Mtetra
.541 .568 .831 r
.52973 .47685 .53599 .48892 .54766 .49056 .5414 .47732 Mtetra
.549 .554 .812 r
.5414 .47732 .54766 .49056 .55942 .49208 .55314 .47769 Mtetra
.561 .545 .794 r
.55314 .47769 .55942 .49208 .57126 .49317 .56497 .47772 Mtetra
.575 .541 .779 r
.56497 .47772 .57126 .49317 .58317 .49351 .57686 .4772 Mtetra
.591 .541 .767 r
.57686 .4772 .58317 .49351 .59513 .49283 .58881 .4759 Mtetra
.607 .544 .758 r
.58881 .4759 .59513 .49283 .60715 .49092 .60081 .47369 Mtetra
.623 .551 .753 r
.60081 .47369 .60715 .49092 .61918 .48769 .61284 .47051 Mtetra
.638 .56 .75 r
.61284 .47051 .61918 .48769 .63124 .48319 .62491 .46636 Mtetra
.652 .571 .751 r
.62491 .46636 .63124 .48319 .6433 .47755 .63699 .46137 Mtetra
.665 .584 .755 r
.63699 .46137 .6433 .47755 .65536 .47101 .64909 .45571 Mtetra
.675 .599 .762 r
.64909 .45571 .65536 .47101 .66743 .46387 .66122 .44959 Mtetra
.684 .615 .772 r
.66122 .44959 .66743 .46387 .67951 .45644 .67337 .44323 Mtetra
.691 .631 .785 r
.67337 .44323 .67951 .45644 .69162 .44897 .68555 .43682 Mtetra
.695 .649 .799 r
.68555 .43682 .69162 .44897 .70377 .44169 .69777 .43052 Mtetra
.697 .666 .816 r
.69777 .43052 .70377 .44169 .71596 .43475 .71005 .42443 Mtetra
.697 .682 .832 r
.71005 .42443 .71596 .43475 .72822 .42821 .72237 .41862 Mtetra
.695 .697 .847 r
.72237 .41862 .72822 .42821 .74053 .4221 .73476 .41307 Mtetra
.693 .71 .861 r
.73476 .41307 .74053 .4221 .75291 .41636 .7472 .40777 Mtetra
.69 .72 .872 r
.7472 .40777 .75291 .41636 .76535 .41094 .75971 .40266 Mtetra
.688 .728 .881 r
.75971 .40266 .76535 .41094 .77786 .40575 .77227 .39767 Mtetra
.686 .734 .887 r
.77227 .39767 .77786 .40575 .79042 .4007 .78489 .39275 Mtetra
.686 .738 .891 r
.78489 .39275 .79042 .4007 .80305 .39572 .79756 .38785 Mtetra
.686 .741 .893 r
.79756 .38785 .80305 .39572 .81572 .39075 .81027 .38291 Mtetra
.688 .744 .894 r
.81027 .38291 .81572 .39075 .82843 .38575 .82303 .37792 Mtetra
.689 .746 .894 r
.82303 .37792 .82843 .38575 .8412 .38068 .83584 .37284 Mtetra
.692 .747 .894 r
.83584 .37284 .8412 .38068 .854 .37553 .84869 .36768 Mtetra
.694 .748 .894 r
.84869 .36768 .854 .37553 .86685 .37029 .86158 .36241 Mtetra
.696 .75 .893 r
.86158 .36241 .86685 .37029 .87973 .36497 .87451 .35706 Mtetra
.697 .751 .893 r
.87451 .35706 .87973 .36497 .89266 .35955 .88748 .35162 Mtetra
.699 .752 .893 r
.88748 .35162 .89266 .35955 .90563 .35406 .90049 .34611 Mtetra
.648 .742 .918 r
.30174 .51192 .30856 .51811 .31917 .5151 .31238 .50889 Mtetra
.647 .742 .919 r
.31238 .50889 .31917 .5151 .32982 .5121 .32305 .50588 Mtetra
.646 .742 .919 r
.32305 .50588 .32982 .5121 .34052 .50912 .33378 .50288 Mtetra
.645 .742 .92 r
.33378 .50288 .34052 .50912 .35126 .50615 .34454 .49989 Mtetra
.644 .742 .921 r
.34454 .49989 .35126 .50615 .36205 .5032 .35535 .49692 Mtetra
.642 .742 .921 r
.35535 .49692 .36205 .5032 .37288 .50027 .36621 .49397 Mtetra
.64 .741 .922 r
.36621 .49397 .37288 .50027 .38376 .49738 .37712 .49105 Mtetra
.638 .741 .923 r
.37712 .49105 .38376 .49738 .39468 .49454 .38807 .48817 Mtetra
.636 .74 .923 r
.38807 .48817 .39468 .49454 .40565 .49176 .39907 .48535 Mtetra
.633 .738 .924 r
.39907 .48535 .40565 .49176 .41667 .48907 .41011 .48259 Mtetra
.629 .735 .924 r
.41011 .48259 .41667 .48907 .42773 .48651 .42121 .47993 Mtetra
.623 .731 .924 r
.42121 .47993 .42773 .48651 .43884 .48412 .43235 .4774 Mtetra
.617 .725 .924 r
.43235 .4774 .43884 .48412 .45 .48195 .44354 .47504 Mtetra
.609 .717 .922 r
.44354 .47504 .45 .48195 .46121 .48007 .45478 .47288 Mtetra
.599 .706 .919 r
.45478 .47288 .46121 .48007 .47248 .47854 .46607 .47098 Mtetra
.589 .692 .913 r
.46607 .47098 .47248 .47854 .48379 .4774 .47742 .46937 Mtetra
.58 .675 .905 r
.47742 .46937 .48379 .4774 .49517 .47669 .48882 .46807 Mtetra
.571 .656 .894 r
.48882 .46807 .49517 .47669 .50662 .47641 .50029 .46707 Mtetra
.565 .636 .88 r
.50029 .46707 .50662 .47641 .51813 .4765 .51183 .46634 Mtetra
.563 .617 .864 r
.51183 .46634 .51813 .4765 .52973 .47685 .52343 .4658 Mtetra
.564 .6 .847 r
.52343 .4658 .52973 .47685 .5414 .47732 .53511 .46532 Mtetra
.57 .586 .83 r
.53511 .46532 .5414 .47732 .55314 .47769 .54686 .46477 Mtetra
.578 .576 .814 r
.54686 .46477 .55314 .47769 .56497 .47772 .55867 .46398 Mtetra
.589 .57 .8 r
.55867 .46398 .56497 .47772 .57686 .4772 .57056 .46276 Mtetra
.601 .568 .789 r
.57056 .46276 .57686 .4772 .58881 .4759 .5825 .46099 Mtetra
.614 .57 .781 r
.5825 .46099 .58881 .4759 .60081 .47369 .5945 .45854 Mtetra
.627 .574 .775 r
.5945 .45854 .60081 .47369 .61284 .47051 .60654 .45539 Mtetra
.64 .582 .773 r
.60654 .45539 .61284 .47051 .62491 .46636 .61862 .45153 Mtetra
.651 .591 .774 r
.61862 .45153 .62491 .46636 .63699 .46137 .63073 .44706 Mtetra
.662 .603 .779 r
.63073 .44706 .63699 .46137 .64909 .45571 .64287 .44208 Mtetra
.671 .616 .786 r
.64287 .44208 .64909 .45571 .66122 .44959 .65504 .43675 Mtetra
.678 .631 .795 r
.65504 .43675 .66122 .44959 .67337 .44323 .66725 .43122 Mtetra
.683 .646 .807 r
.66725 .43122 .67337 .44323 .68555 .43682 .6795 .42564 Mtetra
.687 .662 .82 r
.6795 .42564 .68555 .43682 .69777 .43052 .69179 .4201 Mtetra
.688 .677 .834 r
.69179 .4201 .69777 .43052 .71005 .42443 .70413 .41468 Mtetra
.688 .691 .848 r
.70413 .41468 .71005 .42443 .72237 .41862 .71652 .40941 Mtetra
.687 .704 .86 r
.71652 .40941 .72237 .41862 .73476 .41307 .72897 .4043 Mtetra
.686 .714 .871 r
.72897 .4043 .73476 .41307 .7472 .40777 .74147 .39932 Mtetra
.684 .723 .879 r
.74147 .39932 .7472 .40777 .75971 .40266 .75403 .39443 Mtetra
.683 .729 .885 r
.75403 .39443 .75971 .40266 .77227 .39767 .76664 .38959 Mtetra
.683 .734 .889 r
.76664 .38959 .77227 .39767 .78489 .39275 .77931 .38476 Mtetra
.684 .738 .892 r
.77931 .38476 .78489 .39275 .79756 .38785 .79202 .3799 Mtetra
.685 .741 .893 r
.79202 .3799 .79756 .38785 .81027 .38291 .80478 .37499 Mtetra
.687 .743 .894 r
.80478 .37499 .81027 .38291 .82303 .37792 .81759 .36999 Mtetra
.689 .744 .894 r
.81759 .36999 .82303 .37792 .83584 .37284 .83044 .36489 Mtetra
.691 .746 .893 r
.83044 .36489 .83584 .37284 .84869 .36768 .84333 .3597 Mtetra
.693 .747 .893 r
.84333 .3597 .84869 .36768 .86158 .36241 .85626 .35441 Mtetra
.695 .748 .892 r
.85626 .35441 .86158 .36241 .87451 .35706 .86923 .34903 Mtetra
.697 .749 .892 r
.86923 .34903 .87451 .35706 .88748 .35162 .88224 .34357 Mtetra
.698 .75 .891 r
.88224 .34357 .88748 .35162 .90049 .34611 .8953 .33803 Mtetra
.647 .741 .918 r
.29487 .50566 .30174 .51192 .31238 .50889 .30553 .50262 Mtetra
.30553 .50262 .31238 .50889 .32305 .50588 .31623 .49959 Mtetra
.646 .741 .919 r
.31623 .49959 .32305 .50588 .33378 .50288 .32698 .49656 Mtetra
.645 .741 .919 r
.32698 .49656 .33378 .50288 .34454 .49989 .33777 .49356 Mtetra
.643 .741 .92 r
.33777 .49356 .34454 .49989 .35535 .49692 .34861 .49057 Mtetra
.642 .741 .921 r
.34861 .49057 .35535 .49692 .36621 .49397 .3595 .4876 Mtetra
.641 .741 .921 r
.3595 .4876 .36621 .49397 .37712 .49105 .37043 .48465 Mtetra
.639 .74 .922 r
.37043 .48465 .37712 .49105 .38807 .48817 .38141 .48174 Mtetra
.637 .739 .922 r
.38141 .48174 .38807 .48817 .39907 .48535 .39243 .47887 Mtetra
.634 .738 .923 r
.39243 .47887 .39907 .48535 .41011 .48259 .40351 .47606 Mtetra
.631 .736 .923 r
.40351 .47606 .41011 .48259 .42121 .47993 .41463 .47332 Mtetra
.627 .733 .923 r
.41463 .47332 .42121 .47993 .43235 .4774 .4258 .47067 Mtetra
.622 .728 .923 r
.4258 .47067 .43235 .4774 .44354 .47504 .43702 .46815 Mtetra
.616 .722 .922 r
.43702 .46815 .44354 .47504 .45478 .47288 .44829 .46578 Mtetra
.609 .714 .919 r
.44829 .46578 .45478 .47288 .46607 .47098 .45962 .46359 Mtetra
.602 .703 .915 r
.45962 .46359 .46607 .47098 .47742 .46937 .47099 .4616 Mtetra
.595 .69 .909 r
.47099 .4616 .47742 .46937 .48882 .46807 .48243 .45984 Mtetra
.589 .676 .9 r
.48243 .45984 .48882 .46807 .50029 .46707 .49392 .45828 Mtetra
.585 .66 .889 r
.49392 .45828 .50029 .46707 .51183 .46634 .50548 .45691 Mtetra
.582 .644 .877 r
.50548 .45691 .51183 .46634 .52343 .4658 .5171 .45567 Mtetra
.583 .629 .863 r
.5171 .45567 .52343 .4658 .53511 .46532 .52879 .45447 Mtetra
.587 .616 .848 r
.52879 .45447 .53511 .46532 .54686 .46477 .54055 .45321 Mtetra
.593 .606 .835 r
.54055 .45321 .54686 .46477 .55867 .46398 .55237 .45177 Mtetra
.601 .6 .823 r
.55237 .45177 .55867 .46398 .57056 .46276 .56426 .45003 Mtetra
.61 .597 .813 r
.56426 .45003 .57056 .46276 .5825 .46099 .57621 .44788 Mtetra
.62 .597 .805 r
.57621 .44788 .5825 .46099 .5945 .45854 .58821 .44526 Mtetra
.631 .6 .801 r
.58821 .44526 .5945 .45854 .60654 .45539 .60027 .44212 Mtetra
.641 .606 .799 r
.60027 .44212 .60654 .45539 .61862 .45153 .61236 .43848 Mtetra
.65 .614 .8 r
.61236 .43848 .61862 .45153 .63073 .44706 .6245 .43439 Mtetra
.659 .624 .804 r
.6245 .43439 .63073 .44706 .64287 .44208 .63668 .42993 Mtetra
.666 .636 .81 r
.63668 .42993 .64287 .44208 .65504 .43675 .64889 .42519 Mtetra
.672 .649 .819 r
.64889 .42519 .65504 .43675 .66725 .43122 .66115 .42029 Mtetra
.676 .662 .829 r
.66115 .42029 .66725 .43122 .6795 .42564 .67345 .41531 Mtetra
.679 .676 .84 r
.67345 .41531 .6795 .42564 .69179 .4201 .6858 .41034 Mtetra
.68 .689 .851 r
.6858 .41034 .69179 .4201 .70413 .41468 .6982 .4054 Mtetra
.681 .701 .862 r
.6982 .4054 .70413 .41468 .71652 .40941 .71064 .40054 Mtetra
.68 .711 .871 r
.71064 .40054 .71652 .40941 .72897 .4043 .72315 .39574 Mtetra
.68 .719 .879 r
.72315 .39574 .72897 .4043 .74147 .39932 .7357 .39098 Mtetra
.68 .726 .885 r
.7357 .39098 .74147 .39932 .75403 .39443 .74831 .38625 Mtetra
.68 .731 .889 r
.74831 .38625 .75403 .39443 .76664 .38959 .76097 .38151 Mtetra
.681 .735 .891 r
.76097 .38151 .76664 .38959 .77931 .38476 .77368 .37674 Mtetra
.682 .738 .893 r
.77368 .37674 .77931 .38476 .79202 .3799 .78644 .3719 Mtetra
.684 .74 .893 r
.78644 .3719 .79202 .3799 .80478 .37499 .79925 .36697 Mtetra
.686 .742 .893 r
.79925 .36697 .80478 .37499 .81759 .36999 .81209 .36196 Mtetra
.688 .743 .893 r
.81209 .36196 .81759 .36999 .83044 .36489 .82498 .35684 Mtetra
.691 .744 .892 r
.82498 .35684 .83044 .36489 .84333 .3597 .83792 .35162 Mtetra
.693 .745 .892 r
.83792 .35162 .84333 .3597 .85626 .35441 .85089 .34631 Mtetra
.695 .746 .891 r
.85089 .34631 .85626 .35441 .86923 .34903 .86391 .3409 Mtetra
.696 .747 .891 r
.86391 .3409 .86923 .34903 .88224 .34357 .87696 .3354 Mtetra
.698 .748 .891 r
.87696 .3354 .88224 .34357 .8953 .33803 .89007 .32984 Mtetra
.647 .741 .917 r
.28795 .49934 .29487 .50566 .30553 .50262 .29864 .49628 Mtetra
.646 .741 .918 r
.29864 .49628 .30553 .50262 .31623 .49959 .30936 .49322 Mtetra
.645 .741 .918 r
.30936 .49322 .31623 .49959 .32698 .49656 .32014 .49018 Mtetra
.644 .74 .919 r
.32014 .49018 .32698 .49656 .33777 .49356 .33096 .48715 Mtetra
.643 .74 .919 r
.33096 .48715 .33777 .49356 .34861 .49057 .34182 .48414 Mtetra
.642 .74 .92 r
.34182 .48414 .34861 .49057 .3595 .4876 .35273 .48115 Mtetra
.641 .74 .921 r
.35273 .48115 .3595 .4876 .37043 .48465 .36369 .47818 Mtetra
.639 .739 .921 r
.36369 .47818 .37043 .48465 .38141 .48174 .37469 .47524 Mtetra
.637 .739 .922 r
.37469 .47524 .38141 .48174 .39243 .47887 .38575 .47233 Mtetra
.635 .738 .922 r
.38575 .47233 .39243 .47887 .40351 .47606 .39685 .46947 Mtetra
.632 .736 .923 r
.39685 .46947 .40351 .47606 .41463 .47332 .408 .46666 Mtetra
.629 .734 .923 r
.408 .46666 .41463 .47332 .4258 .47067 .4192 .46392 Mtetra
.626 .731 .922 r
.4192 .46392 .4258 .47067 .43702 .46815 .43045 .46127 Mtetra
.621 .726 .922 r
.43045 .46127 .43702 .46815 .44829 .46578 .44175 .45873 Mtetra
.616 .72 .92 r
.44175 .45873 .44829 .46578 .45962 .46359 .45311 .45632 Mtetra
.611 .712 .917 r
.45311 .45632 .45962 .46359 .47099 .4616 .46452 .45405 Mtetra
.606 .703 .912 r
.46452 .45405 .47099 .4616 .48243 .45984 .47598 .45193 Mtetra
.602 .692 .906 r
.47598 .45193 .48243 .45984 .49392 .45828 .4875 .44996 Mtetra
.599 .679 .898 r
.4875 .44996 .49392 .45828 .50548 .45691 .49909 .44811 Mtetra
.597 .667 .888 r
.49909 .44811 .50548 .45691 .5171 .45567 .51073 .44634 Mtetra
.597 .655 .877 r
.51073 .44634 .5171 .45567 .52879 .45447 .52244 .4446 Mtetra
.6 .644 .866 r
.52244 .4446 .52879 .45447 .54055 .45321 .53421 .4428 Mtetra
.604 .635 .855 r
.53421 .4428 .54055 .45321 .55237 .45177 .54605 .44088 Mtetra
.61 .629 .845 r
.54605 .44088 .55237 .45177 .56426 .45003 .55795 .43874 Mtetra
.617 .626 .836 r
.55795 .43874 .56426 .45003 .57621 .44788 .56991 .43632 Mtetra
.625 .625 .83 r
.56991 .43632 .57621 .44788 .58821 .44526 .58193 .43355 Mtetra
.634 .627 .826 r
.58193 .43355 .58821 .44526 .60027 .44212 .594 .43042 Mtetra
.642 .631 .825 r
.594 .43042 .60027 .44212 .61236 .43848 .60612 .42693 Mtetra
.649 .638 .826 r
.60612 .42693 .61236 .43848 .6245 .43439 .61828 .42311 Mtetra
.656 .647 .829 r
.61828 .42311 .6245 .43439 .63668 .42993 .63049 .41902 Mtetra
.662 .657 .834 r
.63049 .41902 .63668 .42993 .64889 .42519 .64275 .41471 Mtetra
.667 .667 .841 r
.64275 .41471 .64889 .42519 .66115 .42029 .65505 .41025 Mtetra
.67 .679 .849 r
.65505 .41025 .66115 .42029 .67345 .41531 .6674 .40571 Mtetra
.673 .69 .858 r
.6674 .40571 .67345 .41531 .6858 .41034 .6798 .40113 Mtetra
.674 .7 .866 r
.6798 .40113 .6858 .41034 .6982 .4054 .69225 .39654 Mtetra
.675 .709 .874 r
.69225 .39654 .6982 .4054 .71064 .40054 .70475 .39195 Mtetra
.675 .717 .881 r
.70475 .39195 .71064 .40054 .72315 .39574 .7173 .38736 Mtetra
.676 .724 .886 r
.7173 .38736 .72315 .39574 .7357 .39098 .72991 .38275 Mtetra
.677 .729 .89 r
.72991 .38275 .7357 .39098 .74831 .38625 .74256 .37812 Mtetra
.678 .733 .892 r
.74256 .37812 .74831 .38625 .76097 .38151 .75527 .37343 Mtetra
.679 .736 .893 r
.75527 .37343 .76097 .38151 .77368 .37674 .76802 .36867 Mtetra
.681 .738 .894 r
.76802 .36867 .77368 .37674 .78644 .3719 .78082 .36383 Mtetra
.684 .74 .894 r
.78082 .36383 .78644 .3719 .79925 .36697 .79366 .35889 Mtetra
.686 .742 .893 r
.79366 .35889 .79925 .36697 .81209 .36196 .80655 .35385 Mtetra
.688 .743 .893 r
.80655 .35385 .81209 .36196 .82498 .35684 .81949 .3487 Mtetra
.691 .744 .892 r
.81949 .3487 .82498 .35684 .83792 .35162 .83246 .34345 Mtetra
.693 .745 .891 r
.83246 .34345 .83792 .35162 .85089 .34631 .84548 .3381 Mtetra
.694 .745 .891 r
.84548 .3381 .85089 .34631 .86391 .3409 .85854 .33266 Mtetra
.696 .746 .89 r
.85854 .33266 .86391 .3409 .87696 .3354 .87164 .32714 Mtetra
.697 .747 .89 r
.87164 .32714 .87696 .3354 .89007 .32984 .88478 .32155 Mtetra
.647 .74 .917 r
.28098 .49295 .28795 .49934 .29864 .49628 .29169 .48986 Mtetra
.646 .74 .917 r
.29169 .48986 .29864 .49628 .30936 .49322 .30244 .48679 Mtetra
.645 .74 .918 r
.30244 .48679 .30936 .49322 .32014 .49018 .31324 .48372 Mtetra
.644 .74 .918 r
.31324 .48372 .32014 .49018 .33096 .48715 .32409 .48068 Mtetra
.643 .739 .919 r
.32409 .48068 .33096 .48715 .34182 .48414 .33498 .47764 Mtetra
.642 .739 .919 r
.33498 .47764 .34182 .48414 .35273 .48115 .34591 .47463 Mtetra
.641 .739 .92 r
.34591 .47463 .35273 .48115 .36369 .47818 .3569 .47163 Mtetra
.639 .739 .921 r
.3569 .47163 .36369 .47818 .37469 .47524 .36793 .46866 Mtetra
.638 .738 .921 r
.36793 .46866 .37469 .47524 .38575 .47233 .37901 .46572 Mtetra
.636 .737 .922 r
.37901 .46572 .38575 .47233 .39685 .46947 .39014 .46281 Mtetra
.634 .736 .922 r
.39014 .46281 .39685 .46947 .408 .46666 .40132 .45995 Mtetra
.631 .734 .922 r
.40132 .45995 .408 .46666 .4192 .46392 .41255 .45714 Mtetra
.628 .732 .922 r
.41255 .45714 .4192 .46392 .43045 .46127 .42383 .4544 Mtetra
.625 .729 .922 r
.42383 .4544 .43045 .46127 .44175 .45873 .43517 .45173 Mtetra
.621 .725 .92 r
.43517 .45173 .44175 .45873 .45311 .45632 .44655 .44915 Mtetra
.618 .719 .918 r
.44655 .44915 .45311 .45632 .46452 .45405 .45799 .44667 Mtetra
.614 .712 .915 r
.45799 .44667 .46452 .45405 .47598 .45193 .46948 .44429 Mtetra
.611 .704 .911 r
.46948 .44429 .47598 .45193 .4875 .44996 .48103 .44201 Mtetra
.609 .695 .905 r
.48103 .44201 .4875 .44996 .49909 .44811 .49264 .43981 Mtetra
.608 .686 .898 r
.49264 .43981 .49909 .44811 .51073 .44634 .50431 .43766 Mtetra
.608 .677 .89 r
.50431 .43766 .51073 .44634 .52244 .4446 .51605 .43552 Mtetra
.61 .668 .881 r
.51605 .43552 .52244 .4446 .53421 .4428 .52784 .43334 Mtetra
.613 .661 .873 r
.52784 .43334 .53421 .4428 .54605 .44088 .5397 .43106 Mtetra
.617 .656 .865 r
.5397 .43106 .54605 .44088 .55795 .43874 .55162 .42863 Mtetra
.623 .653 .859 r
.55162 .42863 .55795 .43874 .56991 .43632 .5636 .426 Mtetra
.629 .652 .853 r
.5636 .426 .56991 .43632 .58193 .43355 .57563 .42313 Mtetra
.635 .653 .85 r
.57563 .42313 .58193 .43355 .594 .43042 .58772 .41999 Mtetra
.642 .656 .849 r
.58772 .41999 .594 .43042 .60612 .42693 .59987 .4166 Mtetra
.648 .662 .849 r
.59987 .4166 .60612 .42693 .61828 .42311 .61206 .41296 Mtetra
.653 .668 .852 r
.61206 .41296 .61828 .42311 .63049 .41902 .62431 .40912 Mtetra
.658 .676 .856 r
.62431 .40912 .63049 .41902 .64275 .41471 .6366 .40509 Mtetra
.662 .685 .861 r
.6366 .40509 .64275 .41471 .65505 .41025 .64895 .40094 Mtetra
.665 .694 .867 r
.64895 .40094 .65505 .41025 .6674 .40571 .66134 .39669 Mtetra
.667 .702 .873 r
.66134 .39669 .6674 .40571 .6798 .40113 .67378 .39237 Mtetra
.669 .71 .879 r
.67378 .39237 .6798 .40113 .69225 .39654 .68628 .388 Mtetra
.67 .718 .884 r
.68628 .388 .69225 .39654 .70475 .39195 .69882 .38359 Mtetra
.672 .724 .888 r
.69882 .38359 .70475 .39195 .7173 .38736 .71142 .37912 Mtetra
.673 .728 .891 r
.71142 .37912 .7173 .38736 .72991 .38275 .72407 .3746 Mtetra
.675 .732 .893 r
.72407 .3746 .72991 .38275 .74256 .37812 .73677 .37002 Mtetra
.677 .735 .895 r
.73677 .37002 .74256 .37812 .75527 .37343 .74952 .36535 Mtetra
.679 .738 .895 r
.74952 .36535 .75527 .37343 .76802 .36867 .76231 .36059 Mtetra
.681 .739 .895 r
.76231 .36059 .76802 .36867 .78082 .36383 .77515 .35572 Mtetra
.684 .741 .894 r
.77515 .35572 .78082 .36383 .79366 .35889 .78804 .35075 Mtetra
.686 .742 .894 r
.78804 .35075 .79366 .35889 .80655 .35385 .80097 .34567 Mtetra
.688 .743 .893 r
.80097 .34567 .80655 .35385 .81949 .3487 .81394 .34049 Mtetra
.69 .743 .892 r
.81394 .34049 .81949 .3487 .83246 .34345 .82696 .3352 Mtetra
.692 .744 .891 r
.82696 .3352 .83246 .34345 .84548 .3381 .84002 .32981 Mtetra
.694 .745 .89 r
.84002 .32981 .84548 .3381 .85854 .33266 .85312 .32434 Mtetra
.696 .746 .89 r
.85312 .32434 .85854 .33266 .87164 .32714 .86627 .31878 Mtetra
.697 .746 .89 r
.86627 .31878 .87164 .32714 .88478 .32155 .87946 .31316 Mtetra
.647 .739 .917 r
.27396 .48649 .28098 .49295 .29169 .48986 .28469 .48338 Mtetra
.646 .739 .917 r
.28469 .48338 .29169 .48986 .30244 .48679 .29547 .48028 Mtetra
.645 .739 .917 r
.29547 .48028 .30244 .48679 .31324 .48372 .30629 .4772 Mtetra
.644 .739 .918 r
.30629 .4772 .31324 .48372 .32409 .48068 .31716 .47412 Mtetra
.643 .739 .918 r
.31716 .47412 .32409 .48068 .33498 .47764 .32808 .47107 Mtetra
.642 .738 .919 r
.32808 .47107 .33498 .47764 .34591 .47463 .33905 .46803 Mtetra
.641 .738 .919 r
.33905 .46803 .34591 .47463 .3569 .47163 .35006 .46501 Mtetra
.639 .738 .92 r
.35006 .46501 .3569 .47163 .36793 .46866 .36112 .46201 Mtetra
.638 .737 .921 r
.36112 .46201 .36793 .46866 .37901 .46572 .37223 .45904 Mtetra
.636 .737 .921 r
.37223 .45904 .37901 .46572 .39014 .46281 .38338 .4561 Mtetra
.634 .736 .921 r
.38338 .4561 .39014 .46281 .40132 .45995 .39459 .45319 Mtetra
.632 .735 .922 r
.39459 .45319 .40132 .45995 .41255 .45714 .40585 .45033 Mtetra
.63 .733 .922 r
.40585 .45033 .41255 .45714 .42383 .4544 .41716 .44751 Mtetra
.627 .731 .922 r
.41716 .44751 .42383 .4544 .43517 .45173 .42852 .44475 Mtetra
.625 .728 .921 r
.42852 .44475 .43517 .45173 .44655 .44915 .43994 .44205 Mtetra
.622 .724 .92 r
.43994 .44205 .44655 .44915 .45799 .44667 .45141 .43941 Mtetra
.62 .719 .917 r
.45141 .43941 .45799 .44667 .46948 .44429 .46293 .43685 Mtetra
.617 .714 .914 r
.46293 .43685 .46948 .44429 .48103 .44201 .47451 .43434 Mtetra
.616 .708 .911 r
.47451 .43434 .48103 .44201 .49264 .43981 .48615 .43189 Mtetra
.615 .701 .906 r
.48615 .43189 .49264 .43981 .50431 .43766 .49785 .42947 Mtetra
.615 .694 .9 r
.49785 .42947 .50431 .43766 .51605 .43552 .50961 .42705 Mtetra
.616 .688 .894 r
.50961 .42705 .51605 .43552 .52784 .43334 .52143 .42459 Mtetra
.619 .683 .888 r
.52143 .42459 .52784 .43334 .5397 .43106 .53331 .42207 Mtetra
.622 .679 .883 r
.53331 .42207 .5397 .43106 .55162 .42863 .54525 .41943 Mtetra
.627 .676 .878 r
.54525 .41943 .55162 .42863 .5636 .426 .55725 .41664 Mtetra
.631 .675 .874 r
.55725 .41664 .5636 .426 .57563 .42313 .56931 .41369 Mtetra
.636 .676 .871 r
.56931 .41369 .57563 .42313 .58772 .41999 .58143 .41054 Mtetra
.641 .679 .87 r
.58143 .41054 .58772 .41999 .59987 .4166 .5936 .4072 Mtetra
.646 .683 .87 r
.5936 .4072 .59987 .4166 .61206 .41296 .60583 .40368 Mtetra
.651 .688 .872 r
.60583 .40368 .61206 .41296 .62431 .40912 .61811 .39999 Mtetra
.655 .694 .875 r
.61811 .39999 .62431 .40912 .6366 .40509 .63044 .39615 Mtetra
.658 .701 .878 r
.63044 .39615 .6366 .40509 .64895 .40094 .64282 .39218 Mtetra
.661 .707 .882 r
.64282 .39218 .64895 .40094 .66134 .39669 .65525 .38811 Mtetra
.663 .714 .886 r
.65525 .38811 .66134 .39669 .67378 .39237 .66774 .38396 Mtetra
.665 .72 .889 r
.66774 .38396 .67378 .39237 .68628 .388 .68028 .37972 Mtetra
.667 .725 .892 r
.68028 .37972 .68628 .388 .69882 .38359 .69287 .3754 Mtetra
.669 .729 .894 r
.69287 .3754 .69882 .38359 .71142 .37912 .70551 .371 Mtetra
.671 .733 .896 r
.70551 .371 .71142 .37912 .72407 .3746 .7182 .36652 Mtetra
.674 .735 .897 r
.7182 .36652 .72407 .3746 .73677 .37002 .73094 .36194 Mtetra
.676 .738 .897 r
.73094 .36194 .73677 .37002 .74952 .36535 .74373 .35726 Mtetra
.679 .739 .897 r
.74373 .35726 .74952 .36535 .76231 .36059 .75656 .35248 Mtetra
.681 .741 .896 r
.75656 .35248 .76231 .36059 .77515 .35572 .76944 .34758 Mtetra
.684 .742 .895 r
.76944 .34758 .77515 .35572 .78804 .35075 .78237 .34257 Mtetra
.686 .742 .894 r
.78237 .34257 .78804 .35075 .80097 .34567 .79534 .33744 Mtetra
.689 .743 .893 r
.79534 .33744 .80097 .34567 .81394 .34049 .80835 .33221 Mtetra
.691 .744 .892 r
.80835 .33221 .81394 .34049 .82696 .3352 .82141 .32688 Mtetra
.693 .744 .891 r
.82141 .32688 .82696 .3352 .84002 .32981 .83451 .32145 Mtetra
.694 .745 .89 r
.83451 .32145 .84002 .32981 .85312 .32434 .84766 .31594 Mtetra
.696 .745 .89 r
.84766 .31594 .85312 .32434 .86627 .31878 .86085 .31035 Mtetra
.697 .746 .889 r
.86085 .31035 .86627 .31878 .87946 .31316 .87408 .3047 Mtetra
.647 .739 .916 r
.26688 .47996 .27396 .48649 .28469 .48338 .27764 .47683 Mtetra
.646 .739 .916 r
.27764 .47683 .28469 .48338 .29547 .48028 .28845 .4737 Mtetra
.645 .738 .917 r
.28845 .4737 .29547 .48028 .30629 .4772 .2993 .47059 Mtetra
.644 .738 .917 r
.2993 .47059 .30629 .4772 .31716 .47412 .31019 .46749 Mtetra
.643 .738 .918 r
.31019 .46749 .31716 .47412 .32808 .47107 .32114 .46441 Mtetra
.642 .738 .918 r
.32114 .46441 .32808 .47107 .33905 .46803 .33213 .46135 Mtetra
.641 .737 .919 r
.33213 .46135 .33905 .46803 .35006 .46501 .34316 .45831 Mtetra
.639 .737 .919 r
.34316 .45831 .35006 .46501 .36112 .46201 .35425 .45528 Mtetra
.638 .737 .92 r
.35425 .45528 .36112 .46201 .37223 .45904 .36539 .45228 Mtetra
.636 .736 .92 r
.36539 .45228 .37223 .45904 .38338 .4561 .37657 .44931 Mtetra
.635 .736 .921 r
.37657 .44931 .38338 .4561 .39459 .45319 .38781 .44637 Mtetra
.633 .735 .921 r
.38781 .44637 .39459 .45319 .40585 .45033 .3991 .44346 Mtetra
.631 .734 .922 r
.3991 .44346 .40585 .45033 .41716 .44751 .41044 .44059 Mtetra
.629 .732 .922 r
.41044 .44059 .41716 .44751 .42852 .44475 .42183 .43775 Mtetra
.627 .73 .921 r
.42183 .43775 .42852 .44475 .43994 .44205 .43327 .43497 Mtetra
.625 .728 .921 r
.43327 .43497 .43994 .44205 .45141 .43941 .44477 .43223 Mtetra
.623 .724 .919 r
.44477 .43223 .45141 .43941 .46293 .43685 .45633 .42953 Mtetra
.621 .721 .918 r
.45633 .42953 .46293 .43685 .47451 .43434 .46794 .42687 Mtetra
.62 .717 .915 r
.46794 .42687 .47451 .43434 .48615 .43189 .47961 .42425 Mtetra
.62 .712 .912 r
.47961 .42425 .48615 .43189 .49785 .42947 .49133 .42164 Mtetra
.62 .708 .908 r
.49133 .42164 .49785 .42947 .50961 .42705 .50312 .41902 Mtetra
.621 .704 .904 r
.50312 .41902 .50961 .42705 .52143 .42459 .51497 .41638 Mtetra
.623 .7 .9 r
.51497 .41638 .52143 .42459 .53331 .42207 .52688 .41368 Mtetra
.625 .697 .896 r
.52688 .41368 .53331 .42207 .54525 .41943 .53884 .4109 Mtetra
.629 .695 .893 r
.53884 .4109 .54525 .41943 .55725 .41664 .55087 .408 Mtetra
.632 .695 .89 r
.55087 .408 .55725 .41664 .56931 .41369 .56296 .40498 Mtetra
.636 .695 .888 r
.56296 .40498 .56931 .41369 .58143 .41054 .57511 .40181 Mtetra
.64 .697 .887 r
.57511 .40181 .58143 .41054 .5936 .4072 .58731 .3985 Mtetra
.644 .7 .887 r
.58731 .3985 .5936 .4072 .60583 .40368 .59957 .39504 Mtetra
.648 .704 .888 r
.59957 .39504 .60583 .40368 .61811 .39999 .61188 .39143 Mtetra
.652 .709 .889 r
.61188 .39143 .61811 .39999 .63044 .39615 .62425 .3877 Mtetra
.655 .714 .891 r
.62425 .3877 .63044 .39615 .64282 .39218 .63667 .38384 Mtetra
.658 .719 .893 r
.63667 .38384 .64282 .39218 .65525 .38811 .64914 .37987 Mtetra
.66 .723 .896 r
.64914 .37987 .65525 .38811 .66774 .38396 .66167 .3758 Mtetra
.663 .727 .897 r
.66167 .3758 .66774 .38396 .68028 .37972 .67424 .37163 Mtetra
.665 .731 .899 r
.67424 .37163 .68028 .37972 .69287 .3754 .68687 .36735 Mtetra
.668 .734 .899 r
.68687 .36735 .69287 .3754 .70551 .371 .69956 .36298 Mtetra
.671 .737 .9 r
.69956 .36298 .70551 .371 .7182 .36652 .71229 .35849 Mtetra
.673 .739 .9 r
.71229 .35849 .7182 .36652 .73094 .36194 .72507 .3539 Mtetra
.676 .74 .899 r
.72507 .3539 .73094 .36194 .74373 .35726 .73789 .34919 Mtetra
.679 .741 .898 r
.73789 .34919 .74373 .35726 .75656 .35248 .75077 .34436 Mtetra
.682 .742 .897 r
.75077 .34436 .75656 .35248 .76944 .34758 .76369 .33941 Mtetra
.684 .743 .896 r
.76369 .33941 .76944 .34758 .78237 .34257 .77666 .33435 Mtetra
.687 .744 .895 r
.77666 .33435 .78237 .34257 .79534 .33744 .78967 .32918 Mtetra
.689 .744 .893 r
.78967 .32918 .79534 .33744 .80835 .33221 .80272 .3239 Mtetra
.691 .745 .892 r
.80272 .3239 .80835 .33221 .82141 .32688 .81582 .31851 Mtetra
.693 .745 .891 r
.81582 .31851 .82141 .32688 .83451 .32145 .82897 .31304 Mtetra
.694 .745 .891 r
.82897 .31304 .83451 .32145 .84766 .31594 .84215 .30748 Mtetra
.696 .746 .89 r
.84215 .30748 .84766 .31594 .86085 .31035 .85539 .30186 Mtetra
.697 .746 .89 r
.85539 .30186 .86085 .31035 .87408 .3047 .86867 .29616 Mtetra
.647 .738 .916 r
.25976 .47336 .26688 .47996 .27764 .47683 .27054 .4702 Mtetra
.646 .738 .916 r
.27054 .4702 .27764 .47683 .28845 .4737 .28137 .46705 Mtetra
.645 .738 .916 r
.28137 .46705 .28845 .4737 .2993 .47059 .29225 .46391 Mtetra
.644 .737 .917 r
.29225 .46391 .2993 .47059 .31019 .46749 .30317 .46079 Mtetra
.643 .737 .917 r
.30317 .46079 .31019 .46749 .32114 .46441 .31414 .45769 Mtetra
.642 .737 .918 r
.31414 .45769 .32114 .46441 .33213 .46135 .32515 .4546 Mtetra
.641 .737 .918 r
.32515 .4546 .33213 .46135 .34316 .45831 .33622 .45153 Mtetra
.639 .736 .919 r
.33622 .45153 .34316 .45831 .35425 .45528 .34733 .44848 Mtetra
.638 .736 .919 r
.34733 .44848 .35425 .45528 .36539 .45228 .3585 .44545 Mtetra
.636 .736 .92 r
.3585 .44545 .36539 .45228 .37657 .44931 .36971 .44245 Mtetra
.635 .735 .92 r
.36971 .44245 .37657 .44931 .38781 .44637 .38097 .43948 Mtetra
.633 .734 .921 r
.38097 .43948 .38781 .44637 .3991 .44346 .39229 .43653 Mtetra
.632 .734 .921 r
.39229 .43653 .3991 .44346 .41044 .44059 .40366 .43362 Mtetra
.63 .733 .922 r
.40366 .43362 .41044 .44059 .42183 .43775 .41508 .43074 Mtetra
.628 .731 .922 r
.41508 .43074 .42183 .43775 .43327 .43497 .42655 .42789 Mtetra
.626 .73 .921 r
.42655 .42789 .43327 .43497 .44477 .43223 .43808 .42507 Mtetra
.625 .728 .921 r
.43808 .42507 .44477 .43223 .45633 .42953 .44967 .42229 Mtetra
.624 .726 .92 r
.44967 .42229 .45633 .42953 .46794 .42687 .46131 .41953 Mtetra
.623 .723 .918 r
.46131 .41953 .46794 .42687 .47961 .42425 .47301 .41679 Mtetra
.622 .72 .917 r
.47301 .41679 .47961 .42425 .49133 .42164 .48476 .41405 Mtetra
.622 .718 .914 r
.48476 .41405 .49133 .42164 .50312 .41902 .49658 .41131 Mtetra
.623 .715 .912 r
.49658 .41131 .50312 .41902 .51497 .41638 .50846 .40854 Mtetra
.625 .713 .909 r
.50846 .40854 .51497 .41638 .52688 .41368 .52039 .40572 Mtetra
.627 .711 .907 r
.52039 .40572 .52688 .41368 .53884 .4109 .53239 .40283 Mtetra
.629 .71 .904 r
.53239 .40283 .53884 .4109 .55087 .408 .54445 .39986 Mtetra
.632 .71 .902 r
.54445 .39986 .55087 .408 .56296 .40498 .55657 .39679 Mtetra
.636 .711 .901 r
.55657 .39679 .56296 .40498 .57511 .40181 .56874 .3936 Mtetra
.639 .712 .9 r
.56874 .3936 .57511 .40181 .58731 .3985 .58098 .39029 Mtetra
.643 .715 .9 r
.58098 .39029 .58731 .3985 .59957 .39504 .59327 .38686 Mtetra
.646 .717 .9 r
.59327 .38686 .59957 .39504 .61188 .39143 .60562 .3833 Mtetra
.649 .721 .901 r
.60562 .3833 .61188 .39143 .62425 .3877 .61802 .37961 Mtetra
.652 .724 .901 r
.61802 .37961 .62425 .3877 .63667 .38384 .63048 .3758 Mtetra
.656 .728 .902 r
.63048 .3758 .63667 .38384 .64914 .37987 .64299 .37188 Mtetra
.659 .731 .903 r
.64299 .37188 .64914 .37987 .66167 .3758 .65555 .36784 Mtetra
.662 .734 .904 r
.65555 .36784 .66167 .3758 .67424 .37163 .66817 .36369 Mtetra
.665 .737 .904 r
.66817 .36369 .67424 .37163 .68687 .36735 .68084 .35942 Mtetra
.668 .739 .903 r
.68084 .35942 .68687 .36735 .69956 .36298 .69356 .35503 Mtetra
.671 .741 .903 r
.69356 .35503 .69956 .36298 .71229 .35849 .70633 .35052 Mtetra
.674 .742 .902 r
.70633 .35052 .71229 .35849 .72507 .3539 .71915 .34588 Mtetra
.677 .743 .901 r
.71915 .34588 .72507 .3539 .73789 .34919 .73202 .34113 Mtetra
.68 .744 .9 r
.73202 .34113 .73789 .34919 .75077 .34436 .74494 .33624 Mtetra
.682 .745 .898 r
.74494 .33624 .75077 .34436 .76369 .33941 .7579 .33124 Mtetra
.685 .745 .897 r
.7579 .33124 .76369 .33941 .77666 .33435 .7709 .32612 Mtetra
.687 .745 .895 r
.7709 .32612 .77666 .33435 .78967 .32918 .78395 .32089 Mtetra
.69 .746 .894 r
.78395 .32089 .78967 .32918 .80272 .3239 .79705 .31555 Mtetra
.692 .746 .893 r
.79705 .31555 .80272 .3239 .81582 .31851 .81019 .31011 Mtetra
.693 .746 .892 r
.81019 .31011 .81582 .31851 .82897 .31304 .82338 .30459 Mtetra
.695 .746 .891 r
.82338 .30459 .82897 .31304 .84215 .30748 .83661 .29898 Mtetra
.696 .747 .89 r
.83661 .29898 .84215 .30748 .85539 .30186 .84988 .29331 Mtetra
.697 .747 .89 r
.84988 .29331 .85539 .30186 .86867 .29616 .86321 .28758 Mtetra
.647 .738 .915 r
.25258 .46669 .25976 .47336 .27054 .4702 .26339 .4635 Mtetra
.646 .737 .915 r
.26339 .4635 .27054 .4702 .28137 .46705 .27424 .46032 Mtetra
.645 .737 .916 r
.27424 .46032 .28137 .46705 .29225 .46391 .28514 .45716 Mtetra
.644 .737 .916 r
.28514 .45716 .29225 .46391 .30317 .46079 .29609 .45401 Mtetra
.643 .736 .917 r
.29609 .45401 .30317 .46079 .31414 .45769 .30709 .45088 Mtetra
.642 .736 .917 r
.30709 .45088 .31414 .45769 .32515 .4546 .31813 .44777 Mtetra
.641 .736 .918 r
.31813 .44777 .32515 .4546 .33622 .45153 .32922 .44467 Mtetra
.639 .736 .918 r
.32922 .44467 .33622 .45153 .34733 .44848 .34036 .4416 Mtetra
.638 .735 .919 r
.34036 .4416 .34733 .44848 .3585 .44545 .35155 .43855 Mtetra
.636 .735 .919 r
.35155 .43855 .3585 .44545 .36971 .44245 .36279 .43552 Mtetra
.635 .734 .92 r
.36279 .43552 .36971 .44245 .38097 .43948 .37409 .43252 Mtetra
.633 .734 .921 r
.37409 .43252 .38097 .43948 .39229 .43653 .38543 .42955 Mtetra
.632 .733 .921 r
.38543 .42955 .39229 .43653 .40366 .43362 .39683 .4266 Mtetra
.63 .733 .922 r
.39683 .4266 .40366 .43362 .41508 .43074 .40827 .42368 Mtetra
.629 .732 .922 r
.40827 .42368 .41508 .43074 .42655 .42789 .41978 .42079 Mtetra
.627 .731 .922 r
.41978 .42079 .42655 .42789 .43808 .42507 .43134 .41792 Mtetra
.626 .73 .922 r
.43134 .41792 .43808 .42507 .44967 .42229 .44295 .41508 Mtetra
.625 .729 .922 r
.44295 .41508 .44967 .42229 .46131 .41953 .45462 .41225 Mtetra
.624 .727 .921 r
.45462 .41225 .46131 .41953 .47301 .41679 .46635 .40944 Mtetra
.624 .726 .92 r
.46635 .40944 .47301 .41679 .48476 .41405 .47814 .40662 Mtetra
.624 .724 .919 r
.47814 .40662 .48476 .41405 .49658 .41131 .48999 .40379 Mtetra
.624 .723 .917 r
.48999 .40379 .49658 .41131 .50846 .40854 .5019 .40094 Mtetra
.625 .722 .916 r
.5019 .40094 .50846 .40854 .52039 .40572 .51386 .39805 Mtetra
.627 .721 .914 r
.51386 .39805 .52039 .40572 .53239 .40283 .52589 .39509 Mtetra
.629 .721 .913 r
.52589 .39509 .53239 .40283 .54445 .39986 .53798 .39207 Mtetra
.632 .721 .912 r
.53798 .39207 .54445 .39986 .55657 .39679 .55013 .38896 Mtetra
.635 .722 .911 r
.55013 .38896 .55657 .39679 .56874 .3936 .56234 .38575 Mtetra
.638 .723 .91 r
.56234 .38575 .56874 .3936 .58098 .39029 .5746 .38243 Mtetra
.641 .725 .909 r
.5746 .38243 .58098 .39029 .59327 .38686 .58693 .379 Mtetra
.644 .728 .909 r
.58693 .379 .59327 .38686 .60562 .3833 .59931 .37545 Mtetra
.648 .73 .909 r
.59931 .37545 .60562 .3833 .61802 .37961 .61175 .37178 Mtetra
.651 .733 .909 r
.61175 .37178 .61802 .37961 .63048 .3758 .62425 .36799 Mtetra
.654 .735 .909 r
.62425 .36799 .63048 .3758 .64299 .37188 .6368 .36407 Mtetra
.658 .738 .909 r
.6368 .36407 .64299 .37188 .65555 .36784 .6494 .36003 Mtetra
.661 .74 .909 r
.6494 .36003 .65555 .36784 .66817 .36369 .66206 .35587 Mtetra
.664 .742 .908 r
.66206 .35587 .66817 .36369 .68084 .35942 .67477 .35157 Mtetra
.668 .743 .907 r
.67477 .35157 .68084 .35942 .69356 .35503 .68753 .34715 Mtetra
.671 .745 .906 r
.68753 .34715 .69356 .35503 .70633 .35052 .70034 .34259 Mtetra
.674 .746 .904 r
.70034 .34259 .70633 .35052 .71915 .34588 .7132 .33791 Mtetra
.677 .746 .903 r
.7132 .33791 .71915 .34588 .73202 .34113 .7261 .33309 Mtetra
.68 .747 .901 r
.7261 .33309 .73202 .34113 .74494 .33624 .73906 .32815 Mtetra
.683 .747 .9 r
.73906 .32815 .74494 .33624 .7579 .33124 .75206 .32308 Mtetra
.686 .747 .898 r
.75206 .32308 .7579 .33124 .7709 .32612 .7651 .31789 Mtetra
.688 .748 .897 r
.7651 .31789 .7709 .32612 .78395 .32089 .7782 .3126 Mtetra
.69 .748 .895 r
.7782 .3126 .78395 .32089 .79705 .31555 .79133 .30719 Mtetra
.692 .748 .894 r
.79133 .30719 .79705 .31555 .81019 .31011 .80452 .3017 Mtetra
.694 .748 .893 r
.80452 .3017 .81019 .31011 .82338 .30459 .81774 .29611 Mtetra
.695 .748 .892 r
.81774 .29611 .82338 .30459 .83661 .29898 .83102 .29045 Mtetra
.696 .748 .891 r
.83102 .29045 .83661 .29898 .84988 .29331 .84434 .28473 Mtetra
.697 .748 .891 r
.84434 .28473 .84988 .29331 .86321 .28758 .85771 .27894 Mtetra
.647 .737 .915 r
.24534 .45994 .25258 .46669 .26339 .4635 .25618 .45673 Mtetra
.646 .737 .915 r
.25618 .45673 .26339 .4635 .27424 .46032 .26706 .45352 Mtetra
.645 .736 .915 r
.26706 .45352 .27424 .46032 .28514 .45716 .27799 .45033 Mtetra
.644 .736 .916 r
.27799 .45033 .28514 .45716 .29609 .45401 .28896 .44716 Mtetra
.643 .736 .916 r
.28896 .44716 .29609 .45401 .30709 .45088 .29998 .444 Mtetra
.642 .735 .917 r
.29998 .444 .30709 .45088 .31813 .44777 .31105 .44086 Mtetra
.641 .735 .917 r
.31105 .44086 .31813 .44777 .32922 .44467 .32217 .43774 Mtetra
.639 .735 .918 r
.32217 .43774 .32922 .44467 .34036 .4416 .33334 .43464 Mtetra
.638 .734 .918 r
.33334 .43464 .34036 .4416 .35155 .43855 .34456 .43157 Mtetra
.636 .734 .919 r
.34456 .43157 .35155 .43855 .36279 .43552 .35582 .42852 Mtetra
.635 .734 .92 r
.35582 .42852 .36279 .43552 .37409 .43252 .36714 .4255 Mtetra
.633 .734 .92 r
.36714 .4255 .37409 .43252 .38543 .42955 .37852 .4225 Mtetra
.632 .733 .921 r
.37852 .4225 .38543 .42955 .39683 .4266 .38994 .41953 Mtetra
.63 .733 .922 r
.38994 .41953 .39683 .4266 .40827 .42368 .40142 .41658 Mtetra
.629 .732 .922 r
.40142 .41658 .40827 .42368 .41978 .42079 .41295 .41366 Mtetra
.627 .732 .922 r
.41295 .41366 .41978 .42079 .43134 .41792 .42454 .41076 Mtetra
.626 .731 .923 r
.42454 .41076 .43134 .41792 .44295 .41508 .43618 .40788 Mtetra
.625 .731 .923 r
.43618 .40788 .44295 .41508 .45462 .41225 .44788 .40501 Mtetra
.624 .73 .923 r
.44788 .40501 .45462 .41225 .46635 .40944 .45964 .40215 Mtetra
.624 .729 .923 r
.45964 .40215 .46635 .40944 .47814 .40662 .47146 .39928 Mtetra
.624 .729 .922 r
.47146 .39928 .47814 .40662 .48999 .40379 .48334 .3964 Mtetra
.624 .728 .922 r
.48334 .3964 .48999 .40379 .5019 .40094 .49528 .3935 Mtetra
.625 .728 .921 r
.49528 .3935 .5019 .40094 .51386 .39805 .50728 .39056 Mtetra
.627 .728 .92 r
.50728 .39056 .51386 .39805 .52589 .39509 .51934 .38756 Mtetra
.629 .729 .919 r
.51934 .38756 .52589 .39509 .53798 .39207 .53146 .3845 Mtetra
.631 .729 .918 r
.53146 .3845 .53798 .39207 .55013 .38896 .54364 .38137 Mtetra
.634 .73 .918 r
.54364 .38137 .55013 .38896 .56234 .38575 .55588 .37814 Mtetra
.636 .732 .917 r
.55588 .37814 .56234 .38575 .5746 .38243 .56818 .37481 Mtetra
.64 .733 .917 r
.56818 .37481 .5746 .38243 .58693 .379 .58055 .37137 Mtetra
.643 .735 .916 r
.58055 .37137 .58693 .379 .59931 .37545 .59296 .36782 Mtetra
.646 .738 .916 r
.59296 .36782 .59931 .37545 .61175 .37178 .60544 .36414 Mtetra
.65 .74 .915 r
.60544 .36414 .61175 .37178 .62425 .36799 .61797 .36034 Mtetra
.654 .742 .914 r
.61797 .36034 .62425 .36799 .6368 .36407 .63056 .35641 Mtetra
.657 .744 .914 r
.63056 .35641 .6368 .36407 .6494 .36003 .6432 .35235 Mtetra
.661 .745 .913 r
.6432 .35235 .6494 .36003 .66206 .35587 .6559 .34815 Mtetra
.665 .747 .911 r
.6559 .34815 .66206 .35587 .67477 .35157 .66865 .34381 Mtetra
.668 .748 .91 r
.66865 .34381 .67477 .35157 .68753 .34715 .68145 .33934 Mtetra
.672 .749 .908 r
.68145 .33934 .68753 .34715 .70034 .34259 .6943 .33473 Mtetra
.675 .75 .907 r
.6943 .33473 .70034 .34259 .7132 .33791 .7072 .32998 Mtetra
.679 .75 .905 r
.7072 .32998 .7132 .33791 .7261 .33309 .72014 .3251 Mtetra
.682 .75 .903 r
.72014 .3251 .7261 .33309 .73906 .32815 .73314 .32008 Mtetra
.684 .75 .901 r
.73314 .32008 .73906 .32815 .75206 .32308 .74618 .31494 Mtetra
.687 .75 .9 r
.74618 .31494 .75206 .32308 .7651 .31789 .75927 .30968 Mtetra
.689 .75 .898 r
.75927 .30968 .7651 .31789 .7782 .3126 .7724 .30431 Mtetra
.692 .75 .897 r
.7724 .30431 .7782 .3126 .79133 .30719 .78558 .29884 Mtetra
.693 .75 .895 r
.78558 .29884 .79133 .30719 .80452 .3017 .7988 .29327 Mtetra
.695 .75 .894 r
.7988 .29327 .80452 .3017 .81774 .29611 .81207 .28762 Mtetra
.696 .75 .893 r
.81207 .28762 .81774 .29611 .83102 .29045 .82539 .2819 Mtetra
.697 .749 .892 r
.82539 .2819 .83102 .29045 .84434 .28473 .83875 .27612 Mtetra
.698 .749 .891 r
.83875 .27612 .84434 .28473 .85771 .27894 .85216 .27028 Mtetra
.647 .736 .914 r
.23806 .45313 .24534 .45994 .25618 .45673 .24892 .44988 Mtetra
.646 .736 .914 r
.24892 .44988 .25618 .45673 .26706 .45352 .25982 .44665 Mtetra
.645 .736 .915 r
.25982 .44665 .26706 .45352 .27799 .45033 .27078 .44343 Mtetra
.644 .735 .915 r
.27078 .44343 .27799 .45033 .28896 .44716 .28178 .44023 Mtetra
.643 .735 .916 r
.28178 .44023 .28896 .44716 .29998 .444 .29282 .43704 Mtetra
.642 .735 .916 r
.29282 .43704 .29998 .444 .31105 .44086 .30392 .43388 Mtetra
.64 .734 .917 r
.30392 .43388 .31105 .44086 .32217 .43774 .31507 .43073 Mtetra
.639 .734 .917 r
.31507 .43073 .32217 .43774 .33334 .43464 .32626 .42761 Mtetra
.638 .734 .918 r
.32626 .42761 .33334 .43464 .34456 .43157 .33751 .42451 Mtetra
.636 .733 .919 r
.33751 .42451 .34456 .43157 .35582 .42852 .3488 .42144 Mtetra
.634 .733 .919 r
.3488 .42144 .35582 .42852 .36714 .4255 .36015 .4184 Mtetra
.633 .733 .92 r
.36015 .4184 .36714 .4255 .37852 .4225 .37155 .41538 Mtetra
.631 .733 .921 r
.37155 .41538 .37852 .4225 .38994 .41953 .383 .41239 Mtetra
.63 .733 .922 r
.383 .41239 .38994 .41953 .40142 .41658 .39451 .40943 Mtetra
.628 .732 .922 r
.39451 .40943 .40142 .41658 .41295 .41366 .40607 .40649 Mtetra
.627 .732 .923 r
.40607 .40649 .41295 .41366 .42454 .41076 .41768 .40357 Mtetra
.626 .732 .924 r
.41768 .40357 .42454 .41076 .43618 .40788 .42936 .40066 Mtetra
.625 .732 .924 r
.42936 .40066 .43618 .40788 .44788 .40501 .44109 .39777 Mtetra
.624 .732 .924 r
.44109 .39777 .44788 .40501 .45964 .40215 .45288 .39488 Mtetra
.623 .732 .925 r
.45288 .39488 .45964 .40215 .47146 .39928 .46473 .39199 Mtetra
.46473 .39199 .47146 .39928 .48334 .3964 .47664 .38908 Mtetra
.624 .732 .925 r
.47664 .38908 .48334 .3964 .49528 .3935 .48861 .38615 Mtetra
.625 .732 .924 r
.48861 .38615 .49528 .3935 .50728 .39056 .50064 .38319 Mtetra
.626 .733 .924 r
.50064 .38319 .50728 .39056 .51934 .38756 .51273 .38017 Mtetra
.628 .734 .924 r
.51273 .38017 .51934 .38756 .53146 .3845 .52489 .37709 Mtetra
.63 .735 .923 r
.52489 .37709 .53146 .3845 .54364 .38137 .5371 .37393 Mtetra
.632 .736 .923 r
.5371 .37393 .54364 .38137 .55588 .37814 .54938 .37069 Mtetra
.635 .738 .922 r
.54938 .37069 .55588 .37814 .56818 .37481 .56172 .36735 Mtetra
.638 .74 .922 r
.56172 .36735 .56818 .37481 .58055 .37137 .57411 .3639 Mtetra
.642 .742 .921 r
.57411 .3639 .58055 .37137 .59296 .36782 .58657 .36033 Mtetra
.645 .743 .921 r
.58657 .36033 .59296 .36782 .60544 .36414 .59908 .35664 Mtetra
.649 .745 .92 r
.59908 .35664 .60544 .36414 .61797 .36034 .61165 .35282 Mtetra
.653 .747 .919 r
.61165 .35282 .61797 .36034 .63056 .35641 .62428 .34886 Mtetra
.657 .749 .918 r
.62428 .34886 .63056 .35641 .6432 .35235 .63696 .34476 Mtetra
.661 .75 .916 r
.63696 .34476 .6432 .35235 .6559 .34815 .6497 .34052 Mtetra
.665 .751 .915 r
.6497 .34052 .6559 .34815 .66865 .34381 .66249 .33613 Mtetra
.669 .752 .913 r
.66249 .33613 .66865 .34381 .68145 .33934 .67533 .3316 Mtetra
.673 .753 .911 r
.67533 .3316 .68145 .33934 .6943 .33473 .68821 .32693 Mtetra
.676 .754 .909 r
.68821 .32693 .6943 .33473 .7072 .32998 .70115 .32211 Mtetra
.68 .754 .907 r
.70115 .32211 .7072 .32998 .72014 .3251 .71414 .31715 Mtetra
.683 .754 .905 r
.71414 .31715 .72014 .3251 .73314 .32008 .72718 .31206 Mtetra
.686 .754 .903 r
.72718 .31206 .73314 .32008 .74618 .31494 .74026 .30684 Mtetra
.689 .754 .901 r
.74026 .30684 .74618 .31494 .75927 .30968 .75338 .3015 Mtetra
.691 .754 .9 r
.75338 .3015 .75927 .30968 .7724 .30431 .76656 .29606 Mtetra
.693 .753 .898 r
.76656 .29606 .7724 .30431 .78558 .29884 .77978 .2905 Mtetra
.695 .753 .897 r
.77978 .2905 .78558 .29884 .7988 .29327 .79304 .28486 Mtetra
.696 .753 .895 r
.79304 .28486 .7988 .29327 .81207 .28762 .80636 .27914 Mtetra
.697 .752 .894 r
.80636 .27914 .81207 .28762 .82539 .2819 .81971 .27335 Mtetra
.698 .752 .893 r
.81971 .27335 .82539 .2819 .83875 .27612 .83312 .2675 Mtetra
.699 .751 .892 r
.83312 .2675 .83875 .27612 .85216 .27028 .84658 .2616 Mtetra
.648 .736 .914 r
.23071 .44624 .23806 .45313 .24892 .44988 .2416 .44297 Mtetra
.647 .736 .914 r
.2416 .44297 .24892 .44988 .25982 .44665 .25253 .4397 Mtetra
.645 .735 .914 r
.25253 .4397 .25982 .44665 .27078 .44343 .26351 .43646 Mtetra
.644 .735 .915 r
.26351 .43646 .27078 .44343 .28178 .44023 .27454 .43322 Mtetra
.643 .734 .915 r
.27454 .43322 .28178 .44023 .29282 .43704 .28561 .43001 Mtetra
.642 .734 .916 r
.28561 .43001 .29282 .43704 .30392 .43388 .29674 .42682 Mtetra
.64 .734 .916 r
.29674 .42682 .30392 .43388 .31507 .43073 .30791 .42365 Mtetra
.639 .733 .917 r
.30791 .42365 .31507 .43073 .32626 .42761 .31913 .4205 Mtetra
.637 .733 .918 r
.31913 .4205 .32626 .42761 .33751 .42451 .3304 .41738 Mtetra
.636 .733 .918 r
.3304 .41738 .33751 .42451 .3488 .42144 .34172 .41429 Mtetra
.634 .733 .919 r
.34172 .41429 .3488 .42144 .36015 .4184 .3531 .41123 Mtetra
.632 .732 .92 r
.3531 .41123 .36015 .4184 .37155 .41538 .36452 .4082 Mtetra
.631 .732 .921 r
.36452 .4082 .37155 .41538 .383 .41239 .376 .40519 Mtetra
.629 .732 .922 r
.376 .40519 .383 .41239 .39451 .40943 .38754 .40221 Mtetra
.628 .732 .922 r
.38754 .40221 .39451 .40943 .40607 .40649 .39913 .39926 Mtetra
.626 .732 .923 r
.39913 .39926 .40607 .40649 .41768 .40357 .41077 .39633 Mtetra
.625 .732 .924 r
.41077 .39633 .41768 .40357 .42936 .40066 .42248 .39342 Mtetra
.624 .733 .925 r
.42248 .39342 .42936 .40066 .44109 .39777 .43424 .39051 Mtetra
.623 .733 .926 r
.43424 .39051 .44109 .39777 .45288 .39488 .44606 .38762 Mtetra
.622 .733 .926 r
.44606 .38762 .45288 .39488 .46473 .39199 .45794 .38471 Mtetra
.622 .734 .927 r
.45794 .38471 .46473 .39199 .47664 .38908 .46988 .3818 Mtetra
.623 .735 .927 r
.46988 .3818 .47664 .38908 .48861 .38615 .48188 .37886 Mtetra
.48188 .37886 .48861 .38615 .50064 .38319 .49395 .37588 Mtetra
.625 .737 .927 r
.49395 .37588 .50064 .38319 .51273 .38017 .50607 .37285 Mtetra
.626 .738 .927 r
.50607 .37285 .51273 .38017 .52489 .37709 .51826 .36977 Mtetra
.628 .739 .927 r
.51826 .36977 .52489 .37709 .5371 .37393 .53051 .3666 Mtetra
.631 .741 .927 r
.53051 .3666 .5371 .37393 .54938 .37069 .54282 .36335 Mtetra
.634 .743 .927 r
.54282 .36335 .54938 .37069 .56172 .36735 .55519 .36 Mtetra
.637 .745 .926 r
.55519 .36 .56172 .36735 .57411 .3639 .56763 .35654 Mtetra
.641 .747 .926 r
.56763 .35654 .57411 .3639 .58657 .36033 .58012 .35296 Mtetra
.645 .748 .925 r
.58012 .35296 .58657 .36033 .59908 .35664 .59267 .34924 Mtetra
.649 .75 .924 r
.59267 .34924 .59908 .35664 .61165 .35282 .60528 .3454 Mtetra
.653 .752 .923 r
.60528 .3454 .61165 .35282 .62428 .34886 .61795 .34141 Mtetra
.657 .754 .921 r
.61795 .34141 .62428 .34886 .63696 .34476 .63067 .33727 Mtetra
.661 .755 .92 r
.63067 .33727 .63696 .34476 .6497 .34052 .64345 .33298 Mtetra
.666 .756 .918 r
.64345 .33298 .6497 .34052 .66249 .33613 .65628 .32854 Mtetra
.67 .757 .916 r
.65628 .32854 .66249 .33613 .67533 .3316 .66916 .32395 Mtetra
.674 .758 .914 r
.66916 .32395 .67533 .3316 .68821 .32693 .68209 .3192 Mtetra
.678 .758 .912 r
.68209 .3192 .68821 .32693 .70115 .32211 .69507 .31431 Mtetra
.681 .758 .91 r
.69507 .31431 .70115 .32211 .71414 .31715 .70809 .30927 Mtetra
.684 .758 .908 r
.70809 .30927 .71414 .31715 .72718 .31206 .72117 .3041 Mtetra
.687 .758 .905 r
.72117 .3041 .72718 .31206 .74026 .30684 .73429 .29879 Mtetra
.69 .758 .903 r
.73429 .29879 .74026 .30684 .75338 .3015 .74746 .29337 Mtetra
.692 .757 .902 r
.74746 .29337 .75338 .3015 .76656 .29606 .76068 .28784 Mtetra
.694 .757 .9 r
.76068 .28784 .76656 .29606 .77978 .2905 .77394 .2822 Mtetra
.696 .756 .898 r
.77394 .2822 .77978 .2905 .79304 .28486 .78725 .27647 Mtetra
.697 .756 .897 r
.78725 .27647 .79304 .28486 .80636 .27914 .8006 .27067 Mtetra
.698 .755 .895 r
.8006 .27067 .80636 .27914 .81971 .27335 .814 .2648 Mtetra
.699 .754 .894 r
.814 .2648 .81971 .27335 .83312 .2675 .82745 .25887 Mtetra
.7 .754 .894 r
.82745 .25887 .83312 .2675 .84658 .2616 .84095 .2529 Mtetra
.648 .735 .913 r
.22332 .43929 .23071 .44624 .2416 .44297 .23423 .43598 Mtetra
.647 .735 .913 r
.23423 .43598 .2416 .44297 .25253 .4397 .24519 .43269 Mtetra
.646 .735 .914 r
.24519 .43269 .25253 .4397 .26351 .43646 .25619 .42941 Mtetra
.644 .734 .914 r
.25619 .42941 .26351 .43646 .27454 .43322 .26724 .42614 Mtetra
.643 .734 .915 r
.26724 .42614 .27454 .43322 .28561 .43001 .27835 .4229 Mtetra
.642 .733 .915 r
.27835 .4229 .28561 .43001 .29674 .42682 .28949 .41968 Mtetra
.64 .733 .916 r
.28949 .41968 .29674 .42682 .30791 .42365 .30069 .41649 Mtetra
.639 .733 .917 r
.30069 .41649 .30791 .42365 .31913 .4205 .31194 .41332 Mtetra
.637 .732 .917 r
.31194 .41332 .31913 .4205 .3304 .41738 .32324 .41018 Mtetra
.635 .732 .918 r
.32324 .41018 .3304 .41738 .34172 .41429 .33459 .40707 Mtetra
.634 .732 .919 r
.33459 .40707 .34172 .41429 .3531 .41123 .34599 .40399 Mtetra
.632 .732 .92 r
.34599 .40399 .3531 .41123 .36452 .4082 .35745 .40095 Mtetra
.63 .732 .921 r
.35745 .40095 .36452 .4082 .376 .40519 .36895 .39793 Mtetra
.628 .732 .922 r
.36895 .39793 .376 .40519 .38754 .40221 .38052 .39494 Mtetra
.627 .732 .923 r
.38052 .39494 .38754 .40221 .39913 .39926 .39213 .39198 Mtetra
.625 .732 .924 r
.39213 .39198 .39913 .39926 .41077 .39633 .40381 .38905 Mtetra
.624 .732 .925 r
.40381 .38905 .41077 .39633 .42248 .39342 .41554 .38613 Mtetra
.622 .733 .926 r
.41554 .38613 .42248 .39342 .43424 .39051 .42733 .38323 Mtetra
.622 .733 .927 r
.42733 .38323 .43424 .39051 .44606 .38762 .43918 .38034 Mtetra
.621 .734 .928 r
.43918 .38034 .44606 .38762 .45794 .38471 .45109 .37744 Mtetra
.621 .735 .928 r
.45109 .37744 .45794 .38471 .46988 .3818 .46306 .37452 Mtetra
.621 .736 .929 r
.46306 .37452 .46988 .3818 .48188 .37886 .4751 .37159 Mtetra
.622 .737 .93 r
.4751 .37159 .48188 .37886 .49395 .37588 .48719 .36861 Mtetra
.623 .739 .93 r
.48719 .36861 .49395 .37588 .50607 .37285 .49935 .36559 Mtetra
.624 .741 .93 r
.49935 .36559 .50607 .37285 .51826 .36977 .51158 .36251 Mtetra
.627 .742 .93 r
.51158 .36251 .51826 .36977 .53051 .3666 .52386 .35934 Mtetra
.629 .744 .93 r
.52386 .35934 .53051 .3666 .54282 .36335 .53621 .35609 Mtetra
.632 .746 .93 r
.53621 .35609 .54282 .36335 .55519 .36 .54862 .35274 Mtetra
.636 .749 .93 r
.54862 .35274 .55519 .36 .56763 .35654 .56109 .34927 Mtetra
.64 .751 .929 r
.56109 .34927 .56763 .35654 .58012 .35296 .57362 .34567 Mtetra
.644 .753 .928 r
.57362 .34567 .58012 .35296 .59267 .34924 .58621 .34194 Mtetra
.648 .755 .927 r
.58621 .34194 .59267 .34924 .60528 .3454 .59886 .33807 Mtetra
.653 .757 .926 r
.59886 .33807 .60528 .3454 .61795 .34141 .61157 .33405 Mtetra
.657 .758 .924 r
.61157 .33405 .61795 .34141 .63067 .33727 .62433 .32987 Mtetra
.662 .76 .923 r
.62433 .32987 .63067 .33727 .64345 .33298 .63715 .32553 Mtetra
.666 .761 .921 r
.63715 .32553 .64345 .33298 .65628 .32854 .65002 .32103 Mtetra
.671 .762 .919 r
.65002 .32103 .65628 .32854 .66916 .32395 .66294 .31637 Mtetra
.675 .763 .917 r
.66294 .31637 .66916 .32395 .68209 .3192 .67591 .31155 Mtetra
.679 .763 .914 r
.67591 .31155 .68209 .3192 .69507 .31431 .68893 .30658 Mtetra
.683 .763 .912 r
.68893 .30658 .69507 .31431 .70809 .30927 .702 .30146 Mtetra
.686 .763 .91 r
.702 .30146 .70809 .30927 .72117 .3041 .71512 .2962 Mtetra
.689 .763 .908 r
.71512 .2962 .72117 .3041 .73429 .29879 .72829 .29081 Mtetra
.692 .762 .906 r
.72829 .29081 .73429 .29879 .74746 .29337 .7415 .28529 Mtetra
.694 .762 .904 r
.7415 .28529 .74746 .29337 .76068 .28784 .75475 .27966 Mtetra
.696 .761 .902 r
.75475 .27966 .76068 .28784 .77394 .2822 .76806 .27394 Mtetra
.698 .76 .9 r
.76806 .27394 .77394 .2822 .78725 .27647 .78141 .26812 Mtetra
.699 .759 .898 r
.78141 .26812 .78725 .27647 .8006 .27067 .7948 .26223 Mtetra
.7 .758 .897 r
.7948 .26223 .8006 .27067 .814 .2648 .80825 .25627 Mtetra
.701 .757 .896 r
.80825 .25627 .814 .2648 .82745 .25887 .82174 .25026 Mtetra
.701 .756 .895 r
.82174 .25026 .82745 .25887 .84095 .2529 .83528 .24421 Mtetra
.648 .735 .913 r
.21586 .43226 .22332 .43929 .23423 .43598 .2268 .42892 Mtetra
.647 .735 .913 r
.2268 .42892 .23423 .43598 .24519 .43269 .23779 .42559 Mtetra
.646 .734 .913 r
.23779 .42559 .24519 .43269 .25619 .42941 .24882 .42228 Mtetra
.644 .734 .914 r
.24882 .42228 .25619 .42941 .26724 .42614 .2599 .41899 Mtetra
.643 .733 .914 r
.2599 .41899 .26724 .42614 .27835 .4229 .27102 .41572 Mtetra
.642 .733 .915 r
.27102 .41572 .27835 .4229 .28949 .41968 .2822 .41247 Mtetra
.64 .733 .915 r
.2822 .41247 .28949 .41968 .30069 .41649 .29342 .40925 Mtetra
.639 .732 .916 r
.29342 .40925 .30069 .41649 .31194 .41332 .3047 .40606 Mtetra
.637 .732 .917 r
.3047 .40606 .31194 .41332 .32324 .41018 .31602 .4029 Mtetra
.635 .732 .918 r
.31602 .4029 .32324 .41018 .33459 .40707 .3274 .39978 Mtetra
.633 .731 .919 r
.3274 .39978 .33459 .40707 .34599 .40399 .33883 .39668 Mtetra
.631 .731 .92 r
.33883 .39668 .34599 .40399 .35745 .40095 .35031 .39363 Mtetra
.629 .731 .921 r
.35031 .39363 .35745 .40095 .36895 .39793 .36185 .3906 Mtetra
.627 .731 .922 r
.36185 .3906 .36895 .39793 .38052 .39494 .37344 .38761 Mtetra
.625 .731 .923 r
.37344 .38761 .38052 .39494 .39213 .39198 .38508 .38465 Mtetra
.624 .732 .924 r
.38508 .38465 .39213 .39198 .40381 .38905 .39678 .38172 Mtetra
.622 .732 .926 r
.39678 .38172 .40381 .38905 .41554 .38613 .40855 .37881 Mtetra
.621 .733 .927 r
.40855 .37881 .41554 .38613 .42733 .38323 .42037 .37592 Mtetra
.62 .734 .928 r
.42037 .37592 .42733 .38323 .43918 .38034 .43225 .37303 Mtetra
.619 .735 .929 r
.43225 .37303 .43918 .38034 .45109 .37744 .44419 .37015 Mtetra
.619 .736 .93 r
.44419 .37015 .45109 .37744 .46306 .37452 .45619 .36725 Mtetra
.619 .737 .931 r
.45619 .36725 .46306 .37452 .4751 .37159 .46826 .36433 Mtetra
.619 .739 .932 r
.46826 .36433 .4751 .37159 .48719 .36861 .48038 .36137 Mtetra
.621 .741 .932 r
.48038 .36137 .48719 .36861 .49935 .36559 .49258 .35836 Mtetra
.622 .743 .933 r
.49258 .35836 .49935 .36559 .51158 .36251 .50483 .35529 Mtetra
.624 .745 .933 r
.50483 .35529 .51158 .36251 .52386 .35934 .51715 .35214 Mtetra
.627 .747 .933 r
.51715 .35214 .52386 .35934 .53621 .35609 .52954 .34889 Mtetra
.63 .749 .933 r
.52954 .34889 .53621 .35609 .54862 .35274 .54199 .34554 Mtetra
.634 .752 .933 r
.54199 .34554 .54862 .35274 .56109 .34927 .55449 .34207 Mtetra
.638 .754 .932 r
.55449 .34207 .56109 .34927 .57362 .34567 .56707 .33847 Mtetra
.643 .757 .932 r
.56707 .33847 .57362 .34567 .58621 .34194 .5797 .33472 Mtetra
.647 .759 .931 r
.5797 .33472 .58621 .34194 .59886 .33807 .59239 .33083 Mtetra
.652 .761 .929 r
.59239 .33083 .59886 .33807 .61157 .33405 .60513 .32677 Mtetra
.657 .763 .928 r
.60513 .32677 .61157 .33405 .62433 .32987 .61794 .32255 Mtetra
.662 .764 .926 r
.61794 .32255 .62433 .32987 .63715 .32553 .6308 .31816 Mtetra
.667 .766 .924 r
.6308 .31816 .63715 .32553 .65002 .32103 .64371 .31361 Mtetra
.672 .767 .922 r
.64371 .31361 .65002 .32103 .66294 .31637 .65667 .30888 Mtetra
.676 .767 .92 r
.65667 .30888 .66294 .31637 .67591 .31155 .66969 .30399 Mtetra
.68 .768 .917 r
.66969 .30399 .67591 .31155 .68893 .30658 .68275 .29894 Mtetra
.684 .768 .915 r
.68275 .29894 .68893 .30658 .702 .30146 .69587 .29373 Mtetra
.688 .768 .912 r
.69587 .29373 .702 .30146 .71512 .2962 .70903 .28838 Mtetra
.691 .768 .91 r
.70903 .28838 .71512 .2962 .72829 .29081 .72223 .28289 Mtetra
.694 .767 .908 r
.72223 .28289 .72829 .29081 .7415 .28529 .73549 .27728 Mtetra
.696 .766 .906 r
.73549 .27728 .7415 .28529 .75475 .27966 .74879 .27155 Mtetra
.698 .765 .904 r
.74879 .27155 .75475 .27966 .76806 .27394 .76213 .26572 Mtetra
.7 .764 .902 r
.76213 .26572 .76806 .27394 .78141 .26812 .77553 .25981 Mtetra
.701 .763 .9 r
.77553 .25981 .78141 .26812 .7948 .26223 .78897 .25382 Mtetra
.702 .762 .899 r
.78897 .25382 .7948 .26223 .80825 .25627 .80245 .24776 Mtetra
.702 .761 .897 r
.80245 .24776 .80825 .25627 .82174 .25026 .81599 .24166 Mtetra
.702 .759 .896 r
.81599 .24166 .82174 .25026 .83528 .24421 .82958 .23552 Mtetra
.648 .735 .912 r
.20835 .42516 .21586 .43226 .2268 .42892 .21932 .42179 Mtetra
.647 .734 .913 r
.21932 .42179 .2268 .42892 .23779 .42559 .23033 .41843 Mtetra
.646 .734 .913 r
.23033 .41843 .23779 .42559 .24882 .42228 .24139 .41509 Mtetra
.645 .733 .913 r
.24139 .41509 .24882 .42228 .2599 .41899 .25249 .41177 Mtetra
.643 .733 .914 r
.25249 .41177 .2599 .41899 .27102 .41572 .26365 .40847 Mtetra
.642 .732 .915 r
.26365 .40847 .27102 .41572 .2822 .41247 .27485 .40519 Mtetra
.64 .732 .915 r
.27485 .40519 .2822 .41247 .29342 .40925 .2861 .40195 Mtetra
.638 .732 .916 r
.2861 .40195 .29342 .40925 .3047 .40606 .2974 .39873 Mtetra
.636 .731 .917 r
.2974 .39873 .3047 .40606 .31602 .4029 .30875 .39555 Mtetra
.634 .731 .918 r
.30875 .39555 .31602 .4029 .3274 .39978 .32016 .39241 Mtetra
.632 .731 .919 r
.32016 .39241 .3274 .39978 .33883 .39668 .33161 .3893 Mtetra
.63 .731 .92 r
.33161 .3893 .33883 .39668 .35031 .39363 .34312 .38624 Mtetra
.628 .731 .921 r
.34312 .38624 .35031 .39363 .36185 .3906 .35468 .38321 Mtetra
.626 .731 .922 r
.35468 .38321 .36185 .3906 .37344 .38761 .3663 .38022 Mtetra
.624 .731 .923 r
.3663 .38022 .37344 .38761 .38508 .38465 .37797 .37727 Mtetra
.622 .731 .925 r
.37797 .37727 .38508 .38465 .39678 .38172 .3897 .37434 Mtetra
.62 .732 .926 r
.3897 .37434 .39678 .38172 .40855 .37881 .40149 .37144 Mtetra
.619 .733 .928 r
.40149 .37144 .40855 .37881 .42037 .37592 .41334 .36857 Mtetra
.618 .734 .929 r
.41334 .36857 .42037 .37592 .43225 .37303 .42525 .3657 Mtetra
.617 .735 .93 r
.42525 .3657 .43225 .37303 .44419 .37015 .43722 .36284 Mtetra
.616 .736 .932 r
.43722 .36284 .44419 .37015 .45619 .36725 .44926 .35996 Mtetra
.616 .738 .933 r
.44926 .35996 .45619 .36725 .46826 .36433 .46135 .35706 Mtetra
.617 .74 .934 r
.46135 .35706 .46826 .36433 .48038 .36137 .47352 .35413 Mtetra
.618 .742 .935 r
.47352 .35413 .48038 .36137 .49258 .35836 .48574 .35115 Mtetra
.62 .744 .935 r
.48574 .35115 .49258 .35836 .50483 .35529 .49803 .3481 Mtetra
.622 .747 .936 r
.49803 .3481 .50483 .35529 .51715 .35214 .51039 .34497 Mtetra
.625 .749 .936 r
.51039 .34497 .51715 .35214 .52954 .34889 .52281 .34174 Mtetra
.628 .752 .936 r
.52281 .34174 .52954 .34889 .54199 .34554 .5353 .3384 Mtetra
.632 .755 .936 r
.5353 .3384 .54199 .34554 .55449 .34207 .54784 .33494 Mtetra
.637 .758 .936 r
.54784 .33494 .55449 .34207 .56707 .33847 .56045 .33133 Mtetra
.641 .76 .935 r
.56045 .33133 .56707 .33847 .5797 .33472 .57313 .32758 Mtetra
.646 .763 .934 r
.57313 .32758 .5797 .33472 .59239 .33083 .58586 .32366 Mtetra
.652 .765 .932 r
.58586 .32366 .59239 .33083 .60513 .32677 .59865 .31958 Mtetra
.657 .767 .931 r
.59865 .31958 .60513 .32677 .61794 .32255 .61149 .31532 Mtetra
.662 .769 .929 r
.61149 .31532 .61794 .32255 .6308 .31816 .6244 .31088 Mtetra
.667 .77 .927 r
.6244 .31088 .6308 .31816 .64371 .31361 .63735 .30627 Mtetra
.672 .772 .925 r
.63735 .30627 .64371 .31361 .65667 .30888 .65036 .30148 Mtetra
.677 .772 .922 r
.65036 .30148 .65667 .30888 .66969 .30399 .66342 .29651 Mtetra
.682 .773 .92 r
.66342 .29651 .66969 .30399 .68275 .29894 .67653 .29138 Mtetra
.686 .773 .917 r
.67653 .29138 .68275 .29894 .69587 .29373 .68968 .28608 Mtetra
.69 .773 .915 r
.68968 .28608 .69587 .29373 .70903 .28838 .70289 .28064 Mtetra
.693 .772 .912 r
.70289 .28064 .70903 .28838 .72223 .28289 .71614 .27505 Mtetra
.696 .772 .91 r
.71614 .27505 .72223 .28289 .73549 .27728 .72944 .26933 Mtetra
.698 .771 .908 r
.72944 .26933 .73549 .27728 .74879 .27155 .74278 .2635 Mtetra
.7 .77 .906 r
.74278 .2635 .74879 .27155 .76213 .26572 .75617 .25756 Mtetra
.702 .769 .904 r
.75617 .25756 .76213 .26572 .77553 .25981 .7696 .25154 Mtetra
.703 .767 .902 r
.7696 .25154 .77553 .25981 .78897 .25382 .78309 .24544 Mtetra
.704 .766 .9 r
.78309 .24544 .78897 .25382 .80245 .24776 .79662 .23928 Mtetra
.704 .764 .899 r
.79662 .23928 .80245 .24776 .81599 .24166 .8102 .23308 Mtetra
.704 .763 .897 r
.8102 .23308 .81599 .24166 .82958 .23552 .82383 .22684 Mtetra
.648 .734 .912 r
.20079 .418 .20835 .42516 .21932 .42179 .21178 .41459 Mtetra
.647 .734 .912 r
.21178 .41459 .21932 .42179 .23033 .41843 .22281 .4112 Mtetra
.646 .733 .913 r
.22281 .4112 .23033 .41843 .24139 .41509 .2339 .40782 Mtetra
.645 .733 .913 r
.2339 .40782 .24139 .41509 .25249 .41177 .24503 .40447 Mtetra
.643 .732 .914 r
.24503 .40447 .25249 .41177 .26365 .40847 .25621 .40114 Mtetra
.642 .732 .914 r
.25621 .40114 .26365 .40847 .27485 .40519 .26744 .39783 Mtetra
.64 .731 .915 r
.26744 .39783 .27485 .40519 .2861 .40195 .27872 .39456 Mtetra
.638 .731 .916 r
.27872 .39456 .2861 .40195 .2974 .39873 .29005 .39133 Mtetra
.636 .731 .917 r
.29005 .39133 .2974 .39873 .30875 .39555 .30142 .38813 Mtetra
.634 .73 .918 r
.30142 .38813 .30875 .39555 .32016 .39241 .31285 .38497 Mtetra
.632 .73 .919 r
.31285 .38497 .32016 .39241 .33161 .3893 .32434 .38186 Mtetra
.629 .73 .92 r
.32434 .38186 .33161 .3893 .34312 .38624 .33587 .37878 Mtetra
.627 .73 .921 r
.33587 .37878 .34312 .38624 .35468 .38321 .34746 .37575 Mtetra
.625 .73 .922 r
.34746 .37575 .35468 .38321 .3663 .38022 .3591 .37277 Mtetra
.623 .73 .924 r
.3591 .37277 .3663 .38022 .37797 .37727 .3708 .36982 Mtetra
.621 .731 .925 r
.3708 .36982 .37797 .37727 .3897 .37434 .38256 .36691 Mtetra
.619 .731 .927 r
.38256 .36691 .3897 .37434 .40149 .37144 .39438 .36403 Mtetra
.617 .732 .929 r
.39438 .36403 .40149 .37144 .41334 .36857 .40626 .36117 Mtetra
.615 .733 .93 r
.40626 .36117 .41334 .36857 .42525 .3657 .4182 .35833 Mtetra
.614 .735 .932 r
.4182 .35833 .42525 .3657 .43722 .36284 .4302 .3555 Mtetra
.614 .736 .933 r
.4302 .3555 .43722 .36284 .44926 .35996 .44226 .35265 Mtetra
.614 .738 .934 r
.44226 .35265 .44926 .35996 .46135 .35706 .45439 .34979 Mtetra
.614 .74 .936 r
.45439 .34979 .46135 .35706 .47352 .35413 .46659 .34689 Mtetra
.615 .743 .937 r
.46659 .34689 .47352 .35413 .48574 .35115 .47885 .34394 Mtetra
.617 .745 .938 r
.47885 .34394 .48574 .35115 .49803 .3481 .49117 .34092 Mtetra
.619 .748 .938 r
.49117 .34092 .49803 .3481 .51039 .34497 .50357 .33782 Mtetra
.622 .751 .939 r
.50357 .33782 .51039 .34497 .52281 .34174 .51602 .33462 Mtetra
.626 .754 .939 r
.51602 .33462 .52281 .34174 .5353 .3384 .52855 .3313 Mtetra
.63 .757 .939 r
.52855 .3313 .5353 .3384 .54784 .33494 .54113 .32785 Mtetra
.635 .76 .939 r
.54113 .32785 .54784 .33494 .56045 .33133 .55378 .32425 Mtetra
.64 .763 .938 r
.55378 .32425 .56045 .33133 .57313 .32758 .5665 .32049 Mtetra
.645 .766 .937 r
.5665 .32049 .57313 .32758 .58586 .32366 .57927 .31656 Mtetra
.651 .769 .935 r
.57927 .31656 .58586 .32366 .59865 .31958 .5921 .31246 Mtetra
.656 .771 .934 r
.5921 .31246 .59865 .31958 .61149 .31532 .60499 .30817 Mtetra
.662 .773 .932 r
.60499 .30817 .61149 .31532 .6244 .31088 .61794 .30369 Mtetra
.668 .775 .93 r
.61794 .30369 .6244 .31088 .63735 .30627 .63094 .29902 Mtetra
.673 .776 .928 r
.63094 .29902 .63735 .30627 .65036 .30148 .64399 .29416 Mtetra
.678 .777 .925 r
.64399 .29416 .65036 .30148 .66342 .29651 .6571 .28912 Mtetra
.683 .778 .923 r
.6571 .28912 .66342 .29651 .67653 .29138 .67025 .2839 Mtetra
.688 .778 .92 r
.67025 .2839 .67653 .29138 .68968 .28608 .68345 .27852 Mtetra
.692 .778 .917 r
.68345 .27852 .68968 .28608 .70289 .28064 .6967 .27297 Mtetra
.695 .778 .915 r
.6967 .27297 .70289 .28064 .71614 .27505 .71 .26728 Mtetra
.698 .777 .912 r
.71 .26728 .71614 .27505 .72944 .26933 .72334 .26145 Mtetra
.701 .776 .91 r
.72334 .26145 .72944 .26933 .74278 .2635 .73672 .25551 Mtetra
.703 .774 .908 r
.73672 .25551 .74278 .2635 .75617 .25756 .75016 .24946 Mtetra
.704 .773 .905 r
.75016 .24946 .75617 .25756 .7696 .25154 .76364 .24332 Mtetra
.705 .771 .903 r
.76364 .24332 .7696 .25154 .78309 .24544 .77716 .23711 Mtetra
.706 .77 .902 r
.77716 .23711 .78309 .24544 .79662 .23928 .79074 .23084 Mtetra
.706 .768 .9 r
.79074 .23084 .79662 .23928 .8102 .23308 .80436 .22452 Mtetra
.706 .766 .899 r
.80436 .22452 .8102 .23308 .82383 .22684 .81804 .21818 Mtetra
.648 .734 .912 r
.19316 .41076 .20079 .418 .21178 .41459 .20418 .40732 Mtetra
.647 .733 .912 r
.20418 .40732 .21178 .41459 .22281 .4112 .21524 .40389 Mtetra
.646 .733 .912 r
.21524 .40389 .22281 .4112 .2339 .40782 .22635 .40048 Mtetra
.645 .732 .913 r
.22635 .40048 .2339 .40782 .24503 .40447 .23751 .3971 Mtetra
.643 .732 .913 r
.23751 .3971 .24503 .40447 .25621 .40114 .24872 .39374 Mtetra
.641 .731 .914 r
.24872 .39374 .25621 .40114 .26744 .39783 .25997 .39041 Mtetra
.64 .731 .915 r
.25997 .39041 .26744 .39783 .27872 .39456 .27128 .38711 Mtetra
.638 .731 .915 r
.27128 .38711 .27872 .39456 .29005 .39133 .28263 .38385 Mtetra
.636 .73 .916 r
.28263 .38385 .29005 .39133 .30142 .38813 .29404 .38064 Mtetra
.633 .73 .917 r
.29404 .38064 .30142 .38813 .31285 .38497 .30549 .37746 Mtetra
.631 .73 .919 r
.30549 .37746 .31285 .38497 .32434 .38186 .317 .37434 Mtetra
.628 .729 .92 r
.317 .37434 .32434 .38186 .33587 .37878 .32856 .37126 Mtetra
.626 .729 .921 r
.32856 .37126 .33587 .37878 .34746 .37575 .34018 .36823 Mtetra
.623 .729 .923 r
.34018 .36823 .34746 .37575 .3591 .37277 .35185 .36525 Mtetra
.621 .73 .924 r
.35185 .36525 .3591 .37277 .3708 .36982 .36358 .36231 Mtetra
.619 .73 .926 r
.36358 .36231 .3708 .36982 .38256 .36691 .37536 .35942 Mtetra
.616 .731 .928 r
.37536 .35942 .38256 .36691 .39438 .36403 .38721 .35656 Mtetra
.614 .732 .929 r
.38721 .35656 .39438 .36403 .40626 .36117 .39912 .35373 Mtetra
.613 .733 .931 r
.39912 .35373 .40626 .36117 .4182 .35833 .41108 .35093 Mtetra
.611 .734 .933 r
.41108 .35093 .4182 .35833 .4302 .3555 .42311 .34812 Mtetra
.611 .736 .934 r
.42311 .34812 .4302 .3555 .44226 .35265 .43521 .34532 Mtetra
.61 .738 .936 r
.43521 .34532 .44226 .35265 .45439 .34979 .44737 .3425 Mtetra
.611 .74 .937 r
.44737 .3425 .45439 .34979 .46659 .34689 .4596 .33964 Mtetra
.612 .743 .939 r
.4596 .33964 .46659 .34689 .47885 .34394 .47189 .33673 Mtetra
.613 .746 .94 r
.47189 .33673 .47885 .34394 .49117 .34092 .48425 .33376 Mtetra
.616 .749 .941 r
.48425 .33376 .49117 .34092 .50357 .33782 .49668 .33069 Mtetra
.619 .752 .941 r
.49668 .33069 .50357 .33782 .51602 .33462 .50917 .32752 Mtetra
.623 .756 .942 r
.50917 .32752 .51602 .33462 .52855 .3313 .52174 .32423 Mtetra
.627 .759 .942 r
.52174 .32423 .52855 .3313 .54113 .32785 .53436 .3208 Mtetra
.632 .763 .941 r
.53436 .3208 .54113 .32785 .55378 .32425 .54705 .31721 Mtetra
.638 .766 .941 r
.54705 .31721 .55378 .32425 .5665 .32049 .55981 .31346 Mtetra
.644 .769 .94 r
.55981 .31346 .5665 .32049 .57927 .31656 .57263 .30952 Mtetra
.65 .772 .938 r
.57263 .30952 .57927 .31656 .5921 .31246 .5855 .3054 Mtetra
.656 .775 .937 r
.5855 .3054 .5921 .31246 .60499 .30817 .59844 .30108 Mtetra
.662 .777 .935 r
.59844 .30108 .60499 .30817 .61794 .30369 .61143 .29656 Mtetra
.668 .779 .933 r
.61143 .29656 .61794 .30369 .63094 .29902 .62448 .29184 Mtetra
.674 .781 .93 r
.62448 .29184 .63094 .29902 .64399 .29416 .63757 .28692 Mtetra
.679 .782 .928 r
.63757 .28692 .64399 .29416 .6571 .28912 .65072 .28181 Mtetra
.685 .783 .925 r
.65072 .28181 .6571 .28912 .67025 .2839 .66392 .27651 Mtetra
.689 .783 .922 r
.66392 .27651 .67025 .2839 .68345 .27852 .67717 .27103 Mtetra
.694 .783 .92 r
.67717 .27103 .68345 .27852 .6967 .27297 .69046 .26538 Mtetra
.697 .782 .917 r
.69046 .26538 .6967 .27297 .71 .26728 .70381 .25958 Mtetra
.701 .782 .914 r
.70381 .25958 .71 .26728 .72334 .26145 .71719 .25364 Mtetra
.703 .78 .912 r
.71719 .25364 .72334 .26145 .73672 .25551 .73062 .24758 Mtetra
.705 .779 .909 r
.73062 .24758 .73672 .25551 .75016 .24946 .7441 .24141 Mtetra
.707 .777 .907 r
.7441 .24141 .75016 .24946 .76364 .24332 .75763 .23515 Mtetra
.708 .776 .905 r
.75763 .23515 .76364 .24332 .77716 .23711 .7712 .22882 Mtetra
.708 .774 .903 r
.7712 .22882 .77716 .23711 .79074 .23084 .78481 .22242 Mtetra
.709 .772 .901 r
.78481 .22242 .79074 .23084 .80436 .22452 .79848 .21599 Mtetra
.708 .77 .9 r
.79848 .21599 .80436 .22452 .81804 .21818 .8122 .20953 Mtetra
.649 .734 .911 r
.18548 .40345 .19316 .41076 .20418 .40732 .19652 .39998 Mtetra
.647 .733 .911 r
.19652 .39998 .20418 .40732 .21524 .40389 .20761 .39651 Mtetra
.646 .733 .912 r
.20761 .39651 .21524 .40389 .22635 .40048 .21875 .39307 Mtetra
.645 .732 .912 r
.21875 .39307 .22635 .40048 .23751 .3971 .22994 .38965 Mtetra
.643 .732 .913 r
.22994 .38965 .23751 .3971 .24872 .39374 .24117 .38626 Mtetra
.641 .731 .914 r
.24117 .38626 .24872 .39374 .25997 .39041 .25245 .3829 Mtetra
.639 .731 .914 r
.25245 .3829 .25997 .39041 .27128 .38711 .26378 .37958 Mtetra
.637 .73 .915 r
.26378 .37958 .27128 .38711 .28263 .38385 .27516 .3763 Mtetra
.635 .73 .916 r
.27516 .3763 .28263 .38385 .29404 .38064 .28659 .37307 Mtetra
.633 .729 .917 r
.28659 .37307 .29404 .38064 .30549 .37746 .29808 .36988 Mtetra
.63 .729 .919 r
.29808 .36988 .30549 .37746 .317 .37434 .30961 .36675 Mtetra
.627 .729 .92 r
.30961 .36675 .317 .37434 .32856 .37126 .3212 .36367 Mtetra
.625 .729 .922 r
.3212 .36367 .32856 .37126 .34018 .36823 .33284 .36064 Mtetra
.622 .729 .923 r
.33284 .36064 .34018 .36823 .35185 .36525 .34454 .35767 Mtetra
.619 .729 .925 r
.34454 .35767 .35185 .36525 .36358 .36231 .35629 .35475 Mtetra
.617 .729 .927 r
.35629 .35475 .36358 .36231 .37536 .35942 .36811 .35187 Mtetra
.614 .73 .928 r
.36811 .35187 .37536 .35942 .38721 .35656 .37998 .34904 Mtetra
.612 .731 .93 r
.37998 .34904 .38721 .35656 .39912 .35373 .39191 .34624 Mtetra
.61 .732 .932 r
.39191 .34624 .39912 .35373 .41108 .35093 .40391 .34347 Mtetra
.608 .734 .934 r
.40391 .34347 .41108 .35093 .42311 .34812 .41597 .34071 Mtetra
.607 .736 .936 r
.41597 .34071 .42311 .34812 .43521 .34532 .42809 .33795 Mtetra
.607 .738 .938 r
.42809 .33795 .43521 .34532 .44737 .3425 .44029 .33518 Mtetra
.607 .74 .939 r
.44029 .33518 .44737 .3425 .4596 .33964 .45255 .33237 Mtetra
.608 .743 .941 r
.45255 .33237 .4596 .33964 .47189 .33673 .46487 .32951 Mtetra
.61 .746 .942 r
.46487 .32951 .47189 .33673 .48425 .33376 .47727 .32658 Mtetra
.612 .749 .943 r
.47727 .32658 .48425 .33376 .49668 .33069 .48973 .32356 Mtetra
.616 .753 .943 r
.48973 .32356 .49668 .33069 .50917 .32752 .50226 .32043 Mtetra
.62 .757 .944 r
.50226 .32043 .50917 .32752 .52174 .32423 .51486 .31717 Mtetra
.624 .761 .944 r
.51486 .31717 .52174 .32423 .53436 .3208 .52753 .31377 Mtetra
.63 .765 .944 r
.52753 .31377 .53436 .3208 .54705 .31721 .54026 .3102 Mtetra
.636 .768 .943 r
.54026 .3102 .54705 .31721 .55981 .31346 .55306 .30646 Mtetra
.642 .772 .942 r
.55306 .30646 .55981 .31346 .57263 .30952 .56592 .30253 Mtetra
.648 .775 .941 r
.56592 .30253 .57263 .30952 .5855 .3054 .57884 .29839 Mtetra
.655 .778 .939 r
.57884 .29839 .5855 .3054 .59844 .30108 .59182 .29405 Mtetra
.662 .781 .937 r
.59182 .29405 .59844 .30108 .61143 .29656 .60486 .28949 Mtetra
.668 .783 .935 r
.60486 .28949 .61143 .29656 .62448 .29184 .61795 .28472 Mtetra
.674 .785 .933 r
.61795 .28472 .62448 .29184 .63757 .28692 .6311 .27974 Mtetra
.68 .786 .93 r
.6311 .27974 .63757 .28692 .65072 .28181 .6443 .27456 Mtetra
.686 .787 .927 r
.6443 .27456 .65072 .28181 .66392 .27651 .65754 .26917 Mtetra
.691 .788 .924 r
.65754 .26917 .66392 .27651 .67717 .27103 .67084 .2636 Mtetra
.696 .788 .921 r
.67084 .2636 .67717 .27103 .69046 .26538 .68418 .25785 Mtetra
.7 .787 .919 r
.68418 .25785 .69046 .26538 .70381 .25958 .69756 .25194 Mtetra
.703 .786 .916 r
.69756 .25194 .70381 .25958 .71719 .25364 .711 .24588 Mtetra
.706 .785 .913 r
.711 .24588 .71719 .25364 .73062 .24758 .72448 .2397 Mtetra
.708 .783 .911 r
.72448 .2397 .73062 .24758 .7441 .24141 .738 .2334 Mtetra
.709 .782 .908 r
.738 .2334 .7441 .24141 .75763 .23515 .75157 .22702 Mtetra
.711 .78 .906 r
.75157 .22702 .75763 .23515 .7712 .22882 .76518 .22055 Mtetra
.711 .778 .904 r
.76518 .22055 .7712 .22882 .78481 .22242 .77885 .21403 Mtetra
.711 .775 .902 r
.77885 .21403 .78481 .22242 .79848 .21599 .79256 .20747 Mtetra
.711 .773 .901 r
.79256 .20747 .79848 .21599 .8122 .20953 .80632 .20089 Mtetra
.649 .733 .911 r
.17774 .39608 .18548 .40345 .19652 .39998 .18881 .39257 Mtetra
.648 .733 .911 r
.18881 .39257 .19652 .39998 .20761 .39651 .19993 .38907 Mtetra
.646 .732 .912 r
.19993 .38907 .20761 .39651 .21875 .39307 .21109 .38559 Mtetra
.645 .732 .912 r
.21109 .38559 .21875 .39307 .22994 .38965 .2223 .38214 Mtetra
.643 .731 .913 r
.2223 .38214 .22994 .38965 .24117 .38626 .23356 .37872 Mtetra
.641 .731 .913 r
.23356 .37872 .24117 .38626 .25245 .3829 .24487 .37533 Mtetra
.639 .73 .914 r
.24487 .37533 .25245 .3829 .26378 .37958 .25623 .37198 Mtetra
.637 .73 .915 r
.25623 .37198 .26378 .37958 .27516 .3763 .26763 .36868 Mtetra
.635 .729 .916 r
.26763 .36868 .27516 .3763 .28659 .37307 .27909 .36543 Mtetra
.632 .729 .917 r
.27909 .36543 .28659 .37307 .29808 .36988 .2906 .36223 Mtetra
.629 .728 .919 r
.2906 .36223 .29808 .36988 .30961 .36675 .30216 .35909 Mtetra
.626 .728 .92 r
.30216 .35909 .30961 .36675 .3212 .36367 .31377 .356 Mtetra
.623 .728 .922 r
.31377 .356 .3212 .36367 .33284 .36064 .32544 .35298 Mtetra
.62 .728 .923 r
.32544 .35298 .33284 .36064 .34454 .35767 .33717 .35002 Mtetra
.617 .728 .925 r
.33717 .35002 .34454 .35767 .35629 .35475 .34895 .34711 Mtetra
.614 .729 .927 r
.34895 .34711 .35629 .35475 .36811 .35187 .36079 .34426 Mtetra
.612 .729 .929 r
.36079 .34426 .36811 .35187 .37998 .34904 .37269 .34146 Mtetra
.609 .73 .931 r
.37269 .34146 .37998 .34904 .39191 .34624 .38465 .33869 Mtetra
.607 .731 .933 r
.38465 .33869 .39191 .34624 .40391 .34347 .39667 .33596 Mtetra
.605 .733 .935 r
.39667 .33596 .40391 .34347 .41597 .34071 .40876 .33325 Mtetra
.604 .735 .937 r
.40876 .33325 .41597 .34071 .42809 .33795 .42092 .33054 Mtetra
.603 .737 .939 r
.42092 .33054 .42809 .33795 .44029 .33518 .43314 .32781 Mtetra
.604 .74 .941 r
.43314 .32781 .44029 .33518 .45255 .33237 .44543 .32506 Mtetra
.604 .742 .942 r
.44543 .32506 .45255 .33237 .46487 .32951 .45779 .32225 Mtetra
.606 .746 .943 r
.45779 .32225 .46487 .32951 .47727 .32658 .47022 .31938 Mtetra
.609 .749 .945 r
.47022 .31938 .47727 .32658 .48973 .32356 .48272 .31641 Mtetra
.612 .753 .945 r
.48272 .31641 .48973 .32356 .50226 .32043 .49529 .31333 Mtetra
.616 .757 .946 r
.49529 .31333 .50226 .32043 .51486 .31717 .50793 .31011 Mtetra
.621 .761 .946 r
.50793 .31011 .51486 .31717 .52753 .31377 .52064 .30674 Mtetra
.627 .766 .946 r
.52064 .30674 .52753 .31377 .54026 .3102 .53341 .30321 Mtetra
.633 .77 .945 r
.53341 .30321 .54026 .3102 .55306 .30646 .54625 .29948 Mtetra
.64 .774 .944 r
.54625 .29948 .55306 .30646 .56592 .30253 .55915 .29555 Mtetra
.647 .777 .943 r
.55915 .29555 .56592 .30253 .57884 .29839 .57212 .29141 Mtetra
.654 .781 .941 r
.57212 .29141 .57884 .29839 .59182 .29405 .58515 .28705 Mtetra
.661 .784 .939 r
.58515 .28705 .59182 .29405 .60486 .28949 .59823 .28246 Mtetra
.668 .786 .937 r
.59823 .28246 .60486 .28949 .61795 .28472 .61137 .27765 Mtetra
.675 .788 .935 r
.61137 .27765 .61795 .28472 .6311 .27974 .62456 .27261 Mtetra
.681 .79 .932 r
.62456 .27261 .6311 .27974 .6443 .27456 .63781 .26735 Mtetra
.687 .791 .929 r
.63781 .26735 .6443 .27456 .65754 .26917 .6511 .26189 Mtetra
.693 .792 .926 r
.6511 .26189 .65754 .26917 .67084 .2636 .66445 .25622 Mtetra
.698 .792 .923 r
.66445 .25622 .67084 .2636 .68418 .25785 .67784 .25037 Mtetra
.702 .791 .92 r
.67784 .25037 .68418 .25785 .69756 .25194 .69127 .24434 Mtetra
.705 .79 .917 r
.69127 .24434 .69756 .25194 .711 .24588 .70475 .23817 Mtetra
.708 .789 .914 r
.70475 .23817 .711 .24588 .72448 .2397 .71828 .23186 Mtetra
.71 .788 .912 r
.71828 .23186 .72448 .2397 .738 .2334 .73185 .22543 Mtetra
.712 .786 .909 r
.73185 .22543 .738 .2334 .75157 .22702 .74546 .21891 Mtetra
.713 .784 .907 r
.74546 .21891 .75157 .22702 .76518 .22055 .75912 .21231 Mtetra
.714 .781 .905 r
.75912 .21231 .76518 .22055 .77885 .21403 .77283 .20566 Mtetra
.714 .779 .903 r
.77283 .20566 .77885 .21403 .79256 .20747 .78659 .19897 Mtetra
.713 .776 .902 r
.78659 .19897 .79256 .20747 .80632 .20089 .8004 .19225 Mtetra
.649 .733 .911 r
.16994 .38864 .17774 .39608 .18881 .39257 .18104 .38509 Mtetra
.648 .733 .911 r
.18104 .38509 .18881 .39257 .19993 .38907 .19218 .38155 Mtetra
.646 .732 .911 r
.19218 .38155 .19993 .38907 .21109 .38559 .20337 .37804 Mtetra
.645 .731 .912 r
.20337 .37804 .21109 .38559 .2223 .38214 .21461 .37455 Mtetra
.643 .731 .912 r
.21461 .37455 .2223 .38214 .23356 .37872 .22589 .3711 Mtetra
.641 .73 .913 r
.22589 .3711 .23356 .37872 .24487 .37533 .23723 .36768 Mtetra
.639 .73 .914 r
.23723 .36768 .24487 .37533 .25623 .37198 .24861 .36431 Mtetra
.637 .729 .915 r
.24861 .36431 .25623 .37198 .26763 .36868 .26004 .36099 Mtetra
.634 .729 .916 r
.26004 .36099 .26763 .36868 .27909 .36543 .27153 .35771 Mtetra
.631 .728 .917 r
.27153 .35771 .27909 .36543 .2906 .36223 .28306 .3545 Mtetra
.628 .728 .919 r
.28306 .3545 .2906 .36223 .30216 .35909 .29465 .35135 Mtetra
.625 .727 .92 r
.29465 .35135 .30216 .35909 .31377 .356 .30629 .34826 Mtetra
.622 .727 .922 r
.30629 .34826 .31377 .356 .32544 .35298 .31798 .34524 Mtetra
.619 .727 .924 r
.31798 .34524 .32544 .35298 .33717 .35002 .32973 .34229 Mtetra
.615 .727 .926 r
.32973 .34229 .33717 .35002 .34895 .34711 .34154 .3394 Mtetra
.612 .728 .928 r
.34154 .3394 .34895 .34711 .36079 .34426 .35341 .33657 Mtetra
.609 .728 .93 r
.35341 .33657 .36079 .34426 .37269 .34146 .36533 .3338 Mtetra
.606 .729 .932 r
.36533 .3338 .37269 .34146 .38465 .33869 .37732 .33107 Mtetra
.604 .73 .934 r
.37732 .33107 .38465 .33869 .39667 .33596 .38937 .32838 Mtetra
.602 .732 .936 r
.38937 .32838 .39667 .33596 .40876 .33325 .40149 .32572 Mtetra
.6 .733 .938 r
.40149 .32572 .40876 .33325 .42092 .33054 .41368 .32306 Mtetra
.6 .736 .94 r
.41368 .32306 .42092 .33054 .43314 .32781 .42593 .32039 Mtetra
.6 .738 .942 r
.42593 .32039 .43314 .32781 .44543 .32506 .43825 .3177 Mtetra
.6 .741 .943 r
.43825 .3177 .44543 .32506 .45779 .32225 .45065 .31495 Mtetra
.602 .745 .945 r
.45065 .31495 .45779 .32225 .47022 .31938 .46311 .31213 Mtetra
.605 .749 .946 r
.46311 .31213 .47022 .31938 .48272 .31641 .47565 .30922 Mtetra
.608 .753 .947 r
.47565 .30922 .48272 .31641 .49529 .31333 .48825 .30619 Mtetra
.613 .757 .947 r
.48825 .30619 .49529 .31333 .50793 .31011 .50093 .30303 Mtetra
.618 .761 .948 r
.50093 .30303 .50793 .31011 .52064 .30674 .51368 .2997 Mtetra
.624 .766 .948 r
.51368 .2997 .52064 .30674 .53341 .30321 .52649 .29619 Mtetra
.631 .77 .947 r
.52649 .29619 .53341 .30321 .54625 .29948 .53938 .29249 Mtetra
.638 .775 .946 r
.53938 .29249 .54625 .29948 .55915 .29555 .55232 .28857 Mtetra
.645 .779 .945 r
.55232 .28857 .55915 .29555 .57212 .29141 .56534 .28443 Mtetra
.653 .783 .943 r
.56534 .28443 .57212 .29141 .58515 .28705 .57841 .28005 Mtetra
.661 .786 .941 r
.57841 .28005 .58515 .28705 .59823 .28246 .59154 .27544 Mtetra
.668 .789 .939 r
.59154 .27544 .59823 .28246 .61137 .27765 .60473 .27058 Mtetra
.675 .791 .936 r
.60473 .27058 .61137 .27765 .62456 .27261 .61797 .26549 Mtetra
.682 .793 .933 r
.61797 .26549 .62456 .27261 .63781 .26735 .63126 .26017 Mtetra
.688 .794 .93 r
.63126 .26017 .63781 .26735 .6511 .26189 .64461 .25462 Mtetra
.694 .795 .927 r
.64461 .25462 .6511 .26189 .66445 .25622 .658 .24886 Mtetra
.699 .795 .924 r
.658 .24886 .66445 .25622 .67784 .25037 .67144 .24291 Mtetra
.704 .795 .921 r
.67144 .24291 .67784 .25037 .69127 .24434 .68492 .23677 Mtetra
.708 .794 .918 r
.68492 .23677 .69127 .24434 .70475 .23817 .69845 .23048 Mtetra
.711 .793 .915 r
.69845 .23048 .70475 .23817 .71828 .23186 .71202 .22404 Mtetra
.713 .791 .913 r
.71202 .22404 .71828 .23186 .73185 .22543 .72564 .21748 Mtetra
.715 .789 .91 r
.72564 .21748 .73185 .22543 .74546 .21891 .7393 .21082 Mtetra
.716 .787 .908 r
.7393 .21082 .74546 .21891 .75912 .21231 .75301 .20408 Mtetra
.717 .785 .906 r
.75301 .20408 .75912 .21231 .77283 .20566 .76677 .19729 Mtetra
.716 .782 .904 r
.76677 .19729 .77283 .20566 .78659 .19897 .78057 .19046 Mtetra
.716 .779 .902 r
.78057 .19046 .78659 .19897 .8004 .19225 .79442 .18361 Mtetra
.649 .733 .91 r
.16208 .38113 .16994 .38864 .18104 .38509 .1732 .37754 Mtetra
.648 .732 .911 r
.1732 .37754 .18104 .38509 .19218 .38155 .18437 .37396 Mtetra
.647 .732 .911 r
.18437 .37396 .19218 .38155 .20337 .37804 .19559 .37041 Mtetra
.645 .731 .912 r
.19559 .37041 .20337 .37804 .21461 .37455 .20685 .36689 Mtetra
.643 .731 .912 r
.20685 .36689 .21461 .37455 .22589 .3711 .21816 .36341 Mtetra
.641 .73 .913 r
.21816 .36341 .22589 .3711 .23723 .36768 .22952 .35996 Mtetra
.639 .729 .914 r
.22952 .35996 .23723 .36768 .24861 .36431 .24093 .35656 Mtetra
.636 .729 .915 r
.24093 .35656 .24861 .36431 .26004 .36099 .25239 .35322 Mtetra
.634 .728 .916 r
.25239 .35322 .26004 .36099 .27153 .35771 .2639 .34993 Mtetra
.631 .728 .917 r
.2639 .34993 .27153 .35771 .28306 .3545 .27547 .3467 Mtetra
.628 .727 .919 r
.27547 .3467 .28306 .3545 .29465 .35135 .28708 .34354 Mtetra
.624 .727 .92 r
.28708 .34354 .29465 .35135 .30629 .34826 .29874 .34045 Mtetra
.621 .726 .922 r
.29874 .34045 .30629 .34826 .31798 .34524 .31046 .33743 Mtetra
.617 .726 .924 r
.31046 .33743 .31798 .34524 .32973 .34229 .32224 .33449 Mtetra
.614 .726 .926 r
.32224 .33449 .32973 .34229 .34154 .3394 .33407 .33161 Mtetra
.61 .726 .928 r
.33407 .33161 .34154 .3394 .35341 .33657 .34597 .32881 Mtetra
.607 .727 .93 r
.34597 .32881 .35341 .33657 .36533 .3338 .35792 .32607 Mtetra
.604 .728 .932 r
.35792 .32607 .36533 .3338 .37732 .33107 .36993 .32338 Mtetra
.601 .729 .934 r
.36993 .32338 .37732 .33107 .38937 .32838 .38201 .32073 Mtetra
.599 .73 .936 r
.38201 .32073 .38937 .32838 .40149 .32572 .39416 .31811 Mtetra
.597 .732 .939 r
.39416 .31811 .40149 .32572 .41368 .32306 .40637 .31551 Mtetra
.596 .734 .941 r
.40637 .31551 .41368 .32306 .42593 .32039 .41866 .3129 Mtetra
.596 .737 .942 r
.41866 .3129 .42593 .32039 .43825 .3177 .43101 .31026 Mtetra
.596 .74 .944 r
.43101 .31026 .43825 .3177 .45065 .31495 .44344 .30758 Mtetra
.598 .743 .946 r
.44344 .30758 .45065 .31495 .46311 .31213 .45593 .30482 Mtetra
.601 .747 .947 r
.45593 .30482 .46311 .31213 .47565 .30922 .46851 .30197 Mtetra
.605 .751 .948 r
.46851 .30197 .47565 .30922 .48825 .30619 .48115 .299 Mtetra
.609 .756 .949 r
.48115 .299 .48825 .30619 .50093 .30303 .49386 .29589 Mtetra
.615 .761 .949 r
.49386 .29589 .50093 .30303 .51368 .2997 .50665 .2926 Mtetra
.621 .765 .949 r
.50665 .2926 .51368 .2997 .52649 .29619 .51951 .28913 Mtetra
.628 .77 .948 r
.51951 .28913 .52649 .29619 .53938 .29249 .53244 .28545 Mtetra
.636 .775 .947 r
.53244 .28545 .53938 .29249 .55232 .28857 .54543 .28155 Mtetra
.644 .779 .946 r
.54543 .28155 .55232 .28857 .56534 .28443 .55849 .27742 Mtetra
.652 .783 .944 r
.55849 .27742 .56534 .28443 .57841 .28005 .57161 .27303 Mtetra
.66 .787 .942 r
.57161 .27303 .57841 .28005 .59154 .27544 .58479 .2684 Mtetra
.668 .79 .94 r
.58479 .2684 .59154 .27544 .60473 .27058 .59802 .26351 Mtetra
.676 .793 .937 r
.59802 .26351 .60473 .27058 .61797 .26549 .61131 .25836 Mtetra
.683 .795 .934 r
.61131 .25836 .61797 .26549 .63126 .26017 .62466 .25298 Mtetra
.69 .796 .931 r
.62466 .25298 .63126 .26017 .64461 .25462 .63805 .24735 Mtetra
.696 .797 .928 r
.63805 .24735 .64461 .25462 .658 .24886 .65149 .2415 Mtetra
.701 .798 .925 r
.65149 .2415 .658 .24886 .67144 .24291 .66498 .23544 Mtetra
.706 .797 .922 r
.66498 .23544 .67144 .24291 .68492 .23677 .67852 .2292 Mtetra
.71 .797 .919 r
.67852 .2292 .68492 .23677 .69845 .23048 .69209 .22278 Mtetra
.713 .796 .916 r
.69209 .22278 .69845 .23048 .71202 .22404 .70572 .21621 Mtetra
.716 .794 .913 r
.70572 .21621 .71202 .22404 .72564 .21748 .71938 .20952 Mtetra
.718 .792 .91 r
.71938 .20952 .72564 .21748 .7393 .21082 .73309 .20272 Mtetra
.719 .79 .908 r
.73309 .20272 .7393 .21082 .75301 .20408 .74685 .19585 Mtetra
.719 .787 .906 r
.74685 .19585 .75301 .20408 .76677 .19729 .76065 .18891 Mtetra
.719 .785 .904 r
.76065 .18891 .76677 .19729 .78057 .19046 .7745 .18194 Mtetra
.719 .782 .902 r
.7745 .18194 .78057 .19046 .79442 .18361 .7884 .17495 Mtetra
.65 .733 .91 r
.15416 .37355 .16208 .38113 .1732 .37754 .1653 .36992 Mtetra
.648 .732 .91 r
.1653 .36992 .1732 .37754 .18437 .37396 .1765 .36631 Mtetra
.647 .732 .911 r
.1765 .36631 .18437 .37396 .19559 .37041 .18774 .36272 Mtetra
.645 .731 .911 r
.18774 .36272 .19559 .37041 .20685 .36689 .19903 .35917 Mtetra
.643 .73 .912 r
.19903 .35917 .20685 .36689 .21816 .36341 .21037 .35565 Mtetra
.641 .73 .913 r
.21037 .35565 .21816 .36341 .22952 .35996 .22176 .35217 Mtetra
.639 .729 .914 r
.22176 .35217 .22952 .35996 .24093 .35656 .2332 .34874 Mtetra
.636 .728 .915 r
.2332 .34874 .24093 .35656 .25239 .35322 .24468 .34537 Mtetra
.633 .728 .916 r
.24468 .34537 .25239 .35322 .2639 .34993 .25622 .34206 Mtetra
.63 .727 .917 r
.25622 .34206 .2639 .34993 .27547 .3467 .26781 .33882 Mtetra
.627 .726 .919 r
.26781 .33882 .27547 .3467 .28708 .34354 .27945 .33565 Mtetra
.623 .726 .92 r
.27945 .33565 .28708 .34354 .29874 .34045 .29114 .33255 Mtetra
.619 .725 .922 r
.29114 .33255 .29874 .34045 .31046 .33743 .30289 .32954 Mtetra
.616 .725 .924 r
.30289 .32954 .31046 .33743 .32224 .33449 .31469 .3266 Mtetra
.612 .725 .926 r
.31469 .3266 .32224 .33449 .33407 .33161 .32655 .32374 Mtetra
.608 .725 .928 r
.32655 .32374 .33407 .33161 .34597 .32881 .33846 .32096 Mtetra
.604 .725 .93 r
.33846 .32096 .34597 .32881 .35792 .32607 .35044 .31825 Mtetra
.601 .726 .932 r
.35044 .31825 .35792 .32607 .36993 .32338 .36249 .31559 Mtetra
.598 .727 .935 r
.36249 .31559 .36993 .32338 .38201 .32073 .37459 .31299 Mtetra
.595 .728 .937 r
.37459 .31299 .38201 .32073 .39416 .31811 .38677 .31042 Mtetra
.593 .73 .939 r
.38677 .31042 .39416 .31811 .40637 .31551 .39901 .30787 Mtetra
.592 .732 .941 r
.39901 .30787 .40637 .31551 .41866 .3129 .41132 .30532 Mtetra
.592 .734 .943 r
.41132 .30532 .41866 .3129 .43101 .31026 .42371 .30274 Mtetra
.593 .738 .945 r
.42371 .30274 .43101 .31026 .44344 .30758 .43616 .30012 Mtetra
.594 .741 .946 r
.43616 .30012 .44344 .30758 .45593 .30482 .44869 .29743 Mtetra
.597 .745 .947 r
.44869 .29743 .45593 .30482 .46851 .30197 .4613 .29464 Mtetra
.601 .749 .948 r
.4613 .29464 .46851 .30197 .48115 .299 .47398 .29172 Mtetra
.606 .754 .949 r
.47398 .29172 .48115 .299 .49386 .29589 .48673 .28866 Mtetra
.611 .759 .949 r
.48673 .28866 .49386 .29589 .50665 .2926 .49956 .28543 Mtetra
.618 .764 .949 r
.49956 .28543 .50665 .2926 .51951 .28913 .51246 .282 Mtetra
.626 .769 .949 r
.51246 .282 .51951 .28913 .53244 .28545 .52543 .27835 Mtetra
.634 .774 .948 r
.52543 .27835 .53244 .28545 .54543 .28155 .53847 .27447 Mtetra
.642 .779 .946 r
.53847 .27447 .54543 .28155 .55849 .27742 .55157 .27034 Mtetra
.65 .783 .945 r
.55157 .27034 .55849 .27742 .57161 .27303 .56474 .26595 Mtetra
.659 .787 .942 r
.56474 .26595 .57161 .27303 .58479 .2684 .57797 .2613 Mtetra
.668 .79 .94 r
.57797 .2613 .58479 .2684 .59802 .26351 .59125 .25637 Mtetra
.676 .793 .937 r
.59125 .25637 .59802 .26351 .61131 .25836 .60459 .25119 Mtetra
.683 .796 .934 r
.60459 .25119 .61131 .25836 .62466 .25298 .61799 .24574 Mtetra
.691 .797 .931 r
.61799 .24574 .62466 .25298 .63805 .24735 .63143 .24004 Mtetra
.697 .799 .928 r
.63143 .24004 .63805 .24735 .65149 .2415 .64493 .2341 Mtetra
.703 .799 .925 r
.64493 .2341 .65149 .2415 .66498 .23544 .65846 .22795 Mtetra
.708 .799 .922 r
.65846 .22795 .66498 .23544 .67852 .2292 .67205 .22159 Mtetra
.712 .799 .918 r
.67205 .22159 .67852 .2292 .69209 .22278 .68568 .21505 Mtetra
.716 .798 .915 r
.68568 .21505 .69209 .22278 .70572 .21621 .69935 .20836 Mtetra
.718 .796 .913 r
.69935 .20836 .70572 .21621 .71938 .20952 .71306 .20153 Mtetra
.72 .794 .91 r
.71306 .20153 .71938 .20952 .73309 .20272 .72682 .19459 Mtetra
.721 .792 .908 r
.72682 .19459 .73309 .20272 .74685 .19585 .74063 .18757 Mtetra
.722 .79 .906 r
.74063 .18757 .74685 .19585 .76065 .18891 .75448 .18049 Mtetra
.722 .787 .904 r
.75448 .18049 .76065 .18891 .7745 .18194 .76837 .17338 Mtetra
.721 .784 .902 r
.76837 .17338 .7745 .18194 .7884 .17495 .78232 .16625 Mtetra
.65 .733 .91 r
.14617 .3659 .15416 .37355 .1653 .36992 .15735 .36223 Mtetra
.649 .732 .91 r
.15735 .36223 .1653 .36992 .1765 .36631 .16857 .35858 Mtetra
.647 .731 .91 r
.16857 .35858 .1765 .36631 .18774 .36272 .17984 .35496 Mtetra
.645 .731 .911 r
.17984 .35496 .18774 .36272 .19903 .35917 .19116 .35136 Mtetra
.643 .73 .912 r
.19116 .35136 .19903 .35917 .21037 .35565 .20252 .34781 Mtetra
.641 .729 .912 r
.20252 .34781 .21037 .35565 .22176 .35217 .21394 .3443 Mtetra
.639 .729 .913 r
.21394 .3443 .22176 .35217 .2332 .34874 .2254 .34084 Mtetra
.636 .728 .914 r
.2254 .34084 .2332 .34874 .24468 .34537 .23691 .33744 Mtetra
.633 .727 .916 r
.23691 .33744 .24468 .34537 .25622 .34206 .24848 .33411 Mtetra
.63 .726 .917 r
.24848 .33411 .25622 .34206 .26781 .33882 .26009 .33085 Mtetra
.626 .726 .919 r
.26009 .33085 .26781 .33882 .27945 .33565 .27176 .32767 Mtetra
.622 .725 .92 r
.27176 .32767 .27945 .33565 .29114 .33255 .28347 .32457 Mtetra
.618 .724 .922 r
.28347 .32457 .29114 .33255 .30289 .32954 .29524 .32155 Mtetra
.614 .724 .924 r
.29524 .32155 .30289 .32954 .31469 .3266 .30707 .31862 Mtetra
.61 .724 .926 r
.30707 .31862 .31469 .3266 .32655 .32374 .31896 .31578 Mtetra
.606 .723 .928 r
.31896 .31578 .32655 .32374 .33846 .32096 .3309 .31301 Mtetra
.602 .724 .93 r
.3309 .31301 .33846 .32096 .35044 .31825 .34291 .31032 Mtetra
.598 .724 .932 r
.34291 .31032 .35044 .31825 .36249 .31559 .35497 .3077 Mtetra
.595 .725 .935 r
.35497 .3077 .36249 .31559 .37459 .31299 .36711 .30514 Mtetra
.592 .726 .937 r
.36711 .30514 .37459 .31299 .38677 .31042 .37931 .30262 Mtetra
.59 .727 .939 r
.37931 .30262 .38677 .31042 .39901 .30787 .39158 .30012 Mtetra
.589 .729 .941 r
.39158 .30012 .39901 .30787 .41132 .30532 .40392 .29762 Mtetra
.588 .732 .943 r
.40392 .29762 .41132 .30532 .42371 .30274 .41634 .2951 Mtetra
.589 .735 .945 r
.41634 .2951 .42371 .30274 .43616 .30012 .42882 .29254 Mtetra
.59 .738 .946 r
.42882 .29254 .43616 .30012 .44869 .29743 .44139 .28991 Mtetra
.593 .742 .947 r
.44139 .28991 .44869 .29743 .4613 .29464 .45403 .28718 Mtetra
.597 .747 .948 r
.45403 .28718 .4613 .29464 .47398 .29172 .46674 .28433 Mtetra
.602 .751 .949 r
.46674 .28433 .47398 .29172 .48673 .28866 .47954 .28132 Mtetra
.608 .756 .949 r
.47954 .28132 .48673 .28866 .49956 .28543 .4924 .27814 Mtetra
.615 .761 .949 r
.4924 .27814 .49956 .28543 .51246 .282 .50534 .27475 Mtetra
.623 .767 .948 r
.50534 .27475 .51246 .282 .52543 .27835 .51835 .27113 Mtetra
.631 .772 .948 r
.51835 .27113 .52543 .27835 .53847 .27447 .53144 .26728 Mtetra
.64 .777 .946 r
.53144 .26728 .53847 .27447 .55157 .27034 .54459 .26316 Mtetra
.649 .781 .944 r
.54459 .26316 .55157 .27034 .56474 .26595 .5578 .25877 Mtetra
.658 .786 .942 r
.5578 .25877 .56474 .26595 .57797 .2613 .57108 .2541 Mtetra
.667 .789 .94 r
.57108 .2541 .57797 .2613 .59125 .25637 .58441 .24915 Mtetra
.676 .793 .937 r
.58441 .24915 .59125 .25637 .60459 .25119 .59781 .24392 Mtetra
.684 .795 .934 r
.59781 .24392 .60459 .25119 .61799 .24574 .61125 .23842 Mtetra
.691 .797 .931 r
.61125 .23842 .61799 .24574 .63143 .24004 .62475 .23265 Mtetra
.698 .799 .927 r
.62475 .23265 .63143 .24004 .64493 .2341 .63829 .22663 Mtetra
.704 .8 .924 r
.63829 .22663 .64493 .2341 .65846 .22795 .65188 .22038 Mtetra
.71 .8 .921 r
.65188 .22038 .65846 .22795 .67205 .22159 .66552 .21391 Mtetra
.714 .799 .918 r
.66552 .21391 .67205 .22159 .68568 .21505 .6792 .20726 Mtetra
.718 .799 .915 r
.6792 .20726 .68568 .21505 .69935 .20836 .69292 .20044 Mtetra
.721 .797 .912 r
.69292 .20044 .69935 .20836 .71306 .20153 .70669 .19348 Mtetra
.723 .796 .909 r
.70669 .19348 .71306 .20153 .72682 .19459 .7205 .1864 Mtetra
.724 .793 .907 r
.7205 .1864 .72682 .19459 .74063 .18757 .73435 .17924 Mtetra
.724 .791 .905 r
.73435 .17924 .74063 .18757 .75448 .18049 .74825 .17202 Mtetra
.724 .789 .903 r
.74825 .17202 .75448 .18049 .76837 .17338 .76219 .16476 Mtetra
.724 .786 .902 r
.76219 .16476 .76837 .17338 .78232 .16625 .77619 .15749 Mtetra
.65 .732 .909 r
.13812 .35819 .14617 .3659 .15735 .36223 .14933 .35448 Mtetra
.649 .732 .91 r
.14933 .35448 .15735 .36223 .16857 .35858 .16058 .35079 Mtetra
.647 .731 .91 r
.16058 .35079 .16857 .35858 .17984 .35496 .17187 .34712 Mtetra
.645 .731 .911 r
.17187 .34712 .17984 .35496 .19116 .35136 .18322 .34349 Mtetra
.643 .73 .911 r
.18322 .34349 .19116 .35136 .20252 .34781 .19461 .3399 Mtetra
.641 .729 .912 r
.19461 .3399 .20252 .34781 .21394 .3443 .20605 .33636 Mtetra
.639 .728 .913 r
.20605 .33636 .21394 .3443 .2254 .34084 .21754 .33287 Mtetra
.636 .727 .914 r
.21754 .33287 .2254 .34084 .23691 .33744 .22908 .32944 Mtetra
.632 .727 .915 r
.22908 .32944 .23691 .33744 .24848 .33411 .24067 .32608 Mtetra
.629 .726 .917 r
.24067 .32608 .24848 .33411 .26009 .33085 .25231 .3228 Mtetra
.625 .725 .918 r
.25231 .3228 .26009 .33085 .27176 .32767 .264 .31961 Mtetra
.621 .724 .92 r
.264 .31961 .27176 .32767 .28347 .32457 .27575 .31649 Mtetra
.617 .723 .922 r
.27575 .31649 .28347 .32457 .29524 .32155 .28754 .31347 Mtetra
.613 .723 .924 r
.28754 .31347 .29524 .32155 .30707 .31862 .2994 .31054 Mtetra
.608 .722 .926 r
.2994 .31054 .30707 .31862 .31896 .31578 .31131 .30771 Mtetra
.604 .722 .928 r
.31131 .30771 .31896 .31578 .3309 .31301 .32328 .30496 Mtetra
.6 .722 .93 r
.32328 .30496 .3309 .31301 .34291 .31032 .33531 .30229 Mtetra
.596 .722 .932 r
.33531 .30229 .34291 .31032 .35497 .3077 .3474 .2997 Mtetra
.592 .722 .934 r
.3474 .2997 .35497 .3077 .36711 .30514 .35956 .29717 Mtetra
.589 .723 .936 r
.35956 .29717 .36711 .30514 .37931 .30262 .37179 .29469 Mtetra
.587 .724 .938 r
.37179 .29469 .37931 .30262 .39158 .30012 .38409 .29224 Mtetra
.585 .726 .94 r
.38409 .29224 .39158 .30012 .40392 .29762 .39646 .28979 Mtetra
.585 .729 .942 r
.39646 .28979 .40392 .29762 .41634 .2951 .4089 .28733 Mtetra
.585 .731 .944 r
.4089 .28733 .41634 .2951 .42882 .29254 .42142 .28483 Mtetra
.587 .735 .945 r
.42142 .28483 .42882 .29254 .44139 .28991 .43402 .28225 Mtetra
.59 .739 .947 r
.43402 .28225 .44139 .28991 .45403 .28718 .44669 .27958 Mtetra
.594 .743 .947 r
.44669 .27958 .45403 .28718 .46674 .28433 .45944 .27678 Mtetra
.599 .748 .948 r
.45944 .27678 .46674 .28433 .47954 .28132 .47227 .27383 Mtetra
.605 .753 .948 r
.47227 .27383 .47954 .28132 .4924 .27814 .48518 .27069 Mtetra
.613 .758 .948 r
.48518 .27069 .4924 .27814 .50534 .27475 .49816 .26735 Mtetra
.621 .763 .948 r
.49816 .26735 .50534 .27475 .51835 .27113 .51121 .26377 Mtetra
.629 .769 .947 r
.51121 .26377 .51835 .27113 .53144 .26728 .52434 .25994 Mtetra
.639 .774 .945 r
.52434 .25994 .53144 .26728 .54459 .26316 .53753 .25583 Mtetra
.648 .779 .943 r
.53753 .25583 .54459 .26316 .5578 .25877 .5508 .25144 Mtetra
.657 .783 .941 r
.5508 .25144 .5578 .25877 .57108 .2541 .56412 .24677 Mtetra
.667 .787 .938 r
.56412 .24677 .57108 .2541 .58441 .24915 .57751 .24179 Mtetra
.676 .791 .936 r
.57751 .24179 .58441 .24915 .59781 .24392 .59095 .23652 Mtetra
.684 .794 .933 r
.59095 .23652 .59781 .24392 .61125 .23842 .60445 .23097 Mtetra
.692 .796 .929 r
.60445 .23097 .61125 .23842 .62475 .23265 .61799 .22513 Mtetra
.699 .798 .926 r
.61799 .22513 .62475 .23265 .63829 .22663 .63159 .21904 Mtetra
.706 .799 .923 r
.63159 .21904 .63829 .22663 .65188 .22038 .64523 .2127 Mtetra
.711 .799 .919 r
.64523 .2127 .65188 .22038 .66552 .21391 .65892 .20613 Mtetra
.716 .799 .916 r
.65892 .20613 .66552 .21391 .6792 .20726 .67265 .19936 Mtetra
.72 .798 .913 r
.67265 .19936 .6792 .20726 .69292 .20044 .68643 .19242 Mtetra
.723 .797 .911 r
.68643 .19242 .69292 .20044 .70669 .19348 .70025 .18533 Mtetra
.725 .796 .908 r
.70025 .18533 .70669 .19348 .7205 .1864 .71411 .17813 Mtetra
.726 .794 .906 r
.71411 .17813 .7205 .1864 .73435 .17924 .72801 .17083 Mtetra
.727 .792 .904 r
.72801 .17083 .73435 .17924 .74825 .17202 .74196 .16346 Mtetra
.727 .789 .902 r
.74196 .16346 .74825 .17202 .76219 .16476 .75595 .15606 Mtetra
.726 .787 .901 r
.75595 .15606 .76219 .16476 .77619 .15749 .77 .14865 Mtetra
.65 .732 .909 r
.13001 .35041 .13812 .35819 .14933 .35448 .14124 .34666 Mtetra
.649 .732 .91 r
.14124 .34666 .14933 .35448 .16058 .35079 .15252 .34292 Mtetra
.648 .731 .91 r
.15252 .34292 .16058 .35079 .17187 .34712 .16384 .33922 Mtetra
.646 .73 .911 r
.16384 .33922 .17187 .34712 .18322 .34349 .17521 .33555 Mtetra
.644 .73 .911 r
.17521 .33555 .18322 .34349 .19461 .3399 .18664 .33192 Mtetra
.641 .729 .912 r
.18664 .33192 .19461 .3399 .20605 .33636 .1981 .32834 Mtetra
.639 .728 .913 r
.1981 .32834 .20605 .33636 .21754 .33287 .20962 .32482 Mtetra
.636 .727 .914 r
.20962 .32482 .21754 .33287 .22908 .32944 .22119 .32136 Mtetra
.632 .726 .915 r
.22119 .32136 .22908 .32944 .24067 .32608 .2328 .31797 Mtetra
.629 .725 .917 r
.2328 .31797 .24067 .32608 .25231 .3228 .24447 .31467 Mtetra
.625 .724 .918 r
.24447 .31467 .25231 .3228 .264 .31961 .25619 .31145 Mtetra
.621 .723 .92 r
.25619 .31145 .264 .31961 .27575 .31649 .26796 .30832 Mtetra
.616 .722 .922 r
.26796 .30832 .27575 .31649 .28754 .31347 .27978 .3053 Mtetra
.612 .721 .923 r
.27978 .3053 .28754 .31347 .2994 .31054 .29166 .30236 Mtetra
.607 .721 .925 r
.29166 .30236 .2994 .31054 .31131 .30771 .30359 .29953 Mtetra
.602 .72 .927 r
.30359 .29953 .31131 .30771 .32328 .30496 .31559 .29679 Mtetra
.598 .72 .929 r
.31559 .29679 .32328 .30496 .33531 .30229 .32765 .29414 Mtetra
.594 .72 .932 r
.32765 .29414 .33531 .30229 .3474 .2997 .33977 .29157 Mtetra
.59 .72 .934 r
.33977 .29157 .3474 .2997 .35956 .29717 .35195 .28907 Mtetra
.587 .72 .936 r
.35195 .28907 .35956 .29717 .37179 .29469 .36421 .28662 Mtetra
.584 .721 .938 r
.36421 .28662 .37179 .29469 .38409 .29224 .37653 .28421 Mtetra
.583 .723 .939 r
.37653 .28421 .38409 .29224 .39646 .28979 .38893 .28181 Mtetra
.582 .725 .941 r
.38893 .28181 .39646 .28979 .4089 .28733 .40141 .27939 Mtetra
.582 .727 .943 r
.40141 .27939 .4089 .28733 .42142 .28483 .41396 .27694 Mtetra
.584 .731 .944 r
.41396 .27694 .42142 .28483 .43402 .28225 .42658 .27442 Mtetra
.587 .734 .945 r
.42658 .27442 .43402 .28225 .44669 .27958 .43929 .2718 Mtetra
.591 .739 .946 r
.43929 .2718 .44669 .27958 .45944 .27678 .45208 .26906 Mtetra
.596 .743 .947 r
.45208 .26906 .45944 .27678 .47227 .27383 .46494 .26615 Mtetra
.603 .748 .947 r
.46494 .26615 .47227 .27383 .48518 .27069 .47789 .26306 Mtetra
.61 .754 .946 r
.47789 .26306 .48518 .27069 .49816 .26735 .49091 .25976 Mtetra
.619 .759 .946 r
.49091 .25976 .49816 .26735 .51121 .26377 .504 .25621 Mtetra
.628 .764 .945 r
.504 .25621 .51121 .26377 .52434 .25994 .51717 .2524 Mtetra
.637 .77 .943 r
.51717 .2524 .52434 .25994 .53753 .25583 .53041 .24831 Mtetra
.647 .775 .941 r
.53041 .24831 .53753 .25583 .5508 .25144 .54372 .24393 Mtetra
.657 .779 .939 r
.54372 .24393 .5508 .25144 .56412 .24677 .55709 .23924 Mtetra
.666 .784 .937 r
.55709 .23924 .56412 .24677 .57751 .24179 .57053 .23425 Mtetra
.675 .787 .934 r
.57053 .23425 .57751 .24179 .59095 .23652 .58402 .22895 Mtetra
.684 .791 .931 r
.58402 .22895 .59095 .23652 .60445 .23097 .59757 .22335 Mtetra
.692 .793 .927 r
.59757 .22335 .60445 .23097 .61799 .22513 .61117 .21746 Mtetra
.7 .795 .924 r
.61117 .21746 .61799 .22513 .63159 .21904 .62482 .21129 Mtetra
.706 .797 .921 r
.62482 .21129 .63159 .21904 .64523 .2127 .63852 .20486 Mtetra
.712 .797 .917 r
.63852 .20486 .64523 .2127 .65892 .20613 .65226 .1982 Mtetra
.717 .797 .914 r
.65226 .1982 .65892 .20613 .67265 .19936 .66604 .19133 Mtetra
.721 .797 .911 r
.66604 .19133 .67265 .19936 .68643 .19242 .67987 .18427 Mtetra
.724 .796 .909 r
.67987 .18427 .68643 .19242 .70025 .18533 .69374 .17706 Mtetra
.727 .795 .906 r
.69374 .17706 .70025 .18533 .71411 .17813 .70765 .16973 Mtetra
.728 .793 .904 r
.70765 .16973 .71411 .17813 .72801 .17083 .72161 .16229 Mtetra
.729 .791 .902 r
.72161 .16229 .72801 .17083 .74196 .16346 .73561 .1548 Mtetra
.729 .789 .9 r
.73561 .1548 .74196 .16346 .75595 .15606 .74965 .14726 Mtetra
.728 .787 .899 r
.74965 .14726 .75595 .15606 .77 .14865 .76374 .13971 Mtetra
.651 .732 .909 r
.12184 .34256 .13001 .35041 .14124 .34666 .13309 .33876 Mtetra
.649 .732 .909 r
.13309 .33876 .14124 .34666 .15252 .34292 .1444 .33499 Mtetra
.648 .731 .91 r
.1444 .33499 .15252 .34292 .16384 .33922 .15575 .33124 Mtetra
.646 .73 .91 r
.15575 .33124 .16384 .33922 .17521 .33555 .16715 .32753 Mtetra
.644 .729 .911 r
.16715 .32753 .17521 .33555 .18664 .33192 .1786 .32386 Mtetra
.641 .729 .912 r
.1786 .32386 .18664 .33192 .1981 .32834 .19009 .32024 Mtetra
.639 .728 .913 r
.19009 .32024 .1981 .32834 .20962 .32482 .20164 .31668 Mtetra
.636 .727 .914 r
.20164 .31668 .20962 .32482 .22119 .32136 .21323 .31319 Mtetra
.632 .726 .915 r
.21323 .31319 .22119 .32136 .2328 .31797 .22487 .30978 Mtetra
.628 .725 .916 r
.22487 .30978 .2328 .31797 .24447 .31467 .23657 .30644 Mtetra
.624 .723 .918 r
.23657 .30644 .24447 .31467 .25619 .31145 .24831 .3032 Mtetra
.62 .722 .919 r
.24831 .3032 .25619 .31145 .26796 .30832 .26011 .30006 Mtetra
.616 .721 .921 r
.26011 .30006 .26796 .30832 .27978 .3053 .27195 .29701 Mtetra
.611 .72 .923 r
.27195 .29701 .27978 .3053 .29166 .30236 .28386 .29407 Mtetra
.606 .719 .925 r
.28386 .29407 .29166 .30236 .30359 .29953 .29582 .29123 Mtetra
.601 .718 .927 r
.29582 .29123 .30359 .29953 .31559 .29679 .30784 .2885 Mtetra
.596 .718 .929 r
.30784 .2885 .31559 .29679 .32765 .29414 .31992 .28585 Mtetra
.592 .717 .931 r
.31992 .28585 .32765 .29414 .33977 .29157 .33207 .2833 Mtetra
.588 .717 .933 r
.33207 .2833 .33977 .29157 .35195 .28907 .34428 .28082 Mtetra
.585 .717 .935 r
.34428 .28082 .35195 .28907 .36421 .28662 .35657 .27839 Mtetra
.582 .718 .936 r
.35657 .27839 .36421 .28662 .37653 .28421 .36892 .27601 Mtetra
.58 .719 .938 r
.36892 .27601 .37653 .28421 .38893 .28181 .38134 .27365 Mtetra
.579 .721 .94 r
.38134 .27365 .38893 .28181 .40141 .27939 .39385 .27127 Mtetra
.58 .723 .941 r
.39385 .27127 .40141 .27939 .41396 .27694 .40643 .26886 Mtetra
.581 .726 .942 r
.40643 .26886 .41396 .27694 .42658 .27442 .41909 .26639 Mtetra
.584 .73 .943 r
.41909 .26639 .42658 .27442 .43929 .2718 .43183 .26382 Mtetra
.588 .734 .944 r
.43183 .26382 .43929 .2718 .45208 .26906 .44465 .26112 Mtetra
.594 .738 .944 r
.44465 .26112 .45208 .26906 .46494 .26615 .45755 .25826 Mtetra
.6 .743 .944 r
.45755 .25826 .46494 .26615 .47789 .26306 .47053 .25521 Mtetra
.608 .748 .944 r
.47053 .25521 .47789 .26306 .49091 .25976 .48359 .25194 Mtetra
.617 .754 .943 r
.48359 .25194 .49091 .25976 .504 .25621 .49672 .24842 Mtetra
.626 .759 .942 r
.49672 .24842 .504 .25621 .51717 .2524 .50994 .24464 Mtetra
.636 .764 .941 r
.50994 .24464 .51717 .2524 .53041 .24831 .52322 .24056 Mtetra
.646 .77 .939 r
.52322 .24056 .53041 .24831 .54372 .24393 .53658 .23618 Mtetra
.656 .775 .936 r
.53658 .23618 .54372 .24393 .55709 .23924 .55 .23149 Mtetra
.665 .779 .934 r
.55 .23149 .55709 .23924 .57053 .23425 .56348 .22648 Mtetra
.675 .783 .931 r
.56348 .22648 .57053 .23425 .58402 .22895 .57702 .22115 Mtetra
.684 .786 .928 r
.57702 .22115 .58402 .22895 .59757 .22335 .59062 .21551 Mtetra
.692 .789 .925 r
.59062 .21551 .59757 .22335 .61117 .21746 .60428 .20956 Mtetra
.7 .791 .921 r
.60428 .20956 .61117 .21746 .62482 .21129 .61798 .20333 Mtetra
.707 .793 .918 r
.61798 .20333 .62482 .21129 .63852 .20486 .63173 .19683 Mtetra
.713 .794 .915 r
.63173 .19683 .63852 .20486 .65226 .1982 .64552 .19008 Mtetra
.718 .795 .912 r
.64552 .19008 .65226 .1982 .66604 .19133 .65936 .18311 Mtetra
.722 .795 .909 r
.65936 .18311 .66604 .19133 .67987 .18427 .67324 .17595 Mtetra
.726 .794 .906 r
.67324 .17595 .67987 .18427 .69374 .17706 .68716 .16862 Mtetra
.728 .793 .904 r
.68716 .16862 .69374 .17706 .70765 .16973 .70113 .16117 Mtetra
.729 .792 .902 r
.70113 .16117 .70765 .16973 .72161 .16229 .71514 .15361 Mtetra
.73 .79 .9 r
.71514 .15361 .72161 .16229 .73561 .1548 .72919 .14598 Mtetra
.73 .788 .899 r
.72919 .14598 .73561 .1548 .74965 .14726 .74328 .13832 Mtetra
.73 .786 .897 r
.74328 .13832 .74965 .14726 .76374 .13971 .75743 .13063 Mtetra
.651 .732 .909 r
.1136 .33464 .12184 .34256 .13309 .33876 .12488 .3308 Mtetra
.65 .732 .909 r
.12488 .3308 .13309 .33876 .1444 .33499 .13621 .32698 Mtetra
.648 .731 .909 r
.13621 .32698 .1444 .33499 .15575 .33124 .14759 .32319 Mtetra
.646 .73 .91 r
.14759 .32319 .15575 .33124 .16715 .32753 .15902 .31944 Mtetra
.644 .729 .911 r
.15902 .31944 .16715 .32753 .1786 .32386 .17049 .31573 Mtetra
.642 .728 .911 r
.17049 .31573 .1786 .32386 .19009 .32024 .18202 .31207 Mtetra
.639 .727 .912 r
.18202 .31207 .19009 .32024 .20164 .31668 .19359 .30847 Mtetra
.636 .726 .913 r
.19359 .30847 .20164 .31668 .21323 .31319 .20521 .30494 Mtetra
.632 .725 .915 r
.20521 .30494 .21323 .31319 .22487 .30978 .21688 .30149 Mtetra
.628 .724 .916 r
.21688 .30149 .22487 .30978 .23657 .30644 .2286 .29813 Mtetra
.624 .723 .917 r
.2286 .29813 .23657 .30644 .24831 .3032 .24037 .29485 Mtetra
.62 .721 .919 r
.24037 .29485 .24831 .3032 .26011 .30006 .25219 .29168 Mtetra
.615 .72 .921 r
.25219 .29168 .26011 .30006 .27195 .29701 .26407 .28862 Mtetra
.61 .719 .922 r
.26407 .28862 .27195 .29701 .28386 .29407 .276 .28566 Mtetra
.605 .717 .924 r
.276 .28566 .28386 .29407 .29582 .29123 .28799 .28281 Mtetra
.6 .716 .926 r
.28799 .28281 .29582 .29123 .30784 .2885 .30003 .28007 Mtetra
.595 .715 .928 r
.30003 .28007 .30784 .2885 .31992 .28585 .31214 .27742 Mtetra
.591 .715 .93 r
.31214 .27742 .31992 .28585 .33207 .2833 .32431 .27487 Mtetra
.587 .714 .931 r
.32431 .27487 .33207 .2833 .34428 .28082 .33655 .2724 Mtetra
.583 .714 .933 r
.33655 .2724 .34428 .28082 .35657 .27839 .34886 .26999 Mtetra
.58 .714 .935 r
.34886 .26999 .35657 .27839 .36892 .27601 .36124 .26763 Mtetra
.578 .715 .936 r
.36124 .26763 .36892 .27601 .38134 .27365 .3737 .26529 Mtetra
.577 .717 .938 r
.3737 .26529 .38134 .27365 .39385 .27127 .38623 .26294 Mtetra
.578 .719 .939 r
.38623 .26294 .39385 .27127 .40643 .26886 .39884 .26057 Mtetra
.579 .721 .94 r
.39884 .26057 .40643 .26886 .41909 .26639 .41153 .25813 Mtetra
.582 .724 .941 r
.41153 .25813 .41909 .26639 .43183 .26382 .4243 .25559 Mtetra
.586 .728 .941 r
.4243 .25559 .43183 .26382 .44465 .26112 .43715 .25293 Mtetra
.592 .732 .941 r
.43715 .25293 .44465 .26112 .45755 .25826 .45009 .2501 Mtetra
.599 .737 .941 r
.45009 .2501 .45755 .25826 .47053 .25521 .4631 .24709 Mtetra
.606 .742 .941 r
.4631 .24709 .47053 .25521 .48359 .25194 .4762 .24385 Mtetra
.615 .747 .94 r
.4762 .24385 .48359 .25194 .49672 .24842 .48938 .24036 Mtetra
.624 .753 .939 r
.48938 .24036 .49672 .24842 .50994 .24464 .50263 .23659 Mtetra
.634 .758 .937 r
.50263 .23659 .50994 .24464 .52322 .24056 .51596 .23253 Mtetra
.644 .763 .935 r
.51596 .23253 .52322 .24056 .53658 .23618 .52936 .22816 Mtetra
.655 .768 .933 r
.52936 .22816 .53658 .23618 .55 .23149 .54283 .22347 Mtetra
.665 .773 .93 r
.54283 .22347 .55 .23149 .56348 .22648 .55636 .21844 Mtetra
.674 .777 .927 r
.55636 .21844 .56348 .22648 .57702 .22115 .56995 .21309 Mtetra
.684 .781 .924 r
.56995 .21309 .57702 .22115 .59062 .21551 .5836 .20741 Mtetra
.692 .784 .921 r
.5836 .20741 .59062 .21551 .60428 .20956 .59731 .20142 Mtetra
.7 .786 .918 r
.59731 .20142 .60428 .20956 .61798 .20333 .61106 .19513 Mtetra
.707 .788 .915 r
.61106 .19513 .61798 .20333 .63173 .19683 .62487 .18855 Mtetra
.713 .79 .912 r
.62487 .18855 .63173 .19683 .64552 .19008 .63871 .18173 Mtetra
.719 .791 .909 r
.63871 .18173 .64552 .19008 .65936 .18311 .65261 .17467 Mtetra
.723 .791 .906 r
.65261 .17467 .65936 .18311 .67324 .17595 .66654 .16741 Mtetra
.726 .791 .903 r
.66654 .16741 .67324 .17595 .68716 .16862 .68052 .15998 Mtetra
.729 .79 .901 r
.68052 .15998 .68716 .16862 .70113 .16117 .69453 .15242 Mtetra
.73 .789 .899 r
.69453 .15242 .70113 .16117 .71514 .15361 .7086 .14474 Mtetra
.731 .788 .898 r
.7086 .14474 .71514 .15361 .72919 .14598 .7227 .137 Mtetra
.731 .786 .896 r
.7227 .137 .72919 .14598 .74328 .13832 .73685 .12921 Mtetra
.731 .784 .895 r
.73685 .12921 .74328 .13832 .75743 .13063 .75105 .12141 Mtetra
.652 .732 .908 r
.10529 .32666 .1136 .33464 .12488 .3308 .1166 .32277 Mtetra
.65 .732 .909 r
.1166 .32277 .12488 .3308 .13621 .32698 .12796 .31891 Mtetra
.649 .731 .909 r
.12796 .31891 .13621 .32698 .14759 .32319 .13937 .31507 Mtetra
.647 .73 .91 r
.13937 .31507 .14759 .32319 .15902 .31944 .15082 .31128 Mtetra
.644 .729 .91 r
.15082 .31128 .15902 .31944 .17049 .31573 .16232 .30752 Mtetra
.642 .728 .911 r
.16232 .30752 .17049 .31573 .18202 .31207 .17388 .30382 Mtetra
.639 .727 .912 r
.17388 .30382 .18202 .31207 .19359 .30847 .18548 .30017 Mtetra
.636 .726 .913 r
.18548 .30017 .19359 .30847 .20521 .30494 .19712 .2966 Mtetra
.632 .725 .914 r
.19712 .2966 .20521 .30494 .21688 .30149 .20882 .29311 Mtetra
.628 .723 .915 r
.20882 .29311 .21688 .30149 .2286 .29813 .22057 .28971 Mtetra
.624 .722 .917 r
.22057 .28971 .2286 .29813 .24037 .29485 .23237 .28641 Mtetra
.62 .72 .918 r
.23237 .28641 .24037 .29485 .25219 .29168 .24422 .2832 Mtetra
.615 .719 .92 r
.24422 .2832 .25219 .29168 .26407 .28862 .25612 .28011 Mtetra
.61 .717 .921 r
.25612 .28011 .26407 .28862 .276 .28566 .26808 .27713 Mtetra
.605 .716 .923 r
.26808 .27713 .276 .28566 .28799 .28281 .28009 .27426 Mtetra
.6 .714 .925 r
.28009 .27426 .28799 .28281 .30003 .28007 .29216 .2715 Mtetra
.595 .713 .926 r
.29216 .2715 .30003 .28007 .31214 .27742 .3043 .26884 Mtetra
.59 .712 .928 r
.3043 .26884 .31214 .27742 .32431 .27487 .3165 .26628 Mtetra
.586 .711 .93 r
.3165 .26628 .32431 .27487 .33655 .2724 .32876 .26381 Mtetra
.582 .711 .931 r
.32876 .26381 .33655 .2724 .34886 .26999 .3411 .2614 Mtetra
.579 .711 .933 r
.3411 .2614 .34886 .26999 .36124 .26763 .35351 .25905 Mtetra
.577 .711 .934 r
.35351 .25905 .36124 .26763 .3737 .26529 .36599 .25672 Mtetra
.576 .712 .935 r
.36599 .25672 .3737 .26529 .38623 .26294 .37855 .25439 Mtetra
.576 .714 .936 r
.37855 .25439 .38623 .26294 .39884 .26057 .39119 .25203 Mtetra
.578 .716 .937 r
.39119 .25203 .39884 .26057 .41153 .25813 .40391 .24961 Mtetra
.581 .719 .937 r
.40391 .24961 .41153 .25813 .4243 .25559 .41671 .2471 Mtetra
.585 .722 .938 r
.41671 .2471 .4243 .25559 .43715 .25293 .42959 .24446 Mtetra
.591 .726 .938 r
.42959 .24446 .43715 .25293 .45009 .2501 .44256 .24167 Mtetra
.597 .731 .938 r
.44256 .24167 .45009 .2501 .4631 .24709 .45562 .23867 Mtetra
.605 .735 .937 r
.45562 .23867 .4631 .24709 .4762 .24385 .46875 .23546 Mtetra
.614 .741 .936 r
.46875 .23546 .4762 .24385 .48938 .24036 .48197 .23199 Mtetra
.623 .746 .935 r
.48197 .23199 .48938 .24036 .50263 .23659 .49526 .22824 Mtetra
.633 .751 .933 r
.49526 .22824 .50263 .23659 .51596 .23253 .50863 .22419 Mtetra
.643 .756 .931 r
.50863 .22419 .51596 .23253 .52936 .22816 .52208 .21982 Mtetra
.654 .761 .929 r
.52208 .21982 .52936 .22816 .54283 .22347 .53559 .21512 Mtetra
.664 .766 .926 r
.53559 .21512 .54283 .22347 .55636 .21844 .54917 .21009 Mtetra
.673 .77 .923 r
.54917 .21009 .55636 .21844 .56995 .21309 .56281 .20471 Mtetra
.683 .774 .92 r
.56281 .20471 .56995 .21309 .5836 .20741 .57651 .199 Mtetra
.692 .778 .917 r
.57651 .199 .5836 .20741 .59731 .20142 .59027 .19297 Mtetra
.7 .78 .914 r
.59027 .19297 .59731 .20142 .61106 .19513 .60407 .18663 Mtetra
.707 .783 .911 r
.60407 .18663 .61106 .19513 .62487 .18855 .61793 .18 Mtetra
.713 .784 .908 r
.61793 .18 .62487 .18855 .63871 .18173 .63183 .1731 Mtetra
.718 .786 .905 r
.63183 .1731 .63871 .18173 .65261 .17467 .64578 .16597 Mtetra
.723 .786 .902 r
.64578 .16597 .65261 .17467 .66654 .16741 .65977 .15862 Mtetra
.727 .787 .9 r
.65977 .15862 .66654 .16741 .68052 .15998 .6738 .1511 Mtetra
.729 .786 .898 r
.6738 .1511 .68052 .15998 .69453 .15242 .68787 .14344 Mtetra
.731 .786 .896 r
.68787 .14344 .69453 .15242 .7086 .14474 .70198 .13566 Mtetra
.732 .785 .895 r
.70198 .13566 .7086 .14474 .7227 .137 .71614 .12781 Mtetra
.732 .784 .894 r
.71614 .12781 .7227 .137 .73685 .12921 .73035 .11991 Mtetra
.732 .782 .893 r
.73035 .11991 .73685 .12921 .75105 .12141 .7446 .112 Mtetra
.652 .732 .908 r
.09691 .31861 .10529 .32666 .1166 .32277 .10825 .31468 Mtetra
.651 .732 .909 r
.10825 .31468 .1166 .32277 .12796 .31891 .11964 .31077 Mtetra
.649 .731 .909 r
.11964 .31077 .12796 .31891 .13937 .31507 .13108 .30688 Mtetra
.647 .73 .909 r
.13108 .30688 .13937 .31507 .15082 .31128 .14256 .30304 Mtetra
.645 .729 .91 r
.14256 .30304 .15082 .31128 .16232 .30752 .15409 .29923 Mtetra
.642 .728 .911 r
.15409 .29923 .16232 .30752 .17388 .30382 .16567 .29548 Mtetra
.639 .727 .912 r
.16567 .29548 .17388 .30382 .18548 .30017 .1773 .2918 Mtetra
.636 .726 .913 r
.1773 .2918 .18548 .30017 .19712 .2966 .18898 .28818 Mtetra
.633 .724 .914 r
.18898 .28818 .19712 .2966 .20882 .29311 .2007 .28465 Mtetra
.629 .723 .915 r
.2007 .28465 .20882 .29311 .22057 .28971 .21248 .2812 Mtetra
.624 .721 .916 r
.21248 .2812 .22057 .28971 .23237 .28641 .2243 .27786 Mtetra
.62 .72 .918 r
.2243 .27786 .23237 .28641 .24422 .2832 .23618 .27461 Mtetra
.615 .718 .919 r
.23618 .27461 .24422 .2832 .25612 .28011 .24811 .27148 Mtetra
.61 .716 .92 r
.24811 .27148 .25612 .28011 .26808 .27713 .26009 .26847 Mtetra
.605 .714 .922 r
.26009 .26847 .26808 .27713 .28009 .27426 .27213 .26557 Mtetra
.6 .713 .923 r
.27213 .26557 .28009 .27426 .29216 .2715 .28424 .26278 Mtetra
.594 .711 .925 r
.28424 .26278 .29216 .2715 .3043 .26884 .2964 .2601 Mtetra
.59 .71 .926 r
.2964 .2601 .3043 .26884 .3165 .26628 .30862 .25752 Mtetra
.585 .708 .928 r
.30862 .25752 .3165 .26628 .32876 .26381 .32091 .25503 Mtetra
.582 .707 .929 r
.32091 .25503 .32876 .26381 .3411 .2614 .33328 .25261 Mtetra
.579 .707 .93 r
.33328 .25261 .3411 .2614 .35351 .25905 .34571 .25025 Mtetra
.576 .707 .931 r
.34571 .25025 .35351 .25905 .36599 .25672 .35822 .24792 Mtetra
.575 .708 .932 r
.35822 .24792 .36599 .25672 .37855 .25439 .37081 .24559 Mtetra
.576 .709 .933 r
.37081 .24559 .37855 .25439 .39119 .25203 .38347 .24324 Mtetra
.577 .71 .933 r
.38347 .24324 .39119 .25203 .40391 .24961 .39622 .24082 Mtetra
.58 .713 .934 r
.39622 .24082 .40391 .24961 .41671 .2471 .40906 .23832 Mtetra
.584 .716 .934 r
.40906 .23832 .41671 .2471 .42959 .24446 .42197 .2357 Mtetra
.59 .72 .934 r
.42197 .2357 .42959 .24446 .44256 .24167 .43498 .23292 Mtetra
.596 .724 .933 r
.43498 .23292 .44256 .24167 .45562 .23867 .44807 .22994 Mtetra
.604 .728 .932 r
.44807 .22994 .45562 .23867 .46875 .23546 .46124 .22674 Mtetra
.613 .733 .931 r
.46124 .22674 .46875 .23546 .48197 .23199 .47449 .22328 Mtetra
.622 .738 .93 r
.47449 .22328 .48197 .23199 .49526 .22824 .48783 .21954 Mtetra
.632 .743 .928 r
.48783 .21954 .49526 .22824 .50863 .22419 .50124 .2155 Mtetra
.642 .748 .926 r
.50124 .2155 .50863 .22419 .52208 .21982 .51472 .21113 Mtetra
.652 .753 .924 r
.51472 .21113 .52208 .21982 .53559 .21512 .52828 .20643 Mtetra
.662 .758 .921 r
.52828 .20643 .53559 .21512 .54917 .21009 .54191 .20138 Mtetra
.672 .763 .918 r
.54191 .20138 .54917 .21009 .56281 .20471 .5556 .19599 Mtetra
.682 .767 .915 r
.5556 .19599 .56281 .20471 .57651 .199 .56935 .19025 Mtetra
.691 .77 .912 r
.56935 .19025 .57651 .199 .59027 .19297 .58315 .18419 Mtetra
.699 .773 .909 r
.58315 .18419 .59027 .19297 .60407 .18663 .59701 .17781 Mtetra
.706 .776 .906 r
.59701 .17781 .60407 .18663 .61793 .18 .61092 .17112 Mtetra
.712 .778 .904 r
.61092 .17112 .61793 .18 .63183 .1731 .62488 .16417 Mtetra
.718 .78 .901 r
.62488 .16417 .63183 .1731 .64578 .16597 .63888 .15697 Mtetra
.723 .781 .899 r
.63888 .15697 .64578 .16597 .65977 .15862 .65292 .14955 Mtetra
.726 .781 .896 r
.65292 .14955 .65977 .15862 .6738 .1511 .667 .14195 Mtetra
.729 .782 .895 r
.667 .14195 .6738 .1511 .68787 .14344 .68113 .1342 Mtetra
.731 .782 .893 r
.68113 .1342 .68787 .14344 .70198 .13566 .6953 .12634 Mtetra
.732 .781 .892 r
.6953 .12634 .70198 .13566 .71614 .12781 .70951 .11839 Mtetra
.732 .78 .891 r
.70951 .11839 .71614 .12781 .73035 .11991 .72377 .1104 Mtetra
.732 .779 .89 r
.72377 .1104 .73035 .11991 .7446 .112 .73808 .10239 Mtetra
.652 .732 .908 r
.08847 .31049 .09691 .31861 .10825 .31468 .09984 .30651 Mtetra
.651 .732 .908 r
.09984 .30651 .10825 .31468 .11964 .31077 .11125 .30255 Mtetra
.649 .731 .909 r
.11125 .30255 .11964 .31077 .13108 .30688 .12272 .29862 Mtetra
.647 .73 .909 r
.12272 .29862 .13108 .30688 .14256 .30304 .13423 .29472 Mtetra
.645 .729 .91 r
.13423 .29472 .14256 .30304 .15409 .29923 .14579 .29087 Mtetra
.643 .728 .91 r
.14579 .29087 .15409 .29923 .16567 .29548 .1574 .28707 Mtetra
.64 .727 .911 r
.1574 .28707 .16567 .29548 .1773 .2918 .16906 .28333 Mtetra
.637 .725 .912 r
.16906 .28333 .1773 .2918 .18898 .28818 .18076 .27967 Mtetra
.633 .724 .913 r
.18076 .27967 .18898 .28818 .2007 .28465 .19251 .27609 Mtetra
.629 .722 .914 r
.19251 .27609 .2007 .28465 .21248 .2812 .20432 .27259 Mtetra
.625 .721 .915 r
.20432 .27259 .21248 .2812 .2243 .27786 .21617 .2692 Mtetra
.62 .719 .917 r
.21617 .2692 .2243 .27786 .23618 .27461 .22808 .26591 Mtetra
.615 .717 .918 r
.22808 .26591 .23618 .27461 .24811 .27148 .24004 .26274 Mtetra
.61 .715 .919 r
.24004 .26274 .24811 .27148 .26009 .26847 .25205 .25968 Mtetra
.605 .713 .921 r
.25205 .25968 .26009 .26847 .27213 .26557 .26412 .25673 Mtetra
.6 .711 .922 r
.26412 .25673 .27213 .26557 .28424 .26278 .27624 .25391 Mtetra
.595 .709 .923 r
.27624 .25391 .28424 .26278 .2964 .2601 .28843 .25119 Mtetra
.59 .707 .925 r
.28843 .25119 .2964 .2601 .30862 .25752 .30069 .24858 Mtetra
.585 .706 .926 r
.30069 .24858 .30862 .25752 .32091 .25503 .31301 .24606 Mtetra
.582 .704 .927 r
.31301 .24606 .32091 .25503 .33328 .25261 .32539 .24362 Mtetra
.579 .703 .928 r
.32539 .24362 .33328 .25261 .34571 .25025 .33786 .24123 Mtetra
.576 .703 .928 r
.33786 .24123 .34571 .25025 .35822 .24792 .35039 .23888 Mtetra
.575 .703 .929 r
.35039 .23888 .35822 .24792 .37081 .24559 .36301 .23653 Mtetra
.576 .704 .929 r
.36301 .23653 .37081 .24559 .38347 .24324 .37571 .23417 Mtetra
.577 .705 .93 r
.37571 .23417 .38347 .24324 .39622 .24082 .38848 .23175 Mtetra
.58 .707 .93 r
.38848 .23175 .39622 .24082 .40906 .23832 .40135 .22924 Mtetra
.584 .71 .929 r
.40135 .22924 .40906 .23832 .42197 .2357 .4143 .22662 Mtetra
.589 .713 .929 r
.4143 .22662 .42197 .2357 .43498 .23292 .42733 .22383 Mtetra
.596 .717 .928 r
.42733 .22383 .43498 .23292 .44807 .22994 .44045 .22086 Mtetra
.603 .721 .927 r
.44045 .22086 .44807 .22994 .46124 .22674 .45366 .21766 Mtetra
.612 .725 .926 r
.45366 .21766 .46124 .22674 .47449 .22328 .46695 .2142 Mtetra
.621 .73 .925 r
.46695 .2142 .47449 .22328 .48783 .21954 .48032 .21046 Mtetra
.631 .735 .923 r
.48032 .21046 .48783 .21954 .50124 .2155 .49378 .20642 Mtetra
.641 .74 .921 r
.49378 .20642 .50124 .2155 .51472 .21113 .5073 .20205 Mtetra
.651 .745 .918 r
.5073 .20205 .51472 .21113 .52828 .20643 .52091 .19734 Mtetra
.661 .75 .916 r
.52091 .19734 .52828 .20643 .54191 .20138 .53458 .19229 Mtetra
.671 .754 .913 r
.53458 .19229 .54191 .20138 .5556 .19599 .54831 .18688 Mtetra
.68 .758 .91 r
.54831 .18688 .5556 .19599 .56935 .19025 .56211 .18113 Mtetra
.689 .762 .907 r
.56211 .18113 .56935 .19025 .58315 .18419 .57597 .17504 Mtetra
.697 .766 .904 r
.57597 .17504 .58315 .18419 .59701 .17781 .58988 .16862 Mtetra
.705 .768 .902 r
.58988 .16862 .59701 .17781 .61092 .17112 .60384 .1619 Mtetra
.711 .771 .899 r
.60384 .1619 .61092 .17112 .62488 .16417 .61784 .1549 Mtetra
.717 .773 .897 r
.61784 .1549 .62488 .16417 .63888 .15697 .6319 .14764 Mtetra
.722 .774 .894 r
.6319 .14764 .63888 .15697 .65292 .14955 .64599 .14017 Mtetra
.725 .775 .892 r
.64599 .14017 .65292 .14955 .667 .14195 .66013 .1325 Mtetra
.728 .776 .891 r
.66013 .1325 .667 .14195 .68113 .1342 .67432 .12468 Mtetra
.73 .776 .89 r
.67432 .12468 .68113 .1342 .6953 .12634 .68854 .11674 Mtetra
.732 .776 .889 r
.68854 .11674 .6953 .12634 .70951 .11839 .70281 .10872 Mtetra
.732 .776 .888 r
.70281 .10872 .70951 .11839 .72377 .1104 .71712 .10065 Mtetra
.732 .775 .888 r
.71712 .10065 .72377 .1104 .73808 .10239 .73148 .09255 Mtetra
.653 .732 .908 r
.07996 .3023 .08847 .31049 .09984 .30651 .09136 .29827 Mtetra
.651 .732 .908 r
.09136 .29827 .09984 .30651 .11125 .30255 .1028 .29427 Mtetra
.65 .731 .908 r
.1028 .29427 .11125 .30255 .12272 .29862 .11429 .29028 Mtetra
.648 .73 .909 r
.11429 .29028 .12272 .29862 .13423 .29472 .12583 .28634 Mtetra
.646 .729 .909 r
.12583 .28634 .13423 .29472 .14579 .29087 .13742 .28243 Mtetra
.643 .728 .91 r
.13742 .28243 .14579 .29087 .1574 .28707 .14906 .27858 Mtetra
.64 .727 .911 r
.14906 .27858 .1574 .28707 .16906 .28333 .16075 .27479 Mtetra
.637 .725 .912 r
.16075 .27479 .16906 .28333 .18076 .27967 .17248 .27107 Mtetra
.634 .724 .913 r
.17248 .27107 .18076 .27967 .19251 .27609 .18426 .26743 Mtetra
.63 .722 .914 r
.18426 .26743 .19251 .27609 .20432 .27259 .1961 .26388 Mtetra
.625 .72 .915 r
.1961 .26388 .20432 .27259 .21617 .2692 .20798 .26044 Mtetra
.621 .718 .916 r
.20798 .26044 .21617 .2692 .22808 .26591 .21991 .25709 Mtetra
.616 .716 .917 r
.21991 .25709 .22808 .26591 .24004 .26274 .2319 .25386 Mtetra
.611 .714 .918 r
.2319 .25386 .24004 .26274 .25205 .25968 .24394 .25075 Mtetra
.606 .712 .919 r
.24394 .25075 .25205 .25968 .26412 .25673 .25604 .24776 Mtetra
.601 .709 .92 r
.25604 .24776 .26412 .25673 .27624 .25391 .26819 .24488 Mtetra
.595 .707 .921 r
.26819 .24488 .27624 .25391 .28843 .25119 .28041 .24211 Mtetra
.591 .705 .922 r
.28041 .24211 .28843 .25119 .30069 .24858 .29269 .23946 Mtetra
.586 .703 .923 r
.29269 .23946 .30069 .24858 .31301 .24606 .30504 .23689 Mtetra
.582 .701 .924 r
.30504 .23689 .31301 .24606 .32539 .24362 .31746 .2344 Mtetra
.579 .7 .925 r
.31746 .2344 .32539 .24362 .33786 .24123 .32995 .23198 Mtetra
.577 .699 .925 r
.32995 .23198 .33786 .24123 .35039 .23888 .34251 .22959 Mtetra
.576 .699 .925 r
.34251 .22959 .35039 .23888 .36301 .23653 .35515 .22721 Mtetra
.576 .699 .926 r
.35515 .22721 .36301 .23653 .37571 .23417 .36788 .22482 Mtetra
.577 .7 .925 r
.36788 .22482 .37571 .23417 .38848 .23175 .38069 .22237 Mtetra
.58 .701 .925 r
.38069 .22237 .38848 .23175 .40135 .22924 .39358 .21985 Mtetra
.584 .703 .925 r
.39358 .21985 .40135 .22924 .4143 .22662 .40656 .2172 Mtetra
.589 .706 .924 r
.40656 .2172 .4143 .22662 .42733 .22383 .41963 .2144 Mtetra
.596 .709 .923 r
.41963 .2144 .42733 .22383 .44045 .22086 .43278 .21141 Mtetra
.603 .713 .922 r
.43278 .21141 .44045 .22086 .45366 .21766 .44602 .2082 Mtetra
.611 .717 .921 r
.44602 .2082 .45366 .21766 .46695 .2142 .45935 .20474 Mtetra
.62 .722 .919 r
.45935 .20474 .46695 .2142 .48032 .21046 .47276 .201 Mtetra
.63 .727 .917 r
.47276 .201 .48032 .21046 .49378 .20642 .48625 .19694 Mtetra
.64 .731 .915 r
.48625 .19694 .49378 .20642 .5073 .20205 .49982 .19257 Mtetra
.65 .736 .913 r
.49982 .19257 .5073 .20205 .52091 .19734 .51346 .18785 Mtetra
.66 .741 .91 r
.51346 .18785 .52091 .19734 .53458 .19229 .52718 .18279 Mtetra
.669 .745 .907 r
.52718 .18279 .53458 .19229 .54831 .18688 .54096 .17737 Mtetra
.679 .75 .905 r
.54096 .17737 .54831 .18688 .56211 .18113 .5548 .1716 Mtetra
.687 .754 .902 r
.5548 .1716 .56211 .18113 .57597 .17504 .56871 .16548 Mtetra
.695 .757 .899 r
.56871 .16548 .57597 .17504 .58988 .16862 .58267 .15904 Mtetra
.703 .76 .897 r
.58267 .15904 .58988 .16862 .60384 .1619 .59668 .15229 Mtetra
.709 .763 .894 r
.59668 .15229 .60384 .1619 .61784 .1549 .61074 .14526 Mtetra
.715 .765 .892 r
.61074 .14526 .61784 .1549 .6319 .14764 .62484 .13796 Mtetra
.72 .767 .89 r
.62484 .13796 .6319 .14764 .64599 .14017 .63899 .13044 Mtetra
.724 .769 .888 r
.63899 .13044 .64599 .14017 .66013 .1325 .65319 .12273 Mtetra
.727 .77 .887 r
.65319 .12273 .66013 .1325 .67432 .12468 .66743 .11485 Mtetra
.729 .771 .886 r
.66743 .11485 .67432 .12468 .68854 .11674 .68171 .10686 Mtetra
.731 .771 .885 r
.68171 .10686 .68854 .11674 .70281 .10872 .69603 .09877 Mtetra
.69603 .09877 .70281 .10872 .71712 .10065 .7104 .09063 Mtetra
.7104 .09063 .71712 .10065 .73148 .09255 .72482 .08247 Mtetra
.653 .733 .908 r
.07138 .29404 .07996 .3023 .09136 .29827 .0828 .28997 Mtetra
.652 .732 .908 r
.0828 .28997 .09136 .29827 .1028 .29427 .09428 .28591 Mtetra
.65 .731 .908 r
.09428 .28591 .1028 .29427 .11429 .29028 .1058 .28187 Mtetra
.649 .73 .909 r
.1058 .28187 .11429 .29028 .12583 .28634 .11737 .27787 Mtetra
.646 .729 .909 r
.11737 .27787 .12583 .28634 .13742 .28243 .12899 .27392 Mtetra
.644 .728 .91 r
.12899 .27392 .13742 .28243 .14906 .27858 .14065 .27001 Mtetra
.641 .727 .91 r
.14065 .27001 .14906 .27858 .16075 .27479 .15237 .26616 Mtetra
.638 .725 .911 r
.15237 .26616 .16075 .27479 .17248 .27107 .16413 .26238 Mtetra
.634 .724 .912 r
.16413 .26238 .17248 .27107 .18426 .26743 .17595 .25869 Mtetra
.631 .722 .913 r
.17595 .25869 .18426 .26743 .1961 .26388 .18781 .25508 Mtetra
.626 .72 .914 r
.18781 .25508 .1961 .26388 .20798 .26044 .19972 .25157 Mtetra
.622 .718 .915 r
.19972 .25157 .20798 .26044 .21991 .25709 .21168 .24816 Mtetra
.617 .715 .916 r
.21168 .24816 .21991 .25709 .2319 .25386 .2237 .24487 Mtetra
.612 .713 .917 r
.2237 .24487 .2319 .25386 .24394 .25075 .23577 .24169 Mtetra
.607 .71 .918 r
.23577 .24169 .24394 .25075 .25604 .24776 .2479 .23863 Mtetra
.602 .708 .919 r
.2479 .23863 .25604 .24776 .26819 .24488 .26008 .23569 Mtetra
.597 .705 .92 r
.26008 .23569 .26819 .24488 .28041 .24211 .27233 .23287 Mtetra
.592 .703 .92 r
.27233 .23287 .28041 .24211 .29269 .23946 .28464 .23015 Mtetra
.587 .701 .921 r
.28464 .23015 .29269 .23946 .30504 .23689 .29701 .22752 Mtetra
.584 .699 .921 r
.29701 .22752 .30504 .23689 .31746 .2344 .30946 .22498 Mtetra
.581 .697 .922 r
.30946 .22498 .31746 .2344 .32995 .23198 .32198 .22249 Mtetra
.578 .696 .922 r
.32198 .22249 .32995 .23198 .34251 .22959 .33457 .22005 Mtetra
.577 .695 .922 r
.33457 .22005 .34251 .22959 .35515 .22721 .34724 .21762 Mtetra
.577 .694 .922 r
.34724 .21762 .35515 .22721 .36788 .22482 .36 .21518 Mtetra
.578 .695 .921 r
.36 .21518 .36788 .22482 .38069 .22237 .37283 .21269 Mtetra
.581 .696 .921 r
.37283 .21269 .38069 .22237 .39358 .21985 .38576 .21012 Mtetra
.585 .697 .92 r
.38576 .21012 .39358 .21985 .40656 .2172 .39877 .20744 Mtetra
.59 .7 .919 r
.39877 .20744 .40656 .2172 .41963 .2144 .41187 .20461 Mtetra
.596 .702 .918 r
.41187 .20461 .41963 .2144 .43278 .21141 .42505 .2016 Mtetra
.603 .706 .916 r
.42505 .2016 .43278 .21141 .44602 .2082 .43833 .19836 Mtetra
.611 .71 .915 r
.43833 .19836 .44602 .2082 .45935 .20474 .45169 .19488 Mtetra
.62 .714 .913 r
.45169 .19488 .45935 .20474 .47276 .201 .46513 .19112 Mtetra
.629 .718 .911 r
.46513 .19112 .47276 .201 .48625 .19694 .47866 .18705 Mtetra
.639 .723 .909 r
.47866 .18705 .48625 .19694 .49982 .19257 .49227 .18266 Mtetra
.648 .727 .907 r
.49227 .18266 .49982 .19257 .51346 .18785 .50595 .17794 Mtetra
.658 .732 .904 r
.50595 .17794 .51346 .18785 .52718 .18279 .51971 .17286 Mtetra
.668 .736 .902 r
.51971 .17286 .52718 .18279 .54096 .17737 .53354 .16743 Mtetra
.677 .741 .899 r
.53354 .16743 .54096 .17737 .5548 .1716 .54743 .16165 Mtetra
.685 .745 .896 r
.54743 .16165 .5548 .1716 .56871 .16548 .56138 .15552 Mtetra
.693 .748 .894 r
.56138 .15552 .56871 .16548 .58267 .15904 .57538 .14906 Mtetra
.701 .752 .891 r
.57538 .14906 .58267 .15904 .59668 .15229 .58945 .14229 Mtetra
.707 .755 .889 r
.58945 .14229 .59668 .15229 .61074 .14526 .60356 .13523 Mtetra
.713 .758 .887 r
.60356 .13523 .61074 .14526 .62484 .13796 .61772 .12791 Mtetra
.718 .76 .886 r
.61772 .12791 .62484 .13796 .63899 .13044 .63192 .12036 Mtetra
.722 .762 .884 r
.63192 .12036 .63899 .13044 .65319 .12273 .64617 .11261 Mtetra
.725 .763 .883 r
.64617 .11261 .65319 .12273 .66743 .11485 .66046 .1047 Mtetra
.728 .765 .882 r
.66046 .1047 .66743 .11485 .68171 .10686 .6748 .09666 Mtetra
.729 .765 .882 r
.6748 .09666 .68171 .10686 .69603 .09877 .68918 .08853 Mtetra
.73 .766 .882 r
.68918 .08853 .69603 .09877 .7104 .09063 .7036 .08034 Mtetra
.7036 .08034 .7104 .09063 .72482 .08247 .71807 .07213 Mtetra
.654 .733 .907 r
.06273 .28572 .07138 .29404 .0828 .28997 .07418 .28159 Mtetra
.652 .732 .908 r
.07418 .28159 .0828 .28997 .09428 .28591 .08568 .27748 Mtetra
.651 .731 .908 r
.08568 .27748 .09428 .28591 .1058 .28187 .09723 .27339 Mtetra
.649 .73 .908 r
.09723 .27339 .1058 .28187 .11737 .27787 .10883 .26934 Mtetra
.647 .729 .909 r
.10883 .26934 .11737 .27787 .12899 .27392 .12048 .26532 Mtetra
.645 .728 .909 r
.12048 .26532 .12899 .27392 .14065 .27001 .13218 .26136 Mtetra
.642 .727 .91 r
.13218 .26136 .14065 .27001 .15237 .26616 .14392 .25745 Mtetra
.639 .725 .911 r
.14392 .25745 .15237 .26616 .16413 .26238 .15572 .25361 Mtetra
.635 .723 .911 r
.15572 .25361 .16413 .26238 .17595 .25869 .16756 .24985 Mtetra
.632 .722 .912 r
.16756 .24985 .17595 .25869 .18781 .25508 .17945 .24617 Mtetra
.627 .719 .913 r
.17945 .24617 .18781 .25508 .19972 .25157 .1914 .24259 Mtetra
.623 .717 .914 r
.1914 .24259 .19972 .25157 .21168 .24816 .20339 .23912 Mtetra
.618 .715 .915 r
.20339 .23912 .21168 .24816 .2237 .24487 .21544 .23575 Mtetra
.613 .712 .916 r
.21544 .23575 .2237 .24487 .23577 .24169 .22754 .2325 Mtetra
.608 .71 .916 r
.22754 .2325 .23577 .24169 .2479 .23863 .2397 .22937 Mtetra
.603 .707 .917 r
.2397 .22937 .2479 .23863 .26008 .23569 .25191 .22635 Mtetra
.598 .704 .918 r
.25191 .22635 .26008 .23569 .27233 .23287 .26419 .22345 Mtetra
.594 .701 .918 r
.26419 .22345 .27233 .23287 .28464 .23015 .27653 .22065 Mtetra
.589 .699 .918 r
.27653 .22065 .28464 .23015 .29701 .22752 .28893 .21795 Mtetra
.585 .696 .919 r
.28893 .21795 .29701 .22752 .30946 .22498 .3014 .21533 Mtetra
.582 .694 .919 r
.3014 .21533 .30946 .22498 .32198 .22249 .31395 .21278 Mtetra
.58 .692 .918 r
.31395 .21278 .32198 .22249 .33457 .22005 .32657 .21026 Mtetra
.579 .691 .918 r
.32657 .21026 .33457 .22005 .34724 .21762 .33928 .20776 Mtetra
.579 .69 .918 r
.33928 .20776 .34724 .21762 .36 .21518 .35206 .20526 Mtetra
.58 .69 .917 r
.35206 .20526 .36 .21518 .37283 .21269 .36493 .20271 Mtetra
.582 .691 .916 r
.36493 .20271 .37283 .21269 .38576 .21012 .37788 .20008 Mtetra
.586 .692 .915 r
.37788 .20008 .38576 .21012 .39877 .20744 .39092 .19734 Mtetra
.591 .694 .914 r
.39092 .19734 .39877 .20744 .41187 .20461 .40405 .19446 Mtetra
.596 .696 .912 r
.40405 .19446 .41187 .20461 .42505 .2016 .41727 .19141 Mtetra
.603 .699 .911 r
.41727 .19141 .42505 .2016 .43833 .19836 .43057 .18813 Mtetra
.611 .702 .909 r
.43057 .18813 .43833 .19836 .45169 .19488 .44397 .18462 Mtetra
.619 .706 .907 r
.44397 .18462 .45169 .19488 .46513 .19112 .45745 .18083 Mtetra
.628 .71 .905 r
.45745 .18083 .46513 .19112 .47866 .18705 .47101 .17674 Mtetra
.637 .714 .903 r
.47101 .17674 .47866 .18705 .49227 .18266 .48466 .17233 Mtetra
.647 .719 .9 r
.48466 .17233 .49227 .18266 .50595 .17794 .49838 .16759 Mtetra
.656 .723 .898 r
.49838 .16759 .50595 .17794 .51971 .17286 .51218 .1625 Mtetra
.666 .727 .896 r
.51218 .1625 .51971 .17286 .53354 .16743 .52605 .15705 Mtetra
.674 .732 .893 r
.52605 .15705 .53354 .16743 .54743 .16165 .53998 .15126 Mtetra
.683 .736 .891 r
.53998 .15126 .54743 .16165 .56138 .15552 .55398 .14513 Mtetra
.691 .74 .888 r
.55398 .14513 .56138 .15552 .57538 .14906 .56803 .13866 Mtetra
.698 .743 .886 r
.56803 .13866 .57538 .14906 .58945 .14229 .58214 .13188 Mtetra
.705 .747 .884 r
.58214 .13188 .58945 .14229 .60356 .13523 .5963 .12481 Mtetra
.711 .75 .883 r
.5963 .12481 .60356 .13523 .61772 .12791 .61051 .11747 Mtetra
.716 .752 .881 r
.61051 .11747 .61772 .12791 .63192 .12036 .62477 .1099 Mtetra
.72 .755 .88 r
.62477 .1099 .63192 .12036 .64617 .11261 .63907 .10213 Mtetra
.723 .757 .879 r
.63907 .10213 .64617 .11261 .66046 .1047 .65342 .0942 Mtetra
.726 .758 .879 r
.65342 .0942 .66046 .1047 .6748 .09666 .66781 .08614 Mtetra
.727 .76 .878 r
.66781 .08614 .6748 .09666 .68918 .08853 .68225 .07798 Mtetra
.728 .76 .878 r
.68225 .07798 .68918 .08853 .7036 .08034 .69673 .06976 Mtetra
.728 .761 .879 r
.69673 .06976 .7036 .08034 .71807 .07213 .71126 .06151 Mtetra
.654 .733 .907 r
.054 .27733 .06273 .28572 .07418 .28159 .06548 .27315 Mtetra
.653 .732 .907 r
.06548 .27315 .07418 .28159 .08568 .27748 .07702 .26898 Mtetra
.652 .731 .908 r
.07702 .26898 .08568 .27748 .09723 .27339 .0886 .26484 Mtetra
.65 .73 .908 r
.0886 .26484 .09723 .27339 .10883 .26934 .10023 .26073 Mtetra
.648 .729 .908 r
.10023 .26073 .10883 .26934 .12048 .26532 .1119 .25665 Mtetra
.645 .728 .909 r
.1119 .25665 .12048 .26532 .13218 .26136 .12363 .25262 Mtetra
.643 .727 .909 r
.12363 .25262 .13218 .26136 .14392 .25745 .13541 .24865 Mtetra
.64 .725 .91 r
.13541 .24865 .14392 .25745 .15572 .25361 .14723 .24475 Mtetra
.636 .723 .911 r
.14723 .24475 .15572 .25361 .16756 .24985 .15911 .24091 Mtetra
.633 .721 .911 r
.15911 .24091 .16756 .24985 .17945 .24617 .17103 .23717 Mtetra
.629 .719 .912 r
.17103 .23717 .17945 .24617 .1914 .24259 .18301 .23351 Mtetra
.624 .717 .913 r
.18301 .23351 .1914 .24259 .20339 .23912 .19503 .22996 Mtetra
.62 .714 .913 r
.19503 .22996 .20339 .23912 .21544 .23575 .20711 .22652 Mtetra
.615 .712 .914 r
.20711 .22652 .21544 .23575 .22754 .2325 .21924 .22318 Mtetra
.61 .709 .915 r
.21924 .22318 .22754 .2325 .2397 .22937 .23143 .21997 Mtetra
.605 .706 .915 r
.23143 .21997 .2397 .22937 .25191 .22635 .24368 .21686 Mtetra
.6 .703 .916 r
.24368 .21686 .25191 .22635 .26419 .22345 .25598 .21387 Mtetra
.596 .7 .916 r
.25598 .21387 .26419 .22345 .27653 .22065 .26835 .21098 Mtetra
.591 .697 .916 r
.26835 .21098 .27653 .22065 .28893 .21795 .28079 .20819 Mtetra
.588 .694 .916 r
.28079 .20819 .28893 .21795 .3014 .21533 .29329 .20548 Mtetra
.585 .692 .916 r
.29329 .20548 .3014 .21533 .31395 .21278 .30587 .20283 Mtetra
.583 .69 .915 r
.30587 .20283 .31395 .21278 .32657 .21026 .31852 .20023 Mtetra
.581 .688 .914 r
.31852 .20023 .32657 .21026 .33928 .20776 .33125 .19764 Mtetra
.581 .687 .914 r
.33125 .19764 .33928 .20776 .35206 .20526 .34407 .19505 Mtetra
.582 .686 .913 r
.34407 .19505 .35206 .20526 .36493 .20271 .35696 .19242 Mtetra
.584 .686 .911 r
.35696 .19242 .36493 .20271 .37788 .20008 .36995 .18972 Mtetra
.587 .687 .91 r
.36995 .18972 .37788 .20008 .39092 .19734 .38302 .18691 Mtetra
.592 .688 .909 r
.38302 .18691 .39092 .19734 .40405 .19446 .39617 .18397 Mtetra
.597 .69 .907 r
.39617 .18397 .40405 .19446 .41727 .19141 .40942 .18085 Mtetra
.604 .692 .905 r
.40942 .18085 .41727 .19141 .43057 .18813 .42276 .17752 Mtetra
.611 .695 .903 r
.42276 .17752 .43057 .18813 .44397 .18462 .43619 .17396 Mtetra
.619 .698 .901 r
.43619 .17396 .44397 .18462 .45745 .18083 .4497 .17013 Mtetra
.628 .702 .899 r
.4497 .17013 .45745 .18083 .47101 .17674 .4633 .16601 Mtetra
.636 .706 .897 r
.4633 .16601 .47101 .17674 .48466 .17233 .47698 .16157 Mtetra
.645 .71 .894 r
.47698 .16157 .48466 .17233 .49838 .16759 .49074 .15681 Mtetra
.655 .714 .892 r
.49074 .15681 .49838 .16759 .51218 .1625 .50458 .1517 Mtetra
.663 .719 .89 r
.50458 .1517 .51218 .1625 .52605 .15705 .51849 .14625 Mtetra
.672 .723 .887 r
.51849 .14625 .52605 .15705 .53998 .15126 .53247 .14045 Mtetra
.68 .727 .885 r
.53247 .14045 .53998 .15126 .55398 .14513 .54651 .1343 Mtetra
.688 .731 .883 r
.54651 .1343 .55398 .14513 .56803 .13866 .56061 .12783 Mtetra
.695 .735 .881 r
.56061 .12783 .56803 .13866 .58214 .13188 .57476 .12105 Mtetra
.702 .738 .88 r
.57476 .12105 .58214 .13188 .5963 .12481 .58897 .11398 Mtetra
.708 .742 .878 r
.58897 .11398 .5963 .12481 .61051 .11747 .60324 .10664 Mtetra
.713 .745 .877 r
.60324 .10664 .61051 .11747 .62477 .1099 .61754 .09907 Mtetra
.717 .747 .876 r
.61754 .09907 .62477 .1099 .63907 .10213 .6319 .0913 Mtetra
.72 .75 .875 r
.6319 .0913 .63907 .10213 .65342 .0942 .6463 .08336 Mtetra
.723 .752 .875 r
.6463 .08336 .65342 .0942 .66781 .08614 .66075 .07529 Mtetra
.725 .753 .875 r
.66075 .07529 .66781 .08614 .68225 .07798 .67524 .06712 Mtetra
.726 .755 .875 r
.67524 .06712 .68225 .07798 .69673 .06976 .68978 .05888 Mtetra
.726 .756 .876 r
.68978 .05888 .69673 .06976 .71126 .06151 .70437 .05062 Mtetra
.655 .733 .907 r
.04521 .26886 .054 .27733 .06548 .27315 .05672 .26463 Mtetra
.654 .732 .907 r
.05672 .26463 .06548 .27315 .07702 .26898 .06828 .26041 Mtetra
.652 .731 .907 r
.06828 .26041 .07702 .26898 .0886 .26484 .07989 .25621 Mtetra
.651 .731 .908 r
.07989 .25621 .0886 .26484 .10023 .26073 .09155 .25204 Mtetra
.649 .729 .908 r
.09155 .25204 .10023 .26073 .1119 .25665 .10326 .24791 Mtetra
.646 .728 .908 r
.10326 .24791 .1119 .25665 .12363 .25262 .11502 .24381 Mtetra
.644 .727 .909 r
.11502 .24381 .12363 .25262 .13541 .24865 .12682 .23977 Mtetra
.641 .725 .909 r
.12682 .23977 .13541 .24865 .14723 .24475 .13868 .2358 Mtetra
.638 .723 .91 r
.13868 .2358 .14723 .24475 .15911 .24091 .15059 .23189 Mtetra
.634 .721 .911 r
.15059 .23189 .15911 .24091 .17103 .23717 .16254 .22807 Mtetra
.63 .719 .911 r
.16254 .22807 .17103 .23717 .18301 .23351 .17455 .22433 Mtetra
.626 .717 .912 r
.17455 .22433 .18301 .23351 .19503 .22996 .18661 .2207 Mtetra
.622 .714 .912 r
.18661 .2207 .19503 .22996 .20711 .22652 .19872 .21716 Mtetra
.617 .711 .913 r
.19872 .21716 .20711 .22652 .21924 .22318 .21088 .21374 Mtetra
.612 .708 .913 r
.21088 .21374 .21924 .22318 .23143 .21997 .2231 .21043 Mtetra
.607 .705 .913 r
.2231 .21043 .23143 .21997 .24368 .21686 .23538 .20722 Mtetra
.603 .702 .914 r
.23538 .20722 .24368 .21686 .25598 .21387 .24772 .20413 Mtetra
.598 .699 .914 r
.24772 .20413 .25598 .21387 .26835 .21098 .26012 .20114 Mtetra
.594 .696 .913 r
.26012 .20114 .26835 .21098 .28079 .20819 .27259 .19824 Mtetra
.591 .693 .913 r
.27259 .19824 .28079 .20819 .29329 .20548 .28512 .19542 Mtetra
.588 .69 .913 r
.28512 .19542 .29329 .20548 .30587 .20283 .29773 .19267 Mtetra
.585 .687 .912 r
.29773 .19267 .30587 .20283 .31852 .20023 .31041 .18996 Mtetra
.584 .685 .911 r
.31041 .18996 .31852 .20023 .33125 .19764 .32318 .18727 Mtetra
.584 .684 .91 r
.32318 .18727 .33125 .19764 .34407 .19505 .33602 .18458 Mtetra
.585 .683 .908 r
.33602 .18458 .34407 .19505 .35696 .19242 .34895 .18185 Mtetra
.586 .682 .907 r
.34895 .18185 .35696 .19242 .36995 .18972 .36196 .17905 Mtetra
.589 .682 .905 r
.36196 .17905 .36995 .18972 .38302 .18691 .37506 .17616 Mtetra
.594 .683 .904 r
.37506 .17616 .38302 .18691 .39617 .18397 .38825 .17313 Mtetra
.599 .684 .902 r
.38825 .17313 .39617 .18397 .40942 .18085 .40153 .16993 Mtetra
.605 .686 .9 r
.40153 .16993 .40942 .18085 .42276 .17752 .4149 .16654 Mtetra
.612 .689 .898 r
.4149 .16654 .42276 .17752 .43619 .17396 .42835 .16292 Mtetra
.619 .692 .896 r
.42835 .16292 .43619 .17396 .4497 .17013 .4419 .15904 Mtetra
.627 .695 .893 r
.4419 .15904 .4497 .17013 .4633 .16601 .45553 .15487 Mtetra
.636 .699 .891 r
.45553 .15487 .4633 .16601 .47698 .16157 .46925 .1504 Mtetra
.644 .702 .889 r
.46925 .1504 .47698 .16157 .49074 .15681 .48305 .14561 Mtetra
.653 .706 .887 r
.48305 .14561 .49074 .15681 .50458 .1517 .49692 .14048 Mtetra
.661 .711 .884 r
.49692 .14048 .50458 .1517 .51849 .14625 .51087 .13501 Mtetra
.67 .715 .882 r
.51087 .13501 .51849 .14625 .53247 .14045 .52489 .12921 Mtetra
.678 .719 .88 r
.52489 .12921 .53247 .14045 .54651 .1343 .53897 .12306 Mtetra
.685 .723 .878 r
.53897 .12306 .54651 .1343 .56061 .12783 .55311 .11659 Mtetra
.692 .727 .876 r
.55311 .11659 .56061 .12783 .57476 .12105 .56732 .10982 Mtetra
.699 .73 .875 r
.56732 .10982 .57476 .12105 .58897 .11398 .58158 .10275 Mtetra
.705 .734 .874 r
.58158 .10275 .58897 .11398 .60324 .10664 .59589 .09543 Mtetra
.71 .737 .873 r
.59589 .09543 .60324 .10664 .61754 .09907 .61025 .08786 Mtetra
.714 .74 .872 r
.61025 .08786 .61754 .09907 .6319 .0913 .62465 .0801 Mtetra
.717 .743 .872 r
.62465 .0801 .6319 .0913 .6463 .08336 .63911 .07217 Mtetra
.72 .745 .872 r
.63911 .07217 .6463 .08336 .66075 .07529 .65361 .06411 Mtetra
.722 .747 .872 r
.65361 .06411 .66075 .07529 .67524 .06712 .66816 .05594 Mtetra
.723 .749 .873 r
.66816 .05594 .67524 .06712 .68978 .05888 .68276 .04771 Mtetra
.724 .751 .874 r
.68276 .04771 .68978 .05888 .70437 .05062 .6974 .03945 Mtetra
.655 .733 .907 r
.03634 .26033 .04521 .26886 .05672 .26463 .04788 .25605 Mtetra
.654 .732 .907 r
.04788 .25605 .05672 .26463 .06828 .26041 .05947 .25177 Mtetra
.653 .732 .907 r
.05947 .25177 .06828 .26041 .07989 .25621 .07111 .24752 Mtetra
.651 .731 .907 r
.07111 .24752 .07989 .25621 .09155 .25204 .0828 .24328 Mtetra
.649 .73 .908 r
.0828 .24328 .09155 .25204 .10326 .24791 .09454 .23908 Mtetra
.647 .728 .908 r
.09454 .23908 .10326 .24791 .11502 .24381 .10633 .23493 Mtetra
.645 .727 .908 r
.10633 .23493 .11502 .24381 .12682 .23977 .11817 .23082 Mtetra
.642 .725 .909 r
.11817 .23082 .12682 .23977 .13868 .2358 .13006 .22677 Mtetra
.639 .724 .909 r
.13006 .22677 .13868 .2358 .15059 .23189 .142 .22278 Mtetra
.636 .722 .91 r
.142 .22278 .15059 .23189 .16254 .22807 .15398 .21888 Mtetra
.632 .719 .91 r
.15398 .21888 .16254 .22807 .17455 .22433 .16602 .21506 Mtetra
.628 .717 .911 r
.16602 .21506 .17455 .22433 .18661 .2207 .17812 .21133 Mtetra
.624 .714 .911 r
.17812 .21133 .18661 .2207 .19872 .21716 .19026 .2077 Mtetra
.619 .711 .911 r
.19026 .2077 .19872 .21716 .21088 .21374 .20246 .20417 Mtetra
.615 .708 .912 r
.20246 .20417 .21088 .21374 .2231 .21043 .21471 .20076 Mtetra
.61 .705 .912 r
.21471 .20076 .2231 .21043 .23538 .20722 .22702 .19744 Mtetra
.605 .702 .912 r
.22702 .19744 .23538 .20722 .24772 .20413 .23939 .19424 Mtetra
.601 .698 .912 r
.23939 .19424 .24772 .20413 .26012 .20114 .25183 .19113 Mtetra
.597 .695 .911 r
.25183 .19113 .26012 .20114 .27259 .19824 .26433 .18811 Mtetra
.594 .692 .911 r
.26433 .18811 .27259 .19824 .28512 .19542 .2769 .18518 Mtetra
.591 .689 .91 r
.2769 .18518 .28512 .19542 .29773 .19267 .28954 .1823 Mtetra
.589 .686 .909 r
.28954 .1823 .29773 .19267 .31041 .18996 .30225 .17947 Mtetra
.587 .683 .908 r
.30225 .17947 .31041 .18996 .32318 .18727 .31504 .17666 Mtetra
.587 .681 .906 r
.31504 .17666 .32318 .18727 .33602 .18458 .32792 .17385 Mtetra
.587 .68 .905 r
.32792 .17385 .33602 .18458 .34895 .18185 .34087 .171 Mtetra
.589 .679 .903 r
.34087 .171 .34895 .18185 .36196 .17905 .35392 .16809 Mtetra
.592 .679 .901 r
.35392 .16809 .36196 .17905 .37506 .17616 .36705 .16509 Mtetra
.596 .679 .899 r
.36705 .16509 .37506 .17616 .38825 .17313 .38027 .16197 Mtetra
.6 .68 .897 r
.38027 .16197 .38825 .17313 .40153 .16993 .39358 .15868 Mtetra
.606 .681 .895 r
.39358 .15868 .40153 .16993 .4149 .16654 .40698 .15521 Mtetra
.612 .683 .893 r
.40698 .15521 .4149 .16654 .42835 .16292 .42047 .15151 Mtetra
.619 .686 .89 r
.42047 .15151 .42835 .16292 .4419 .15904 .43404 .14757 Mtetra
.627 .689 .888 r
.43404 .14757 .4419 .15904 .45553 .15487 .44771 .14335 Mtetra
.635 .692 .886 r
.44771 .14335 .45553 .15487 .46925 .1504 .46146 .13884 Mtetra
.643 .695 .884 r
.46146 .13884 .46925 .1504 .48305 .14561 .47529 .13401 Mtetra
.651 .699 .881 r
.47529 .13401 .48305 .14561 .49692 .14048 .4892 .12886 Mtetra
.659 .703 .879 r
.4892 .12886 .49692 .14048 .51087 .13501 .50319 .12337 Mtetra
.667 .707 .877 r
.50319 .12337 .51087 .13501 .52489 .12921 .51724 .11756 Mtetra
.675 .711 .875 r
.51724 .11756 .52489 .12921 .53897 .12306 .53137 .11141 Mtetra
.682 .715 .874 r
.53137 .11141 .53897 .12306 .55311 .11659 .54556 .10495 Mtetra
.689 .719 .872 r
.54556 .10495 .55311 .11659 .56732 .10982 .5598 .09819 Mtetra
.696 .723 .871 r
.5598 .09819 .56732 .10982 .58158 .10275 .57411 .09114 Mtetra
.701 .727 .87 r
.57411 .09114 .58158 .10275 .59589 .09543 .58847 .08383 Mtetra
.706 .73 .869 r
.58847 .08383 .59589 .09543 .61025 .08786 .60288 .07629 Mtetra
.711 .733 .869 r
.60288 .07629 .61025 .08786 .62465 .0801 .61734 .06856 Mtetra
.714 .736 .869 r
.61734 .06856 .62465 .0801 .63911 .07217 .63184 .06065 Mtetra
.717 .739 .869 r
.63184 .06065 .63911 .07217 .65361 .06411 .6464 .05261 Mtetra
.719 .741 .869 r
.6464 .05261 .65361 .06411 .66816 .05594 .661 .04446 Mtetra
.72 .744 .87 r
.661 .04446 .66816 .05594 .68276 .04771 .67566 .03625 Mtetra
.721 .745 .871 r
.67566 .03625 .68276 .04771 .6974 .03945 .69036 .02801 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.9902 .74716 m
.97588 .7322 L
.9644 .72162 L
.94482 .7064 L
.9386 .70218 L
.9128 .68726 L
.89859 .6806 L
.887 .67603 L
.8612 .66797 L
.8354 .66279 L
.8096 .66032 L
.7838 .66046 L
.758 .66324 L
.7322 .66872 L
.7064 .67712 L
.69773 .6806 L
.6806 .68874 L
.6548 .70412 L
.65149 .7064 L
.629 .72415 L
.62031 .7322 L
.6032 .75054 L
.59714 .758 L
.5794 .7838 L
.5774 .78714 L
.56582 .8096 L
.55574 .8354 L
.5516 .84869 L
.54871 .8612 L
.54448 .887 L
.54292 .9128 L
.54398 .9386 L
.54768 .9644 L
.5516 .9813 L
.55415 .9902 L
s
.4742 .77876 m
.5 .77124 L
.5258 .77024 L
.5516 .77553 L
.57192 .7838 L
.5774 .78809 L
.60115 .8096 L
.6032 .81189 L
.617 .8354 L
.62453 .8612 L
.62563 .887 L
.62056 .9128 L
.60803 .9386 L
.6032 .94557 L
.58451 .9644 L
.5774 .96891 L
.5516 .98089 L
.5258 .98659 L
.5 .98545 L
.4742 .97772 L
.44972 .9644 L
.4484 .96321 L
.42609 .9386 L
.4226 .93435 L
.41366 .9128 L
.4085 .887 L
.40962 .8612 L
.41728 .8354 L
.4226 .82386 L
.43286 .8096 L
.4484 .79415 L
.46304 .7838 L
.4742 .77876 L
s
.0098 .24767 m
.0356 .24347 L
.04568 .242 L
.0614 .24075 L
.0872 .2395 L
.113 .23971 L
.1388 .24137 L
.14591 .242 L
.1646 .24451 L
.1904 .24915 L
.2162 .25534 L
.242 .26315 L
.25524 .2678 L
.2678 .27267 L
.2936 .28401 L
.31257 .2936 L
.3194 .29734 L
.3452 .31284 L
.35506 .3194 L
.371 .33082 L
.38923 .3452 L
.3968 .35163 L
.41775 .371 L
.4226 .37585 L
.44201 .3968 L
.4484 .40431 L
.46286 .4226 L
.4742 .4384 L
.48087 .4484 L
.4964 .4742 L
.5 .48076 L
.50975 .5 L
.52111 .5258 L
.5258 .53784 L
.53065 .5516 L
.53848 .5774 L
.5447 .6032 L
.54935 .629 L
.5516 .64499 L
.55251 .6548 L
.55419 .6806 L
.55442 .7064 L
.55318 .7322 L
.5516 .75097 L
.55049 .758 L
.5463 .7838 L
.54057 .8096 L
.53325 .8354 L
.5258 .8571 L
.52425 .8612 L
Mistroke
.51346 .887 L
.50074 .9128 L
.5 .91419 L
.48591 .9386 L
.4742 .95656 L
.4687 .9644 L
.44877 .9902 L
Mfstroke
.5258 .26772 m
.5516 .26758 L
.55665 .2678 L
.5774 .26961 L
.6032 .27387 L
.629 .28046 L
.6548 .28954 L
.66448 .2936 L
.6806 .30134 L
.7064 .31626 L
.71118 .3194 L
.7322 .33487 L
.7444 .3452 L
.758 .35812 L
.77003 .371 L
.7838 .38777 L
.79043 .3968 L
.80679 .4226 L
.8096 .42763 L
.81985 .4484 L
.83002 .4742 L
.8354 .49132 L
.83762 .5 L
.84284 .5258 L
.8458 .5516 L
.84656 .5774 L
.84514 .6032 L
.84151 .629 L
.83559 .6548 L
.8354 .65552 L
.82725 .6806 L
.81625 .7064 L
.8096 .71944 L
.80226 .7322 L
.78476 .758 L
.7838 .75927 L
.76295 .7838 L
.758 .78892 L
.73537 .8096 L
.7322 .81218 L
.7064 .83079 L
.69906 .8354 L
.6806 .84571 L
.6548 .85752 L
.64534 .8612 L
.629 .86659 L
.6032 .87318 L
.5774 .87744 L
.5516 .87948 L
.5258 .87934 L
Mistroke
.5 .87701 L
.4742 .87244 L
.4484 .86553 L
.43551 .8612 L
.4226 .8561 L
.3968 .84391 L
.38178 .8354 L
.371 .82854 L
.34548 .8096 L
.3452 .80936 L
.3194 .78538 L
.3179 .7838 L
.29608 .758 L
.2936 .75467 L
.27859 .7322 L
.2678 .71288 L
.2646 .7064 L
.2536 .6806 L
.24525 .6548 L
.242 .64248 L
.23933 .629 L
.23571 .6032 L
.23429 .5774 L
.23505 .5516 L
.23801 .5258 L
.242 .50457 L
.24323 .5 L
.25082 .4742 L
.261 .4484 L
.2678 .43415 L
.27405 .4226 L
.29042 .3968 L
.2936 .39238 L
.31082 .371 L
.3194 .36166 L
.33645 .3452 L
.3452 .33768 L
.36968 .3194 L
.371 .31852 L
.3968 .30314 L
.41639 .2936 L
.4226 .29095 L
.4484 .28152 L
.4742 .27461 L
.5 .27005 L
.5242 .2678 L
.5258 .26772 L
Mfstroke
.66027 .9902 m
.65916 .9644 L
.6548 .94707 L
.65164 .9386 L
.63593 .9128 L
.629 .90506 L
.60507 .887 L
.6032 .88604 L
.5774 .87606 L
.5516 .87298 L
.5258 .87613 L
.5 .88621 L
.49847 .887 L
.4742 .90539 L
.46759 .9128 L
.45187 .9386 L
.4484 .94801 L
.44436 .9644 L
.44325 .9902 L
s
.9902 .18709 m
.98732 .1904 L
.9644 .21363 L
.96139 .2162 L
.9386 .23287 L
.92292 .242 L
.9128 .24692 L
.887 .25688 L
.8612 .26328 L
.8354 .26645 L
.8096 .26654 L
.7838 .26355 L
.758 .25734 L
.7322 .24761 L
.72056 .242 L
.7064 .23382 L
.68212 .2162 L
.6806 .21491 L
.65609 .1904 L
.6548 .18889 L
.63717 .1646 L
.629 .15048 L
.62337 .1388 L
.61363 .113 L
.60742 .0872 L
.60442 .0614 L
.60451 .0356 L
.60767 .0098 L
s
.80302 .0098 m
.8096 .02245 L
.81637 .0356 L
.82573 .0614 L
.8316 .0872 L
.83427 .113 L
.83388 .1388 L
.83039 .1646 L
.82366 .1904 L
.81332 .2162 L
.8096 .22373 L
.79881 .242 L
.7838 .26223 L
.77896 .2678 L
.758 .28825 L
.75149 .2936 L
.7322 .30715 L
.70978 .3194 L
.7064 .32094 L
.6806 .33069 L
.6548 .3369 L
.629 .33989 L
.6032 .33981 L
.5774 .33664 L
.5516 .33024 L
.5258 .32028 L
.52388 .3194 L
.5 .30625 L
.48213 .2936 L
.4742 .28702 L
.45467 .2678 L
.4484 .26051 L
.43482 .242 L
.4226 .22091 L
.42032 .2162 L
.40998 .1904 L
.40324 .1646 L
.39975 .1388 L
.39935 .113 L
.40203 .0872 L
.4079 .0614 L
.41726 .0356 L
.4226 .0251 L
.43061 .0098 L
s
.9902 .92824 m
.9644 .93373 L
.9386 .93695 L
.9128 .93797 L
.887 .93681 L
.8612 .93344 L
.8354 .92778 L
.8096 .91971 L
.79211 .9128 L
.7838 .90901 L
.758 .89536 L
.74464 .887 L
.7322 .87827 L
.71109 .8612 L
.7064 .85695 L
.68524 .8354 L
.6806 .83005 L
.66469 .8096 L
.6548 .79483 L
.64821 .7838 L
.63507 .758 L
.629 .74366 L
.62482 .7322 L
.61715 .7064 L
.61188 .6806 L
.60888 .6548 L
.60807 .629 L
.60945 .6032 L
.61303 .5774 L
.61892 .5516 L
.62724 .5258 L
.629 .52113 L
.6382 .5 L
.65217 .4742 L
.6548 .46991 L
.66962 .4484 L
.6806 .43467 L
.6914 .4226 L
.7064 .40777 L
.71895 .3968 L
.7322 .38646 L
.75527 .371 L
.758 .36937 L
.7838 .35571 L
.80909 .3452 L
.8096 .34502 L
.8354 .33694 L
.8612 .33129 L
.887 .32792 L
.9128 .32675 L
Mistroke
.9386 .32777 L
.9644 .33099 L
.9902 .33649 L
Mfstroke
.0098 .65705 m
.0356 .65875 L
.0614 .65926 L
.0872 .65857 L
.113 .65668 L
.1304 .6548 L
.1388 .65358 L
.1646 .64925 L
.1904 .64366 L
.2162 .63677 L
.24064 .629 L
.242 .62853 L
.2678 .61887 L
.2936 .60771 L
.30313 .6032 L
.3194 .59496 L
.3452 .58048 L
.35031 .5774 L
.371 .56411 L
.38882 .5516 L
.3968 .54565 L
.42145 .5258 L
.4226 .52481 L
.4484 .50124 L
.44967 .5 L
.4742 .4744 L
.47438 .4742 L
.49618 .4484 L
.5 .44354 L
.51549 .4226 L
.5258 .40744 L
.5326 .3968 L
.54776 .371 L
.5516 .36393 L
.56114 .3452 L
.57287 .3194 L
.5774 .30843 L
.58307 .2936 L
.59183 .2678 L
.59922 .242 L
.6032 .22577 L
.60528 .2162 L
.61008 .1904 L
.61363 .1646 L
.61596 .1388 L
.6171 .113 L
.61703 .0872 L
.61578 .0614 L
.61332 .0356 L
.60964 .0098 L
Mistroke
Mfstroke
0 g
.03 w
.79815 .9153 Mdot
.51709 .87879 Mdot
.09643 .69748 Mdot
.54042 .57353 Mdot
.55176 .98188 Mdot
.82175 .04921 Mdot
.61682 .12256 Mdot
.91366 .63236 Mdot
.0594 .10144 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.51961 .87894 m
.53922 .87664 L
.55882 .88411 L
.5695 .89216 L
.57843 .90946 L
.57935 .91176 L
.58275 .93137 L
.57843 .95092 L
.57843 .95098 L
.56172 .97059 L
.55882 .9713 L
.53922 .97358 L
.52031 .97059 L
.51961 .97032 L
.50023 .95098 L
.5 .94942 L
.49351 .93137 L
.49384 .91176 L
.5 .89683 L
.5032 .89216 L
.51961 .87894 L
s
.58338 .9902 m
.59804 .97251 L
.59915 .97059 L
.60666 .95098 L
.60873 .93137 L
.60629 .91176 L
.59908 .89216 L
.59804 .89003 L
.58591 .87255 L
.57843 .86541 L
.55882 .85327 L
.558 .85294 L
.53922 .84817 L
.51961 .84925 L
.50829 .85294 L
.5 .85715 L
.48291 .87255 L
.48039 .8758 L
.47243 .89216 L
.4681 .91176 L
.46851 .93137 L
.47341 .95098 L
.48039 .96627 L
.48346 .97059 L
.5 .98683 L
.50141 .9902 L
s
.61325 .9902 m
.61765 .9829 L
.62335 .97059 L
.62858 .95098 L
.62997 .93137 L
.6279 .91176 L
.6223 .89216 L
.61765 .88124 L
.61263 .87255 L
.59804 .85383 L
.59719 .85294 L
.57843 .83798 L
.57128 .83333 L
.55882 .82881 L
.53922 .82473 L
.51961 .82535 L
.5 .831 L
.49451 .83333 L
.48039 .84298 L
.47015 .85294 L
.46078 .86614 L
.45747 .87255 L
.45045 .89216 L
.44762 .91176 L
.44834 .93137 L
.4525 .95098 L
.46046 .97059 L
.46078 .9711 L
.47313 .9902 L
s
.63697 .9902 m
.63725 .98963 L
.64475 .97059 L
.64888 .95098 L
.64994 .93137 L
.64814 .91176 L
.64345 .89216 L
.63725 .87585 L
.6356 .87255 L
.62389 .85294 L
.61765 .84489 L
.60669 .83333 L
.59804 .82605 L
.57843 .81379 L
.57833 .81373 L
.55882 .8063 L
.53922 .80289 L
.51961 .80331 L
.5 .80776 L
.48532 .81373 L
.48039 .8169 L
.46078 .83253 L
.46 .83333 L
.44517 .85294 L
.44118 .8601 L
.43603 .87255 L
.43083 .89216 L
.42885 .91176 L
.42977 .93137 L
.43353 .95098 L
.44032 .97059 L
.44118 .97227 L
.4506 .9902 L
s
.65938 .9902 m
.66579 .97059 L
.66927 .95098 L
.67016 .93137 L
.66861 .91176 L
.6646 .89216 L
.658 .87255 L
.65686 .86979 L
.64842 .85294 L
.63725 .83607 L
.63512 .83333 L
.61765 .8148 L
.61644 .81373 L
.59804 .80011 L
.58755 .79412 L
.57843 .79007 L
.55882 .78382 L
.53922 .78094 L
.51961 .78132 L
.5 .78505 L
.48039 .79253 L
.47717 .79412 L
.46078 .80465 L
.45019 .81373 L
.44118 .82348 L
.43379 .83333 L
.42287 .85294 L
.42157 .85576 L
.41579 .87255 L
.41177 .89216 L
.41039 .91176 L
.41148 .93137 L
.41499 .95098 L
.42103 .97059 L
.42157 .97185 L
.42989 .9902 L
s
.68252 .9902 m
.68807 .97059 L
.69116 .95098 L
.69202 .93137 L
.69075 .91176 L
.68735 .89216 L
.68176 .87255 L
.67647 .85883 L
.67375 .85294 L
.66291 .83333 L
.65686 .82438 L
.64853 .81373 L
.63725 .80161 L
.62907 .79412 L
.61765 .78522 L
.60035 .77451 L
.59804 .77332 L
.57843 .76502 L
.55882 .75981 L
.53922 .75746 L
.51961 .75789 L
.5 .76119 L
.48039 .76759 L
.46589 .77451 L
.46078 .7776 L
.44118 .79226 L
.43914 .79412 L
.42167 .81373 L
.42157 .81386 L
.40943 .83333 L
.40196 .84996 L
.40089 .85294 L
.39527 .87255 L
.39214 .89216 L
.39125 .91176 L
.3925 .93137 L
.39584 .95098 L
.40134 .97059 L
.40196 .97222 L
.40922 .9902 L
s
.70855 .9902 m
.71361 .97059 L
.71569 .96171 L
.71656 .95098 L
.71755 .93137 L
.7167 .91176 L
.71569 .89905 L
.71399 .89216 L
.70936 .87255 L
.70272 .85294 L
.69608 .8377 L
.69388 .83333 L
.68238 .81373 L
.67647 .80525 L
.66762 .79412 L
.65686 .78248 L
.64836 .77451 L
.63725 .76546 L
.62167 .7549 L
.61765 .75256 L
.59804 .743 L
.57843 .73625 L
.57586 .73529 L
.55882 .7321 L
.53922 .73037 L
.51961 .73102 L
.5 .73409 L
.49443 .73529 L
.48039 .73979 L
.46078 .74842 L
.44942 .7549 L
.44118 .76051 L
.42429 .77451 L
.42157 .77716 L
.40672 .79412 L
.40196 .80066 L
.39381 .81373 L
.3843 .83333 L
.38235 .83815 L
.37753 .85294 L
.37309 .87255 L
.37072 .89216 L
.37028 .91176 L
.3717 .93137 L
.37495 .95098 L
.38006 .97059 L
.38235 .97705 L
.38719 .9902 L
s
.74156 .9902 m
.74659 .97059 L
.74984 .95098 L
.75142 .93137 L
.75137 .91176 L
.74971 .89216 L
.74641 .87255 L
.74143 .85294 L
.73529 .83488 L
.73468 .83333 L
.72582 .81373 L
.71569 .79563 L
.71473 .79412 L
.70079 .77451 L
.69608 .76875 L
.68327 .7549 L
.67647 .74844 L
.66059 .73529 L
.65686 .73258 L
.63725 .72016 L
.62885 .71569 L
.61765 .71058 L
.59804 .70345 L
.57843 .69853 L
.56245 .69608 L
.55882 .69572 L
.53922 .69495 L
.52039 .69608 L
.51961 .69617 L
.5 .69947 L
.48039 .70493 L
.46078 .71271 L
.45454 .71569 L
.44118 .7232 L
.4236 .73529 L
.42157 .7369 L
.40196 .75482 L
.40189 .7549 L
.3855 .77451 L
.38235 .77893 L
.37286 .79412 L
.3631 .81373 L
.36275 .81454 L
.35579 .83333 L
.35056 .85294 L
.3472 .87255 L
.34558 .89216 L
.34562 .91176 L
.34727 .93137 L
.35052 .95098 L
Mistroke
.35537 .97059 L
.3619 .9902 L
Mfstroke
.79648 .9902 m
.80349 .97059 L
.80932 .95098 L
.81373 .93259 L
.81397 .93137 L
.8174 .91176 L
.81973 .89216 L
.82093 .87255 L
.82092 .85294 L
.81962 .83333 L
.8169 .81373 L
.81373 .79858 L
.81258 .79412 L
.8065 .77451 L
.7984 .7549 L
.79412 .74629 L
.78796 .73529 L
.77476 .71569 L
.77451 .71536 L
.75818 .69608 L
.7549 .69271 L
.73709 .67647 L
.73529 .67503 L
.71569 .66096 L
.70912 .65686 L
.69608 .64979 L
.67647 .64097 L
.66643 .63725 L
.65686 .63437 L
.63725 .62974 L
.61765 .62675 L
.59804 .62534 L
.57843 .62542 L
.55882 .6269 L
.53922 .62974 L
.51961 .63388 L
.50659 .63725 L
.5 .63942 L
.48039 .64664 L
.46078 .65531 L
.45757 .65686 L
.44118 .66598 L
.42466 .67647 L
.42157 .67867 L
.40196 .69406 L
.39962 .69608 L
.38235 .71281 L
.37966 .71569 L
.36343 .73529 L
.36275 .73621 L
Mistroke
.35016 .7549 L
.34314 .76711 L
.33933 .77451 L
.33063 .79412 L
.32376 .81373 L
.32353 .81446 L
.31866 .83333 L
.31511 .85294 L
.31303 .87255 L
.31236 .89216 L
.31306 .91176 L
.3151 .93137 L
.31848 .95098 L
.32317 .97059 L
.32353 .97183 L
.32938 .9902 L
Mfstroke
.87927 .0098 m
.89074 .02941 L
.89216 .03226 L
.89911 .04902 L
.90493 .06863 L
.90855 .08824 L
.91019 .10784 L
.91003 .12745 L
.90818 .14706 L
.90471 .16667 L
.89968 .18627 L
.89311 .20588 L
.89216 .20842 L
.88503 .22549 L
.87539 .2451 L
.87255 .25034 L
.86417 .26471 L
.85294 .2819 L
.85126 .28431 L
.83652 .30392 L
.83333 .30783 L
.81968 .32353 L
.81373 .32983 L
.8002 .34314 L
.79412 .34862 L
.7769 .36275 L
.77451 .36451 L
.7549 .37756 L
.74657 .38235 L
.73529 .38771 L
.71569 .39487 L
.69608 .39893 L
.67647 .39983 L
.65686 .3976 L
.63725 .3923 L
.61765 .38397 L
.61444 .38235 L
.59804 .37255 L
.58439 .36275 L
.57843 .35787 L
.56242 .34314 L
.55882 .33941 L
.54494 .32353 L
.53922 .31612 L
.53066 .30392 L
.51961 .28554 L
.51894 .28431 L
.5094 .26471 L
.50182 .2451 L
.5 .2396 L
Mistroke
.49603 .22549 L
.49195 .20588 L
.4895 .18627 L
.48868 .16667 L
.48948 .14706 L
.49195 .12745 L
.49615 .10784 L
.5 .09447 L
.5022 .08824 L
.51025 .06863 L
.51961 .05063 L
.52056 .04902 L
.53346 .02941 L
.53922 .02194 L
.54952 .0098 L
Mfstroke
.27436 .9902 m
.26782 .97059 L
.26471 .96001 L
.2624 .95098 L
.25803 .93137 L
.25458 .91176 L
.25205 .89216 L
.25044 .87255 L
.24973 .85294 L
.24991 .83333 L
.25095 .81373 L
.25279 .79412 L
.25538 .77451 L
.25864 .7549 L
.26247 .73529 L
.26471 .72485 L
.26674 .71569 L
.27127 .69608 L
.27579 .67647 L
.28002 .65686 L
.2837 .63725 L
.28431 .63388 L
.2866 .61765 L
.28863 .59804 L
.28983 .57843 L
.29037 .55882 L
.29046 .53922 L
.29029 .51961 L
.29 .5 L
.28967 .48039 L
.28935 .46078 L
.28904 .44118 L
.28875 .42157 L
.2885 .40196 L
.2883 .38235 L
.28817 .36275 L
.28815 .34314 L
.28828 .32353 L
.28862 .30392 L
.28922 .28431 L
.29013 .26471 L
.2914 .2451 L
.2931 .22549 L
.29529 .20588 L
.29801 .18627 L
.30132 .16667 L
.30392 .1534 L
.30529 .14706 L
.30997 .12745 L
.31541 .10784 L
Mistroke
.32169 .08824 L
.32353 .08297 L
.32889 .06863 L
.33706 .04902 L
.34314 .03587 L
.34632 .02941 L
.35675 .0098 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo03kooooo00<0
0000ooooooooool07oooool00`00003oooooooooo`0hooooo`0300000?oooooooooo01Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo?P00000P01TI6@030000000c
<c<0<c<c03T0<c<c00<0000001TI6@0I6AT0400I6AT4ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooocd00000800I6AT00`000000<c<c03<c<`0k03<c<`030000000I
6AT06ATI00l06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ooll000002006ATI00?o000003<c<`0c<c<0?@0c<c<00ol000006ATI01TI6@0>01TI6@Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo>`0000000ol000006ATI01TI
6@0N01TI6@030000000c<c<0<c<c03d0<c<c00<0000001TI6@0I6AT03P0I6AT4ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?oooooooooooooooc`000007`0I6AT00`000000<c<c03<c
<`0n03<c<`030000000I6AT06ATI00h06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooolk000002006ATI00<0000003<c<`0c<c<0?`0c<c<00`0000006ATI01TI
6@0=01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo>`00
000O01TI6@030000000c<c<0<c<c0400<c<c00<0000001TI6@0I6AT03@0I6AT4ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?oooooooooooooooc/000007`0I6AT00`000000<c<c03<c
<`1003<c<`030000000I6AT06ATI00d06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooolj000001l06ATI00<0000003<c<`0c<c<0@P0c<c<00`0000006ATI01TI
6@0<01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo>@00
000O01TI6@030000000c<c<0<c<c04<0<c<c00<0000001TI6@0I6AT0300I6AT4ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooocT000007`0I6AT00`000000<c<c03<c
<`1303<c<`030000000I6AT06ATI00`06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooolh000002006ATI00<0000003<c<`0c<c<0@`0c<c<00`0000006ATI01TI
6@0<01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo>000
000O01TI6@030000000c<c<0<c<c04D0<c<c00<0000001TI6@0I6AT02`0I6AT4ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003ooooooooooooooolg00000003o`00000I
6AT06ATI01d06ATI00<0000003<c<`0c<c<0A@0c<c<00`0000006ATI01TI6@0;01TI6@Cooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooocP000007P0I6AT00ol00000<c<c03<c<`1603<c<`030000000I6AT06ATI00/06ATI1?oo
ool00`00003oooooooooo`26ooooo`;o00001?ooool2o`00047ooooo0009ooooo`0400000?oooooo
ooooooooocL000007`0I6AT00`000000<c<c03<c<`1603<c<`030000000I6AT06ATI00/06ATI1?oo
ool00`00003oooooooooo`23ooooo`?o00001_ooool00ol0003oooooo`000010ooooo`002Oooool0
1000003ooooooooooooooolg000001l06ATI00<0000003<c<`0c<c<0AP0c<c<00`0000006ATI01TI
6@0;01TI6@Cooooo00<00000ooooooooool0P?ooool3o`0000Wooooo00?o0000ooooool00000@?oo
ool000Wooooo00@00000oooooooooooooooo=`00000O01TI6@030000000c<c<0<c<c04H0<c<c00<0
000001TI6@0I6AT02`0I6AT4ooooo`0300000?oooooooooo07kooooo0_l0000<ooooo`04o`000?oo
ooooooooo`0003oooooo0009ooooo`0400000?ooooooooooooooocH000007`0I6AT00`000000<c<c
03<c<`1703<c<`030000000I6AT06ATI00/06ATI1?ooool00`00003oooooooooo`1kooooo`?o0000
3Oooool00onh_]ko0000ooooo`02ooooo`03o`000?oooooooooo03cooooo0009ooooo`0400000?oo
ooooooooooooocH000007`0I6AT00`000000<c<c03<c<`1703<c<`030000000I6AT06ATI00/06ATI
1?ooool00`00003oooooooooo`1iooooo`;o00003oooool2okRngP05o`000?ooooooooooooooool0
0000?_ooool000Wooooo00@00000oooooooooooooooo=P00000O01TI6@030000000c<c<0<c<c04L0
<c<c00<0000001TI6@0I6AT02`0I6AT4ooooo`0300000?oooooooooo07Kooooo0ol0000?ooooo`Co
^;kN00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`002Oooool01000003ooooo
oooooooooolf000001l06ATI00<0000003<c<`0c<c<0A`0c<c<00`0000006ATI01TI6@0;01TI6@Co
oooo00<00000ooooooooool0M?ooool2o`00013ooooo00?o^;gNokRng_nh_]h00onh_]h00ol0003o
^L3Oooooo`02ooooo`03o`000?oooooooooo03_ooooo0009ooooo`0400000?ooooooooooooooocD0
0000800I6AT00`000000<c<c03<c<`1703<c<`030000000I6AT06ATI00/06ATI1?ooool00`00003o
ooooooooo`1aooooo`?o00004Oooool3okRmgP;o^;kN00Go^KoOokW0gol0003o^L3OokW1h003oooo
o`03o`000?oooooooooo03[ooooo0009ooooo`0400000?ooooooooooooooocD00000800I6AT00`00
0000<c<c03<c<`1703<c<`030000000I6AT06ATI00/06ATI1?ooool00`00003oooooooooo`1^oooo
o`?o00004_ooool01Ong_Mko^;gNokRmg_nh_Mko^;oO00Co^KoO00Co0000okW1h?ni`N3o^L7P0ooo
ool00ol0003oooooooooo`0iooooo`002Oooool01000003ooooooooooooooold00000003o`00000I
6AT06ATI01h06ATI00<0000003<c<`0c<c<0A`0c<c<00`0000006ATI01TI6@0;01TI6@Cooooo00<0
0000ooooooooool0K?ooool2o`0001?ooooo00Go][cNokNmg_ng_Mko]kgNokRmgP03okRog`;o^KoO
00Go^L7OokW1h?l0003o^L7Pok[2h@03ooooo`03o`000?oooooooooo03Wooooo0009ooooo`040000
0?ooooooooooooooocD000007`0I6AT00`000000<c<c03<c<`1703<c<`030000000I6AT06ATI00`0
6ATI1?ooool00`00003oooooooooo`1Yooooo`?o00005?ooool3okJlgP03okNmg_nh_]oo^;kO00?o
^;oO1?ni`Ml01?l0003o^/;Qok[2hOnj`^43ooooo`03o`000?oooooooooo03Sooooo0009ooooo`04
00000?oooooooooooooooc@00000800I6AT00`000000<c<c03<c<`1703<c<`030000000I6AT06ATI
00`06ATI1?ooool00`00003oooooooooo`1Wooooo`;o00005Oooool01Onf^mko][cNokJlg_nf_=ko
]kkO00Co^;kO00?o^;oOokW0goni`=l00_ni`Ml01Onj`^3o0000ok[2hOnj`^7o^/CQ00Cooooo00?o
0000ooooooooool0=oooool000Wooooo00@00000oooooooooooooooo=000000P01TI6@030000000c
<c<0<c<c04L0<c<c00<0000001TI6@0I6AT0300I6AT4ooooo`0300000?oooooooooo06Cooooo0ol0
000Dooooo`03okBjg_nf^mko][_N00;o][_N00Co][cNokNngong_]oo]kkO0_nh_]l4okW0g`?o^/;P
00?o0000ok[2hOnja>400_nja>43ooooo`03o`000?oooooooooo03Oooooo0009ooooo`0400000?oo
oooooooooooooc@00000800I6AT00`000000<c<c03<c<`1703<c<`030000000I6AT06ATI00`06ATI
1?ooool00`00003oooooooooo`1Rooooo`;o00005Oooool01?nc^]ko];[NokBjg_nd^]h2okJkgP05
okJmgong_]oo]kkOokNngonh_ml01Oni`=l4ok[2h003o`000?nja>7o^/CQ00;o^/CQ1?ooool00ol0
003oooooooooo`0fooooo`002Oooool01000003ooooooooooooooold000002406ATI00<0000003<c
<`0c<c<0A@0c<c<00`0000006ATI01TI6@0=01TI6@Cooooo00<00000ooooooooool0Goooool3o`00
01Kooooo0onc^]h00ond^]ko]KcOokFlg`03okJmg`04okNngonh_moo^;oOokRog`;o^L3O00Oo^L;Q
ok[2h?nj`^3o^/;Pok[3hOnja>7o000000?o^/CQ0_nkaN84ooooo`03o`000?oooooooooo03Gooooo
0009ooooo`0400000?oooooooooooooooc@000008@0I6AT00`000000<c<c03<c<`1503<c<`030000
000I6AT06ATI00d06ATI1?ooool00`00003oooooooooo`1Mooooo`;o00005oooool01Onb^Mko/k[N
ok>jg_nc^]ko];_O00Co]KcO00?o][gOokNoh?ng_n000onh_ml01Oni`N7o^L;QokW2hOni`^7o^/;P
00?o^/?Q00?o0000ok[4hOnkaN800_nkaN82ok_6h`?ooooo00?o0000ooooooooool0=Oooool000Wo
oooo00@00000oooooooooooooooo=000000Q01TI6@030000000c<c<0<c<c04D0<c<c00<0000001TI
6@0I6AT03@0I6AT4ooooo`0300000?oooooooooo05[ooooo0ol0000Fooooo`;o/;SO0onb^Mh01?nc
^]ko];_OokBkgond^ml2okFlg`03okJnh?ng_n3o]koP00;o]koP00Go^;oOokW1hOni`N7o^L7QokW2
h@04ok[3h@04ok_5h_l0003o^lGRok_5hPGo^lKS0oooool00ol0003oooooooooo`0dooooo`002Ooo
ool01000003ooooooooooooooolc000002806ATI00<0000003<c<`0c<c<0A00c<c<00`0000006ATI
01TI6@0>01TI6@Cooooo00<00000ooooooooool0Eoooool3o`0001Oooooo00?o[[OOok2hgon`^=l0
0_n`^=l00onb^Mko/[[Ook:jg`03okBkg`Co][kP0_ng_n02okS1h@;o^L7Q00Go^L?Rok[3hOnj`n7o
^/?Qok[5hP02ok_5hP03o`000?nkaN;o^lKS00Co^lKS0_nkan<3ooooo`03o`000?oooooooooo03?o
oooo0009ooooo`0400000?oooooooooooooooc<000008P0I6AT00`000000<c<c03<c<`1403<c<`03
o`00000I6AT06ATI00h06ATI1?ooool00`00003oooooooooo`1Eooooo`;o00005oooool2ojbfg`?o
[[OO0_n`^=l00ona^^3o/[[Ook:jg`02ok:jg`03okBkgone_N3o]KgP00;o][kP00Go]l3QokS1hOnh
`N7o^<7QokS3hP04okW3hP06ok[3hOnjaN;o^/GRok[5h_nkaN;o00000onka^<01OnkanCo^lOSok_7
honkan?o^lST00?ooooo00?o0000ooooooooool0<oooool000Wooooo00@00000oooooooooooooooo
<`00000R01TI6@030000000c<c<0<c<c04@0<c<c00<0000001TI6@0I6AT03P0I6AT4ooooo`030000
0?oooooooooo05;ooooo0ol0000Gooooo`03ojZdh?n/]]oo[;KO00;o[;KO00?o[[OOojnih?na^^00
0ona^^02ok:jg`05ok>lhOne_N3o]KgPokFmh?nf_n800ong`>401?nh`N7o^<?RokS3h_nh`n82okW3
hP07ok[5honjaN;o^/GRok[5h_nja^?o^lKSo`000002ok_6h`?o^lOT00Co^lOSok_8i?nkb>Co^lST
0oooool00ol0003oooooooooo`0booooo`002Oooool01000003ooooooooooooooolc000002806ATI
00<0000003<c<`0c<c<0A00c<c<00`0000006ATI01TI6@0>01TI6@Cooooo00<00000ooooooooool0
D?ooool2o`0001Oooooo00?oZ;?QojZdh?nZ]>000_nZ]>02ojbfg`04ojfhhOn_^N3o[kWPojnih0;o
/K[P00?o/KcQok>lhOnc_>400_nc_>401One_N3o][oRokJoh_nf_n;o]l3Q00;o]l;R0onh`n84ok[5
h`05ok[5h_nja^?o^/KSok[6hol000001?nkan@4ok_8i005ok_8iOooooooooooooooool00000=?oo
ool000Wooooo00@00000oooooooooooooooo<`00000S01TI6@030000000c<c<0<c<c0480<c<c00<0
000001TI6@0I6AT03`0I6AT4ooooo`0300000?oooooooooo04gooooo0ol0000Gooooo`04ojJbhOnX
/n7oZ;?QojRch@;oZ[CP00?oZkOQojfhhOn]^>400_n]^>400on_^N3o/;_Rok2khP03ok6lh@;o/kcQ
00Go];oRokJoh_nf_n;o][oRokK2h`04okO2hP03okS3h_nia>?o^LCS00;o^/GS0_nja^@2ok[6h`05
ok_8i?l0003o^lOTok_7i?nkb>D00onkb>@4ok_8i@?ooooo00?o0000ooooooooool0<Oooool000Wo
oooo00@00000oooooooooooooooo<`00000S01TI6@030000000c<c<0<c<c0480<c<c00<0000001TI
6@0I6AT03`0I6AT4ooooo`0300000?oooooooooo04_ooooo0_l0000Gooooo`03ojBah_nV/^7oY[;Q
00;oY[;Q0_nX/n401?nZ]>3oZkOQoj^ghOn[]n42ojfhh@03ojjjh_n`^n;o/;_R00;o/;_R00?o/KcQ
ok:nh_nb_^800ond_n801?nf_n;o]/;SokK2honf`^<2okO2hP;o^<CS00?o^LCSokW6i?nia^@00onj
a^@3ok_8i003o`000?nkanCo^lSU00;o^lSU00?o^lSTok_9iOnkbND00_nkb>D2ok[9i@?ooooo00?o
0000ooooooooool0<?ooool000Wooooo00@00000oooooooooooooooo<`00000S01TI6@030000000c
<c<0<c<c0480<c<c00<0000001TI6@0I6AT03`0I6AT4ooooo`0300000?oooooooooo04Sooooo0ol0
000Fooooo`;oX[7R0onT/N83ojJbh@03ojRchOnY]^;oZKKR00?oZkOQ00Co[KSQojjjh_n^^^;o[[[R
0_n`^n800on`_N?o/[kRok:nhP02ok:nhP06okBoh_nd`N?o]<7SokC1honf`^?o]l?T0onha><00onh
a^Co^LKTokW6i002okW6i003ok[6i?njb>Go^/SU00;o^lST00Co0000ok_9iOnkb>Go^lSU1?nkbND0
1?njbNKo^/WUok[9iOnjbND3ooooo`03o`000?oooooooooo033ooooo0009ooooo`0400000?oooooo
oooooooooc<000008`0I6AT00`000000<c<c03<c<`1103<c<`030000000I6AT06ATI01006ATI1?oo
ool00`00003oooooooooo`15ooooo`?o00005oooool00onP/>?oX[7Roj:ahP02oj:ahP03ojBah_nT
/n?oY;?S00;oYkCS1?nY]^801On[]n7o[;WSojbihon/^N?o[[[R00;o[[cT0on`_N<2ok:nhP05ok?0
i?nd`N?o]<7SokC1hone`n@00ong`n@01?nha>?o^<KTokS6i?nha^@2okW6i0;o^LOU00Go^/SUok[9
iOnjbNGo^lWUo`000006ok_9i@?o^/WV00?o^/WUok[9i_njbNH00oooool00ol0003oooooooooo`0_
ooooo`002Oooool01000003ooooooooooooooolc000002@06ATI00?o000003<c<`0c<c<0?`0c<c<0
0ol000006ATI01TI6@0A01TI6@Cooooo00<00000ooooooooool0@oooool2o`0001Sooooo00CoWZoS
oj2`honP/>?oX;3S0_nR/N800onR/^CoY;?SojBch`02ojBch`;oYkCS0_nY]^801OnY^>?o[;WSojbi
hon/^N?o[;_T00Co[[cT00?o/;gSok6oi?nc`>@00onc`>@01Ond`N?o]L?TokG3i?ne`nCo]l?T00;o
]lGU0onha^@3okW7i@03ok[9i_njbNGo^/WU00;o^/WU00?o0000ok[9i_njbNH00_nkbND2ok[:iPGo
^/WV00?o^LWVooooooooool00_ooool00ol0003oooooooooo`0^ooooo`002Oooool01000003ooooo
oooooooooolc000002@06ATI00<0000003<c<`0c<c<0?P0c<c<00`0000006ATI01TI6@0B01TI6@Co
oooo00<00000ooooooooool0@?ooool3o`0001Gooooo00CoVjkUoib^i?nL[^CoW:kT0onN[n<00onP
/>?oX;7Toj2ai003oj:bi0;oY;?S00CoYKGTojNfi?nW]^CoYkKT0onY^><01?n/^N?o[;_Tojbki?n/
^n@2ojjli004ojnniOna_nCo/KoTok6oi0;o/l3T0_nc`^D2okG3i003okK5i_ngaNGo]lGU00;o]lGU
00Co^<KTokW7i_nianKo^LOU0onjbNH2ok[9i@03ok[:i_l0003o^/WV00Go^/[V1?njbNH3okW9iP?o
oooo00?o0000ooooooooool0;_ooool000Wooooo00@00000oooooooooooooooo<`00000T01TI6@03
0000000c<c<0<c<c03h0<c<c00<0000001TI6@0I6AT04P0I6AT4ooooo`0300000?oooooooooo03ko
oooo0_l0000Cooooo`04oiR]i_nI[^GoVJkUoiV^i@?oVjkU0onL[^@00onN[n?oW[7Uoj2ai003oj2a
i003oj:bi?nR]>GoX[CU00?oYKGT0onW]^@01_nY^>?oZ[[UojZjiOnZ^^Go[;_TojfmiPCo[kkU00?o
/KoTok71i_na`NH00onc`^D01?nda>Ko]/GVokK5i_nfaNH2okO5i@;o]lOV00Ko^LOVokW9i_nibNKo
^LWVok[9i_nib^L3ok[:iP05o`000?njb^Ko^/[Vok[:i_njbnL00onjb^H4ok[9iPCo^LWV0_ooool0
0ol0003oooooooooo`0]ooooo`002Oooool01000003ooooooooooooooolb000002H06ATI00<00000
03<c<`0c<c<0?00c<c<00`0000006ATI01TI6@0C01TI6@Cooooo00<00000ooooooooool0>oooool3
o`0001;ooooo0_nG[NH3oiR]iP?oVJkU00?oVjkUoiZ_i_nL/>D00_nL/>D3oijai@;oX;7T00?oX;?V
oj:diOnR]>D00_nR]>D00onU]NCoYKSVojFhiP03ojNii@;oZ[[U00CoZkcVojfmi_n]_NKo[KgV0_n_
_^D00on_`NKo/L7Vok71iP02ok71iP05ok?2iOnda>Ko]<CVokC4i_nfaNH00_nfanL2okO7iP04okO9
ionibNKo^LWVokW9iPCo^L[W00Go^/[Vok[;iol0003o^/_Wok[:iP03ok[;i`03ok[:i_njb^Oo^/[W
00;o^/WV0_nibNL2okW9iP05okS8i_ooooooooooooooool00000;_ooool000Wooooo00@00000oooo
oooooooooooo<P00000V01TI6@030000000c<c<0<c<c03`0<c<c00<0000001TI6@0I6AT04`0I6AT4
ooooo`0300000?oooooooooo03Wooooo0_l0000Aooooo`03oiJ^ionF[NOoUZgW00CoUjgV00?oV:gV
oiR^ionH[^L00_nI[nH3oiZ_iP?oW;3U00?oW[7Uoijbi_nN/^H00onP/nH2oj:di@03oj>fionU^>Ko
YKSV00;oYKSV00?oYkWUojRkion[_>H00on[_>H00on]_NKo[KoWojfoi`03ojo1iP;o/L7V0_nba>L2
okC4iP05okC6ionfanOo]/OWokK7ionfb>P00ongbNL00onibNKo^L[WokW:i`02okW:i`?o^L_W00?o
0000ok[;ionjbnL00_njbnL01OnibnOo^/[Wok[:ionjb^Oo^L[W00?o^LWW1?nhb>H2ooooo`03o`00
0?oooooooooo02cooooo0009ooooo`0400000?oooooooooooooooc8000009P0I6AT00`000000<c<c
03<c<`0l03<c<`030000000I6AT06ATI01<06ATI1?ooool00`00003oooooooooo`0fooooo`?o0000
3_ooool00onF[^SoUZkWoiJ^i`04oiJ^i`;oUZgW0_nG[NH00onF[^OoV:kWoiR^i`02oiR^i`;oVJoV
00?oVZoVoiZaionJ/NL00_nL/NL4oijbiP03oj2ci_nP]NOoX;GW00?oXkKW0_nU^>H01?nU^^SoZ;_W
ojRkionX^nL2oj^liP03oj^nj?n]_nOo[KoW00;o[KoW00Ko[l7Vok33j?n``nSo/<?Xok;4ionbaNP4
okC6i`05okK7ionfb>So]/SXokK8j?ngbNL00_nhb^P2okW:i`;o^<_X0_nibnL01?nibnSo0000ok[;
ionjbnL4okW;i`05ok[:ionib^Oo^L[WokW:ionibNL00_nhbNL4okS8iP;ooooo00?o0000oooooooo
ool0:oooool000Wooooo00@00000oooooooooooooooo<P00000W01TI6@030000000c<c<0<c<c03X0
<c<c00<0000001TI6@0I6AT0500I6AT4ooooo`0300000?oooooooooo03?ooooo0ol0000<ooooo`;o
Uk3X0onF[nP2oiJ^j0CoUZkW0_nE[^P3oiJ^j0;oUZkW0_nH[^L01?nG/>SoV;3XoiR`j?nH/>P3oiZa
i`;oW;7W0_nN/^H00onN]>SoX;GWoj2ei`02oj2ei`03oj>fionS^NSoYK[X00?oYK[X00?oZ;_WojRm
j?nX_NP00on[_^P2ojfoi`05ojk2j?n``nSo/<?Xok33j?n`aNT00onbaNP2okC6i`;o]<SY0_nfb>P0
1Onfb^Wo^<[XokS:j?nhb^So]l_Y00?o^<_X0onibnP01?l0003o^/_WokW;j?nibnP2okW;i`;o^L_X
0_nib^L2okS:i`03okS9ionhb>Oo^<SV00;o^<SV00Co]lOVoooooooooooo0000;Oooool000Wooooo
00@00000oooooooooooooooo<P00000X01TI6@030000000c<c<0<c<c03P0<c<c00<0000001TI6@0I
6AT05@0I6AT4ooooo`0300000?oooooooooo037ooooo0_l0000;ooooo`GoV;7Y0_nG/>P00onF[nSo
UJoYoiF_j@02oiF_j@?oUJoX0onE[^P00onF[^SoUJoYoiJ_j002oiJ_j0?oUk3X0onH/>P00onJ/NOo
V[;Yoibcj003oibcj0;oW[CX0_nP]NL01?nQ]nWoXkWXoj>ij?nS^NP2ojFjj003ojJljOnX_NSoZ;gX
00;oZ;gX00?oZkkXoj_1jOn[`NT00on^`^P01On``nSo/<GYok35jOn`aNWo//GX00?o/lOY00?o]<SY
okC9j_nfb^T00onfb^T01Onhb^So]l_YokO;jOngbnWo^<_X00;o^<cY0_nibnP00onic>Wo0000okW;
j004okW;j005okS:j?nhb^Oo^<[WokS:ionhbNL00onhb>L01?nhb>Ko]lOVokO7i_nganH2ooooo`03
o`000?oooooooooo02[ooooo0009ooooo`0400000?oooooooooooooooc800000:00I6AT00`000000
<c<c03<c<`0h03<c<`030000000I6AT06ATI01D06ATI1?ooool00`00003oooooooooo`0^ooooo`?o
00002?ooool2oiZcj@;oVK;Y1OnH/NT00onG/NWoU[3YoiJ`j@06oiF_j@03oiF_j?nD[nWoU:oY00;o
U:oY0onE[nT3oiJ_j003oiN`j?nG/NWoUk7Y00;oV;;Y0onJ/^T2oibcj003oibej_nN]^WoW[KY00;o
W[KY0_nQ]nT00onS^NSoXk_Zoj>kjP03ojJlj@;oZ;gX00?oZKoZoj_1jOn[`NT00_n[`NT00on^`^So
[/CZojk4jP02ok35j@05ok77j_ncanWo/lOYok?7jOncbN/00ondbNX2okK:j@;o]/_Z0_ngbnT2okO<
j@?o^<cY0_nic>T01Ol0003o^L_XokW;j?nibnSo^<_X00?o^<[X00Go^<[WokS9ionhbNOo^<WWokS8
i`02okO8i`;o]lOV0_nfa^H2ooooo`03o`000?oooooooooo02Wooooo0009ooooo`0400000?oooooo
oooooooooc800000:@0I6AT00`000000<c<c03<c<`0f03<c<`030000000I6AT06ATI01H06ATI1?oo
ool00`00003oooooooooo`0/ooooo`;o00001oooool01?nM]NWoW;CYoibdjOnL]>T3oiZcj@;oVK;Y
00?oV;7YoiRbjOnH/^T00onG/NT2oiJ`j@;oUJoY00?oUK3ZoiB`jOnD/>T01_nD[nT00onE[nWoU;3Z
oiB`jP02oiJajPCoUk7Y0_nH/^T00onJ/^WoV[CZoiZdjP03oibejP;oW[KY00CoW[S[oj6jj_nQ^^[o
XK[Z0onS^nX01?nV_>WoY[k[ojJnjonV_^/2ojVojP;oZl7Y0_n/`n/00on^a>[o[/K[ojk6j`03ok77
jP05ok?7jOncbN_o/lW[ok?9jondbNX00ondbn/00onfbn[o]/cZokK<jP02okO<j@09okO<j_nhc>Wo
^<cYokS<jOngc>[o^<cYo`000?nhc>Wo^L_X00?o^<_X0onhb^P2okS9i`?o]lSW00Go]/OWokK6i_nf
a^Ko]/KVokK5iP02ooooo`03o`000?oooooooooo02Wooooo0009ooooo`0400000?oooooooooooooo
oc800000:@0I6AT00`000000<c<c03<c<`0e03<c<`030000000I6AT06ATI01L06ATI1?ooool00`00
003oooooooooo`0Yooooo`?o00001oooool01?nN]^WoWKGYoifejOnM]NT3oibdj@;oV[?Y1?nI/^T2
oiRbj@03oiNajOnF/N[oU[7Z00;oUK7Z0onE/>X2oiB`j@;oU:oY00?oU;3[oiB`j_nD/>X01?nD/>X2
oiJajP;oUk7Y00CoUk?[oiRcjonH/n_oV;?[0onJ]>X00onL]N[oW;O[oijhj`03oijhj`03oj6jj_nQ
_>coXKc/00?oY;g[0_nV_^/01?nV`>coZL;[ojW2jonY`^/2ojc3j`03ojc5k?n^a^_o[/K[00;o[/K[
00?o/LOZok78jonab>/00_ncbN/2ok?:j`;o]<_[00Co]<c[okK<j_nfc>[o]/cZ1?ngc>X01Onhc>Wo
]lcZokO<j_ngc>[o000000;o]l_Y0_nhbnP2okO:j003okS:j?ngbNSo]lSW00;o]lSW1?nfanL01?nf
a^Ko]/GVokK5i_nfaNH2ooooo`03o`000?oooooooooo02Sooooo0009ooooo`0400000?oooooooooo
oooooc800000:P0I6AT00`000000<c<c03<c<`0c03<c<`030000000I6AT06ATI01P06ATI1?ooool0
0`00003oooooooooo`0Wooooo`;o00001Oooool2oj2gj@?oWkKY0_nN]^T00onM]NWoW;GYoibej@03
oi^dj@;oV[?Y0_nI/^T00onH/n[oUk;ZoiNbjP04oiJajP;oUK7Z00?oUK3ZoiBajonD/N/01OnD/>/4
oiB`jP03oiBbjonE/^_oUK;[00;oUK;[0_nG/n/00onH/n_oV;G/oiRek003oiZfk0;oW;O[0_nN^>/0
0onN^^coXKc/oj6lk002oj6lk003ojBmjonT_ngoY/3/00?oY/3/00?oZL;[ojW4kOnYa>d00on/aN`2
ojk6j`;o[lO/00Ko/LS[ok79k?nabNco/LW/ok?:joncbn`4okC<j`03okK<j_nfc>_o]/c[00;o]lcZ
0_nfc>/3okO<jP04o`000?ngbnWo]l_YokO;j@;o]l[X1?ngbNP00ongb>Oo]/OWokK7i`02okK7i`;o
]/KV0_nfaNH01OneaNKooooooooooooooooo000002Wooooo0009ooooo`0400000?oooooooooooooo
oc800000:P0I6AT00`000000<c<c03<c<`0b03<c<`030000000I6AT06ATI01T06ATI1?ooool00`00
003oooooooooo`0Tooooo`?o00001Oooool2oj6hj0?oX;OY0_nO]^T4oiffj@;oW;GY00?oVkCYoiZd
j_nJ]>X00_nI/nX3oiRcjP;oUk;Z0_nF/NX00onE/^_oU;7[oiBaj`04oiBaj`03oiB`jonC/NcoTk7/
00;oTk7/0onC/N/2oiBbj`;oUK;[00?oUK?/oiJdk?nF]>`01?nH]N`00onJ]^coV[S]oibik@02oibi
k@?oW[[/0_nQ_>`01?nQ_^goY;o]ojBokOnT_nd2ojK0k003ojO2kOnYa>goZLC]00;oZLC]00?o[<G/
ojc6kOn/a^d00_n_an`01On_bNgo/LW/ok79k?nabNco/L_]00?o/l_/0_ndc>/2okC<k004okK<jone
c>_o]Lc[okG<j`?o]/c[0_ngc>X01?l0003o]l_YokO;jOngbnT5okO9j0;o]/SX1?nfanL00onfa^Ko
]LGVokG5iP03okG5iP;ooooo00?o0000ooooooooool09oooool000Wooooo00@00000oooooooooooo
oooo<P00000[01TI6@030000000c<c<0<c<c0300<c<c00<0000001TI6@0I6AT06P0I6AT4ooooo`03
00000?oooooooooo02;ooooo0_l00004ooooo`04oj>ij?nR^>SoX[SXoj:hj0?oXKSX0_nP]nT3oinf
j@?oWKKY0_nL]NX4oiZdjP;oVK?Z00?oV;?ZoiRcjonH/n/00onF/^/2oiFbj`03oiBajonD/^coU;;/
00;oTk;/1_nC/N`00onC/N_oTk?/oiBck002oiBck0?oUK?/0_nF]>`2oiRek004oiRgkOnJ^>goV[S]
oiZhk@?oW;W]00CoW[[/oinlk_nO_>koWkc^0_nQ_^d01?nT_ngoY<7^ojC1k_nT`Nh2ojO2k@;oZLC]
0_nZaNh00on/a^go[<S^ojc8kP03ojo9k@05ok79k?nabngo/L_]ok7;kOncbn`00_nbc>d4okC<k0;o
]Lc[00Co]Lc/okK<jonfc>_o]/c[0_nfbnX00ol0003o]/_ZokO;j@02okK:j@;o]lWX0_nfbNP00onf
b>So]/OWokK7i`03okK7i`Go]LGV0_nda>H2ooooo`03o`000?oooooooooo02Kooooo0009ooooo`04
00000?oooooooooooooooc800000;00I6AT00ol00000<c<c03<c<`0^03<c<`03o`00000I6AT06ATI
01/06ATI1?ooool00`00003oooooooooo`0Oooooo`?o00001?ooool01OnT^NSoXkWXoj>ij?nS^NSo
X[SX00;oX[SY0onQ^>T2oj2gj@03oinfjOnN]^WoW[KY00?oWKKY0_nL]NX3oiZdjP?oVKC[0onH/n/0
1?nF/^_oU[?[oiFbjonE/^/4oiBbk0;oTk;/00?oTk7/oi>bk?nC/^`00onC/^d2oi>ck0?oU;?/00?o
UK?/oiFekOnF]^d00onF]^d2oiRgk@03oiZhkOnJ^^koV[[^00?oW;_^0_nO_>h01?nO_^ooX/3^oj;0
k_nR`>h2ojC1kP03ojC3konWa>koYlC^00;oYlC^00?oZ/G^oj[7kon/b>h00on/b>h00on_bNgo[l[^
ojo:kP04ok7;k@Co//c]00?o]<c/ok?<k?nec>`00onec>`01Onfc>_o]Lc[okG<jonfbn[o000000;o
]/_Z00Ko]/[YokG9jOnebNWo]LWYokK9j?neb>P5okK7i`;o]LKW0_neaNH3okC4iP05okC3iOoooooo
ooooooooool000009oooool000Wooooo00@00000oooooooooooooooo<P00000]01TI6@030000000c
<c<0<c<c02`0<c<c00<0000001TI6@0I6AT0700I6AT4ooooo`0300000?oooooooooo01cooooo0ol0
0004ooooo`?oYK[X0_nT^NP3oj>ij0?oX[SY0onQ^>T3oingj@;oW[KY00?oWKKYoibfj_nL]^X00onK
]NX2oiZdjP03oiVdjonH]>_oV;C[00?oUk?[0_nF/n/2oiFbj`;oU;;/00?oU;?/oi>bk?nC/^`01?nC
/^`00onC/^goTkC]oi>dkP02oi>dkP?oU;C^0_nE]Nd2oiJfk@04oiNhkonH^NkoV;W^oiRikP?oV[[^
00?oW;_^oifmkonM_Nl00onO_^l00onR`>koX/;_oj;2k`03ojC3k`;oYlC^0_nWa^l2oj[7k`;o[<S^
0_n/bNl01_n_b^ko[l_^ojo;k_n_bnko/L_]ok3<kPCo//c]0oncc>`2okG<k0;o]<c/00Go]Lc[okG;
jonebn_o0000okK;jP04okG9j@04okG8jOneb>So]LSXokG8j0;o]/OW0onea^L2okC5iP;o]<CV00Co
]<?VokC3iOnd`nGo]<?U0_ooool00ol0003oooooooooo`0Uooooo`002Oooool01000003ooooooooo
oooooolb000002h06ATI00<0000003<c<`0c<c<0:`0c<c<00`0000006ATI01TI6@0L01TI6@Cooooo
00<00000ooooooooool06_ooool2o`0000?ooooo0_nV^^P4ojFjj0;oY;[X0onT^NP2oj>ij0;oX[SY
1?nQ^>T2oingj@?oW[OZ0onL]^X00onK]N[oVkG[oiZej`03oiZej`;oV;C[00?oUk?[oiNdk?nF/n`0
0_nF/n`5oiBck003oi>bk?nC/ngoTk?]00;oTk?]0onC]>d3oi>dkP03oiBdk_nD]^ooUKO_00?oUKO_
0_nG^>l00onH^NkoV;_`oiRkl003oiZlk`?oWKg_00?oWkk_oio0l?nO`?000onR`^l00onT`nooYLG`
ojG5l002ojO6k`04ojS7l?nZb>ooZ/S_oj[8k`;o[<W_0_n]b^l2ojo;kP04ojo;kon`c>ko/<c^ok3<
kPCo//c]0oncc>`2okC<k0;o]<_[0_nebn/01?l0003o]LWYokG9jOnebNT4okG8j@03okG8j?nda^So
]<KX00;o]LKW00Co]<GWokC5i_ndaNKo]<GV1?nd`nH00ond`nGo/l;Uok?2i@02ooooo`03o`000?oo
oooooooo02Cooooo0009ooooo`0400000?oooooooooooooooc800000;`0I6AT00`000000<c<c03<c
<`0Y03<c<`030000000I6AT06ATI01d06ATI1?ooool00`00003oooooooooo`0Gooooo`?o00000ooo
ool2ojJkj0?oY[[X0_nU^^P4ojBjj003ojBij?nS^NSoX[WY00;oX[WY0_nR^>T2oj6hj@05oj2hjOnO
]nWoWkOYoingjOnN]nX00_nM]nX3oibfjP;oVkG[0_nJ]N/00onI]N_oV;C[oiRdj`03oiNdk0?oU[?/
00?oU;?/oiBdkOnD/nd00onD/nd4oi>ck@03oi>dkOnC]NkoTkG^00?oTkG^0_nD]^l2oiFgk`04oiFh
l?nG^O3oUkW`oiNil0?oV;_`00?oV[c_oi^ml?nK_O000onM_o000onO`?3oX<;aoj32l@03oj;3l003
ojG5l?nUa_3oYLK`00?oZ<O`00KoZ/S_oj[9l?nZbO3oZ/W`ojg:kon]bnl4ojo;k`?o/<c^1?nbc>d0
1oncc>co//_/ok;;k?nbbnco]<_[ok?:jondb^X00_l000001?ndb^[o]LWYokC8jOndb>T2okG8j@;o
]<OX00?o]<KXokC5iondaNL00ondaNL00ondaNKo]<CVokC4iP02okC3iP?o/l;U00Go/l7Uoooooooo
ooooooooo`00000Uooooo`002Oooool01000003ooooooooooooooolb000003006ATI00?o000003<c
<`0c<c<09`0c<c<00ol000006ATI01TI6@0N01TI6@Cooooo00<00000ooooooooool05_ooool00ol0
00000000ooooo`02ooooo`;oYk_X0onV^nP2ojJjj0?oYK[X0onT^^P3oj>ij0?oX[WY0onQ^>T2oj2h
j@03oingjOnO]n[oWkOZ00?oWKOZ00?oW;KZoibfjonL]^/00_nK]^/3oiVej`;oV;C[0onG]>`3oiFd
k@;oU;C]0_nD/nd00onD]>koTkC^oi>dkP07oi>ekP03oi>gkonD^>ooU;S_00;oU;S_0_nE^?000onG
^O3oUk_`oiNkl003oiVll0?oVkg`00?oWKo`oig1lOnM`O400onP`_400onR`o3oXlGaoj?5l@03ojG6
l003ojS7l?nXb?3oZ<S`00?oZ/W`0on]bnl2ojo;k`;o[/__00Go/<c^ok3;k_n`bnko/<_^ok;<k@02
ok7;k@;o//_/00Ko//[/o`000?l0003o0000okC:j_l00002ok?9jP03okC8jOncanWo/lOY00;o]<OX
00?o/lKXokC5iondaNL00ondaNL2ok?4iP03okC4i_nc`nKo/l?V00;o/l;U1?nc`ND2ooooo`03o`00
0?oooooooooo02?ooooo0009ooooo`0400000?oooooooooooooooc800000<@0I6AT00`000000<c<c
03<c<`0T03<c<`8000008@0I6AT4ooooo`0300000?oooooooooo01Kooooo00?o0000ojNkj?nW^nP0
0onW^nP5ojJkj0;oY[[X1?nU^^P2ojBjj003oj>ij?nS^NWoXkWY00?oX[WY0_nQ^>T4oj2hj@;oWkOZ
0_nM]nX4oibfj`;oVkK[00?oVKG[oiVfk?nH]N`00onH]N`2oiNdk003oiFdkOnE]NgoU;C]00?oU;C]
0_nD]>h2oi>dkP03oi>ek_nC]^ooTkK_00?oTkK_0_nC]nl2oiBhk`04oiBil?nF^_3oU[[`oiJjl0?o
Uk_`00?oVKc`oiVnlOnK_o400onK_o400onM`O7oW/;boj33l@03oj33l@03oj?5lOnSa_7oXlKa00?o
YLOa00CoZ<S`ojS9lOnXbO7oZ<Wa0_nZbO04ojg;k`?o[/__0on`bnh3ok7;k@?o000000Ko//[/ok?:
joncbN_o/lW[ok?9j_l00002ok?8j@03ok?7jOnca^So/lKX00?o/lKX00?o]<GWok?4ionca>L00_nc
a>H4ok?3iPGo/l7U0_nc`N@2ooooo`03o`000?oooooooooo02;ooooo0009ooooo`0400000?oooooo
oooooooooc800000<P0I6AT00`000000<c<c03<c<`0R03<c<`030000000I6AT06ATI02406ATI1?oo
ool00`00003oooooooooo`0Fooooo`03o`000?nW^nSoYk_X00?oYk_X1?nV^nP2ojJjj0GoYK[X1?nT
^^P2oj>ij@;oX[WY0onQ^>T2oj2hj@04oinhj_nN]n[oW[OZoijgjP;oWKOZ0_nL]^/01?nL]n_oV[K[
oiZfjonJ]^/2oiVfk0;oV;G/00CoV;K/oiNekOnG]NgoUkG]0_nE]Nd2oiBdk@?oU;K^1onC]^l2oi>h
l0?oU;S`0_nD^O000onF^_3oU[_aoiJkl@03oiRll@;oVKka0_nK_o42oic1lP;oW/;b0_nP`o42oj74
lP?oXlKa00?oYLOaojK7lOnVao400onXbO43oj_:l0Co[L__00?o[/__ojk;k_n^bnh00_n`bnh3o`00
0003ok7:kOnbb^co//[/00;o//W[00Ko/lW[ok;8j_nbb>[o/lSYo`000?nba^T5ok?6j0;o/lGW00?o
/lCWok?3i_nc`nH01?nc`nH2ok?2i@;o/l7U00Co//7Tok?1i?nc`NCo/l7T0_ooool00ol0003ooooo
ooooo`0Rooooo`002Oooool01000003ooooooooooooooolb000003<06ATI00?o00000000000c<c<0
7`0c<c<00`00003o000001TI6@0S01TI6@Cooooo00<00000ooooooooool05_ooool00ol0003oYk_X
ojNkj004ojNkj0?oY[_X0onV^^P5ojFjj0?oY;[X0onS^NT2oj:ij@CoXKSY0_nO^>X00onN]n[oW[SZ
oijhjP03oifgj`;oW;O[00?oV[K[oiZfk?nJ]^`00onI]^`2oiRfk003oiNekOnG]^goUkK]00?oU[K^
1?nD]^h2oi>fk`04oi>gkonC]o3oTkO`oi>gl0?oTkS`00?oU;S`oiBilOnE^_400_nE^_43oiJkl@03
oiRllOnH__;oV[ob00?oV[ob00?oW<7boic2l_nN`o800onN`o800onQa?;oXLGboj?6lP03oj?6lP03
ojK7lOnVb?7oZ<Wa00?oZ<Wa0on[b_02ojg;k`;o[<[_00Co[/_^o`000?l0003o00000_n_b^d01_na
b^go/<W/ok39k?n`bNco//W[ok78j`?o//SZ00Go/LOZok;6jOl0003o//KYok?6j002ok;5j0;o/lGW
00?o//?Wok?3i_nc`nH00onc`nH2ok;2i@03ok?2iOnb`NGo//7T00?o//7T00?o/l7Tok;0i?nb`>@0
0_ooool00ol0003oooooooooo`0Qooooo`002Oooool01000003ooooooooooooooolb000003D06ATI
00<0000003<c<`0c<c<0700c<c<00`0000006ATI01TI6@0T01TI6@Cooooo00<00000ooooooooool0
5Oooool01?l0003oooooooooooooool6ojNkj0;oY[_X0onV^^P3ojFjj0GoY;[X0onS^NT3oj:ij@;o
XKSY1?nO^>X2oijhjP;oWKO[1?nL]n/2oiZfk0;oVKK/0onH]^d3oiNfk@;oU[K^1?nE]^h2oiBfk`;o
TkO_00?oTkO`oiBhl?nD^?000onD^O02oiBil@03oiFjlOnF^o7oU[_a00?oUkgb0_nH__82oiZolP;o
V/3b0_nL`_82oik3lP;oWlCb0_nQaO82oj?6lP;oY<Ob0_nVb?44ojS9l@04oj_:l?n[bO3oZlW`oj_9
l0?o00000on^b^h00on_b^go[lW]ojo9k@02ok39k005ok38k?nab>_o/LS[ok78jonbb>X00onaanX0
1?l0003o//GXok;5j?nbaNP2ok;4i`?o//?W00?o/l?Vok;2i_nb`^H00_nb`^D4ok;1i@;o//7T0onb
`>@01Onb_nCooooooooooooooooo000002;ooooo0009ooooo`0400000?oooooooooooooooc800000
=P0I6AT2000001/0<c<c00<0000001TI6@0I6AT09@0I6AT4ooooo`0300000?oooooooooo01Gooooo
00Co0000oooooooooooooooo1OnW^nP4ojJkj0?oY[[X0onU^^P3ojBjj0?oXk[Y0_nS^NT2oj:ij@?o
XKSY0onO^>X3oijhj`;oWKO[0onL]n/3oiZgk0;oVKK/00?oV;K]oiRgkOnH]nd00onG]nh2oiJfkP;o
UKK^00?oUKO_oiBgkonD]nl01_nD^?000onD^O3oU;[aoiFkl@03oiFkl@;oU[_a00?oUkgboiRnl_nI
_o800onI_o800onJ`?;oVl7boig2lP03oig2lP03oio4l_nPa?;oX/Kb00?oX/Kb0_nTao84ojK8l@03
ojS9lOnYbO3oZLW`00?o00000on/bNl2ojk:kP;o[/W^00?o[lW]ojo8k?n_b>`00on`b>`00onab>_o
/LOZok77jP02ok77jP;o/LGY00?o0000ok74j?nba>L00onba>L01?nb`nOo//;Vok;2i_nb`^H6ok;1
i@Co//3T1?nb_n@2ooooo`03o`000?oooooooooo023ooooo0009ooooo`0400000?oooooooooooooo
oc800000>00I6AT00`000000<c<c03<c<`0F03<c<`800000:00I6AT4ooooo`0300000?oooooooooo
01Gooooo00?o0000ooooooooool00_ooool3ojNkj0KoY[_X0onV^^P2ojFjj0?oY;[X0onS^^T3oj>i
j@;oX[WY00?oXKSYoj6ij_nQ^NX00onO^>X3oijhj`?oWKS[0_nL]n/3oiZgk0?oVKO]0_nH]nd2oiNg
kPCoU[O^0_nE]nl2oiBgk`03oiBhl?nE^O3oUKW`00?oU;W`0_nD^_42oiFkl@04oiJllOnG_O;oUkgb
oiNmlP;oV;kb0_nI_o82oi[0lP;oVl7b0_nM`_82oik3lP;oX<Cb1?nRa_82ojC7lP;oY/Sa00GoYlSa
o`000?l0003o0000ojW8l003oj_9k`03ojc9kon/b>ko[<S^00;o[/W^0_n]b>d00on_b>co[/O/ok37
j`03ok37j`03ok77j_n`aN[o/<GZ00;o/LGY00Co/<CXok74j?l0003o/LCX0_nba>L2ok73i`03ok;2
i_na`NKo//7U00Co//7U0_nb`>D00onb`>Co/[oTok:oi006ok:oi0;ooooo00?o0000ooooooooool0
7oooool000Wooooo00@00000oooooooooooooooo<P00000i01TI6@<000004`0c<c<2000002X06ATI
1?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo0_nW^nP6ojJkj003ojJj
j?nU^^SoYK[X00;oYK[X0onT^^P3oj>jj@03oj>ijOnR^NWoX[WY00?oX[WY0_nQ^NX3oinhjP?oW[S[
0_nM^>/3oibhk0?oV[O/0_nI]nd3oiRgk@;oUkO^0_nF]nh01?nG^>ooU[S_oiJhkonF^>l2oiFhl0?o
UKW`00?oU;W`oiFjlOnE^o400onE^o42oiJll@?oUkgb0onH_o800onJ`?;oVl7boic2lP03oic2lP;o
W/?b1?nPaO801?nRa_;oXlKbojG7lOnUao43o`0000;oYlO`00?oZLS`ojW7konYanl00on[b>l01_n/
b>ko[<O^ojc7k_n/anko[LS]ojg6k0?o[/O/0_n`an/2ojo5jP03ok35j_n`a>Wo/<CX00?o/<CX00?o
/LCXo`000?na`nL00_na`nL4ok71iP06ok;1iOna`>Go/L3Uok70iOnb`>Go/KoT2?nb_n@01Onb_n?o
oooooooooooooooo0000023ooooo0009ooooo`0400000?oooooooooooooooc800000?00I6AT40000
00d0<c<c0P00000/01TI6@Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`04oooo
o`CoYk_X1OnV^nP6ojFjj0;oY;[X1?nS^^T3oj:ij@05oj6ijOnP^N[oX;WZoj2ij_nO^>X00_nO^NX3
oijhj`;oWKS[0onL^>`3oi^hk0;oVKO]00?oV;O]oiVhkOnI^>d00onH^>h2oiNhk`03oiJhkonF^Noo
U[W_00?oU[W`0_nE^O02oiFjl@;oUK_a0_nF_?42oiNllP03oiNml_nH__;oV;kb00?oVKob0_nK`O82
oic2lP;oWL;b0_nN`o82oj35lP;oXLGb00CoXlKbo`000?l0003oYLOa0_nUa_42ojO7l0CoZLO_00?o
ZlS_oj_7k_n[anh00_n/anh01On/a^go[LK/ojg6k?n]a^co[/O/00?o[/G[00?o[lGZojo4j_n`a>T0
0_n`a>T2ok34j0;o/<?X00?o0000ok32iona`NH01?na`NH4ok70i@05ok6oiOna_nCo/KoTok6oi?nb
_n@00_na_n@2ok:oi0Co/[oS0_ooool00ol0003oooooooooo`0Nooooo`002Oooool01000003ooooo
oooooooooolb000004006ATI0`00000603<c<`@00000;P0I6AT4ooooo`0300000?oooooooooo01Go
oooo00?o0000ooooooooool01Oooool3ojNkj0KoY[_X1OnU^^P3ojBjj@?oXk[Y0onR^NT2oj6ij@?o
X;WZ0onO^NX2oijhj`CoWKS[0_nL^>`2oi^hk0?oV[S]0onI^>d2oiRhkP?oUkS_0onF^Nl00onF^O3o
Uk[`oiJjl002oiJjl0?oU[_a00?oU[caoiNllOnH_O800_nH_O83oiRnlP03oiVol_nJ`?;oVl7b00?o
Vl7b00?oWL;boik2l_nOa?800onOa?83o`0000;oXlKa0_nUa_42ojG6l0;oYlO`0_nYanl2ojW6k`03
oj_7k_n[a^ko[<K]00?o[<K]00?o[LK/ojg5k?n]aN`00_n^aN/01On^a>[o[lCZojo4j_n_a>[o/<CY
00;o[l?X0_n``nP01?n_`^Oo/<;Wo`000?n``^L2ok71iP;o/<7V00?o/L3Uok6oiOna_nD00ona_nD4
ok6oi003ok6ni?nb_n?o/[oS00?o/[oS0_nb_^<2ooooo`03o`000?oooooooooo01gooooo0009oooo
o`0400000?oooooooooooooooc800000@`0I6AT6000003806ATI1?ooool00`00003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo0_nW^nP6ojJkj0GoYK[X0onT^^T3oj>jj@?oX[WY0onQ^NX2
oj2ijP03oinij_nO^N_oWkW[00;oW[S[0_nM^>/01?nM^>coW;S/oibhk?nL^>`2oi^hk0?oV[S]0onI
^>h2oiRhkP03oiNhkonH^NooV;W_00?oUkW_0_nG^_000onF^_3oUk_`oiNkl003oiNkl@;oUkca00?o
V;gboiVnl_nI__800onI_o82oi[0lP;oVl7b0_nL`O82oik2lP?o000000CoX<Cboj;5lOnRaO7oXlKa
0onTaO400onUa_3oY/G`ojO6k`02ojO6k`;oZLK_0_nYaNh2oj_6kP;o[<K]0_n/aN`00on]aNco[LC[
ojg4j`03ojk4jP04ojo4j_n^`nWo[/?Yojo3j0;o[l;X0on_`^L00on``^Oo0000ok31iP02ok31iP03
ok2oiOna_nGo/KoU00?o/KoU0ona_n@4ok6ni0;o/[oS1?nb_^<3ooooo`03o`000?oooooooooo01co
oooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oooooooooo01Co
oooo00?o0000ooooooooool02Oooool8ojJkj0?oYK[X0onT^^P2ojBjj@?oXk[Y0onR^NT2oj6ijP?o
X;WZ0onO^N/3oijij`;oWKS/00?oW;S/oibik?nL^N`00onK^>d2oiZhk@03oiVhk_nJ^NkoVKW^00?o
VKW^0_nH^Nl00onG^NooV;[_oiNjl003oiNjl0;oUk_`00?oUk_aoiRllOnH_O400onH_O42oiVnlP03
oiVol_nJ_o;oV[ob00?oVl3b00GoW<7bo`000?l0003o0000oik2lP02oj34lP04oj73lOnRa?7oX/Ca
oj;4l@;oY<Ga0_nTa?02ojK5l006ojO6konWaNooYlG_ojO5konYaNkoZLC]0onZaNd2ojc5k0;o[<C/
00?o[LC[ojc3j_n]`nT00on]`nT00on^`nWo[/;Xojk2j003ojo2j005ojo2ion_`NOo[l7Wok31i_l0
00001?n`_nD00ona_nGo/;oUok2oi@02ok6oi0Oo/KkT1_nb_^<2ooooo`03o`000?oooooooooo01co
oooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oooooooooo01Co
oooo00?o0000ooooooooool02_ooool8ojJkj0?oYK[X00?oY;[XojBjjOnT^^T00_nT^^T3oj>jj@?o
X[[Y0_nQ^NX00onP^N[oXKWZoj6ijP03oinij`;oW[W[0onM^N`3oibik003oi^hkOnL^NgoVkW]00;o
VkW]0_nJ^Nh3oiVikP?oVK[_0_nH^^l2oiNjl0CoV;_`0_nH_?42oiRml@;oVKga0_nJ__400onJ_o;o
Vkoaoi^ol@03o`0000;oWL7b00CoW/;boio2lOnO`_7oWl;a0_nQ`o401_nRa?7oXlC`oj?4l?nSa?3o
Y<C`ojG4k`?oY/C_0_nWaNl2ojS4kP;oZLC]00KoZ/G]oj[4k?nZa>coZ/C/ojc4k?n[`n/3ojc3jP;o
[L?Y0_n]`^T00on^`^So[/7Xojk1i`03ojk1i`05ojo1ion__nKo[koVo`000?n__nH01On`_nD00on`
_^Co/KkTok6ni006ok6ni003ok6nhonb_^?o/[kS00Go/[kS0_ooool00ol0003oooooooooo`0Koooo
o`002Oooool01000003ooooooooooooooolb000007/06ATI1?ooool00`00003oooooooooo`0Doooo
o`03o`000?oooooooooo00_ooooo2?nV^nP3ojFjj0GoY;[Y0onS^^T2oj:jj@KoXKWZ0onO^N/2oiji
j`03oifik?nN^NcoW[W/00?oWKW/0_nL^Nd3oi^ik@?oV[W^0_nI^Nh6oiVjk`?oV;_`0_nI_?03oiVl
l@04oiVmlOnJ_O7oVkkaoi^nl@?o000000CoVkoaoic0lOnM`?7oWL3a0_nN`O42oio2l@;oX<;a0_nQ
`o02oj?4l0;oXl?`0_nUa>l00onVa>ooY/?^ojK3kP02ojS4kP04ojS3kOnY`ngoZL?]ojW3k@;oZ/C/
00GoZ/;[oj_3jon[`n_oZl?[ojc3jP03ojc2j@03ojg2jOn]`NSo[/7X00;o[/7X0_n^`NL2ojjoi`?o
[koV00Go0000ojnoiOn`_nGo/;oUojnni@03ok2ni0;o/KkT0_n`_^@2ok6ni0?o/KkS1Onb_^<01Onb
_n?ooooooooooooooooo000001cooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4
ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool5ojJkj0?oYK_X0onU^^P5
ojBjj@?oXk[Y0_nR^^T2oj6ijP05oj6jj_nQ^N[oXKWZoj6ij_nO^N/00_nP^N/3oinij`;oW[W/0_nM
^N`3oibik@?oVkW]00?oV[W^oi^jk_nJ^^h00_nJ^^h4oiVjk`;oV[__0_nI^o000onI_?3oV[c`oiZl
l003oiZml0?o00000_nL__43oibol@03oig0lOnN`?3oWl7a00?oWl7a00?oX<;aoj71l?nR`_000_nR
`_02oj?3l005ojC2konU`nooYL?_ojG3konV`nh00_nV`^d3ojS3k@03ojW3kOnY`^coZL;/00?oZ/;[
00?oZl?[oj_1j_n[`NX00_n/`^T01On/`>Wo[L7Xojg1j?n]`NSo[/7X00;o[KoW0_n^_nL4ojjoiP03
ojnoiOl0003o[kkU00?o[kkU1_n`_^@3ok6ni0?o/KkS0onb_^<3ok:oh`;ooooo00?o0000oooooooo
ool06_ooool000Wooooo00@00000oooooooooooooooo<P00001k01TI6@Cooooo00<00000oooooooo
ool05?ooool00ol0003oooooooooo`0=ooooo`GoY[_X1?nU^nP2ojFjj0GoY;[Y0onS^^T3oj:jj@;o
XK[Z0onQ^NX3oj2ij`;oWkW[0onN^N`2oifik003oibikOnM^NgoWKW]00?oW;W]0_nK^^h01?nJ^^ko
Vk[^oi^jk_nK^^h2oiZjk`;oV[__0onJ_>l2oiZll0?o00000onK__03oibnl@03oibolOnM_o3oWKo`
00;oW/3`0_nO`O42oj31l0;oXL7`00CoX/;`oj?2konS`^ooXl;_0_nT`^l00onU`nooYL;^ojG2kP03
ojK2k@04ojS3kOnX`^coZ<;/ojW2k0;oZL7[0onZ`N/00on[`N[oZl3Yojc0j@03ojc0j@05ojg1j?n/
_nSo[;oXojfoion]_^L01On^_nH00on^_^Go[kkUo`000005ojnni@Ko/;kT0ona_^@00ona_^?o/KkT
ok:nh`03ok:nh`03ok:ohonb_nCo/[oT00;ooooo00?o0000ooooooooool06Oooool000Wooooo00@0
0000oooooooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04oooool00ol0003ooooo
ooooo`0?ooooo`KoY[_X0_nU^nP3ojFjj@KoY;[Y0_nS^^T2oj:jj@?oX[[Z00?oXKWZoj6jj_nQ^^X0
0onP^N/2oinij`?oW[W/0onM^N`2oifik@03oibikOnL^^goW;[]00GoVk[^0onK^nh2oiZkk`04oiZl
kol0003o0000o`0000;oVkc`0_nK_O000onK__3oW;k`oibnl003oibnl003oifol?nN_o3oWl3`00?o
Wl3`00?oX<7`oj30konQ`Nl00_nQ`Nl2oj?2k`05oj?1k_nT`NkoY<7^ojC1k_nU`^h00_nU`Nd3ojO1
k@03ojS2k?nX`N_oZ<7[00?oZL7[00?oZ/7[oj[0j_nZ`>X00_n[`>T2ojc0j@?o[;oX00Co[;kWojfn
ion]_^Oo[KkW0_n^_nH2ojjniP;o[[kU00?o[kkUo`000?n__^D00_n__^D00on__NCo/;kTok2ni005
ok2ni0Go/KkT0_nb_^<4ok:oi0;ooooo00?o0000ooooooooool06Oooool000Wooooo00@00000oooo
oooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0@
ooooo`GoY[_X0onU^nP00onU^^WoYK_YojFkj@05ojBjj@?oXk[Y0_nR^^T4oj:jjP;oXK[Z00?oX;W[
oj2jjonO^^/00_nO^^/3oijik003oifik?nN^^coW[[/00;oWK[]00?oW;[]oifjkOnM^^d00onL^^d2
oi^jkP03oi^kk_nL^nkoVk__00;o000000CoVk__oi^lkonK_>ooVkc`0_nL_>l2oibmk`;oW;k`00Co
WKk_oifnl?nM__3oWKk`0_nN_o02oio0l0;oWko_0_nP`>l01?nQ`NooX/3^oj;0k_nR`>h2oj?1kP03
ojC1k_nT`>goY<3]00?oYL7]00GoYl7]ojO0k?nW`>coZ<7[ojRoj`04ojVojP03oj[0j_nZ_nWoZkoX
00;oZkoX0_n/_nP01On[_^Oo[;kWojbnion/_^Oo[KkW00?o[KkV00?o[[kVojfmiOn^_ND00_n^_ND0
0on__^Go0000ojnmi@03ojnmi0Ko/;kT1_na_^@6ok:oi0;ooooo00?o0000ooooooooool06?ooool0
00Wooooo00@00000oooooooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04oooool0
0ol0003oooooooooo`0Aooooo`GoY[_X1?nU^nP2ojFkj@GoY;[Y0onS^^T5oj:jjP?oXK[Z0_nP^^/3
oinjj`?oWk[/0_nN^^`3oifjk0?oWK[]00CoW;[]oifjkOnL^nkoW;_^0ol00002oi^kk`;oW;_^0onL
_>l00onM_>ooWKg_oifmk`02oifmk`;oWKk_00?oWKk`oijnkonN_^l01?nO_nl01?nP_nkoXKo^oj6o
k_nQ_nh2oj;0kP06oj:ok_nS`>goXl3]oj?0kOnT`>goYKo/1?nV_n`00onW`>coYko[ojRoj`02ojRo
j`;oZKoZ00GoZKkYojZojOnZ_nWoZ[oYoj^oj002oj^nj0?oZkkW00?o[;kWojbmi_n/_NH00_n]_^H0
1?n]_NKo[KgUojfmiOn]_ND3ojjmi@03ojnmiOl0003o[kgU00?o[kgT1_n`_^@4ok6ni003ok6oi?nb
_nCo/[oT00?o/[oT0_nb`>@2ooooo`03o`000?oooooooooo01Oooooo0009ooooo`0400000?oooooo
oooooooooc800000N`0I6AT4ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_oo
ool6ojJkj0;oYK_X0onU^nT6ojBjj@;oXk[Y1OnR^^X3oj6jjP?oX;[[0_nO^^/3oinjk0;oW[[/00?o
WK[/oijjk?nN^^`00onM^^d3o`0000?oWK_]0onL^nh4oiflkP;oWKc_0onM_Nl3oijmk`03oijnkonO
_^koWkk^00?oWkk^0_nP_nh00onQ_nkoXKk^oj6nkP03oj:okP03oj?0kOnT_ngoY;o]00;oYKo/0_nV
_n`2ojJnj`;oYko[00CoZ;o[ojRnjOnX_^WoZ;kY0_nY_^T01?nZ_nWoZKgXojVmj?n[_^P5oj^mi`;o
[;gV1?n]_NH3ojfmi@;o[[gU00?o[kgTo`000?n__N@00on__N@7ok2ni003ok6ni?na_nCo/KoT00;o
/KoT0_nb_n@3ok;0i004ok;1i?ooooooooooo`0001Wooooo0009ooooo`0400000?oooooooooooooo
oc800000N`0I6AT4ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04oooool6ojJk
j0;oYK_X0onU^nT5ojBjj@?oXk[Y00?oX[[Zoj>jj_nR^^X00onR^^X2oj6jjP03oj2jjonQ^^_oXK[[
00;oX;[[1_nO^^`01?nN^^co0000o`000?l00006oifkk@?oWK_^2?nM_>h2oifmk`03oijmkonN_Nko
W[g^00CoWkk^0_nP_Nh3oj6nkP;oX[k]0onS_^d00onT_ngoY;g[ojFnj`03ojFnj`03ojJnjonV_N[o
YkgY00;oYkgY0_nX_^T00onX_>SoZKgXojVmj002ojVmj003ojZlion[_NOoZkgW00?oZkgW0_n[_>H2
ojbmiP;o[KgV0_n]_>D00on]_NGo[KcUojjmi@02ojjmi@03ojnmi?l0003o[kgT00?o[kgT1_n`_^@4
ok6oi0;o/[oT0onb`>@3ok;1i0;ooooo00?o0000ooooooooool05_ooool000Wooooo00@00000oooo
oooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`CoY[_X00?oYK_XojFkjOnU^nT01?nU^nT3ojBkj@;oY;[Y0onS^^T2oj>jjP?oX[[Z0onQ^^X2
oj6jj`?oX;[[0onO^^`3o`0000;oW[[/0_nN^^d01?nM^ngoW[_]oijkkOnN^nd2oifkk@03oifkk_nN
^ngoWKc^00KoWKc^0_nN_>h3oijmkPGoWkg^00?oX;g^oj2mkOnQ_Nd00_nQ_Nd3oj:nk@03oj>nkOnS
_NcoXkg/00;oY;g[0_nU_^/2ojFljP;oY[gZ00?oYkgYojNlj?nW_>P00onX_>P00onY_NSoZK_WojVk
i`02ojZli`;oZkgW0_n[^nH00on[_>KoZk_Uojbli@02ojbli@Ko[KcU00Go[[gUojjli?n^_>Co[kgT
o`000004ojnmi0Ko/;kT0ona_n@00onb_nCo//3Uok;0i002ok;0i0;o//7T0_nc`ND2ooooo`03o`00
0?oooooooooo01Gooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`030000
0?oooooooooo01;ooooo00?o0000ooooooooool05_ooool3ojJkj0;oYK_X1_nU^nT2ojBkj@?oY;[Y
0onS^^T3oj>jjP;oX[[Z00?oXK[Zoj:jj_nR^^X00_nQ^^/2oj2jj`?o000000CoX;[[oinjk?nO^^co
W[[/0_nO^^`3oijkk0OoW[_]00CoWKc^oijlkOnN_>goW[c]0onN_>h01?nN_>goWkc^oinlk_nO_>h4
oinmkP;oX;c]0_nP_Nd00onQ_NgoXKc/oj6lk003oj:lk003oj>mk?nS^n[oY;cZ00;oY;cZ0_nU_>X0
1_nU^^SoY[_XojJkj?nV^nSoYkcXojNjiPCoZ;_W00?oZK_WojVjiOnZ^nH00_nZ^nH2oj^kiP06oj^j
i?n[^nGoZk_Uoj^kiOn/_>Go[;_T1On]_>D2ojfli0;o[[cT0_n__N@00ol0003o[kgTojnmi002ojnn
i0Co/;kT0ona_n@01Ona`>Go//3Uok;0iOnb`>Go//3T00;o//7U0_nc`ND2ok?2i@03ooooool0003o
oooo01Kooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oooooo
oooo01;ooooo00?o0000ooooooooool05oooool3ojJkj0SoYK_Y0_nT^nT01?nT^^WoY;_YojBkjOnT
^nT2oj>jj@;oXk[Z1_nR^^X3o`0000GoX;[[0onO^^`5oinkk0OoW[_]0_nN_>d00onN^ngoW[c]oijl
k@03oijlk@03oinlk_nO_>goWkc]00?oWkc]00?oX;c]oj2kk?nQ_>`01OnQ_>`00onR_>coX[_Zoj:k
jP02oj>kjP04ojBlj_nT^^SoY;[XojBjj0;oYK[X00?oY[_XojJii_nW^^H00_nW^^H2ojRki`06ojRi
iOnY^^GoZK[UojVjiOnZ^nKoZ[WT1?n[^^@00on[^nGo[;[Tojbji002ojbki0;o[KcU0_n]^n@00on]
_>Co[[cTojjli002ojjli005ojnmi?l0003o[kgTojnmi?n__^@01?n`_^@2ok6oi005ok6oiOna`>Go
/L3Uok70iOnb`>D00onb`ND2ok;2i@;o/l;U00Co/l?Voooooooooooo00005_ooool000Wooooo00@0
0000oooooooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0Iooooo`;oY[_X2?nU^nT5ojBkj@?oXk_Y0_nS^^X2oj:jjP?o000000?oX[[Zoj6jjonQ^^/0
0onQ^^/00onP^^_oX;_[oj2kk003oj2kk0CoWk_/0onO^nd00onN^ngoWk_]oinkk@03oinkk@;oW[_]
00?oW[c]oinkkOnO_>d01?nO_>d00onO^ncoX;_/oj2kk003oj2kk004oj6lk?nQ^^_oXK[[oj6jj`;o
X[[[00?oX[_Zoj>ij?nT^NP00_nT^NP2ojBjj004ojFgi_nV^>KoY[SVojJhiP;oY[WV00CoYk[VojRh
i?nX^>CoZ;ST0_nX^ND00onY^^GoZ[SSojZhh`02ojZii0;oZk[T0_n/^N<00on/^^Co[KWRojfjh`02
ojfjh`;o[K_T00?o[[_Sojjli?n^_>@00_n^_>@2ojnli003ojnmi?l0003o[kgT00Co/;kT0_n`_nD0
0ona_nGo/L3Uok70i@03ok70i@?o//7U00?o//;Uok;2i_nc`nH00_nc`nH3ooooo`03o`000?oooooo
oooo01?ooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oooooo
oooo01;ooooo00?o0000ooooooooool06Oooool3ojJkj@SoYK_Y1OnT^nT01?nS^nWoXk_Zoj>kj_nS
^nX2o`000003oj:jj_nR^n[oX[[[00;oX[[[0onQ^^/2oj6kj`;oX;_[0onP^n`5oinkk003oinkkOnO
^ncoWk_/00[oWk_]00?oWkc]oinkk?nO^n`00onO^n`00onP^ncoX;[[oj6jj`04oj6jj`04oj6hjOnR
^>WoX[SYoj:hj@;oXkWX00?oY;WXojBgi_nU]nH00onU]nH00onV^>KoY[GSojNfi002ojNfi0;oZ;ST
00KoZKCQojVfh_nY]^;oZKKRojZhhon[]N44oj^ghP03ojbihon/]n7o[KWR00;o[KWR00?o[K[Sojji
h_n^^N800on^^n<00on^_>Co[[_Sojjkh`02ojnli0;o[kgT00?o0000ojnmi?n`_^@00_n`_^@2ok2o
i@Go/L3U0_na`ND00onb`NGo//;Vok;2iP02ok;2iP?o/l?V0_ooool00ol0003oooooooooo`0Coooo
o`002Oooool01000003ooooooooooooooolb000007/06ATI1?ooool00`00003oooooooooo`0Boooo
o`03o`000?oooooooooo01[ooooo1?nV^nT7ojFkj@GoY;_Y0ol00003oj>kjP;oX[_Z00?oX[[[oj:k
jonR^n/02?nQ^n/2oj2kk003oinkk?nP^ncoX;_/00SoWk_/0onO^nd6oinkk004oinjk?nO^^_oWk[[
oinjj`;oX;[[00?oXK[[oj6hjOnQ^>T00onQ^>T00onR^>WoX[KVoj>fiP02oj>fiP;oY;OV0_nU]nH2
ojFdh`;oY[GS00?oYkKTojRch?nY]>400onY]>400onY]^;oZ[?Ooj^eh@02oj^eh@;oZkOR00Go[;GO
ojbghOn/]n7o[;OQojfihP02ojjhh@03ojjih_n_^N7o[[[R00?o[[[R00?o[[_Sojnkhon__>@00_n_
_>@2ojnmi003o`000?n`_^Co/;kT00Co/;oU00?o/L3Uok71iOna`ND00_na`ND5ok;2iP?o/l?V0_nc
a>L2ooooo`03o`000?oooooooooo01;ooooo0009ooooo`0400000?oooooooooooooooc800000N`0I
6AT4ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool2ojJkj@SoYK_Y00Co
Y;_Yo`000?l0003o00000_nT^nT4oj>kjP?oX[_Z1_nR^n/5oj6kj`SoX;_/2?nO^n`7oinjk003oinj
jonO^>[oX;SY00;oX;SY0_nQ^>T01?nQ]NOoXKGVoj6ei_nQ]NH2oj:fiP03oj>fi_nS/^?oY;?S00?o
Y;?S00?oYKCSojJ`gonW/Ml00_nW/Ml2ojRch0;oZKCQ00GoZ[7MojZcgonZ/mooZ[?Ooj^eh@02ojbc
g@?o[;GO00Go[;OQojjfg_n^]]ko[[SQojnfgP03ojnih@;o[[[R00Go/;[Qojnkhon_^n?o[k_Sojnl
i002ok2mh`03ok2ni?l0003o/;kT00Co/;oU0_na`>D00ona`NGo/L7Vok;2iP04ok;2iP;o//?V00Go
/l?Vok?4ionca>Oo/lCWok?5i`02ooooo`03o`000?oooooooooo01;ooooo0009ooooo`0400000?oo
oooooooooooooc800000N`0I6AT4ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool0
7Oooool2ojJkj@GoYK_Y0ol00004ojBkj@03ojBkj_nS^n[oXk_Z00?oXk_Z00?oX[_Zoj>kj_nS^nX0
1OnR^n/5oj6kj`?oXK_/2?nP^n`2oinkk0OoWk[/00CoWkW[oinij_nO^N[oWkWZ0_nO^>X00onP^>Wo
X;KXoj2fj003oj6ei`03oj6ei_nQ/N?oX[7S00;oX[7S0_nS/^<2ojBch`06ojF^g_nV/=ooY[3OojJ`
gonW/MooZ:gK1?nY[m`2ojZag@05ojZcgon//=_o[;3KojbcgOn^/=T01?n^/m`00on^]]ko[kCLojnf
gP02ojnfgP03ojnihOn`^=oo/;SO00?o/;[Q00Go[k_Sok2kh_n`^n;o/;gSok6mh`02ok2ni003o`00
0?n`_^Co/;oU00;o/KoU00?o/L3Uok71i_na`NH00_na`NH2ok;2iP?o//?V0_nba>L00onca>Oo/lGW
ok?5i`02ok?5i`;ooooo00?o0000ooooooooool04Oooool000Wooooo00@00000oooooooooooooooo
<P00001k01TI6@Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`CoYK_Y
0ol00004ojFkj@?oY;_Y0_nT^nX8oj>kjPGoX[_[1OnQ^n/4oj6kk0OoX;_/0_nO^n`00onO^^coWk[[
oinjj`05oinij`03oinij_nO]nWoWkOY00;oWkKX00?oX;KXoinbiOnO/^D00_nQ/N@3oj6ah`03oj:a
honR[MkoY:gN00?oY:gN0_nU[]h00onV/=ooYj_JojR]f`02ojR]f`;oZJoL00KoZZ[Goj^]fOn[[MWo
ZjgIojb`fon][ML3ojj`f@;o[[?L00Go/;3Iojndg?n_]=co[kCLojnfgP02ok6eg003ok2hgonb]mgo
/K[P00?o/K[P00?o/;_Rok:khOnb^n400_na_N<2ok2ni003o`000?na_nGo/KoU00;o/L3U00?o/L7V
ok;2i_nb`^H00_nb`^H00onb`nKo//CWok;4i`02ok;4i`;o//GX00?o/lGWok?6j?nca^P00_nca^P2
ooooo`03o`000?oooooooooo013ooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4
ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool07oooool3o`0000SoYK_Y0_nT^nT3
ojBkjPSoXk_Z1OnR^n/00onQ^n_oX[_[oj6kj`03oj6kj`GoXK_/0onP^n`01?nP^^coWk[/oinjk?nO
^^`3oinjj`03oinijonO^>[oWkSZ00?oWkOY00CoW[CWoinci_nO/nKoWk?V0onO/^D2oj6ai003oj6a
honQ[=ooXZgN00;oXZgN0_nT[Mh00onTYmWoYJWIojFYf@03ojN[fP03ojR]fonYZ=GoZZ[G00?oZZ[G
00?oZjgIojfYe?n][ML00_n][ML00on^/=Wo/:gEok2`f@03ok2`f@05ojndg?na/]So/K;Hok6eg?nc
]=T00onb]md2ok6jh0;o/kWN00?o/[_Qok>lh?nb_N800_nb_N800ona_nCo/[oTo`000002ok70i@03
ok;1iOnb`^Ko//;V00;o//;V0_nb`nL00onba>Oo//GXok;5j002ok;5j0Go/lKX0_ncanT00ooooooo
0000ooooo`0Aooooo`002Oooool01000003ooooooooooooooolb000007/06ATI1?ooool00`00003o
ooooooooo`0Aooooo`03o`000?oooooooooo01cooooo0ol00002ooooo`03ojFkjOnU_>WoYK_Y00Go
YK_Y1?nT^nT4ojBkjPGoXk_Z0_nS^n/7oj:kj`CoXK_[1?nQ^n`3oj2kk0;oX;[/00?oWk[/oinijonO
^N/00onO^N/00onO^>[oW[KYoijej002oijej0;oW[CW00?oWk?Voij^honN[^<00_nO[N83oj2]h0;o
XJcO00?oXZgNoj:WfOnTYmT00onTYmT2ojFYf@03ojN[f_nWYMCoZJSE00;oZJSE0_nZZ]L01_n/Y]7o
[JWDojfYe?n]ZMCo[JgGojnYd@?o/:gE0_n`/=T01?nb[]Co/K;Hok6bf?na/]P3ok>df@03ok:ggOnd
]m_o];OK00?o/kWN0onc_>001Onb_N;o/kkRok>nh_nb_nCo000000Co//7U00Co//;Vok;3i_nb`nKo
//?W0_nba>L2ok;5j0Go/lKX1OncanT00ooooooo0000ooooo`0@ooooo`002Oooool01000003ooooo
oooooooooolb000007/06ATI1?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Wo
oooo0ol00006ooooo`;oYKcY00?oYK_YojFljOnU_>T00_nU^nT3ojBkj@GoY;_Z1OnS^nX3oj>kj`So
X[_[0_nQ^n/5oj6kk003oj2kk?nP^^_oX;[[00?oWk[[00?oWkW[oijhjonN]nX00_nN]nX2oijfj@03
oijej?nM/NKoWK3T00;oWK3T0onN[^<2oin]hP04oj2]h?nOYm_oXJKJoj6VfP?oXZOI0_nTYmT00onT
XM?oYZ?CojJSd`03ojNUe003ojVXeOnZX/ooZZ;?00?o[:KA00?o[JWDojjUc_n_ZM400_n_ZM400on`
[MGo/Z[@ok:Zd003ok:^e005ok6bf?nd/=Go];3Eok>dfOnf/mH01?nd]m/01?nc^Mko]K[MokFjgOnc
_>02okFlg`05ok>nh_ne_n;o/l3Tok?0i?l000000_nb`ND2ok?2i@04ok;3i_nca>Oo/lCWok;4i`;o
/lGX0_nbaNP00onca^So/lOYok?7j@05ok?7j@04ok?8jP0000000000o`00013ooooo0009ooooo`04
00000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oooooooooo017ooooo00?o0000oooo
ooooool05_ooool3o`0000Wooooo2OnU_>T2ojBkj@GoY;_Z1OnS^nX4oj>kj`OoX[_[0_nQ^n/3oj6k
k0;oX;_/00?oX;[[oinjjonO^^/00onO^N/2oijhj`03oijgj_nM]NWoWK?W00;oWK?W0_nM/NH3oif`
i003oij^honLZMooWJOM00;oWJOM0_nOYm/2oj6VfP03oj:WfOnRX=?oXZ3C00?oY:7C0_nVXm<00onW
YMCoZ9o=ojZRc`03ojZRc`03ojbVdOn]XL_o[ZG>00;o[ZG>00?o[jWAok6Vc?nbZ]000onbZ]001Onb
[]Co]:c@okB/d?nd/=Go]joA00?o][?F0_nd]m/2okNgf@05okFjgOng^]_o]k[KokFlgong_Mh00one
_n800onc`>Co]<;To`000002ok?2i@03okC3i_nca>Oo/lCW00;o/lGW00?o/lGXok?6jOnba^T00_nb
a^T01?ncanWo/lOZok?7j_ncanT3ok?8jP;o/lW[00?oooooo`000?ooool03oooool000Wooooo00@0
0000oooooooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`;o00003Oooool9ojFlj@;oY;cZ00?oY;_ZojBlj_nT_>X00_nT_>X00onS^n[oY;cZ
ojBljP03oj>lj`03oj>kjonS_>_oX[c[00;oX[c[1OnR^n/2oj6kj`?oXK_/0onP^^/2oinjj`03oini
jonN^>[oWKKY00;oWKKY0_nM]NT00onM/nOoVjoUoi^]h`02oi^]h`?oW:_Q0_nLZMl01?nMYmgoW:7H
oifPe_nMX=H2oinOe0CoXZ3C00CoY:7CojBKc?nVWLcoYYg<0onXWld2ojZRc`06oj^MbOn]XL_o[J7;
ojfQbon^YLko/:780onaY/`2ok:Zd004okBWc?nd[=3o]:c@okB/d0?o]joA00?o][?FokVcdoni/m<0
0_ng]mT01?nj]mOo]k[KokNjfong^]/3okNmgP07okFoh_ng`>7o]l3QokC2i?nf`nCo0000okC3iP02
okC5iP;o/lGW00Go]<KXok?6jOnca^Wo/lKYok;6j@03ok?7jP;o//SZ00Co/lSZok;9jonbbN_o/lW[
0_nbbN/00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooooooooolb000007/06ATI
1?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol0000Aooooo`KoYKcY
00?oYKcZojBlj_nT_>X02OnT_>X5oj>lj`GoX[c[00?oX[_[oj:ljonQ^n`01OnQ^n`00onP^^_oWk[[
oinjj`02oinij`;oW[SZ00?oWKKYoibdjOnK/NL00_nK/NL2oi^_i@?oVjgS00CoW:_QoiVTgOnJX][o
VZ;J0onLXMP2oifPeP;oWioD0_nRX=<01?nQVLgoY9_<ojBKc?nTVl`2ojJMc003ojROcOnYV/OoZig9
00?oZig900?o[J7;ojnMaOn`XLP00_n`XLP00onaY/co]:?7okBWc003okBWc005okB/d?nhZlco^:_<
okN_dOnj[/h00oni/m<4okZge`04okNjfonj^m[o^[_JokNmgP;o^KkN00So]l3QokS2hOnh`^7o]/?T
o`000?nga>Co]<GVokG6i`Co]<KX00Co/lKYok?8jOncb>Wo/lOZ0_ncb>X01?nbb>[o//W[ok;9jonb
bN/2ok;:j`03ok;9jonbb^co0000013ooooo0009ooooo`0400000?oooooooooooooooc800000N`0I
6AT4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0001Gooooo1OnU
_>T2ojFljPWoY;cZ0_nT_>/5oj>lj`OoX[c[1?nQ^n`2oj2kk003oinjjonN^N_oW[S[00;oW[S[0_nM
]^X2oibdj@03oi^aionI[NGoV:[S00;oV:[S0onHYn02oiVTg@;oVZ;J0_nLXMP00onMX=KoW9S@oijH
cP02oijHcP?oXIW=0_nTVl`00onVWLcoYYO6ojVJa`02ojVJa`;oZig900Co[9W3ojnMaOn_WLGo[ig5
0_n`XLP3okBSa`;o]:O<00Co]jK7okR[c?nhZlco^:_<0onj[/h00oni/m?o_;?Aokbcd@02okZge`03
okfhe?nj^m[o^[_J00;o_KcI00Co^KkNokc0gOnl`=go^<;Q0_nja>400onga>Co0000okG6i`02okG6
i`;o]<KX00Co]<SYok?8jOncb>Wo/lWZ0_ncb>X3ok;9j`;o//[/00?o//[[ok;;k?nbbn`00_nbb^`0
0ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolb000007/06ATI1?ooool0
0`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`?oYKcY1OnU_>X6
ojBljPCoY;c[1OnS_>/6oj:lj`;oXKc/00?oXK_/oj2kk?nO^^`00_nO^^`2oijij`03oijhjonL]^[o
Vk?Y00;oVk?Y0_nJ/NL2oiV]i@?oV:[S00CoV:OPoiFQg?nFWMWoUYgI0_nGVmD2oiVIdP?oW9S@0onN
V<h2oj6Ic@03ojBKc?nSU<GoYYO600;oYYO60_nYV/L01?n[WLWo[9W3ojbI`on/VL<2ojnMa@03ok2Q
b?nbW/?o/Yk300;o]:?71?ngY/L01?nhZlco^jW8ok^Yb?nj[/h2okf^b`03okbcdOno/lko_KSD00;o
_KSD0onm_=T01?o0_]So_<3Mokc0gOnl`=d3ok[4h@;o^<KU00Go0000okG6ionfb>So]/SXokC8j@02
okC9j@03ok?9j_ncb^_o/l[[00;o//W[00?o//_/ok;:k?nbb^`00onbbn`3ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool3o`0001gooooo2?nU_>X5ojBljPGoY;c[1_nS_>/3
oj:lj`04oj:lk?nQ^ncoXK_/oj6kk0;oX;_/00?oWk[/oijik?nN^N`00_nM^>/2oibfjP03oi^cjOnH
/>SoUZgV00;oUZgV0onEZ><2oiBTh0;oUJ7L0_nFWMT2oiNKe@;oVIWB0_nLV=02oijHcP03oifAaonP
T/KoX9;600?oXiC50_nVUlH00onYV/OoZYG1ojZE`@03ojbI``03ojnMaOn`V/3o/Yk300;o/Yk300?o
]:?7okNQ`_ngXL800ongY/L3ok^Yb0?o_Jk;0ono/lh01?nm^=Co`;WCol2idonm_=T3ol2nf004okc0
gOnn`]go_/;Mok[4h@;o_<KR00Co^<KUo`000?nib>Go]/SX0_ngbNP01?ndbNWo]<_[okC;joncb^/2
ok?;k004ok;;k?nbbngo//_]ok;;k0Kooooo00?o0000ooooooooool03Oooool000Wooooo00@00000
oooooooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool04?ooool00ol0003ooooooooo
o`06ooooo`?o00008Oooool8ojFljP?oY;cZ2?nT_>/4oj>lj`GoX[c/0onQ^n`2oj2kk003oijik?nM
^>coVkK[00;oVkK[0_nJ/nX2oiR`j0?oUZgV00CoUJSSoi2RhOn@WMgoT9gM0_n@VMP2oi6Fe0;oTi?@
0_nFTL`3oiVAb@?oWI770_nPT/H01?nSU<GoXhnoojJB`?nVT/04ojZE`@03ojbI`on^UKgo/9[000;o
/9[000?o/Yk3okFL__ngXL800ongXL801?ngY/Oo^ZC3okZT`onkZLP2okjYa@04okf^boo1[lSo`Jo8
oknccP;o`kG<00?o`;WColBkd_o4^m800_o0_]P2ol?0f004okk2gOo1aMgo`LGMokc6hP;o_LSR00Co
^LSUo`000?njb^Ko]lWX0_ngbnT01?ndbn_o]<c[okC<joncbn`2ok?<k@03ok;;kOoooooooooo00Ko
oooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo<P00001k01TI6@Co
oooo00<00000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`?o00009Oooool8ojFljP;o
Y;cZ00?oY;c[ojBmjonT_N/01?nT_>/01?nT_N_oXkg[oj>mjonS_N/2oj>lj`?oX[c/0_nQ_>`00onQ
^ncoX;_/oj2kk002oinjk0;oWKS/00?oVkK[oiVdjonF/NT00onF/NT2oiB/i`;oTZOT0_n@X^42oi2M
g@;oT9WH0_nAU]@2oi>Cd0;oUY7<0onITLT2oifAa`04oj2Ba_nOSL3oXhnooj>?_`?oYY;00_nZUL40
1?n[TK_o[YFmojjE_On^UKd2ok2J`0?o]Ibn0_ngXL801?niWkko^ZC3okZT`onjY<<3okjYa@?o`Jo8
0oo3]L`3olBkdP03olNmdOo3`=So`l3H00;oa/?H00Co`LGMol?8g_o3b=ko_LSR0_nobn<01?njb^Ko
0000ok_<iongbnT2okO=jP04okC<jondcNco]<g/ok?<k@[ooooo00?o0000ooooooooool03Oooool0
00Wooooo00@00000oooooooooooooooo<P00001k01TI6@Cooooo00<00000ooooooooool03oooool0
1?l0003oooooooooooooool3o`0002Wooooo00?oYKcZojFmj_nU_NX00_nU_NX00onU_>[oYKgZojFm
jP05ojBmj`03ojBljonT_N_oY;g[00;oY;g[0onS_N/2oj>mk0?oX[c/0_nQ_>`00onP^ncoWk_/oifi
k002oifik0;oVkO/0_nI]>/2oiJaj@03oi:]jOn?Z>KoSjSV00;oS:;S0_n:Vmh2ohVFfP;oRY7D0_n<
SLl2oi>Cd003oiJAc?nCR/OoUh[400;oUh[40_nKRl83oin=`0;oXhno0_nVT/001?nZUL7oZi6koj^A
^on[TK/2ojjE_@03ok2J`?nbUk_o/YNk00;o]Ibn1?niWkh01?njY<?o_ZBookjT_onnZLD2ol:Z`P04
ol6_b?o5/<KoaK36ol>ec0;oakO;00?oa;_BolNmdOo7_M400oo6`mP01?o9amSo`lSNol?8g_o5bml2
oko;h`;o`<gT00Co^lcWo`000?nkc^Wo]lgZ0_ngc^`00ondcNcoooooooooo`0:ooooo`03o`000?oo
oooooooo00gooooo0009ooooo`0400000?oooooooooooooooc800000N`0I6AT4ooooo`0300000?oo
oooooooo00oooooo1?l0000^ooooo`OoYKgZ2_nT_N/00onS_N_oXkg/oj>mk002oj>mk0;oX[c/0onQ
_>`2oinkk003oifik?nL^>coW;S/00?oVKK/0_nF/^/2oi:]j@;oSjSV0_n<X^<2ohZKgP;oRIKJ0_n:
TM@00on<SLooSh_;ohn;b`03oi>:a`?oUh[40_nKRl82oin=`0;oXhno00?oYY;0ojN>^on[TK/00on[
TK/00on^UKgo/9>iok:G^`02ok:G^`03okFL__nhVk[o^9^j00;o^Inn00Co_InkokjT_onnY;oo_ZBo
0oo2Z/83olF`aP?oakO;00Gobk[:olNmdOo;`M7obl7AolK3f002olW7f0?oaL_O00OoaloPol3=i?o0
cNCo`M3Vok_>jOl0003o^m3Z00;o]lk/3_ooool00ol0003oooooooooo`0=ooooo`002Oooool01000
003ooooooooooooooolb000007/06ATI1?ooool00`00003oooooooooo`0?ooooo`03o`000000003o
oooo033ooooo1OnU_NX2ojFmj`[oY;g[0_nS_N`3oj:mk0;oX[c/00CoXKc/oj2kk?nP^ncoX;_/0_nN
^^`2oibhk004oiVfk?nF]>coTJo[oi6_j`;oSJWY0_n8X^D2ohBKh@;oPYCL0_n1S]H2ohZAe0;oS8g?
0_n?Rl/3oi>:a`;oUh[40_nKRl801?nOSL3oWXRkoj>;^_nSRkX3ojN>^`?oZi6k0on`TkT2ok:G^`?o
^9^j00Go^InnokfO^onmWk_o_InkokjT_`02ol:U_0;o`Z[200GoaZboolF`a_o9/lCobK?4olNgb`02
ol^jbP?obl7A00GoclGAolW7f?o<bmWoc<_IolG;g`02olO?h006olSBh_o1d>Ko`M?Xol7Cj?nkd>[o
00004Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolb000007/0
6ATI1?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo02oooooo0onU_NX4ojFmj`03
ojBmjonU_N_oY;g[00CoY;g[1OnS_N`4oj:mk0;oXKc/00?oX;_/oinkkOnL^^d00_nL^^d2oiVgk@;o
U[C/0_nA[n/2ohfYj@;oR:;U0_n4Vn42oh:Dg003oh6>e_n3R=7oPhSA00;oQXG;0_n:PlH3ohn3`P;o
U8Bo0_nIQKd2oij8^`?oXh^j0onWS[/00on[TK_o[8ngok2C^@02ok2C^@03ok:G^oneU[Oo]IJg00;o
^9^j1?nmWk/3ol:U_003ol:Z`_o6[;ooaZbo00?obK?40oo;^/X01_o?_/Wobl7Aolo5dOo?aM7od/[B
olc;f@;oc]3K00GoaloPolSBh_o8d^;ob=KTol7Cj003ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo<P00001k01TI6@Cooooo00<0
0000ooooooooool04_ooool00`00003oooooooooo`0^ooooo`?oYKgZ1onU_N/5ojBmj`KoXkg/0onR
_N`2oj6lk@;oWk_]00?oW;[]oi^ikOnK^Nd00_nG]^d2oi:bk@;oS:c[0_n5YNT2ognLi@03ogZCh?mg
Rm[oMh_J00;oMhGC0_n3R=42ohJ5b`;oRX?60_n?Pl82oiB4_`?oVHFm0_nNR;/2oj>;^P;oYhjk00Co
Z8^fojb?]on/SkOo[8ng0_n`TkT3okFF]`03okRK^_nkV[Oo^iZg00?o_Ink00?o`:2hol:U_?o2YK`0
0oo6[;l01Oo:[[kobK?4oljf`oo>]/?obk[:00;ockk900Koe<?:olo5dOoBb];od/[BomK@e?o>d=/2
om3Dg@03olSBh_o8e^Cooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`002Oooool01000003ooooooooooooooolb000007/06ATI1?ooool00`00003oooooooooo`0C
ooooo`0300000?oooooooooo02kooooo00?oYKgZojFmjonU_N/02?nU_N/00onT_N_oY;k[ojBnj`02
ojBmk003oj>mk?nS_^coXkk/00;oXkg/00?oX[g/oj6mkOnP_>d00_nP_>d2oijkk@03oi^ikOnH^>ko
TkC^00;oTkC^0_n=[nd2ohFXk003ogbOjOmdUNCoM9GT00;oKX_O0_mgRmX00omgQM?oNX3=ogZ0c@02
ogima`?oRX?60_n?Pl82oiB4_`;oVHFm0_nNR;/00onSRk[oXhNfojR;]P03ojR;]P;o[8ng00?o/9>i
ok:A]OnbTKD00_neU[L4ok^J]`04okfO^oo0X;So`:2hol:U_0;oaZNj00?oaZboolZ^__o:[[h00oo>
]/<01_oB^l?ockk9omC3b_oD`l[of<W;om;:dP;oe]3D00Cof=KFom3DgOoAfMoodMWO1oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
oc800000N`0I6AT4ooooo`0300000?oooooooooo01Cooooo0P00000`ooooo`KoYKg[1?nU_^/3ojBn
j`;oY;k/0onS_^`2oj>mk0;oXKg]00?oX;c]oinlkOnO_>d00_nL^nh2oiRhkP04oi>dk_n?/nooQjg^
ohN]kP;oO:C]0_maV^T2ogBEi003ofj;gomZP]SoJX;H00;oMhGC0_mjP<d01?mnOLOoQ7c3ohAl`on4
O<<2ohYm_P;oU8Bo00CoVHFmoiN1^OnMQ;OoWHBg0onSQkH3ojR;]P03ojb?]on^SKCo/Y6e00;o/Y6e
00?o]IJgokRF]?nhU[@00_nkV[L01?nnVkCo`:2hol2P^?o0X;P3olJW^P?obZjn00Cock:moljf`ooB
^l?od[_30ooD`lX00ooHbL_og=3<omK@e002omSFeP03om[MfOoAfMoooooo00Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolb0000
07/06ATI1?ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo02kooooo00?oYKg[ojFn
jonU_^/01onU_^/00onT_^_oY;k/ojBnk002ojBnk0;oXkk/0onR_^`2oj6mk@03oinlkOnN_>koW[c^
00;oVk[^0_nF]nl2ohnck`;oQjg^0_mlY>d2og6Jj@04ofJ=i?mMPMgoGH7MofZ2f0;oJg_A0_m^Ml/2
ogima`;oQ7c30_n:OKh2oi5n^`;oUh6i0_nMQ;L3oj>7]P?oZ8^f0_n^SK@3ok:A]@?o^9Jd00Co^iZg
okjK]?nnVkCo_Y^d0_o0X;P01Oo4X[KoaZNjolJW^_o:Z[WobZjn00;ock:m0ooB^l<01ooH`<?oe<?:
omS9booHbL_og=3<on3HcooHe]H00_oJgMT;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool000Wooooo00@00000oooooooooooooooo<P00001k01TI6@Cooooo00<00000oooo
ooooool05oooool00`00003oooooooooo`0^ooooo`[oYKk[1OnT_^`2oj>nk003oj:nk?nR_^goX[k]
00;oXKg]00?oW[c^oiflk_nM_>h00_nI^^l2oi>gk`;oRk;`0_n0Z^l2og:Pk@04of>CjOmDQ>?oE8CS
oef1g@;oFGOF0_m[Nm400om^Ml_oMGG5ogEea@03ohAl``;oRWfn00CoTGjkoiN1^OnGPKWoUh6i0_nM
Q;L3oj>7]P03ojR;]_nYRK?o[Xfd00;o[Xfd0_nbTKD3okRF]0Co_Y^d00Co`:2holBR]_o4X[KoaZNj
0_o:Z[T3olnb_@06omBg_?oB^l?of<33omS0`ooMalCof<W;0_oLd<`00ooPf<ooh]oAom[Mf@0=oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooo
oooooooo<@00000[01TI6AH00000>`0I6AT4ooooo`0300000?oooooooooo01Sooooo00<00000oooo
ooooool0;_ooool8ojFnj`;oYKk/1OnT_^`2oj>nk0?oX[k]0_nP_Nd00onM_>koW;c_oiRjk`02oiRj
k`;oT;K`0_n6/?42ogRXl@04ofJKk_mBRnWoDX_YoeB4h`;oB7KK00?oFGOFoeY`comJL<l00_m^Ml/0
1?meMLGoOGG0ogee`?mmML02ohYm_P;oTGjk0_nGPKT2oif4]`;oXhNf00CoXhFcojV9/onYRK?oZHVc
0_n^SK@00onbTKGo]96bokBA/P02okRF]004ok^G/_nnVkCo_Y^dokjK]0?oa::f0oo:Z[T01_o?[[So
ck:momBg_?oD]kcof[flomS0``;ogLO400Goh/o5omc@c?oPf<ooh=S?on;Od@0>ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo<@00
000X01TI6@<000005P0c<c<2000003T06ATI1?ooool00`00003oooooooooo`0Iooooo`800000;ooo
ool7ojFnj`CoYKk/1OnT_^`00onS_^coX[k]oj:nk@02oj:nk@04oinmk_nL_>ooW;c_oiRjk`?oU[[`
00CoS[Kaoh6_l_n1[o;oL:Gb0_mIUnl01?mBRnWo?GWQoceihOm8M]/2od9Zd`03oeY`comPK<SoH6c8
00;oMGG50_mmML02ohEg_0;oSWZi00CoUh6ioiIm]_nMPKCoWH6d0onSQK<3ojV9/`03ojj=]?n`SK7o
]96b00;o]96b00?o^9Jdok^G/_nkUk800onnVk@01Oo2WK?oa::folBR]_o9YKCobZZi00;ocjjh0ooD
]k`02?oJ_KcogLO4omg7a?oMalCoh/o5onOHaooPf<ooh]oA4?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooc00000000?o000001TI
6@0I6AT08P0I6AT4000001/0<c<c1000000e01TI6@Cooooo00<00000ooooooooool06oooool00`00
003oooooooooo`0^ooooo`;oY[k[1OnU_^/5ojFnk0?oY;k/0_nS_^d3oj:nk@;oWkg^0_nK_>l00onF
^_3oU;[aoiBjl@02oh^flP;oOJoc0_mIUnl02?lmP^So?GWQobaWf?l/ImSo@V[CodASc?mJL<ooH6c8
0omYK<<00ommML3oQGNlohEg_002ohij^@;oUWff0onMPK@3oj>5/`;oZHVc0on`SK42okBA/PCo^iNb
00Co_Y^dol:M/oo2WK?oa::f0_o9YK@3oln^^006omFc]ooD]kcof[flomZm_?oPaKgogLO40_oRclD0
0ooWf<Ooj^;9ooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
00Wooooo00@00000oooooooooooooooo<@00000Q01TI6@<000008`0c<c<00`0000006ATI01TI6@0b
01TI6@Cooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0^ooooo`;oY[k[00?oYKk[
ojJnjonV_^/00_nU_^/00onU_^coYKo/ojFok002ojFok003ojBnk?nT_ncoY;o/00;oXkk]00?oX[k]
oj6nkOnQ_^d00_nO_Nh2oi^lk`03oiBjlOnC^_;oTk[b00;oRKKc0_mh[_D01?mOX_CoBi7_od^AkolQ
Jm`2obaWf004od9Zdom4HlcoH6c8of1/b0;oJFc300GoM6jnogee`?n5MkcoQGNlohij^@03oiIm]P;o
WH6d0onSQK<00onYRK?oZXRaok2=/@02ok2=/@03okBA/_ngT[3o]i:`00?o^iNb0oo2WK<3olVU]004
olnZ]?o?[[SoeK>gomFc]`;of[fl0_oPaKd01OoVckkoh/o5onOHaooWf<Ooj^;901?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooool`
000002406ATI00<0000003<c<`0c<c<09@0c<c<3000003406ATI1?ooool00`00003oooooooooo`0M
ooooo`0300000?oooooooooo02kooooo0onV_^/2ojJoj`;oYKo[1OnU_n`3ojBok0;oXko]00?oXKk]
oj6nk_nQ_^h00_nO_^l2oiZll003oi>jl_nC^o;oTk_b00;oQkKd0_me[oH01omIXOGo?8c^o`i]g_l>
KMko05[Co`UDd?m4Hl`00om<HLH00omYK<?oM6jnogA^_P02ohEg_0;oSWZi0_nFOKH3oif1]003oj>5
/onTQ;7oZXRa00;oZXRa0_n`SK43okNB/0?o^iNb00Go_iVaol:M/oo2WK?oaj6bolVU]002olnZ]005
oln^^?oE/kOoeK>gombj^?oJ_K`00_oPaKd01?oVckkok=W0onOHaooZh/TDooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo<000000N
01TI6@80000000?o000003<c<`0c<c<0:@0c<c<00`0000006ATI01TI6@0^01TI6@Cooooo00<00000
ooooooooool07_ooool2000002oooooo0_nV_^/3ojJoj`;oY[o/1OnU_n`3ojBok0;oXko]00?oXKk^
oj:ok_nR_nh00_nO_^l2oiZml0?oTk_b0_n7]oD2og>`m`07oeBQm_l^R>co3VgNo`17aOl0?L7o04?5
obIBb002odaQaP03oeUR`_mYK<?oM6jn00;oOg:j0_n:M[L2oiIm]P;oWH6d00?oW7ncojB4/OnTQ;40
0onZR;42ok2=/@Co]i:`00Co^iNboknI/OnoVK7o`Yfc0_o7XK800oo9YKCocjZdolnZ]002omFc]`;o
g;Zh00Kohl>hon35_OoVckkoi/nnoncI`?o`i<4Fooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool000Wooooo00@00000oooooooooooooooo<000000M01TI6@030000000c<c<0
<c<c02d0<c<c00?o000001TI6@0I6AT0;@0I6AT4ooooo`0300000?oooooooooo023ooooo00<00000
ooooooooool0;Oooool5ojJoj`;oY[o/1OnU_n`3ojBok0;oXko]0onR_nh2oinnk`;oV[g`00?oTk_b
oi>llonC_?<00_n7^?H2og>an008oe:Rm_lTQ^[o06;Fo`17aOl0?L7o04?5obIBb?m<HLH2oeUR`P;o
M6jn00?oOg:johYf]on:M[L00_nDNk@3oiao/`?oY8Ba0_nZR;400on`SK7o/Xj`ok:>/002okNB/004
ok^D[onoVK7o_iVaoknI/@?oaj6b0oo?Z[@01ooE/;CoeK>gombj^?oL^[Sohl>hon[>^OoVckh00_o/
fL000oo`i<7oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool000Wooooo00@00000oooooooooooooooo<000000K01TI6@800000<@0c<c<00`0000006ATI01TI
6@0/01TI6@Cooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0^ooooo`CoY[o[0_nV
_n`00onU_ncoY[o/ojJok002ojFok003ojBok?nU_ncoYKo/00;oXko]0onR_nh2oinok`;oVkka00?o
TkccoiBmlonD_O<00_n9^_H2ogFcn009oeBUmolMQ^Wo7HKYo`0d/_l09k7o03^noc5A`om<HLKoFF;2
00;oJ6Nm0_moL[X01?n:M[OoU7^doiAk]?nDNk@3oiao/`;oY8Ba00?oZXRaojb9/?nbS[000_nbS[00
1?ngT[3o^iB_ok^D[onkU:l2oknI/@05olBM/?o7XK;oaj6bolfV/Oo?Z[@00_oE/;@02?oL^;Cog;Zh
on?3^?oS`kSoj/jioo3J^_o/fL3ol>C16Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo0009ooooo`0400000?oooooooooooooooc0000006P0I6AT00`000000<c<c03<c<`0b
03<c<`030000000I6AT06ATI02/06ATI1?ooool00`00003oooooooooo`0Rooooo`0300000?oooooo
oooo02kooooo1_nV_n/3ojJok0GoYKo/0_nT_nd3oj:okP;oX;o_0_nK__000onD_O?oU[gcoiJml`02
oh^kmP;oNKKi00OoFJWioaf8j_lMR>[o02>Mo`0W/Ol0>kko<E7300;oFF;200?oJ6NmogM]^_mgKKX0
0_n:M[L2oiAk]0?oW7nc00CoY8BaojF4/On/RK3o[8V`0onbS[04ok^D[`04oknI/Oo4WK3oa9f`olNQ
/P;ocJJa0ooE/;@00ooL^;Cohl>hon?3^002on[>^@03oo3J^_odik[ooooo01Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool`0000
01P06ATI0P00000f03<c<`800000:`0I6AT4ooooo`0300000?oooooooooo02?ooooo00<00000oooo
ooooool0;_ooool7ojJoj`?oY[o/1?nU_n`2ojBok@03oj:ok_nS_nkoXko^00;oX;o_0_nL_o000onF
_O?oooooooooo`07ooooo`03o`1La?l0>kko2Sbl00;o@eK000?oJ6NmogM]^_mgKKX00_n5LkL3oiAk
]004oiao/onLOk;oYHBaojF4/@?o[8V`0_nbS[001?nfT:oo^iB_ok^D[onkU:l3olBM/0?ocJJa00Oo
djfbomF`]?oL^;Cog;RdonC2]OoS`kSoj/ji00;ol=Zj00?om>Njooooooooool06Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooc00
00005`0I6AT00`000000<c<c03<c<`0h03<c<`030000000I6AT06ATI02P06ATI1?ooool00`00003o
ooooooooo`0Tooooo`800000;oooool2ojNoj`GoY[o[1OnV_n`3ojFok003ojBokOnS_nkooooo00oo
oooo00Oo00JAo`0k__l:?;co@eK0oeQN_OmXIkgoMffj00;oQG>g0onBNK@2oiao/P?oYHBa0_n/RK00
0onbS[3o]Y2_okJ@[`03ok^D[`?oa9f`00KobJ:`olfV/OoC[K;odjfbomF`]?oL^;@2onC2]@04onc>
]_oZc[Wol=ZjooCW^Qgooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`00
2Oooool01000003oooooooooooooool_000001L06ATI00<0000003<c<`0c<c<0>P0c<c<00`000000
6ATI01TI6@0W01TI6@Cooooo00<00000ooooooooool09_ooool00`00003oooooooooo`0]ooooo`;o
Yko[00?oY[o[ojNojonW_n/00_nV_n/5ojJok003ojFok?oooooooooo01;ooooo00?o01bYo`Xl_?m3
E/000_mHG[d2ogM]^P;oQG>g0_nBNK@3oiao/P;oYHBa0_n/RK04okJ@[`04ok^D[onoV:oo_iR_olBM
/0;obJ:`00?ocJJaom>]/_oC[K800_oL^;@2onC2]@04onc>]_ocg;KomnZcooCW^Qgooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool_
000001H06ATI00<0000003<c<`0c<c<0400c<c<:00000003o`0000000000<c<c01l0<c<c00<00000
01TI6@0I6AT09P0I6AT4ooooo`0300000?oooooooooo02Oooooo00<00000ooooooooool0;Oooool7
ojNoj`03ojJok?oooooooooo01Oooooo00Co01j[o`Xl_?m3E/3oF5jm0_m]Ik/2ohEc]`?oTWVd0_nL
Ok82ojF4/@03ojb9/?n_Rk3o]Y2_00?o]Y2_0onoV:l00oo4WK3obJ:`olVR/003om>]/P03om^e/_oL
^;Coi<:e00;ok<jf00?olmbfooOZ/oooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`0400000?ooooooooooooooobl000005@0I6AT00`000000<c<c03<c
<`0>03<c<`<00000301<C4`3000001d0<c<c00<0000001TI6@0I6AT09P0I6AT4ooooo`0300000?oo
oooooooo02Sooooo00<00000ooooooooool0;Oooool3ojNojakooooo00?o01j[ob95_OmHG[d00_m]
Ik/3ogm`^0;oTWVd0_nLOk800onUQ;7oYhFaojn;/002ojn;/0;o]Y2_00Co^YB`oknH[onoV:oo_iR_
0oo9X[002?o@ZK7odjfbom^e/_oK]K;oi<6donC2]Oo/c[Kolmbf0_ogj[<Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo;`00000D
01TI6@030000000c<c<0<c<c00`0<c<c0`00000B04a<C0@000006P0c<c<00`0000006ATI01TI6@0U
01TI6@Cooooo00<00000ooooooooool0:Oooool2000002gooooo00<00000ooooooooool07_ooool0
1Ol07Z_o8TFmocmB__mHG[goKFNk00?oOg2h0_n?N;D2oiao/`;oYhFa0on_Rk001?nfT:oo^YB`okZD
/?njU;02oknH[`05olFN/?o9X[3od:Vaom2Y/OoC[K800_oK]K801OoT`KCokLndonc>]_ocg;KomnZc
02;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01000003o
ooooooooooooool^000001@06ATI00?o000003<c<`0c<c<02P0c<c<3000001T0C4a<0P00000I03<c
<`030000000I6AT06ATI02@06ATI1?ooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo
02[ooooo00<00000ooooooooool07oooool00ol07Z_o8TFmocmB_P02ofeW^`;oOg2h0_n?N;D2oiao
/`?oYhFa0_n_Rk04okZD/004oknH[oo5W[3oaIj`olVR/0;od:Va0_oK]K82onC1]003ong?]?ofgkCo
n>j]02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01000
003oooooooooooooool^000001<06ATI00<0000003<c<`0c<c<02@0c<c<2000001h0C4a<0P00000H
03<c<`030000000I6AT06ATI02<06ATI1?ooool00`00003oooooooooo`0/ooooo`0300000?oooooo
oooo02Wooooo00<00000ooooooooool08?ooool01?l0:k;o?e:noeeP_Om]Ik/3ogm`^0;oSgRe0_nL
Ok<2ojN5/@03ojn;/?nbSk7o/Xna00?o^YB`0oo5W[03om2Y/@03omVc/_oK]K;oi<6d00;okLnd00?o
m]ndooS^[Oooool08oooool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`0400000?oo
ooooooooooooobd0000000?o000001TI6@0I6AT0400I6AT00`000000<c<c03<c<`0803<c<`800000
8P1<C4`2000001H0<c<c00<0000001TI6@0I6AT08`0I6AT4ooooo`0300000?oooooooooo02gooooo
00<00000ooooooooool0:?ooool00`00003oooooooooo`0Pooooo`04o`0[/_lH?k_o?e:noeeP_@?o
Og2h0_n?N;D2oiao/`03ojN5/OnYR;?o/Xna00;o/Xna0onjU;03olFN/009olbV/_o@ZK7ofK>bomVc
/_oS`;Coi<6dong?]?ofgkCon>j]02Kooooo00Co0000oooooooooooo00002oooool000Wooooo00@0
0000oooooooooooooooo;P00000A01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`0
2`1<C4`8o`000140C4a<00<0000003<c<`0c<c<0500c<c<00`0000006ATI01TI6@0R01TI6@Cooooo
00<00000ooooooooool0;_ooool2000002Sooooo00<00000ooooooooool08Oooool00ol0:k;o63nk
oeeP_@03ogM]^`;oSgRe00?oW7ncoib1]OnYR;<00_nYR;<3ok:?/@04okZD/?noVK7o_iVaolFN/0;o
c:Jb00Sod:VaomVc/_oI/k;ohl2donkA]_o]ckCom]ndooS^[BOooooo00?o0000ooooool000002ooo
ool000Wooooo00@00000oooooooooooooooo;@00000A01TI6@030000000c<c<0<c<c00P0<c<c00<0
000004a<C01<C4`0201<C4`4o`0000P0IVIV1_l0000<04a<C00300000?l00000<c<c01@0<c<c00<0
000001TI6@0I6AT08@0I6AT4ooooo`0300000?oooooooooo033ooooo00<00000ooooooooool09Ooo
ool00`00003oooooooooo`0Qooooo`04o`03U_lH?k_o@eK1od=F`@;oMffk0_n<N;P2oib1]@?oZHRc
0onbSk43oknI/@03olFN/?o<Y[;oc:Jb00;ofK>b0_oS`;@00oo^dKKomnBdoo?cY`0Xooooo`03o`00
0?oooooo000000_ooooo0009ooooo`0400000?ooooooooooooooobd000004@0I6AT00`000000<c<c
03<c<`0703<c<`030000001<C4`0C4a<00L0C4a<0_l0000B06IVIP;o0000301<C4`00`000000<c<c
03<c<`0C03<c<`030000000I6AT06ATI02006ATI1?ooool00`00003oooooooooo`0aooooo`030000
0?oooooooooo02Cooooo00<00000ooooooooool08_ooool2o`0O[0;o@eK100?oMffkohah^?n<N;P0
0onLPKD3ojV8/`03ok:?/OngU;?o_iVa00;o_iVa0oo<Y[800ooE/KCofK>bon?0]002onkA]P03ooOT
]?ocljOooooo02Sooooo00?o0000ooooool000002_ooool000Wooooo00@00000oooooooooooooooo
;@00000@01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01`1<C4`00ol00000IVIV
06IVIP0D06IVIP?o00002P1<C4`00`000000<c<c03<c<`0C03<c<`030000000I6AT06ATI01l06ATI
1?ooool00`00003oooooooooo`0booooo`0300000?oooooooooo02?ooooo00<00000ooooooooool0
8oooool2o`0O[003od=F`OmYJ/7oMffk00;oS7Rh0_nLPKD2ojV8/`04ojb>]_ngU;?o]iBcokND/`;o
_iVa00WoaZ:dolbV/_oE/KCoeK6don30^?oS`;Cok]6fooOT]?ocljL0:oooool2o`0000[ooooo0009
ooooo`0400000?ooooooooooooooobd00000400I6AT00`000000<c<c03<c<`0503<c<`03o`000000
0000C4a<00L0C4a<0_l0000J06IVIP03o`00001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<04P0c
<c<00`0000006ATI01TI6@0O01TI6@Cooooo00<00000ooooooooool0<oooool2000002?ooooo00<0
0000ooooooooool09?ooool01?l07jco@eK1ofUZ`OmYJ/42ohah^0;oW86e00?oZHRcojb>]_n/S[H0
0ongU;<00onoVK7oaZ:dolJR]003omFa]005on30^?o]eK_ok]6fooOT]?ocljL0:_ooool200000003
o`000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooobd000003`0I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<0_l0000906IVIPP00000301VIVH2o`0000T0
C4a<00?o000003<c<`0c<c<04@0c<c<00`0000006ATI01TI6@0O01TI6@Cooooo00<00000oooooooo
ool0=Oooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo02Gooooo00?o01n/od=F`OmY
J/400_n6N[h2oib5^PCo[8jf0_ngU;<3olJR]007oln^^?oE/KCoh<2hon30^?o]eK_omNfhonCeW`0W
ooooo`@000003Oooool000Wooooo00@00000oooooooooooooooo;@00000?01TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`2o`0000P0IVIV0`00000807moO`H00000201VIVH0
0ol00000C4a<04a<C00704a<C0030000000c<c<0<c<c0100<c<c00<0000001TI6@0I6AT07`0I6AT4
ooooo`0300000?oooooooooo03Kooooo00<00000ooooooooool07oooool00`00003oooooooooo`0V
ooooo`04oaA3`?mYJ/7oJF[1ohIj_P?oW8Fj0on/S[H01?ngU;?o_IfgokfM]oo6X[@2oln^^006omFa
]?oP`;SokMFkongE^ooekKSoi?FO9?ooool30000017ooooo0009ooooo`0400000?oooooooooooooo
ob`000003`0I6AT00ol00000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00?o000006IV
IP1VIVH01@1VIVH300000140Ogmo0P00000706IVIP;o0000201<C4`00`000000<c<c03<c<`0@03<c
<`030000000I6AT06ATI01h06ATI1?ooool00`00003oooooooooo`0gooooo`0300000?oooooooooo
01kooooo00<00000ooooooooool09oooool2odmUb@;oQWZn0_nLQKX2ojb>]P05ok2F_?nmWKOo_Ifg
okfM]oo6X[@00_o?[[P01OoL`Kkoh<2hongE^ooekKSoi?FO027ooooo1000000Dooooo`002Oooool0
1000003oooooooooooooool/000000h06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<
C00404a<C003o`00001VIVH0IVIV00@0IVIV00?o00000000001oOgl05@1oOgl2000000L0IVIV00?o
000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0@03<c<`030000000I6AT06ATI01d06ATI1?oo
ool00`00003oooooooooo`0hooooo`8000007_ooool00`00003oooooooooo`0Wooooo`06o`0KZ?m?
ILWoOGg8ogemb?nLQK[oW8g31?n`U[`2okfM]`?ocjjh00Cog<6non[KaOo]eK_omNfh7_ooool40000
01Sooooo0009ooooo`0400000?ooooooooooooooob`000003P0I6AT00`000000<c<c03<c<`0503<c
<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH2000000L0Ogmo2?l0000:07mo
O`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0@03<c
<`030000000I6AT06ATI01d06ATI1?ooool00`00003oooooooooo`0jooooo`0300000?oooooooooo
01_ooooo00<00000ooooooooool0:?ooool00olGELkoCfG9ogemb003oib=``?o/9Jl00Co_IfgolJ[
__o6Zkkocjjh0_oL`Kh00ooZflGokORookOWRP0Jooooo`@000007?ooool000Wooooo00@00000oooo
oooooooooooo;000000=01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`0
0ol00000IVIV06IVIP0206IVIP8000001P1oOgl3o`0000P0VIVI1?l0000707moO`030000001VIVH0
IVIV00@0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0?03<c<`030000000I6AT0
6ATI01d06ATI1?ooool00`00003oooooooooo`0kooooo`0300000?oooooooooo01[ooooo00<00000
ooooooooool0:Oooool00olGELkoOGg8ogemb003oib=``03ok2F_?nfYLOoaZ^n00;oaZ^n00God/79
omc1__oZflGoj]_5ongh_`0Hooooo`<000008?ooool000Wooooo00@00000oooooooooooooooo;000
000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000IVIV06IV
IP0206IVIP03o`00001oOgl0Ogmo00@0Ogmo0_l0000?09VIV@;o00001P1oOgl00`000000IVIV06IV
IP0406IVIP03o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<03`0c<c<00`0000006ATI01TI
6@0L01TI6@Cooooo00<00000ooooooooool0??ooool00`00003oooooooooo`0Iooooo`0300000?oo
oooooooo02[ooooo0_mWP]T2oib=``05oiZJd_nfYLOo]ZG7okJUaoo6Zkh00_oB`LT00ooPiMOoj]_5
ongh_`0Eooooo`@000008oooool000Wooooo00@00000oooooooooooooooo;000000<01TI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo0_l0000C09VIV@;o00001@1oOgl2000000D0IVIV00?o000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0>03<c<`030000000I6AT06ATI01`06ATI1?ooool00`00003ooooo
ooooo`0mooooo`8000006Oooool00`00003oooooooooo`0[ooooo`;oIh;I0onJV]82okJUa`?od/79
00?oh>GGolcna_ooool04Oooool4000002Oooooo0009ooooo`0400000?ooooooooooooooob`00000
300I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH0
0`1VIVH00`000000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00D0VIVI2000000809VIV@;o0000
1@1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0
3P0c<c<00`0000006ATI01TI6@0L01TI6@Cooooo00<00000ooooooooool0?oooool00`00003ooooo
ooooo`0Fooooo`0300000?oooooooooo02cooooo0_lWOnP2oiZJdP06okJUaono_m[o_koJom;1bOoP
iMOoc?k63oooool4000002_ooooo0009ooooo`0400000?ooooooooooooooob/00000300I6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00<0VIVI0`0000080;>c/`@000001P2IVIT00ol0
0000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`01@1<C4`00`00
0000<c<c03<c<`0>03<c<`030000000I6AT06ATI01/06ATI1?ooool00`00003oooooooooo`10oooo
o`0300000?oooooooooo01Cooooo00<00000ooooooooool0<?ooool2oi2ckP03oknof_nnk??oF<^U
00kooooo0`00000_ooooo`002Oooool01000003oooooooooooooool[000000`06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0000007mo
O`1oOgl00P1oOgl00ol00000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00d0/k>c0P00000509VI
V@03o`00001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00404a<
C0030000000c<c<0<c<c00h0<c<c00<0000001TI6@0I6AT06`0I6AT4ooooo`0300000?oooooooooo
047ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0oooooo`@00000<_ooool000Wo
oooo00@00000oooooooooooooooo:`00000<01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<
C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moOol00000102IVIT2
00000180/k>c0P00000309VIV@03o`00001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH0
0ol00000C4a<04a<C00404a<C0030000000c<c<0<c<c00h0<c<c00<0000001TI6@0I6AT06`0I6AT4
ooooo`0300000?oooooooooo04;ooooo0P00000Cooooo`0300000?oooooooooo03_ooooo1000000f
ooooo`002Oooool01000003oooooooooooooool[000000`06ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00204a<C003o`00001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmoo`00
000409VIV@030000002c/k<0/k>c00@0/k>c2?l000080;>c/`050000002IVIT0VIVI09VIVOl00000
1@1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0
3@0c<c<00`0000006ATI01TI6@0K01TI6@Cooooo00<00000ooooooooool0A?ooool00`00003ooooo
ooooo`0@ooooo`0300000?oooooooooo03Oooooo1000000jooooo`002Oooool01000003ooooooooo
ooooool[000000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C005o`00
001VIVH0IVIV06IVIP000000101oOgl01Ol00000VIVI09VIV@2IVIWo000000D0/k>c0_l000080<c<
c0?o00001@2c/k<00`000000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00`1VIVH00ol00000C4a<04a<C00404a<C0030000000c<c<0<c<c00d0<c<c00<0000001TI
6@0I6AT06`0I6AT4ooooo`0300000?oooooooooo04Gooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0cooooo`@00000?_ooool000Wooooo00@00000oooooooooooooooo:`00000;01TI
6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0
000000@0Ogmo00Go000009VIV@2IVIT0VIVI000000040;>c/`;o00003@3<c<`3o`0000<0/k>c00<0
000009VIV@2IVIT00P2IVIT2o`0000<0Ogmo00<0000006IVIP1VIVH00`1VIVH00ol00000C4a<04a<
C00404a<C0030000000c<c<0<c<c00`0<c<c00<0000001TI6@0I6AT06`0I6AT4ooooo`0300000?oo
oooooooo04Kooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0`ooooo`<00000@_oo
ool000Wooooo00@00000oooooooooooooooo:`00000;01TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0000000@0Ogmo00Go000009VIV@2IVIT0
VIVI000000030;>c/`03o`00003<c<`0c<c<0100c<c<00Go00000;>c/`2c/k<0/k>c0000000409VI
V@05o`00001oOgl0Ogmo07moO`0000001@1VIVH00ol00000C4a<04a<C00404a<C0030000000c<c<0
<c<c00`0<c<c00<0000001TI6@0I6AT06`0I6AT4ooooo`0300000?oooooooooo04Oooooo00<00000
ooooooooool03Oooool00`00003oooooooooo`0/ooooo`@00000AOooool000Wooooo00@00000oooo
oooooooooooo:`00000;01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`0
1Ol00000IVIV06IVIP1VIVH0000000@0Ogmo00Go000009VIV@2IVIT0VIVI000000030;>c/`03o`00
003<c<`0c<c<00@0c<c<1ol000070<c<c005o`00002c/k<0/k>c0;>c/`000000102IVIT01Ol00000
Ogmo07moO`1oOgl0000000D0IVIV00?o000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0;03<c
<`030000000I6AT06ATI01/06ATI1?ooool00`00003oooooooooo`18ooooo`8000003Oooool00`00
003oooooooooo`0Xooooo`@00000BOooool000Wooooo00@00000oooooooooooooooo:`00000;01TI
6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0
000000<0Ogmo00Go000009VIV@2IVIT0VIVIo`0000030;>c/`03o`00003<c<`0c<c<00<0c<c<0_l0
00070>KViP?o00001@3<c<`01Ol00000/k>c0;>c/`2c/k?o000000@0VIVI00Go000007moO`1oOgl0
Ogmo0000000406IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<02`0c<c<00`000000
6ATI01TI6@0K01TI6@Cooooo00<00000ooooooooool0B_ooool00`00003oooooooooo`0:ooooo`03
00000?oooooooooo02Cooooo1000001=ooooo`002Oooool01000003oooooooooooooool[000000/0
6ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IV
IP0000000`1oOgl01?l00000VIVI09VIV@0000040;>c/`03o`00003<c<`0c<c<0080c<c<00?o0000
0>KViP3Vi^H02P3Vi^H00ol00000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/`000000102I
VIT00ol00000Ogmo07moO`0207moO`05o`00001VIVH0IVIV06IVI_l000001P1<C4`00`000000<c<c
03<c<`0;03<c<`030000000I6AT06ATI01/06ATI1?ooool00`00003oooooooooo`1;ooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool08Oooool30000057ooooo0009ooooo`0400000?oo
ooooooooooooob/000002`0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<
00Go000006IVIP1VIVH0IVIV0000000307moO`04o`00002IVIT0VIVI000000<0/k>c00?o00000<c<
c03<c<`00P3<c<`00ol00000i^KV0>KViP0<0>KViP03o`00003<c<`0c<c<0080c<c<00Go00000;>c
/`2c/k<0/k>c0000000409VIV@05o`00001oOgl0Ogmo07moO`000000101VIVH00ol00000C4a<04a<
C00304a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT06`0I6AT4ooooo`0300000?oo
oooooooo04cooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Mooooo`@00000E?oo
ool000Wooooo00@00000oooooooooooooooo:`00000:01TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0000000<0Ogmo00Co000009VIV@2IVIT0
0000102c/k<01Ol00000c<c<0<c<c03<c<co00000100i^KV00Go00000<c<c03<c<`0c<c<o`000004
0;>c/`050000002IVIT0VIVI09VIVOl00000101oOgl01@000000IVIV06IVIP1VIVKo000000H0C4a<
00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0K01TI6@Cooooo00<00000ooooooooool0
COooool2000000Sooooo00<00000ooooooooool06Oooool4000005Sooooo0009ooooo`0400000?oo
ooooooooooooob/000002P0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<
00Go000006IVIP1VIVH0IVIV0000000307moO`04o`00002IVIT0VIVI000000<0/k>c00Go00000<c<
c03<c<`0c<c<o`0000080>KViP<000001`3Vi^H01Ol00000c<c<0<c<c03<c<co000000@0/k>c00@0
000009VIV@2IVIWo0000101oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0K01TI6@Cooooo00<00000ooooooooool0
Coooool00`00003oooooooooo`05ooooo`0300000?oooooooooo01Gooooo1000001Looooo`002Ooo
ool01000003oooooooooooooool[000000X06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<
04a<C00204a<C005o`00001VIVH0IVIV06IVIP0000000`1oOgl01?l00000VIVI09VIV@0000030;>c
/`05o`00003<c<`0c<c<0<c<c?l000001@3Vi^H3000000<0oooo0P0000050>KViP03o`00003<c<`0
c<c<0080c<c<00Go00000;>c/`2c/k<0/k>c0000000209VIV@03o`00001oOgl0Ogmo0080Ogmo00<0
000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00X0<c<c00<0
000001TI6@0I6AT06`0I6AT4ooooo`0300000?oooooooooo053ooooo00<00000ooooooooool01?oo
ool00`00003oooooooooo`0Booooo`<00000H?ooool000Wooooo00@00000oooooooooooooooo;000
000901TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01?l00000IVIV06IV
IP00000307moO`04o`00002IVIT0VIVI000000<0/k>c00Go00000<c<c03<c<`0c<c<o`0000050>KV
iP030000003oool0oooo00H0oooo0P0000040>KViP05o`00003<c<`0c<c<0<c<c?l00000102c/k<0
10000000VIVI09VIVOl0000407moO`050000001VIVH0IVIV06IVI_l000001P1<C4`00`000000<c<c
03<c<`0903<c<`030000000I6AT06ATI01/06ATI1?ooool00`00003oooooooooo`1Aooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool03_ooool4000006?ooooo0009ooooo`0400000?oo
ooooooooooooob`000002@0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<
00Co000006IVIP1VIVH000000`1oOgl01?l00000VIVI09VIV@0000030;>c/`05o`00003<c<`0c<c<
0<c<c?l00000103Vi^H00`000000oooo0?ooo`090?ooo`030000003Vi^H0i^KV0080i^KV00Go0000
0<c<c03<c<`0c<c<o`0000030;>c/`050000002IVIT0VIVI09VIVOl000000`1oOgl01@000000IVIV
06IVIP1VIVKo000000H0C4a<00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0K01TI6@Co
oooo00<00000ooooooooool0D_ooool2000000?ooooo00<00000ooooooooool02_ooool4000006Oo
oooo0009ooooo`0400000?ooooooooooooooob`000002@0I6AT00`000000<c<c03<c<`0303<c<`03
0000001<C4`0C4a<0080C4a<00Co000006IVIP1VIVH000000`1oOgl01?l00000VIVI09VIV@000003
0;>c/`05o`00003<c<`0c<c<0<c<c?l000000`3Vi^H00ol00000oooo0?ooo`0:0?ooo`030000003V
i^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<o`0000030;>c/`050000002IVIT0VIVI09VIVOl0
00000`1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c
<c<02@0c<c<00`0000006ATI01TI6@0K01TI6@Cooooo00<00000ooooooooool0E?ooool01000003o
ooooooooo`000008ooooo`@00000Joooool000Wooooo00@00000oooooooooooooooo;000000901TI
6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP050000001oOgl0
Ogmo07moOol000000P2IVIT010000000/k>c0;>c/ol000030<c<c003o`00003Vi^H0i^KV0080i^KV
00<000000?ooo`3oool02`3oool00`000000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c?l0
00000`2c/k<010000000VIVI09VIVOl0000307moO`030000001VIVH0IVIV0080IVIV00?o000004a<
C01<C4`00`1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI01/06ATI1?ooool00`00
003oooooooooo`1Eooooo`0300000?ooool0000000Gooooo0`00001_ooooo`002Oooool01000003o
ooooooooooooool/000000T06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4co
000000<0IVIV00D0000007moO`1oOgl0Ogmoo`00000209VIV@040000002c/k<0/k>co`0000<0c<c<
00Go00000>KViP3Vi^H0i^KV0000000>0?ooo`03o`0000000000i^KV0080i^KV00Go00000<c<c03<
c<`0c<c<o`0000030;>c/`040000002IVIT0VIVIo`0000<0Ogmo00<0000006IVIP1VIVH00P1VIVH0
0ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT06`0I6AT4
ooooo`0300000?oooooooooo05Kooooo0P0000000oooool0000000000002000007;ooooo0009oooo
o`0400000?ooooooooooooooob`000002@0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0
C4a<04a<C?l000000`1VIVH01@000000Ogmo07moO`1oOgoo00000080VIVI00@000000;>c/`2c/k?o
00000`3<c<`01Ol00000i^KV0>KViP3Vi^H0000000l0oooo00D000000>KViP3Vi^H0i^KVo`000003
0<c<c005o`00002c/k<0/k>c0;>c/`0000000P2IVIT01Ol00000Ogmo07moO`1oOgl0000000@0IVIV
00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI01/06ATI
1?ooool00`00003oooooooooo`1Gooooo`800000M_ooool000Wooooo00@00000oooooooooooooooo
;000000901TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP05
0000001oOgl0Ogmo07moOol000000P2IVIT010000000/k>c0;>c/ol000030<c<c005o`00003Vi^H0
i^KV0>KViP0000003`3oool01@000000i^KV0>KViP3Vi^Ko000000<0c<c<00Go00000;>c/`2c/k<0
/k>c0000000209VIV@05o`00001oOgl0Ogmo07moO`000000101VIVH00ol00000C4a<04a<C00304a<
C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT06`0I6AT4ooooo`0300000?oooooooooo
0<oooooo0009ooooo`0400000?ooooooooooooooobd000002@0I6AT00`000000<c<c03<c<`0203<c
<`030000001<C4`0C4a<0080C4a<00Co000006IVIP1VIVH000000`1oOgl01?l00000VIVI09VIV@00
00020;>c/`05o`00003<c<`0c<c<0<c<c?l000000`3Vi^H00`000000oooo0?ooo`0=0?ooo`030000
003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<o`0000020;>c/`050000002IVIT0VIVI09VI
VOl000000P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c
<`0c<c<0200c<c<00`0000006ATI01TI6@0L01TI6@Cooooo00<00000ooooooooool0coooool000Wo
oooo00@00000oooooooooooooooo;@00000901TI6@030000000c<c<0<c<c0080<c<c00<0000004a<
C01<C4`00P1<C4`01?l00000IVIV06IVIP00000307moO`04o`00002IVIT0VIVI00000080/k>c00Go
00000<c<c03<c<`0c<c<o`0000030>KViP030000003oool0oooo00d0oooo00<000000>KViP3Vi^H0
0P3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c00D0000009VIV@2IVIT0VIVIo`00000207mo
O`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI01`06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool]000000T06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<
C004o`00001VIVH0IVIV000000<0Ogmo00Co000009VIV@2IVIT000000P2c/k<01Ol00000c<c<0<c<
c03<c<co000000<0i^KV00<000000?ooo`3oool03@3oool00`000000i^KV0>KViP020>KViP05o`00
003<c<`0c<c<0<c<c?l000000P2c/k<01@000000VIVI09VIV@2IVIWo00000080Ogmo00<0000006IV
IP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI
6@0I6AT0700I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
obd000002@0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C?l000000`1VIVH0
10000000Ogmo07moOol0000309VIV@040000002c/k<0/k>co`0000<0c<c<00Go00000>KViP3Vi^H0
i^KV0000000=0?ooo`030000003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<o`0000030;>c
/`040000002IVIT0VIVIo`0000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C003
04a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT07@0I6AT4ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?ooooooooooooooobd000002@0I6AT00`000000<c<c03<c<`03
03<c<`050000001<C4`0C4a<04a<C?l000000`1VIVH010000000Ogmo07moOol0000309VIV@040000
002c/k<0/k>co`0000<0c<c<00Ko00000>KViP3Vi^H0i^KV00000?l0000<0?ooo`8000000`3Vi^H0
1Ol00000c<c<0<c<c03<c<co000000<0/k>c00@0000009VIV@2IVIWo00000`1oOgl00`000000IVIV
06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI
01TI6@0M01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
;@00000901TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP04
0000001oOgl0Ogmoo`0000<0VIVI00@000000;>c/`2c/k?o00000`3<c<`00ol00000i^KV0>KViP02
0>KViP030000003oool0oooo00X0oooo00<000000>KViP3Vi^H00P3Vi^H01Ol00000c<c<0<c<c03<
c<co000000<0/k>c00@0000009VIV@2IVIWo00000`1oOgl00`000000IVIV06IVIP0206IVIP03o`00
001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0M01TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo;P00000801TI6@030000
000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP040000001oOgl0Ogmoo`00
00<0VIVI00@000000;>c/`2c/k?o0000103<c<`00ol00000i^KV0>KViP020>KViP030000003oool0
oooo00P0oooo00<000000>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<co000000<0/k>c00@0
000009VIV@2IVIWo00000`1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0M01TI6@Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo;P00000901TI6@030000000c<c<0<c<c00<0<c<c
00D0000004a<C01<C4`0C4a<o`00000306IVIP040000001oOgl0Ogmoo`0000<0VIVI00@000000;>c
/`2c/k?o00000`3<c<`00ol00000i^KV0>KViP030>KViP030000003oool0oooo00H0oooo00<00000
0>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<co000000<0/k>c00D0000009VIV@2IVIT0VIVI
o`00000307moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0703<c<`030000000I6AT06ATI01h06ATI1?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003oooooooooooooool^000000T06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<
04a<C01<C4co000000<0IVIV00<0000007moO`1oOgl00_l0000209VIV@030000002c/k<0/k>c00;o
00000`3<c<`00ol00000i^KV0>KViP030>KViPP000001P3Vi^H01Ol00000c<c<0<c<c03<c<co0000
00<0/k>c00D0000009VIV@2IVIT0VIVIo`00000307moO`050000001VIVH0IVIV06IVI_l000001@1<
C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI01h06ATI1?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool^000000T06ATI00<0000003<c<`0c<c<00`0c
<c<00`000000C4a<04a<C00204a<C004o`00001VIVH0IVIV000000<0Ogmo00Co000009VIV@2IVIT0
00000`2c/k<01Ol00000c<c<0<c<c03<c<co00000180i^KV00?o00000<c<c03<c<`00P3<c<`01Ol0
0000/k>c0;>c/`2c/k<0000000<0VIVI00Go000007moO`1oOgl0Ogmo0000000306IVIP03o`00001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0N01TI6@Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo;`00000901TI6@030000000c
<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP050000001oOgl0Ogmo07moOol0
00000P2IVIT01@000000/k>c0;>c/`2c/k?o000000<0c<c<00?o00000>KViP3Vi^H03P3Vi^H00ol0
0000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/`0000000`2IVIT01Ol00000Ogmo07moO`1o
Ogl0000000<0IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0703<c<`030000000I
6AT06ATI01l06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ool_000000T06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4co000000<0IVIV
00D0000007moO`1oOgl0Ogmoo`00000309VIV@050000002c/k<0/k>c0;>c/ol000000`3<c<`2o`00
00d0i^KV00?o00000<c<c03<c<`00`3<c<`01Ol00000/k>c0;>c/`2c/k<0000000<0VIVI00Go0000
07moO`1oOgl0Ogmo0000000306IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01`0c
<c<00`0000006ATI01TI6@0O01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool0coooool000Wooooo]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00
017ooooo]_l0000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1;ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool00`00003ooooo
ooooo`0Oooooo`0300000?oooooooooo03Wooooo00<00000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0?_ooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo03Wooooo00<0
0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1:
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0P
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool00`00003oooooooooo`0O
ooooo`0300000?oooooooooo03_ooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`19ooooo`03o`00oooooooooooo01kooooo00?o003ooooo
ool00?l08_ooool00ol00?ooooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0?Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo03_ooooo00<00000oooo
ooooool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`19ooooo`03
o`00oooooooooooo01kooooo00?o003oooooool00?l08oooool00ol00?ooooooooooo`0Oooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool00`00003oooooooooo`0Oooooo`03
00000?oooooooooo03gooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`19ooooo`03o`00oooooooooooo01kooooo00?o003oooooool00?l0
8oooool3o`0001oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01oooooo00<00000ooooooooool0?_ooool00`00003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool07_oo
ool00ol00?ooooooo`00o`0Rooooo`Go00007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03_ooooo00<00000ooooooooool07_ooool00`00003oooooooooo`10ooooo`0300000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B?ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooo003o02;ooooo1Ol0000Nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0>_ooool00`00003oooooooooo`0Nooooo`0300000?oooooo
oooo04;ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`18ooooo`03o`00oooooooooooo01oooooo00?o003oooooool00?l08_ooool5o`00
01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`0300000?oooooooooo
01kooooo00<00000ooooooooool0@_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool08?ooool00ol00?oo
ooooo`00o`0Sooooo`?o00007oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`13ooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Aoooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooo003o02Gooooo00?o003oooooooooool07Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Wooooo00<00000ooooooooool07_ooool00`00003ooooo
ooooo`14ooooo`0300000?oooooooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0Aoooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo003o02Gooooo00?o
003oooooooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`15ooooo`0300000?oooooooooo00kooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooo003o02Gooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Wooooo00<00000ooooooooool07Oooool00`00003oooooooooo`15
ooooo`0300000?oooooooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0A_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo003o02Gooooo00?o003ooooo
ooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`16ooooo`0300000?oooooooooo00kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooo003o02Gooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool07_ooool00`00003oooooooooo`16ooooo`03
00000?oooooooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
1oooool3o`0003cooooo00?o003oooooooooool08_ooool00ol00?ooooooo`00o`0Uooooo`03o`00
oooooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`030000
0?oooooooooo01gooooo00?o0000ooooooooool0Aoooool00`00003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo1Ol0000kooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooool00?l09Oooool00ol00?ooooooooooo`0Looooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0=oooool00`00003oooooooooo`0Mooooo`0300000?oo
oooooooo04Oooooo00<00000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`06ooooo`Go0000>_ooool00ol00?ooooooooooo`0Tooooo`;o003o9_ooool0
0ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool0
0`00003oooooooooo`0Nooooo`0300000?oooooooooo04Sooooo00<00000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`Go0000>_ooool00ol0
0?ooooooooooo`0Tooooo`;o003o9_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0=_ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo
04Sooooo00<00000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`07ooooo`?o0000>oooool00ol00?ooooooooooo`0Sooooo`?o00009_ooool00ol00?oo
ooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool00`00003o
ooooooooo`0Nooooo`0300000?oooooooooo04Sooooo00<00000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo02;ooooo
1Ol0000Uooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0eooooo`0300000?oooooooooo01kooooo00<00000ooooooooool0BOooool00`00003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Gooooo00?o
003oooooooooool08_ooool5o`0002Gooooo00?o003oooooooooool06oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Gooooo00<00000ooooooooool07_ooool00`00003ooooooooo
o`19ooooo`0300000?oooooooooo00gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0AOooool00ol00?ooooooooooo`0Rooooo`Go00009Oooool00ol00?ooooooooooo`0K
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00`00003oooooooooo`0N
ooooo`0300000?oooooooooo04Wooooo00<00000ooooooooool03Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo02?ooooo0ol000000ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0eooooo`0300000?oooooooooo01kooooo00<00000ooooooooool0BOooool00`00
003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Go
oooo00?o003oooooooooool09?ooool00ol00?ooooooo`00o`0Uooooo`03o`00oooooooooooo01_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`0300000?oooooooooo01oo
oooo00<00000ooooooooool0B?ooool00`00003oooooooooo`0>ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool09?ooool01?l00?oooooo
ooooool00?lTooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0dooooo`0300000?oooooooooo01oooooo00<00000ooooooooool0B?ooool00`00003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Kooooo
00?o003oooooooooool08oooool01?l00?ooooooooooool00?lSooooo`03o`00oooooooooooo01co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01oo
oooo00<00000ooooooooool0B?ooool00`00003oooooooooo`0>ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool08oooool01Ol00?oooooo
oooooooooooo003o02;ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Cooooo00<00000ooooooooool07_ooool00`00003oooooooooo`19ooooo`03
00000?oooooooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
A_ooool00ol00?ooooooooooo`03oooooaT0okK11oooool01Ol00?oooooooooooooooooo003o02;o
oooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Co
oooo00<00000ooooooooool05Oooool90?nf`@030000003o]/40okK100d0okK1??ooool00`00003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Kooooo
00?o003oooooooooool07`3o]/44ooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?oo
ooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00`00003o
ooooooooo`0Booooo``0okK100<000000?nf`@3o]/40403o]/4iooooo`0300000?oooooooooo00ko
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool00ol00?l0okK1
0?nf`@0R0?nf`@03ooooool00?oooooo00?ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00`00003ooooo
ooooo`0?ooooo`l0okK100<000000?nf`@3o]/404`3o]/4fooooo`0300000?oooooooooo00kooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@oooool40?nf`@03o`00o`3o
]/40okK10240okK100?o003o0?nf`@3o]/401?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`0300000?oo
oooooooo00gooooo4`3o]/400`000000okK10?nf`@0E0?nf`C;ooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`10ooooo`L0okK100?o003o
0?nf`@3o]/408@3o]/400ol00?l0okK10?nf`@030?nf`@;ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooo0000017ooooo00?o0000ooooooooool0<oooool0
0`00003oooooooooo`0:oooooaH0okK100<000000?nf`@3o]/40603o]/4_ooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?Oooool:0?nf
`@03o`00o`3o]/40okK10240okK100?o003o0?nf`@3o]/401P3o]/400ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo01[ooooo0_l00?l00ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo
03?ooooo00<00000ooooooooool01ooooolI0?nf`@030000003o]/40okK101/0okK1;?ooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03[o
oooo3@3o]/400ol00?l0okK10?nf`@0Q0?nf`@03o`00o`3o]/40okK100L0okK100?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool000004Oooool00ol0
003oooooooooo`0booooo`0300000?oooooooooo00Gooooo703o]/400`000000okK10?nf`@0L0?nf
`B[ooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0iooooo`l0okK100?o003o0?nf`@3o]/40803o]/400ol00?l0okK10?nf`@080?nf`@03
o`00oooooooooooo01Sooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool00`00003oooooooooo`04oooooad0
okK100<000000?nf`@3o]/407@3o]/4Yooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0=ooooolA0?nf`@03o`00o`3o]/40okK101l0okK1
00?o003o0?nf`@3o]/402P3o]/400ol00?l0okK1ooooo`0Gooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo
00<00000ooooooooool00_oooolO0?nf`@030000003o]/40okK10200okK19Oooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Gooooo503o
]/400ol00?l0okK10?nf`@0N0?nf`@03o`00o`3o]/40okK100/0okK10_l00?l00`3o]/7ooooooooo
o`0Cooooo`03o`00oooooooooooo01Oooooo0_l00?l6ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<_ooool00`00003oooooooooo`0Q0?nf`@030000003o]/40okK10280okK18ooo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo03Cooooo5@3o]/400ol00?l0okK10?nf`@0N0?nf`@03o`00o`3o]/40okK100d0okK10_l00?lD
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03;ooooo00<00000ooooo`3o]/408P3o]/400`000000okK10?nf`@0R
0?nf`B7ooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0coooooaH0okK100?o003o0?nf`@3o]/407P3o]/400ol00?l0okK10?nf`@0?0?nf
`@03o`00oooooooooooo013ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool00`000000okK10?nf`@0R0?nf
`@030000003o]/40okK102<0okK18?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03;ooooo603o]/400ol00?l0okK10?nf`@0M0?nf`@03
o`00o`3o]/40okK10100okK100?o003oooooooooool03oooool00ol00?ooooooooooo`0Dooooo`;o
003o2_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo00<000000?nf`@3o
]/408P3o]/400`000000okK10?nf`@0T0?nf`Aoooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0;ooooo`X0003o6ooooolK0?nf`@03o`00
o`3o]/40okK101/0okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK1ooooo`0=ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo033ooooo0P3o]/400`000000okK10?nf`@0R0?nf`@030000003o]/40okK102H0okK1
7?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00;ooooo0P000?l00ol00?l0003o0000o`040000o`[ooooo00<0003oo`00o`000?l01`00
0?l@oooooad0okK100?o003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@0C0?nf`@;o003o3?oo
ool00ol00?ooooooooooo`0Cooooo`;o003o3Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02oooooo0`3o]/400`000000okK10?nf`@0S0?nf`@03o`00003o]/40okK102H0okK16_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
003o0080003o7Oooool40000o`_ooooo7P3o]/400ol00?l0okK10?nf`@0J0?nf`@03o`00o`3o]/40
okK101D0okK10_l00?l:ooooo`03o`00oooooooooooo017ooooo0_l00?l?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0;_ooool40?nf`@030000003o]/40okK102<0okK100<00000
0?nf`@3o]/409`3o]/4Iooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool08oooool30000o`Oooooo803o]/400ol00?l0okK10?nf`@0I0?nf
`@03o`00o`3o]/40okK101L0okK10ol00?l6ooooo`03o`00oooooooooooo00oooooo0ol00?lAoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool50?nf`@030000003o]/40okK1
02<0okK100<000000?nf`@3o]/40:03o]/4Hooooo`0300000?oooooooooo01Cooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool09_ooool30000o`?ooooo8P3o]/400ol00?l0
okK10?nf`@0G0?nf`@03o`00o`3o]/40okK101T0okK10_ooool4o`00o`;ooooo00?o003ooooooooo
ool03?ooool3o`00oaCooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`H0
okK100<000000?nf`@3o]/40903o]/400`000000okK10?nf`@0X0?nf`AKooooo00<00000oooooooo
ool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Yooooo`80003o
8`3o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o]/40okK101X0okK11OoooolAo`00oaOooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`L0okK100<000000?nf`@3o]/40
903o]/400`000000okK10?nf`@0Y0?nf`ACooooo00<00000ooooooooool05_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Zooooo`030?nf`@000?l0003o00<0003o7`3o
]/42o`00o`@0okK11`000?l=o`00oa`0okK11?ooool2o`00obOooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Zooooo`P0okK100<000000?nf`@3o]/40903o]/400`000000okK10?nf
`@0Y0?nf`ACooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Zooooo`H0okK100<0003o0?nf`@3o]/407P3o]/401?l00?l0003o0000o`00
0?lC0?nf`@Ko003o603o]/42ooooo`03o`00oooooooooooo02Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Zooooo`P0okK100<000000?nf`@3o]/409@3o]/400`000000okK10?nf
`@0Y0?nf`A;ooooo00<00000ooooooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Yooooo`P0okK100<0003o0?nf`@3o]/406@3o]/440000o`030?nf`Ol00?l0
okK101<0okK100?o003o0?nf`@3o]/40103o]/43o`00oaH0okK100?o003oooooooooool0:?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo203o]/400`000000okK10?nf`@0V
0?nf`@030000003o]/40okK102X0okK14?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02Sooooo2P3o]/430000oaD0okK10`000?l60?nf
`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/401`3o]/42o`00oa<0okK100?o003o0?nf
`Oooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo2@3o]/400`00
0000okK10?nf`@0W0?nf`@030000003o]/40okK102X0okK13oooool00`00003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Oooooo3P3o]/400`000?oo
003o0?nf`@0?0?nf`@030000ool00?l0003o00X0okK100?o003o0?nf`@3o]/403`3o]/400ol00?l0
okK10?nf`@0:0?nf`@Co003o3@3o]/42o`00o`<0okK1:Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Oooooo2P3o]/400`000000okK10?nf`@0W0?nf`@030000003o]/40okK102/0
okK13Oooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02Kooooo4@3o]/420000o`d0okK100<0003o0?nf`@3o]/40303o]/400ol00?l0okK1
0?nf`@0>0?nf`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o]/402@3o]/400ol00?l0okK1
0?nf`@030?nf`BWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`/0okK1
00<000000?nf`@3o]/40:03o]/400`000000okK10?nf`@0Z0?nf`@cooooo00<00000ooooooooool0
6_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Voooooa<0okK10P00
0?l90?nf`@80003o403o]/400ol00?l0okK10?nf`@0<0?nf`@03o`00o`3o]/40okK10100okK10_l0
0?l80?nf`@03o`00o`3o]/40okK100D0okK1:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Kooooo2`3o]/400`000000okK10?nf`@0Y0?nf`@030000003o]/40okK102X0okK12_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02Gooooo5P3o]/400`000?l0okK10?nf`@040?nf`@80003o4`3o]/42o`00o``0okK100?o003o
0?nf`@3o]/404P3o]/43o`00o`<0okK10_l00?l90?nf`BOooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Uooooo``0okK100<000000?nf`@3o]/40:P3o]/400`000000okK10?nf`@0Z
0?nf`@Wooooo00<00000ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0ToooooaP0okK100?o003o0?nf`@3o]/400P3o]/400`000?l0okK10?nf`@0E0?nf
`@?o003o2@3o]/400ol00?l0okK10?nf`@0E0?nf`@?o003o2`3o]/4Wooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool09?ooool=0?nf`@030000003o]/40okK102/0okK100<000000?nf
`@3o]/40:@3o]/48ooooo`0300000?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool09?oooolI0?nf`@@0003o6`3o]/42o`00o`L0okK100?o003o0?nf`@3o
]/40503o]/43o`00o`d0okK19_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Co
oooo3@3o]/400`000000okK10?nf`@0[0?nf`@030000003o]/40okK102X0okK11_ooool00`00003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02?ooooo
6`3o]/420000oah0okK10ol00?l40?nf`@03o`00o`3o]/40okK10140okK10ol00?l30?nf`@03o`00
o`3o]/40okK100X0okK13oooool7o`00o`P0003o2?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02?ooooo3P3o]/400`000000okK10?nf`@0/0?nf`@030000003o]/40okK102T0okK1
1Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo02?ooooo6P3o]/4010000?l0okK10?nf`@000?lP0?nf`@Co003o4@3o]/43o`00o`L0okK1
00?o003o0?nf`@3o]/402P3o]/4:ooooo`Co003o3oooool50000o`?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Sooooo`h0okK100<000000?nf`@3o]/40;03o]/400`000000okK1
0?nf`@0Z0?nf`@?ooooo00<00000ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0RoooooaX0okK100<0003o0?nf`@3o]/400P3o]/400`000?l0okK10?nf
`@0P0?nf`@Go003o203o]/45o`00o`/0okK10_l00?l;0?nf`@Gooooo1?l00?lHooooo`80003o00?o
ooooo`000?ooool04?ooool00ol0003oooooooooo`0Rooooo`l0okK100<000000?nf`@3o]/40;@3o
]/400`000000okK10?nf`@0Z0?nf`@03ooooo`00003ooooo027ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool08OoooolJ0?nf`@030000o`3o]/40okK100@0okK100<0003o
0?nf`@3o]/407`3o]/400ol00?l0okK10?nf`@020?nf`@So003o4P3o]/400ol00?l0okK10?nf`@08
0?nf`@;ooooo0ol00?lOooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool@
0?nf`@030000003o]/40okK102h0okK100<00000o`00003o]/40:@3o]/400ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo6@3o]/400`00
0?l0okK10?nf`@060?nf`@80003o7P3o]/400ol00?l0okK10?nf`@0N0?nf`@03o`00o`3o]/40okK1
00H0okK10ol00?lRooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool@0?nf
`@030000003o]/40okK10300okK100<000000?nf`@3o]/409P3o]/400`000000okK1ooooo`0Roooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023ooooo6@3o]/400`000?l0
okK10?nf`@090?nf`@80003o703o]/400ol00?l0okK10?nf`@0O0?nf`@03o`00o`3o]/40okK10080
okK10ol00?l20?nf`B?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Poooooa40
okK100<000000?nf`@3o]/40<@3o]/400`000000okK10?nf`@0T0?nf`@030000003o]/40okK102?o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08?oooolH0?nf`@030000
o`3o]/40okK100`0okK100<0003o0?nf`@3o]/40603o]/400ol00?l0okK10?nf`@0Q0?nf`@04o`00
o`3o]/7o003oo`00o`H0okK18_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023o
oooo4@3o]/400`000000okK10?nf`@0b0?nf`@030000003o]/40okK10280okK100<000000?nf`@3o
]/400P3o]/4Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01oooooo
5`3o]/420000oa00okK100<0003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0S0?nf`@03o`00
o`3o]/40okK100L0okK18Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo
4P3o]/400`000000okK10?nf`@0c0?nf`@03o`00003o]/40okK101h0okK10P0000000ol00000okK1
0?nf`@040?nf`B7ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oo
oolG0?nf`@030000o`3o]/40okK10140okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf
`@0R0?nf`@;o003o00<0okK1o`00o`3o]/401`3o]/4Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool07_oooolC0?nf`@030000003o]/40okK103@0okK100<000000?nf`@3o]/40703o
]/400`000000okK10?nf`@070?nf`B7ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool07_oooolG0?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/40503o]/40
0ol00?l0okK10?nf`@0P0?nf`@;o003o103o]/400ol00?l0okK10?nf`@060?nf`B3ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Noooooa<0okK100<000000?nf`@3o]/40=@3o]/43
000001T0okK10P00000;0?nf`B3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool07OoooolG0?nf`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/404P3o]/400ol0
0?l0okK10?nf`@0P0?nf`@03o`00o`3o]/40okK100D0okK100?o003o0?nf`@3o]/401@3o]/4Poooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07OoooolD0?nf`@030000003o]/40okK1
03P0okK100<000000?nf`@3o]/40503o]/42000000d0okK18?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0MoooooaH0okK100<0003o0?nf`@3o]/405@3o]/400`000?l0
okK10?nf`@060?nf`@L0oooo0`3o]/400ol00?l0okK10?nf`@0P0?nf`@03o`00o`3o]/40okK100L0
okK100?o003o0?nf`@3o]/40103o]/4Pooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool07OoooolD0?nf`@030000003o]/40okK10200okK11`3ooolB0?nf`@03o`000000000000000140
okK10P00000?0?nf`B3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
7OoooolE0?nf`@030000o`3o]/40okK101L0okK100@0003o0?nf`@3o]/40okK13P3oool00ol00?l0
okK10?nf`@0O0?nf`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/401@3o]/4Oooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07OoooolD0?nf`@030000003o]/40okK101`0
okK13`3ooolA0?nf`@<00000303o]/4200000180okK17oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0LoooooaH0okK100?o003o0?nf`@3o]/40603o]/400ol00?l0oooo
0?ooo`0=0?ooo`04o`00o`3oool0oooo0?oooah0okK100?o003o0?nf`@3o]/402P3o]/400ol00?l0
okK10?nf`@040?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0LoooooaD0
okK100<000000?nf`@3o]/406P3o]/4C0?oooa80okK13000000D0?nf`Aoooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool07?oooolF0?nf`@030000o`3o]/40okK101L0okK1
0P3oool00`000?l0oooo0?ooo`0<0?ooo`03o`00o`3oool0oooo00<0oooo6`3o]/400ol00?l0okK1
0?nf`@0;0?nf`@03o`00o`3o]/40okK100@0okK17oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01cooooo5@3o]/400`000000okK10?nf`@0H0?nf`AL0oooo<03o]/4Oooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo5@3o]/400`000?l0okK10?nf
`@0G0?nf`@<0oooo00<0003o0?ooo`3oool02`3oool00ol00?l0oooo0?ooo`060?oooaP0okK100?o
003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@040?nf`Akooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0LoooooaD0okK100<000000?nf`@3o]/405`3o]/4J0?ooobl0okK17_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0KoooooaD0okK100<0003o
0?nf`@3o]/405`3o]/450?ooo`030000o`3oool0oooo00X0oooo00?o003o0?ooo`3oool01`3ooolF
0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/400`3o]/4Nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06ooooolF0?nf`@030000003o]/40okK101H0okK1703oool^
0?nf`Akooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06ooooolE0?nf
`@030000o`3o]/40okK101H0okK11`3oool00`000?l0oooo0?ooo`080?ooo`03o`00o`3oool0oooo
00T0oooo503o]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100<0okK17_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo5P3o]/400`000000okK10?nf`@0E0?nf
`Ah0oooo;@3o]/4Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_o
oooo503o]/400`000?l0okK10?nf`@0F0?nf`@T0oooo00<0003o0?ooo`3oool01P3oool00ol00?l0
oooo0?ooo`0;0?oooa80okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@020?nf`Ako
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0KoooooaH0okK100<000000?nf`@3o
]/40503o]/4P0?ooob`0okK17_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Koooooa@0okK100<0003o0?nf`@3o]/405P3o]/4:0?ooo`030000o`3oool0oooo00@0oooo
00?o003o0?ooo`3oool0303ooolA0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40
0P3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06ooooolF0?nf`@030000
003o]/40okK101@0okK1803oool/0?nf`Akooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06ooooolC0?nf`@030000o`3o]/40okK101D0okK13@3oool00`000?l0oooo0?oo
o`020?ooo`03o`00o`3oool0oooo00h0oooo3`3o]/400ol00?l0okK10?nf`@0E0?nf`@04o`00o`3o
]/40okK10?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0KoooooaH0okK1
00<000000?nf`@3o]/404P3o]/4S0?ooob/0okK17_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Koooooa80okK100<0003o0?nf`@3o]/405@3o]/4>0?ooo`050000o`3o
ool0oooo0?ooool00?l04P3oool=0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/40
0P3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06ooooolF0?nf`@030000
003o]/40okK10140okK19@3oool[0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06_oooolB0?nf`@030000o`3o]/40okK101H0okK13`3oool010000?l0oooo0?oo
ool00?lB0?ooo``0okK100?o003o0?nf`@3o]/40603o]/401?l00?l0okK10?nf`@3o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06_oooolG0?nf`@030000003o]/40okK10140
okK19@3oool[0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6_oooolB0?nf`@030000o`3o]/40okK101D0okK1403oool010000?l0oooo0?ooool00?lC0?ooo`/0
okK100?o003o0?nf`@3o]/40603o]/401?l00?l0okK10?nf`@3o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_oooolG0?nf`@030000003o]/40okK10100okK19`3ooolZ0?nf
`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_oooolA0?nf`@03
0000o`3o]/40okK101H0okK14@3oool00`000?oo003o0?ooo`0C0?ooo`X0okK100?o003o0?nf`@3o
]/406P3o]/400ol00?l0okK10?nf`@0Mooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06_oooolG0?nf`@030000003o]/40okK10100okK19`3ooolZ0?nf`Agooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool06_oooolA0?nf`@030000o`3o]/40okK101D0okK1
4P3oool00ol00?l0003o0?ooo`0D0?ooo`P0okK100?o003o0?nf`@3o]/406`3o]/400ol00?l0okK1
0?nf`@0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_oooolG0?nf`@030000
003o]/40okK100l0okK1:@3ooolY0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06_oooolA0?nf`@030000o`3o]/40okK101D0okK14@3oool00ol00?l0oooo0000
o`0E0?ooo`L0okK100?o003o0?nf`@3o]/40703o]/400ol00?l0okK10?nf`@0Mooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06_oooolG0?nf`@030000003o]/40okK100l0okK1:@3o
oolY0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool@
0?nf`@030000o`3o]/40okK101H0okK1403oool01Ol00?l0oooo0?ooo`3ooooo003o01@0oooo1`3o
]/400ol00?l0okK10?nf`@0M0?nf`@03o`00o`3o]/7ooooo01cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0JoooooaL0okK100<000000?nf`@3o]/403`3o]/4Y0?ooobT0okK17Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Joooooa00okK100<0003o
0?nf`@3o]/405P3o]/4?0?ooo`03o`00o`3oool0oooo0080oooo00<0003o0?ooo`3oool04P3oool7
0?nf`@03o`00o`3o]/40okK101d0okK100?o003o0?nf`Oooool07?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01[ooooo5`3o]/400`000000okK10?nf`@0?0?nf`BT0oooo:@3o]/4M
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo403o]/400`00
0?l0okK10?nf`@0E0?nf`@l0oooo00?o003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0C0?oo
o`D0okK100?o003o0?nf`@3o]/407`3o]/400ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_oooolG0?nf`@030000003o]/40okK100h0okK1:`3ooolX0?nf
`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool?0?nf`@03
0000o`3o]/40okK101H0okK13P3oool00ol00?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180
oooo103o]/400ol00?l0okK10?nf`@0P0?nf`@03o`00oooooooooooo01_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0JoooooaL0okK100<000000?nf`@3o]/403P3o]/4[0?ooobP0
okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Ioooooa00okK1
00<0003o0?nf`@3o]/405P3o]/4=0?ooo`03o`00o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4P3oool40?nf`@03o`00o`3o]/40okK10200okK100?o003oooooooooool06oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Wooooo6@3o]/400`000000okK10?nf`@0=0?nf`B/0oooo
:03o]/4Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo403o
]/400`000?l0okK10?nf`@0F0?nf`@/0oooo0_l00?l:0?ooo`030000o`3oool0oooo0140oooo0`3o
]/400ol00?l0okK10?nf`@0Q0?nf`@03o`00oooooooooooo01_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0IoooooaT0okK100<000000?nf`@3o]/403@3o]/4[0?ooobP0okK17Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Ioooooa00okK100<0003o
0?nf`@3o]/405P3o]/4:0?ooo`03o`00o`3oool0oooo00X0oooo00<0003o0?ooo`3oool04@3oool3
0?nf`@03o`00o`3o]/40okK10240okK100?o003oooooooooool06oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Wooooo6@3o]/400`000000okK10?nf`@0=0?nf`B/0oooo:03o]/4M
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo403o]/400`00
0?l0okK10?nf`@0F0?nf`@T0oooo00?o003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0@0?oo
o`80okK100?o003o0?nf`@3o]/408P3o]/400ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06OoooolI0?nf`@030000003o]/40okK100d0okK1:`3ooolX0?nf
`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool>0?nf`@03
0000o`3o]/40okK101L0okK1203oool00ol00?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0100
oooo0P3o]/400ol00?l0okK10?nf`@0S0?nf`@03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0JoooooaP0okK100<000000?nf`@3o]/403@3o]/4[0?ooobP0
okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`h0okK1
00<0003o0?nf`@3o]/405`3o]/470?ooo`03o`00o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o]/7o003o0?nf`@0U0?nf`@03o`00oooooooooooo01[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0JoooooaP0okK100<000000?nf`@3o]/403@3o]/4[0?ooobP0okK1
7Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`h0okK100<0
003o0?nf`@3o]/40603o]/450?ooo`03o`00o`3oool0oooo0100oooo00<0003o0?ooo`3oool03P3o
ool20?nf`@03o`00o`3o]/40okK102@0okK100?o003oooooooooool06_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo603o]/400`000000okK10?nf`@0>0?nf`BT0oooo:@3o
]/4Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo3P3o]/40
0`000?l0okK10?nf`@0H0?nf`@@0oooo00?o003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0=
0?ooo`80okK100?o003o0?nf`@3o]/40903o]/400ol00?ooooooooooo`0Jooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06_oooolH0?nf`@030000003o]/40okK100h0okK1:@3ooolY
0?nf`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool>0?nf
`@030000o`3o]/40okK101P0okK10`3oool00ol00?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00d0oooo00<0okK1o`00o`3o]/409P3o]/400ooooooo003oooooo`0Jooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_oooolH0?nf`@030000003o]/40okK100h0okK1:@3ooolY0?nf
`Agooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool>0?nf`@03
0000o`3o]/40okK101P0okK100<0ooooo`00ool00?l05`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?nf`Ol00?l0okK102H0okK100?oooooo`00ooooool06_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01[ooooo603o]/400`000000okK10?nf`@0>0?nf`BT0oooo:@3o]/4Mooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo3P3o]/400`000?l0okK1
0?nf`@0G0?nf`@;o003o6@3oool00`000?l0oooo0?ooo`0;0?ooo`80okK100?o003o0?nf`@3o]/40
9@3o]/400ooooooo003oooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_oooolH0?nf`@030000003o]/40okK100l0okK19`3ooolZ0?nf`Agooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool06_ooool>0?nf`@030000o`3o]/40okK101H0okK100?o
003o0?nf`@3o]/406@3oool00`000?l0oooo0?ooo`0;0?ooo`80okK100?o003o0?nf`@3o]/409@3o
]/400ooooooo003oooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_oo
oolH0?nf`@030000003o]/40okK100l0okK19`3ooolZ0?nf`Agooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool06_ooool>0?nf`@030000o`3o]/40okK101@0okK10_l00?l4
0?nf`AP0oooo00@0003oo`000?l0003o00002@3oool30?nf`@03o`00o`3o]/40okK102D0okK100?o
ooooo`00ooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo603o
]/400`000000okK10?nf`@0@0?nf`BD0oooo:`3o]/4Mooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01_ooooo303o]/400`000?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40
okK100H0okK15P3oool5o`0000P0oooo0P3o]/400ol00?l0okK10?nf`@0V0?nf`@03ooooool00?oo
oooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0KoooooaL0okK100<00000
0?nf`@3o]/404P3o]/4S0?ooob/0okK17Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Kooooo``0okK100<0003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@070?nf
`AH0oooo1Ol000070?ooo`<0okK100?o003o0?nf`@3o]/409@3o]/42ooooo`03o`00oooooooooooo
01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0KoooooaH0okK100<000000?nf
`@3o]/404`3o]/4R0?ooob/0okK17_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Kooooo``0okK100<0003o0?nf`@3o]/404@3o]/42o`00o`/0okK15@3oool5o`0000H0
oooo103o]/400ol00?l0okK10?nf`@0U0?nf`@;ooooo00?o003oooooooooool06Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo5P3o]/400`000000okK10?nf`@0D0?nf`B00
oooo;03o]/4Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo
303o]/400`000?l0okK10?nf`@0?0?nf`@;o003o3P3o]/4E0?ooo`?o00001P3oool50?nf`@03o`00
o`3o]/40okK102D0okK10_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06ooooolF0?nf`@030000003o]/40okK101D0okK17P3oool]0?nf`Akooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool<0?nf`@030000o`3o
]/40okK100h0okK100?o003o0?nf`@3o]/403`3o]/4E0?ooo`030000o`3oool0oooo00@0oooo1P3o
]/400ol00?l0okK10?nf`@0U0?nf`@;ooooo00?o003oooooooooool06Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01_ooooo5P3o]/400`000000okK10?nf`@0F0?nf`A`0oooo;P3o
]/4Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo303o]/40
0`000?l0okK10?nf`@0;0?nf`@;o003o4`3o]/4D0?ooo`030000o`3oool0oooo0080oooo1`3o]/40
0ol00?l0okK10?nf`@0V0?nf`@;ooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01cooooo5@3o]/400`000000okK10?nf`@0G0?nf`AT0oooo<03o]/4N
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo303o]/400`00
0?l0okK10?nf`@080?nf`@?o003o5`3o]/4C0?ooo`030000o`3oool0okK100P0okK100?o003o0?nf
`@3o]/409@3o]/43ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0LoooooaD0okK100<000000?nf`@3o]/406@3o]/4E0?oooc40okK17oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo``0okK100<0003o0?nf`@3o
]/401P3o]/42o`00oa`0okK14@3oool00`000?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK102D0
okK10oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool07?oooolE0?nf`@030000003o]/40okK101/0okK14@3ooolc0?nf`Aoooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool07Oooool;0?nf`@030000o`3o]/40okK100@0okK1
0_l00?lP0?nf`@d0oooo0P3o]/400`000?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK102D0okK1
0oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7OoooolD0?nf`@030000003o]/40okK101d0okK13@3ooole0?nf`Aoooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool07Oooool;0?nf`@030000o`3o]/40okK10080okK10_l0
0?lV0?nf`@D0oooo1P3o]/400`000?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK102@0okK10ooo
ool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Ooo
oolD0?nf`@030000003o]/40okK10240okK11@3ooolh0?nf`B3ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool07Oooool;0?nf`@030000o`3o]/7o003o00;o003o<`3o]/40
0`000?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK102@0okK10oooool00ol00?ooooooooooo`09
ooooo`?o00003_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo503o]/40
0`000000okK10?nf`@0]0?nf`@l000008P3o]/4Pooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01kooooo2@3o]/43o`00ocH0okK100<0003o0?nf`@3o]/40203o]/400ol0
0?l0okK10?nf`@0T0?nf`@?ooooo00?o003oooooooooool02?ooool5o`0000gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Noooooa80okK100<000000?nf`@3o]/40:P3o]/440000
00l0okK10`00000O0?nf`B3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool07_ooool40?nf`@Go003o00<0okK10000o`3o]/40=P3o]/400`000?l0okK10?nf`@080?nf`@03
o`00o`3o]/40okK102<0okK11?ooool00ol00?ooooooooooo`08ooooo`Go00003Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01kooooo4P3o]/400`000000okK10?nf`@0U0?nf`@D0
00005P3o]/44000001X0okK18Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Nooooo`Co003o1`3o]/400`000?l0okK10?nf`@0e0?nf`@030000o`3o]/40okK100L0okK1
00?o003o0?nf`@3o]/408`3o]/44ooooo`03o`00oooooooooooo00Sooooo1Ol0000=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07ooooolA0?nf`@030000003o]/40okK102<0okK1
0P00000O0?nf`@03o`0000000000okK101L0okK18Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Iooooo`Go003o0_ooool90?nf`@030000o`3o]/40okK103D0okK100?o
003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@0R0?nf`@Cooooo00?o003oooooooooool02_oo
ool3o`0000kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Poooooa00okK100<0
00000?nf`@3o]/40803o]/43000002<0okK10P00000E0?nf`B;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool05?ooool5o`00o`Oooooo2@3o]/400`000?l0okK10?nf`@0e
0?nf`@030000o`3o]/40okK100L0okK100?o003o0?nf`@3o]/408@3o]/45ooooo`03o`00oooooooo
oooo01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Poooooa00okK100<00000
0?nf`@3o]/407P3o]/42000002P0okK10P00000B0?nf`B?ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooool00?l05?l00?l=ooooo`P0okK100<0003o0?nf`@3o]/40=@3o]/400`00
0?l0okK10?nf`@070?nf`@03o`00o`3o]/40okK101l0okK11_l00?l00ooooooo003oooooo`0Loooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool?0?nf`@030000003o]/40okK1
01`0okK10P00000/0?nf`@030000003o]/40okK100l0okK18oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Qooooo`T0okK100<0003o0?nf`@3o]/40=03o]/400`000?l0
okK10?nf`@070?nf`@03o`00o`3o]/40okK101H0okK12Ol00?l00`3o]/7oooooooooo`03ooooo`Go
003o6_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo3`3o]/400`000000
okK10?nf`@0K0?nf`@030000003o]/40okK102d0okK100?o00000000003o]/403@3o]/4Tooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo2@3o]/400`000?l0okK1
0?nf`@0d0?nf`@030000o`3o]/40okK100P0okK100?o003o0?nf`@3o]/404@3o]/44o`00o`X0okK1
1_ooool01?l00?ooooooooooooooool4o`00oaKooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Qooooo`h0okK100<000000?nf`@3o]/406P3o]/4200000380okK10P00000<0?nf`BCo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08_ooool80?nf`@030000
o`3o]/40okK103@0okK100<0003o0?nf`@3o]/40203o]/400ol00?l0okK10?nf`@0?0?nf`@;o003o
3P3o]/45ooooo`03o`00oooooooooooo00Kooooo0ol00?lCooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool08_ooool=0?nf`@030000003o]/40okK101P0okK100?o00000000003o]/40
=@3o]/42000000X0okK19?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Sooooo`P0okK100<0003o0?nf`@3o]/40<`3o]/400`000?l0okK10?nf`@080?nf`@03o`00o`3o
]/40okK100/0okK11?l00?l?0?nf`@Kooooo00?o003oooooooooool02Oooool3o`00oa3ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo``0okK100<000000?nf`@3o]/405`3o
]/400`000000okK10?nf`@0h0?nf`@030000003o]/40okK100H0okK19Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0=ooooo`?o00004oooool80?nf`@030000o`3o]/40
okK103<0okK100<0003o0?nf`@3o]/40203o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40
okK10100okK11oooool00ol00?ooooooooooo`0<ooooo`;o003o3_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02?ooooo303o]/400`000000okK10?nf`@0F0?nf`@030000003o]/40
okK103X0okK100<000000?nf`@3o]/40103o]/4Vooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00cooooo1Ol0000Cooooo`P0okK100<0003o0?nf`@3o]/40<P3o]/400`00
0?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100P0okK10_l00?lC0?nf`@Kooooo00?o003ooooo
ooooool03oooool2o`00o`cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Toooo
o`X0okK100<000000?nf`@3o]/405P3o]/400`000000okK10?nf`@0l0?nf`@030000003o]/40okK1
00<0okK19_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0<ooooo`Go
00004oooool80?nf`@030000o`3o]/40okK10380okK100<0003o0?nf`@3o]/402@3o]/400ol00?l0
okK10?nf`@040?nf`@?o003o503o]/47ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo2P3o]/400`000000
okK10?nf`@0D0?nf`@0300000?l00000okK10140okK12P0000000ol00000000000000003000001d0
okK100?o00000?nf`@3o]/400P3o]/4Wooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00cooooo1Ol0000Dooooo`L0okK100<0003o0?nf`@3o]/40<P3o]/400`000?l0okK1
0?nf`@090?nf`@03o`00o`3o]/40okK100<0okK100?o003o0?nf`@3o]/405@3o]/47ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02Gooooo2@3o]/400`000000okK10?nf`@0C0?nf`@030000003o]/40okK100l0okK1
0`00000@0?nf`@800000703o]/4010000000okK10?nf`@3o]/4Wooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00gooooo0ol0000Fooooo`L0okK100<0003o0?nf`@3o]/40
<@3o]/400`000?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK10080okK10_l00?lF0?nf`@Oooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool09_ooool80?nf`@030000003o]/40okK10180okK100<000000?nf`@3o]/40
303o]/44000001D0okK10P00000K0?nf`@030000003o]/7ooooo02Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool09oooool70?nf`@03o`00o`3o]/40okK10300okK100<0
003o0?nf`@3o]/402@3o]/401Ol00?l0okK10?nf`@3o]/7o003o01L0okK11oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Wooooo`H0okK100<000000?nf`@3o]/404P3o]/400ol00000okK10?nf`@0;0?nf`@03o`00
00000000okK101X0okK10P00000J0?nf`@0300000?oooooooooo02Kooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0:?ooool60?nf`@030000o`3o]/40okK10300okK100<0
003o0?nf`@3o]/402@3o]/401?l00?l0okK10?nf`Ol00?lG0?nf`@Oooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:?ooool50?nf`@030000003o]/40okK10180okK100<000000?nf`@3o]/402@3o]/42000001l0okK1
00<00000o`00000000005P3o]/400ooooooo0000ooooo`0Wooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02Sooooo1`3o]/400`000?l0okK10?nf`@0_0?nf`@030000o`3o
]/40okK100X0okK10_l00?lG0?nf`@Sooooo00?o003oooooooooool06Oooool2o`00o`Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`D0okK100?o00000?nf`@3o]/404@3o
]/400`000000okK10?nf`@080?nf`@800000903o]/400`000000okK10?nf`@0B0?nf`@?ooooo00<0
0000ooooooooool09Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Y
ooooo`H0okK100<0003o0?nf`@3o]/40;`3o]/400`000?l0okK10?nf`@090?nf`@;o003o603o]/47
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Wooooo103o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40
okK100P0okK100<000000?nf`@3o]/402`3o]/4<000000h0okK100<000000?nf`@3o]/404@3o]/44
ooooo`0300000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0:_ooool50?nf`@030000o`3o]/40okK102l0okK100<0003o0?nf`@3o]/402@3o]/42o`00
oaL0okK12?ooool00ol00?ooooooooooo`0Mooooo`05o`00ooooooooooooooooool000004Oooool0
0ol0003oooooooooo`0Zooooo`<0okK100<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@07
0?nf`@0300000?l00000okK100T0okK10P0000000ol0000000000?nf`@0;0?nf`@0400000?l00000
0000000000/0okK10P00000@0?nf`@Kooooo00<00000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0[ooooo`D0okK100<0003o0?nf`@3o]/40;P3o]/40
0`000?l0okK10?nf`@080?nf`@04o`00o`3o]/40okK1o`00oaD0okK12?ooool00ol00?oooooooooo
o`0Oooooo`04o`00ooooooooooooo`00017ooooo00?o0000ooooooooool0:oooool20?nf`@030000
003o]/40okK100l0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@060?nf`@<00000
503o]/42000000/0okK100<000000?nf`@3o]/40303o]/47ooooo`0300000?oooooooooo02?ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?ooool50?nf`@030000o`3o
]/40okK102d0okK100<0003o0?nf`@3o]/401`3o]/401Ol00?l0okK10?nf`@3o]/7o003o01@0okK1
2?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo0000017ooooo00?o0000ooooooooool0
;?ooool00`3o]/4000000?nf`@0?0?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40
1@3o]/42000001T0okK10P00000:0?nf`@030000003o]/40okK100X0okK12Oooool00`00003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02gooooo103o
]/400`000?l0okK10?nf`@0]0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/400P3o
]/400ol00?l0okK10?nf`@0@0?nf`@[ooooo00?o003oooooooooool08oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02cooooo00<000000?nf`@3o]/403P3o]/400`000000okK10?nf
`@070?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/406`3o]/400`000000okK10?nf
`@080?nf`@030000003o]/40okK100L0okK12oooool00`00003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo02kooooo103o]/400`000?oo003o0?nf`@0/
0?nf`@030000o`3o]/40okK100D0okK100?o003o0?nf`@3o]/40103o]/400ol00?l0okK10?nf`@0>
0?nf`@[ooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02cooooo00<00000ooooo`3o]/403@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40
okK100D0okK100?o00000?nf`@3o]/40203o]/4<000000P0okK100?o00000000000000002@3o]/40
0`000000okK10?nf`@050?nf`@cooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0`ooooo`<0okK100<0003o0?nf`@3o]/40:`3o]/400`00
0?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK100@0okK100?o003o0?nf`@3o]/403@3o]/4;oooo
o`03o`00oooooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/oooo
o`0400000?ooooooooooooooo``0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@04
0?nf`@800000203o]/43000000`0okK10`0000080?nf`@030000003o]/40okK100L0okK100<00000
0?nf`@3o]/400`3o]/4=ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0<Oooool30?nf`@030000o`3o]/40okK102<0okK11_l00?l00`3o
]/40003o0?nf`@050?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/402`3o]/4;oooo
o`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[oooo
o`0300000?oooooooooo00?ooooo2P3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/401@3o]/4300000180okK100<000000?nf`@3o]/401P3o]/400`00
0000okK10?nf`@070?nf`@040000003o]/40okK10?nf`@oooooo00<00000ooooooooool08Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0booooo`<0okK100<0003o0?nf
`@3o]/407@3o]/45o`00o`H0okK100<0003oo`00ool00?l0103o]/400ol00?l0okK10?nf`@070?nf
`@03o`00o`3o]/40okK100X0okK12oooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0:oooool00`00003oooooooooo`04ooooo`P0okK100<000000?nf
`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o00000000
003o]/405@3o]/400`00003o0000000000060?nf`@030000003o]/40okK100L0okK100?o00000?nf
`Oooool04?ooool00`00003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo03?ooooo0`3o]/400`000?l0okK10?nf`@0I0?nf`@?o003o2`3o]/4010000?l0
okK10?nf`Ol00?l30?nf`@03o`00o`3o]/40okK100L0okK100?o003o0?nf`@3o]/402@3o]/4;oooo
o`03o`00oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[oooo
o`0300000?oooooooooo00Gooooo1`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/400`3o]/42000000P0okK12@00000:0?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/401P3o]/400`00003oooooooooo`0@ooooo`0300000?oooooooooo
023ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=Oooool20?nf`@80
003o5`3o]/42o`00o`h0okK100@0003o0?nf`@3o]/40okK10ol00?l;0?nf`@03o`00o`3o]/40okK1
00H0okK13?ooool00ol00?ooooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:oooool00`00003oooooooooo`07ooooo`D0okK100<000000?nf`@3o]/401@3o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/401@3o]/430000
00T0okK10`0000080?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/42oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool08?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0fooooo`<0okK100<0003o0?nf`@3o]/404`3o]/400ol00?l0
okK10?nf`@0>0?nf`@030000o`3o]/40okK10080okK10_l00?l;0?nf`@03o`00o`3o]/40okK100D0
okK12oooool2o`00ob_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`03
00000?oooooooooo00Sooooo0`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@040?nf`@03o`0000000000okK100h0
okK10P0000070?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/43ooooo`03
00000?oooooooooo013ooooo00<00000ooooooooool07oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0hooooo`80okK100<0003o0?nf`@3o]/40403o]/42o`00oa40okK1
00D0003o0?nf`@3o]/40okK1o`00o`020?nf`@;o003o2P3o]/400ol00?l0okK10?nf`@020?nf`@co
oooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_o
oooo00<00000ooooooooool02_ooool00`3o]/4000000?nf`@050?nf`@030000003o]/40okK100@0
okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@8000004`3o]/400ol00000
00000?nf`@050?nf`@030000003o]/40okK100@0okK100<000000?nf`Oooool01Oooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo01oooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0>_ooool00`3o]/40003o0?nf`@0?0?nf`@03o`00o`3o]/40okK10100okK1
00<0003o0?nf`@3o]/400P3o]/400ol00?l0okK10?nf`@020?nf`@03o`00o`3o]/40okK100P0okK1
00?o003o0?nf`Oooool03?ooool00ol00?ooooooooooo`0/ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:oooool00`00003oooooooooo`0;ooooo`030000003o]/40okK100@0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/401@3o]/49000000L0okK10P0000050?nf`@03o`00003o]/40okK100<0okK1
00<00000ooooooooool01Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01oooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>oooool00`3o]/40003o0?nf
`@0=0?nf`@03o`00o`3o]/40okK10140okK100D0003o0?nf`@3o]/40okK1o`00o`060?nf`@03o`00
o`3o]/40okK100P0okK100?o003oooooooooool02_ooool00ol00?ooooooooooo`0]ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK10P0000050?nf`@<000002@3o]/43000000H0okK10P0000040?nf`@040000
003o]/40okK10?nf`@;ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo01kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
?Oooool00`000?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK10140okK100D0003o0?nf`@3o]/40
okK1o`00o`060?nf`@03o`00o`3o]/40okK100H0okK10_ooool00ol00?ooooooooooo`08ooooo`;o
003o<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`03ooooo`030?nf`@000000okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o
]/403@3o]/43000000D0okK100<000000?nf`@3o]/400P3o]/400`00003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Nooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03kooooo00<0003oooooooooool0
2@3o]/400ol00?l0okK10?nf`@0A0?nf`@030000o`3o]/40okK10080okK100?o003o0?nf`@3o]/40
103o]/400ol00?l0okK10?nf`@030?nf`@Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00003ooooo
ooooo`0;ooooo`0300000?oooooooooo00Cooooo00<00000ooooo`3o]/400P3o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/42000001<0okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@03ooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01kooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?oooool00`000?oooooooooo
o`02ooooo`D0okK100?o003o0?nf`@3o]/404P3o]/401@000?l0okK10?nf`@3o]/7o003o00P0okK1
00?o003o0?nf`Oooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo037ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`050000003o]/40okK10?nf`@00
0000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK12@0000070?nf`@06
0000003o]/40okK10?nf`Oooool000001Oooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo00Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo043ooooo0P000?l5ooooo`80okK100?o003o0?nf
`@3o]/404P3o]/401@000?l0okK10?nf`@3o]/7o003o00L0okK10_ooool00ol00?ooooooooooo`09
ooooo`04o`00ooooooooooooooooo`;o003o=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02[ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo00;ooooo00H00000oooooooooooooooo0?nf`@0000040?nf`@050000003o]/40okK10?nf
`@0000001@3o]/400ol0000000000?nf`@080?nf`@8000001P3o]/400`00003oooooooooo`02oooo
o`0300000?oooooooooo00;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`04oooo
o`0300000?oooooooooo00gooooo00<00000ooooooooool07_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`12ooooo`80003o1Oooool00ol00?l0okK10?nf`@0A0?nf`@03
0000o`3o]/40okK10080okK100?o003o0?nf`@3o]/400P3o]/46ooooo`03o`00oooooooooooo00Wo
oooo0ol00?lfooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00003o
ooooooooo`0:ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00oooool01Ol0003o
ooooooooooooool0000000;ooooo0P3o]/401@000000okK10?nf`@3o]/40000000D0okK100<00000
0?nf`@3o]/402`3o]/42000000030?nf`Ooooooooooo00;ooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo01kooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0A?ooool00`000?ooooooooooo`02ooooo`04o`00oooooooooooo
oooooa00okK100<0003o0?nf`@3o]/400P3o]/400ol00?l0okK1ooooo`08ooooo`03o`00oooooooo
oooo00Wooooo0_l00?lgooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool0
0`00003oooooooooo`0:ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D000000?nf`@3o]/40okK10000
00040?nf`@030000003o]/40okK100`0okK10_ooool2000000Cooooo00D00000oooooooooooooooo
00000004ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo01kooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0AOooool20000o`03ooooool00?oooooo00cooooo103o]/43ooooo`050000oooo
ooooooooooooool00?l02oooool00ol00?ooooooooooo`07ooooo`;o003o0_ooool00ol00?oooooo
ooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00003ooooo
ooooo`09ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00oooool01@00003ooooo
ooooooooool0000000Cooooo00D00000oooooooooooooooo00000003ooooo`80000000?ooooo0?nf
`@3o]/400P3o]/43ooooo`D000001_ooool00`00003oooooooooo`02ooooo`0500000?oooooooooo
ooooo`0000001?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000
ooooooooool02oooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo04Oooooo0P000?lCooooo`030000oooooooooooo00;ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`03ooooo`?o003o1Oooool00ol00?ooooooooooo`0coooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00003oooooooooo`09oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02oooo
o`0500000?ooooooooooooooool000000oooool01@00003oooooooooooooool0000000Gooooo1@00
0005ooooo`8000001Oooool00`00003oooooooooo`02ooooo`05o`000?ooooooooooooooo`000000
1?ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo04Sooooo00Co003o0000o`000?l0003o4?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo03;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool00oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00;ooooo00@00000ooooooooool000001?ooool01@00003oooooooooooooool00000
00Cooooo00<00000ooooooooool02_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo
00;ooooo00D00000oooooooooooooooo00000004ooooo`03o`000?oooooooooo00;ooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`02oooo
o`80003o3_ooool01@000?oooooooooooooooooo003o00gooooo00?o003oooooooooool00_l00?l;
ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Z
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00;ooooo00@00000ooooooooool000000oooool01@00003ooooooooo
ooooool0000000Cooooo00<00000ooooooooool03?ooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00;ooooo00D00000oooooooooooooooo00000003ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01ko
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Aoooool00ol00?oooooo
ooooo`04ooooo`@0003o1oooool3o`0000050000ooooooooooooooooool00?l03?ooool4o`00o`ko
oooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[o
oooo00<00000ooooooooool02Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;o
oooo00D00000oooooooooooooooo00000002ooooo`0300000?oooooooooo00;ooooo00@00000oooo
oooooooo00001?ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00;ooooo00D00000
oooooooooooooooo00000004ooooo`0500000?ooooooooooooooo`0000001?ooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool07_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo00Sooooo1000
0?l2ooooo`Go00002_l00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oooooo013ooooo00?o
003oooooooooool0;oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00D0
0000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000oooool01@00003o
ooooooooooooool0000001;ooooo00?o0000ooooooooool00_ooool01@00003oooooooooooooool0
000000?ooooo00Go0000oooooooooooooooo00000004ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool03?ooool20000o`Go00003Ol00?l4
ooooo`03o`00oooooooooooo013ooooo0ol00?l^ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0:_ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool00_ooool01@00003oooooooooooooool0000000;ooooo00D00000oooooooooooooooo
00000003ooooo`0500000?ooooooooooooooo`0000001Oooool8000000Gooooo00<00000oooooooo
ool00oooool01?l0003oooooooooo`000003ooooo`0500000?ooooooooooooooo`0000001?ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool07_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo
00gooooo00?o003oo`000?l000000ol00003ooooo`03o`00oooooooooooo00Oooooo0_l00?l2oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`03oooo
o`0500000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000;ooooo00D0
0000oooooooooooooooo00000003ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
1_ooool2000000Cooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0000000?o
oooo00D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo04Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03o`0000Co
oooo00?o003oooooooooool02Oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooooooo02[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`0300000?oooooooooo00So
oooo00<00000ooooooooool00oooool01@00003oooooooooooooool0000000?ooooo00D00000oooo
oooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000_ooool00`00003ooooooooo
o`03ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`02ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo00000004ooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Nooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool0
2oooool01Ol00?ooooooooooooooool0003o00Kooooo00?o003oooooooooool02_ooool2o`00oaOo
oooo0_l00?lZooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00`00003o
ooooooooo`08ooooo`0300000?oooooooooo00?ooooo00D00000oooooooooooooooo00000003oooo
o`0500000?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0000000;ooooo00<0
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool00_ooool01000003oooooooooo`000003ooooo`0500000?ooooooooooooooo`00
00001?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000oooooooo
ool07_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`18ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`03ooooo`03o`00
oooooooooooo00_ooooo0_l00?lIooooo`?o003o9oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`03ooooo`050000
0?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000;ooooo00D00000oooo
oooooooooooo00000002ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003ooooooooo
ooooool0000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00ooo
ool00`000?ooooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l06ooo
ool01?l00?oo0000o`000?l0000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00?ooooo00D00000oooooooooooo
oooo00000003ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000000oooool0
1@00003oooooooooooooool0000000kooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`02ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo00000003ooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Nooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`02ooooo`030000ool00?oooooo00Gooooo00?o003oooooooooool0
2oooool01?l00?ooooooooooool00?lJooooo`Go00008_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`03ooooo`05
00000?ooooooooooooooo`0000000oooool01000003oooooooooo`000003ooooo`0400000?oooooo
oooo000000?ooooo00D00000oooooooooooooooo0000000?ooooo`0300000?oooooooooo00;ooooo
00D00000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04So
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`030000oooooooooooo00Go
oooo00?o003oooooooooool02oooool01?l00?ooooooooooool00?lJooooo`Go000000?o003ooooo
ooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`03ooooo`0500000?ooooooooooooooo`0000000oooool0
1000003oooooooooo`000003ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooo
oooo0000000?ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000002oooo
o`0500000?ooooooooooooooo`0000000oooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`02ooooo`030000oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo1Ol000001?oooooo003oo`00ool00?lN
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00`00003oooooooooo`07
ooooo`0300000?oooooooooo00?ooooo00D00000oooooooooooooooo00000003ooooo`0400000?oo
oooooooo000000?ooooo00@00000ooooooooool000000oooool01@00003oooooooooooooool00000
00oooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0000000?ooooo00@00000
ooooooooool000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03
ooooo`030000oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01Oooooo0ol00005ooooo`Co003o5_ooool3o`00o`03ooooool0003o
oooo013ooooo00?o0000ooooooooool0;?ooool00`00003oooooooooo`07ooooo`0300000?oooooo
oooo00?ooooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000?ooooo
00@00000ooooooooool000000oooool01@00003oooooooooooooool0000000oooooo00<00000oooo
ooooool00_ooool01@00003oooooooooooooool0000000?ooooo00@00000ooooooooool000000ooo
ool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo04Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`030000oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo02?ooooo2Ol00?l4ooooo`Wo003o1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02cooooo00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`0500000?oooooo
ooooooooo`0000000oooool01000003oooooooooo`000003ooooo`0400000?oooooooooo000000?o
oooo00D00000oooooooooooooooo0000000?ooooo`0300000?oooooooooo00;ooooo00D00000oooo
oooooooooooo00000003ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool00_oo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00oooool00`000?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0[ooooo`Co003o3Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`03ooooo`0500000?ooooooooooooooo`0000000oooool01000003ooooooooo
o`000003ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo0000000?oooo
o`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooo
oooo000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1;ooooo`04o`00ooooooooooooo`00o`Kooooo00<0003oooooooooool01ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0??oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo
00000002ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo00000003oooo
o`0300000?oooooooooo00cooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0
000000;ooooo00D00000oooooooooooooooo00000003ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0C?ooool00ol00?ooooooo`00o`05
ooooo`030000oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02
ooooo`0500000?ooooooooooooooo`0000000_ooool01000003oooooooooo`000003ooooo`050000
0?ooooooooooooooo`0000000oooool00`00003o0000ooooo`0<ooooo`0300000?oooooooooo00;o
oooo00D00000oooooooooooooooo00000002ooooo`0500000?ooooooooooooooo`0000000oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
04gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0kooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0;Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0000000;ooooo00@00000
ooooooooool000000oooool01@00003oooooooooooooool0000000Cooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000_ooool01@00003o
ooooooooooooool0000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`03oooo
o`0300000?oooooooooo00Oooooo00<00000ooooooooool08?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1=ooooo`?o003o0_ooool00`000?ooooooooooo`0;ooooo`03
o`00oooooooooooo00?ooooo0_l00?l<ooooo`03o`00oooooooooooo03_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0]ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000_ooool01@00
003oooooooooooooool0000000;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00_ooool00`00003oooooooooo`02
ooooo`0400000?oooooooooo000000?ooooo00D00000oooooooooooooooo00000003ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_l0
0?l00`000?ooooooooooo`0;ooooo`04o`00ooooooooooooooooo`;o003o3_ooool00ol00?oooooo
ooooo`0kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool01@00003ooooo
ooooooooool0000000;ooooo00@00000ooooooooool000000oooool01@00003ooooooooooooooooo
000000Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`0500000?oooooo
ooooooooo`0000000oooool01000003oooooooooo`000003ooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo027ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0COooool01_l00?oooooooooo
ooooool0003oo`00o`gooooo0ol000000ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo03_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`0300000?oooooooooo00Oo
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`02ooooo`05o`000?oooooooooooooo
o`0000000_ooool01@00003oooooooooooooool0000000;ooooo00@00000oooooooooooooooo0P00
0005ooooo`P0000000?o0000ooooooooool00oooool00`00003oooooooooo`02ooooo`0500000?oo
ooooooooooooo`0000000_ooool01@00003oooooooooooooool0000000Cooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo027ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0COooool01?l00?ooooooooooo`000?l2ooooo`?o
003o2Oooool5o`00013ooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02kooooo00<00000ooooooooool01oooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00;ooooo00D00000oooooooooooooooo00000002ooooo`0500000?oooooooooo
ooooo`0000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo013ooooo00<00000
ooooooooool00_ooool01@00003oooooooooooooool0000000;ooooo00D00000oooooooooooooooo
00000004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo00?o
003oooooo`000?l01_ooool9o`00o`Go00004?ooool00ol00?ooooooooooo`0kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0;oooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00;ooooo00D00000oooooooooooooooo00000004ooooo`0400000?oooooooooo000000?o
oooo00D00000oooooooooooooooo00000004ooooo`03o`000?oooooooooo00kooooo00<00000oooo
ooooool00_ooool01@00003oooooooooooooool0000000;ooooo00D00000oooooooooooooooo0000
0004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo00?o003o
0000ooooool03oooool5o`00013ooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02oooooo00<00000ooooooooool01oooool00`00003oooooooooo`03
ooooo`0500000?ooooooooooooooo`0000000oooool01@00003oooooooooooooool0000000?ooooo
00D00000oooooooooooooooo00000004ooooo`03o`000?oooooooooo00cooooo00<00000oooooooo
ool00_ooool01Ol0003oooooooooooooool0000000?ooooo00D00000oooooooooooooooo00000004
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01oooool00`00003oooooooooo`0R
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo063ooooo0ol0001?oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Ooooonfo`00017ooooo]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 g
.01923 .06727 m
.03846 .05797 L
.03957 .05769 L
.05769 .0503 L
.07692 .04515 L
.09615 .04187 L
.11538 .03964 L
.12698 .03846 L
.13462 .0377 L
.15385 .03559 L
.17308 .0332 L
.19231 .03068 L
.21154 .0282 L
.23077 .02589 L
.25 .02382 L
.26923 .02201 L
.28846 .02048 L
.30726 .01923 L
.01923 .01923 L
F
0 g
.01923 .06727 m
.03846 .05797 L
.03957 .05769 L
.05769 .0503 L
.07692 .04515 L
.09615 .04187 L
.11538 .03964 L
.12698 .03846 L
.13462 .0377 L
.15385 .03559 L
.17308 .0332 L
.19231 .03068 L
.21154 .0282 L
.23077 .02589 L
.25 .02382 L
.26923 .02201 L
.28846 .02048 L
.30726 .01923 L
s
.1 g
.01923 .12267 m
.03303 .13462 L
.03846 .13932 L
.05096 .15385 L
.05769 .16843 L
.05835 .17308 L
.05769 .18121 L
.05481 .19231 L
.04745 .21154 L
.04015 .23077 L
.03846 .23572 L
.03411 .25 L
.0296 .26923 L
.02655 .28846 L
.02475 .30769 L
.02392 .32692 L
.02369 .34615 L
.0237 .36538 L
.02368 .38462 L
.02351 .40385 L
.02323 .42308 L
.02294 .44231 L
.02273 .46154 L
.02268 .48077 L
.02282 .5 L
.02318 .51923 L
.02375 .53846 L
.02454 .55769 L
.02556 .57692 L
.0268 .59615 L
.02828 .61538 L
.03001 .63462 L
.03198 .65385 L
.03421 .67308 L
.03667 .69231 L
.03846 .70556 L
.03926 .71154 L
.04176 .73077 L
.0437 .75 L
.04448 .76923 L
.04361 .78846 L
.0413 .80769 L
.039 .82692 L
.03896 .84615 L
.04264 .86538 L
.0496 .88462 L
.05769 .90299 L
.05812 .90385 L
.06832 .92308 L
.07692 .93732 L
.08035 .94231 L
.09615 .96119 L
.09645 .96154 L
.11538 .97699 L
.1229 .98077 L
.01923 .98077 L
F
0 g
.01923 .12267 m
.03303 .13462 L
.03846 .13932 L
.05096 .15385 L
.05769 .16843 L
.05835 .17308 L
.05769 .18121 L
.05481 .19231 L
.04745 .21154 L
.04015 .23077 L
.03846 .23572 L
.03411 .25 L
.0296 .26923 L
.02655 .28846 L
.02475 .30769 L
.02392 .32692 L
.02369 .34615 L
.0237 .36538 L
.02368 .38462 L
.02351 .40385 L
.02323 .42308 L
.02294 .44231 L
.02273 .46154 L
.02268 .48077 L
.02282 .5 L
.02318 .51923 L
.02375 .53846 L
.02454 .55769 L
.02556 .57692 L
.0268 .59615 L
.02828 .61538 L
.03001 .63462 L
.03198 .65385 L
.03421 .67308 L
.03667 .69231 L
.03846 .70556 L
.03926 .71154 L
.04176 .73077 L
.0437 .75 L
.04448 .76923 L
.04361 .78846 L
.0413 .80769 L
.039 .82692 L
.03896 .84615 L
.04264 .86538 L
.0496 .88462 L
.05769 .90299 L
.05812 .90385 L
.06832 .92308 L
.07692 .93732 L
Mistroke
.08035 .94231 L
.09615 .96119 L
.09645 .96154 L
.11538 .97699 L
.1229 .98077 L
Mfstroke
.01923 .90416 m
.02968 .92308 L
.03846 .93701 L
.04203 .94231 L
.05554 .96154 L
.05769 .96478 L
.06988 .98077 L
.01923 .98077 L
F
.01923 .90416 m
.02968 .92308 L
.03846 .93701 L
.04203 .94231 L
.05554 .96154 L
.05769 .96478 L
.06988 .98077 L
s
.01923 .02808 m
.03846 .02183 L
.04786 .01923 L
.01923 .01923 L
F
.01923 .02808 m
.03846 .02183 L
.04786 .01923 L
s
.01923 .76488 m
.01992 .75 L
.0193 .73077 L
.01923 .72912 L
F
.01923 .76488 m
.01992 .75 L
.0193 .73077 L
.01923 .72912 L
s
.3 g
.98077 .69571 m
.97972 .71154 L
.97821 .73077 L
.97639 .75 L
.97424 .76923 L
.9717 .78846 L
.96886 .80769 L
.96623 .82692 L
.96518 .84615 L
.96707 .86538 L
.97065 .88462 L
.97127 .90385 L
.96393 .92308 L
.96154 .92683 L
.94231 .94163 L
.93988 .94231 L
.92308 .94333 L
.91806 .94231 L
.90385 .93877 L
.88462 .93524 L
.86538 .93684 L
.84615 .94121 L
.8415 .94231 L
.82692 .94754 L
.80769 .95395 L
.78846 .95963 L
.78121 .96154 L
.76923 .96413 L
.75 .96711 L
.73077 .96849 L
.71154 .96855 L
.69231 .96789 L
.67308 .96721 L
.65385 .96694 L
.63462 .96716 L
.61538 .96774 L
.59615 .96845 L
.57692 .96915 L
.55769 .96973 L
.53846 .97014 L
.51923 .97035 L
.5 .97036 L
.48077 .97015 L
.46154 .96972 L
.44231 .96905 L
.42308 .96812 L
.40385 .96693 L
.38462 .96545 L
.36538 .96364 L
.34664 .96154 L
.34615 .96148 L
.32692 .95892 L
.30769 .95591 L
.28846 .95245 L
.26923 .94862 L
.25 .94475 L
.23523 .94231 L
.23077 .94176 L
.21154 .94113 L
.20114 .94231 L
.19231 .94401 L
.17308 .94942 L
.15385 .95402 L
.13462 .95358 L
.11538 .94508 L
.11119 .94231 L
.09615 .92643 L
.09357 .92308 L
.08134 .90385 L
.07692 .89564 L
.07176 .88462 L
.06447 .86538 L
.06022 .84615 L
.05911 .82692 L
.05986 .80769 L
.06068 .78846 L
.06038 .76923 L
.05877 .75 L
.05769 .74034 L
.05638 .73077 L
.05371 .71154 L
.05098 .69231 L
.04838 .67308 L
.04601 .65385 L
.04388 .63462 L
.04203 .61538 L
.04045 .59615 L
.03913 .57692 L
.03846 .56519 L
.0381 .55769 L
.03734 .53846 L
.03686 .51923 L
.03666 .5 L
.03675 .48077 L
.0371 .46154 L
.03769 .44231 L
.03843 .42308 L
.03846 .42236 L
.03922 .40385 L
.03991 .38462 L
.04042 .36538 L
.04081 .34615 L
.04137 .32692 L
.04253 .30769 L
.04481 .28846 L
.04865 .26923 L
.0545 .25 L
.05769 .24189 L
.06301 .23077 L
.07516 .21154 L
.07692 .20974 L
.09224 .19231 L
.09615 .18839 L
.11129 .17308 L
.11538 .16692 L
.11727 .15385 L
.11538 .15054 L
.09615 .13651 L
.09293 .13462 L
.07692 .12726 L
.06614 .11538 L
.05783 .09615 L
.07185 .07692 L
.07692 .073 L
.09615 .06455 L
.11538 .06059 L
.13462 .05814 L
.1386 .05769 L
.15385 .05474 L
.17308 .05102 L
.19231 .04745 L
.21154 .04413 L
.23077 .04112 L
.25 .03847 L
.25008 .03846 L
.26923 .03619 L
.28846 .03427 L
.30769 .03273 L
.32692 .03153 L
.34615 .03064 L
.36538 .03004 L
.38462 .02967 L
.40385 .0295 L
.42308 .02948 L
.44231 .02961 L
.46154 .02989 L
.48077 .03031 L
.5 .03089 L
.51923 .03165 L
.53846 .03261 L
.55769 .03375 L
.57692 .0351 L
.59615 .03661 L
.61538 .03824 L
.61793 .03846 L
.63462 .03985 L
.65385 .04124 L
.67308 .04206 L
.69231 .04193 L
.71154 .04055 L
.72775 .03846 L
.73077 .03789 L
.75 .03433 L
.76923 .03054 L
.78846 .02734 L
.80769 .0255 L
.82692 .02559 L
.84615 .02791 L
.86538 .03251 L
.88257 .03846 L
.88462 .03932 L
.90385 .04892 L
.91627 .05769 L
.92308 .06385 L
.9335 .07692 L
.94231 .09478 L
.94276 .09615 L
.94746 .11538 L
.95012 .13462 L
.95227 .15385 L
.95447 .17308 L
.95665 .19231 L
.95856 .21154 L
.96009 .23077 L
.96129 .25 L
.96154 .25452 L
.9623 .26923 L
.96325 .28846 L
.96424 .30769 L
.96529 .32692 L
.96636 .34615 L
.96742 .36538 L
.96847 .38462 L
.96957 .40385 L
.97083 .42308 L
.97232 .44231 L
.97413 .46154 L
.97627 .48077 L
.97988 .5 L
.98077 .51481 L
F
0 g
.98077 .69571 m
.97972 .71154 L
.97821 .73077 L
.97639 .75 L
.97424 .76923 L
.9717 .78846 L
.96886 .80769 L
.96623 .82692 L
.96518 .84615 L
.96707 .86538 L
.97065 .88462 L
.97127 .90385 L
.96393 .92308 L
.96154 .92683 L
.94231 .94163 L
.93988 .94231 L
.92308 .94333 L
.91806 .94231 L
.90385 .93877 L
.88462 .93524 L
.86538 .93684 L
.84615 .94121 L
.8415 .94231 L
.82692 .94754 L
.80769 .95395 L
.78846 .95963 L
.78121 .96154 L
.76923 .96413 L
.75 .96711 L
.73077 .96849 L
.71154 .96855 L
.69231 .96789 L
.67308 .96721 L
.65385 .96694 L
.63462 .96716 L
.61538 .96774 L
.59615 .96845 L
.57692 .96915 L
.55769 .96973 L
.53846 .97014 L
.51923 .97035 L
.5 .97036 L
.48077 .97015 L
.46154 .96972 L
.44231 .96905 L
.42308 .96812 L
.40385 .96693 L
.38462 .96545 L
.36538 .96364 L
.34664 .96154 L
Mistroke
.34615 .96148 L
.32692 .95892 L
.30769 .95591 L
.28846 .95245 L
.26923 .94862 L
.25 .94475 L
.23523 .94231 L
.23077 .94176 L
.21154 .94113 L
.20114 .94231 L
.19231 .94401 L
.17308 .94942 L
.15385 .95402 L
.13462 .95358 L
.11538 .94508 L
.11119 .94231 L
.09615 .92643 L
.09357 .92308 L
.08134 .90385 L
.07692 .89564 L
.07176 .88462 L
.06447 .86538 L
.06022 .84615 L
.05911 .82692 L
.05986 .80769 L
.06068 .78846 L
.06038 .76923 L
.05877 .75 L
.05769 .74034 L
.05638 .73077 L
.05371 .71154 L
.05098 .69231 L
.04838 .67308 L
.04601 .65385 L
.04388 .63462 L
.04203 .61538 L
.04045 .59615 L
.03913 .57692 L
.03846 .56519 L
.0381 .55769 L
.03734 .53846 L
.03686 .51923 L
.03666 .5 L
.03675 .48077 L
.0371 .46154 L
.03769 .44231 L
.03843 .42308 L
.03846 .42236 L
.03922 .40385 L
.03991 .38462 L
Mistroke
.04042 .36538 L
.04081 .34615 L
.04137 .32692 L
.04253 .30769 L
.04481 .28846 L
.04865 .26923 L
.0545 .25 L
.05769 .24189 L
.06301 .23077 L
.07516 .21154 L
.07692 .20974 L
.09224 .19231 L
.09615 .18839 L
.11129 .17308 L
.11538 .16692 L
.11727 .15385 L
.11538 .15054 L
.09615 .13651 L
.09293 .13462 L
.07692 .12726 L
.06614 .11538 L
.05783 .09615 L
.07185 .07692 L
.07692 .073 L
.09615 .06455 L
.11538 .06059 L
.13462 .05814 L
.1386 .05769 L
.15385 .05474 L
.17308 .05102 L
.19231 .04745 L
.21154 .04413 L
.23077 .04112 L
.25 .03847 L
.25008 .03846 L
.26923 .03619 L
.28846 .03427 L
.30769 .03273 L
.32692 .03153 L
.34615 .03064 L
.36538 .03004 L
.38462 .02967 L
.40385 .0295 L
.42308 .02948 L
.44231 .02961 L
.46154 .02989 L
.48077 .03031 L
.5 .03089 L
.51923 .03165 L
.53846 .03261 L
Mistroke
.55769 .03375 L
.57692 .0351 L
.59615 .03661 L
.61538 .03824 L
.61793 .03846 L
.63462 .03985 L
.65385 .04124 L
.67308 .04206 L
.69231 .04193 L
.71154 .04055 L
.72775 .03846 L
.73077 .03789 L
.75 .03433 L
.76923 .03054 L
.78846 .02734 L
.80769 .0255 L
.82692 .02559 L
.84615 .02791 L
.86538 .03251 L
.88257 .03846 L
.88462 .03932 L
.90385 .04892 L
.91627 .05769 L
.92308 .06385 L
.9335 .07692 L
.94231 .09478 L
.94276 .09615 L
.94746 .11538 L
.95012 .13462 L
.95227 .15385 L
.95447 .17308 L
.95665 .19231 L
.95856 .21154 L
.96009 .23077 L
.96129 .25 L
.96154 .25452 L
.9623 .26923 L
.96325 .28846 L
.96424 .30769 L
.96529 .32692 L
.96636 .34615 L
.96742 .36538 L
.96847 .38462 L
.96957 .40385 L
.97083 .42308 L
.97232 .44231 L
.97413 .46154 L
.97627 .48077 L
.97988 .5 L
.98077 .51481 L
Mistroke
Mfstroke
.4 g
.23077 .05452 m
.25 .05108 L
.26923 .04824 L
.28846 .04593 L
.30769 .0441 L
.32692 .0427 L
.34615 .04168 L
.36538 .04099 L
.38462 .04058 L
.40385 .04039 L
.42308 .04039 L
.44231 .04056 L
.46154 .04089 L
.48077 .0414 L
.5 .04212 L
.51923 .04307 L
.53846 .04427 L
.55769 .04575 L
.57692 .04756 L
.59615 .0497 L
.61538 .05216 L
.63462 .0548 L
.65385 .0573 L
.65727 .05769 L
.67308 .05898 L
.69231 .05924 L
.71154 .05769 L
.71163 .05769 L
.73077 .05453 L
.75 .05056 L
.76923 .04661 L
.78846 .04347 L
.80769 .04184 L
.82692 .04235 L
.84615 .04538 L
.86538 .0511 L
.88068 .05769 L
.88462 .05977 L
.90385 .07301 L
.90791 .07692 L
.92171 .09615 L
.92308 .09898 L
.929 .11538 L
.93343 .13462 L
.93693 .15385 L
.9402 .17308 L
.94231 .18651 L
.94316 .19231 L
.94569 .21154 L
.94778 .23077 L
.94951 .25 L
.9511 .26923 L
.95272 .28846 L
.95452 .30769 L
.95649 .32692 L
.9585 .34615 L
.96037 .36538 L
.96154 .37941 L
.96192 .38462 L
.96309 .40385 L
.96392 .42308 L
.96454 .44231 L
.96505 .46154 L
.96559 .48077 L
.97285 .5 L
.97403 .51923 L
.97499 .53846 L
.97574 .55769 L
.97626 .57692 L
.97652 .59615 L
.97653 .61538 L
.97626 .63462 L
.97571 .65385 L
.96862 .67308 L
.97372 .69231 L
.97223 .71154 L
.97037 .73077 L
.96805 .75 L
.96518 .76923 L
.96162 .78846 L
.96154 .78883 L
.95726 .80769 L
.95244 .82692 L
.94883 .84615 L
.94937 .86538 L
.95238 .88462 L
.95112 .90385 L
.94231 .91714 L
.92308 .92182 L
.90385 .9118 L
.89744 .90385 L
.9032 .88462 L
.90385 .88249 L
.9122 .86538 L
.91433 .84615 L
.90914 .82692 L
.90385 .81303 L
.89955 .80769 L
.88462 .78926 L
.86538 .79434 L
.85578 .80769 L
.84615 .82571 L
.84573 .82692 L
.84034 .84615 L
.84318 .86538 L
.84615 .87316 L
.85442 .88462 L
.86346 .90385 L
.84715 .92308 L
.84615 .92398 L
.82692 .93583 L
.80876 .94231 L
.80769 .94271 L
.78846 .94897 L
.76923 .9537 L
.75 .9568 L
.73077 .95828 L
.71154 .9585 L
.69231 .95808 L
.67308 .95769 L
.65385 .9577 L
.63462 .95817 L
.61538 .95894 L
.59615 .95979 L
.57692 .96056 L
.55769 .96118 L
.54291 .96154 L
.53846 .9616 L
.51923 .96179 L
.5 .96174 L
.4856 .96154 L
.48077 .96144 L
.46154 .96088 L
.44231 .96004 L
.42308 .9589 L
.40385 .95744 L
.38462 .95563 L
.36538 .95341 L
.34615 .95073 L
.32692 .94751 L
.30769 .94364 L
.30185 .94231 L
.28846 .9391 L
.26923 .93359 L
.25 .92734 L
.23835 .92308 L
.23077 .92177 L
.21154 .91915 L
.19231 .92103 L
.18176 .92308 L
.17308 .92606 L
.15385 .92996 L
.13462 .92824 L
.12336 .92308 L
.11538 .91734 L
.10222 .90385 L
.09615 .8945 L
.09028 .88462 L
.08165 .86538 L
.07692 .84796 L
.07668 .84615 L
.07487 .82692 L
.07487 .80769 L
.07496 .78846 L
.07398 .76923 L
.07173 .75 L
.06868 .73077 L
.06538 .71154 L
.06222 .69231 L
.05935 .67308 L
.05769 .66076 L
.05686 .65385 L
.05473 .63462 L
.05287 .61538 L
.05131 .59615 L
.05004 .57692 L
.04907 .55769 L
.04841 .53846 L
.04807 .51923 L
.04806 .5 L
.0484 .48077 L
.04909 .46154 L
.0501 .44231 L
.05139 .42308 L
.05284 .40385 L
.05426 .38462 L
.05545 .36538 L
.05636 .34615 L
.05725 .32692 L
.05769 .31976 L
.05858 .30769 L
.06124 .28846 L
.06608 .26923 L
.07398 .25 L
.07692 .24453 L
.08645 .23077 L
.09615 .22021 L
.106 .21154 L
.11538 .20456 L
.13086 .19231 L
.13462 .19121 L
.15143 .17308 L
.15385 .16986 L
.16223 .15385 L
.15932 .13462 L
.15385 .12559 L
.14244 .11538 L
.13462 .10664 L
.13083 .09615 L
.13462 .0901 L
.15385 .07735 L
.15476 .07692 L
.17308 .06826 L
.19231 .06268 L
.21154 .05853 L
.21583 .05769 L
F
0 g
.23077 .05452 m
.25 .05108 L
.26923 .04824 L
.28846 .04593 L
.30769 .0441 L
.32692 .0427 L
.34615 .04168 L
.36538 .04099 L
.38462 .04058 L
.40385 .04039 L
.42308 .04039 L
.44231 .04056 L
.46154 .04089 L
.48077 .0414 L
.5 .04212 L
.51923 .04307 L
.53846 .04427 L
.55769 .04575 L
.57692 .04756 L
.59615 .0497 L
.61538 .05216 L
.63462 .0548 L
.65385 .0573 L
.65727 .05769 L
.67308 .05898 L
.69231 .05924 L
.71154 .05769 L
.71163 .05769 L
.73077 .05453 L
.75 .05056 L
.76923 .04661 L
.78846 .04347 L
.80769 .04184 L
.82692 .04235 L
.84615 .04538 L
.86538 .0511 L
.88068 .05769 L
.88462 .05977 L
.90385 .07301 L
.90791 .07692 L
.92171 .09615 L
.92308 .09898 L
.929 .11538 L
.93343 .13462 L
.93693 .15385 L
.9402 .17308 L
.94231 .18651 L
.94316 .19231 L
.94569 .21154 L
.94778 .23077 L
Mistroke
.94951 .25 L
.9511 .26923 L
.95272 .28846 L
.95452 .30769 L
.95649 .32692 L
.9585 .34615 L
.96037 .36538 L
.96154 .37941 L
.96192 .38462 L
.96309 .40385 L
.96392 .42308 L
.96454 .44231 L
.96505 .46154 L
.96559 .48077 L
.97285 .5 L
.97403 .51923 L
.97499 .53846 L
.97574 .55769 L
.97626 .57692 L
.97652 .59615 L
.97653 .61538 L
.97626 .63462 L
.97571 .65385 L
.96862 .67308 L
.97372 .69231 L
.97223 .71154 L
.97037 .73077 L
.96805 .75 L
.96518 .76923 L
.96162 .78846 L
.96154 .78883 L
.95726 .80769 L
.95244 .82692 L
.94883 .84615 L
.94937 .86538 L
.95238 .88462 L
.95112 .90385 L
.94231 .91714 L
.92308 .92182 L
.90385 .9118 L
.89744 .90385 L
.9032 .88462 L
.90385 .88249 L
.9122 .86538 L
.91433 .84615 L
.90914 .82692 L
.90385 .81303 L
.89955 .80769 L
.88462 .78926 L
.86538 .79434 L
Mistroke
.85578 .80769 L
.84615 .82571 L
.84573 .82692 L
.84034 .84615 L
.84318 .86538 L
.84615 .87316 L
.85442 .88462 L
.86346 .90385 L
.84715 .92308 L
.84615 .92398 L
.82692 .93583 L
.80876 .94231 L
.80769 .94271 L
.78846 .94897 L
.76923 .9537 L
.75 .9568 L
.73077 .95828 L
.71154 .9585 L
.69231 .95808 L
.67308 .95769 L
.65385 .9577 L
.63462 .95817 L
.61538 .95894 L
.59615 .95979 L
.57692 .96056 L
.55769 .96118 L
.54291 .96154 L
.53846 .9616 L
.51923 .96179 L
.5 .96174 L
.4856 .96154 L
.48077 .96144 L
.46154 .96088 L
.44231 .96004 L
.42308 .9589 L
.40385 .95744 L
.38462 .95563 L
.36538 .95341 L
.34615 .95073 L
.32692 .94751 L
.30769 .94364 L
.30185 .94231 L
.28846 .9391 L
.26923 .93359 L
.25 .92734 L
.23835 .92308 L
.23077 .92177 L
.21154 .91915 L
.19231 .92103 L
.18176 .92308 L
Mistroke
.17308 .92606 L
.15385 .92996 L
.13462 .92824 L
.12336 .92308 L
.11538 .91734 L
.10222 .90385 L
.09615 .8945 L
.09028 .88462 L
.08165 .86538 L
.07692 .84796 L
.07668 .84615 L
.07487 .82692 L
.07487 .80769 L
.07496 .78846 L
.07398 .76923 L
.07173 .75 L
.06868 .73077 L
.06538 .71154 L
.06222 .69231 L
.05935 .67308 L
.05769 .66076 L
.05686 .65385 L
.05473 .63462 L
.05287 .61538 L
.05131 .59615 L
.05004 .57692 L
.04907 .55769 L
.04841 .53846 L
.04807 .51923 L
.04806 .5 L
.0484 .48077 L
.04909 .46154 L
.0501 .44231 L
.05139 .42308 L
.05284 .40385 L
.05426 .38462 L
.05545 .36538 L
.05636 .34615 L
.05725 .32692 L
.05769 .31976 L
.05858 .30769 L
.06124 .28846 L
.06608 .26923 L
.07398 .25 L
.07692 .24453 L
.08645 .23077 L
.09615 .22021 L
.106 .21154 L
.11538 .20456 L
.13086 .19231 L
Mistroke
.13462 .19121 L
.15143 .17308 L
.15385 .16986 L
.16223 .15385 L
.15932 .13462 L
.15385 .12559 L
.14244 .11538 L
.13462 .10664 L
.13083 .09615 L
.13462 .0901 L
.15385 .07735 L
.15476 .07692 L
.17308 .06826 L
.19231 .06268 L
.21154 .05853 L
.21583 .05769 L
.23077 .05452 L
Mfstroke
.5 g
.28846 .05702 m
.30769 .0548 L
.32692 .05317 L
.34615 .05201 L
.36538 .05126 L
.38462 .05083 L
.40385 .05067 L
.42308 .05073 L
.44231 .05101 L
.46154 .0515 L
.48077 .05224 L
.5 .05329 L
.51923 .05468 L
.53846 .05651 L
.54868 .05769 L
.55769 .05881 L
.57692 .06161 L
.59615 .06511 L
.61538 .06946 L
.63462 .07491 L
.6402 .07692 L
.65385 .08301 L
.6539 .09615 L
.65385 .09617 L
.63462 .10262 L
.61538 .10779 L
.59615 .11214 L
.57917 .11538 L
.57692 .11582 L
.55769 .11912 L
.53846 .12175 L
.51923 .12384 L
.5 .12551 L
.48077 .12689 L
.46154 .12813 L
.44231 .12939 L
.42308 .13086 L
.40385 .13276 L
.38904 .13462 L
.38462 .13541 L
.36538 .1397 L
.34615 .14599 L
.32986 .15385 L
.32692 .15568 L
.3084 .17308 L
.30769 .17409 L
.29764 .19231 L
.28846 .21069 L
.28801 .21154 L
.27531 .23077 L
.26923 .23816 L
.25687 .25 L
.25 .2556 L
.23077 .26812 L
.22878 .26923 L
.21154 .27745 L
.19231 .2849 L
.18232 .28846 L
.17308 .29209 L
.15385 .30228 L
.14739 .30769 L
.13462 .32153 L
.13156 .32692 L
.12984 .34615 L
.1272 .36538 L
.12959 .38462 L
.1332 .40385 L
.13462 .42222 L
.13485 .42308 L
.13976 .44231 L
.14417 .46154 L
.14797 .48077 L
.15118 .5 L
.15385 .51923 L
.15385 .51923 L
.15626 .53846 L
.15829 .55769 L
.15997 .57692 L
.16127 .59615 L
.16222 .61538 L
.16279 .63462 L
.16297 .65385 L
.16275 .67308 L
.16212 .69231 L
.16113 .71154 L
.16006 .73077 L
.15956 .75 L
.16091 .76923 L
.16561 .78846 L
.17308 .80593 L
.17413 .80769 L
.18847 .82692 L
.19231 .8308 L
.21154 .84389 L
.21558 .84615 L
.23077 .84786 L
.24238 .84615 L
.25 .8442 L
.26923 .83951 L
.28846 .83608 L
.30769 .83382 L
.32692 .83248 L
.34615 .83191 L
.36538 .83202 L
.38462 .83275 L
.40385 .83406 L
.42308 .83591 L
.44231 .83824 L
.46154 .84101 L
.48077 .84412 L
.49258 .84615 L
.5 .84748 L
.51923 .85103 L
.53846 .85464 L
.55769 .85822 L
.57692 .86166 L
.59615 .86487 L
.5994 .86538 L
.61538 .86766 L
.63462 .86997 L
.65385 .87135 L
.67308 .87113 L
.69231 .86856 L
.70546 .86538 L
.71154 .86285 L
.73077 .85177 L
.73654 .84615 L
.74909 .82692 L
.75 .82448 L
.75437 .80769 L
.75949 .78846 L
.76572 .76923 L
.76923 .75994 L
.77315 .75 L
.78368 .73077 L
.78846 .72366 L
.79598 .71154 L
.80769 .701 L
.81921 .69231 L
.82692 .6878 L
.84615 .68113 L
.86069 .67308 L
.86538 .66592 L
.87115 .65385 L
.87631 .63462 L
.87964 .61538 L
.882 .59615 L
.88371 .57692 L
.88462 .56354 L
.88506 .55769 L
.88634 .53846 L
.88742 .51923 L
.88836 .5 L
.88923 .48077 L
.89005 .46154 L
.89082 .44231 L
.89147 .42308 L
.89189 .40385 L
.89185 .38462 L
.89103 .36538 L
.8889 .34615 L
.88534 .32692 L
.88462 .32263 L
.8785 .30769 L
.86538 .29955 L
.84615 .29549 L
.82692 .29369 L
.80903 .28846 L
.80769 .28787 L
.78846 .27453 L
.78326 .26923 L
.77035 .25 L
.76923 .24778 L
.76233 .23077 L
.75732 .21154 L
.75398 .19231 L
.7507 .17308 L
.75 .16985 L
.74537 .15385 L
.73559 .13462 L
.73077 .1314 L
.71956 .11538 L
.71154 .10819 L
.69776 .09615 L
.71154 .08213 L
.72539 .07692 L
.73077 .07363 L
.75 .06691 L
.76923 .06215 L
.78846 .05866 L
.7966 .05769 L
.80769 .05694 L
.82609 .05769 L
.82692 .05778 L
.84615 .06167 L
.86538 .06921 L
.87847 .07692 L
.88462 .0815 L
.8986 .09615 L
.90385 .10418 L
.90929 .11538 L
.9158 .13462 L
.92084 .15385 L
.92308 .16312 L
.92535 .17308 L
.92943 .19231 L
.93293 .21154 L
.93589 .23077 L
.93864 .25 L
.93913 .26923 L
.94113 .28846 L
.94231 .29871 L
.94349 .30769 L
.94644 .32692 L
.94979 .34615 L
.95323 .36538 L
.95634 .38462 L
.95881 .40385 L
.96052 .42308 L
.96153 .44231 L
.96154 .44264 L
.96198 .46154 L
.96206 .48077 L
.96681 .5 L
.9681 .51923 L
.96914 .53846 L
.96994 .55769 L
.97048 .57692 L
.97074 .59615 L
.97071 .61538 L
.97037 .63462 L
.9697 .65385 L
.96263 .67308 L
.96728 .69231 L
.96542 .71154 L
.96304 .73077 L
.96154 .74085 L
.95999 .75 L
.95601 .76923 L
.95058 .78846 L
.94231 .80745 L
.94213 .80769 L
.92308 .8109 L
.91962 .80769 L
.90647 .78846 L
.90385 .78424 L
.89347 .76923 L
.88462 .75843 L
.86538 .76124 L
.85958 .76923 L
.84894 .78846 L
.84615 .79372 L
.83893 .80769 L
.8292 .82692 L
.82692 .83264 L
.82391 .84615 L
.82512 .86538 L
.82692 .87481 L
.83201 .88462 L
.83515 .90385 L
.82692 .91795 L
.82107 .92308 L
.80769 .93227 L
.78846 .93971 L
.77821 .94231 L
.76923 .94445 L
.75 .94778 L
.73077 .94936 L
.71154 .94966 L
.69231 .94935 L
.67308 .94912 L
.65385 .94936 L
.63462 .95008 L
.61538 .95106 L
.59615 .95208 L
.57692 .95297 L
.55769 .95365 L
.53846 .95408 L
.51923 .95425 L
.5 .95414 L
.48077 .95374 L
.46154 .95303 L
.44231 .952 L
.42308 .95061 L
.40385 .94882 L
.38462 .94658 L
.36538 .9438 L
.3565 .94231 L
.34615 .9406 L
.32692 .93655 L
.30769 .93113 L
.28846 .92398 L
.28638 .92308 L
.26923 .91619 L
.25 .9044 L
.24951 .90385 L
.23077 .89347 L
.21154 .88986 L
.19231 .89353 L
.17308 .90036 L
.16094 .90385 L
.15385 .90512 L
.13752 .90385 L
.13462 .90298 L
.11538 .89008 L
.11 .88462 L
.09821 .86538 L
.09615 .86081 L
.09218 .84615 L
.08953 .82692 L
.08899 .80769 L
.08853 .78846 L
.08673 .76923 L
.08355 .75 L
.07992 .73077 L
.07692 .71295 L
.07664 .71154 L
.07294 .69231 L
.06965 .67308 L
.06681 .65385 L
.06439 .63462 L
.06238 .61538 L
.06076 .59615 L
.05952 .57692 L
.05865 .55769 L
.05816 .53846 L
.05804 .51923 L
.0583 .5 L
.05894 .48077 L
.05996 .46154 L
.06134 .44231 L
.06308 .42308 L
.06526 .40385 L
.06797 .38462 L
.07097 .36538 L
.07346 .34615 L
.07515 .32692 L
.07692 .30813 L
.07696 .30769 L
.07885 .28846 L
.08572 .26923 L
.09615 .2508 L
.0969 .25 L
.11426 .23077 L
.11538 .22969 L
.13462 .21295 L
.13648 .21154 L
.15385 .19631 L
.15826 .19231 L
.17308 .17817 L
.17707 .17308 L
.18966 .15385 L
.19177 .13462 L
.18574 .11538 L
.18455 .09615 L
.19231 .08664 L
.20797 .07692 L
.21154 .0751 L
.23077 .06785 L
.25 .06306 L
.26923 .05961 L
.28352 .05769 L
F
0 g
.28846 .05702 m
.30769 .0548 L
.32692 .05317 L
.34615 .05201 L
.36538 .05126 L
.38462 .05083 L
.40385 .05067 L
.42308 .05073 L
.44231 .05101 L
.46154 .0515 L
.48077 .05224 L
.5 .05329 L
.51923 .05468 L
.53846 .05651 L
.54868 .05769 L
.55769 .05881 L
.57692 .06161 L
.59615 .06511 L
.61538 .06946 L
.63462 .07491 L
.6402 .07692 L
.65385 .08301 L
.6539 .09615 L
.65385 .09617 L
.63462 .10262 L
.61538 .10779 L
.59615 .11214 L
.57917 .11538 L
.57692 .11582 L
.55769 .11912 L
.53846 .12175 L
.51923 .12384 L
.5 .12551 L
.48077 .12689 L
.46154 .12813 L
.44231 .12939 L
.42308 .13086 L
.40385 .13276 L
.38904 .13462 L
.38462 .13541 L
.36538 .1397 L
.34615 .14599 L
.32986 .15385 L
.32692 .15568 L
.3084 .17308 L
.30769 .17409 L
.29764 .19231 L
.28846 .21069 L
.28801 .21154 L
.27531 .23077 L
Mistroke
.26923 .23816 L
.25687 .25 L
.25 .2556 L
.23077 .26812 L
.22878 .26923 L
.21154 .27745 L
.19231 .2849 L
.18232 .28846 L
.17308 .29209 L
.15385 .30228 L
.14739 .30769 L
.13462 .32153 L
.13156 .32692 L
.12984 .34615 L
.1272 .36538 L
.12959 .38462 L
.1332 .40385 L
.13462 .42222 L
.13485 .42308 L
.13976 .44231 L
.14417 .46154 L
.14797 .48077 L
.15118 .5 L
.15385 .51923 L
.15385 .51923 L
.15626 .53846 L
.15829 .55769 L
.15997 .57692 L
.16127 .59615 L
.16222 .61538 L
.16279 .63462 L
.16297 .65385 L
.16275 .67308 L
.16212 .69231 L
.16113 .71154 L
.16006 .73077 L
.15956 .75 L
.16091 .76923 L
.16561 .78846 L
.17308 .80593 L
.17413 .80769 L
.18847 .82692 L
.19231 .8308 L
.21154 .84389 L
.21558 .84615 L
.23077 .84786 L
.24238 .84615 L
.25 .8442 L
.26923 .83951 L
.28846 .83608 L
Mistroke
.30769 .83382 L
.32692 .83248 L
.34615 .83191 L
.36538 .83202 L
.38462 .83275 L
.40385 .83406 L
.42308 .83591 L
.44231 .83824 L
.46154 .84101 L
.48077 .84412 L
.49258 .84615 L
.5 .84748 L
.51923 .85103 L
.53846 .85464 L
.55769 .85822 L
.57692 .86166 L
.59615 .86487 L
.5994 .86538 L
.61538 .86766 L
.63462 .86997 L
.65385 .87135 L
.67308 .87113 L
.69231 .86856 L
.70546 .86538 L
.71154 .86285 L
.73077 .85177 L
.73654 .84615 L
.74909 .82692 L
.75 .82448 L
.75437 .80769 L
.75949 .78846 L
.76572 .76923 L
.76923 .75994 L
.77315 .75 L
.78368 .73077 L
.78846 .72366 L
.79598 .71154 L
.80769 .701 L
.81921 .69231 L
.82692 .6878 L
.84615 .68113 L
.86069 .67308 L
.86538 .66592 L
.87115 .65385 L
.87631 .63462 L
.87964 .61538 L
.882 .59615 L
.88371 .57692 L
.88462 .56354 L
.88506 .55769 L
Mistroke
.88634 .53846 L
.88742 .51923 L
.88836 .5 L
.88923 .48077 L
.89005 .46154 L
.89082 .44231 L
.89147 .42308 L
.89189 .40385 L
.89185 .38462 L
.89103 .36538 L
.8889 .34615 L
.88534 .32692 L
.88462 .32263 L
.8785 .30769 L
.86538 .29955 L
.84615 .29549 L
.82692 .29369 L
.80903 .28846 L
.80769 .28787 L
.78846 .27453 L
.78326 .26923 L
.77035 .25 L
.76923 .24778 L
.76233 .23077 L
.75732 .21154 L
.75398 .19231 L
.7507 .17308 L
.75 .16985 L
.74537 .15385 L
.73559 .13462 L
.73077 .1314 L
.71956 .11538 L
.71154 .10819 L
.69776 .09615 L
.71154 .08213 L
.72539 .07692 L
.73077 .07363 L
.75 .06691 L
.76923 .06215 L
.78846 .05866 L
.7966 .05769 L
.80769 .05694 L
.82609 .05769 L
.82692 .05778 L
.84615 .06167 L
.86538 .06921 L
.87847 .07692 L
.88462 .0815 L
.8986 .09615 L
.90385 .10418 L
Mistroke
.90929 .11538 L
.9158 .13462 L
.92084 .15385 L
.92308 .16312 L
.92535 .17308 L
.92943 .19231 L
.93293 .21154 L
.93589 .23077 L
.93864 .25 L
.93913 .26923 L
.94113 .28846 L
.94231 .29871 L
.94349 .30769 L
.94644 .32692 L
.94979 .34615 L
.95323 .36538 L
.95634 .38462 L
.95881 .40385 L
.96052 .42308 L
.96153 .44231 L
.96154 .44264 L
.96198 .46154 L
.96206 .48077 L
.96681 .5 L
.9681 .51923 L
.96914 .53846 L
.96994 .55769 L
.97048 .57692 L
.97074 .59615 L
.97071 .61538 L
.97037 .63462 L
.9697 .65385 L
.96263 .67308 L
.96728 .69231 L
.96542 .71154 L
.96304 .73077 L
.96154 .74085 L
.95999 .75 L
.95601 .76923 L
.95058 .78846 L
.94231 .80745 L
.94213 .80769 L
.92308 .8109 L
.91962 .80769 L
.90647 .78846 L
.90385 .78424 L
.89347 .76923 L
.88462 .75843 L
.86538 .76124 L
.85958 .76923 L
Mistroke
.84894 .78846 L
.84615 .79372 L
.83893 .80769 L
.8292 .82692 L
.82692 .83264 L
.82391 .84615 L
.82512 .86538 L
.82692 .87481 L
.83201 .88462 L
.83515 .90385 L
.82692 .91795 L
.82107 .92308 L
.80769 .93227 L
.78846 .93971 L
.77821 .94231 L
.76923 .94445 L
.75 .94778 L
.73077 .94936 L
.71154 .94966 L
.69231 .94935 L
.67308 .94912 L
.65385 .94936 L
.63462 .95008 L
.61538 .95106 L
.59615 .95208 L
.57692 .95297 L
.55769 .95365 L
.53846 .95408 L
.51923 .95425 L
.5 .95414 L
.48077 .95374 L
.46154 .95303 L
.44231 .952 L
.42308 .95061 L
.40385 .94882 L
.38462 .94658 L
.36538 .9438 L
.3565 .94231 L
.34615 .9406 L
.32692 .93655 L
.30769 .93113 L
.28846 .92398 L
.28638 .92308 L
.26923 .91619 L
.25 .9044 L
.24951 .90385 L
.23077 .89347 L
.21154 .88986 L
.19231 .89353 L
.17308 .90036 L
Mistroke
.16094 .90385 L
.15385 .90512 L
.13752 .90385 L
.13462 .90298 L
.11538 .89008 L
.11 .88462 L
.09821 .86538 L
.09615 .86081 L
.09218 .84615 L
.08953 .82692 L
.08899 .80769 L
.08853 .78846 L
.08673 .76923 L
.08355 .75 L
.07992 .73077 L
.07692 .71295 L
.07664 .71154 L
.07294 .69231 L
.06965 .67308 L
.06681 .65385 L
.06439 .63462 L
.06238 .61538 L
.06076 .59615 L
.05952 .57692 L
.05865 .55769 L
.05816 .53846 L
.05804 .51923 L
.0583 .5 L
.05894 .48077 L
.05996 .46154 L
.06134 .44231 L
.06308 .42308 L
.06526 .40385 L
.06797 .38462 L
.07097 .36538 L
.07346 .34615 L
.07515 .32692 L
.07692 .30813 L
.07696 .30769 L
.07885 .28846 L
.08572 .26923 L
.09615 .2508 L
.0969 .25 L
.11426 .23077 L
.11538 .22969 L
.13462 .21295 L
.13648 .21154 L
.15385 .19631 L
.15826 .19231 L
.17308 .17817 L
Mistroke
.17707 .17308 L
.18966 .15385 L
.19177 .13462 L
.18574 .11538 L
.18455 .09615 L
.19231 .08664 L
.20797 .07692 L
.21154 .0751 L
.23077 .06785 L
.25 .06306 L
.26923 .05961 L
.28352 .05769 L
.28846 .05702 L
Mfstroke
.6 g
.09615 .39553 m
.10877 .40385 L
.11538 .41544 L
.11879 .42308 L
.12589 .44231 L
.1317 .46154 L
.13462 .47275 L
.13663 .48077 L
.14086 .5 L
.14432 .51923 L
.14711 .53846 L
.14932 .55769 L
.15099 .57692 L
.15218 .59615 L
.15292 .61538 L
.15326 .63462 L
.15326 .65385 L
.15308 .67308 L
.15295 .69231 L
.14887 .71154 L
.14641 .73077 L
.14404 .75 L
.1432 .76923 L
.14611 .78846 L
.15363 .80769 L
.15385 .80794 L
.1653 .82692 L
.17274 .84615 L
.16857 .86538 L
.15385 .87853 L
.13462 .8762 L
.12128 .86538 L
.11538 .86016 L
.10925 .84615 L
.10342 .82692 L
.10684 .80769 L
.10672 .78846 L
.10426 .76923 L
.09942 .75 L
.09615 .73859 L
.09338 .73077 L
.08726 .71154 L
.08242 .69231 L
.079 .67308 L
.07695 .65385 L
.07692 .65353 L
.0742 .63462 L
.07194 .61538 L
.07015 .59615 L
.06882 .57692 L
.06795 .55769 L
.06754 .53846 L
.06763 .51923 L
.06827 .5 L
.06958 .48077 L
.07181 .46154 L
.07542 .44231 L
.07692 .43644 L
.08045 .42308 L
.08824 .40385 L
F
0 g
.09615 .39553 m
.10877 .40385 L
.11538 .41544 L
.11879 .42308 L
.12589 .44231 L
.1317 .46154 L
.13462 .47275 L
.13663 .48077 L
.14086 .5 L
.14432 .51923 L
.14711 .53846 L
.14932 .55769 L
.15099 .57692 L
.15218 .59615 L
.15292 .61538 L
.15326 .63462 L
.15326 .65385 L
.15308 .67308 L
.15295 .69231 L
.14887 .71154 L
.14641 .73077 L
.14404 .75 L
.1432 .76923 L
.14611 .78846 L
.15363 .80769 L
.15385 .80794 L
.1653 .82692 L
.17274 .84615 L
.16857 .86538 L
.15385 .87853 L
.13462 .8762 L
.12128 .86538 L
.11538 .86016 L
.10925 .84615 L
.10342 .82692 L
.10684 .80769 L
.10672 .78846 L
.10426 .76923 L
.09942 .75 L
.09615 .73859 L
.09338 .73077 L
.08726 .71154 L
.08242 .69231 L
.079 .67308 L
.07695 .65385 L
.07692 .65353 L
.0742 .63462 L
.07194 .61538 L
.07015 .59615 L
.06882 .57692 L
Mistroke
.06795 .55769 L
.06754 .53846 L
.06763 .51923 L
.06827 .5 L
.06958 .48077 L
.07181 .46154 L
.07542 .44231 L
.07692 .43644 L
.08045 .42308 L
.08824 .40385 L
.09615 .39553 L
Mfstroke
.7 g
.09615 .45168 m
.11436 .46154 L
.11538 .46332 L
.1225 .48077 L
.12813 .5 L
.13244 .51923 L
.13462 .53102 L
.13595 .53846 L
.13888 .55769 L
.14112 .57692 L
.14273 .59615 L
.14375 .61538 L
.14415 .63462 L
.14384 .65385 L
.14245 .67308 L
.13885 .69231 L
.13462 .70359 L
.13205 .71154 L
.11538 .72542 L
.10563 .71154 L
.09783 .69231 L
.09615 .68711 L
.09097 .67308 L
.08535 .65385 L
.08116 .63462 L
.08247 .61538 L
.0806 .59615 L
.07933 .57692 L
.07869 .55769 L
.0787 .53846 L
.07948 .51923 L
.08121 .5 L
.08432 .48077 L
.09003 .46154 L
F
0 g
.09615 .45168 m
.11436 .46154 L
.11538 .46332 L
.1225 .48077 L
.12813 .5 L
.13244 .51923 L
.13462 .53102 L
.13595 .53846 L
.13888 .55769 L
.14112 .57692 L
.14273 .59615 L
.14375 .61538 L
.14415 .63462 L
.14384 .65385 L
.14245 .67308 L
.13885 .69231 L
.13462 .70359 L
.13205 .71154 L
.11538 .72542 L
.10563 .71154 L
.09783 .69231 L
.09615 .68711 L
.09097 .67308 L
.08535 .65385 L
.08116 .63462 L
.08247 .61538 L
.0806 .59615 L
.07933 .57692 L
.07869 .55769 L
.0787 .53846 L
.07948 .51923 L
.08121 .5 L
.08432 .48077 L
.09003 .46154 L
.09615 .45168 L
s
.8 g
.09615 .52205 m
.11538 .5205 L
.12087 .53846 L
.12464 .55769 L
.12707 .57692 L
.12839 .59615 L
.12861 .61538 L
.12745 .63462 L
.12391 .65385 L
.11538 .66615 L
.10591 .65385 L
.09972 .63462 L
.09615 .61707 L
.09591 .61538 L
.09363 .59615 L
.09242 .57692 L
.09229 .55769 L
.09351 .53846 L
F
0 g
.09615 .52205 m
.11538 .5205 L
.12087 .53846 L
.12464 .55769 L
.12707 .57692 L
.12839 .59615 L
.12861 .61538 L
.12745 .63462 L
.12391 .65385 L
.11538 .66615 L
.10591 .65385 L
.09972 .63462 L
.09615 .61707 L
.09591 .61538 L
.09363 .59615 L
.09242 .57692 L
.09229 .55769 L
.09351 .53846 L
.09615 .52205 L
s
.6 g
.26923 .07241 m
.28846 .06795 L
.30769 .06477 L
.32692 .06242 L
.34615 .06062 L
.36538 .0591 L
.38462 .06199 L
.40385 .06199 L
.42308 .06226 L
.44231 .06279 L
.46154 .06361 L
.48077 .06479 L
.5 .06643 L
.51923 .0687 L
.53846 .07186 L
.55769 .07658 L
.55878 .07692 L
.56883 .09615 L
.55769 .10074 L
.53846 .10579 L
.51923 .10928 L
.5 .11188 L
.48077 .11392 L
.46436 .11538 L
.46154 .11565 L
.44231 .11745 L
.42308 .11938 L
.40385 .12175 L
.38462 .12479 L
.36538 .12861 L
.34615 .13289 L
.3377 .13462 L
.32692 .1385 L
.30769 .1477 L
.29933 .15385 L
.28846 .16556 L
.28517 .17308 L
.27832 .19231 L
.27027 .21154 L
.26923 .21387 L
.25746 .23077 L
.25 .23911 L
.23573 .25 L
.23077 .25316 L
.21154 .26325 L
.19231 .26908 L
.19137 .26923 L
.17308 .27361 L
.15385 .27879 L
.13462 .2805 L
.12158 .26923 L
.13032 .25 L
.13462 .24381 L
.14454 .23077 L
.15385 .21588 L
.16189 .21154 L
.17308 .19965 L
.18134 .19231 L
.19231 .18263 L
.20144 .17308 L
.21154 .16267 L
.21688 .15385 L
.22168 .13462 L
.21867 .11538 L
.2227 .09615 L
.23077 .08868 L
.25 .07879 L
.25513 .07692 L
F
0 g
.26923 .07241 m
.28846 .06795 L
.30769 .06477 L
.32692 .06242 L
.34615 .06062 L
.36538 .0591 L
.38462 .06199 L
.40385 .06199 L
.42308 .06226 L
.44231 .06279 L
.46154 .06361 L
.48077 .06479 L
.5 .06643 L
.51923 .0687 L
.53846 .07186 L
.55769 .07658 L
.55878 .07692 L
.56883 .09615 L
.55769 .10074 L
.53846 .10579 L
.51923 .10928 L
.5 .11188 L
.48077 .11392 L
.46436 .11538 L
.46154 .11565 L
.44231 .11745 L
.42308 .11938 L
.40385 .12175 L
.38462 .12479 L
.36538 .12861 L
.34615 .13289 L
.3377 .13462 L
.32692 .1385 L
.30769 .1477 L
.29933 .15385 L
.28846 .16556 L
.28517 .17308 L
.27832 .19231 L
.27027 .21154 L
.26923 .21387 L
.25746 .23077 L
.25 .23911 L
.23573 .25 L
.23077 .25316 L
.21154 .26325 L
.19231 .26908 L
.19137 .26923 L
.17308 .27361 L
.15385 .27879 L
.13462 .2805 L
Mistroke
.12158 .26923 L
.13032 .25 L
.13462 .24381 L
.14454 .23077 L
.15385 .21588 L
.16189 .21154 L
.17308 .19965 L
.18134 .19231 L
.19231 .18263 L
.20144 .17308 L
.21154 .16267 L
.21688 .15385 L
.22168 .13462 L
.21867 .11538 L
.2227 .09615 L
.23077 .08868 L
.25 .07879 L
.25513 .07692 L
.26923 .07241 L
Mfstroke
.3 g
.53846 .13339 m
.55769 .13179 L
.57692 .12993 L
.59615 .12784 L
.61538 .12563 L
.63462 .12362 L
.65385 .12251 L
.67308 .12348 L
.69231 .12813 L
.7072 .13462 L
.71154 .13811 L
.72515 .15385 L
.73077 .16545 L
.73328 .17308 L
.73762 .19231 L
.74101 .21154 L
.74529 .23077 L
.75 .24582 L
.75163 .25 L
.76109 .26923 L
.76923 .28116 L
.77529 .28846 L
.78846 .30011 L
.80008 .30769 L
.80769 .31071 L
.82692 .31578 L
.84615 .31873 L
.86404 .32692 L
.86538 .3281 L
.8777 .34615 L
.88188 .36538 L
.88361 .38462 L
.88431 .40385 L
.88445 .42308 L
.88427 .44231 L
.88391 .46154 L
.88343 .48077 L
.88281 .5 L
.88203 .51923 L
.88099 .53846 L
.87954 .55769 L
.87747 .57692 L
.87443 .59615 L
.86979 .61538 L
.86538 .62767 L
.86228 .63462 L
.84615 .65369 L
.84593 .65385 L
.82692 .66498 L
.81451 .67308 L
.80769 .67933 L
.79458 .69231 L
.78846 .70052 L
.78052 .71154 L
.76923 .73076 L
.76923 .73077 L
.75995 .75 L
.75236 .76923 L
.75 .7762 L
.74612 .78846 L
.74016 .80769 L
.73234 .82692 L
.73077 .82973 L
.71619 .84615 L
.71154 .84936 L
.69231 .85785 L
.67308 .86129 L
.65385 .86178 L
.63462 .86039 L
.61538 .85783 L
.59615 .85459 L
.57692 .85096 L
.55769 .84713 L
.55287 .84615 L
.53846 .84329 L
.51923 .83945 L
.5 .83571 L
.48077 .83221 L
.46154 .82905 L
.44706 .82692 L
.44231 .82631 L
.42308 .82404 L
.40385 .82221 L
.38462 .82083 L
.36538 .81992 L
.34615 .81952 L
.32692 .81966 L
.30769 .82037 L
.28846 .82165 L
.26923 .82335 L
.25 .82484 L
.23077 .82447 L
.21154 .81914 L
.1945 .80769 L
.19231 .80499 L
.18118 .78846 L
.17476 .76923 L
.17308 .75878 L
.1723 .75 L
.17187 .73077 L
.17224 .71154 L
.17272 .69231 L
.17301 .67308 L
.17299 .65385 L
.17264 .63462 L
.17197 .61538 L
.17098 .59615 L
.16968 .57692 L
.16805 .55769 L
.16611 .53846 L
.16385 .51923 L
.16127 .5 L
.15835 .48077 L
.15513 .46154 L
.15385 .45436 L
.15164 .44231 L
.14794 .42308 L
.1444 .40385 L
.1418 .38462 L
.14137 .36538 L
.14479 .34615 L
.15385 .32755 L
.15443 .32692 L
.17308 .31007 L
.17717 .30769 L
.19231 .30003 L
.21154 .29157 L
.21846 .28846 L
.23077 .28231 L
.25 .27078 L
.25227 .26923 L
.26923 .25589 L
.27552 .25 L
.28846 .23585 L
.29236 .23077 L
.30509 .21154 L
.30769 .20695 L
.31615 .19231 L
.32692 .17723 L
.3307 .17308 L
.34615 .1612 L
.36174 .15385 L
.36538 .15251 L
.38462 .147 L
.40385 .14341 L
.42308 .14105 L
.44231 .13943 L
.46154 .1382 L
.48077 .13712 L
.5 .13601 L
.51923 .13475 L
.52111 .13462 L
F
0 g
.53846 .13339 m
.55769 .13179 L
.57692 .12993 L
.59615 .12784 L
.61538 .12563 L
.63462 .12362 L
.65385 .12251 L
.67308 .12348 L
.69231 .12813 L
.7072 .13462 L
.71154 .13811 L
.72515 .15385 L
.73077 .16545 L
.73328 .17308 L
.73762 .19231 L
.74101 .21154 L
.74529 .23077 L
.75 .24582 L
.75163 .25 L
.76109 .26923 L
.76923 .28116 L
.77529 .28846 L
.78846 .30011 L
.80008 .30769 L
.80769 .31071 L
.82692 .31578 L
.84615 .31873 L
.86404 .32692 L
.86538 .3281 L
.8777 .34615 L
.88188 .36538 L
.88361 .38462 L
.88431 .40385 L
.88445 .42308 L
.88427 .44231 L
.88391 .46154 L
.88343 .48077 L
.88281 .5 L
.88203 .51923 L
.88099 .53846 L
.87954 .55769 L
.87747 .57692 L
.87443 .59615 L
.86979 .61538 L
.86538 .62767 L
.86228 .63462 L
.84615 .65369 L
.84593 .65385 L
.82692 .66498 L
.81451 .67308 L
Mistroke
.80769 .67933 L
.79458 .69231 L
.78846 .70052 L
.78052 .71154 L
.76923 .73076 L
.76923 .73077 L
.75995 .75 L
.75236 .76923 L
.75 .7762 L
.74612 .78846 L
.74016 .80769 L
.73234 .82692 L
.73077 .82973 L
.71619 .84615 L
.71154 .84936 L
.69231 .85785 L
.67308 .86129 L
.65385 .86178 L
.63462 .86039 L
.61538 .85783 L
.59615 .85459 L
.57692 .85096 L
.55769 .84713 L
.55287 .84615 L
.53846 .84329 L
.51923 .83945 L
.5 .83571 L
.48077 .83221 L
.46154 .82905 L
.44706 .82692 L
.44231 .82631 L
.42308 .82404 L
.40385 .82221 L
.38462 .82083 L
.36538 .81992 L
.34615 .81952 L
.32692 .81966 L
.30769 .82037 L
.28846 .82165 L
.26923 .82335 L
.25 .82484 L
.23077 .82447 L
.21154 .81914 L
.1945 .80769 L
.19231 .80499 L
.18118 .78846 L
.17476 .76923 L
.17308 .75878 L
.1723 .75 L
.17187 .73077 L
Mistroke
.17224 .71154 L
.17272 .69231 L
.17301 .67308 L
.17299 .65385 L
.17264 .63462 L
.17197 .61538 L
.17098 .59615 L
.16968 .57692 L
.16805 .55769 L
.16611 .53846 L
.16385 .51923 L
.16127 .5 L
.15835 .48077 L
.15513 .46154 L
.15385 .45436 L
.15164 .44231 L
.14794 .42308 L
.1444 .40385 L
.1418 .38462 L
.14137 .36538 L
.14479 .34615 L
.15385 .32755 L
.15443 .32692 L
.17308 .31007 L
.17717 .30769 L
.19231 .30003 L
.21154 .29157 L
.21846 .28846 L
.23077 .28231 L
.25 .27078 L
.25227 .26923 L
.26923 .25589 L
.27552 .25 L
.28846 .23585 L
.29236 .23077 L
.30509 .21154 L
.30769 .20695 L
.31615 .19231 L
.32692 .17723 L
.3307 .17308 L
.34615 .1612 L
.36174 .15385 L
.36538 .15251 L
.38462 .147 L
.40385 .14341 L
.42308 .14105 L
.44231 .13943 L
.46154 .1382 L
.48077 .13712 L
.5 .13601 L
Mistroke
.51923 .13475 L
.52111 .13462 L
.53846 .13339 L
Mfstroke
.2 g
.42308 .15271 m
.44231 .15084 L
.46154 .14954 L
.48077 .14848 L
.5 .14747 L
.51923 .14639 L
.53846 .14516 L
.55769 .14377 L
.57692 .14226 L
.59615 .1407 L
.61538 .1393 L
.63462 .13843 L
.65385 .13876 L
.67308 .14152 L
.69231 .14925 L
.69884 .15385 L
.71154 .1698 L
.71309 .17308 L
.71937 .19231 L
.72317 .21154 L
.72704 .23077 L
.73077 .24516 L
.7323 .25 L
.73982 .26923 L
.75 .28803 L
.75028 .28846 L
.76521 .30769 L
.76923 .31173 L
.78846 .32654 L
.78903 .32692 L
.80769 .33529 L
.82692 .34 L
.84615 .34473 L
.84916 .34615 L
.86538 .36362 L
.86634 .36538 L
.87291 .38462 L
.87574 .40385 L
.87698 .42308 L
.8774 .44231 L
.87734 .46154 L
.87695 .48077 L
.87626 .5 L
.8752 .51923 L
.87365 .53846 L
.87136 .55769 L
.86794 .57692 L
.86538 .5874 L
.86342 .59615 L
.85495 .61538 L
.84615 .62661 L
.83662 .63462 L
.82692 .64164 L
.8111 .65385 L
.80769 .65685 L
.79179 .67308 L
.78846 .67717 L
.77702 .69231 L
.76923 .70423 L
.76493 .71154 L
.75466 .73077 L
.75 .7406 L
.74606 .75 L
.73861 .76923 L
.73178 .78846 L
.73077 .79135 L
.72493 .80769 L
.71427 .82692 L
.71154 .8302 L
.69231 .84402 L
.68601 .84615 L
.67308 .84915 L
.65385 .85019 L
.63462 .84871 L
.61688 .84615 L
.61538 .84583 L
.59615 .8424 L
.57692 .83845 L
.55769 .83428 L
.53846 .8301 L
.52339 .82692 L
.51923 .82612 L
.5 .82254 L
.48077 .8192 L
.46154 .81619 L
.44231 .81354 L
.42308 .81129 L
.40385 .80945 L
.38462 .80803 L
.37964 .80769 L
.36538 .80708 L
.34615 .80654 L
.32692 .80641 L
.30769 .80668 L
.28846 .80733 L
.28001 .80769 L
.26923 .80813 L
.25 .80836 L
.23934 .80769 L
.23077 .80637 L
.21154 .79874 L
.19966 .78846 L
.19231 .77588 L
.18986 .76923 L
.18558 .75 L
.18419 .73077 L
.18397 .71154 L
.18404 .69231 L
.18402 .67308 L
.18377 .65385 L
.18325 .63462 L
.18246 .61538 L
.18141 .59615 L
.18011 .57692 L
.17857 .55769 L
.17681 .53846 L
.17485 .51923 L
.17308 .50328 L
.17264 .5 L
.16993 .48077 L
.16694 .46154 L
.16377 .44231 L
.1606 .42308 L
.15788 .40385 L
.15636 .38462 L
.15736 .36538 L
.16315 .34615 L
.17308 .33132 L
.17819 .32692 L
.19231 .31683 L
.21021 .30769 L
.21154 .30704 L
.23077 .29737 L
.24693 .28846 L
.25 .28656 L
.26923 .27318 L
.27423 .26923 L
.28846 .25644 L
.29469 .25 L
.30769 .23464 L
.31054 .23077 L
.32348 .21154 L
.32692 .20617 L
.33634 .19231 L
.34615 .18129 L
.35618 .17308 L
.36538 .16756 L
.38462 .15984 L
.40385 .15543 L
.41432 .15385 L
F
0 g
.42308 .15271 m
.44231 .15084 L
.46154 .14954 L
.48077 .14848 L
.5 .14747 L
.51923 .14639 L
.53846 .14516 L
.55769 .14377 L
.57692 .14226 L
.59615 .1407 L
.61538 .1393 L
.63462 .13843 L
.65385 .13876 L
.67308 .14152 L
.69231 .14925 L
.69884 .15385 L
.71154 .1698 L
.71309 .17308 L
.71937 .19231 L
.72317 .21154 L
.72704 .23077 L
.73077 .24516 L
.7323 .25 L
.73982 .26923 L
.75 .28803 L
.75028 .28846 L
.76521 .30769 L
.76923 .31173 L
.78846 .32654 L
.78903 .32692 L
.80769 .33529 L
.82692 .34 L
.84615 .34473 L
.84916 .34615 L
.86538 .36362 L
.86634 .36538 L
.87291 .38462 L
.87574 .40385 L
.87698 .42308 L
.8774 .44231 L
.87734 .46154 L
.87695 .48077 L
.87626 .5 L
.8752 .51923 L
.87365 .53846 L
.87136 .55769 L
.86794 .57692 L
.86538 .5874 L
.86342 .59615 L
.85495 .61538 L
Mistroke
.84615 .62661 L
.83662 .63462 L
.82692 .64164 L
.8111 .65385 L
.80769 .65685 L
.79179 .67308 L
.78846 .67717 L
.77702 .69231 L
.76923 .70423 L
.76493 .71154 L
.75466 .73077 L
.75 .7406 L
.74606 .75 L
.73861 .76923 L
.73178 .78846 L
.73077 .79135 L
.72493 .80769 L
.71427 .82692 L
.71154 .8302 L
.69231 .84402 L
.68601 .84615 L
.67308 .84915 L
.65385 .85019 L
.63462 .84871 L
.61688 .84615 L
.61538 .84583 L
.59615 .8424 L
.57692 .83845 L
.55769 .83428 L
.53846 .8301 L
.52339 .82692 L
.51923 .82612 L
.5 .82254 L
.48077 .8192 L
.46154 .81619 L
.44231 .81354 L
.42308 .81129 L
.40385 .80945 L
.38462 .80803 L
.37964 .80769 L
.36538 .80708 L
.34615 .80654 L
.32692 .80641 L
.30769 .80668 L
.28846 .80733 L
.28001 .80769 L
.26923 .80813 L
.25 .80836 L
.23934 .80769 L
.23077 .80637 L
Mistroke
.21154 .79874 L
.19966 .78846 L
.19231 .77588 L
.18986 .76923 L
.18558 .75 L
.18419 .73077 L
.18397 .71154 L
.18404 .69231 L
.18402 .67308 L
.18377 .65385 L
.18325 .63462 L
.18246 .61538 L
.18141 .59615 L
.18011 .57692 L
.17857 .55769 L
.17681 .53846 L
.17485 .51923 L
.17308 .50328 L
.17264 .5 L
.16993 .48077 L
.16694 .46154 L
.16377 .44231 L
.1606 .42308 L
.15788 .40385 L
.15636 .38462 L
.15736 .36538 L
.16315 .34615 L
.17308 .33132 L
.17819 .32692 L
.19231 .31683 L
.21021 .30769 L
.21154 .30704 L
.23077 .29737 L
.24693 .28846 L
.25 .28656 L
.26923 .27318 L
.27423 .26923 L
.28846 .25644 L
.29469 .25 L
.30769 .23464 L
.31054 .23077 L
.32348 .21154 L
.32692 .20617 L
.33634 .19231 L
.34615 .18129 L
.35618 .17308 L
.36538 .16756 L
.38462 .15984 L
.40385 .15543 L
.41432 .15385 L
Mistroke
.42308 .15271 L
Mfstroke
.1 g
.49638 .98077 m
.48077 .98065 L
.46154 .98035 L
.44231 .97986 L
.42308 .97918 L
.40385 .97829 L
.38462 .97717 L
.36538 .9758 L
.34615 .97415 L
.32692 .9722 L
.30769 .96993 L
.28846 .96735 L
.26923 .96461 L
.25 .96218 L
.24287 .96154 L
.23077 .96101 L
.21907 .96154 L
.21154 .96251 L
.19231 .96777 L
.17308 .97586 L
.16081 .98077 L
F
0 g
.49638 .98077 m
.48077 .98065 L
.46154 .98035 L
.44231 .97986 L
.42308 .97918 L
.40385 .97829 L
.38462 .97717 L
.36538 .9758 L
.34615 .97415 L
.32692 .9722 L
.30769 .96993 L
.28846 .96735 L
.26923 .96461 L
.25 .96218 L
.24287 .96154 L
.23077 .96101 L
.21907 .96154 L
.21154 .96251 L
.19231 .96777 L
.17308 .97586 L
.16081 .98077 L
s
.1 g
.40385 .17059 m
.42308 .16651 L
.44231 .1641 L
.46154 .1626 L
.48077 .16153 L
.5 .16063 L
.51923 .15973 L
.53846 .15877 L
.55769 .15775 L
.57692 .1567 L
.59615 .15575 L
.61538 .15515 L
.63462 .15536 L
.65385 .15735 L
.67308 .16375 L
.68505 .17308 L
.69231 .18338 L
.69607 .19231 L
.70122 .21154 L
.70507 .23077 L
.70952 .25 L
.71154 .25728 L
.71558 .26923 L
.72374 .28846 L
.73077 .30173 L
.73446 .30769 L
.74892 .32692 L
.75 .32814 L
.76923 .34588 L
.76958 .34615 L
.78846 .35769 L
.80769 .3651 L
.80879 .36538 L
.82692 .36982 L
.84615 .37828 L
.8518 .38462 L
.86021 .40385 L
.86383 .42308 L
.86538 .4396 L
.86554 .44231 L
.8663 .46154 L
.86629 .48077 L
.86564 .5 L
.86538 .50553 L
.86447 .51923 L
.86256 .53846 L
.86143 .55769 L
.85547 .57692 L
.84615 .59384 L
.84445 .59615 L
.82692 .61399 L
.82524 .61538 L
.80769 .63029 L
.80304 .63462 L
.78846 .64998 L
.78519 .65385 L
.77044 .67308 L
.76923 .67481 L
.75811 .69231 L
.75 .70618 L
.74731 .71154 L
.73793 .73077 L
.73077 .74666 L
.72953 .75 L
.72226 .76923 L
.71454 .78846 L
.71154 .79516 L
.7059 .80769 L
.69231 .82317 L
.68664 .82692 L
.67308 .83271 L
.65385 .83499 L
.63462 .83358 L
.61538 .83028 L
.59953 .82692 L
.59615 .82623 L
.57692 .82218 L
.55769 .81794 L
.53846 .81379 L
.51923 .80987 L
.50779 .80769 L
.5 .80647 L
.48077 .80357 L
.46154 .80089 L
.44231 .79848 L
.42308 .79637 L
.40385 .7946 L
.38462 .79316 L
.36538 .79208 L
.34615 .79136 L
.32692 .791 L
.30769 .79098 L
.28846 .7912 L
.26923 .79133 L
.25 .79038 L
.23872 .78846 L
.23077 .78626 L
.21154 .77173 L
.20981 .76923 L
.20165 .75 L
.19886 .73077 L
.19797 .71154 L
.19764 .69231 L
.19736 .67308 L
.19694 .65385 L
.19633 .63462 L
.19553 .61538 L
.19456 .59615 L
.19346 .57692 L
.19231 .55862 L
.19222 .55769 L
.19038 .53846 L
.1883 .51923 L
.18598 .5 L
.18346 .48077 L
.18079 .46154 L
.17809 .44231 L
.1756 .42308 L
.17376 .40385 L
.17336 .38462 L
.17617 .36538 L
.18629 .34615 L
.19231 .33945 L
.21044 .32692 L
.21154 .32626 L
.23077 .31559 L
.24574 .30769 L
.25 .30517 L
.26923 .29283 L
.27554 .28846 L
.28846 .27825 L
.29875 .26923 L
.30769 .26048 L
.31724 .25 L
.32692 .23823 L
.3324 .23077 L
.34615 .21154 L
.34615 .21153 L
.36226 .19231 L
.36538 .1895 L
.38462 .17705 L
.39553 .17308 L
F
0 g
.40385 .17059 m
.42308 .16651 L
.44231 .1641 L
.46154 .1626 L
.48077 .16153 L
.5 .16063 L
.51923 .15973 L
.53846 .15877 L
.55769 .15775 L
.57692 .1567 L
.59615 .15575 L
.61538 .15515 L
.63462 .15536 L
.65385 .15735 L
.67308 .16375 L
.68505 .17308 L
.69231 .18338 L
.69607 .19231 L
.70122 .21154 L
.70507 .23077 L
.70952 .25 L
.71154 .25728 L
.71558 .26923 L
.72374 .28846 L
.73077 .30173 L
.73446 .30769 L
.74892 .32692 L
.75 .32814 L
.76923 .34588 L
.76958 .34615 L
.78846 .35769 L
.80769 .3651 L
.80879 .36538 L
.82692 .36982 L
.84615 .37828 L
.8518 .38462 L
.86021 .40385 L
.86383 .42308 L
.86538 .4396 L
.86554 .44231 L
.8663 .46154 L
.86629 .48077 L
.86564 .5 L
.86538 .50553 L
.86447 .51923 L
.86256 .53846 L
.86143 .55769 L
.85547 .57692 L
.84615 .59384 L
.84445 .59615 L
Mistroke
.82692 .61399 L
.82524 .61538 L
.80769 .63029 L
.80304 .63462 L
.78846 .64998 L
.78519 .65385 L
.77044 .67308 L
.76923 .67481 L
.75811 .69231 L
.75 .70618 L
.74731 .71154 L
.73793 .73077 L
.73077 .74666 L
.72953 .75 L
.72226 .76923 L
.71454 .78846 L
.71154 .79516 L
.7059 .80769 L
.69231 .82317 L
.68664 .82692 L
.67308 .83271 L
.65385 .83499 L
.63462 .83358 L
.61538 .83028 L
.59953 .82692 L
.59615 .82623 L
.57692 .82218 L
.55769 .81794 L
.53846 .81379 L
.51923 .80987 L
.50779 .80769 L
.5 .80647 L
.48077 .80357 L
.46154 .80089 L
.44231 .79848 L
.42308 .79637 L
.40385 .7946 L
.38462 .79316 L
.36538 .79208 L
.34615 .79136 L
.32692 .791 L
.30769 .79098 L
.28846 .7912 L
.26923 .79133 L
.25 .79038 L
.23872 .78846 L
.23077 .78626 L
.21154 .77173 L
.20981 .76923 L
.20165 .75 L
Mistroke
.19886 .73077 L
.19797 .71154 L
.19764 .69231 L
.19736 .67308 L
.19694 .65385 L
.19633 .63462 L
.19553 .61538 L
.19456 .59615 L
.19346 .57692 L
.19231 .55862 L
.19222 .55769 L
.19038 .53846 L
.1883 .51923 L
.18598 .5 L
.18346 .48077 L
.18079 .46154 L
.17809 .44231 L
.1756 .42308 L
.17376 .40385 L
.17336 .38462 L
.17617 .36538 L
.18629 .34615 L
.19231 .33945 L
.21044 .32692 L
.21154 .32626 L
.23077 .31559 L
.24574 .30769 L
.25 .30517 L
.26923 .29283 L
.27554 .28846 L
.28846 .27825 L
.29875 .26923 L
.30769 .26048 L
.31724 .25 L
.32692 .23823 L
.3324 .23077 L
.34615 .21154 L
.34615 .21153 L
.36226 .19231 L
.36538 .1895 L
.38462 .17705 L
.39553 .17308 L
.40385 .17059 L
Mfstroke
.7 g
.21154 .19205 m
.23077 .18086 L
.25 .19163 L
.2503 .19231 L
.25 .20429 L
.2478 .21154 L
.23429 .23077 L
.23077 .23416 L
.21154 .24399 L
.19231 .24781 L
.17647 .23077 L
.18799 .21154 L
.19231 .20486 L
.21097 .19231 L
F
0 g
.21154 .19205 m
.23077 .18086 L
.25 .19163 L
.2503 .19231 L
.25 .20429 L
.2478 .21154 L
.23429 .23077 L
.23077 .23416 L
.21154 .24399 L
.19231 .24781 L
.17647 .23077 L
.18799 .21154 L
.19231 .20486 L
.21097 .19231 L
.21154 .19205 L
s
.42308 .18916 m
.44231 .18491 L
.46154 .18256 L
.48077 .18117 L
.5 .1802 L
.51923 .17938 L
.53846 .1786 L
.55769 .17786 L
.57692 .17726 L
.59615 .17705 L
.61538 .17777 L
.63462 .18101 L
.65384 .19231 L
.65385 .19231 L
.66636 .21154 L
.67126 .23077 L
.67308 .24004 L
.67531 .25 L
.6803 .26923 L
.6865 .28846 L
.69231 .30365 L
.69415 .30769 L
.7041 .32692 L
.71154 .33924 L
.71635 .34615 L
.73077 .36398 L
.73207 .36538 L
.75 .38203 L
.75327 .38462 L
.76923 .39512 L
.78692 .40385 L
.78846 .40443 L
.80769 .41057 L
.82692 .41718 L
.8354 .42308 L
.84529 .44231 L
.84615 .44472 L
.84877 .46154 L
.84996 .48077 L
.84969 .5 L
.84799 .51923 L
.84615 .53161 L
.84428 .53846 L
.8373 .55769 L
.82692 .5714 L
.82151 .57692 L
.80769 .59028 L
.80151 .59615 L
.78846 .60966 L
.78339 .61538 L
.76923 .63254 L
.76774 .63462 L
.75417 .65385 L
.75 .66002 L
.74248 .67308 L
.73113 .69231 L
.73077 .69294 L
.72214 .71154 L
.71272 .73077 L
.71154 .7333 L
.70539 .75 L
.6965 .76923 L
.69231 .77692 L
.68738 .78846 L
.67308 .80108 L
.65385 .80758 L
.63462 .80744 L
.61538 .80487 L
.59615 .80112 L
.57692 .79693 L
.55769 .79276 L
.53846 .78884 L
.53651 .78846 L
.51923 .78615 L
.5 .78345 L
.48077 .78077 L
.46154 .77824 L
.44231 .77592 L
.42308 .77386 L
.40385 .7721 L
.38462 .77063 L
.36538 .76947 L
.36091 .76923 L
.34615 .76887 L
.32692 .7685 L
.30769 .76827 L
.28846 .76805 L
.26923 .76733 L
.25 .7643 L
.23099 .75 L
.23077 .74984 L
.222 .73077 L
.21923 .71154 L
.21818 .69231 L
.21754 .67308 L
.21688 .65385 L
.21611 .63462 L
.21522 .61538 L
.21424 .59615 L
.21323 .57692 L
.21223 .55769 L
.21154 .54288 L
.21109 .53846 L
.20902 .51923 L
.20674 .5 L
.20428 .48077 L
.20173 .46154 L
.19928 .44231 L
.1973 .42308 L
.19647 .40385 L
.19835 .38462 L
.20703 .36538 L
.21154 .35928 L
.22855 .34615 L
.23077 .34464 L
.25 .33278 L
.26099 .32692 L
.26923 .32163 L
.28846 .3089 L
.29029 .30769 L
.30769 .29385 L
.31415 .28846 L
.32692 .27653 L
.33406 .26923 L
.34615 .25594 L
.35094 .25 L
.36538 .23194 L
.36622 .23077 L
.3827 .21154 L
.38462 .20972 L
.40385 .19581 L
.41332 .19231 L
F
.42308 .18916 m
.44231 .18491 L
.46154 .18256 L
.48077 .18117 L
.5 .1802 L
.51923 .17938 L
.53846 .1786 L
.55769 .17786 L
.57692 .17726 L
.59615 .17705 L
.61538 .17777 L
.63462 .18101 L
.65384 .19231 L
.65385 .19231 L
.66636 .21154 L
.67126 .23077 L
.67308 .24004 L
.67531 .25 L
.6803 .26923 L
.6865 .28846 L
.69231 .30365 L
.69415 .30769 L
.7041 .32692 L
.71154 .33924 L
.71635 .34615 L
.73077 .36398 L
.73207 .36538 L
.75 .38203 L
.75327 .38462 L
.76923 .39512 L
.78692 .40385 L
.78846 .40443 L
.80769 .41057 L
.82692 .41718 L
.8354 .42308 L
.84529 .44231 L
.84615 .44472 L
.84877 .46154 L
.84996 .48077 L
.84969 .5 L
.84799 .51923 L
.84615 .53161 L
.84428 .53846 L
.8373 .55769 L
.82692 .5714 L
.82151 .57692 L
.80769 .59028 L
.80151 .59615 L
.78846 .60966 L
.78339 .61538 L
Mistroke
.76923 .63254 L
.76774 .63462 L
.75417 .65385 L
.75 .66002 L
.74248 .67308 L
.73113 .69231 L
.73077 .69294 L
.72214 .71154 L
.71272 .73077 L
.71154 .7333 L
.70539 .75 L
.6965 .76923 L
.69231 .77692 L
.68738 .78846 L
.67308 .80108 L
.65385 .80758 L
.63462 .80744 L
.61538 .80487 L
.59615 .80112 L
.57692 .79693 L
.55769 .79276 L
.53846 .78884 L
.53651 .78846 L
.51923 .78615 L
.5 .78345 L
.48077 .78077 L
.46154 .77824 L
.44231 .77592 L
.42308 .77386 L
.40385 .7721 L
.38462 .77063 L
.36538 .76947 L
.36091 .76923 L
.34615 .76887 L
.32692 .7685 L
.30769 .76827 L
.28846 .76805 L
.26923 .76733 L
.25 .7643 L
.23099 .75 L
.23077 .74984 L
.222 .73077 L
.21923 .71154 L
.21818 .69231 L
.21754 .67308 L
.21688 .65385 L
.21611 .63462 L
.21522 .61538 L
.21424 .59615 L
.21323 .57692 L
Mistroke
.21223 .55769 L
.21154 .54288 L
.21109 .53846 L
.20902 .51923 L
.20674 .5 L
.20428 .48077 L
.20173 .46154 L
.19928 .44231 L
.1973 .42308 L
.19647 .40385 L
.19835 .38462 L
.20703 .36538 L
.21154 .35928 L
.22855 .34615 L
.23077 .34464 L
.25 .33278 L
.26099 .32692 L
.26923 .32163 L
.28846 .3089 L
.29029 .30769 L
.30769 .29385 L
.31415 .28846 L
.32692 .27653 L
.33406 .26923 L
.34615 .25594 L
.35094 .25 L
.36538 .23194 L
.36622 .23077 L
.3827 .21154 L
.38462 .20972 L
.40385 .19581 L
.41332 .19231 L
.42308 .18916 L
Mfstroke
.7 g
.34615 .07649 m
.36538 .07547 L
.38462 .0762 L
.40385 .0768 L
.40673 .07692 L
.42308 .07798 L
.44231 .07991 L
.46154 .08338 L
.46227 .09615 L
.46154 .09633 L
.44231 .09992 L
.42308 .10273 L
.40385 .10548 L
.38462 .10854 L
.36538 .11211 L
.35006 .11538 L
.34615 .11657 L
.32692 .12356 L
.30769 .12536 L
.28846 .129 L
.26923 .12712 L
.25768 .11538 L
.26517 .09615 L
.26923 .09346 L
.28846 .0853 L
.30769 .08077 L
.32692 .07808 L
.34089 .07692 L
F
0 g
.34615 .07649 m
.36538 .07547 L
.38462 .0762 L
.40385 .0768 L
.40673 .07692 L
.42308 .07798 L
.44231 .07991 L
.46154 .08338 L
.46227 .09615 L
.46154 .09633 L
.44231 .09992 L
.42308 .10273 L
.40385 .10548 L
.38462 .10854 L
.36538 .11211 L
.35006 .11538 L
.34615 .11657 L
.32692 .12356 L
.30769 .12536 L
.28846 .129 L
.26923 .12712 L
.25768 .11538 L
.26517 .09615 L
.26923 .09346 L
.28846 .0853 L
.30769 .08077 L
.32692 .07808 L
.34089 .07692 L
.34615 .07649 L
s
.6 g
.80769 .72528 m
.82692 .71383 L
.84615 .7275 L
.84683 .73077 L
.84615 .7473 L
.84563 .75 L
.84296 .76923 L
.83255 .78846 L
.82692 .79812 L
.82094 .80769 L
.80999 .82692 L
.80769 .82961 L
.80211 .84615 L
.80592 .86538 L
.80769 .86866 L
.81379 .88462 L
.81535 .90385 L
.80769 .91554 L
.79845 .92308 L
.78846 .92928 L
.76923 .93661 L
.75 .94035 L
.73077 .94203 L
.71154 .9407 L
.69231 .94032 L
.67308 .94015 L
.65385 .94062 L
.63462 .94166 L
.62464 .94231 L
.61538 .94299 L
.59615 .94431 L
.57692 .94543 L
.55769 .94625 L
.53846 .94676 L
.51923 .94693 L
.5 .94677 L
.48077 .94626 L
.46154 .94537 L
.44231 .94409 L
.42308 .94234 L
.42273 .94231 L
.40385 .9407 L
.38462 .93817 L
.36538 .93454 L
.34615 .92955 L
.32752 .92308 L
.32692 .92285 L
.30769 .91745 L
.29088 .90385 L
.28846 .90191 L
.27422 .88462 L
.27707 .86538 L
.28846 .85775 L
.30769 .85117 L
.32692 .8468 L
.33927 .84615 L
.34615 .84574 L
.36538 .84504 L
.38462 .84527 L
.40233 .84615 L
.40385 .84625 L
.42308 .8478 L
.44231 .84991 L
.46154 .85249 L
.48077 .85541 L
.5 .85855 L
.51923 .8618 L
.53846 .86506 L
.54037 .86538 L
.55769 .86802 L
.57692 .87101 L
.59615 .87401 L
.61538 .8769 L
.63462 .87942 L
.65385 .88107 L
.67308 .88109 L
.69231 .87876 L
.71154 .87379 L
.73077 .86647 L
.73261 .86538 L
.75 .85544 L
.76013 .84615 L
.76923 .82877 L
.76969 .82692 L
.77226 .80769 L
.77535 .78846 L
.77891 .76923 L
.78846 .75108 L
.78944 .75 L
.80271 .73077 L
F
0 g
.80769 .72528 m
.82692 .71383 L
.84615 .7275 L
.84683 .73077 L
.84615 .7473 L
.84563 .75 L
.84296 .76923 L
.83255 .78846 L
.82692 .79812 L
.82094 .80769 L
.80999 .82692 L
.80769 .82961 L
.80211 .84615 L
.80592 .86538 L
.80769 .86866 L
.81379 .88462 L
.81535 .90385 L
.80769 .91554 L
.79845 .92308 L
.78846 .92928 L
.76923 .93661 L
.75 .94035 L
.73077 .94203 L
.71154 .9407 L
.69231 .94032 L
.67308 .94015 L
.65385 .94062 L
.63462 .94166 L
.62464 .94231 L
.61538 .94299 L
.59615 .94431 L
.57692 .94543 L
.55769 .94625 L
.53846 .94676 L
.51923 .94693 L
.5 .94677 L
.48077 .94626 L
.46154 .94537 L
.44231 .94409 L
.42308 .94234 L
.42273 .94231 L
.40385 .9407 L
.38462 .93817 L
.36538 .93454 L
.34615 .92955 L
.32752 .92308 L
.32692 .92285 L
.30769 .91745 L
.29088 .90385 L
.28846 .90191 L
Mistroke
.27422 .88462 L
.27707 .86538 L
.28846 .85775 L
.30769 .85117 L
.32692 .8468 L
.33927 .84615 L
.34615 .84574 L
.36538 .84504 L
.38462 .84527 L
.40233 .84615 L
.40385 .84625 L
.42308 .8478 L
.44231 .84991 L
.46154 .85249 L
.48077 .85541 L
.5 .85855 L
.51923 .8618 L
.53846 .86506 L
.54037 .86538 L
.55769 .86802 L
.57692 .87101 L
.59615 .87401 L
.61538 .8769 L
.63462 .87942 L
.65385 .88107 L
.67308 .88109 L
.69231 .87876 L
.71154 .87379 L
.73077 .86647 L
.73261 .86538 L
.75 .85544 L
.76013 .84615 L
.76923 .82877 L
.76969 .82692 L
.77226 .80769 L
.77535 .78846 L
.77891 .76923 L
.78846 .75108 L
.78944 .75 L
.80271 .73077 L
.80769 .72528 L
Mfstroke
.7 g
.34615 .86341 m
.36538 .86014 L
.38462 .85918 L
.40385 .85943 L
.42308 .86052 L
.44231 .86222 L
.46154 .86439 L
.4696 .86538 L
.48077 .86652 L
.5 .86887 L
.51923 .87157 L
.53846 .8745 L
.55769 .87762 L
.57692 .88088 L
.59615 .88426 L
.59812 .88462 L
.61538 .8874 L
.63462 .89026 L
.65385 .89232 L
.67308 .89273 L
.69231 .89074 L
.71154 .88626 L
.71682 .88462 L
.73077 .87936 L
.75 .87199 L
.76923 .86791 L
.78846 .87212 L
.79315 .88462 L
.79515 .90385 L
.78846 .91251 L
.7717 .92308 L
.76923 .92421 L
.75 .93108 L
.73077 .93536 L
.71154 .93054 L
.69231 .92985 L
.67308 .92963 L
.65385 .93046 L
.63462 .93208 L
.61538 .93397 L
.59615 .93575 L
.57692 .9372 L
.55769 .93825 L
.53846 .93889 L
.51923 .93912 L
.5 .93892 L
.48077 .94123 L
.46154 .93992 L
.44231 .93807 L
.42308 .93547 L
.40385 .93192 L
.38462 .92716 L
.37152 .92308 L
.36538 .92113 L
.34615 .91345 L
.33019 .90385 L
.32692 .90099 L
.31815 .88462 L
.32692 .87118 L
.34005 .86538 L
F
0 g
.34615 .86341 m
.36538 .86014 L
.38462 .85918 L
.40385 .85943 L
.42308 .86052 L
.44231 .86222 L
.46154 .86439 L
.4696 .86538 L
.48077 .86652 L
.5 .86887 L
.51923 .87157 L
.53846 .8745 L
.55769 .87762 L
.57692 .88088 L
.59615 .88426 L
.59812 .88462 L
.61538 .8874 L
.63462 .89026 L
.65385 .89232 L
.67308 .89273 L
.69231 .89074 L
.71154 .88626 L
.71682 .88462 L
.73077 .87936 L
.75 .87199 L
.76923 .86791 L
.78846 .87212 L
.79315 .88462 L
.79515 .90385 L
.78846 .91251 L
.7717 .92308 L
.76923 .92421 L
.75 .93108 L
.73077 .93536 L
.71154 .93054 L
.69231 .92985 L
.67308 .92963 L
.65385 .93046 L
.63462 .93208 L
.61538 .93397 L
.59615 .93575 L
.57692 .9372 L
.55769 .93825 L
.53846 .93889 L
.51923 .93912 L
.5 .93892 L
.48077 .94123 L
.46154 .93992 L
.44231 .93807 L
.42308 .93547 L
Mistroke
.40385 .93192 L
.38462 .92716 L
.37152 .92308 L
.36538 .92113 L
.34615 .91345 L
.33019 .90385 L
.32692 .90099 L
.31815 .88462 L
.32692 .87118 L
.34005 .86538 L
.34615 .86341 L
Mfstroke
.8 g
.38462 .88058 m
.40385 .87696 L
.42308 .87127 L
.44231 .87348 L
.46154 .8756 L
.48077 .87794 L
.5 .88055 L
.51923 .88342 L
.52686 .88462 L
.53846 .88629 L
.55769 .88931 L
.57692 .8927 L
.59615 .8966 L
.61538 .9013 L
.62371 .90385 L
.61538 .92104 L
.60676 .92308 L
.59615 .92481 L
.57692 .92722 L
.55769 .92884 L
.53846 .9298 L
.51923 .93015 L
.5 .92992 L
.48077 .93299 L
.46154 .93012 L
.44231 .92647 L
.42776 .92308 L
.42308 .92211 L
.40385 .91714 L
.38462 .90955 L
.37547 .90385 L
.37542 .88462 L
F
0 g
.38462 .88058 m
.40385 .87696 L
.42308 .87127 L
.44231 .87348 L
.46154 .8756 L
.48077 .87794 L
.5 .88055 L
.51923 .88342 L
.52686 .88462 L
.53846 .88629 L
.55769 .88931 L
.57692 .8927 L
.59615 .8966 L
.61538 .9013 L
.62371 .90385 L
.61538 .92104 L
.60676 .92308 L
.59615 .92481 L
.57692 .92722 L
.55769 .92884 L
.53846 .9298 L
.51923 .93015 L
.5 .92992 L
.48077 .93299 L
.46154 .93012 L
.44231 .92647 L
.42776 .92308 L
.42308 .92211 L
.40385 .91714 L
.38462 .90955 L
.37547 .90385 L
.37542 .88462 L
.38462 .88058 L
s
.1 g
.46154 .37935 m
.48077 .37504 L
.5 .37383 L
.51923 .37568 L
.53846 .38028 L
.55207 .38462 L
.55769 .3875 L
.57692 .39918 L
.58358 .40385 L
.59615 .41517 L
.60331 .42308 L
.61538 .43874 L
.61727 .44231 L
.62668 .46154 L
.6334 .48077 L
.63462 .48592 L
.63616 .5 L
.63633 .51923 L
.63462 .53499 L
.6338 .53846 L
.62698 .55769 L
.61642 .57692 L
.61538 .57847 L
.59899 .59615 L
.59615 .59843 L
.57692 .61077 L
.5675 .61538 L
.55769 .61814 L
.53846 .62178 L
.51923 .62255 L
.5 .62046 L
.48077 .61607 L
.47818 .61538 L
.46154 .60753 L
.44243 .59615 L
.44231 .59606 L
.42308 .57893 L
.42126 .57692 L
.40645 .55769 L
.40385 .55372 L
.39667 .53846 L
.38953 .51923 L
.3855 .5 L
.3847 .48077 L
.38723 .46154 L
.3933 .44231 L
.4029 .42308 L
.40385 .42152 L
.41895 .40385 L
.42308 .4002 L
.44231 .38696 L
.44653 .38462 L
F
0 g
.46154 .37935 m
.48077 .37504 L
.5 .37383 L
.51923 .37568 L
.53846 .38028 L
.55207 .38462 L
.55769 .3875 L
.57692 .39918 L
.58358 .40385 L
.59615 .41517 L
.60331 .42308 L
.61538 .43874 L
.61727 .44231 L
.62668 .46154 L
.6334 .48077 L
.63462 .48592 L
.63616 .5 L
.63633 .51923 L
.63462 .53499 L
.6338 .53846 L
.62698 .55769 L
.61642 .57692 L
.61538 .57847 L
.59899 .59615 L
.59615 .59843 L
.57692 .61077 L
.5675 .61538 L
.55769 .61814 L
.53846 .62178 L
.51923 .62255 L
.5 .62046 L
.48077 .61607 L
.47818 .61538 L
.46154 .60753 L
.44243 .59615 L
.44231 .59606 L
.42308 .57893 L
.42126 .57692 L
.40645 .55769 L
.40385 .55372 L
.39667 .53846 L
.38953 .51923 L
.3855 .5 L
.3847 .48077 L
.38723 .46154 L
.3933 .44231 L
.4029 .42308 L
.40385 .42152 L
.41895 .40385 L
.42308 .4002 L
Mistroke
.44231 .38696 L
.44653 .38462 L
.46154 .37935 L
Mfstroke
.2 g
.48077 .39974 m
.5 .39785 L
.51923 .39951 L
.53792 .40385 L
.53846 .40454 L
.55769 .4142 L
.57054 .42308 L
.57692 .42873 L
.58914 .44231 L
.59615 .45217 L
.60101 .46154 L
.60839 .48077 L
.612 .5 L
.61176 .51923 L
.60745 .53846 L
.5985 .55769 L
.59615 .56138 L
.58212 .57692 L
.57692 .58102 L
.55769 .5919 L
.54878 .59615 L
.53846 .59748 L
.51923 .59886 L
.5 .59689 L
.49497 .59615 L
.48077 .59096 L
.46154 .58093 L
.45549 .57692 L
.44231 .56547 L
.43527 .55769 L
.42308 .54025 L
.42218 .53846 L
.41434 .51923 L
.41011 .5 L
.40965 .48077 L
.41316 .46154 L
.4211 .44231 L
.42308 .43879 L
.43586 .42308 L
.44231 .41743 L
.46154 .40566 L
.46414 .40385 L
F
0 g
.48077 .39974 m
.5 .39785 L
.51923 .39951 L
.53792 .40385 L
.53846 .40454 L
.55769 .4142 L
.57054 .42308 L
.57692 .42873 L
.58914 .44231 L
.59615 .45217 L
.60101 .46154 L
.60839 .48077 L
.612 .5 L
.61176 .51923 L
.60745 .53846 L
.5985 .55769 L
.59615 .56138 L
.58212 .57692 L
.57692 .58102 L
.55769 .5919 L
.54878 .59615 L
.53846 .59748 L
.51923 .59886 L
.5 .59689 L
.49497 .59615 L
.48077 .59096 L
.46154 .58093 L
.45549 .57692 L
.44231 .56547 L
.43527 .55769 L
.42308 .54025 L
.42218 .53846 L
.41434 .51923 L
.41011 .5 L
.40965 .48077 L
.41316 .46154 L
.4211 .44231 L
.42308 .43879 L
.43586 .42308 L
.44231 .41743 L
.46154 .40566 L
.46414 .40385 L
.48077 .39974 L
s
.3 g
.48077 .41612 m
.5 .41339 L
.51923 .41506 L
.53846 .42097 L
.5434 .42308 L
.55769 .43211 L
.56945 .44231 L
.57692 .45077 L
.58397 .46154 L
.59253 .48077 L
.59615 .49781 L
.59636 .5 L
.59615 .51576 L
.59571 .51923 L
.59012 .53846 L
.57803 .55769 L
.57692 .55894 L
.55769 .57393 L
.55399 .57692 L
.53846 .58111 L
.51923 .58323 L
.5 .58107 L
.48343 .57692 L
.48077 .57461 L
.46154 .56266 L
.45568 .55769 L
.44231 .54253 L
.43967 .53846 L
.4303 .51923 L
.42566 .5 L
.42551 .48077 L
.43015 .46154 L
.44081 .44231 L
.44231 .4404 L
.46154 .42402 L
.46267 .42308 L
F
0 g
.48077 .41612 m
.5 .41339 L
.51923 .41506 L
.53846 .42097 L
.5434 .42308 L
.55769 .43211 L
.56945 .44231 L
.57692 .45077 L
.58397 .46154 L
.59253 .48077 L
.59615 .49781 L
.59636 .5 L
.59615 .51576 L
.59571 .51923 L
.59012 .53846 L
.57803 .55769 L
.57692 .55894 L
.55769 .57393 L
.55399 .57692 L
.53846 .58111 L
.51923 .58323 L
.5 .58107 L
.48343 .57692 L
.48077 .57461 L
.46154 .56266 L
.45568 .55769 L
.44231 .54253 L
.43967 .53846 L
.4303 .51923 L
.42566 .5 L
.42551 .48077 L
.43015 .46154 L
.44081 .44231 L
.44231 .4404 L
.46154 .42402 L
.46267 .42308 L
.48077 .41612 L
s
.4 g
.46154 .44018 m
.48077 .42963 L
.5 .42597 L
.51923 .4276 L
.53846 .43442 L
.55156 .44231 L
.55769 .44763 L
.56969 .46154 L
.57692 .47311 L
.57947 .48077 L
.58352 .5 L
.58242 .51923 L
.57692 .5355 L
.57539 .53846 L
.55847 .55769 L
.55769 .55825 L
.53846 .56772 L
.51923 .57068 L
.5 .56842 L
.48077 .56094 L
.47501 .55769 L
.46154 .54665 L
.45443 .53846 L
.44338 .51923 L
.44231 .51638 L
.43843 .5 L
.43861 .48077 L
.44231 .46655 L
.44445 .46154 L
.45898 .44231 L
F
0 g
.46154 .44018 m
.48077 .42963 L
.5 .42597 L
.51923 .4276 L
.53846 .43442 L
.55156 .44231 L
.55769 .44763 L
.56969 .46154 L
.57692 .47311 L
.57947 .48077 L
.58352 .5 L
.58242 .51923 L
.57692 .5355 L
.57539 .53846 L
.55847 .55769 L
.55769 .55825 L
.53846 .56772 L
.51923 .57068 L
.5 .56842 L
.48077 .56094 L
.47501 .55769 L
.46154 .54665 L
.45443 .53846 L
.44338 .51923 L
.44231 .51638 L
.43843 .5 L
.43861 .48077 L
.44231 .46655 L
.44445 .46154 L
.45898 .44231 L
.46154 .44018 L
s
.9 g
.46154 .89766 m
.48077 .89681 L
.5 .89786 L
.51923 .90023 L
.53708 .90385 L
.51923 .9151 L
.5 .91533 L
.48077 .91382 L
.46154 .91013 L
.44755 .90385 L
F
0 g
.46154 .89766 m
.48077 .89681 L
.5 .89786 L
.51923 .90023 L
.53708 .90385 L
.51923 .9151 L
.5 .91533 L
.48077 .91382 L
.46154 .91013 L
.44755 .90385 L
.46154 .89766 L
s
.5 g
.5 .43748 m
.51923 .43903 L
.52935 .44231 L
.53846 .44673 L
.55607 .46154 L
.55769 .46302 L
.56768 .48077 L
.5722 .5 L
.5705 .51923 L
.56104 .53846 L
.55769 .54249 L
.53846 .55538 L
.53071 .55769 L
.51923 .55926 L
.50291 .55769 L
.5 .557 L
.48077 .54838 L
.46848 .53846 L
.46154 .53075 L
.45544 .51923 L
.44979 .5 L
.45037 .48077 L
.45818 .46154 L
.46154 .45669 L
.48077 .44233 L
.48081 .44231 L
F
0 g
.5 .43748 m
.51923 .43903 L
.52935 .44231 L
.53846 .44673 L
.55607 .46154 L
.55769 .46302 L
.56768 .48077 L
.5722 .5 L
.5705 .51923 L
.56104 .53846 L
.55769 .54249 L
.53846 .55538 L
.53071 .55769 L
.51923 .55926 L
.50291 .55769 L
.5 .557 L
.48077 .54838 L
.46848 .53846 L
.46154 .53075 L
.45544 .51923 L
.44979 .5 L
.45037 .48077 L
.45818 .46154 L
.46154 .45669 L
.48077 .44233 L
.48081 .44231 L
.5 .43748 L
s
.6 g
.48077 .45513 m
.5 .44847 L
.51923 .44997 L
.53846 .4595 L
.54116 .46154 L
.5561 .48077 L
.55769 .48503 L
.56106 .5 L
.55841 .51923 L
.55769 .52101 L
.54587 .53846 L
.53846 .54273 L
.51923 .54829 L
.5 .54586 L
.4852 .53846 L
.48077 .53589 L
.46711 .51923 L
.46154 .50333 L
.46094 .5 L
.46154 .48342 L
.46207 .48077 L
.47227 .46154 L
F
0 g
.48077 .45513 m
.5 .44847 L
.51923 .44997 L
.53846 .4595 L
.54116 .46154 L
.5561 .48077 L
.55769 .48503 L
.56106 .5 L
.55841 .51923 L
.55769 .52101 L
.54587 .53846 L
.53846 .54273 L
.51923 .54829 L
.5 .54586 L
.4852 .53846 L
.48077 .53589 L
.46711 .51923 L
.46154 .50333 L
.46094 .5 L
.46154 .48342 L
.46207 .48077 L
.47227 .46154 L
.48077 .45513 L
s
.7 g
.5 .46071 m
.51735 .46154 L
.51923 .46171 L
.53846 .47257 L
.54353 .48077 L
.55008 .5 L
.54596 .51923 L
.53846 .53106 L
.51923 .53723 L
.5 .53504 L
.4809 .51923 L
.48077 .51906 L
.47214 .5 L
.47437 .48077 L
.48077 .47162 L
.49683 .46154 L
F
0 g
.5 .46071 m
.51735 .46154 L
.51923 .46171 L
.53846 .47257 L
.54353 .48077 L
.55008 .5 L
.54596 .51923 L
.53846 .53106 L
.51923 .53723 L
.5 .53504 L
.4809 .51923 L
.48077 .51906 L
.47214 .5 L
.47437 .48077 L
.48077 .47162 L
.49683 .46154 L
.5 .46071 L
s
.8 g
.5 .47609 m
.51923 .47489 L
.52513 .48077 L
.53478 .5 L
.52424 .51923 L
.51923 .52225 L
.50154 .51923 L
.5 .51839 L
.48721 .5 L
.49295 .48077 L
F
0 g
.5 .47609 m
.51923 .47489 L
.52513 .48077 L
.53478 .5 L
.52424 .51923 L
.51923 .52225 L
.50154 .51923 L
.5 .51839 L
.48721 .5 L
.49295 .48077 L
.5 .47609 L
s
.1 g
.70226 .98077 m
.69231 .98022 L
.67308 .97912 L
.65385 .97842 L
.63462 .97828 L
.61538 .97857 L
.59615 .9791 L
.57692 .97966 L
.55769 .98016 L
.53846 .98052 L
.51923 .98074 L
.51263 .98077 L
F
0 g
.70226 .98077 m
.69231 .98022 L
.67308 .97912 L
.65385 .97842 L
.63462 .97828 L
.61538 .97857 L
.59615 .9791 L
.57692 .97966 L
.55769 .98016 L
.53846 .98052 L
.51923 .98074 L
.51263 .98077 L
s
.1 g
.73083 .01923 m
.73077 .01924 L
.71154 .02242 L
.69231 .0244 L
.67308 .02515 L
.65385 .02493 L
.63462 .02407 L
.61538 .0229 L
.59615 .02164 L
.57692 .02042 L
.55769 .01932 L
.55593 .01923 L
F
0 g
.73083 .01923 m
.73077 .01924 L
.71154 .02242 L
.69231 .0244 L
.67308 .02515 L
.65385 .02493 L
.63462 .02407 L
.61538 .0229 L
.59615 .02164 L
.57692 .02042 L
.55769 .01932 L
.55593 .01923 L
s
.8 g
.73077 .89808 m
.75 .89368 L
.76449 .90385 L
.75 .9126 L
.73077 .91459 L
.71697 .90385 L
F
0 g
.73077 .89808 m
.75 .89368 L
.76449 .90385 L
.75 .9126 L
.73077 .91459 L
.71697 .90385 L
.73077 .89808 L
s
.1 g
.98077 .93375 m
.97311 .94231 L
.96154 .95362 L
.95074 .96154 L
.94231 .96551 L
.92308 .96545 L
.91195 .96154 L
.90385 .95825 L
.88462 .95257 L
.86538 .95234 L
.84615 .9562 L
.82755 .96154 L
.82692 .96178 L
.80769 .96762 L
.78846 .97292 L
.76923 .97714 L
.75 .97996 L
.74056 .98077 L
.98077 .98077 L
F
0 g
.98077 .93375 m
.97311 .94231 L
.96154 .95362 L
.95074 .96154 L
.94231 .96551 L
.92308 .96545 L
.91195 .96154 L
.90385 .95825 L
.88462 .95257 L
.86538 .95234 L
.84615 .9562 L
.82755 .96154 L
.82692 .96178 L
.80769 .96762 L
.78846 .97292 L
.76923 .97714 L
.75 .97996 L
.74056 .98077 L
s
.6 g
.78846 .07554 m
.80769 .07284 L
.82692 .074 L
.83899 .07692 L
.84615 .07936 L
.86538 .09055 L
.87173 .09615 L
.88462 .1127 L
.88616 .11538 L
.89486 .13462 L
.90141 .15385 L
.90385 .16154 L
.90719 .17308 L
.91226 .19231 L
.91649 .21154 L
.92015 .23077 L
.92128 .25 L
.92308 .26721 L
.92327 .26923 L
.92539 .28846 L
.92842 .30769 L
.93244 .32692 L
.93699 .34615 L
.94152 .36538 L
.94231 .36887 L
.9469 .38462 L
.95193 .40385 L
.95591 .42308 L
.95871 .44231 L
.96044 .46154 L
.96131 .48077 L
.96109 .5 L
.96154 .50547 L
.96254 .51923 L
.9637 .53846 L
.96457 .55769 L
.96514 .57692 L
.9654 .59615 L
.96532 .61538 L
.96488 .63462 L
.96406 .65385 L
.96155 .67308 L
.96154 .68757 L
.96105 .69231 L
.9587 .71154 L
.95557 .73077 L
.95132 .75 L
.94504 .76923 L
.94231 .77506 L
.92308 .78277 L
.91141 .76923 L
.90385 .75714 L
.89956 .75 L
.88955 .73077 L
.88462 .7187 L
.88233 .71154 L
.87948 .69231 L
.88261 .67308 L
.88298 .65385 L
.88445 .63462 L
.88462 .63252 L
.88632 .61538 L
.88801 .59615 L
.88947 .57692 L
.89075 .55769 L
.89189 .53846 L
.89295 .51923 L
.89399 .5 L
.89506 .48077 L
.89622 .46154 L
.8975 .44231 L
.89891 .42308 L
.90042 .40385 L
.90196 .38462 L
.90334 .36538 L
.90385 .35622 L
.90409 .34615 L
.90385 .33226 L
.90325 .32692 L
.90058 .30769 L
.89257 .28846 L
.88462 .27915 L
.86538 .27199 L
.84615 .27237 L
.82692 .27154 L
.81825 .26923 L
.80769 .26441 L
.79088 .25 L
.78846 .24586 L
.78002 .23077 L
.77372 .21154 L
.77019 .19231 L
.76923 .18508 L
.76754 .17308 L
.76401 .15385 L
.75836 .13462 L
.75175 .11538 L
.75258 .09615 L
.76923 .08244 L
.78252 .07692 L
F
0 g
.78846 .07554 m
.80769 .07284 L
.82692 .074 L
.83899 .07692 L
.84615 .07936 L
.86538 .09055 L
.87173 .09615 L
.88462 .1127 L
.88616 .11538 L
.89486 .13462 L
.90141 .15385 L
.90385 .16154 L
.90719 .17308 L
.91226 .19231 L
.91649 .21154 L
.92015 .23077 L
.92128 .25 L
.92308 .26721 L
.92327 .26923 L
.92539 .28846 L
.92842 .30769 L
.93244 .32692 L
.93699 .34615 L
.94152 .36538 L
.94231 .36887 L
.9469 .38462 L
.95193 .40385 L
.95591 .42308 L
.95871 .44231 L
.96044 .46154 L
.96131 .48077 L
.96109 .5 L
.96154 .50547 L
.96254 .51923 L
.9637 .53846 L
.96457 .55769 L
.96514 .57692 L
.9654 .59615 L
.96532 .61538 L
.96488 .63462 L
.96406 .65385 L
.96155 .67308 L
.96154 .68757 L
.96105 .69231 L
.9587 .71154 L
.95557 .73077 L
.95132 .75 L
.94504 .76923 L
.94231 .77506 L
.92308 .78277 L
Mistroke
.91141 .76923 L
.90385 .75714 L
.89956 .75 L
.88955 .73077 L
.88462 .7187 L
.88233 .71154 L
.87948 .69231 L
.88261 .67308 L
.88298 .65385 L
.88445 .63462 L
.88462 .63252 L
.88632 .61538 L
.88801 .59615 L
.88947 .57692 L
.89075 .55769 L
.89189 .53846 L
.89295 .51923 L
.89399 .5 L
.89506 .48077 L
.89622 .46154 L
.8975 .44231 L
.89891 .42308 L
.90042 .40385 L
.90196 .38462 L
.90334 .36538 L
.90385 .35622 L
.90409 .34615 L
.90385 .33226 L
.90325 .32692 L
.90058 .30769 L
.89257 .28846 L
.88462 .27915 L
.86538 .27199 L
.84615 .27237 L
.82692 .27154 L
.81825 .26923 L
.80769 .26441 L
.79088 .25 L
.78846 .24586 L
.78002 .23077 L
.77372 .21154 L
.77019 .19231 L
.76923 .18508 L
.76754 .17308 L
.76401 .15385 L
.75836 .13462 L
.75175 .11538 L
.75258 .09615 L
.76923 .08244 L
.78252 .07692 L
Mistroke
.78846 .07554 L
Mfstroke
.7 g
.80769 .09376 m
.82692 .09469 L
.8317 .09615 L
.84615 .10321 L
.85933 .11538 L
.86538 .12652 L
.86943 .13462 L
.87684 .15385 L
.88236 .17308 L
.88462 .1834 L
.88613 .19231 L
.88667 .21154 L
.88462 .22059 L
.87835 .23077 L
.86538 .2395 L
.84615 .24627 L
.82692 .24663 L
.80769 .23618 L
.80203 .23077 L
.79178 .21154 L
.78846 .19337 L
.7883 .19231 L
.78589 .17308 L
.78391 .15385 L
.78149 .13462 L
.78125 .11538 L
.78846 .10283 L
.79929 .09615 L
F
0 g
.80769 .09376 m
.82692 .09469 L
.8317 .09615 L
.84615 .10321 L
.85933 .11538 L
.86538 .12652 L
.86943 .13462 L
.87684 .15385 L
.88236 .17308 L
.88462 .1834 L
.88613 .19231 L
.88667 .21154 L
.88462 .22059 L
.87835 .23077 L
.86538 .2395 L
.84615 .24627 L
.82692 .24663 L
.80769 .23618 L
.80203 .23077 L
.79178 .21154 L
.78846 .19337 L
.7883 .19231 L
.78589 .17308 L
.78391 .15385 L
.78149 .13462 L
.78125 .11538 L
.78846 .10283 L
.79929 .09615 L
.80769 .09376 L
s
.8 g
.82692 .14275 m
.83933 .15385 L
.84615 .16843 L
.84731 .17308 L
.84756 .19231 L
.84615 .19642 L
.82692 .20558 L
.81697 .19231 L
.81417 .17308 L
.81703 .15385 L
F
0 g
.82692 .14275 m
.83933 .15385 L
.84615 .16843 L
.84731 .17308 L
.84756 .19231 L
.84615 .19642 L
.82692 .20558 L
.81697 .19231 L
.81417 .17308 L
.81703 .15385 L
.82692 .14275 L
s
.89112 .98077 m
.88462 .97882 L
.86538 .97563 L
.84615 .97772 L
.82882 .98077 L
F
.89112 .98077 m
.88462 .97882 L
.86538 .97563 L
.84615 .97772 L
.82882 .98077 L
s
.2 g
.88462 .82593 m
.88502 .82692 L
.89021 .84615 L
.88462 .85968 L
.86538 .85573 L
.86244 .84615 L
.86538 .83308 L
.86989 .82692 L
F
0 g
.88462 .82593 m
.88502 .82692 L
.89021 .84615 L
.88462 .85968 L
.86538 .85573 L
.86244 .84615 L
.86538 .83308 L
.86989 .82692 L
.88462 .82593 L
s
.7 g
.92308 .37257 m
.93225 .38462 L
.93924 .40385 L
.94231 .41496 L
.94539 .42308 L
.95152 .44231 L
.95598 .46154 L
.95898 .48077 L
.95534 .5 L
.95702 .51923 L
.95834 .53846 L
.95931 .55769 L
.95993 .57692 L
.96018 .59615 L
.96004 .61538 L
.95949 .63462 L
.95846 .65385 L
.96099 .67308 L
.95465 .69231 L
.95155 .71154 L
.94712 .73077 L
.94231 .74492 L
.93934 .75 L
.92308 .75701 L
.91612 .75 L
.90478 .73077 L
.90385 .72876 L
.89987 .71154 L
.89414 .69231 L
.89168 .67308 L
.89125 .65385 L
.8918 .63462 L
.89277 .61538 L
.8939 .59615 L
.89506 .57692 L
.89621 .55769 L
.89737 .53846 L
.89857 .51923 L
.89989 .5 L
.90142 .48077 L
.90327 .46154 L
.90385 .45638 L
.90541 .44231 L
.90795 .42308 L
.9112 .40385 L
.91595 .38462 L
F
0 g
.92308 .37257 m
.93225 .38462 L
.93924 .40385 L
.94231 .41496 L
.94539 .42308 L
.95152 .44231 L
.95598 .46154 L
.95898 .48077 L
.95534 .5 L
.95702 .51923 L
.95834 .53846 L
.95931 .55769 L
.95993 .57692 L
.96018 .59615 L
.96004 .61538 L
.95949 .63462 L
.95846 .65385 L
.96099 .67308 L
.95465 .69231 L
.95155 .71154 L
.94712 .73077 L
.94231 .74492 L
.93934 .75 L
.92308 .75701 L
.91612 .75 L
.90478 .73077 L
.90385 .72876 L
.89987 .71154 L
.89414 .69231 L
.89168 .67308 L
.89125 .65385 L
.8918 .63462 L
.89277 .61538 L
.8939 .59615 L
.89506 .57692 L
.89621 .55769 L
.89737 .53846 L
.89857 .51923 L
.89989 .5 L
.90142 .48077 L
.90327 .46154 L
.90385 .45638 L
.90541 .44231 L
.90795 .42308 L
.9112 .40385 L
.91595 .38462 L
.92308 .37257 L
s
.1 g
.98077 .38427 m
.97911 .36538 L
.97787 .34615 L
.97699 .32692 L
.97639 .30769 L
.97597 .28846 L
.97565 .26923 L
.97528 .25 L
.97474 .23077 L
.9739 .21154 L
.97278 .19231 L
.97154 .17308 L
.97051 .15385 L
.96985 .13462 L
.96898 .11538 L
.96631 .09615 L
.96154 .08053 L
.95975 .07692 L
.94777 .05769 L
.94231 .05118 L
.92857 .03846 L
.92308 .03433 L
.90385 .02319 L
.89463 .01923 L
.98077 .01923 L
F
0 g
.98077 .38427 m
.97911 .36538 L
.97787 .34615 L
.97699 .32692 L
.97639 .30769 L
.97597 .28846 L
.97565 .26923 L
.97528 .25 L
.97474 .23077 L
.9739 .21154 L
.97278 .19231 L
.97154 .17308 L
.97051 .15385 L
.96985 .13462 L
.96898 .11538 L
.96631 .09615 L
.96154 .08053 L
.95975 .07692 L
.94777 .05769 L
.94231 .05118 L
.92857 .03846 L
.92308 .03433 L
.90385 .02319 L
.89463 .01923 L
s
.8 g
.92308 .42121 m
.92894 .42308 L
.93826 .44231 L
.94231 .45709 L
.94413 .46154 L
.95069 .48077 L
.94916 .5 L
.9512 .51923 L
.95276 .53846 L
.95388 .55769 L
.95458 .57692 L
.95483 .59615 L
.95462 .61538 L
.9539 .63462 L
.95259 .65385 L
.95656 .67308 L
.94753 .69231 L
.94296 .71154 L
.94231 .71363 L
.93052 .73077 L
.92308 .73121 L
.92249 .73077 L
.90987 .71154 L
.90385 .69288 L
.90373 .69231 L
.90049 .67308 L
.89898 .65385 L
.89868 .63462 L
.89909 .61538 L
.89989 .59615 L
.90091 .57692 L
.90208 .55769 L
.9034 .53846 L
.90385 .53255 L
.90486 .51923 L
.90654 .5 L
.90862 .48077 L
.91129 .46154 L
.91502 .44231 L
.92176 .42308 L
F
0 g
.92308 .42121 m
.92894 .42308 L
.93826 .44231 L
.94231 .45709 L
.94413 .46154 L
.95069 .48077 L
.94916 .5 L
.9512 .51923 L
.95276 .53846 L
.95388 .55769 L
.95458 .57692 L
.95483 .59615 L
.95462 .61538 L
.9539 .63462 L
.95259 .65385 L
.95656 .67308 L
.94753 .69231 L
.94296 .71154 L
.94231 .71363 L
.93052 .73077 L
.92308 .73121 L
.92249 .73077 L
.90987 .71154 L
.90385 .69288 L
.90373 .69231 L
.90049 .67308 L
.89898 .65385 L
.89868 .63462 L
.89909 .61538 L
.89989 .59615 L
.90091 .57692 L
.90208 .55769 L
.9034 .53846 L
.90385 .53255 L
.90486 .51923 L
.90654 .5 L
.90862 .48077 L
.91129 .46154 L
.91502 .44231 L
.92176 .42308 L
.92308 .42121 L
s
.9 g
.92308 .46549 m
.93689 .48077 L
.94162 .5 L
.94231 .50359 L
.94451 .51923 L
.94653 .53846 L
.94792 .55769 L
.94875 .57692 L
.94903 .59615 L
.94872 .61538 L
.94775 .63462 L
.94596 .65385 L
.94386 .67308 L
.94231 .67674 L
.93716 .69231 L
.92308 .70306 L
.91602 .69231 L
.91015 .67308 L
.90736 .65385 L
.90623 .63462 L
.90607 .61538 L
.90653 .59615 L
.90738 .57692 L
.90854 .55769 L
.91001 .53846 L
.91188 .51923 L
.91436 .5 L
.91797 .48077 L
F
0 g
.92308 .46549 m
.93689 .48077 L
.94162 .5 L
.94231 .50359 L
.94451 .51923 L
.94653 .53846 L
.94792 .55769 L
.94875 .57692 L
.94903 .59615 L
.94872 .61538 L
.94775 .63462 L
.94596 .65385 L
.94386 .67308 L
.94231 .67674 L
.93716 .69231 L
.92308 .70306 L
.91602 .69231 L
.91015 .67308 L
.90736 .65385 L
.90623 .63462 L
.90607 .61538 L
.90653 .59615 L
.90738 .57692 L
.90854 .55769 L
.91001 .53846 L
.91188 .51923 L
.91436 .5 L
.91797 .48077 L
.92308 .46549 L
s
1 g
.92308 .51688 m
.93242 .51923 L
.93756 .53846 L
.94018 .55769 L
.94157 .57692 L
.94199 .59615 L
.94141 .61538 L
.9396 .63462 L
.93569 .65385 L
.92308 .6671 L
.91819 .65385 L
.91522 .63462 L
.91419 .61538 L
.91424 .59615 L
.91502 .57692 L
.91646 .55769 L
.91868 .53846 L
.9224 .51923 L
F
0 g
.92308 .51688 m
.93242 .51923 L
.93756 .53846 L
.94018 .55769 L
.94157 .57692 L
.94199 .59615 L
.94141 .61538 L
.9396 .63462 L
.93569 .65385 L
.92308 .6671 L
.91819 .65385 L
.91522 .63462 L
.91419 .61538 L
.91424 .59615 L
.91502 .57692 L
.91646 .55769 L
.91868 .53846 L
.9224 .51923 L
.92308 .51688 L
s
.98077 .04384 m
.976 .03846 L
.96154 .024 L
.95634 .01923 L
.98077 .01923 L
F
.98077 .04384 m
.976 .03846 L
.96154 .024 L
.95634 .01923 L
s
.98077 .97231 m
.97424 .98077 L
.98077 .98077 L
F
.98077 .97231 m
.97424 .98077 L
s
.1 g
.98077 .85222 m
.97992 .84615 L
.9794 .82692 L
.98075 .80769 L
.98077 .80744 L
F
0 g
.98077 .85222 m
.97992 .84615 L
.9794 .82692 L
.98075 .80769 L
.98077 .80744 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.389 .731 .991 r
.39882 .60344 .40501 .60696 .41518 .6063 .40899 .6037 Mtetra
0 .519 .834 r
.40899 .6037 .41518 .6063 .42536 .60743 .41915 .6062 Mtetra
.487 0 0 r
.41915 .6062 .42536 .60743 .43555 .61056 .42932 .61116 Mtetra
.646 .115 0 r
.42932 .61116 .43555 .61056 .44579 .6149 .43954 .61755 Mtetra
.631 .137 .06 r
.43954 .61755 .44579 .6149 .45613 .6185 .44987 .623 Mtetra
.498 .013 .035 r
.44987 .623 .45613 .6185 .4666 .61903 .46037 .62481 Mtetra
.222 0 0 r
.46037 .62481 .4666 .61903 .4772 .61532 .47102 .6217 Mtetra
0 0 0 r
.47102 .6217 .4772 .61532 .48786 .60813 .48176 .61473 Mtetra
.48176 .61473 .48786 .60813 .49856 .59966 .49252 .60655 Mtetra
.49252 .60655 .49856 .59966 .50926 .59205 .50329 .59966 Mtetra
.234 0 0 r
.50329 .59966 .50926 .59205 .51997 .58639 .51407 .59523 Mtetra
.406 0 .15 r
.51407 .59523 .51997 .58639 .53071 .58263 .52489 .59314 Mtetra
.49 .108 .243 r
.52489 .59314 .53071 .58263 .54149 .58016 .53576 .59264 Mtetra
.526 .167 .301 r
.53576 .59264 .54149 .58016 .55233 .57839 .54669 .59299 Mtetra
.542 .201 .34 r
.54669 .59299 .55233 .57839 .56322 .57689 .5577 .59371 Mtetra
.549 .223 .368 r
.5577 .59371 .56322 .57689 .57417 .57546 .56877 .59451 Mtetra
.552 .238 .389 r
.56877 .59451 .57417 .57546 .58517 .574 .57992 .59526 Mtetra
.553 .248 .406 r
.57992 .59526 .58517 .574 .59623 .57245 .59113 .59584 Mtetra
.552 .256 .418 r
.59113 .59584 .59623 .57245 .60734 .57076 .60241 .59617 Mtetra
.55 .261 .428 r
.60241 .59617 .60734 .57076 .61849 .56891 .61375 .59616 Mtetra
.548 .264 .436 r
.61375 .59616 .61849 .56891 .6297 .56684 .62514 .59575 Mtetra
.545 .265 .442 r
.62514 .59575 .6297 .56684 .64095 .56454 .63659 .59486 Mtetra
.541 .265 .446 r
.63659 .59486 .64095 .56454 .65224 .56197 .64807 .59345 Mtetra
.537 .264 .449 r
.64807 .59345 .65224 .56197 .66357 .55913 .6596 .59145 Mtetra
.532 .262 .451 r
.6596 .59145 .66357 .55913 .67494 .55599 .67115 .58885 Mtetra
.527 .258 .451 r
.67115 .58885 .67494 .55599 .68635 .55257 .68273 .58564 Mtetra
.522 .254 .451 r
.68273 .58564 .68635 .55257 .69778 .54885 .69433 .58182 Mtetra
.516 .249 .449 r
.69433 .58182 .69778 .54885 .70925 .54488 .70595 .57743 Mtetra
.51 .244 .446 r
.70595 .57743 .70925 .54488 .72074 .5407 .71757 .57254 Mtetra
.505 .238 .443 r
.71757 .57254 .72074 .5407 .73228 .53644 .72922 .5673 Mtetra
.502 .233 .439 r
.72922 .5673 .73228 .53644 .74386 .53228 .7409 .56198 Mtetra
.503 .231 .435 r
.7409 .56198 .74386 .53228 .75551 .52851 .75263 .55697 Mtetra
.508 .232 .431 r
.75263 .55697 .75551 .52851 .76726 .52538 .76445 .5527 Mtetra
.517 .236 .427 r
.76445 .5527 .76726 .52538 .77911 .523 .7764 .54945 Mtetra
.524 .239 .424 r
.7764 .54945 .77911 .523 .79106 .52105 .78846 .547 Mtetra
.523 .236 .421 r
.78846 .547 .79106 .52105 .80304 .51884 .80058 .54451 Mtetra
.506 .222 .416 r
.80058 .54451 .80304 .51884 .81498 .51545 .81263 .54067 Mtetra
.473 .193 .407 r
.81263 .54067 .81498 .51545 .82681 .51022 .82452 .53433 Mtetra
.428 .152 .391 r
.82452 .53433 .82681 .51022 .8385 .50316 .83618 .52518 Mtetra
.376 .102 .364 r
.83618 .52518 .8385 .50316 .85011 .49493 .84764 .51393 Mtetra
.325 .045 .325 r
.84764 .51393 .85011 .49493 .86171 .48649 .85903 .50197 Mtetra
.278 0 .267 r
.85903 .50197 .86171 .48649 .87338 .47867 .87047 .49067 Mtetra
.24 0 .188 r
.87047 .49067 .87338 .47867 .88522 .47207 .88209 .48107 Mtetra
.243 0 .099 r
.88209 .48107 .88522 .47207 .8973 .46743 .89403 .47425 Mtetra
.342 0 .041 r
.89403 .47425 .8973 .46743 .90979 .46583 .90648 .47157 Mtetra
.479 .001 .042 r
.90648 .47157 .90979 .46583 .92273 .46745 .9195 .47312 Mtetra
.49 .01 .041 r
.9195 .47312 .92273 .46745 .9358 .4693 .93266 .47505 Mtetra
.24 0 0 r
.93266 .47505 .9358 .4693 .94835 .4664 .94518 .47116 Mtetra
0 0 0 r
.94518 .47116 .94835 .4664 .96013 .45725 .95675 .45971 Mtetra
.717 .929 .598 r
.95675 .45971 .96013 .45725 .97161 .44577 .96797 .44562 Mtetra
.209 .653 .949 r
.39256 .60029 .39882 .60344 .40899 .6037 .40272 .60168 Mtetra
.336 0 0 r
.40272 .60168 .40899 .6037 .41915 .6062 .41285 .60586 Mtetra
.662 .122 0 r
.41285 .60586 .41915 .6062 .42932 .61116 .42298 .61302 Mtetra
.726 .257 .134 r
.42298 .61302 .42932 .61116 .43954 .61755 .43316 .62187 Mtetra
.693 .254 .205 r
.43316 .62187 .43954 .61755 .44987 .623 .44349 .62954 Mtetra
.581 .15 .188 r
.44349 .62954 .44987 .623 .46037 .62481 .45401 .63291 Mtetra
.373 0 .098 r
.45401 .63291 .46037 .62481 .47102 .6217 .46471 .63063 Mtetra
.149 0 0 r
.46471 .63063 .47102 .6217 .48176 .61473 .47552 .62413 Mtetra
.106 0 0 r
.47552 .62413 .48176 .61473 .49252 .60655 .48636 .61657 Mtetra
.254 0 .094 r
.48636 .61657 .49252 .60655 .50329 .59966 .49721 .61083 Mtetra
.423 .047 .219 r
.49721 .61083 .50329 .59966 .51407 .59523 .50806 .60817 Mtetra
.523 .166 .304 r
.50806 .60817 .51407 .59523 .52489 .59314 .51896 .60834 Mtetra
.568 .23 .356 r
.51896 .60834 .52489 .59314 .53576 .59264 .52992 .61045 Mtetra
.585 .263 .389 r
.52992 .61045 .53576 .59264 .54669 .59299 .54097 .61359 Mtetra
.59 .28 .412 r
.54097 .61359 .54669 .59299 .5577 .59371 .55211 .6172 Mtetra
.59 .291 .429 r
.55211 .6172 .5577 .59371 .56877 .59451 .56333 .62091 Mtetra
.588 .297 .442 r
.56333 .62091 .56877 .59451 .57992 .59526 .57465 .62453 Mtetra
.585 .301 .452 r
.57465 .62453 .57992 .59526 .59113 .59584 .58605 .62788 Mtetra
.581 .303 .46 r
.58605 .62788 .59113 .59584 .60241 .59617 .59753 .63083 Mtetra
.576 .303 .466 r
.59753 .63083 .60241 .59617 .61375 .59616 .60909 .63324 Mtetra
.571 .303 .47 r
.60909 .63324 .61375 .59616 .62514 .59575 .62072 .63498 Mtetra
.565 .301 .474 r
.62072 .63498 .62514 .59575 .63659 .59486 .6324 .63595 Mtetra
.56 .298 .476 r
.6324 .63595 .63659 .59486 .64807 .59345 .64413 .63605 Mtetra
.554 .295 .478 r
.64413 .63605 .64807 .59345 .6596 .59145 .65589 .6352 Mtetra
.547 .291 .479 r
.65589 .6352 .6596 .59145 .67115 .58885 .66769 .63336 Mtetra
.541 .287 .479 r
.66769 .63336 .67115 .58885 .68273 .58564 .67949 .63052 Mtetra
.534 .282 .478 r
.67949 .63052 .68273 .58564 .69433 .58182 .6913 .62668 Mtetra
.528 .276 .477 r
.6913 .62668 .69433 .58182 .70595 .57743 .70311 .62187 Mtetra
.521 .27 .475 r
.70311 .62187 .70595 .57743 .71757 .57254 .71491 .61621 Mtetra
.516 .265 .473 r
.71491 .61621 .71757 .57254 .72922 .5673 .7267 .60988 Mtetra
.512 .26 .47 r
.7267 .60988 .72922 .5673 .7409 .56198 .73851 .6032 Mtetra
.511 .258 .467 r
.73851 .6032 .7409 .56198 .75263 .55697 .75035 .5967 Mtetra
.515 .259 .465 r
.75035 .5967 .75263 .55697 .76445 .5527 .76228 .591 Mtetra
.524 .264 .463 r
.76228 .591 .76445 .5527 .7764 .54945 .77434 .58664 Mtetra
.533 .27 .461 r
.77434 .58664 .7764 .54945 .78846 .547 .78655 .58358 Mtetra
.536 .27 .46 r
.78655 .58358 .78846 .547 .80058 .54451 .79885 .58091 Mtetra
.524 .261 .458 r
.79885 .58091 .80058 .54451 .81263 .54067 .81109 .57689 Mtetra
.497 .239 .453 r
.81109 .57689 .81263 .54067 .82452 .53433 .8231 .56971 Mtetra
.456 .205 .443 r
.8231 .56971 .82452 .53433 .83618 .52518 .83477 .55846 Mtetra
.41 .165 .428 r
.83477 .55846 .83618 .52518 .84764 .51393 .8461 .54374 Mtetra
.366 .122 .406 r
.8461 .54374 .84764 .51393 .85903 .50197 .85724 .52736 Mtetra
.332 .081 .375 r
.85724 .52736 .85903 .50197 .87047 .49067 .86837 .5114 Mtetra
.314 .045 .337 r
.86837 .5114 .87047 .49067 .88209 .48107 .8797 .49761 Mtetra
.333 .032 .296 r
.8797 .49761 .88209 .48107 .89403 .47425 .89143 .48763 Mtetra
.42 .074 .269 r
.89143 .48763 .89403 .47425 .90648 .47157 .90379 .48319 Mtetra
.528 .147 .262 r
.90379 .48319 .90648 .47157 .9195 .47312 .91687 .48427 Mtetra
.537 .149 .253 r
.91687 .48427 .9195 .47312 .93266 .47505 .9301 .48595 Mtetra
.354 0 .195 r
.9301 .48595 .93266 .47505 .94518 .47116 .94254 .48053 Mtetra
0 0 .017 r
.94254 .48053 .94518 .47116 .95675 .45971 .95383 .46605 Mtetra
0 0 0 r
.95383 .46605 .95675 .45971 .96797 .44562 .96471 .44861 Mtetra
.008 .526 .858 r
.38625 .59724 .39256 .60029 .40272 .60168 .39638 .5999 Mtetra
.541 0 0 r
.39638 .5999 .40272 .60168 .41285 .60586 .40647 .60592 Mtetra
.744 .25 .061 r
.40647 .60592 .41285 .60586 .42298 .61302 .41655 .61549 Mtetra
.769 .334 .219 r
.41655 .61549 .42298 .61302 .43316 .62187 .42668 .62697 Mtetra
.728 .316 .267 r
.42668 .62697 .43316 .62187 .44349 .62954 .43699 .63694 Mtetra
.621 .211 .244 r
.43699 .63694 .44349 .62954 .45401 .63291 .44753 .64181 Mtetra
.419 .009 .151 r
.44753 .64181 .45401 .63291 .46471 .63063 .45829 .64018 Mtetra
.192 0 .035 r
.45829 .64018 .46471 .63063 .47552 .62413 .46918 .63391 Mtetra
.148 0 .019 r
.46918 .63391 .47552 .62413 .48636 .61657 .4801 .62674 Mtetra
.303 0 .121 r
.4801 .62674 .48636 .61657 .49721 .61083 .49102 .62192 Mtetra
.47 .092 .238 r
.49102 .62192 .49721 .61083 .50806 .60817 .50194 .62078 Mtetra
.563 .203 .315 r
.50194 .62078 .50806 .60817 .51896 .60834 .51291 .62294 Mtetra
.603 .26 .361 r
.51291 .62294 .51896 .60834 .52992 .61045 .52396 .6273 Mtetra
.617 .287 .389 r
.52396 .6273 .52992 .61045 .54097 .61359 .53511 .63282 Mtetra
.618 .3 .409 r
.53511 .63282 .54097 .61359 .55211 .6172 .54636 .6388 Mtetra
.615 .306 .423 r
.54636 .6388 .55211 .6172 .56333 .62091 .55772 .64483 Mtetra
.61 .308 .433 r
.55772 .64483 .56333 .62091 .57465 .62453 .56918 .65064 Mtetra
.604 .308 .441 r
.56918 .65064 .57465 .62453 .58605 .62788 .58074 .65603 Mtetra
.596 .306 .447 r
.58074 .65603 .58605 .62788 .59753 .63083 .59239 .66081 Mtetra
.588 .303 .451 r
.59239 .66081 .59753 .63083 .60909 .63324 .60413 .6648 Mtetra
.58 .299 .454 r
.60413 .6648 .60909 .63324 .62072 .63498 .61594 .66786 Mtetra
.571 .293 .455 r
.61594 .66786 .62072 .63498 .6324 .63595 .62781 .66985 Mtetra
.561 .286 .456 r
.62781 .66985 .6324 .63595 .64413 .63605 .63973 .67067 Mtetra
.551 .278 .456 r
.63973 .67067 .64413 .63605 .65589 .6352 .65168 .67025 Mtetra
.54 .27 .454 r
.65168 .67025 .65589 .6352 .66769 .63336 .66365 .66855 Mtetra
.529 .26 .452 r
.66365 .66855 .66769 .63336 .67949 .63052 .67562 .66556 Mtetra
.517 .25 .449 r
.67562 .66556 .67949 .63052 .6913 .62668 .68759 .66131 Mtetra
.505 .239 .445 r
.68759 .66131 .6913 .62668 .70311 .62187 .69955 .65587 Mtetra
.493 .228 .44 r
.69955 .65587 .70311 .62187 .71491 .61621 .71149 .64935 Mtetra
.482 .217 .435 r
.71149 .64935 .71491 .61621 .7267 .60988 .7234 .64198 Mtetra
.474 .208 .43 r
.7234 .64198 .7267 .60988 .73851 .6032 .73531 .63414 Mtetra
.472 .204 .425 r
.73531 .63414 .73851 .6032 .75035 .5967 .74726 .62643 Mtetra
.48 .207 .422 r
.74726 .62643 .75035 .5967 .76228 .591 .75929 .61971 Mtetra
.497 .219 .422 r
.75929 .61971 .76228 .591 .77434 .58664 .77147 .61475 Mtetra
.518 .235 .424 r
.77147 .61475 .77434 .58664 .78655 .58358 .78386 .61183 Mtetra
.531 .246 .427 r
.78386 .61183 .78655 .58358 .79885 .58091 .79639 .61007 Mtetra
.523 .241 .429 r
.79639 .61007 .79885 .58091 .81109 .57689 .80891 .60735 Mtetra
.488 .216 .428 r
.80891 .60735 .81109 .57689 .8231 .56971 .82118 .60102 Mtetra
.431 .173 .42 r
.82118 .60102 .8231 .56971 .83477 .55846 .833 .58927 Mtetra
.361 .117 .404 r
.833 .58927 .83477 .55846 .8461 .54374 .84431 .57223 Mtetra
.292 .058 .377 r
.84431 .57223 .8461 .54374 .85724 .52736 .85526 .55198 Mtetra
.234 .001 .341 r
.85526 .55198 .85724 .52736 .86837 .5114 .8661 .53144 Mtetra
.201 0 .294 r
.8661 .53144 .86837 .5114 .8797 .49761 .87713 .51335 Mtetra
.228 0 .249 r
.87713 .51335 .8797 .49761 .89143 .48763 .88864 .50014 Mtetra
.362 .012 .23 r
.88864 .50014 .89143 .48763 .90379 .48319 .90095 .49413 Mtetra
.521 .13 .24 r
.90095 .49413 .90379 .48319 .91687 .48427 .91412 .49518 Mtetra
.538 .144 .242 r
.91412 .49518 .91687 .48427 .9301 .48595 .92749 .49704 Mtetra
.313 0 .182 r
.92749 .49704 .9301 .48595 .94254 .48053 .93988 .49028 Mtetra
0 0 0 r
.93988 .49028 .94254 .48053 .95383 .46605 .95089 .47267 Mtetra
.95089 .47267 .95383 .46605 .96471 .44861 .96141 .45173 Mtetra
0 .353 .703 r
.37987 .59439 .38625 .59724 .39638 .5999 .38997 .59838 Mtetra
.672 .124 0 r
.38997 .59838 .39638 .5999 .40647 .60592 .40001 .60637 Mtetra
.79 .333 .158 r
.40001 .60637 .40647 .60592 .41655 .61549 .41002 .61844 Mtetra
.795 .385 .273 r
.41002 .61844 .41655 .61549 .42668 .62697 .4201 .63257 Mtetra
.752 .356 .303 r
.4201 .63257 .42668 .62697 .43699 .63694 .43039 .6447 Mtetra
.644 .242 .267 r
.43039 .6447 .43699 .63694 .44753 .64181 .44096 .6507 Mtetra
.42 .007 .146 r
.44096 .6507 .44753 .64181 .45829 .64018 .45178 .64917 Mtetra
.126 0 0 r
.45178 .64917 .45829 .64018 .46918 .63391 .46276 .64245 Mtetra
.039 0 0 r
.46276 .64245 .46918 .63391 .4801 .62674 .47376 .63492 Mtetra
.226 0 .002 r
.47376 .63492 .4801 .62674 .49102 .62192 .48475 .63018 Mtetra
.45 .028 .145 r
.48475 .63018 .49102 .62192 .50194 .62078 .49574 .62962 Mtetra
.572 .169 .238 r
.49574 .62962 .50194 .62078 .51291 .62294 .50678 .63265 Mtetra
.623 .236 .289 r
.50678 .63265 .51291 .62294 .52396 .6273 .51789 .63797 Mtetra
.64 .264 .316 r
.51789 .63797 .52396 .6273 .53511 .63282 .52911 .64437 Mtetra
.641 .273 .33 r
.52911 .64437 .53511 .63282 .54636 .6388 .54043 .65106 Mtetra
.636 .272 .337 r
.54043 .65106 .54636 .6388 .55772 .64483 .55186 .65755 Mtetra
.627 .266 .337 r
.55186 .65755 .55772 .64483 .56918 .65064 .56341 .66356 Mtetra
.615 .253 .333 r
.56341 .66356 .56918 .65064 .58074 .65603 .57504 .66885 Mtetra
.6 .236 .323 r
.57504 .66885 .58074 .65603 .59239 .66081 .58677 .67324 Mtetra
.58 .211 .306 r
.58677 .67324 .59239 .66081 .60413 .6648 .59858 .67657 Mtetra
.554 .177 .28 r
.59858 .67657 .60413 .6648 .61594 .66786 .61045 .67871 Mtetra
.519 .13 .243 r
.61045 .67871 .61594 .66786 .62781 .66985 .62237 .67956 Mtetra
.47 .064 .188 r
.62237 .67956 .62781 .66985 .63973 .67067 .63433 .67907 Mtetra
.398 0 .108 r
.63433 .67907 .63973 .67067 .65168 .67025 .64631 .67723 Mtetra
.289 0 0 r
.64631 .67723 .65168 .67025 .66365 .66855 .6583 .67404 Mtetra
.12 0 0 r
.6583 .67404 .66365 .66855 .67562 .66556 .67029 .66957 Mtetra
0 0 0 r
.67029 .66957 .67562 .66556 .68759 .66131 .68227 .66388 Mtetra
.404 .831 .674 r
.68227 .66388 .68759 .66131 .69955 .65587 .69423 .6571 Mtetra
.624 .959 .833 r
.69423 .6571 .69955 .65587 .71149 .64935 .70617 .64938 Mtetra
.743 .987 .896 r
.70617 .64938 .71149 .64935 .7234 .64198 .7181 .64095 Mtetra
.79 .971 .914 r
.7181 .64095 .7234 .64198 .73531 .63414 .73002 .63221 Mtetra
.792 .946 .924 r
.73002 .63221 .73531 .63414 .74726 .62643 .74198 .62385 Mtetra
.754 .921 .946 r
.74198 .62385 .74726 .62643 .75929 .61971 .75405 .61682 Mtetra
.656 .89 .982 r
.75405 .61682 .75929 .61971 .77147 .61475 .76631 .61221 Mtetra
.441 .817 .992 r
.76631 .61221 .77147 .61475 .78386 .61183 .77884 .6106 Mtetra
.076 .625 .831 r
.77884 .6106 .78386 .61183 .79639 .61007 .79163 .61134 Mtetra
.21 0 0 r
.79163 .61134 .79639 .61007 .80891 .60735 .8045 .6121 Mtetra
.218 0 0 r
.8045 .6121 .80891 .60735 .82118 .60102 .81716 .60936 Mtetra
.058 0 0 r
.81716 .60936 .82118 .60102 .833 .58927 .82931 .60012 Mtetra
0 0 0 r
.82931 .60012 .833 .58927 .84431 .57223 .84079 .58355 Mtetra
.84079 .58355 .84431 .57223 .85526 .55198 .85171 .56165 Mtetra
.85171 .56165 .85526 .55198 .8661 .53144 .86239 .53812 Mtetra
.674 .809 .36 r
.86239 .53812 .8661 .53144 .87713 .51335 .8732 .51685 Mtetra
.725 .92 .569 r
.8732 .51685 .87713 .51335 .88864 .50014 .88457 .50144 Mtetra
.428 .858 .735 r
.88457 .50144 .88864 .50014 .90095 .49413 .8969 .49501 Mtetra
.287 0 0 r
.8969 .49501 .90095 .49413 .91412 .49518 .91029 .49736 Mtetra
.43 0 0 r
.91029 .49736 .91412 .49518 .92749 .49704 .92392 .50075 Mtetra
0 0 0 r
.92392 .50075 .92749 .49704 .93988 .49028 .93636 .49373 Mtetra
.818 .917 .523 r
.93636 .49373 .93988 .49028 .95089 .47267 .94718 .47376 Mtetra
.956 .933 .601 r
.94718 .47376 .95089 .47267 .96141 .45173 .95742 .45 Mtetra
.421 0 0 r
.37342 .59176 .37987 .59439 .38997 .59838 .38349 .59716 Mtetra
.748 .239 0 r
.38349 .59716 .38997 .59838 .40001 .60637 .39346 .60717 Mtetra
.817 .388 .224 r
.39346 .60717 .40001 .60637 .41002 .61844 .4034 .62178 Mtetra
.813 .42 .309 r
.4034 .62178 .41002 .61844 .4201 .63257 .41342 .63847 Mtetra
.768 .383 .324 r
.41342 .63847 .4201 .63257 .43039 .6447 .42369 .65244 Mtetra
.655 .253 .272 r
.42369 .65244 .43039 .6447 .44096 .6507 .43429 .65905 Mtetra
.375 0 .095 r
.43429 .65905 .44096 .6507 .45178 .64917 .4452 .65689 Mtetra
0 0 0 r
.4452 .65689 .45178 .64917 .46276 .64245 .45628 .64887 Mtetra
.45628 .64887 .46276 .64245 .47376 .63492 .46738 .64004 Mtetra
.46738 .64004 .47376 .63492 .48475 .63018 .47845 .63438 Mtetra
.276 0 0 r
.47845 .63438 .48475 .63018 .49574 .62962 .4895 .63324 Mtetra
.501 0 0 r
.4895 .63324 .49574 .62962 .50678 .63265 .50059 .63585 Mtetra
.589 .084 .021 r
.50059 .63585 .50678 .63265 .51789 .63797 .51174 .64064 Mtetra
.612 .101 .011 r
.51174 .64064 .51789 .63797 .52911 .64437 .523 .64627 Mtetra
.596 .064 0 r
.523 .64627 .52911 .64437 .54043 .65106 .53436 .65185 Mtetra
.536 0 0 r
.53436 .65185 .54043 .65106 .55186 .65755 .54582 .65687 Mtetra
.386 0 0 r
.54582 .65687 .55186 .65755 .56341 .66356 .55738 .66103 Mtetra
0 .484 .799 r
.55738 .66103 .56341 .66356 .57504 .66885 .56902 .66413 Mtetra
.297 .648 .969 r
.56902 .66413 .57504 .66885 .58677 .67324 .58073 .66602 Mtetra
.498 .656 .931 r
.58073 .66602 .58677 .67324 .59858 .67657 .5925 .66659 Mtetra
.583 .623 .858 r
.5925 .66659 .59858 .67657 .61045 .67871 .60432 .66579 Mtetra
.62 .591 .8 r
.60432 .66579 .61045 .67871 .62237 .67956 .61616 .66361 Mtetra
.638 .567 .758 r
.61616 .66361 .62237 .67956 .63433 .67907 .62803 .66008 Mtetra
.647 .548 .729 r
.62803 .66008 .63433 .67907 .64631 .67723 .6399 .65527 Mtetra
.652 .534 .707 r
.6399 .65527 .64631 .67723 .6583 .67404 .65177 .64929 Mtetra
.655 .524 .692 r
.65177 .64929 .6583 .67404 .67029 .66957 .66363 .64227 Mtetra
.656 .515 .68 r
.66363 .64227 .67029 .66957 .68227 .66388 .67548 .63435 Mtetra
.656 .509 .671 r
.67548 .63435 .68227 .66388 .69423 .6571 .68731 .62571 Mtetra
.656 .504 .665 r
.68731 .62571 .69423 .6571 .70617 .64938 .69913 .61652 Mtetra
.655 .499 .661 r
.69913 .61652 .70617 .64938 .7181 .64095 .71095 .60703 Mtetra
.652 .495 .658 r
.71095 .60703 .7181 .64095 .73002 .63221 .72278 .59764 Mtetra
.645 .489 .657 r
.72278 .59764 .73002 .63221 .74198 .62385 .73467 .58902 Mtetra
.632 .48 .658 r
.73467 .58902 .74198 .62385 .75405 .61682 .74669 .5822 Mtetra
.609 .466 .661 r
.74669 .5822 .75405 .61682 .76631 .61221 .75895 .57846 Mtetra
.575 .446 .667 r
.75895 .57846 .76631 .61221 .77884 .6106 .77156 .57877 Mtetra
.537 .426 .675 r
.77156 .57877 .77884 .6106 .79163 .61134 .78454 .58289 Mtetra
.514 .422 .689 r
.78454 .58289 .79163 .61134 .8045 .6121 .79775 .58851 Mtetra
.538 .459 .714 r
.79775 .58851 .8045 .6121 .81716 .60936 .81087 .59151 Mtetra
.638 .555 .745 r
.81087 .59151 .81716 .60936 .82931 .60012 .82349 .58754 Mtetra
.781 .678 .75 r
.82349 .58754 .82931 .60012 .84079 .58355 .83532 .5744 Mtetra
.88 .753 .719 r
.83532 .5744 .84079 .58355 .85171 .56165 .84639 .55343 Mtetra
.91 .77 .694 r
.84639 .55343 .85171 .56165 .86239 .53812 .85702 .52881 Mtetra
.892 .753 .701 r
.85702 .52881 .86239 .53812 .8732 .51685 .8677 .5057 Mtetra
.829 .714 .737 r
.8677 .5057 .8732 .51685 .88457 .50144 .87898 .48915 Mtetra
.686 .639 .797 r
.87898 .48915 .88457 .50144 .8969 .49501 .89142 .48339 Mtetra
.417 .504 .841 r
.89142 .48339 .8969 .49501 .91029 .49736 .90512 .4883 Mtetra
.294 .488 .878 r
.90512 .4883 .91029 .49736 .92392 .50075 .9191 .49452 Mtetra
.727 .798 .908 r
.9191 .49452 .92392 .50075 .93636 .49373 .93171 .48839 Mtetra
.939 .842 .721 r
.93171 .48839 .93636 .49373 .94718 .47376 .94242 .46702 Mtetra
.943 .807 .68 r
.94242 .46702 .94718 .47376 .95742 .45 .95248 .44131 Mtetra
.515 0 0 r
.36693 .58874 .37342 .59176 .38349 .59716 .37696 .59544 Mtetra
.789 .3 .045 r
.37696 .59544 .38349 .59716 .39346 .60717 .38687 .60736 Mtetra
.842 .424 .243 r
.38687 .60736 .39346 .60717 .4034 .62178 .39673 .62433 Mtetra
.834 .445 .314 r
.39673 .62433 .4034 .62178 .41342 .63847 .40669 .64326 Mtetra
.788 .398 .315 r
.40669 .64326 .41342 .63847 .42369 .65244 .41694 .65856 Mtetra
.654 .227 .221 r
.41694 .65856 .42369 .65244 .43429 .65905 .42759 .665 Mtetra
.163 0 0 r
.42759 .665 .43429 .65905 .4452 .65689 .4386 .66131 Mtetra
.651 .942 .693 r
.4386 .66131 .4452 .65689 .45628 .64887 .4498 .65106 Mtetra
.831 .999 .83 r
.4498 .65106 .45628 .64887 .46738 .64004 .461 .63998 Mtetra
.764 .971 .924 r
.461 .63998 .46738 .64004 .47845 .63438 .47215 .63244 Mtetra
.537 .868 .993 r
.47215 .63244 .47845 .63438 .4895 .63324 .48326 .62973 Mtetra
.269 .681 .968 r
.48326 .62973 .4895 .63324 .50059 .63585 .49439 .63086 Mtetra
.175 .566 .934 r
.49439 .63086 .50059 .63585 .51174 .64064 .50557 .63406 Mtetra
.246 .545 .927 r
.50557 .63406 .51174 .64064 .523 .64627 .51685 .63783 Mtetra
.367 .551 .902 r
.51685 .63783 .523 .64627 .53436 .65185 .52821 .64125 Mtetra
.466 .549 .857 r
.52821 .64125 .53436 .65185 .54582 .65687 .53966 .64381 Mtetra
.531 .54 .81 r
.53966 .64381 .54582 .65687 .55738 .66103 .5512 .64523 Mtetra
.571 .529 .77 r
.5512 .64523 .55738 .66103 .56902 .66413 .56279 .64537 Mtetra
.597 .519 .737 r
.56279 .64537 .56902 .66413 .58073 .66602 .57444 .64413 Mtetra
.614 .51 .713 r
.57444 .64413 .58073 .66602 .5925 .66659 .58613 .64148 Mtetra
.624 .502 .693 r
.58613 .64148 .5925 .66659 .60432 .66579 .59784 .63746 Mtetra
.631 .495 .678 r
.59784 .63746 .60432 .66579 .61616 .66361 .60956 .63212 Mtetra
.636 .489 .667 r
.60956 .63212 .61616 .66361 .62803 .66008 .62129 .62557 Mtetra
.638 .484 .658 r
.62129 .62557 .62803 .66008 .6399 .65527 .63301 .61798 Mtetra
.64 .48 .651 r
.63301 .61798 .6399 .65527 .65177 .64929 .64473 .60951 Mtetra
.64 .476 .645 r
.64473 .60951 .65177 .64929 .66363 .64227 .65643 .60034 Mtetra
.64 .473 .641 r
.65643 .60034 .66363 .64227 .67548 .63435 .66812 .59066 Mtetra
.639 .47 .638 r
.66812 .59066 .67548 .63435 .68731 .62571 .6798 .58067 Mtetra
.638 .467 .635 r
.6798 .58067 .68731 .62571 .69913 .61652 .69149 .57054 Mtetra
.636 .464 .634 r
.69149 .57054 .69913 .61652 .71095 .60703 .70318 .56053 Mtetra
.633 .462 .633 r
.70318 .56053 .71095 .60703 .72278 .59764 .7149 .55097 Mtetra
.626 .457 .634 r
.7149 .55097 .72278 .59764 .73467 .58902 .7267 .54249 Mtetra
.615 .449 .635 r
.7267 .54249 .73467 .58902 .74669 .5822 .73864 .53613 Mtetra
.594 .436 .637 r
.73864 .53613 .74669 .5822 .75895 .57846 .75086 .53331 Mtetra
.562 .415 .64 r
.75086 .53331 .75895 .57846 .77156 .57877 .76348 .53535 Mtetra
.522 .391 .643 r
.76348 .53535 .77156 .57877 .78454 .58289 .77659 .54255 Mtetra
.489 .374 .65 r
.77659 .54255 .78454 .58289 .79775 .58851 .79008 .55298 Mtetra
.489 .385 .663 r
.79008 .55298 .79775 .58851 .81087 .59151 .80364 .56226 Mtetra
.55 .443 .685 r
.80364 .56226 .81087 .59151 .82349 .58754 .81677 .56487 Mtetra
.668 .543 .703 r
.81677 .56487 .82349 .58754 .83532 .5744 .82907 .55693 Mtetra
.784 .636 .696 r
.82907 .55693 .83532 .5744 .84639 .55343 .84041 .53859 Mtetra
.844 .68 .679 r
.84041 .53859 .84639 .55343 .85702 .52881 .85108 .51402 Mtetra
.845 .681 .679 r
.85108 .51402 .85702 .52881 .8677 .5057 .86166 .48954 Mtetra
.791 .647 .703 r
.86166 .48954 .8677 .5057 .87898 .48915 .87285 .47192 Mtetra
.653 .568 .746 r
.87285 .47192 .87898 .48915 .89142 .48339 .88537 .46687 Mtetra
.41 .431 .772 r
.88537 .46687 .89142 .48339 .90512 .4883 .89938 .47453 Mtetra
.313 .406 .798 r
.89938 .47453 .90512 .4883 .9191 .49452 .91374 .48389 Mtetra
.679 .667 .831 r
.91374 .48389 .9191 .49452 .93171 .48839 .92652 .4789 Mtetra
.895 .76 .704 r
.92652 .4789 .93171 .48839 .94242 .46702 .93713 .4563 Mtetra
.906 .743 .668 r
.93713 .4563 .94242 .46702 .95248 .44131 .94701 .42883 Mtetra
.477 0 0 r
.36046 .58423 .36693 .58874 .37696 .59544 .37044 .59191 Mtetra
.807 .318 0 r
.37044 .59191 .37696 .59544 .38687 .60736 .38029 .6054 Mtetra
.868 .446 .21 r
.38029 .6054 .38687 .60736 .39673 .62433 .39008 .62427 Mtetra
.864 .464 .277 r
.39008 .62427 .39673 .62433 .40669 .64326 .39998 .64482 Mtetra
.818 .399 .248 r
.39998 .64482 .40669 .64326 .41694 .65856 .41023 .6606 Mtetra
.602 .081 0 r
.41023 .6606 .41694 .65856 .42759 .665 .42095 .6659 Mtetra
.649 .966 .907 r
.42095 .6659 .42759 .665 .4386 .66131 .43208 .65962 Mtetra
.889 .879 .819 r
.43208 .65962 .4386 .66131 .4498 .65106 .4434 .64612 Mtetra
.858 .792 .786 r
.4434 .64612 .4498 .65106 .461 .63998 .45472 .6319 Mtetra
.786 .724 .795 r
.45472 .6319 .461 .63998 .47215 .63244 .46595 .62164 Mtetra
.686 .646 .805 r
.46595 .62164 .47215 .63244 .48326 .62973 .4771 .61661 Mtetra
.595 .57 .796 r
.4771 .61661 .48326 .62973 .49439 .63086 .48825 .61558 Mtetra
.549 .52 .775 r
.48825 .61558 .49439 .63086 .50557 .63406 .49944 .61661 Mtetra
.545 .496 .753 r
.49944 .61661 .50557 .63406 .51685 .63783 .5107 .61811 Mtetra
.558 .487 .732 r
.5107 .61811 .51685 .63783 .52821 .64125 .52204 .61915 Mtetra
.575 .483 .714 r
.52204 .61915 .52821 .64125 .53966 .64381 .53345 .61925 Mtetra
.59 .482 .698 r
.53345 .61925 .53966 .64381 .5512 .64523 .54493 .6182 Mtetra
.603 .48 .685 r
.54493 .6182 .5512 .64523 .56279 .64537 .55646 .61589 Mtetra
.613 .479 .675 r
.55646 .61589 .56279 .64537 .57444 .64413 .56803 .61229 Mtetra
.621 .478 .666 r
.56803 .61229 .57444 .64413 .58613 .64148 .57963 .60744 Mtetra
.627 .477 .659 r
.57963 .60744 .58613 .64148 .59784 .63746 .59124 .6014 Mtetra
.632 .476 .653 r
.59124 .6014 .59784 .63746 .60956 .63212 .60286 .5943 Mtetra
.636 .476 .649 r
.60286 .5943 .60956 .63212 .62129 .62557 .61448 .58627 Mtetra
.638 .475 .645 r
.61448 .58627 .62129 .62557 .63301 .61798 .62609 .57748 Mtetra
.64 .474 .643 r
.62609 .57748 .63301 .61798 .64473 .60951 .6377 .56812 Mtetra
.64 .473 .641 r
.6377 .56812 .64473 .60951 .65643 .60034 .6493 .55838 Mtetra
.641 .472 .64 r
.6493 .55838 .65643 .60034 .66812 .59066 .6609 .54843 Mtetra
.64 .472 .639 r
.6609 .54843 .66812 .59066 .6798 .58067 .6725 .53844 Mtetra
.64 .471 .639 r
.6725 .53844 .6798 .58067 .69149 .57054 .68412 .52859 Mtetra
.638 .47 .64 r
.68412 .52859 .69149 .57054 .70318 .56053 .69575 .51906 Mtetra
.635 .469 .641 r
.69575 .51906 .70318 .56053 .7149 .55097 .70743 .51014 Mtetra
.629 .466 .643 r
.70743 .51014 .7149 .55097 .7267 .54249 .71919 .50238 Mtetra
.616 .458 .645 r
.71919 .50238 .7267 .54249 .73864 .53613 .7311 .49676 Mtetra
.591 .443 .649 r
.7311 .49676 .73864 .53613 .75086 .53331 .74328 .49475 Mtetra
.549 .416 .652 r
.74328 .49475 .75086 .53331 .76348 .53535 .7559 .49802 Mtetra
.489 .379 .655 r
.7559 .49802 .76348 .53535 .77659 .54255 .76907 .50741 Mtetra
.427 .343 .659 r
.76907 .50741 .77659 .54255 .79008 .55298 .78277 .52169 Mtetra
.397 .335 .671 r
.78277 .52169 .79008 .55298 .80364 .56226 .79672 .53663 Mtetra
.448 .391 .702 r
.79672 .53663 .80364 .56226 .81677 .56487 .81038 .54589 Mtetra
.605 .529 .741 r
.81038 .54589 .81677 .56487 .82907 .55693 .8232 .54393 Mtetra
.793 .679 .738 r
.8232 .54393 .82907 .55693 .84041 .53859 .83491 .52916 Mtetra
.895 .752 .697 r
.83491 .52916 .84041 .53859 .85108 .51402 .8457 .50518 Mtetra
.911 .762 .684 r
.8457 .50518 .85108 .51402 .86166 .48954 .85619 .47922 Mtetra
.86 .735 .724 r
.85619 .47922 .86166 .48954 .87285 .47192 .86726 .45989 Mtetra
.676 .639 .806 r
.86726 .45989 .87285 .47192 .88537 .46687 .87979 .45475 Mtetra
.246 .39 .811 r
.87979 .45475 .88537 .46687 .89938 .47453 .89404 .46448 Mtetra
.062 .312 .796 r
.89404 .46448 .89938 .47453 .91374 .48389 .90871 .47637 Mtetra
.679 .743 .899 r
.90871 .47637 .91374 .48389 .92652 .4789 .92159 .47181 Mtetra
.934 .803 .692 r
.92159 .47181 .92652 .4789 .93713 .4563 .93202 .44724 Mtetra
.933 .768 .654 r
.93202 .44724 .93713 .4563 .94701 .42883 .94167 .41744 Mtetra
0 .15 .655 r
.35403 .57764 .36046 .58423 .37044 .59191 .36399 .58593 Mtetra
.782 .298 0 r
.36399 .58593 .37044 .59191 .38029 .6054 .37378 .60053 Mtetra
.884 .454 .134 r
.37378 .60053 .38029 .6054 .39008 .62427 .3835 .62077 Mtetra
.888 .471 .198 r
.3835 .62077 .39008 .62427 .39998 .64482 .39335 .64224 Mtetra
.832 .366 .088 r
.39335 .64224 .39998 .64482 .41023 .6606 .40361 .65765 Mtetra
0 .47 .801 r
.40361 .65765 .41023 .6606 .42095 .6659 .41442 .66083 Mtetra
.811 .797 .839 r
.41442 .66083 .42095 .6659 .43208 .65962 .42569 .65105 Mtetra
.838 .721 .735 r
.42569 .65105 .43208 .65962 .4434 .64612 .43715 .63353 Mtetra
.806 .669 .712 r
.43715 .63353 .4434 .64612 .45472 .6319 .44858 .61555 Mtetra
.749 .615 .711 r
.44858 .61555 .45472 .6319 .46595 .62164 .45988 .6021 Mtetra
.68 .559 .711 r
.45988 .6021 .46595 .62164 .4771 .61661 .47106 .59437 Mtetra
.622 .51 .705 r
.47106 .59437 .4771 .61661 .48825 .61558 .48221 .59094 Mtetra
.592 .48 .696 r
.48221 .59094 .48825 .61558 .49944 .61661 .49338 .5897 Mtetra
.584 .467 .686 r
.49338 .5897 .49944 .61661 .5107 .61811 .50461 .58903 Mtetra
.587 .462 .677 r
.50461 .58903 .5107 .61811 .52204 .61915 .5159 .58802 Mtetra
.593 .46 .669 r
.5159 .58802 .52204 .61915 .53345 .61925 .52726 .58622 Mtetra
.601 .461 .663 r
.52726 .58622 .53345 .61925 .54493 .6182 .53867 .58348 Mtetra
.608 .462 .658 r
.53867 .58348 .54493 .6182 .55646 .61589 .55012 .57975 Mtetra
.614 .463 .654 r
.55012 .57975 .55646 .61589 .56803 .61229 .56161 .57503 Mtetra
.62 .465 .651 r
.56161 .57503 .56803 .61229 .57963 .60744 .57312 .56938 Mtetra
.624 .467 .648 r
.57312 .56938 .57963 .60744 .59124 .6014 .58465 .56288 Mtetra
.629 .469 .647 r
.58465 .56288 .59124 .6014 .60286 .5943 .5962 .55563 Mtetra
.633 .471 .646 r
.5962 .55563 .60286 .5943 .61448 .58627 .60775 .54778 Mtetra
.636 .474 .646 r
.60775 .54778 .61448 .58627 .62609 .57748 .61931 .53947 Mtetra
.638 .476 .647 r
.61931 .53947 .62609 .57748 .6377 .56812 .63087 .53084 Mtetra
.641 .479 .649 r
.63087 .53084 .6377 .56812 .6493 .55838 .64244 .52205 Mtetra
.642 .482 .651 r
.64244 .52205 .6493 .55838 .6609 .54843 .65402 .51323 Mtetra
.644 .485 .653 r
.65402 .51323 .6609 .54843 .6725 .53844 .66562 .5045 Mtetra
.644 .488 .656 r
.66562 .5045 .6725 .53844 .68412 .52859 .67725 .49598 Mtetra
.644 .491 .66 r
.67725 .49598 .68412 .52859 .69575 .51906 .6889 .48782 Mtetra
.643 .493 .665 r
.6889 .48782 .69575 .51906 .70743 .51014 .7006 .48022 Mtetra
.637 .493 .67 r
.7006 .48022 .70743 .51014 .71919 .50238 .71238 .47363 Mtetra
.622 .487 .677 r
.71238 .47363 .71919 .50238 .7311 .49676 .72431 .46895 Mtetra
.59 .47 .684 r
.72431 .46895 .7311 .49676 .74328 .49475 .7365 .46764 Mtetra
.527 .433 .691 r
.7365 .46764 .74328 .49475 .7559 .49802 .74911 .47156 Mtetra
.426 .37 .693 r
.74911 .47156 .7559 .49802 .76907 .50741 .76231 .48215 Mtetra
.299 .293 .685 r
.76231 .48215 .76907 .50741 .78277 .52169 .77615 .49895 Mtetra
.197 .242 .683 r
.77615 .49895 .78277 .52169 .79672 .53663 .7904 .51835 Mtetra
.206 .285 .724 r
.7904 .51835 .79672 .53663 .81038 .54589 .80455 .53372 Mtetra
.433 .51 .837 r
.80455 .53372 .81038 .54589 .8232 .54393 .81794 .53803 Mtetra
.818 .826 .856 r
.81794 .53803 .8232 .54393 .83491 .52916 .83011 .52771 Mtetra
.968 .906 .7 r
.83011 .52771 .83491 .52916 .8457 .50518 .84113 .50512 Mtetra
.985 .9 .633 r
.84113 .50512 .8457 .50518 .85619 .47922 .85159 .47787 Mtetra
.966 .918 .706 r
.85159 .47787 .85619 .47922 .86726 .45989 .86253 .45641 Mtetra
.712 .898 .963 r
.86253 .45641 .86726 .45989 .87979 .45475 .87503 .45045 Mtetra
0 .149 .623 r
.87503 .45045 .87979 .45475 .89404 .46448 .88946 .46145 Mtetra
.565 .024 0 r
.88946 .46145 .89404 .46448 .90871 .47637 .90436 .47503 Mtetra
.573 .926 .95 r
.90436 .47503 .90871 .47637 .92159 .47181 .91724 .46992 Mtetra
.986 .884 .637 r
.91724 .46992 .92159 .47181 .93202 .44724 .9274 .44233 Mtetra
.979 .821 .617 r
.9274 .44233 .93202 .44724 .94167 .41744 .93673 .40933 Mtetra
0 .197 .72 r
.34764 .56945 .35403 .57764 .36399 .58593 .35758 .57813 Mtetra
.741 .277 0 r
.35758 .57813 .36399 .58593 .37378 .60053 .36731 .59362 Mtetra
.884 .455 .076 r
.36731 .59362 .37378 .60053 .3835 .62077 .37696 .61493 Mtetra
.892 .468 .126 r
.37696 .61493 .3835 .62077 .39335 .64224 .38677 .6369 Mtetra
.779 .286 0 r
.38677 .6369 .39335 .64224 .40361 .65765 .39705 .65141 Mtetra
.469 .676 .955 r
.39705 .65141 .40361 .65765 .41442 .66083 .40797 .65194 Mtetra
.81 .713 .759 r
.40797 .65194 .41442 .66083 .42569 .65105 .41938 .63823 Mtetra
.823 .672 .696 r
.41938 .63823 .42569 .65105 .43715 .63353 .431 .61645 Mtetra
.795 .634 .682 r
.431 .61645 .43715 .63353 .44858 .61555 .44254 .59465 Mtetra
.745 .589 .682 r
.44254 .59465 .44858 .61555 .45988 .6021 .4539 .57808 Mtetra
.686 .541 .684 r
.4539 .57808 .45988 .6021 .47106 .59437 .46511 .56781 Mtetra
.636 .501 .681 r
.46511 .56781 .47106 .59437 .48221 .59094 .47625 .56222 Mtetra
.609 .476 .675 r
.47625 .56222 .48221 .59094 .49338 .5897 .4874 .55908 Mtetra
.599 .464 .669 r
.4874 .55908 .49338 .5897 .50461 .58903 .49858 .55672 Mtetra
.598 .46 .664 r
.49858 .55672 .50461 .58903 .5159 .58802 .50982 .55425 Mtetra
.601 .459 .659 r
.50982 .55425 .5159 .58802 .52726 .58622 .52111 .55128 Mtetra
.606 .459 .656 r
.52111 .55128 .52726 .58622 .53867 .58348 .53245 .54768 Mtetra
.61 .46 .654 r
.53245 .54768 .53867 .58348 .55012 .57975 .54383 .54343 Mtetra
.614 .462 .652 r
.54383 .54343 .55012 .57975 .56161 .57503 .55525 .53855 Mtetra
.618 .465 .652 r
.55525 .53855 .56161 .57503 .57312 .56938 .5667 .53308 Mtetra
.622 .468 .652 r
.5667 .53308 .57312 .56938 .58465 .56288 .57818 .52711 Mtetra
.626 .472 .653 r
.57818 .52711 .58465 .56288 .5962 .55563 .58968 .5207 Mtetra
.63 .476 .655 r
.58968 .5207 .5962 .55563 .60775 .54778 .60119 .51396 Mtetra
.633 .48 .657 r
.60119 .51396 .60775 .54778 .61931 .53947 .61273 .50698 Mtetra
.637 .486 .661 r
.61273 .50698 .61931 .53947 .63087 .53084 .62429 .49987 Mtetra
.64 .492 .665 r
.62429 .49987 .63087 .53084 .64244 .52205 .63587 .49271 Mtetra
.643 .498 .671 r
.63587 .49271 .64244 .52205 .65402 .51323 .64748 .48559 Mtetra
.646 .505 .677 r
.64748 .48559 .65402 .51323 .66562 .5045 .65912 .47858 Mtetra
.648 .512 .684 r
.65912 .47858 .66562 .5045 .67725 .49598 .67079 .47176 Mtetra
.65 .52 .692 r
.67079 .47176 .67725 .49598 .6889 .48782 .6825 .46521 Mtetra
.65 .528 .701 r
.6825 .46521 .6889 .48782 .7006 .48022 .69426 .45908 Mtetra
.645 .533 .712 r
.69426 .45908 .7006 .48022 .71238 .47363 .7061 .45373 Mtetra
.629 .531 .724 r
.7061 .45373 .71238 .47363 .72431 .46895 .71807 .44992 Mtetra
.588 .513 .738 r
.71807 .44992 .72431 .46895 .7365 .46764 .73027 .44902 Mtetra
.499 .463 .748 r
.73027 .44902 .7365 .46764 .74911 .47156 .74287 .45299 Mtetra
.337 .363 .741 r
.74287 .45299 .74911 .47156 .76231 .48215 .75605 .46368 Mtetra
.119 .222 .697 r
.75605 .46368 .76231 .48215 .77615 .49895 .76992 .48152 Mtetra
0 .106 .642 r
.76992 .48152 .77615 .49895 .7904 .51835 .78437 .50379 Mtetra
0 .099 .649 r
.78437 .50379 .7904 .51835 .80455 .53372 .79891 .52418 Mtetra
.05 .326 .808 r
.79891 .52418 .80455 .53372 .81794 .53803 .81285 .53468 Mtetra
.666 .888 .979 r
.81285 .53468 .81794 .53803 .83011 .52771 .82557 .52971 Mtetra
.92 .966 .66 r
.82557 .52971 .83011 .52771 .84113 .50512 .83694 .5098 Mtetra
.916 .906 .505 r
.83694 .5098 .84113 .50512 .85159 .47787 .8475 .48229 Mtetra
.867 .916 .517 r
.8475 .48229 .85159 .47787 .86253 .45641 .85837 .4591 Mtetra
0 0 0 r
.85837 .4591 .86253 .45641 .87503 .45045 .87086 .45219 Mtetra
.691 .158 0 r
.87086 .45219 .87503 .45045 .88946 .46145 .88545 .46407 Mtetra
.741 .235 .017 r
.88545 .46407 .88946 .46145 .90436 .47503 .90054 .47874 Mtetra
0 0 0 r
.90054 .47874 .90436 .47503 .91724 .46992 .91335 .47224 Mtetra
.97 .892 .522 r
.91335 .47224 .91724 .46992 .9274 .44233 .92314 .44075 Mtetra
.998 .846 .559 r
.92314 .44075 .9274 .44233 .93673 .40933 .93209 .40386 Mtetra
0 .175 .706 r
.34123 .56087 .34764 .56945 .35758 .57813 .35114 .56999 Mtetra
.765 .308 0 r
.35114 .56999 .35758 .57813 .36731 .59362 .36081 .58645 Mtetra
.893 .472 .097 r
.36081 .58645 .36731 .59362 .37696 .61493 .37037 .6089 Mtetra
.895 .474 .132 r
.37037 .6089 .37696 .61493 .38677 .6369 .38014 .63138 Mtetra
.744 .241 0 r
.38014 .63138 .38677 .6369 .39705 .65141 .39046 .64494 Mtetra
.614 .724 .924 r
.39046 .64494 .39705 .65141 .40797 .65194 .40148 .64279 Mtetra
.833 .713 .732 r
.40148 .64279 .40797 .65194 .41938 .63823 .41306 .62526 Mtetra
.838 .676 .681 r
.41306 .62526 .41938 .63823 .431 .61645 .42484 .59951 Mtetra
.811 .642 .673 r
.42484 .59951 .431 .61645 .44254 .59465 .4365 .57434 Mtetra
.763 .602 .678 r
.4365 .57434 .44254 .59465 .4539 .57808 .44792 .55517 Mtetra
.706 .558 .684 r
.44792 .55517 .4539 .57808 .46511 .56781 .45916 .54293 Mtetra
.655 .519 .685 r
.45916 .54293 .46511 .56781 .47625 .56222 .47029 .53578 Mtetra
.625 .494 .683 r
.47029 .53578 .47625 .56222 .4874 .55908 .48142 .53134 Mtetra
.612 .481 .678 r
.48142 .53134 .4874 .55908 .49858 .55672 .49257 .52791 Mtetra
.609 .476 .675 r
.49257 .52791 .49858 .55672 .50982 .55425 .50377 .52462 Mtetra
.61 .475 .672 r
.50377 .52462 .50982 .55425 .52111 .55128 .51501 .52109 Mtetra
.613 .475 .67 r
.51501 .52109 .52111 .55128 .53245 .54768 .5263 .51722 Mtetra
.616 .476 .669 r
.5263 .51722 .53245 .54768 .54383 .54343 .53763 .51299 Mtetra
.619 .478 .668 r
.53763 .51299 .54383 .54343 .55525 .53855 .54901 .50841 Mtetra
.622 .481 .669 r
.54901 .50841 .55525 .53855 .5667 .53308 .56042 .50353 Mtetra
.625 .485 .671 r
.56042 .50353 .5667 .53308 .57818 .52711 .57186 .49839 Mtetra
.628 .49 .674 r
.57186 .49839 .57818 .52711 .58968 .5207 .58334 .49304 Mtetra
.632 .495 .678 r
.58334 .49304 .58968 .5207 .60119 .51396 .59484 .48753 Mtetra
.635 .502 .683 r
.59484 .48753 .60119 .51396 .61273 .50698 .60639 .48192 Mtetra
.639 .509 .689 r
.60639 .48192 .61273 .50698 .62429 .49987 .61796 .47626 Mtetra
.642 .518 .696 r
.61796 .47626 .62429 .49987 .63587 .49271 .62957 .47061 Mtetra
.646 .527 .705 r
.62957 .47061 .63587 .49271 .64748 .48559 .64122 .465 Mtetra
.649 .537 .714 r
.64122 .465 .64748 .48559 .65912 .47858 .6529 .45948 Mtetra
.652 .549 .725 r
.6529 .45948 .65912 .47858 .67079 .47176 .66463 .45408 Mtetra
.655 .561 .736 r
.66463 .45408 .67079 .47176 .6825 .46521 .6764 .44884 Mtetra
.656 .572 .749 r
.6764 .44884 .6825 .46521 .69426 .45908 .68822 .44387 Mtetra
.652 .581 .763 r
.68822 .44387 .69426 .45908 .7061 .45373 .70012 .43945 Mtetra
.634 .583 .779 r
.70012 .43945 .7061 .45373 .71807 .44992 .71213 .43618 Mtetra
.587 .565 .796 r
.71213 .43618 .71807 .44992 .73027 .44902 .72433 .43528 Mtetra
.477 .504 .807 r
.72433 .43528 .73027 .44902 .74287 .45299 .73689 .43866 Mtetra
.27 .37 .782 r
.73689 .43866 .74287 .45299 .75605 .46368 .75 .44845 Mtetra
.005 .182 .696 r
.75 .44845 .75605 .46368 .76992 .48152 .76382 .46579 Mtetra
0 .035 .601 r
.76382 .46579 .76992 .48152 .78437 .50379 .7783 .48909 Mtetra
0 .004 .579 r
.7783 .48909 .78437 .50379 .79891 .52418 .7931 .51286 Mtetra
0 .159 .699 r
.7931 .51286 .79891 .52418 .81285 .53468 .8075 .52883 Mtetra
.422 .683 .971 r
.8075 .52883 .81285 .53468 .82557 .52971 .8208 .52977 Mtetra
.906 .983 .772 r
.8208 .52977 .82557 .52971 .83694 .5098 .83265 .51406 Mtetra
.917 .918 .53 r
.83265 .51406 .83694 .5098 .8475 .48229 .84346 .48794 Mtetra
.813 .883 .455 r
.84346 .48794 .8475 .48229 .85837 .4591 .8544 .46423 Mtetra
0 0 0 r
.8544 .46423 .85837 .4591 .87086 .45219 .86696 .457 Mtetra
.721 .239 .1 r
.86696 .457 .87086 .45219 .88545 .46407 .88173 .4699 Mtetra
.749 .286 .151 r
.88173 .4699 .88545 .46407 .90054 .47874 .89698 .48538 Mtetra
.006 0 0 r
.89698 .48538 .90054 .47874 .91335 .47224 .90967 .47692 Mtetra
.941 .862 .436 r
.90967 .47692 .91335 .47224 .92314 .44075 .91905 .44089 Mtetra
.998 .842 .511 r
.91905 .44089 .92314 .44075 .93209 .40386 .92757 .39966 Mtetra
0 .078 .611 r
.33475 .55295 .34123 .56087 .35114 .56999 .34461 .5628 Mtetra
.833 .379 0 r
.34461 .5628 .35114 .56999 .36081 .58645 .35419 .58055 Mtetra
.907 .498 .176 r
.35419 .58055 .36081 .58645 .37037 .6089 .36366 .60444 Mtetra
.899 .489 .2 r
.36366 .60444 .37037 .6089 .38014 .63138 .37338 .6277 Mtetra
.772 .264 0 r
.37338 .6277 .38014 .63138 .39046 .64494 .38372 .64053 Mtetra
.697 .817 .939 r
.38372 .64053 .39046 .64494 .40148 .64279 .39487 .63597 Mtetra
.872 .748 .723 r
.39487 .63597 .40148 .64279 .41306 .62526 .40662 .61501 Mtetra
.869 .704 .676 r
.40662 .61501 .41306 .62526 .42484 .59951 .41856 .58585 Mtetra
.842 .673 .672 r
.41856 .58585 .42484 .59951 .4365 .57434 .43034 .55794 Mtetra
.797 .638 .685 r
.43034 .55794 .4365 .57434 .44792 .55517 .44184 .53685 Mtetra
.738 .598 .7 r
.44184 .53685 .44792 .55517 .45916 .54293 .45311 .52331 Mtetra
.683 .559 .709 r
.45311 .52331 .45916 .54293 .47029 .53578 .46426 .51521 Mtetra
.646 .533 .711 r
.46426 .51521 .47029 .53578 .48142 .53134 .47537 .51006 Mtetra
.629 .519 .71 r
.47537 .51006 .48142 .53134 .49257 .52791 .48651 .5061 Mtetra
.624 .513 .707 r
.48651 .5061 .49257 .52791 .50377 .52462 .49769 .50245 Mtetra
.624 .511 .705 r
.49769 .50245 .50377 .52462 .51501 .52109 .50891 .49875 Mtetra
.625 .512 .704 r
.50891 .49875 .51501 .52109 .5263 .51722 .52018 .4949 Mtetra
.627 .513 .704 r
.52018 .4949 .5263 .51722 .53763 .51299 .53149 .49088 Mtetra
.629 .516 .706 r
.53149 .49088 .53763 .51299 .54901 .50841 .54284 .48669 Mtetra
.632 .52 .708 r
.54284 .48669 .54901 .50841 .56042 .50353 .55424 .48237 Mtetra
.635 .524 .711 r
.55424 .48237 .56042 .50353 .57186 .49839 .56568 .47794 Mtetra
.637 .53 .716 r
.56568 .47794 .57186 .49839 .58334 .49304 .57715 .47341 Mtetra
.64 .537 .722 r
.57715 .47341 .58334 .49304 .59484 .48753 .58867 .46882 Mtetra
.643 .545 .729 r
.58867 .46882 .59484 .48753 .60639 .48192 .60023 .46419 Mtetra
.647 .555 .737 r
.60023 .46419 .60639 .48192 .61796 .47626 .61183 .45954 Mtetra
.65 .565 .746 r
.61183 .45954 .61796 .47626 .62957 .47061 .62347 .45491 Mtetra
.653 .576 .756 r
.62347 .45491 .62957 .47061 .64122 .465 .63515 .4503 Mtetra
.656 .588 .767 r
.63515 .4503 .64122 .465 .6529 .45948 .64688 .44574 Mtetra
.659 .601 .779 r
.64688 .44574 .6529 .45948 .66463 .45408 .65866 .44123 Mtetra
.661 .614 .791 r
.65866 .44123 .66463 .45408 .6764 .44884 .67048 .43681 Mtetra
.661 .626 .804 r
.67048 .43681 .6764 .44884 .68822 .44387 .68236 .43254 Mtetra
.656 .636 .818 r
.68236 .43254 .68822 .44387 .70012 .43945 .6943 .42862 Mtetra
.639 .637 .832 r
.6943 .42862 .70012 .43945 .71213 .43618 .70634 .42552 Mtetra
.591 .618 .848 r
.70634 .42552 .71213 .43618 .72433 .43528 .71854 .42427 Mtetra
.478 .553 .854 r
.71854 .42427 .72433 .43528 .73689 .43866 .73105 .42659 Mtetra
.268 .408 .819 r
.73105 .42659 .73689 .43866 .75 .44845 .74404 .43467 Mtetra
.005 .204 .717 r
.74404 .43467 .75 .44845 .76382 .46579 .75771 .45021 Mtetra
0 .048 .611 r
.75771 .45021 .76382 .46579 .7783 .48909 .7721 .47269 Mtetra
0 .009 .581 r
.7721 .47269 .7783 .48909 .7931 .51286 .78696 .49784 Mtetra
0 .12 .662 r
.78696 .49784 .7931 .51286 .8075 .52883 .80169 .51788 Mtetra
.303 .461 .853 r
.80169 .51788 .8075 .52883 .8208 .52977 .8155 .52459 Mtetra
.824 .857 .872 r
.8155 .52459 .8208 .52977 .83265 .51406 .82791 .51424 Mtetra
.968 .935 .676 r
.82791 .51424 .83265 .51406 .84346 .48794 .83914 .49139 Mtetra
.896 .94 .573 r
.83914 .49139 .84346 .48794 .8544 .46423 .85032 .46896 Mtetra
0 0 0 r
.85032 .46896 .8544 .46423 .86696 .457 .86307 .46265 Mtetra
.739 .272 .141 r
.86307 .46265 .86696 .457 .88173 .4699 .87809 .47717 Mtetra
.751 .305 .193 r
.87809 .47717 .88173 .4699 .89698 .48538 .89352 .4935 Mtetra
0 0 0 r
.89352 .4935 .89698 .48538 .90967 .47692 .90605 .48268 Mtetra
.939 .839 .398 r
.90605 .48268 .90967 .47692 .91905 .44089 .91498 .44168 Mtetra
.997 .829 .483 r
.91498 .44168 .91905 .44089 .92757 .39966 .92306 .39585 Mtetra
.57 .072 0 r
.32815 .54615 .33475 .55295 .34461 .5628 .33795 .55706 Mtetra
.877 .438 .09 r
.33795 .55706 .34461 .5628 .35419 .58055 .34743 .57646 Mtetra
.908 .516 .252 r
.34743 .57646 .35419 .58055 .36366 .60444 .35679 .60212 Mtetra
.893 .498 .267 r
.35679 .60212 .36366 .60444 .37338 .6277 .36644 .62642 Mtetra
.783 .295 .054 r
.36644 .62642 .37338 .6277 .38372 .64053 .37682 .63877 Mtetra
.758 .918 .943 r
.37682 .63877 .38372 .64053 .39487 .63597 .38809 .63208 Mtetra
.909 .787 .714 r
.38809 .63208 .39487 .63597 .40662 .61501 .40002 .6081 Mtetra
.9 .737 .67 r
.40002 .6081 .40662 .61501 .41856 .58585 .41214 .57603 Mtetra
.876 .709 .673 r
.41214 .57603 .41856 .58585 .43034 .55794 .42405 .54597 Mtetra
.835 .684 .695 r
.42405 .54597 .43034 .55794 .44184 .53685 .43563 .52355 Mtetra
.778 .653 .724 r
.43563 .52355 .44184 .53685 .45311 .52331 .44694 .50922 Mtetra
.717 .619 .747 r
.44694 .50922 .45311 .52331 .46426 .51521 .45811 .50065 Mtetra
.672 .593 .758 r
.45811 .50065 .46426 .51521 .47537 .51006 .46923 .49518 Mtetra
.65 .579 .761 r
.46923 .49518 .47537 .51006 .48651 .5061 .48038 .49101 Mtetra
.643 .573 .761 r
.48038 .49101 .48651 .5061 .49769 .50245 .49155 .48725 Mtetra
.641 .572 .761 r
.49155 .48725 .49769 .50245 .50891 .49875 .50278 .48354 Mtetra
.642 .572 .761 r
.50278 .48354 .50891 .49875 .52018 .4949 .51405 .47979 Mtetra
.643 .574 .762 r
.51405 .47979 .52018 .4949 .53149 .49088 .52536 .47596 Mtetra
.645 .577 .765 r
.52536 .47596 .53149 .49088 .54284 .48669 .53672 .47207 Mtetra
.647 .582 .768 r
.53672 .47207 .54284 .48669 .55424 .48237 .54812 .46811 Mtetra
.649 .587 .772 r
.54812 .46811 .55424 .48237 .56568 .47794 .55957 .46411 Mtetra
.651 .594 .778 r
.55957 .46411 .56568 .47794 .57715 .47341 .57106 .46007 Mtetra
.653 .601 .784 r
.57106 .46007 .57715 .47341 .58867 .46882 .5826 .456 Mtetra
.655 .61 .791 r
.5826 .456 .58867 .46882 .60023 .46419 .59418 .45191 Mtetra
.657 .619 .8 r
.59418 .45191 .60023 .46419 .61183 .45954 .60581 .44782 Mtetra
.659 .629 .808 r
.60581 .44782 .61183 .45954 .62347 .45491 .61748 .44373 Mtetra
.661 .639 .817 r
.61748 .44373 .62347 .45491 .63515 .4503 .6292 .43964 Mtetra
.663 .649 .827 r
.6292 .43964 .63515 .4503 .64688 .44574 .64097 .43557 Mtetra
.664 .66 .836 r
.64097 .43557 .64688 .44574 .65866 .44123 .65279 .43151 Mtetra
.664 .67 .845 r
.65279 .43151 .65866 .44123 .67048 .43681 .66465 .42748 Mtetra
.664 .679 .854 r
.66465 .42748 .67048 .43681 .68236 .43254 .67657 .42353 Mtetra
.659 .685 .863 r
.67657 .42353 .68236 .43254 .6943 .42862 .68855 .41979 Mtetra
.643 .683 .873 r
.68855 .41979 .6943 .42862 .70634 .42552 .70062 .41662 Mtetra
.602 .664 .883 r
.70062 .41662 .70634 .42552 .71854 .42427 .71282 .41482 Mtetra
.504 .603 .885 r
.71282 .41482 .71854 .42427 .73105 .42659 .72526 .41585 Mtetra
.319 .469 .853 r
.72526 .41585 .73105 .42659 .74404 .43467 .73812 .42179 Mtetra
.079 .271 .758 r
.73812 .42179 .74404 .43467 .75771 .45021 .75158 .43462 Mtetra
0 .11 .652 r
.75158 .43462 .75771 .45021 .7721 .47269 .76577 .45474 Mtetra
0 .057 .61 r
.76577 .45474 .7721 .47269 .78696 .49784 .78054 .47925 Mtetra
0 .132 .654 r
.78054 .47925 .78696 .49784 .80169 .51788 .7954 .50146 Mtetra
.269 .351 .763 r
.7954 .50146 .80169 .51788 .8155 .52459 .80962 .51298 Mtetra
.663 .649 .826 r
.80962 .51298 .8155 .52459 .82791 .51424 .82259 .50849 Mtetra
.906 .837 .766 r
.82259 .50849 .82791 .51424 .83914 .49139 .83435 .49052 Mtetra
.949 .947 .736 r
.83435 .49052 .83914 .49139 .85032 .46896 .84594 .47133 Mtetra
0 0 0 r
.84594 .47133 .85032 .46896 .86307 .46265 .85904 .46758 Mtetra
.768 .3 .133 r
.85904 .46758 .86307 .46265 .87809 .47717 .8744 .48472 Mtetra
.759 .317 .201 r
.8744 .48472 .87809 .47717 .89352 .4935 .89004 .5022 Mtetra
0 0 0 r
.89004 .5022 .89352 .4935 .90605 .48268 .90241 .48886 Mtetra
.949 .825 .385 r
.90241 .48886 .90605 .48268 .91498 .44168 .91087 .44261 Mtetra
.998 .817 .466 r
.91087 .44261 .91498 .44168 .92306 .39585 .91851 .39205 Mtetra
.715 .206 0 r
.32145 .54036 .32815 .54615 .33795 .55706 .33116 .55258 Mtetra
.892 .474 .182 r
.33116 .55258 .33795 .55706 .34743 .57646 .34053 .57387 Mtetra
.905 .527 .302 r
.34053 .57387 .34743 .57646 .35679 .60212 .34976 .60151 Mtetra
.885 .503 .309 r
.34976 .60151 .35679 .60212 .36644 .62642 .35934 .62699 Mtetra
.774 .305 .128 r
.35934 .62699 .36644 .62642 .37682 .63877 .36975 .63895 Mtetra
.799 .971 .909 r
.36975 .63895 .37682 .63877 .38809 .63208 .38117 .63027 Mtetra
.933 .81 .7 r
.38117 .63027 .38809 .63208 .40002 .6081 .39329 .60354 Mtetra
.921 .759 .663 r
.39329 .60354 .40002 .6081 .41214 .57603 .40558 .56898 Mtetra
.9 .737 .67 r
.40558 .56898 .41214 .57603 .42405 .54597 .41762 .53721 Mtetra
.866 .722 .701 r
.41762 .53721 .42405 .54597 .43563 .52355 .42929 .51385 Mtetra
.813 .705 .746 r
.42929 .51385 .43563 .52355 .44694 .50922 .44065 .49907 Mtetra
.749 .682 .786 r
.44065 .49907 .44694 .50922 .45811 .50065 .45185 .4903 Mtetra
.697 .661 .811 r
.45185 .4903 .45811 .50065 .46923 .49518 .46299 .48472 Mtetra
.669 .649 .821 r
.46299 .48472 .46923 .49518 .48038 .49101 .47415 .48049 Mtetra
.659 .644 .824 r
.47415 .48049 .48038 .49101 .49155 .48725 .48535 .4767 Mtetra
.656 .643 .825 r
.48535 .4767 .49155 .48725 .50278 .48354 .49659 .47302 Mtetra
.656 .644 .826 r
.49659 .47302 .50278 .48354 .51405 .47979 .50787 .46933 Mtetra
.657 .646 .828 r
.50787 .46933 .51405 .47979 .52536 .47596 .5192 .46562 Mtetra
.658 .649 .83 r
.5192 .46562 .52536 .47596 .53672 .47207 .53058 .46187 Mtetra
.659 .653 .833 r
.53058 .46187 .53672 .47207 .54812 .46811 .542 .4581 Mtetra
.66 .657 .837 r
.542 .4581 .54812 .46811 .55957 .46411 .55347 .4543 Mtetra
.661 .663 .841 r
.55347 .4543 .55957 .46411 .57106 .46007 .56499 .45048 Mtetra
.662 .668 .846 r
.56499 .45048 .57106 .46007 .5826 .456 .57655 .44665 Mtetra
.662 .674 .851 r
.57655 .44665 .5826 .456 .59418 .45191 .58817 .44281 Mtetra
.663 .681 .856 r
.58817 .44281 .59418 .45191 .60581 .44782 .59983 .43896 Mtetra
.664 .687 .862 r
.59983 .43896 .60581 .44782 .61748 .44373 .61153 .43509 Mtetra
.664 .694 .867 r
.61153 .43509 .61748 .44373 .6292 .43964 .62329 .43122 Mtetra
.665 .7 .872 r
.62329 .43122 .6292 .43964 .64097 .43557 .63509 .42733 Mtetra
.665 .705 .877 r
.63509 .42733 .64097 .43557 .65279 .43151 .64695 .42344 Mtetra
.665 .711 .882 r
.64695 .42344 .65279 .43151 .66465 .42748 .65885 .41956 Mtetra
.664 .715 .886 r
.65885 .41956 .66465 .42748 .67657 .42353 .67081 .4157 Mtetra
.66 .717 .891 r
.67081 .4157 .67657 .42353 .68855 .41979 .68282 .41197 Mtetra
.648 .713 .895 r
.68282 .41197 .68855 .41979 .70062 .41662 .69491 .40862 Mtetra
.617 .696 .901 r
.69491 .40862 .70062 .41662 .71282 .41482 .70711 .40623 Mtetra
.542 .647 .902 r
.70711 .40623 .71282 .41482 .72526 .41585 .7195 .40599 Mtetra
.395 .536 .879 r
.7195 .40599 .72526 .41585 .73812 .42179 .73222 .40971 Mtetra
.188 .359 .804 r
.73222 .40971 .73812 .42179 .75158 .43462 .74547 .4194 Mtetra
.018 .194 .704 r
.74547 .4194 .75158 .43462 .76577 .45474 .75938 .43611 Mtetra
0 .122 .648 r
.75938 .43611 .76577 .45474 .78054 .47925 .77392 .45825 Mtetra
.054 .161 .659 r
.77392 .45825 .78054 .47925 .7954 .50146 .78874 .48057 Mtetra
.265 .305 .717 r
.78874 .48057 .7954 .50146 .80962 .51298 .8032 .49533 Mtetra
.549 .512 .767 r
.8032 .49533 .80962 .51298 .82259 .50849 .81665 .49631 Mtetra
.777 .691 .769 r
.81665 .49631 .82259 .50849 .83435 .49052 .829 .48421 Mtetra
.867 .83 .809 r
.829 .48421 .83435 .49052 .84594 .47133 .84114 .47002 Mtetra
.092 .638 .839 r
.84114 .47002 .84594 .47133 .85904 .46758 .85474 .4706 Mtetra
.805 .332 .095 r
.85474 .4706 .85904 .46758 .8744 .48472 .87057 .49161 Mtetra
.776 .33 .189 r
.87057 .49161 .8744 .48472 .89004 .5022 .88647 .51081 Mtetra
0 0 0 r
.88647 .51081 .89004 .5022 .90241 .48886 .89868 .49497 Mtetra
.962 .816 .384 r
.89868 .49497 .90241 .48886 .91087 .44261 .90668 .44338 Mtetra
.998 .805 .456 r
.90668 .44338 .91087 .44261 .91851 .39205 .91389 .38811 Mtetra
.79 .296 0 r
.31465 .53522 .32145 .54036 .33116 .55258 .32427 .5489 Mtetra
.899 .497 .238 r
.32427 .5489 .33116 .55258 .34053 .57387 .3335 .57219 Mtetra
.903 .536 .331 r
.3335 .57219 .34053 .57387 .34976 .60151 .34261 .60184 Mtetra
.881 .507 .331 r
.34261 .60184 .34976 .60151 .35934 .62699 .35212 .62844 Mtetra
.761 .299 .149 r
.35212 .62844 .35934 .62699 .36975 .63895 .36257 .63993 Mtetra
.844 .979 .872 r
.36257 .63993 .36975 .63895 .38117 .63027 .37413 .62929 Mtetra
.943 .813 .686 r
.37413 .62929 .38117 .63027 .39329 .60354 .38645 .59998 Mtetra
.931 .766 .655 r
.38645 .59998 .39329 .60354 .40558 .56898 .39892 .56322 Mtetra
.912 .749 .666 r
.39892 .56322 .40558 .56898 .41762 .53721 .4111 .53007 Mtetra
.883 .744 .703 r
.4111 .53007 .41762 .53721 .42929 .51385 .42285 .50605 Mtetra
.835 .739 .758 r
.42285 .50605 .42929 .51385 .44065 .49907 .43426 .49104 Mtetra
.77 .728 .813 r
.43426 .49104 .44065 .49907 .45185 .4903 .4455 .48219 Mtetra
.712 .713 .849 r
.4455 .48219 .45185 .4903 .46299 .48472 .45667 .47659 Mtetra
.679 .703 .865 r
.45667 .47659 .46299 .48472 .47415 .48049 .46786 .47235 Mtetra
.667 .699 .871 r
.46786 .47235 .47415 .48049 .48535 .4767 .47908 .46856 Mtetra
.663 .699 .873 r
.47908 .46856 .48535 .4767 .49659 .47302 .49034 .46488 Mtetra
.663 .699 .874 r
.49034 .46488 .49659 .47302 .50787 .46933 .50165 .46122 Mtetra
.663 .701 .875 r
.50165 .46122 .50787 .46933 .5192 .46562 .51301 .45754 Mtetra
.663 .703 .876 r
.51301 .45754 .5192 .46562 .53058 .46187 .52441 .45385 Mtetra
.663 .705 .878 r
.52441 .45385 .53058 .46187 .542 .4581 .53586 .45014 Mtetra
.663 .707 .88 r
.53586 .45014 .542 .4581 .55347 .4543 .54736 .44642 Mtetra
.663 .71 .882 r
.54736 .44642 .55347 .4543 .56499 .45048 .55891 .44268 Mtetra
.663 .713 .885 r
.55891 .44268 .56499 .45048 .57655 .44665 .5705 .43894 Mtetra
.663 .716 .888 r
.5705 .43894 .57655 .44665 .58817 .44281 .58214 .43519 Mtetra
.664 .72 .891 r
.58214 .43519 .58817 .44281 .59983 .43896 .59383 .43143 Mtetra
.664 .723 .893 r
.59383 .43143 .59983 .43896 .61153 .43509 .60557 .42764 Mtetra
.664 .726 .896 r
.60557 .42764 .61153 .43509 .62329 .43122 .61736 .42383 Mtetra
.665 .729 .898 r
.61736 .42383 .62329 .43122 .63509 .42733 .6292 .41998 Mtetra
.665 .731 .899 r
.6292 .41998 .63509 .42733 .64695 .42344 .64109 .41612 Mtetra
.665 .733 .9 r
.64109 .41612 .64695 .42344 .65885 .41956 .65303 .41224 Mtetra
.664 .734 .902 r
.65303 .41224 .65885 .41956 .67081 .4157 .66502 .40837 Mtetra
.661 .733 .903 r
.66502 .40837 .67081 .4157 .68282 .41197 .67707 .40458 Mtetra
.653 .729 .905 r
.67707 .40458 .68282 .41197 .69491 .40862 .68918 .40102 Mtetra
.631 .716 .908 r
.68918 .40102 .69491 .40862 .70711 .40623 .70138 .39812 Mtetra
.579 .679 .909 r
.70138 .39812 .70711 .40623 .7195 .40599 .71374 .39677 Mtetra
.47 .595 .895 r
.71374 .39677 .7195 .40599 .73222 .40971 .72635 .39843 Mtetra
.302 .45 .843 r
.72635 .39843 .73222 .40971 .74547 .4194 .73939 .40497 Mtetra
.14 .289 .756 r
.73939 .40497 .74547 .4194 .75938 .43611 .75301 .41779 Mtetra
.072 .196 .688 r
.75301 .41779 .75938 .43611 .77392 .45825 .76724 .43636 Mtetra
.123 .201 .673 r
.76724 .43636 .77392 .45825 .78874 .48057 .78187 .45696 Mtetra
.276 .293 .698 r
.78187 .45696 .78874 .48057 .8032 .49533 .79639 .47306 Mtetra
.483 .436 .729 r
.79639 .47306 .8032 .49533 .81665 .49631 .81019 .47839 Mtetra
.662 .574 .746 r
.81019 .47839 .81665 .49631 .829 .48421 .8231 .47227 Mtetra
.723 .674 .802 r
.8231 .47227 .829 .48421 .84114 .47002 .83586 .46428 Mtetra
.029 .441 .871 r
.83586 .46428 .84114 .47002 .85474 .4706 .85009 .47077 Mtetra
.835 .364 .038 r
.85009 .47077 .85474 .4706 .87057 .49161 .8665 .49697 Mtetra
.8 .345 .158 r
.8665 .49697 .87057 .49161 .88647 .51081 .88273 .5186 Mtetra
0 0 0 r
.88273 .5186 .88647 .51081 .89868 .49497 .89482 .50053 Mtetra
.975 .808 .392 r
.89482 .50053 .89868 .49497 .90668 .44338 .90239 .44373 Mtetra
.998 .795 .451 r
.90239 .44373 .90668 .44338 .91389 .38811 .9092 .3839 Mtetra
.829 .354 .006 r
.30777 .53041 .31465 .53522 .32427 .5489 .31729 .54558 Mtetra
.903 .514 .271 r
.31729 .54558 .32427 .5489 .3335 .57219 .32639 .57086 Mtetra
.903 .543 .347 r
.32639 .57086 .3335 .57219 .34261 .60184 .33536 .60241 Mtetra
.881 .512 .339 r
.33536 .60241 .34261 .60184 .35212 .62844 .3448 .62994 Mtetra
.749 .279 .131 r
.3448 .62994 .35212 .62844 .36257 .63993 .35531 .64077 Mtetra
.885 .959 .843 r
.35531 .64077 .36257 .63993 .37413 .62929 .36703 .62811 Mtetra
.943 .803 .676 r
.36703 .62811 .37413 .62929 .38645 .59998 .37955 .59638 Mtetra
.932 .763 .65 r
.37955 .59638 .38645 .59998 .39892 .56322 .3922 .55769 Mtetra
.916 .751 .663 r
.3922 .55769 .39892 .56322 .4111 .53007 .40451 .52344 Mtetra
.889 .751 .702 r
.40451 .52344 .4111 .53007 .42285 .50605 .41634 .49898 Mtetra
.844 .753 .764 r
.41634 .49898 .42285 .50605 .43426 .49104 .42781 .48387 Mtetra
.779 .75 .827 r
.42781 .48387 .43426 .49104 .4455 .48219 .43908 .47503 Mtetra
.718 .739 .868 r
.43908 .47503 .4455 .48219 .45667 .47659 .45029 .46943 Mtetra
.682 .731 .887 r
.45029 .46943 .45667 .47659 .46786 .47235 .4615 .46519 Mtetra
.669 .728 .894 r
.4615 .46519 .46786 .47235 .47908 .46856 .47275 .46139 Mtetra
.665 .727 .896 r
.47275 .46139 .47908 .46856 .49034 .46488 .48404 .4577 Mtetra
.664 .727 .897 r
.48404 .4577 .49034 .46488 .50165 .46122 .49538 .45403 Mtetra
.664 .728 .897 r
.49538 .45403 .50165 .46122 .51301 .45754 .50676 .45036 Mtetra
.663 .729 .898 r
.50676 .45036 .51301 .45754 .52441 .45385 .5182 .44667 Mtetra
.663 .73 .899 r
.5182 .44667 .52441 .45385 .53586 .45014 .52968 .44298 Mtetra
.663 .731 .9 r
.52968 .44298 .53586 .45014 .54736 .44642 .5412 .43929 Mtetra
.662 .732 .902 r
.5412 .43929 .54736 .44642 .55891 .44268 .55278 .43561 Mtetra
.661 .735 .904 r
.55278 .43561 .55891 .44268 .5705 .43894 .56441 .43193 Mtetra
.661 .737 .906 r
.56441 .43193 .5705 .43894 .58214 .43519 .57609 .42825 Mtetra
.661 .74 .909 r
.57609 .42825 .58214 .43519 .59383 .43143 .58781 .42454 Mtetra
.662 .743 .91 r
.58781 .42454 .59383 .43143 .60557 .42764 .59959 .42079 Mtetra
.664 .746 .911 r
.59959 .42079 .60557 .42764 .61736 .42383 .61141 .41698 Mtetra
.665 .747 .911 r
.61141 .41698 .61736 .42383 .6292 .41998 .62329 .4131 Mtetra
.666 .747 .911 r
.62329 .4131 .6292 .41998 .64109 .41612 .63521 .40916 Mtetra
.667 .746 .91 r
.63521 .40916 .64109 .41612 .65303 .41224 .64718 .40521 Mtetra
.666 .745 .909 r
.64718 .40521 .65303 .41224 .66502 .40837 .6592 .40125 Mtetra
.664 .742 .908 r
.6592 .40125 .66502 .40837 .67707 .40458 .67128 .39735 Mtetra
.658 .738 .908 r
.67128 .39735 .67707 .40458 .68918 .40102 .68342 .3936 Mtetra
.644 .728 .91 r
.68342 .3936 .68918 .40102 .70138 .39812 .69564 .39029 Mtetra
.608 .702 .91 r
.69564 .39029 .70138 .39812 .71374 .39677 .70797 .38804 Mtetra
.533 .642 .903 r
.70797 .38804 .71374 .39677 .72635 .39843 .72051 .38797 Mtetra
.405 .531 .871 r
.72051 .38797 .72635 .39843 .73939 .40497 .73337 .39167 Mtetra
.259 .386 .802 r
.73337 .39167 .73939 .40497 .75301 .41779 .74671 .40059 Mtetra
.173 .277 .73 r
.74671 .40059 .75301 .41779 .76724 .43636 .7606 .41498 Mtetra
.189 .249 .695 r
.7606 .41498 .76724 .43636 .78187 .45696 .77495 .43251 Mtetra
.295 .3 .695 r
.77495 .43251 .78187 .45696 .79639 .47306 .78937 .44814 Mtetra
.447 .397 .71 r
.78937 .44814 .79639 .47306 .81019 .47839 .80336 .45623 Mtetra
.579 .496 .725 r
.80336 .45623 .81019 .47839 .8231 .47227 .81673 .45545 Mtetra
.59 .545 .773 r
.81673 .45545 .8231 .47227 .83586 .46428 .83013 .45408 Mtetra
0 .235 .753 r
.83013 .45408 .83586 .46428 .85009 .47077 .84506 .46756 Mtetra
.843 .391 0 r
.84506 .46756 .85009 .47077 .8665 .49697 .86212 .50005 Mtetra
.826 .362 .11 r
.86212 .50005 .8665 .49697 .88273 .5186 .87875 .52488 Mtetra
.625 .808 .384 r
.87875 .52488 .88273 .5186 .89482 .50053 .89077 .50501 Mtetra
.986 .8 .405 r
.89077 .50501 .89482 .50053 .90239 .44373 .89796 .44336 Mtetra
.998 .785 .45 r
.89796 .44336 .90239 .44373 .9092 .3839 .90442 .3793 Mtetra
.853 .395 .067 r
.30082 .5257 .30777 .53041 .31729 .54558 .31024 .54236 Mtetra
.907 .527 .292 r
.31024 .54236 .31729 .54558 .32639 .57086 .31919 .56952 Mtetra
.906 .55 .355 r
.31919 .56952 .32639 .57086 .33536 .60241 .32804 .60275 Mtetra
.884 .515 .339 r
.32804 .60275 .33536 .60241 .3448 .62994 .33743 .63092 Mtetra
.73 .242 .08 r
.33743 .63092 .3448 .62994 .35531 .64077 .348 .64086 Mtetra
.907 .92 .816 r
.348 .64086 .35531 .64077 .36703 .62811 .35989 .62614 Mtetra
.939 .788 .667 r
.35989 .62614 .36703 .62811 .37955 .59638 .37261 .59214 Mtetra
.929 .755 .646 r
.37261 .59214 .37955 .59638 .3922 .55769 .38544 .5518 Mtetra
.914 .747 .66 r
.38544 .5518 .3922 .55769 .40451 .52344 .39787 .51673 Mtetra
.89 .75 .701 r
.39787 .51673 .40451 .52344 .41634 .49898 .40978 .49203 Mtetra
.845 .757 .765 r
.40978 .49203 .41634 .49898 .42781 .48387 .4213 .47694 Mtetra
.78 .757 .832 r
.4213 .47694 .42781 .48387 .43908 .47503 .43261 .46815 Mtetra
.718 .749 .876 r
.43261 .46815 .43908 .47503 .45029 .46943 .44384 .46258 Mtetra
.683 .741 .896 r
.44384 .46258 .45029 .46943 .4615 .46519 .45509 .45834 Mtetra
.669 .738 .902 r
.45509 .45834 .4615 .46519 .47275 .46139 .46636 .45452 Mtetra
.665 .738 .904 r
.46636 .45452 .47275 .46139 .48404 .4577 .47769 .45082 Mtetra
.664 .738 .905 r
.47769 .45082 .48404 .4577 .49538 .45403 .48905 .44713 Mtetra
.663 .738 .905 r
.48905 .44713 .49538 .45403 .50676 .45036 .50047 .44344 Mtetra
.663 .738 .906 r
.50047 .44344 .50676 .45036 .5182 .44667 .51193 .43976 Mtetra
.661 .739 .907 r
.51193 .43976 .5182 .44667 .52968 .44298 .52344 .4361 Mtetra
.66 .74 .909 r
.52344 .4361 .52968 .44298 .5412 .43929 .53501 .43247 Mtetra
.657 .742 .912 r
.53501 .43247 .5412 .43929 .55278 .43561 .54662 .4289 Mtetra
.655 .746 .917 r
.54662 .4289 .55278 .43561 .56441 .43193 .55828 .42538 Mtetra
.653 .751 .921 r
.55828 .42538 .56441 .43193 .57609 .42825 .56999 .42187 Mtetra
.654 .758 .926 r
.56999 .42187 .57609 .42825 .58781 .42454 .58176 .41831 Mtetra
.657 .764 .929 r
.58176 .41831 .58781 .42454 .59959 .42079 .59357 .41463 Mtetra
.662 .769 .929 r
.59357 .41463 .59959 .42079 .61141 .41698 .60543 .41079 Mtetra
.668 .771 .927 r
.60543 .41079 .61141 .41698 .62329 .4131 .61734 .40678 Mtetra
.671 .769 .923 r
.61734 .40678 .62329 .4131 .63521 .40916 .62929 .40265 Mtetra
.673 .764 .919 r
.62929 .40265 .63521 .40916 .64718 .40521 .6413 .39847 Mtetra
.671 .757 .915 r
.6413 .39847 .64718 .40521 .6592 .40125 .65335 .39431 Mtetra
.669 .751 .912 r
.65335 .39431 .6592 .40125 .67128 .39735 .66546 .39023 Mtetra
.664 .745 .911 r
.66546 .39023 .67128 .39735 .68342 .3936 .67762 .38628 Mtetra
.653 .736 .91 r
.67762 .38628 .68342 .3936 .69564 .39029 .68986 .38264 Mtetra
.63 .718 .91 r
.68986 .38264 .69564 .39029 .70797 .38804 .70219 .37971 Mtetra
.579 .677 .907 r
.70219 .37971 .70797 .38804 .72051 .38797 .71467 .37828 Mtetra
.488 .596 .888 r
.71467 .37828 .72051 .38797 .73337 .39167 .7274 .37959 Mtetra
.366 .476 .839 r
.7274 .37959 .73337 .39167 .74671 .40059 .74051 .38501 Mtetra
.272 .362 .773 r
.74051 .38501 .74671 .40059 .7606 .41498 .75408 .39516 Mtetra
.257 .307 .723 r
.75408 .39516 .7606 .41498 .77495 .43251 .76809 .40888 Mtetra
.321 .322 .705 r
.76809 .40888 .77495 .43251 .78937 .44814 .78231 .42261 Mtetra
.429 .383 .704 r
.78231 .42261 .78937 .44814 .80336 .45623 .79635 .43178 Mtetra
.52 .446 .714 r
.79635 .43178 .80336 .45623 .81673 .45545 .81004 .43512 Mtetra
.478 .448 .746 r
.81004 .43512 .81673 .45545 .83013 .45408 .82401 .44003 Mtetra
0 .091 .646 r
.82401 .44003 .83013 .45408 .84506 .46756 .83964 .46091 Mtetra
.833 .41 0 r
.83964 .46091 .84506 .46756 .86212 .50005 .8574 .50037 Mtetra
.843 .378 .05 r
.8574 .50037 .86212 .50005 .87875 .52488 .87447 .52903 Mtetra
.808 .919 .531 r
.87447 .52903 .87875 .52488 .89077 .50501 .88648 .50793 Mtetra
.994 .792 .42 r
.88648 .50793 .89077 .50501 .89796 .44336 .89335 .442 Mtetra
.998 .777 .453 r
.89335 .442 .89796 .44336 .90442 .3793 .89954 .3742 Mtetra
.869 .425 .11 r
.29382 .52098 .30082 .5257 .31024 .54236 .30313 .53906 Mtetra
.911 .537 .306 r
.30313 .53906 .31024 .54236 .31919 .56952 .31194 .56794 Mtetra
.909 .556 .359 r
.31194 .56794 .31919 .56952 .32804 .60275 .32066 .60256 Mtetra
.888 .518 .333 r
.32066 .60256 .32804 .60275 .33743 .63092 .33002 .63104 Mtetra
.697 .178 0 r
.33002 .63104 .33743 .63092 .348 .64086 .34067 .63984 Mtetra
.912 .877 .788 r
.34067 .63984 .348 .64086 .35989 .62614 .35273 .62303 Mtetra
.932 .773 .661 r
.35273 .62303 .35989 .62614 .37261 .59214 .36565 .58697 Mtetra
.924 .746 .643 r
.36565 .58697 .37261 .59214 .38544 .5518 .37865 .5453 Mtetra
.911 .741 .659 r
.37865 .5453 .38544 .5518 .39787 .51673 .3912 .50971 Mtetra
.887 .747 .701 r
.3912 .50971 .39787 .51673 .40978 .49203 .40318 .48497 Mtetra
.843 .756 .766 r
.40318 .48497 .40978 .49203 .4213 .47694 .41474 .46999 Mtetra
.778 .758 .834 r
.41474 .46999 .4213 .47694 .43261 .46815 .42608 .4613 Mtetra
.717 .751 .879 r
.42608 .4613 .43261 .46815 .44384 .46258 .43735 .45578 Mtetra
.682 .744 .898 r
.43735 .45578 .44384 .46258 .45509 .45834 .44862 .45154 Mtetra
.668 .741 .905 r
.44862 .45154 .45509 .45834 .46636 .45452 .45993 .44771 Mtetra
.664 .741 .907 r
.45993 .44771 .46636 .45452 .47769 .45082 .47128 .44398 Mtetra
.663 .74 .907 r
.47128 .44398 .47769 .45082 .48905 .44713 .48268 .44028 Mtetra
.662 .741 .908 r
.48268 .44028 .48905 .44713 .50047 .44344 .49413 .43659 Mtetra
.66 .741 .91 r
.49413 .43659 .50047 .44344 .51193 .43976 .50562 .43295 Mtetra
.657 .742 .913 r
.50562 .43295 .51193 .43976 .52344 .4361 .51716 .42939 Mtetra
.651 .744 .918 r
.51716 .42939 .52344 .4361 .53501 .43247 .52876 .42597 Mtetra
.644 .749 .926 r
.52876 .42597 .53501 .43247 .54662 .4289 .5404 .42271 Mtetra
.636 .758 .936 r
.5404 .42271 .54662 .4289 .55828 .42538 .5521 .41961 Mtetra
.631 .772 .948 r
.5521 .41961 .55828 .42538 .56999 .42187 .56386 .41656 Mtetra
.631 .789 .958 r
.56386 .41656 .56999 .42187 .58176 .41831 .57567 .41338 Mtetra
.64 .807 .963 r
.57567 .41338 .58176 .41831 .59357 .41463 .58753 .40989 Mtetra
.655 .82 .962 r
.58753 .40989 .59357 .41463 .60543 .41079 .59943 .40597 Mtetra
.672 .823 .956 r
.59943 .40597 .60543 .41079 .61734 .40678 .61137 .40164 Mtetra
.684 .815 .946 r
.61137 .40164 .61734 .40678 .62929 .40265 .62336 .39703 Mtetra
.688 .8 .935 r
.62336 .39703 .62929 .40265 .6413 .39847 .63539 .39234 Mtetra
.685 .783 .925 r
.63539 .39234 .6413 .39847 .65335 .39431 .64746 .38773 Mtetra
.679 .768 .918 r
.64746 .38773 .65335 .39431 .66546 .39023 .6596 .38329 Mtetra
.671 .755 .913 r
.6596 .38329 .66546 .39023 .67762 .38628 .67179 .37907 Mtetra
.662 .744 .911 r
.67179 .37907 .67762 .38628 .68986 .38264 .68405 .37513 Mtetra
.646 .73 .91 r
.68405 .37513 .68986 .38264 .70219 .37971 .69638 .37168 Mtetra
.612 .702 .908 r
.69638 .37168 .70219 .37971 .71467 .37828 .70884 .36924 Mtetra
.55 .647 .898 r
.70884 .36924 .71467 .37828 .7274 .37959 .72148 .3687 Mtetra
.457 .554 .866 r
.72148 .3687 .7274 .37959 .74051 .38501 .73441 .37118 Mtetra
.366 .447 .812 r
.73441 .37118 .74051 .38501 .75408 .39516 .7477 .3775 Mtetra
.327 .373 .757 r
.7477 .3775 .75408 .39516 .76809 .40888 .7614 .38724 Mtetra
.356 .358 .724 r
.7614 .38724 .76809 .40888 .78231 .42261 .77535 .39816 Mtetra
.426 .386 .711 r
.77535 .39816 .78231 .42261 .79635 .43178 .78931 .40698 Mtetra
.477 .417 .711 r
.78931 .40698 .79635 .43178 .81004 .43512 .8032 .41298 Mtetra
.38 .373 .726 r
.8032 .41298 .81004 .43512 .82401 .44003 .81762 .42325 Mtetra
0 0 .559 r
.81762 .42325 .82401 .44003 .83964 .46091 .83389 .45122 Mtetra
.821 .426 0 r
.83389 .45122 .83964 .46091 .8574 .50037 .85233 .49779 Mtetra
.844 .389 0 r
.85233 .49779 .8574 .50037 .87447 .52903 .86985 .53062 Mtetra
.922 .961 .646 r
.86985 .53062 .87447 .52903 .88648 .50793 .88191 .50885 Mtetra
.997 .783 .437 r
.88191 .50885 .88648 .50793 .89335 .442 .88856 .43938 Mtetra
.997 .769 .458 r
.88856 .43938 .89335 .442 .89954 .3742 .89454 .36848 Mtetra
.88 .448 .142 r
.28675 .51619 .29382 .52098 .30313 .53906 .29596 .53558 Mtetra
.914 .546 .315 r
.29596 .53558 .30313 .53906 .31194 .56794 .30464 .56596 Mtetra
.912 .561 .36 r
.30464 .56596 .31194 .56794 .32066 .60256 .31325 .60165 Mtetra
.893 .519 .322 r
.31325 .60165 .32066 .60256 .33002 .63104 .32258 .63006 Mtetra
.627 .067 0 r
.32258 .63006 .33002 .63104 .34067 .63984 .33333 .6375 Mtetra
.909 .837 .763 r
.33333 .6375 .34067 .63984 .35273 .62303 .34557 .61863 Mtetra
.925 .758 .656 r
.34557 .61863 .35273 .62303 .36565 .58697 .35868 .58078 Mtetra
.919 .738 .641 r
.35868 .58078 .36565 .58697 .37865 .5453 .37183 .53813 Mtetra
.907 .735 .658 r
.37183 .53813 .37865 .5453 .3912 .50971 .38448 .5023 Mtetra
.884 .743 .701 r
.38448 .5023 .3912 .50971 .40318 .48497 .39653 .47772 Mtetra
.84 .753 .768 r
.39653 .47772 .40318 .48497 .41474 .46999 .40813 .46296 Mtetra
.775 .756 .836 r
.40813 .46296 .41474 .46999 .42608 .4613 .41951 .45441 Mtetra
.715 .75 .88 r
.41951 .45441 .42608 .4613 .43735 .45578 .43081 .44895 Mtetra
.681 .745 .899 r
.43081 .44895 .43735 .45578 .44862 .45154 .44211 .44471 Mtetra
.668 .742 .906 r
.44211 .44471 .44862 .45154 .45993 .44771 .45345 .44087 Mtetra
.664 .741 .908 r
.45345 .44087 .45993 .44771 .47128 .44398 .46483 .43712 Mtetra
.662 .741 .909 r
.46483 .43712 .47128 .44398 .48268 .44028 .47626 .43342 Mtetra
.66 .741 .91 r
.47626 .43342 .48268 .44028 .49413 .43659 .48773 .42978 Mtetra
.655 .742 .914 r
.48773 .42978 .49413 .43659 .50562 .43295 .49926 .42626 Mtetra
.646 .744 .921 r
.49926 .42626 .50562 .43295 .51716 .42939 .51083 .42298 Mtetra
.63 .749 .933 r
.51083 .42298 .51716 .42939 .52876 .42597 .52246 .42007 Mtetra
.607 .759 .952 r
.52246 .42007 .52876 .42597 .5404 .42271 .53414 .41758 Mtetra
.576 .777 .974 r
.53414 .41758 .5404 .42271 .5521 .41961 .54589 .41547 Mtetra
.543 .804 .994 r
.54589 .41547 .5521 .41961 .56386 .41656 .5577 .41346 Mtetra
.523 .837 .999 r
.5577 .41346 .56386 .41656 .57567 .41338 .56956 .41113 Mtetra
.536 .872 .991 r
.56956 .41113 .57567 .41338 .58753 .40989 .58148 .40802 Mtetra
.587 .904 .982 r
.58148 .40802 .58753 .40989 .59943 .40597 .59344 .40391 Mtetra
.653 .92 .977 r
.59344 .40391 .59943 .40597 .61137 .40164 .60542 .39884 Mtetra
.7 .907 .968 r
.60542 .39884 .61137 .40164 .62336 .39703 .61742 .39318 Mtetra
.718 .874 .954 r
.61742 .39318 .62336 .39703 .63539 .39234 .62946 .38739 Mtetra
.714 .834 .939 r
.62946 .38739 .63539 .39234 .64746 .38773 .64155 .38184 Mtetra
.7 .798 .926 r
.64155 .38184 .64746 .38773 .6596 .38329 .6537 .37671 Mtetra
.685 .772 .917 r
.6537 .37671 .6596 .38329 .67179 .37907 .66591 .37202 Mtetra
.672 .755 .913 r
.66591 .37202 .67179 .37907 .68405 .37513 .67819 .36773 Mtetra
.658 .74 .91 r
.67819 .36773 .68405 .37513 .69638 .37168 .69055 .36388 Mtetra
.635 .72 .909 r
.69055 .36388 .69638 .37168 .70884 .36924 .703 .36071 Mtetra
.594 .683 .903 r
.703 .36071 .70884 .36924 .72148 .3687 .71559 .35881 Mtetra
.528 .617 .884 r
.71559 .35881 .72148 .3687 .73441 .37118 .72839 .35902 Mtetra
.45 .527 .844 r
.72839 .35902 .73441 .37118 .7477 .3775 .74147 .36212 Mtetra
.399 .446 .793 r
.74147 .36212 .7477 .3775 .7614 .38724 .75489 .36817 Mtetra
.398 .406 .751 r
.75489 .36817 .7614 .38724 .77535 .39816 .76857 .37595 Mtetra
.434 .405 .727 r
.76857 .37595 .77535 .39816 .78931 .40698 .78239 .38341 Mtetra
.447 .405 .718 r
.78239 .38341 .78931 .40698 .8032 .41298 .79635 .3907 Mtetra
.287 .311 .712 r
.79635 .3907 .8032 .41298 .81762 .42325 .81109 .40505 Mtetra
0 0 .479 r
.81109 .40505 .81762 .42325 .83389 .45122 .8279 .43925 Mtetra
.818 .443 0 r
.8279 .43925 .83389 .45122 .85233 .49779 .84694 .49245 Mtetra
.832 .394 0 r
.84694 .49245 .85233 .49779 .86985 .53062 .86488 .52943 Mtetra
.959 .94 .71 r
.86488 .52943 .86985 .53062 .88191 .50885 .87702 .50747 Mtetra
.997 .774 .454 r
.87702 .50747 .88191 .50885 .88856 .43938 .88354 .43529 Mtetra
.994 .761 .464 r
.88354 .43529 .88856 .43938 .89454 .36848 .88942 .36204 Mtetra
.889 .465 .165 r
.27963 .51129 .28675 .51619 .29596 .53558 .28873 .53185 Mtetra
.917 .552 .321 r
.28873 .53185 .29596 .53558 .30464 .56596 .29729 .56346 Mtetra
.916 .565 .357 r
.29729 .56346 .30464 .56596 .31325 .60165 .30581 .59984 Mtetra
.897 .518 .306 r
.30581 .59984 .31325 .60165 .32258 .63006 .31514 .62783 Mtetra
.473 0 0 r
.31514 .62783 .32258 .63006 .33333 .6375 .326 .6337 Mtetra
.901 .803 .742 r
.326 .6337 .33333 .6375 .34557 .61863 .33841 .61286 Mtetra
.918 .744 .652 r
.33841 .61286 .34557 .61863 .35868 .58078 .3517 .57352 Mtetra
.913 .73 .64 r
.3517 .57352 .35868 .58078 .37183 .53813 .36499 .53027 Mtetra
.902 .73 .658 r
.36499 .53027 .37183 .53813 .38448 .5023 .37774 .49452 Mtetra
.88 .739 .702 r
.37774 .49452 .38448 .5023 .39653 .47772 .38984 .47028 Mtetra
.836 .751 .77 r
.38984 .47028 .39653 .47772 .40813 .46296 .40148 .45583 Mtetra
.771 .755 .838 r
.40148 .45583 .40813 .46296 .41951 .45441 .41288 .44746 Mtetra
.712 .75 .881 r
.41288 .44746 .41951 .45441 .43081 .44895 .42421 .44207 Mtetra
.68 .744 .9 r
.42421 .44207 .43081 .44895 .44211 .44471 .43555 .43784 Mtetra
.667 .742 .906 r
.43555 .43784 .44211 .44471 .45345 .44087 .44691 .43398 Mtetra
.663 .741 .908 r
.44691 .43398 .45345 .44087 .46483 .43712 .45832 .43023 Mtetra
.66 .741 .91 r
.45832 .43023 .46483 .43712 .47626 .43342 .46978 .42656 Mtetra
.655 .741 .913 r
.46978 .42656 .47626 .43342 .48773 .42978 .48129 .42304 Mtetra
.643 .742 .921 r
.48129 .42304 .48773 .42978 .49926 .42626 .49284 .41983 Mtetra
.619 .745 .936 r
.49284 .41983 .49926 .42626 .51083 .42298 .50444 .41717 Mtetra
.573 .751 .962 r
.50444 .41717 .51083 .42298 .52246 .42007 .5161 .41533 Mtetra
.487 .758 .99 r
.5161 .41533 .52246 .42007 .53414 .41758 .52782 .41445 Mtetra
.332 .743 .979 r
.52782 .41445 .53414 .41758 .54589 .41547 .53962 .41433 Mtetra
.12 .661 .842 r
.53962 .41433 .54589 .41547 .5577 .41346 .5515 .41438 Mtetra
.015 0 0 r
.5515 .41438 .5577 .41346 .56956 .41113 .56345 .41366 Mtetra
0 0 0 r
.56345 .41366 .56956 .41113 .58148 .40802 .57545 .41122 Mtetra
.57545 .41122 .58148 .40802 .59344 .40391 .58746 .4066 Mtetra
.402 .834 .687 r
.58746 .4066 .59344 .40391 .60542 .39884 .59948 .40002 Mtetra
.634 .964 .846 r
.59948 .40002 .60542 .39884 .61742 .39318 .61151 .39229 Mtetra
.748 .973 .926 r
.61151 .39229 .61742 .39318 .62946 .38739 .62355 .38439 Mtetra
.762 .913 .941 r
.62355 .38439 .62946 .38739 .64155 .38184 .63563 .37708 Mtetra
.738 .848 .932 r
.63563 .37708 .64155 .38184 .6537 .37671 .64778 .37071 Mtetra
.709 .8 .921 r
.64778 .37071 .6537 .37671 .66591 .37202 .66001 .36524 Mtetra
.686 .769 .914 r
.66001 .36524 .66591 .37202 .67819 .36773 .67231 .36047 Mtetra
.669 .749 .911 r
.67231 .36047 .67819 .36773 .69055 .36388 .68468 .35623 Mtetra
.651 .732 .909 r
.68468 .35623 .69055 .36388 .703 .36071 .69714 .35254 Mtetra
.624 .707 .906 r
.69714 .35254 .703 .36071 .71559 .35881 .70971 .3497 Mtetra
.579 .663 .895 r
.70971 .3497 .71559 .35881 .72839 .35902 .72243 .34825 Mtetra
.52 .595 .869 r
.72243 .34825 .72839 .35902 .74147 .36212 .73537 .34885 Mtetra
.467 .519 .828 r
.73537 .34885 .74147 .36212 .75489 .36817 .74856 .35179 Mtetra
.446 .464 .784 r
.74856 .35179 .75489 .36817 .76857 .37595 .76201 .35653 Mtetra
.451 .437 .752 r
.76201 .35653 .76857 .37595 .78239 .38341 .77565 .36208 Mtetra
.425 .406 .735 r
.77565 .36208 .78239 .38341 .79635 .3907 .7896 .36957 Mtetra
.191 .257 .702 r
.7896 .36957 .79635 .3907 .81109 .40505 .80454 .3867 Mtetra
0 0 .4 r
.80454 .3867 .81109 .40505 .8279 .43925 .82175 .4259 Mtetra
.825 .461 0 r
.82175 .4259 .8279 .43925 .84694 .49245 .84127 .48477 Mtetra
.815 .396 0 r
.84127 .48477 .84694 .49245 .86488 .52943 .85957 .52544 Mtetra
.951 .891 .735 r
.85957 .52544 .86488 .52943 .87702 .50747 .87182 .50362 Mtetra
.995 .764 .469 r
.87182 .50362 .87702 .50747 .88354 .43529 .87831 .4296 Mtetra
.991 .754 .472 r
.87831 .4296 .88354 .43529 .88942 .36204 .88417 .35482 Mtetra
.895 .478 .181 r
.27246 .50624 .27963 .51129 .28873 .53185 .28146 .5278 Mtetra
.92 .557 .323 r
.28146 .5278 .28873 .53185 .29729 .56346 .28991 .56035 Mtetra
.919 .568 .352 r
.28991 .56035 .29729 .56346 .30581 .59984 .29836 .59702 Mtetra
.901 .514 .282 r
.29836 .59702 .30581 .59984 .31514 .62783 .30771 .62421 Mtetra
0 .387 .745 r
.30771 .62421 .31514 .62783 .326 .6337 .31868 .62836 Mtetra
.892 .774 .724 r
.31868 .62836 .326 .6337 .33841 .61286 .33127 .60568 Mtetra
.91 .732 .649 r
.33127 .60568 .33841 .61286 .3517 .57352 .34473 .56521 Mtetra
.908 .722 .64 r
.34473 .56521 .3517 .57352 .36499 .53027 .35814 .52174 Mtetra
.898 .725 .659 r
.35814 .52174 .36499 .53027 .37774 .49452 .37095 .48638 Mtetra
.875 .735 .704 r
.37095 .48638 .37774 .49452 .38984 .47028 .3831 .46266 Mtetra
.831 .748 .773 r
.3831 .46266 .38984 .47028 .40148 .45583 .39477 .4486 Mtetra
.767 .753 .84 r
.39477 .4486 .40148 .45583 .41288 .44746 .40621 .44045 Mtetra
.709 .749 .883 r
.40621 .44045 .41288 .44746 .42421 .44207 .41757 .43513 Mtetra
.678 .744 .9 r
.41757 .43513 .42421 .44207 .43555 .43784 .42893 .43091 Mtetra
.667 .742 .906 r
.42893 .43091 .43555 .43784 .44691 .43398 .44033 .42705 Mtetra
.662 .741 .909 r
.44033 .42705 .44691 .43398 .45832 .43023 .45177 .42332 Mtetra
.656 .741 .912 r
.45177 .42332 .45832 .43023 .46978 .42656 .46326 .41973 Mtetra
.644 .741 .919 r
.46326 .41973 .46978 .42656 .48129 .42304 .47479 .41647 Mtetra
.617 .741 .934 r
.47479 .41647 .48129 .42304 .49284 .41983 .48637 .41385 Mtetra
.557 .74 .962 r
.48637 .41385 .49284 .41983 .50444 .41717 .49799 .41236 Mtetra
.412 .721 .988 r
.49799 .41236 .50444 .41717 .5161 .41533 .50968 .41248 Mtetra
.072 .588 .881 r
.50968 .41248 .5161 .41533 .52782 .41445 .52144 .41444 Mtetra
.347 0 0 r
.52144 .41444 .52782 .41445 .53962 .41433 .5333 .41783 Mtetra
.499 0 0 r
.5333 .41783 .53962 .41433 .5515 .41438 .54526 .42141 Mtetra
.486 .016 .064 r
.54526 .42141 .5515 .41438 .56345 .41366 .55732 .42333 Mtetra
.395 0 .1 r
.55732 .42333 .56345 .41366 .57545 .41122 .56942 .42183 Mtetra
.235 0 .047 r
.56942 .42183 .57545 .41122 .58746 .4066 .58153 .41612 Mtetra
0 0 0 r
.58153 .41612 .58746 .4066 .59948 .40002 .59359 .40678 Mtetra
.59359 .40678 .59948 .40002 .61151 .39229 .60562 .39543 Mtetra
.7 .964 .721 r
.60562 .39543 .61151 .39229 .62355 .38439 .61764 .38398 Mtetra
.815 .986 .883 r
.61764 .38398 .62355 .38439 .63563 .37708 .6297 .3738 Mtetra
.793 .908 .92 r
.6297 .3738 .63563 .37708 .64778 .37071 .64184 .36543 Mtetra
.744 .835 .92 r
.64184 .36543 .64778 .37071 .66001 .36524 .65406 .35876 Mtetra
.705 .787 .915 r
.65406 .35876 .66001 .36524 .67231 .36047 .66638 .35333 Mtetra
.68 .759 .911 r
.66638 .35333 .67231 .36047 .68468 .35623 .67877 .3487 Mtetra
.662 .742 .909 r
.67877 .3487 .68468 .35623 .69714 .35254 .69125 .34461 Mtetra
.643 .724 .907 r
.69125 .34461 .69714 .35254 .70971 .3497 .70382 .34113 Mtetra
.614 .695 .901 r
.70382 .34113 .70971 .3497 .72243 .34825 .7165 .33855 Mtetra
.573 .647 .886 r
.7165 .33855 .72243 .34825 .73537 .34885 .72935 .33733 Mtetra
.527 .585 .856 r
.72935 .33733 .73537 .34885 .74856 .35179 .74239 .33783 Mtetra
.496 .526 .818 r
.74239 .33783 .74856 .35179 .76201 .35653 .75565 .33994 Mtetra
.477 .481 .783 r
.75565 .33994 .76201 .35653 .77565 .36208 .76913 .34347 Mtetra
.409 .419 .759 r
.76913 .34347 .77565 .36208 .7896 .36957 .78301 .35044 Mtetra
.086 .204 .691 r
.78301 .35044 .7896 .36957 .80454 .3867 .79806 .36919 Mtetra
0 0 .321 r
.79806 .36919 .80454 .3867 .82175 .4259 .81553 .41202 Mtetra
.838 .478 0 r
.81553 .41202 .82175 .4259 .84127 .48477 .83538 .47526 Mtetra
.8 .397 0 r
.83538 .47526 .84127 .48477 .85957 .52544 .85395 .51884 Mtetra
.925 .839 .74 r
.85395 .51884 .85957 .52544 .87182 .50362 .86631 .49731 Mtetra
.99 .754 .483 r
.86631 .49731 .87182 .50362 .87831 .4296 .87285 .42227 Mtetra
.988 .747 .48 r
.87285 .42227 .87831 .4296 .88417 .35482 .87878 .34679 Mtetra
.899 .487 .191 r
.26524 .501 .27246 .50624 .28146 .5278 .27415 .52337 Mtetra
.923 .561 .322 r
.27415 .52337 .28146 .5278 .28991 .56035 .28251 .55652 Mtetra
.923 .569 .343 r
.28251 .55652 .28991 .56035 .29836 .59702 .29091 .59307 Mtetra
.903 .507 .249 r
.29091 .59307 .29836 .59702 .30771 .62421 .3003 .61912 Mtetra
.198 .602 .946 r
.3003 .61912 .30771 .62421 .31868 .62836 .3114 .62144 Mtetra
.883 .75 .711 r
.3114 .62144 .31868 .62836 .33127 .60568 .32416 .59711 Mtetra
.903 .722 .647 r
.32416 .59711 .33127 .60568 .34473 .56521 .33776 .55589 Mtetra
.902 .716 .64 r
.33776 .55589 .34473 .56521 .35814 .52174 .35127 .51261 Mtetra
.893 .72 .661 r
.35127 .51261 .35814 .52174 .37095 .48638 .36414 .47791 Mtetra
.87 .732 .707 r
.36414 .47791 .37095 .48638 .3831 .46266 .37632 .45488 Mtetra
.826 .746 .776 r
.37632 .45488 .3831 .46266 .39477 .4486 .38802 .44129 Mtetra
.762 .752 .843 r
.38802 .44129 .39477 .4486 .40621 .44045 .39948 .43338 Mtetra
.706 .748 .884 r
.39948 .43338 .40621 .44045 .41757 .43513 .41087 .42814 Mtetra
.677 .744 .901 r
.41087 .42814 .41757 .43513 .42893 .43091 .42226 .42394 Mtetra
.666 .742 .907 r
.42226 .42394 .42893 .43091 .44033 .42705 .43369 .42008 Mtetra
.659 .741 .91 r
.43369 .42008 .44033 .42705 .45177 .42332 .44516 .41639 Mtetra
.65 .74 .916 r
.44516 .41639 .45177 .42332 .46326 .41973 .45667 .41297 Mtetra
.626 .738 .928 r
.45667 .41297 .46326 .41973 .47479 .41647 .46823 .41014 Mtetra
.569 .733 .953 r
.46823 .41014 .47479 .41647 .48637 .41385 .47983 .4085 Mtetra
.414 .703 .981 r
.47983 .4085 .48637 .41385 .49799 .41236 .49147 .40887 Mtetra
0 .507 .848 r
.49147 .40887 .49799 .41236 .50968 .41248 .50317 .41209 Mtetra
.534 0 0 r
.50317 .41209 .50968 .41248 .52144 .41444 .51496 .41845 Mtetra
.673 .188 .091 r
.51496 .41845 .52144 .41444 .5333 .41783 .52688 .42715 Mtetra
.66 .243 .243 r
.52688 .42715 .5333 .41783 .54526 .42141 .53895 .43594 Mtetra
.596 .22 .299 r
.53895 .43594 .54526 .42141 .55732 .42333 .55114 .44157 Mtetra
.493 .143 .3 r
.55114 .44157 .55732 .42333 .56942 .42183 .56339 .44111 Mtetra
.337 .008 .251 r
.56339 .44111 .56942 .42183 .58153 .41612 .5756 .43339 Mtetra
.104 0 .129 r
.5756 .43339 .58153 .41612 .59359 .40678 .58772 .41965 Mtetra
0 0 0 r
.58772 .41965 .59359 .40678 .60562 .39543 .59975 .40285 Mtetra
.63 .849 .466 r
.59975 .40285 .60562 .39543 .61764 .38398 .61174 .38621 Mtetra
.85 .995 .759 r
.61174 .38621 .61764 .38398 .6297 .3738 .62376 .37195 Mtetra
.853 .95 .878 r
.62376 .37195 .6297 .3738 .64184 .36543 .63586 .36084 Mtetra
.787 .865 .907 r
.63586 .36084 .64184 .36543 .65406 .35876 .64808 .35256 Mtetra
.729 .803 .91 r
.64808 .35256 .65406 .35876 .66638 .35333 .6604 .34629 Mtetra
.692 .768 .909 r
.6604 .34629 .66638 .35333 .67877 .3487 .67282 .34121 Mtetra
.671 .748 .909 r
.67282 .34121 .67877 .3487 .69125 .34461 .68532 .33682 Mtetra
.655 .734 .908 r
.68532 .33682 .69125 .34461 .70382 .34113 .69791 .33291 Mtetra
.636 .716 .905 r
.69791 .33291 .70382 .34113 .7165 .33855 .71058 .32959 Mtetra
.609 .685 .896 r
.71058 .32959 .7165 .33855 .72935 .33733 .72338 .32714 Mtetra
.575 .64 .877 r
.72338 .32714 .72935 .33733 .74239 .33783 .73633 .32587 Mtetra
.543 .587 .848 r
.73633 .32587 .74239 .33783 .75565 .33994 .74945 .32589 Mtetra
.507 .533 .818 r
.74945 .32589 .75565 .33994 .76913 .34347 .7628 .32756 Mtetra
.398 .443 .791 r
.7628 .32756 .76913 .34347 .78301 .35044 .7766 .33366 Mtetra
0 .152 .676 r
.7766 .33366 .78301 .35044 .79806 .36919 .79168 .35313 Mtetra
.67 .335 0 r
.79168 .35313 .79806 .36919 .81553 .41202 .80929 .39828 Mtetra
.853 .492 0 r
.80929 .39828 .81553 .41202 .83538 .47526 .82934 .46443 Mtetra
.787 .395 0 r
.82934 .46443 .83538 .47526 .85395 .51884 .84806 .5099 Mtetra
.899 .794 .736 r
.84806 .5099 .85395 .51884 .86631 .49731 .86052 .48863 Mtetra
.983 .744 .494 r
.86052 .48863 .86631 .49731 .87285 .42227 .86718 .41334 Mtetra
.984 .741 .489 r
.86718 .41334 .87285 .42227 .87878 .34679 .87328 .33797 Mtetra
.902 .493 .196 r
.25797 .49555 .26524 .501 .27415 .52337 .26681 .51849 Mtetra
.925 .563 .318 r
.26681 .51849 .27415 .52337 .28251 .55652 .27509 .5519 Mtetra
.926 .57 .331 r
.27509 .5519 .28251 .55652 .29091 .59307 .28347 .58792 Mtetra
.902 .493 .202 r
.28347 .58792 .29091 .59307 .3003 .61912 .29292 .6125 Mtetra
.448 .678 .962 r
.29292 .6125 .3003 .61912 .3114 .62144 .30416 .61293 Mtetra
.875 .731 .7 r
.30416 .61293 .3114 .62144 .32416 .59711 .31707 .5872 Mtetra
.896 .712 .646 r
.31707 .5872 .32416 .59711 .33776 .55589 .3308 .54563 Mtetra
.897 .71 .641 r
.3308 .54563 .33776 .55589 .35127 .51261 .34438 .50292 Mtetra
.888 .716 .663 r
.34438 .50292 .35127 .51261 .36414 .47791 .35729 .46916 Mtetra
.865 .73 .711 r
.35729 .46916 .36414 .47791 .37632 .45488 .3695 .44696 Mtetra
.82 .745 .781 r
.3695 .44696 .37632 .45488 .38802 .44129 .38122 .43391 Mtetra
.757 .75 .847 r
.38122 .43391 .38802 .44129 .39948 .43338 .39271 .42624 Mtetra
.703 .747 .886 r
.39271 .42624 .39948 .43338 .41087 .42814 .40412 .4211 Mtetra
.675 .743 .902 r
.40412 .4211 .41087 .42814 .42226 .42394 .41554 .41692 Mtetra
.664 .741 .908 r
.41554 .41692 .42226 .42394 .43369 .42008 .427 .41307 Mtetra
.656 .74 .912 r
.427 .41307 .43369 .42008 .44516 .41639 .4385 .40945 Mtetra
.64 .738 .92 r
.4385 .40945 .44516 .41639 .45667 .41297 .45004 .40628 Mtetra
.598 .733 .939 r
.45004 .40628 .45667 .41297 .46823 .41014 .46161 .40408 Mtetra
.483 .709 .97 r
.46161 .40408 .46823 .41014 .47983 .4085 .47321 .4038 Mtetra
.127 .565 .922 r
.47321 .4038 .47983 .4085 .49147 .40887 .48485 .40673 Mtetra
.517 0 0 r
.48485 .40673 .49147 .40887 .50317 .41209 .49656 .41409 Mtetra
.744 .258 .086 r
.49656 .41409 .50317 .41209 .51496 .41845 .50837 .42627 Mtetra
.754 .345 .275 r
.50837 .42627 .51496 .41845 .52688 .42715 .52034 .44184 Mtetra
.712 .344 .351 r
.52034 .44184 .52688 .42715 .53895 .43594 .53252 .45716 Mtetra
.637 .295 .376 r
.53252 .45716 .53895 .43594 .55114 .44157 .54486 .46718 Mtetra
.52 .2 .366 r
.54486 .46718 .55114 .44157 .56339 .44111 .55726 .46749 Mtetra
.339 .044 .31 r
.55726 .46749 .56339 .44111 .5756 .43339 .5696 .45663 Mtetra
.064 0 .18 r
.5696 .45663 .5756 .43339 .58772 .41965 .58179 .43689 Mtetra
0 0 0 r
.58179 .43689 .58772 .41965 .59975 .40285 .59383 .41304 Mtetra
.7 .831 .39 r
.59383 .41304 .59975 .40285 .61174 .38621 .60578 .38997 Mtetra
.901 .973 .672 r
.60578 .38997 .61174 .38621 .62376 .37195 .61776 .37083 Mtetra
.903 .952 .823 r
.61776 .37083 .62376 .37195 .63586 .36084 .62984 .35653 Mtetra
.827 .877 .881 r
.62984 .35653 .63586 .36084 .64808 .35256 .64205 .34643 Mtetra
.753 .813 .9 r
.64205 .34643 .64808 .35256 .6604 .34629 .65438 .33923 Mtetra
.704 .773 .905 r
.65438 .33923 .6604 .34629 .67282 .34121 .66682 .33372 Mtetra
.677 .752 .907 r
.66682 .33372 .67282 .34121 .68532 .33682 .67935 .32908 Mtetra
.662 .74 .908 r
.67935 .32908 .68532 .33682 .69791 .33291 .69196 .32491 Mtetra
.649 .729 .907 r
.69196 .32491 .69791 .33291 .71058 .32959 .70465 .32114 Mtetra
.632 .71 .903 r
.70465 .32114 .71058 .32959 .72338 .32714 .71744 .3179 Mtetra
.609 .68 .892 r
.71744 .3179 .72338 .32714 .73633 .32587 .73034 .31541 Mtetra
.582 .639 .873 r
.73034 .31541 .73633 .32587 .74945 .32589 .74338 .3139 Mtetra
.537 .586 .851 r
.74338 .3139 .74945 .32589 .7628 .32756 .75663 .31405 Mtetra
.391 .475 .826 r
.75663 .31405 .7628 .32756 .7766 .33366 .77036 .31918 Mtetra
0 .102 .654 r
.77036 .31918 .7766 .33366 .79168 .35313 .78542 .33874 Mtetra
.735 .378 0 r
.78542 .33874 .79168 .35313 .80929 .39828 .80308 .38506 Mtetra
.865 .502 .004 r
.80308 .38506 .80929 .39828 .82934 .46443 .82317 .45268 Mtetra
.775 .39 0 r
.82317 .45268 .82934 .46443 .84806 .5099 .84193 .49893 Mtetra
.876 .759 .73 r
.84193 .49893 .84806 .5099 .86052 .48863 .85446 .47779 Mtetra
.977 .735 .505 r
.85446 .47779 .86052 .48863 .86718 .41334 .86132 .40292 Mtetra
.979 .736 .497 r
.86132 .40292 .86718 .41334 .87328 .33797 .86765 .3284 Mtetra
.904 .496 .196 r
.25066 .48985 .25797 .49555 .26681 .51849 .25944 .51313 Mtetra
.927 .564 .311 r
.25944 .51313 .26681 .51849 .27509 .5519 .26767 .54644 Mtetra
.929 .568 .315 r
.26767 .54644 .27509 .5519 .28347 .58792 .27605 .58152 Mtetra
.893 .47 .136 r
.27605 .58152 .28347 .58792 .29292 .6125 .28559 .60436 Mtetra
.577 .685 .914 r
.28559 .60436 .29292 .6125 .30416 .61293 .29697 .6029 Mtetra
.866 .714 .691 r
.29697 .6029 .30416 .61293 .31707 .5872 .31002 .57604 Mtetra
.889 .704 .645 r
.31002 .57604 .31707 .5872 .3308 .54563 .32384 .53453 Mtetra
.891 .704 .643 r
.32384 .53453 .3308 .54563 .34438 .50292 .33747 .49275 Mtetra
.882 .713 .667 r
.33747 .49275 .34438 .50292 .35729 .46916 .3504 .46018 Mtetra
.859 .728 .716 r
.3504 .46018 .35729 .46916 .3695 .44696 .36262 .43893 Mtetra
.814 .743 .786 r
.36262 .43893 .3695 .44696 .38122 .43391 .37437 .42645 Mtetra
.751 .749 .85 r
.37437 .42645 .38122 .43391 .39271 .42624 .38588 .41906 Mtetra
.7 .746 .887 r
.38588 .41906 .39271 .42624 .40412 .4211 .39732 .414 Mtetra
.674 .743 .902 r
.39732 .414 .40412 .4211 .41554 .41692 .40877 .40984 Mtetra
.662 .741 .908 r
.40877 .40984 .41554 .41692 .427 .41307 .42026 .40602 Mtetra
.652 .739 .914 r
.42026 .40602 .427 .41307 .4385 .40945 .43178 .4025 Mtetra
.627 .735 .925 r
.43178 .4025 .4385 .40945 .45004 .40628 .44334 .39962 Mtetra
.56 .722 .949 r
.44334 .39962 .45004 .40628 .46161 .40408 .45493 .39818 Mtetra
.357 .656 .969 r
.45493 .39818 .46161 .40408 .47321 .4038 .46653 .3995 Mtetra
0 .31 .719 r
.46653 .3995 .47321 .4038 .48485 .40673 .47816 .40534 Mtetra
.728 .201 0 r
.47816 .40534 .48485 .40673 .49656 .41409 .48984 .41735 Mtetra
.811 .379 .217 r
.48984 .41735 .49656 .41409 .50837 .42627 .50165 .43589 Mtetra
.796 .415 .334 r
.50165 .43589 .50837 .42627 .52034 .44184 .51366 .45879 Mtetra
.748 .395 .384 r
.51366 .45879 .52034 .44184 .53252 .45716 .52592 .48082 Mtetra
.665 .331 .397 r
.52592 .48082 .53252 .45716 .54486 .46718 .5384 .49494 Mtetra
.521 .206 .374 r
.5384 .49494 .54486 .46718 .55726 .46749 .55096 .4953 Mtetra
.266 0 .288 r
.55096 .4953 .55726 .46749 .5696 .45663 .56344 .48037 Mtetra
0 0 .089 r
.56344 .48037 .5696 .45663 .58179 .43689 .57571 .45384 Mtetra
0 0 0 r
.57571 .45384 .58179 .43689 .59383 .41304 .58777 .42251 Mtetra
.882 .896 .477 r
.58777 .42251 .59383 .41304 .60578 .38997 .59972 .39294 Mtetra
.962 .942 .662 r
.59972 .39294 .60578 .38997 .61776 .37083 .61168 .36905 Mtetra
.93 .917 .782 r
.61168 .36905 .61776 .37083 .62984 .35653 .62374 .35177 Mtetra
.849 .862 .851 r
.62374 .35177 .62984 .35653 .64205 .34643 .63595 .34003 Mtetra
.769 .809 .885 r
.63595 .34003 .64205 .34643 .65438 .33923 .64831 .33203 Mtetra
.713 .773 .9 r
.64831 .33203 .65438 .33923 .66682 .33372 .66078 .32616 Mtetra
.682 .753 .906 r
.66078 .32616 .66682 .33372 .67935 .32908 .67334 .32134 Mtetra
.666 .744 .908 r
.67334 .32134 .67935 .32908 .69196 .32491 .68598 .31702 Mtetra
.656 .737 .909 r
.68598 .31702 .69196 .32491 .70465 .32114 .6987 .313 Mtetra
.645 .726 .908 r
.6987 .313 .70465 .32114 .71744 .3179 .71149 .3093 Mtetra
.631 .708 .902 r
.71149 .3093 .71744 .3179 .73034 .31541 .72438 .30605 Mtetra
.61 .68 .892 r
.72438 .30605 .73034 .31541 .74338 .3139 .73738 .30349 Mtetra
.563 .633 .879 r
.73738 .30349 .74338 .3139 .75663 .31405 .75057 .30249 Mtetra
.385 .51 .862 r
.75057 .30249 .75663 .31405 .77036 .31918 .76425 .30673 Mtetra
0 .059 .624 r
.76425 .30673 .77036 .31918 .78542 .33874 .77928 .32598 Mtetra
.779 .407 0 r
.77928 .32598 .78542 .33874 .80308 .38506 .7969 .37252 Mtetra
.874 .508 .019 r
.7969 .37252 .80308 .38506 .82317 .45268 .81692 .44029 Mtetra
.759 .38 0 r
.81692 .44029 .82317 .45268 .84193 .49893 .83559 .48621 Mtetra
.859 .732 .722 r
.83559 .48621 .84193 .49893 .85446 .47779 .84819 .46503 Mtetra
.97 .728 .514 r
.84819 .46503 .85446 .47779 .86132 .40292 .85528 .39117 Mtetra
.974 .731 .506 r
.85528 .39117 .86132 .40292 .86765 .3284 .86192 .31818 Mtetra
.905 .497 .191 r
.2433 .48388 .25066 .48985 .25944 .51313 .25204 .50725 Mtetra
.929 .563 .3 r
.25204 .50725 .25944 .51313 .26767 .54644 .26024 .5401 Mtetra
.931 .564 .293 r
.26024 .5401 .26767 .54644 .27605 .58152 .26867 .57387 Mtetra
.87 .431 .044 r
.26867 .57387 .27605 .58152 .28559 .60436 .27831 .59473 Mtetra
.642 .673 .864 r
.27831 .59473 .28559 .60436 .29697 .6029 .28983 .59143 Mtetra
.859 .701 .685 r
.28983 .59143 .29697 .6029 .31002 .57604 .303 .56375 Mtetra
.883 .696 .645 r
.303 .56375 .31002 .57604 .32384 .53453 .31689 .52269 Mtetra
.886 .7 .645 r
.31689 .52269 .32384 .53453 .33747 .49275 .33054 .48219 Mtetra
.877 .71 .671 r
.33054 .48219 .33747 .49275 .3504 .46018 .34348 .451 Mtetra
.853 .726 .722 r
.34348 .451 .3504 .46018 .36262 .43893 .35571 .43081 Mtetra
.807 .742 .792 r
.35571 .43081 .36262 .43893 .37437 .42645 .36746 .41893 Mtetra
.745 .748 .854 r
.36746 .41893 .37437 .42645 .38588 .41906 .379 .41181 Mtetra
.696 .745 .889 r
.379 .41181 .38588 .41906 .39732 .414 .39047 .40685 Mtetra
.672 .742 .903 r
.39047 .40685 .39732 .414 .40877 .40984 .40195 .40271 Mtetra
.661 .741 .909 r
.40195 .40271 .40877 .40984 .42026 .40602 .41346 .39891 Mtetra
.647 .738 .916 r
.41346 .39891 .42026 .40602 .43178 .4025 .42501 .39549 Mtetra
.614 .731 .929 r
.42501 .39549 .43178 .4025 .44334 .39962 .43659 .39291 Mtetra
.52 .706 .955 r
.43659 .39291 .44334 .39962 .45493 .39818 .44819 .39219 Mtetra
.227 .582 .944 r
.44819 .39219 .45493 .39818 .46653 .3995 .45979 .395 Mtetra
.451 0 0 r
.45979 .395 .46653 .3995 .47816 .40534 .47139 .4035 Mtetra
.801 .312 .017 r
.47139 .4035 .47816 .40534 .48984 .41735 .48304 .4196 Mtetra
.851 .436 .243 r
.48304 .4196 .48984 .41735 .50165 .43589 .49482 .44355 Mtetra
.837 .459 .335 r
.49482 .44355 .50165 .43589 .51366 .45879 .50683 .47241 Mtetra
.793 .431 .372 r
.50683 .47241 .51366 .45879 .52592 .48082 .51915 .4995 Mtetra
.702 .348 .373 r
.51915 .4995 .52592 .48082 .5384 .49494 .53173 .51617 Mtetra
.492 .15 .314 r
.53173 .51617 .5384 .49494 .55096 .4953 .54443 .51555 Mtetra
0 0 .092 r
.54443 .51555 .55096 .4953 .56344 .48037 .55703 .49643 Mtetra
.696 .77 .281 r
.55703 .49643 .56344 .48037 .57571 .45384 .56939 .46395 Mtetra
.946 .889 .489 r
.56939 .46395 .57571 .45384 .58777 .42251 .58151 .42662 Mtetra
.99 .89 .594 r
.58151 .42662 .58777 .42251 .59972 .39294 .59348 .39219 Mtetra
.973 .876 .678 r
.59348 .39219 .59972 .39294 .61168 .36905 .60546 .36497 Mtetra
.923 .856 .757 r
.60546 .36497 .61168 .36905 .62374 .35177 .61755 .34574 Mtetra
.849 .826 .825 r
.61755 .34574 .62374 .35177 .63595 .34003 .62978 .33299 Mtetra
.773 .793 .87 r
.62978 .33299 .63595 .34003 .64831 .33203 .64217 .32453 Mtetra
.715 .767 .893 r
.64217 .32453 .64831 .33203 .66078 .32616 .65467 .31848 Mtetra
.682 .752 .904 r
.65467 .31848 .66078 .32616 .67334 .32134 .66728 .31359 Mtetra
.666 .745 .909 r
.66728 .31359 .67334 .32134 .68598 .31702 .67996 .30921 Mtetra
.658 .742 .912 r
.67996 .30921 .68598 .31702 .6987 .313 .69271 .30509 Mtetra
.651 .737 .912 r
.69271 .30509 .6987 .313 .71149 .3093 .70553 .30115 Mtetra
.643 .728 .91 r
.70553 .30115 .71149 .3093 .72438 .30605 .71843 .29747 Mtetra
.628 .71 .906 r
.71843 .29747 .72438 .30605 .73738 .30349 .73143 .29426 Mtetra
.583 .673 .902 r
.73143 .29426 .73738 .30349 .75057 .30249 .74459 .29245 Mtetra
.38 .545 .893 r
.74459 .29245 .75057 .30249 .76425 .30673 .75824 .29594 Mtetra
0 .026 .593 r
.75824 .29594 .76425 .30673 .77928 .32598 .77322 .31465 Mtetra
.807 .422 0 r
.77322 .31465 .77928 .32598 .7969 .37252 .79074 .36064 Mtetra
.878 .509 .028 r
.79074 .36064 .7969 .37252 .81692 .44029 .81059 .42738 Mtetra
.738 .363 0 r
.81059 .42738 .81692 .44029 .83559 .48621 .82909 .47199 Mtetra
.846 .711 .714 r
.82909 .47199 .83559 .48621 .84819 .46503 .84172 .45061 Mtetra
.963 .721 .522 r
.84172 .45061 .84819 .46503 .85528 .39117 .8491 .37829 Mtetra
.97 .727 .515 r
.8491 .37829 .85528 .39117 .86192 .31818 .85609 .30739 Mtetra
.905 .495 .182 r
.23591 .47762 .2433 .48388 .25204 .50725 .24462 .50083 Mtetra
.93 .56 .285 r
.24462 .50083 .25204 .50725 .26024 .5401 .25283 .53287 Mtetra
.931 .558 .264 r
.25283 .53287 .26024 .5401 .26867 .57387 .26132 .565 Mtetra
.816 .365 0 r
.26132 .565 .26867 .57387 .27831 .59473 .27109 .58371 Mtetra
.678 .66 .825 r
.27109 .58371 .27831 .59473 .28983 .59143 .28274 .57866 Mtetra
.852 .689 .68 r
.28274 .57866 .28983 .59143 .303 .56375 .29601 .55047 Mtetra
.877 .69 .646 r
.29601 .55047 .303 .56375 .31689 .52269 .30994 .51025 Mtetra
.88 .696 .649 r
.30994 .51025 .31689 .52269 .33054 .48219 .32359 .47131 Mtetra
.872 .707 .676 r
.32359 .47131 .33054 .48219 .34348 .451 .33651 .44168 Mtetra
.847 .725 .728 r
.33651 .44168 .34348 .451 .35571 .43081 .34874 .42261 Mtetra
.799 .741 .798 r
.34874 .42261 .35571 .43081 .36746 .41893 .3605 .41137 Mtetra
.739 .747 .858 r
.3605 .41137 .36746 .41893 .379 .41181 .37206 .40452 Mtetra
.693 .745 .891 r
.37206 .40452 .379 .41181 .39047 .40685 .38356 .39965 Mtetra
.671 .742 .904 r
.38356 .39965 .39047 .40685 .40195 .40271 .39507 .39552 Mtetra
.659 .74 .91 r
.39507 .39552 .40195 .40271 .41346 .39891 .40661 .39173 Mtetra
.644 .737 .917 r
.40661 .39173 .41346 .39891 .42501 .39549 .41819 .38838 Mtetra
.604 .726 .931 r
.41819 .38838 .42501 .39549 .43659 .39291 .42979 .38601 Mtetra
.494 .689 .955 r
.42979 .38601 .43659 .39291 .44819 .39219 .4414 .38578 Mtetra
.158 .527 .92 r
.4414 .38578 .44819 .39219 .45979 .395 .453 .38956 Mtetra
.5 0 0 r
.453 .38956 .45979 .395 .47139 .4035 .46459 .39969 Mtetra
.82 .34 0 r
.46459 .39969 .47139 .4035 .48304 .4196 .4762 .41812 Mtetra
.882 .461 .193 r
.4762 .41812 .48304 .4196 .49482 .44355 .48794 .44489 Mtetra
.884 .488 .27 r
.48794 .44489 .49482 .44355 .50683 .47241 .49994 .47641 Mtetra
.859 .461 .285 r
.49994 .47641 .50683 .47241 .51915 .4995 .51226 .50519 Mtetra
.771 .337 .221 r
.51226 .50519 .51915 .4995 .53173 .51617 .52489 .52183 Mtetra
.195 0 0 r
.52489 .52183 .53173 .51617 .54443 .51555 .53766 .51937 Mtetra
.94 .962 .683 r
.53766 .51937 .54443 .51555 .55703 .49643 .55035 .49721 Mtetra
.985 .855 .629 r
.55035 .49721 .55703 .49643 .56939 .46395 .5628 .46151 Mtetra
.972 .809 .622 r
.5628 .46151 .56939 .46395 .58151 .42662 .575 .42159 Mtetra
.954 .792 .642 r
.575 .42159 .58151 .42662 .59348 .39219 .58706 .3855 Mtetra
.929 .787 .683 r
.58706 .3855 .59348 .39219 .60546 .36497 .5991 .35745 Mtetra
.888 .786 .742 r
.5991 .35745 .60546 .36497 .61755 .34574 .61124 .3379 Mtetra
.83 .782 .806 r
.61124 .3379 .61755 .34574 .62978 .33299 .62353 .3251 Mtetra
.765 .77 .857 r
.62353 .3251 .62978 .33299 .64217 .32453 .63597 .31667 Mtetra
.712 .757 .888 r
.63597 .31667 .64217 .32453 .65467 .31848 .64852 .31067 Mtetra
.68 .749 .904 r
.64852 .31067 .65467 .31848 .66728 .31359 .66117 .30583 Mtetra
.664 .746 .911 r
.66117 .30583 .66728 .31359 .67996 .30921 .67389 .30149 Mtetra
.657 .745 .915 r
.67389 .30149 .67996 .30921 .69271 .30509 .68668 .29737 Mtetra
.652 .745 .918 r
.68668 .29737 .69271 .30509 .70553 .30115 .69954 .29337 Mtetra
.647 .742 .918 r
.69954 .29337 .70553 .30115 .71843 .29747 .71247 .2895 Mtetra
.637 .734 .918 r
.71247 .2895 .71843 .29747 .73143 .29426 .72549 .28592 Mtetra
.594 .705 .921 r
.72549 .28592 .73143 .29426 .74459 .29245 .73866 .2836 Mtetra
.373 .575 .918 r
.73866 .2836 .74459 .29245 .75824 .29594 .75229 .28649 Mtetra
0 .006 .566 r
.75229 .28649 .75824 .29594 .77322 .31465 .76721 .30449 Mtetra
.823 .428 0 r
.76721 .30449 .77322 .31465 .79074 .36064 .78459 .34931 Mtetra
.879 .507 .029 r
.78459 .34931 .79074 .36064 .81059 .42738 .80419 .41403 Mtetra
.707 .336 0 r
.80419 .41403 .81059 .42738 .82909 .47199 .82245 .4565 Mtetra
.837 .695 .706 r
.82245 .4565 .82909 .47199 .84172 .45061 .83509 .43479 Mtetra
.957 .715 .53 r
.83509 .43479 .84172 .45061 .8491 .37829 .84279 .36446 Mtetra
.965 .724 .524 r
.84279 .36446 .8491 .37829 .85609 .30739 .85018 .29616 Mtetra
.902 .489 .167 r
.22848 .47108 .23591 .47762 .24462 .50083 .23718 .49389 Mtetra
.929 .554 .266 r
.23718 .49389 .24462 .50083 .25283 .53287 .24543 .5248 Mtetra
.929 .547 .228 r
.24543 .5248 .25283 .53287 .26132 .565 .254 .55499 Mtetra
.708 .259 0 r
.254 .55499 .26132 .565 .27109 .58371 .26391 .57144 Mtetra
.7 .649 .796 r
.26391 .57144 .27109 .58371 .28274 .57866 .2757 .56478 Mtetra
.846 .68 .677 r
.2757 .56478 .28274 .57866 .29601 .55047 .28904 .5364 Mtetra
.871 .685 .648 r
.28904 .5364 .29601 .55047 .30994 .51025 .30298 .49735 Mtetra
.875 .692 .652 r
.30298 .49735 .30994 .51025 .32359 .47131 .31661 .46022 Mtetra
.866 .706 .681 r
.31661 .46022 .32359 .47131 .33651 .44168 .32951 .43228 Mtetra
.84 .724 .736 r
.32951 .43228 .33651 .44168 .34874 .42261 .34172 .41437 Mtetra
.792 .741 .805 r
.34172 .41437 .34874 .42261 .3605 .41137 .35349 .40376 Mtetra
.733 .746 .863 r
.35349 .40376 .3605 .41137 .37206 .40452 .36507 .39718 Mtetra
.69 .744 .893 r
.36507 .39718 .37206 .40452 .38356 .39965 .37659 .39239 Mtetra
.67 .742 .904 r
.37659 .39239 .38356 .39965 .39507 .39552 .38813 .38827 Mtetra
.658 .74 .91 r
.38813 .38827 .39507 .39552 .40661 .39173 .39971 .38447 Mtetra
.642 .735 .916 r
.39971 .38447 .40661 .39173 .41819 .38838 .41131 .38113 Mtetra
.602 .723 .93 r
.41131 .38113 .41819 .38838 .42979 .38601 .42294 .37881 Mtetra
.492 .68 .95 r
.42294 .37881 .42979 .38601 .4414 .38578 .43457 .37868 Mtetra
.188 .522 .918 r
.43457 .37868 .4414 .38578 .453 .38956 .44618 .38258 Mtetra
0 .095 .599 r
.44618 .38258 .453 .38956 .46459 .39969 .45777 .39278 Mtetra
.76 .282 0 r
.45777 .39278 .46459 .39969 .4762 .41812 .46938 .41101 Mtetra
.865 .429 .02 r
.46938 .41101 .4762 .41812 .48794 .44489 .4811 .43699 Mtetra
.883 .463 .053 r
.4811 .43699 .48794 .44489 .49994 .47641 .49307 .46691 Mtetra
.818 .388 0 r
.49307 .46691 .49994 .47641 .51226 .50519 .50536 .49331 Mtetra
0 .105 .658 r
.50536 .49331 .51226 .50519 .52489 .52183 .51797 .50728 Mtetra
.648 .609 .796 r
.51797 .50728 .52489 .52183 .53766 .51937 .53075 .5027 Mtetra
.82 .665 .69 r
.53075 .5027 .53766 .51937 .55035 .49721 .54348 .47973 Mtetra
.863 .675 .647 r
.54348 .47973 .55035 .49721 .5628 .46151 .556 .44469 Mtetra
.877 .683 .637 r
.556 .44469 .5628 .46151 .575 .42159 .5683 .40652 Mtetra
.877 .694 .65 r
.5683 .40652 .575 .42159 .58706 .3855 .58046 .37255 Mtetra
.867 .708 .683 r
.58046 .37255 .58706 .3855 .5991 .35745 .59261 .34641 Mtetra
.843 .726 .735 r
.59261 .34641 .5991 .35745 .61124 .3379 .60485 .3283 Mtetra
.8 .741 .798 r
.60485 .3283 .61124 .3379 .62353 .3251 .61721 .3164 Mtetra
.748 .748 .852 r
.61721 .3164 .62353 .3251 .63597 .31667 .62971 .30849 Mtetra
.702 .748 .887 r
.62971 .30849 .63597 .31667 .64852 .31067 .64231 .30276 Mtetra
.674 .746 .905 r
.64231 .30276 .64852 .31067 .66117 .30583 .65501 .29809 Mtetra
.659 .747 .915 r
.65501 .29809 .66117 .30583 .67389 .30149 .66778 .29389 Mtetra
.652 .749 .921 r
.66778 .29389 .67389 .30149 .68668 .29737 .68062 .28989 Mtetra
.648 .752 .926 r
.68062 .28989 .68668 .29737 .69954 .29337 .69353 .28597 Mtetra
.645 .755 .929 r
.69353 .28597 .69954 .29337 .71247 .2895 .7065 .28209 Mtetra
.639 .753 .931 r
.7065 .28209 .71247 .2895 .72549 .28592 .71956 .27837 Mtetra
.598 .733 .939 r
.71956 .27837 .72549 .28592 .73866 .2836 .73275 .27576 Mtetra
.364 .603 .94 r
.73275 .27576 .73866 .2836 .75229 .28649 .74638 .27816 Mtetra
0 0 .545 r
.74638 .27816 .75229 .28649 .76721 .30449 .76124 .29532 Mtetra
.831 .428 0 r
.76124 .29532 .76721 .30449 .78459 .34931 .77845 .33844 Mtetra
.877 .5 .023 r
.77845 .33844 .78459 .34931 .80419 .41403 .79773 .40029 Mtetra
.665 .3 0 r
.79773 .40029 .80419 .41403 .82245 .4565 .81569 .43993 Mtetra
.831 .684 .7 r
.81569 .43993 .82245 .4565 .83509 .43479 .82833 .41784 Mtetra
.951 .71 .538 r
.82833 .41784 .83509 .43479 .84279 .36446 .83639 .34992 Mtetra
.96 .722 .533 r
.83639 .34992 .84279 .36446 .85018 .29616 .84421 .28461 Mtetra
.898 .48 .147 r
.22101 .46428 .22848 .47108 .23718 .49389 .22973 .48646 Mtetra
.928 .546 .242 r
.22973 .48646 .23718 .49389 .24543 .5248 .23803 .51596 Mtetra
.922 .529 .181 r
.23803 .51596 .24543 .5248 .254 .55499 .24672 .54398 Mtetra
0 0 .449 r
.24672 .54398 .254 .55499 .26391 .57144 .25678 .55812 Mtetra
.715 .642 .775 r
.25678 .55812 .26391 .57144 .2757 .56478 .26869 .55003 Mtetra
.84 .673 .676 r
.26869 .55003 .2757 .56478 .28904 .5364 .28208 .52177 Mtetra
.865 .681 .651 r
.28208 .52177 .28904 .5364 .30298 .49735 .29601 .48418 Mtetra
.869 .69 .657 r
.29601 .48418 .30298 .49735 .31661 .46022 .30959 .44904 Mtetra
.86 .705 .688 r
.30959 .44904 .31661 .46022 .32951 .43228 .32245 .42286 Mtetra
.833 .724 .744 r
.32245 .42286 .32951 .43228 .34172 .41437 .33465 .40613 Mtetra
.784 .741 .813 r
.33465 .40613 .34172 .41437 .35349 .40376 .34643 .39613 Mtetra
.727 .746 .867 r
.34643 .39613 .35349 .40376 .36507 .39718 .35802 .3898 Mtetra
.687 .744 .894 r
.35802 .3898 .36507 .39718 .37659 .39239 .36958 .38508 Mtetra
.669 .742 .905 r
.36958 .38508 .37659 .39239 .38813 .38827 .38114 .38096 Mtetra
.659 .74 .91 r
.38114 .38096 .38813 .38827 .39971 .38447 .39275 .37713 Mtetra
.644 .735 .915 r
.39275 .37713 .39971 .38447 .41131 .38113 .40439 .37371 Mtetra
.607 .721 .926 r
.40439 .37371 .41131 .38113 .42294 .37881 .41605 .37125 Mtetra
.515 .681 .941 r
.41605 .37125 .42294 .37881 .43457 .37868 .42771 .37078 Mtetra
.289 .556 .927 r
.42771 .37078 .43457 .37868 .44618 .38258 .43935 .37392 Mtetra
0 .256 .762 r
.43935 .37392 .44618 .38258 .45777 .39278 .45097 .38259 Mtetra
0 0 .481 r
.45097 .38259 .45777 .39278 .46938 .41101 .46261 .39813 Mtetra
0 0 .345 r
.46261 .39813 .46938 .41101 .4811 .43699 .47434 .42 Mtetra
0 0 .415 r
.47434 .42 .4811 .43699 .49307 .46691 .4863 .4446 Mtetra
0 .071 .607 r
.4863 .4446 .49307 .46691 .50536 .49331 .49855 .46538 Mtetra
.388 .342 .686 r
.49855 .46538 .50536 .49331 .51797 .50728 .51111 .47499 Mtetra
.619 .478 .668 r
.51111 .47499 .51797 .50728 .53075 .5027 .52382 .46878 Mtetra
.722 .541 .645 r
.52382 .46878 .53075 .5027 .54348 .47973 .53653 .44745 Mtetra
.773 .576 .633 r
.53653 .44745 .54348 .47973 .556 .44469 .5491 .41665 Mtetra
.799 .602 .635 r
.5491 .41665 .556 .44469 .5683 .40652 .56148 .38386 Mtetra
.812 .626 .652 r
.56148 .38386 .5683 .40652 .58046 .37255 .57376 .35502 Mtetra
.812 .653 .686 r
.57376 .35502 .58046 .37255 .59261 .34641 .58604 .33291 Mtetra
.798 .683 .738 r
.58604 .33291 .59261 .34641 .60485 .3283 .59838 .31749 Mtetra
.768 .712 .799 r
.59838 .31749 .60485 .3283 .61721 .3164 .61083 .30719 Mtetra
.727 .731 .854 r
.61083 .30719 .61721 .3164 .62971 .30849 .62339 .30013 Mtetra
.689 .74 .89 r
.62339 .30013 .62971 .30849 .64231 .30276 .63605 .29485 Mtetra
.664 .745 .91 r
.63605 .29485 .64231 .30276 .65501 .29809 .6488 .29047 Mtetra
.65 .749 .922 r
.6488 .29047 .65501 .29809 .66778 .29389 .66163 .28651 Mtetra
.641 .754 .93 r
.66163 .28651 .66778 .29389 .68062 .28989 .67452 .28275 Mtetra
.637 .761 .937 r
.67452 .28275 .68062 .28989 .69353 .28597 .68749 .27905 Mtetra
.636 .769 .943 r
.68749 .27905 .69353 .28597 .7065 .28209 .70052 .27533 Mtetra
.633 .774 .948 r
.70052 .27533 .7065 .28209 .71956 .27837 .71362 .27166 Mtetra
.594 .761 .958 r
.71362 .27166 .71956 .27837 .73275 .27576 .72685 .2689 Mtetra
.347 .63 .958 r
.72685 .2689 .73275 .27576 .74638 .27816 .74049 .27089 Mtetra
0 0 .527 r
.74049 .27089 .74638 .27816 .76124 .29532 .7553 .28705 Mtetra
.834 .421 0 r
.7553 .28705 .76124 .29532 .77845 .33844 .7723 .32801 Mtetra
.872 .49 .012 r
.7723 .32801 .77845 .33844 .79773 .40029 .79121 .38628 Mtetra
0 0 .33 r
.79121 .38628 .79773 .40029 .81569 .43993 .80883 .42255 Mtetra
.827 .676 .695 r
.80883 .42255 .81569 .43993 .82833 .41784 .82148 .40004 Mtetra
.945 .706 .546 r
.82148 .40004 .82833 .41784 .83639 .34992 .82991 .33486 Mtetra
.956 .72 .542 r
.82991 .33486 .83639 .34992 .84421 .28461 .83818 .27284 Mtetra
.892 .468 .123 r
.21349 .45727 .22101 .46428 .22973 .48646 .22224 .47864 Mtetra
.924 .534 .214 r
.22224 .47864 .22973 .48646 .23803 .51596 .23063 .50653 Mtetra
.908 .504 .124 r
.23063 .50653 .23803 .51596 .24672 .54398 .23946 .53223 Mtetra
0 .058 .618 r
.23946 .53223 .24672 .54398 .25678 .55812 .24967 .54408 Mtetra
.726 .639 .761 r
.24967 .54408 .25678 .55812 .26869 .55003 .26169 .53476 Mtetra
.836 .669 .676 r
.26169 .53476 .26869 .55003 .28208 .52177 .27512 .5069 Mtetra
.861 .679 .654 r
.27512 .5069 .28208 .52177 .29601 .48418 .289 .47099 Mtetra
.865 .69 .663 r
.289 .47099 .29601 .48418 .30959 .44904 .30252 .43795 Mtetra
.855 .706 .696 r
.30252 .43795 .30959 .44904 .32245 .42286 .31534 .41354 Mtetra
.827 .726 .754 r
.31534 .41354 .32245 .42286 .33465 .40613 .32751 .39794 Mtetra
.777 .742 .821 r
.32751 .39794 .33465 .40613 .34643 .39613 .3393 .38852 Mtetra
.721 .747 .872 r
.3393 .38852 .34643 .39613 .35802 .3898 .35092 .38241 Mtetra
.685 .745 .896 r
.35092 .38241 .35802 .3898 .36958 .38508 .3625 .37773 Mtetra
.668 .742 .906 r
.3625 .37773 .36958 .38508 .38114 .38096 .3741 .37358 Mtetra
.66 .74 .909 r
.3741 .37358 .38114 .38096 .39275 .37713 .38573 .36969 Mtetra
.647 .735 .913 r
.38573 .36969 .39275 .37713 .40439 .37371 .39741 .36615 Mtetra
.618 .723 .921 r
.39741 .36615 .40439 .37371 .41605 .37125 .40911 .36339 Mtetra
.55 .689 .931 r
.40911 .36339 .41605 .37125 .42771 .37078 .42081 .36224 Mtetra
.406 .601 .926 r
.42081 .36224 .42771 .37078 .43935 .37392 .43251 .36397 Mtetra
.165 .422 .86 r
.43251 .36397 .43935 .37392 .45097 .38259 .44419 .37 Mtetra
0 .21 .732 r
.44419 .37 .45097 .38259 .46261 .39813 .45589 .38123 Mtetra
0 .111 .653 r
.45589 .38123 .46261 .39813 .47434 .42 .46768 .397 Mtetra
.076 .161 .65 r
.46768 .397 .47434 .42 .4863 .4446 .47964 .41432 Mtetra
.312 .278 .659 r
.47964 .41432 .4863 .4446 .49855 .46538 .49187 .42813 Mtetra
.495 .379 .651 r
.49187 .42813 .49855 .46538 .51111 .47499 .50434 .43308 Mtetra
.609 .448 .638 r
.50434 .43308 .51111 .47499 .52382 .46878 .51697 .42611 Mtetra
.678 .494 .63 r
.51697 .42611 .52382 .46878 .53653 .44745 .52963 .40817 Mtetra
.72 .528 .629 r
.52963 .40817 .53653 .44745 .5491 .41665 .54219 .38366 Mtetra
.747 .558 .638 r
.54219 .38366 .5491 .41665 .56148 .38386 .55464 .35811 Mtetra
.763 .588 .66 r
.55464 .35811 .56148 .38386 .57376 .35502 .56703 .33578 Mtetra
.768 .622 .697 r
.56703 .33578 .57376 .35502 .58604 .33291 .57942 .31857 Mtetra
.76 .66 .751 r
.57942 .31857 .58604 .33291 .59838 .31749 .59186 .30633 Mtetra
.737 .696 .812 r
.59186 .30633 .59838 .31749 .61083 .30719 .6044 .29785 Mtetra
.704 .722 .864 r
.6044 .29785 .61083 .30719 .62339 .30013 .61703 .29177 Mtetra
.673 .736 .898 r
.61703 .29177 .62339 .30013 .63605 .29485 .62975 .28704 Mtetra
.65 .744 .918 r
.62975 .28704 .63605 .29485 .6488 .29047 .64255 .28304 Mtetra
.635 .751 .932 r
.64255 .28304 .6488 .29047 .66163 .28651 .65544 .27946 Mtetra
.624 .76 .944 r
.65544 .27946 .66163 .28651 .67452 .28275 .6684 .2761 Mtetra
.617 .771 .954 r
.6684 .2761 .67452 .28275 .68749 .27905 .68143 .2728 Mtetra
.616 .785 .963 r
.68143 .2728 .68749 .27905 .70052 .27533 .69453 .26943 Mtetra
.615 .798 .97 r
.69453 .26943 .70052 .27533 .71362 .27166 .7077 .26596 Mtetra
.578 .791 .98 r
.7077 .26596 .71362 .27166 .72685 .2689 .72098 .26318 Mtetra
.317 .656 .971 r
.72098 .26318 .72685 .2689 .74049 .27089 .73464 .26478 Mtetra
0 0 .506 r
.73464 .26478 .74049 .27089 .7553 .28705 .74938 .27978 Mtetra
.834 .411 0 r
.74938 .27978 .7553 .28705 .7723 .32801 .76616 .31811 Mtetra
.864 .476 0 r
.76616 .31811 .7723 .32801 .79121 .38628 .78466 .37219 Mtetra
0 0 .395 r
.78466 .37219 .79121 .38628 .80883 .42255 .80191 .40464 Mtetra
.826 .671 .691 r
.80191 .40464 .80883 .42255 .82148 .40004 .81456 .38172 Mtetra
.94 .703 .553 r
.81456 .38172 .82148 .40004 .82991 .33486 .82339 .31952 Mtetra
.951 .72 .552 r
.82339 .31952 .82991 .33486 .83818 .27284 .83211 .26098 Mtetra
.884 .452 .097 r
.20592 .45015 .21349 .45727 .22224 .47864 .21472 .4706 Mtetra
.917 .519 .183 r
.21472 .4706 .22224 .47864 .23063 .50653 .22321 .49675 Mtetra
.886 .47 .059 r
.22321 .49675 .23063 .50653 .23946 .53223 .23219 .5201 Mtetra
0 .203 .731 r
.23219 .5201 .23946 .53223 .24967 .54408 .24255 .52979 Mtetra
.736 .64 .753 r
.24255 .52979 .24967 .54408 .26169 .53476 .25467 .51948 Mtetra
.834 .669 .678 r
.25467 .51948 .26169 .53476 .27512 .5069 .2681 .49226 Mtetra
.858 .68 .659 r
.2681 .49226 .27512 .5069 .289 .47099 .28193 .45819 Mtetra
.863 .692 .67 r
.28193 .45819 .289 .47099 .30252 .43795 .29539 .42727 Mtetra
.852 .711 .705 r
.29539 .42727 .30252 .43795 .31534 .41354 .30815 .40455 Mtetra
.823 .732 .765 r
.30815 .40455 .31534 .41354 .32751 .39794 .32031 .38998 Mtetra
.772 .748 .831 r
.32031 .38998 .32751 .39794 .3393 .38852 .33211 .38103 Mtetra
.718 .751 .878 r
.33211 .38103 .3393 .38852 .35092 .38241 .34375 .37506 Mtetra
.684 .747 .899 r
.34375 .37506 .35092 .38241 .3625 .37773 .35536 .37038 Mtetra
.669 .744 .907 r
.35536 .37038 .3625 .37773 .3741 .37358 .36699 .36618 Mtetra
.661 .741 .909 r
.36699 .36618 .3741 .37358 .38573 .36969 .37866 .3622 Mtetra
.652 .737 .912 r
.37866 .3622 .38573 .36969 .39741 .36615 .39037 .35849 Mtetra
.631 .726 .916 r
.39037 .35849 .39741 .36615 .40911 .36339 .40211 .35535 Mtetra
.587 .7 .921 r
.40211 .35535 .40911 .36339 .42081 .36224 .41387 .35338 Mtetra
.502 .641 .917 r
.41387 .35338 .42081 .36224 .43251 .36397 .42563 .35344 Mtetra
.377 .533 .885 r
.42563 .35344 .43251 .36397 .44419 .37 .4374 .35648 Mtetra
.268 .405 .816 r
.4374 .35648 .44419 .37 .45589 .38123 .44918 .363 Mtetra
.256 .327 .745 r
.44918 .363 .45589 .38123 .46768 .397 .46105 .37239 Mtetra
.336 .324 .697 r
.46105 .37239 .46768 .397 .47964 .41432 .47306 .38245 Mtetra
.445 .361 .667 r
.47306 .38245 .47964 .41432 .49187 .42813 .48527 .38975 Mtetra
.538 .405 .647 r
.48527 .38975 .49187 .42813 .50434 .43308 .49767 .39083 Mtetra
.607 .445 .636 r
.49767 .39083 .50434 .43308 .51697 .42611 .51021 .38395 Mtetra
.655 .478 .633 r
.51021 .38395 .51697 .42611 .52963 .40817 .52279 .36998 Mtetra
.69 .509 .637 r
.52279 .36998 .52963 .40817 .54219 .38366 .53534 .35197 Mtetra
.714 .539 .651 r
.53534 .35197 .54219 .38366 .55464 .35811 .54783 .33355 Mtetra
.729 .572 .678 r
.54783 .33355 .55464 .35811 .56703 .33578 .5603 .31745 Mtetra
.735 .612 .72 r
.5603 .31745 .56703 .33578 .57942 .31857 .57278 .30483 Mtetra
.729 .655 .775 r
.57278 .30483 .57942 .31857 .59186 .30633 .58531 .29553 Mtetra
.71 .694 .833 r
.58531 .29553 .59186 .30633 .6044 .29785 .59792 .28873 Mtetra
.682 .721 .879 r
.59792 .28873 .6044 .29785 .61703 .29177 .61062 .28357 Mtetra
.655 .736 .909 r
.61062 .28357 .61703 .29177 .62975 .28704 .6234 .27943 Mtetra
.631 .745 .93 r
.6234 .27943 .62975 .28704 .64255 .28304 .63626 .27594 Mtetra
.611 .754 .946 r
.63626 .27594 .64255 .28304 .65544 .27946 .64921 .27289 Mtetra
.592 .765 .962 r
.64921 .27289 .65544 .27946 .6684 .2761 .66225 .27014 Mtetra
.579 .781 .975 r
.66225 .27014 .6684 .2761 .68143 .2728 .67536 .26747 Mtetra
.573 .802 .986 r
.67536 .26747 .68143 .2728 .69453 .26943 .68855 .26465 Mtetra
.573 .824 .992 r
.68855 .26465 .69453 .26943 .7077 .26596 .70179 .26156 Mtetra
.538 .823 .998 r
.70179 .26156 .7077 .26596 .72098 .26318 .71514 .25887 Mtetra
.261 .675 .966 r
.71514 .25887 .72098 .26318 .73464 .26478 .72882 .26006 Mtetra
.523 0 0 r
.72882 .26006 .73464 .26478 .74938 .27978 .7435 .27369 Mtetra
.833 .396 0 r
.7435 .27369 .74938 .27978 .76616 .31811 .76003 .30898 Mtetra
.856 .458 0 r
.76003 .30898 .76616 .31811 .78466 .37219 .7781 .35831 Mtetra
0 0 .467 r
.7781 .35831 .78466 .37219 .80191 .40464 .79496 .38656 Mtetra
.828 .671 .689 r
.79496 .38656 .80191 .40464 .81456 .38172 .80761 .36321 Mtetra
.935 .702 .561 r
.80761 .36321 .81456 .38172 .82339 .31952 .81683 .30412 Mtetra
.947 .72 .562 r
.81683 .30412 .82339 .31952 .83211 .26098 .82601 .24915 Mtetra
.874 .435 .072 r
.19829 .44302 .20592 .45015 .21472 .4706 .20714 .46252 Mtetra
.908 .5 .151 r
.20714 .46252 .21472 .4706 .22321 .49675 .21574 .48695 Mtetra
.859 .429 0 r
.21574 .48695 .22321 .49675 .23219 .5201 .22487 .50809 Mtetra
.056 .309 .795 r
.22487 .50809 .23219 .5201 .24255 .52979 .23537 .51587 Mtetra
.746 .649 .753 r
.23537 .51587 .24255 .52979 .25467 .51948 .24756 .50491 Mtetra
.836 .674 .682 r
.24756 .50491 .25467 .51948 .2681 .49226 .26098 .47859 Mtetra
.86 .686 .666 r
.26098 .47859 .2681 .49226 .28193 .45819 .27475 .44643 Mtetra
.864 .702 .678 r
.27475 .44643 .28193 .45819 .29539 .42727 .28813 .41754 Mtetra
.854 .723 .717 r
.28813 .41754 .29539 .42727 .30815 .40455 .30085 .39633 Mtetra
.824 .747 .779 r
.30085 .39633 .30815 .40455 .32031 .38998 .31301 .38258 Mtetra
.773 .762 .844 r
.31301 .38258 .32031 .38998 .33211 .38103 .32483 .37391 Mtetra
.72 .762 .886 r
.32483 .37391 .33211 .38103 .34375 .37506 .33651 .36793 Mtetra
.687 .756 .904 r
.33651 .36793 .34375 .37506 .35536 .37038 .34816 .36314 Mtetra
.672 .75 .909 r
.34816 .36314 .35536 .37038 .36699 .36618 .35983 .35881 Mtetra
.665 .745 .91 r
.35983 .35881 .36699 .36618 .37866 .3622 .37154 .35469 Mtetra
.657 .74 .911 r
.37154 .35469 .37866 .3622 .39037 .35849 .38328 .35079 Mtetra
.643 .731 .912 r
.38328 .35079 .39037 .35849 .40211 .35535 .39507 .34727 Mtetra
.616 .712 .913 r
.39507 .34727 .40211 .35535 .41387 .35338 .40688 .34451 Mtetra
.569 .672 .909 r
.40688 .34451 .41387 .35338 .42563 .35344 .41871 .34303 Mtetra
.504 .605 .886 r
.41871 .34303 .42563 .35344 .4374 .35648 .43056 .34338 Mtetra
.447 .519 .839 r
.43056 .34338 .4374 .35648 .44918 .363 .44244 .3458 Mtetra
.433 .45 .778 r
.44244 .3458 .44918 .363 .46105 .37239 .45439 .34982 Mtetra
.463 .42 .724 r
.45439 .34982 .46105 .37239 .47306 .38245 .46646 .35402 Mtetra
.515 .42 .686 r
.46646 .35402 .47306 .38245 .48527 .38975 .47867 .35632 Mtetra
.567 .437 .663 r
.47867 .35632 .48527 .38975 .49767 .39083 .49103 .35475 Mtetra
.611 .46 .652 r
.49103 .35475 .49767 .39083 .51021 .38395 .50349 .34843 Mtetra
.646 .484 .65 r
.50349 .34843 .51021 .38395 .52279 .36998 .51601 .33803 Mtetra
.673 .511 .659 r
.51601 .33803 .52279 .36998 .53534 .35197 .52854 .32542 Mtetra
.693 .542 .678 r
.52854 .32542 .53534 .35197 .54783 .33355 .54106 .31275 Mtetra
.706 .579 .71 r
.54106 .31275 .54783 .33355 .5603 .31745 .55358 .30156 Mtetra
.711 .622 .756 r
.55358 .30156 .5603 .31745 .57278 .30483 .56613 .2925 Mtetra
.704 .665 .809 r
.56613 .2925 .57278 .30483 .58531 .29553 .57873 .28546 Mtetra
.685 .701 .859 r
.57873 .28546 .58531 .29553 .59792 .28873 .59141 .27999 Mtetra
.66 .724 .896 r
.59141 .27999 .59792 .28873 .61062 .28357 .60416 .27563 Mtetra
.633 .737 .923 r
.60416 .27563 .61062 .28357 .6234 .27943 .617 .27211 Mtetra
.604 .745 .944 r
.617 .27211 .6234 .27943 .63626 .27594 .62993 .26926 Mtetra
.571 .754 .964 r
.62993 .26926 .63626 .27594 .64921 .27289 .64295 .26697 Mtetra
.537 .766 .982 r
.64295 .26697 .64921 .27289 .66225 .27014 .65608 .26508 Mtetra
.506 .784 .995 r
.65608 .26508 .66225 .27014 .67536 .26747 .66929 .26332 Mtetra
.486 .808 1 r
.66929 .26332 .67536 .26747 .68855 .26465 .68257 .26132 Mtetra
.482 .835 .996 r
.68257 .26132 .68855 .26465 .70179 .26156 .69591 .25881 Mtetra
.447 .836 .984 r
.69591 .25881 .70179 .26156 .71514 .25887 .70934 .25631 Mtetra
.161 .666 .907 r
.70934 .25631 .71514 .25887 .72882 .26006 .72305 .25705 Mtetra
.55 0 0 r
.72305 .25705 .72882 .26006 .7435 .27369 .73766 .26909 Mtetra
.83 .377 0 r
.73766 .26909 .7435 .27369 .76003 .30898 .75393 .3009 Mtetra
.847 .435 0 r
.75393 .3009 .76003 .30898 .7781 .35831 .77155 .34498 Mtetra
0 0 .546 r
.77155 .34498 .7781 .35831 .79496 .38656 .78801 .36872 Mtetra
.834 .676 .687 r
.78801 .36872 .79496 .38656 .80761 .36321 .80066 .34486 Mtetra
.932 .703 .568 r
.80066 .34486 .80761 .36321 .81683 .30412 .81026 .28889 Mtetra
.944 .722 .572 r
.81026 .28889 .81683 .30412 .82601 .24915 .81989 .23747 Mtetra
.865 .418 .05 r
.19058 .43596 .19829 .44302 .20714 .46252 .19949 .45459 Mtetra
.898 .481 .125 r
.19949 .45459 .20714 .46252 .21574 .48695 .20818 .47749 Mtetra
.833 .39 0 r
.20818 .47749 .21574 .48695 .22487 .50809 .21744 .49674 Mtetra
.134 .377 .833 r
.21744 .49674 .22487 .50809 .23537 .51587 .22805 .50309 Mtetra
.756 .666 .763 r
.22805 .50309 .23537 .51587 .24756 .50491 .24028 .49197 Mtetra
.843 .689 .691 r
.24028 .49197 .24756 .50491 .26098 .47859 .25367 .46688 Mtetra
.868 .703 .676 r
.25367 .46688 .26098 .47859 .27475 .44643 .26736 .43672 Mtetra
.874 .723 .691 r
.26736 .43672 .27475 .44643 .28813 .41754 .28068 .40972 Mtetra
.866 .751 .733 r
.28068 .40972 .28813 .41754 .30085 .39633 .29338 .38972 Mtetra
.837 .781 .799 r
.29338 .38972 .30085 .39633 .31301 .38258 .30557 .37641 Mtetra
.785 .796 .862 r
.30557 .37641 .31301 .38258 .32483 .37391 .31744 .36767 Mtetra
.732 .791 .9 r
.31744 .36767 .32483 .37391 .33651 .36793 .32917 .36138 Mtetra
.698 .777 .912 r
.32917 .36138 .33651 .36793 .34816 .36314 .34087 .35625 Mtetra
.681 .764 .914 r
.34087 .35625 .34816 .36314 .35983 .35881 .35259 .35163 Mtetra
.672 .754 .912 r
.35259 .35163 .35983 .35881 .37154 .35469 .36434 .34727 Mtetra
.664 .746 .911 r
.36434 .34727 .37154 .35469 .38328 .35079 .37613 .34313 Mtetra
.654 .737 .911 r
.37613 .34313 .38328 .35079 .39507 .34727 .38796 .33927 Mtetra
.638 .723 .909 r
.38796 .33927 .39507 .34727 .40688 .34451 .39982 .33586 Mtetra
.613 .697 .904 r
.39982 .33586 .40688 .34451 .41871 .34303 .41172 .33318 Mtetra
.579 .654 .888 r
.41172 .33318 .41871 .34303 .43056 .34338 .42365 .3315 Mtetra
.548 .596 .854 r
.42365 .3315 .43056 .34338 .44244 .3458 .43562 .33092 Mtetra
.533 .539 .807 r
.43562 .33092 .44244 .3458 .45439 .34982 .44765 .33113 Mtetra
.541 .5 .759 r
.44765 .33113 .45439 .34982 .46646 .35402 .45977 .33131 Mtetra
.564 .482 .721 r
.45977 .33131 .46646 .35402 .47867 .35632 .472 .33035 Mtetra
.593 .482 .697 r
.472 .33035 .47867 .35632 .49103 .35475 .48434 .32723 Mtetra
.621 .493 .685 r
.48434 .32723 .49103 .35475 .50349 .34843 .49676 .32158 Mtetra
.645 .512 .686 r
.49676 .32158 .50349 .34843 .51601 .33803 .50924 .31383 Mtetra
.666 .537 .697 r
.50924 .31383 .51601 .33803 .52854 .32542 .52176 .30502 Mtetra
.681 .568 .721 r
.52176 .30502 .52854 .32542 .54106 .31275 .53429 .29627 Mtetra
.691 .606 .757 r
.53429 .29627 .54106 .31275 .55358 .30156 .54685 .28838 Mtetra
.692 .648 .801 r
.54685 .28838 .55358 .30156 .56613 .2925 .55946 .28169 Mtetra
.682 .685 .846 r
.55946 .28169 .56613 .2925 .57873 .28546 .57212 .27617 Mtetra
.663 .712 .885 r
.57212 .27617 .57873 .28546 .59141 .27999 .58485 .27165 Mtetra
.637 .728 .914 r
.58485 .27165 .59141 .27999 .60416 .27563 .59766 .26799 Mtetra
.605 .736 .938 r
.59766 .26799 .60416 .27563 .617 .27211 .61056 .26514 Mtetra
.562 .741 .96 r
.61056 .26514 .617 .27211 .62993 .26926 .62356 .26311 Mtetra
.507 .745 .981 r
.62356 .26311 .62993 .26926 .64295 .26697 .63667 .26184 Mtetra
.438 .749 .994 r
.63667 .26184 .64295 .26697 .65608 .26508 .64989 .26114 Mtetra
.366 .754 .988 r
.64989 .26114 .65608 .26508 .66929 .26332 .66321 .26063 Mtetra
.312 .762 .958 r
.66321 .26063 .66929 .26332 .68257 .26132 .67662 .25977 Mtetra
.294 .777 .915 r
.67662 .25977 .68257 .26132 .69591 .25881 .69007 .25807 Mtetra
.267 .771 .866 r
.69007 .25807 .69591 .25881 .70934 .25631 .70359 .25587 Mtetra
.018 .591 .743 r
.70359 .25587 .70934 .25631 .72305 .25705 .71735 .2561 Mtetra
.565 0 0 r
.71735 .2561 .72305 .25705 .73766 .26909 .73188 .2663 Mtetra
.823 .351 0 r
.73188 .2663 .73766 .26909 .75393 .3009 .74788 .2942 Mtetra
.836 .406 0 r
.74788 .2942 .75393 .3009 .77155 .34498 .76504 .33258 Mtetra
0 .073 .634 r
.76504 .33258 .77155 .34498 .78801 .36872 .7811 .35151 Mtetra
.844 .686 .686 r
.7811 .35151 .78801 .36872 .80066 .34486 .79374 .327 Mtetra
.931 .706 .575 r
.79374 .327 .80066 .34486 .81026 .28889 .80371 .27405 Mtetra
.942 .726 .582 r
.80371 .27405 .81026 .28889 .81989 .23747 .81376 .22603 Mtetra
.856 .403 .031 r
.1828 .42896 .19058 .43596 .19949 .45459 .19174 .4469 Mtetra
.89 .464 .105 r
.19174 .4469 .19949 .45459 .20818 .47749 .20051 .46859 Mtetra
.817 .363 0 r
.20051 .46859 .20818 .47749 .21744 .49674 .20985 .48651 Mtetra
.129 .406 .855 r
.20985 .48651 .21744 .49674 .22805 .50309 .22052 .49217 Mtetra
.765 .695 .785 r
.22052 .49217 .22805 .50309 .24028 .49197 .23274 .48162 Mtetra
.856 .716 .708 r
.23274 .48162 .24028 .49197 .25367 .46688 .24604 .45831 Mtetra
.884 .735 .691 r
.24604 .45831 .25367 .46688 .26736 .43672 .25964 .43036 Mtetra
.896 .764 .708 r
.25964 .43036 .26736 .43672 .28068 .40972 .27291 .40513 Mtetra
.893 .806 .756 r
.27291 .40513 .28068 .40972 .29338 .38972 .28563 .38597 Mtetra
.866 .848 .824 r
.28563 .38597 .29338 .38972 .30557 .37641 .29788 .37261 Mtetra
.813 .865 .886 r
.29788 .37261 .30557 .37641 .31744 .36767 .30985 .36324 Mtetra
.76 .851 .919 r
.30985 .36324 .31744 .36767 .32917 .36138 .32168 .35612 Mtetra
.724 .823 .926 r
.32168 .35612 .32917 .36138 .34087 .35625 .33347 .3502 Mtetra
.701 .796 .923 r
.33347 .3502 .34087 .35625 .35259 .35163 .34526 .34495 Mtetra
.686 .774 .918 r
.34526 .34495 .35259 .35163 .36434 .34727 .35707 .34014 Mtetra
.675 .759 .914 r
.35707 .34014 .36434 .34727 .37613 .34313 .36891 .33564 Mtetra
.665 .747 .911 r
.36891 .33564 .37613 .34313 .38796 .33927 .38078 .33142 Mtetra
.654 .734 .909 r
.38078 .33142 .38796 .33927 .39982 .33586 .3927 .32751 Mtetra
.64 .717 .904 r
.3927 .32751 .39982 .33586 .41172 .33318 .40465 .32401 Mtetra
.622 .69 .892 r
.40465 .32401 .41172 .33318 .42365 .3315 .41665 .32101 Mtetra
.606 .653 .871 r
.41665 .32101 .42365 .3315 .43562 .33092 .42869 .31854 Mtetra
.595 .612 .838 r
.42869 .31854 .43562 .33092 .44765 .33113 .44079 .3164 Mtetra
.595 .576 .802 r
.44079 .3164 .44765 .33113 .45977 .33131 .45296 .31419 Mtetra
.604 .552 .77 r
.45296 .31419 .45977 .33131 .472 .33035 .46522 .31137 Mtetra
.619 .543 .747 r
.46522 .31137 .472 .33035 .48434 .32723 .47756 .30748 Mtetra
.635 .547 .737 r
.47756 .30748 .48434 .32723 .49676 .32158 .48997 .30238 Mtetra
.652 .561 .739 r
.48997 .30238 .49676 .32158 .50924 .31383 .50244 .29631 Mtetra
.666 .583 .753 r
.50244 .29631 .50924 .31383 .52176 .30502 .51495 .28979 Mtetra
.676 .613 .778 r
.51495 .28979 .52176 .30502 .53429 .29627 .52751 .28335 Mtetra
.68 .647 .81 r
.52751 .28335 .53429 .29627 .54685 .28838 .5401 .27739 Mtetra
.676 .68 .846 r
.5401 .27739 .54685 .28838 .55946 .28169 .55275 .27209 Mtetra
.664 .706 .879 r
.55275 .27209 .55946 .28169 .57212 .27617 .56546 .2675 Mtetra
.643 .722 .906 r
.56546 .2675 .57212 .27617 .58485 .27165 .57824 .26365 Mtetra
.612 .73 .929 r
.57824 .26365 .58485 .27165 .59766 .26799 .59111 .26062 Mtetra
.567 .732 .952 r
.59111 .26062 .59766 .26799 .61056 .26514 .60407 .25856 Mtetra
.5 .728 .975 r
.60407 .25856 .61056 .26514 .62356 .26311 .61714 .25756 Mtetra
.401 .716 .987 r
.61714 .25756 .62356 .26311 .63667 .26184 .63034 .25762 Mtetra
.267 .687 .967 r
.63034 .25762 .63667 .26184 .64989 .26114 .64368 .25849 Mtetra
.126 .64 .893 r
.64368 .25849 .64989 .26114 .66321 .26063 .65713 .25962 Mtetra
.03 .597 .781 r
.65713 .25962 .66321 .26063 .67662 .25977 .67068 .26025 Mtetra
0 0 0 r
.67068 .26025 .67662 .25977 .69007 .25807 .68427 .25965 Mtetra
.68427 .25965 .69007 .25807 .70359 .25587 .6979 .25786 Mtetra
.127 0 0 r
.6979 .25786 .70359 .25587 .71735 .2561 .7117 .25752 Mtetra
.554 0 0 r
.7117 .25752 .71735 .2561 .73188 .2663 .72616 .2656 Mtetra
.804 .314 0 r
.72616 .2656 .73188 .2663 .74788 .2942 .74189 .28919 Mtetra
.82 .366 0 r
.74189 .28919 .74788 .2942 .76504 .33258 .75859 .32145 Mtetra
0 .209 .735 r
.75859 .32145 .76504 .33258 .7811 .35151 .77424 .33529 Mtetra
.857 .7 .686 r
.77424 .33529 .7811 .35151 .79374 .327 .78687 .30994 Mtetra
.931 .711 .582 r
.78687 .30994 .79374 .327 .80371 .27405 .79718 .25979 Mtetra
.94 .731 .593 r
.79718 .25979 .80371 .27405 .81376 .22603 .80763 .21494 Mtetra
.848 .39 .012 r
.17496 .42191 .1828 .42896 .19174 .4469 .18392 .43932 Mtetra
.883 .451 .09 r
.18392 .43932 .19174 .4469 .20051 .46859 .19273 .46021 Mtetra
.815 .353 0 r
.19273 .46021 .20051 .46859 .20985 .48651 .2021 .4775 Mtetra
.02 .375 .841 r
.2021 .4775 .20985 .48651 .22052 .49217 .21274 .48343 Mtetra
.762 .734 .827 r
.21274 .48343 .22052 .49217 .23274 .48162 .22484 .47448 Mtetra
.873 .761 .736 r
.22484 .47448 .23274 .48162 .24604 .45831 .238 .45381 Mtetra
.91 .789 .715 r
.238 .45381 .24604 .45831 .25964 .43036 .25146 .42861 Mtetra
.93 .837 .731 r
.25146 .42861 .25964 .43036 .27291 .40513 .26468 .40527 Mtetra
.93 .901 .776 r
.26468 .40527 .27291 .40513 .28563 .38597 .27745 .38669 Mtetra
.895 .954 .832 r
.27745 .38669 .28563 .38597 .29788 .37261 .28983 .37273 Mtetra
.84 .968 .884 r
.28983 .37273 .29788 .37261 .30985 .36324 .30195 .36201 Mtetra
.797 .947 .921 r
.30195 .36201 .30985 .36324 .32168 .35612 .31395 .35329 Mtetra
.767 .904 .936 r
.31395 .35329 .32168 .35612 .33347 .3502 .32589 .34586 Mtetra
.74 .857 .935 r
.32589 .34586 .33347 .3502 .34526 .34495 .3378 .33938 Mtetra
.715 .816 .928 r
.3378 .33938 .34526 .34495 .35707 .34014 .34969 .33366 Mtetra
.695 .785 .92 r
.34969 .33366 .35707 .34014 .36891 .33564 .3616 .32853 Mtetra
.679 .764 .915 r
.3616 .32853 .36891 .33564 .38078 .33142 .37353 .32384 Mtetra
.667 .748 .91 r
.37353 .32384 .38078 .33142 .3927 .32751 .3855 .31949 Mtetra
.657 .733 .906 r
.3855 .31949 .3927 .32751 .40465 .32401 .39751 .31543 Mtetra
.647 .716 .898 r
.39751 .31543 .40465 .32401 .41665 .32101 .40956 .31165 Mtetra
.638 .694 .886 r
.40956 .31165 .41665 .32101 .42869 .31854 .42166 .30812 Mtetra
.632 .668 .867 r
.42166 .30812 .42869 .31854 .44079 .3164 .43381 .30471 Mtetra
.631 .643 .844 r
.43381 .30471 .44079 .3164 .45296 .31419 .44603 .30125 Mtetra
.634 .623 .822 r
.44603 .30125 .45296 .31419 .46522 .31137 .45832 .29749 Mtetra
.641 .613 .806 r
.45832 .29749 .46522 .31137 .47756 .30748 .47068 .29326 Mtetra
.65 .613 .799 r
.47068 .29326 .47756 .30748 .48997 .30238 .4831 .28851 Mtetra
.66 .623 .802 r
.4831 .28851 .48997 .30238 .50244 .29631 .49557 .28335 Mtetra
.667 .641 .814 r
.49557 .28335 .50244 .29631 .51495 .28979 .5081 .27803 Mtetra
.671 .663 .834 r
.5081 .27803 .51495 .28979 .52751 .28335 .52068 .27279 Mtetra
.67 .687 .857 r
.52068 .27279 .52751 .28335 .5401 .27739 .53331 .26781 Mtetra
.663 .707 .88 r
.53331 .26781 .5401 .27739 .55275 .27209 .546 .26325 Mtetra
.648 .721 .901 r
.546 .26325 .55275 .27209 .56546 .2675 .55876 .25922 Mtetra
.623 .727 .921 r
.55876 .25922 .56546 .2675 .57824 .26365 .57158 .25589 Mtetra
.583 .727 .942 r
.57158 .25589 .57824 .26365 .59111 .26062 .5845 .25352 Mtetra
.517 .72 .965 r
.5845 .25352 .59111 .26062 .60407 .25856 .59752 .25237 Mtetra
.408 .698 .98 r
.59752 .25237 .60407 .25856 .61714 .25756 .61067 .25265 Mtetra
.236 .645 .959 r
.61067 .25265 .61714 .25756 .63034 .25762 .62398 .25437 Mtetra
.015 .543 .855 r
.62398 .25437 .63034 .25762 .64368 .25849 .63744 .25719 Mtetra
.175 0 0 r
.63744 .25719 .64368 .25849 .65713 .25962 .65104 .26038 Mtetra
.26 0 0 r
.65104 .26038 .65713 .25962 .67068 .26025 .66475 .2629 Mtetra
.243 0 0 r
.66475 .2629 .67068 .26025 .68427 .25965 .6785 .26366 Mtetra
.182 0 0 r
.6785 .26366 .68427 .25965 .6979 .25786 .69225 .26241 Mtetra
.225 0 0 r
.69225 .26241 .6979 .25786 .7117 .25752 .70612 .26142 Mtetra
.515 0 0 r
.70612 .26142 .7117 .25752 .72616 .2656 .72051 .26712 Mtetra
.767 .26 0 r
.72051 .26712 .72616 .2656 .74189 .28919 .73596 .28601 Mtetra
.792 .307 0 r
.73596 .28601 .74189 .28919 .75859 .32145 .7522 .31179 Mtetra
.069 .384 .846 r
.7522 .31179 .75859 .32145 .77424 .33529 .76746 .32031 Mtetra
.875 .717 .684 r
.76746 .32031 .77424 .33529 .78687 .30994 .78005 .29389 Mtetra
.933 .718 .588 r
.78005 .29389 .78687 .30994 .79718 .25979 .79068 .24623 Mtetra
.94 .739 .603 r
.79068 .24623 .79718 .25979 .80763 .21494 .80149 .20423 Mtetra
.837 .375 0 r
.16708 .41453 .17496 .42191 .18392 .43932 .17606 .43149 Mtetra
.877 .442 .069 r
.17606 .43149 .18392 .43932 .19273 .46021 .18487 .45189 Mtetra
.818 .356 0 r
.18487 .45189 .19273 .46021 .2021 .4775 .19421 .46922 Mtetra
0 .256 .749 r
.19421 .46922 .2021 .4775 .21274 .48343 .20472 .47644 Mtetra
.72 .771 .892 r
.20472 .47644 .21274 .48343 .22484 .47448 .2166 .47034 Mtetra
.882 .823 .785 r
.2166 .47034 .22484 .47448 .238 .45381 .22948 .45355 Mtetra
.935 .871 .751 r
.22948 .45355 .238 .45381 .25146 .42861 .24273 .43208 Mtetra
.949 .939 .745 r
.24273 .43208 .25146 .42861 .26468 .40527 .25586 .41123 Mtetra
.895 .985 .726 r
.25586 .41123 .26468 .40527 .27745 .38669 .26869 .39336 Mtetra
.787 .976 .692 r
.26869 .39336 .27745 .38669 .28983 .37273 .28124 .37846 Mtetra
.737 .972 .714 r
.28124 .37846 .28983 .37273 .30195 .36201 .29361 .36566 Mtetra
.763 .994 .799 r
.29361 .36566 .30195 .36201 .31395 .35329 .30587 .35439 Mtetra
.796 .991 .883 r
.30587 .35439 .31395 .35329 .32589 .34586 .31804 .34445 Mtetra
.792 .946 .924 r
.31804 .34445 .32589 .34586 .3378 .33938 .33013 .33583 Mtetra
.764 .886 .932 r
.33013 .33583 .3378 .33938 .34969 .33366 .34217 .32848 Mtetra
.731 .833 .928 r
.34217 .32848 .34969 .33366 .3616 .32853 .35419 .32219 Mtetra
.704 .794 .921 r
.35419 .32219 .3616 .32853 .37353 .32384 .3662 .31672 Mtetra
.684 .767 .914 r
.3662 .31672 .37353 .32384 .3855 .31949 .37822 .31182 Mtetra
.671 .749 .909 r
.37822 .31182 .3855 .31949 .39751 .31543 .39028 .30731 Mtetra
.662 .735 .904 r
.39028 .30731 .39751 .31543 .40956 .31165 .40238 .30305 Mtetra
.655 .721 .897 r
.40238 .30305 .40956 .31165 .42166 .30812 .41453 .29895 Mtetra
.652 .706 .887 r
.41453 .29895 .42166 .30812 .43381 .30471 .42673 .29492 Mtetra
.651 .692 .875 r
.42673 .29492 .43381 .30471 .44603 .30125 .43899 .29086 Mtetra
.652 .68 .864 r
.43899 .29086 .44603 .30125 .45832 .29749 .45131 .28668 Mtetra
.655 .673 .855 r
.45131 .28668 .45832 .29749 .47068 .29326 .4637 .28231 Mtetra
.66 .673 .852 r
.4637 .28231 .47068 .29326 .4831 .28851 .47614 .27773 Mtetra
.664 .679 .855 r
.47614 .27773 .4831 .28851 .49557 .28335 .48864 .273 Mtetra
.666 .69 .863 r
.48864 .273 .49557 .28335 .5081 .27803 .5012 .26822 Mtetra
.666 .703 .874 r
.5012 .26822 .5081 .27803 .52068 .27279 .51381 .26351 Mtetra
.662 .715 .888 r
.51381 .26351 .52068 .27279 .53331 .26781 .52647 .25899 Mtetra
.652 .724 .901 r
.52647 .25899 .53331 .26781 .546 .26325 .5392 .2548 Mtetra
.635 .728 .915 r
.5392 .2548 .546 .26325 .55876 .25922 .55199 .25114 Mtetra
.603 .727 .932 r
.55199 .25114 .55876 .25922 .57158 .25589 .56487 .24829 Mtetra
.548 .719 .952 r
.56487 .24829 .57158 .25589 .5845 .25352 .57783 .24663 Mtetra
.45 .697 .972 r
.57783 .24663 .5845 .25352 .59752 .25237 .59092 .24654 Mtetra
.279 .64 .965 r
.59092 .24654 .59752 .25237 .61067 .25265 .60415 .24833 Mtetra
.018 .515 .871 r
.60415 .24833 .61067 .25265 .62398 .25437 .61756 .25202 Mtetra
.256 0 0 r
.61756 .25202 .62398 .25437 .63744 .25719 .63116 .25717 Mtetra
.419 0 0 r
.63116 .25717 .63744 .25719 .65104 .26038 .64493 .26283 Mtetra
.456 0 0 r
.64493 .26283 .65104 .26038 .66475 .2629 .65881 .26759 Mtetra
.404 0 0 r
.65881 .26759 .66475 .2629 .6785 .26366 .67273 .26999 Mtetra
.308 0 0 r
.67273 .26999 .6785 .26366 .69225 .26241 .68663 .26939 Mtetra
.275 0 0 r
.68663 .26939 .69225 .26241 .70612 .26142 .70057 .26768 Mtetra
.456 0 0 r
.70057 .26768 .70612 .26142 .72051 .26712 .71489 .27076 Mtetra
.702 .185 0 r
.71489 .27076 .72051 .26712 .73596 .28601 .73007 .28462 Mtetra
.737 .215 0 r
.73007 .28462 .73596 .28601 .7522 .31179 .74587 .30366 Mtetra
.306 .588 .943 r
.74587 .30366 .7522 .31179 .76746 .32031 .76074 .30667 Mtetra
.893 .737 .68 r
.76074 .30667 .76746 .32031 .78005 .29389 .77331 .27894 Mtetra
.937 .727 .594 r
.77331 .27894 .78005 .29389 .79068 .24623 .78421 .23341 Mtetra
.941 .747 .613 r
.78421 .23341 .79068 .24623 .80149 .20423 .79535 .19393 Mtetra
.817 .351 0 r
.1592 .40653 .16708 .41453 .17606 .43149 .16821 .42291 Mtetra
.867 .428 .031 r
.16821 .42291 .17606 .43149 .18487 .45189 .17703 .44285 Mtetra
.815 .359 0 r
.17703 .44285 .18487 .45189 .19421 .46922 .18629 .46058 Mtetra
0 .097 .613 r
.18629 .46058 .19421 .46922 .20472 .47644 .19658 .46986 Mtetra
.572 .748 .96 r
.19658 .46986 .20472 .47644 .2166 .47034 .20812 .46776 Mtetra
.849 .887 .866 r
.20812 .46776 .2166 .47034 .22948 .45355 .22059 .45622 Mtetra
.913 .966 .798 r
.22059 .45622 .22948 .45355 .24273 .43208 .23349 .4399 Mtetra
.826 .976 .676 r
.23349 .4399 .24273 .43208 .25586 .41123 .24643 .42275 Mtetra
.592 .838 .47 r
.24643 .42275 .25586 .41123 .26869 .39336 .25926 .40639 Mtetra
0 0 0 r
.25926 .40639 .26869 .39336 .28124 .37846 .272 .39076 Mtetra
.272 .39076 .28124 .37846 .29361 .36566 .28468 .37553 Mtetra
.575 .845 .498 r
.28468 .37553 .29361 .36566 .30587 .35439 .29728 .36087 Mtetra
.72 .956 .674 r
.29728 .36087 .30587 .35439 .31804 .34445 .30979 .34732 Mtetra
.809 1 .822 r
.30979 .34732 .31804 .34445 .33013 .33583 .32218 .33543 Mtetra
.819 .967 .899 r
.32218 .33543 .33013 .33583 .34217 .32848 .33445 .32542 Mtetra
.786 .903 .924 r
.33445 .32542 .34217 .32848 .35419 .32219 .34663 .31719 Mtetra
.745 .843 .925 r
.34663 .31719 .35419 .32219 .3662 .31672 .35875 .31039 Mtetra
.711 .799 .919 r
.35875 .31039 .3662 .31672 .37822 .31182 .37086 .30464 Mtetra
.688 .769 .913 r
.37086 .30464 .37822 .31182 .39028 .30731 .38298 .29957 Mtetra
.674 .751 .909 r
.38298 .29957 .39028 .30731 .40238 .30305 .39513 .2949 Mtetra
.666 .738 .904 r
.39513 .2949 .40238 .30305 .41453 .29895 .40732 .29046 Mtetra
.662 .729 .899 r
.40732 .29046 .41453 .29895 .42673 .29492 .41956 .28611 Mtetra
.66 .721 .894 r
.41956 .28611 .42673 .29492 .43899 .29086 .43186 .28179 Mtetra
.66 .715 .889 r
.43186 .28179 .43899 .29086 .45131 .28668 .44422 .27742 Mtetra
.661 .712 .886 r
.44422 .27742 .45131 .28668 .4637 .28231 .45664 .27297 Mtetra
.663 .712 .884 r
.45664 .27297 .4637 .28231 .47614 .27773 .46911 .26845 Mtetra
.664 .715 .886 r
.46911 .26845 .47614 .27773 .48864 .273 .48164 .26388 Mtetra
.664 .719 .89 r
.48164 .26388 .48864 .273 .5012 .26822 .49423 .25931 Mtetra
.662 .725 .896 r
.49423 .25931 .5012 .26822 .51381 .26351 .50687 .25482 Mtetra
.656 .729 .903 r
.50687 .25482 .51381 .26351 .52647 .25899 .51958 .25049 Mtetra
.645 .731 .912 r
.51958 .25049 .52647 .25899 .5392 .2548 .53234 .24651 Mtetra
.623 .73 .924 r
.53234 .24651 .5392 .2548 .55199 .25114 .54517 .24314 Mtetra
.582 .723 .94 r
.54517 .24314 .55199 .25114 .56487 .24829 .55809 .24076 Mtetra
.507 .705 .96 r
.55809 .24076 .56487 .24829 .57783 .24663 .57111 .23987 Mtetra
.366 .659 .97 r
.57111 .23987 .57783 .24663 .59092 .24654 .58425 .24097 Mtetra
.12 .549 .919 r
.58425 .24097 .59092 .24654 .60415 .24833 .59757 .24447 Mtetra
0 .343 .727 r
.59757 .24447 .60415 .24833 .61756 .25202 .61109 .25037 Mtetra
.465 0 0 r
.61109 .25037 .61756 .25202 .63116 .25717 .62483 .25816 Mtetra
.571 0 0 r
.62483 .25816 .63116 .25717 .64493 .26283 .63876 .2666 Mtetra
.571 .029 0 r
.63876 .2666 .64493 .26283 .65881 .26759 .65283 .27391 Mtetra
.499 0 0 r
.65283 .27391 .65881 .26759 .67273 .26999 .66694 .27818 Mtetra
.379 0 0 r
.66694 .27818 .67273 .26999 .68663 .26939 .68099 .27832 Mtetra
.29 0 0 r
.68099 .27832 .68663 .26939 .70057 .26768 .69501 .27584 Mtetra
.381 0 0 r
.69501 .27584 .70057 .26768 .71489 .27076 .70928 .2761 Mtetra
.602 .08 0 r
.70928 .2761 .71489 .27076 .73007 .28462 .7242 .2847 Mtetra
.626 .062 0 r
.7242 .2847 .73007 .28462 .74587 .30366 .73957 .29685 Mtetra
.556 .77 .978 r
.73957 .29685 .74587 .30366 .76074 .30667 .75409 .29428 Mtetra
.911 .754 .674 r
.75409 .29428 .76074 .30667 .77331 .27894 .76661 .26505 Mtetra
.941 .737 .6 r
.76661 .26505 .77331 .27894 .78421 .23341 .77777 .22131 Mtetra
.942 .756 .623 r
.77777 .22131 .78421 .23341 .79535 .19393 .78919 .18399 Mtetra
.773 .303 0 r
.15136 .39769 .1592 .40653 .16821 .42291 .16044 .4131 Mtetra
.839 .399 0 r
.16044 .4131 .16821 .42291 .17703 .44285 .1693 .43226 Mtetra
.785 .342 0 r
.1693 .43226 .17703 .44285 .18629 .46058 .17848 .45021 Mtetra
0 0 .54 r
.17848 .45021 .18629 .46058 .19658 .46986 .18854 .46168 Mtetra
.294 .574 .936 r
.18854 .46168 .19658 .46986 .20812 .46776 .19964 .46414 Mtetra
.688 .872 .968 r
.19964 .46414 .20812 .46776 .22059 .45622 .21157 .4589 Mtetra
.741 .993 .856 r
.21157 .4589 .22059 .45622 .23349 .4399 .22396 .44919 Mtetra
0 0 0 r
.22396 .44919 .23349 .4399 .24643 .42275 .23654 .43741 Mtetra
.23654 .43741 .24643 .42275 .25926 .40639 .24926 .42409 Mtetra
.24926 .42409 .25926 .40639 .272 .39076 .26212 .40883 Mtetra
.26212 .40883 .272 .39076 .28468 .37553 .2751 .3916 Mtetra
.2751 .3916 .28468 .37553 .29728 .36087 .28812 .37331 Mtetra
.59 .819 .429 r
.28812 .37331 .29728 .36087 .30979 .34732 .30107 .35538 Mtetra
.752 .947 .624 r
.30107 .35538 .30979 .34732 .32218 .33543 .31385 .33914 Mtetra
.84 .999 .786 r
.31385 .33914 .32218 .33543 .33445 .32542 .32644 .32535 Mtetra
.843 .971 .88 r
.32644 .32535 .33445 .32542 .34663 .31719 .33887 .31418 Mtetra
.8 .906 .914 r
.33887 .31418 .34663 .31719 .35875 .31039 .35116 .3053 Mtetra
.752 .844 .92 r
.35116 .3053 .35875 .31039 .37086 .30464 .36339 .29818 Mtetra
.714 .798 .917 r
.36339 .29818 .37086 .30464 .38298 .29957 .37559 .29226 Mtetra
.689 .769 .912 r
.37559 .29226 .38298 .29957 .39513 .2949 .38779 .28709 Mtetra
.675 .752 .909 r
.38779 .28709 .39513 .2949 .40732 .29046 .40004 .28232 Mtetra
.668 .742 .906 r
.40004 .28232 .40732 .29046 .41956 .28611 .41232 .27776 Mtetra
.665 .736 .903 r
.41232 .27776 .41956 .28611 .43186 .28179 .42466 .27327 Mtetra
.663 .733 .901 r
.42466 .27327 .43186 .28179 .44422 .27742 .43705 .2688 Mtetra
.663 .731 .9 r
.43705 .2688 .44422 .27742 .45664 .27297 .4495 .26431 Mtetra
.4495 .26431 .45664 .27297 .46911 .26845 .46201 .25979 Mtetra
.663 .732 .901 r
.46201 .25979 .46911 .26845 .48164 .26388 .47458 .25526 Mtetra
.662 .733 .902 r
.47458 .25526 .48164 .26388 .49423 .25931 .4872 .25075 Mtetra
.659 .735 .906 r
.4872 .25075 .49423 .25931 .50687 .25482 .49988 .24632 Mtetra
.652 .735 .91 r
.49988 .24632 .50687 .25482 .51958 .25049 .51262 .24209 Mtetra
.638 .734 .917 r
.51262 .24209 .51958 .25049 .53234 .24651 .52542 .23825 Mtetra
.611 .728 .929 r
.52542 .23825 .53234 .24651 .54517 .24314 .53829 .23514 Mtetra
.56 .715 .945 r
.53829 .23514 .54517 .24314 .55809 .24076 .55125 .23324 Mtetra
.46 .685 .963 r
.55125 .23324 .55809 .24076 .57111 .23987 .56431 .23315 Mtetra
.271 .608 .955 r
.56431 .23315 .57111 .23987 .58425 .24097 .57752 .23552 Mtetra
0 .434 .842 r
.57752 .23552 .58425 .24097 .59757 .24447 .59092 .24081 Mtetra
.391 0 0 r
.59092 .24081 .59757 .24447 .61109 .25037 .60454 .24908 Mtetra
.596 .024 0 r
.60454 .24908 .61109 .25037 .62483 .25816 .61841 .25967 Mtetra
.661 .117 0 r
.61841 .25967 .62483 .25816 .63876 .2666 .63251 .27109 Mtetra
.642 .123 0 r
.63251 .27109 .63876 .2666 .65283 .27391 .64677 .28113 Mtetra
.559 .061 .029 r
.64677 .28113 .65283 .27391 .66694 .27818 .66107 .28739 Mtetra
.418 0 .016 r
.66107 .28739 .66694 .27818 .68099 .27832 .67527 .28833 Mtetra
.277 0 0 r
.67527 .28833 .68099 .27832 .69501 .27584 .68938 .28501 Mtetra
.284 0 0 r
.68938 .28501 .69501 .27584 .70928 .2761 .70361 .28235 Mtetra
.452 0 0 r
.70361 .28235 .70928 .2761 .7242 .2847 .71829 .28559 Mtetra
.399 0 0 r
.71829 .28559 .7242 .2847 .73957 .29685 .73327 .29088 Mtetra
.747 .87 .936 r
.73327 .29088 .73957 .29685 .75409 .29428 .74745 .28283 Mtetra
.926 .767 .665 r
.74745 .28283 .75409 .29428 .76661 .26505 .75995 .25202 Mtetra
.944 .746 .605 r
.75995 .25202 .76661 .26505 .77777 .22131 .77133 .20977 Mtetra
.942 .764 .632 r
.77133 .20977 .77777 .22131 .78919 .18399 .78301 .1743 Mtetra
.683 .217 0 r
.14355 .388 .15136 .39769 .16044 .4131 .15277 .40191 Mtetra
.77 .334 0 r
.15277 .40191 .16044 .4131 .1693 .43226 .16174 .4196 Mtetra
.693 .279 0 r
.16174 .4196 .1693 .43226 .17848 .45021 .17093 .43703 Mtetra
0 0 .558 r
.17093 .43703 .17848 .45021 .18854 .46168 .18079 .44999 Mtetra
.093 .355 .824 r
.18079 .44999 .18854 .46168 .19964 .46414 .19146 .45658 Mtetra
.375 .638 .958 r
.19146 .45658 .19964 .46414 .21157 .4589 .2028 .45773 Mtetra
.379 .826 .941 r
.2028 .45773 .21157 .4589 .22396 .44919 .21455 .45542 Mtetra
0 0 0 r
.21455 .45542 .22396 .44919 .23654 .43741 .22661 .45051 Mtetra
.034 0 0 r
.22661 .45051 .23654 .43741 .24926 .42409 .23901 .44219 Mtetra
0 0 0 r
.23901 .44219 .24926 .42409 .26212 .40883 .25183 .42925 Mtetra
.25183 .42925 .26212 .40883 .2751 .3916 .26502 .41154 Mtetra
.26502 .41154 .2751 .3916 .28812 .37331 .27842 .39042 Mtetra
.27842 .39042 .28812 .37331 .30107 .35538 .29184 .36818 Mtetra
.708 .875 .475 r
.29184 .36818 .30107 .35538 .31385 .33914 .3051 .34708 Mtetra
.827 .966 .645 r
.3051 .34708 .31385 .33914 .32644 .32535 .31811 .32868 Mtetra
.876 .994 .787 r
.31811 .32868 .32644 .32535 .33887 .31418 .33086 .31364 Mtetra
.857 .959 .873 r
.33086 .31364 .33887 .31418 .35116 .3053 .3434 .30186 Mtetra
.804 .895 .908 r
.3434 .30186 .35116 .3053 .36339 .29818 .35579 .29274 Mtetra
.751 .836 .916 r
.35579 .29274 .36339 .29818 .37559 .29226 .3681 .28555 Mtetra
.712 .793 .915 r
.3681 .28555 .37559 .29226 .38779 .28709 .38038 .27962 Mtetra
.688 .767 .912 r
.38038 .27962 .38779 .28709 .40004 .28232 .39268 .27442 Mtetra
.675 .752 .909 r
.39268 .27442 .40004 .28232 .41232 .27776 .40501 .26961 Mtetra
.668 .745 .908 r
.40501 .26961 .41232 .27776 .42466 .27327 .41738 .26499 Mtetra
.665 .741 .907 r
.41738 .26499 .42466 .27327 .43705 .2688 .42981 .26043 Mtetra
.664 .739 .906 r
.42981 .26043 .43705 .2688 .4495 .26431 .4423 .25589 Mtetra
.4423 .25589 .4495 .26431 .46201 .25979 .45484 .25134 Mtetra
.663 .739 .906 r
.45484 .25134 .46201 .25979 .47458 .25526 .46745 .2468 Mtetra
.661 .739 .908 r
.46745 .2468 .47458 .25526 .4872 .25075 .48011 .24228 Mtetra
.658 .739 .91 r
.48011 .24228 .4872 .25075 .49988 .24632 .49282 .23787 Mtetra
.65 .737 .913 r
.49282 .23787 .49988 .24632 .51262 .24209 .5056 .23368 Mtetra
.633 .734 .92 r
.5056 .23368 .51262 .24209 .52542 .23825 .51844 .22996 Mtetra
.601 .725 .932 r
.51844 .22996 .52542 .23825 .53829 .23514 .53135 .2271 Mtetra
.537 .706 .949 r
.53135 .2271 .53829 .23514 .55125 .23324 .54435 .22566 Mtetra
.412 .66 .962 r
.54435 .22566 .55125 .23324 .56431 .23315 .55745 .22636 Mtetra
.174 .547 .929 r
.55745 .22636 .56431 .23315 .57752 .23552 .57072 .22997 Mtetra
0 .319 .757 r
.57072 .22997 .57752 .23552 .59092 .24081 .58418 .23704 Mtetra
.512 0 0 r
.58418 .23704 .59092 .24081 .60454 .24908 .59789 .24765 Mtetra
.673 .123 0 r
.59789 .24765 .60454 .24908 .61841 .25967 .61189 .26103 Mtetra
.717 .192 0 r
.61189 .26103 .61841 .25967 .63251 .27109 .62614 .27542 Mtetra
.692 .184 .026 r
.62614 .27542 .63251 .27109 .64677 .28113 .64058 .28818 Mtetra
.603 .106 .046 r
.64058 .28818 .64677 .28113 .66107 .28739 .65506 .29643 Mtetra
.437 0 .014 r
.65506 .29643 .66107 .28739 .67527 .28833 .66942 .29814 Mtetra
.233 0 0 r
.66942 .29814 .67527 .28833 .68938 .28501 .68361 .29398 Mtetra
.142 0 0 r
.68361 .29398 .68938 .28501 .70361 .28235 .69781 .28839 Mtetra
.214 0 0 r
.69781 .28839 .70361 .28235 .71829 .28559 .71229 .28639 Mtetra
0 0 0 r
.71229 .28639 .71829 .28559 .73327 .29088 .72691 .28508 Mtetra
.856 .89 .861 r
.72691 .28508 .73327 .29088 .74745 .28283 .74081 .27184 Mtetra
.935 .773 .656 r
.74081 .27184 .74745 .28283 .75995 .25202 .75328 .23952 Mtetra
.946 .752 .61 r
.75328 .23952 .75995 .25202 .77133 .20977 .76488 .19858 Mtetra
.941 .77 .641 r
.76488 .19858 .77133 .20977 .78301 .1743 .7768 .16472 Mtetra
0 0 .463 r
.13576 .37767 .14355 .388 .15277 .40191 .14518 .38957 Mtetra
.627 .212 0 r
.14518 .38957 .15277 .40191 .16174 .4196 .15435 .40499 Mtetra
0 0 .435 r
.15435 .40499 .16174 .4196 .17093 .43703 .16367 .42079 Mtetra
0 .057 .621 r
.16367 .42079 .17093 .43703 .18079 .44999 .17347 .43385 Mtetra
.085 .257 .743 r
.17347 .43385 .18079 .44999 .19146 .45658 .18384 .44306 Mtetra
.191 .377 .818 r
.18384 .44306 .19146 .45658 .2028 .45773 .19465 .44935 Mtetra
.096 .456 .886 r
.19465 .44935 .2028 .45773 .21455 .45542 .20575 .45392 Mtetra
.177 0 0 r
.20575 .45392 .21455 .45542 .22661 .45051 .21717 .45637 Mtetra
.186 0 0 r
.21717 .45637 .22661 .45051 .23901 .44219 .22907 .45457 Mtetra
0 0 0 r
.22907 .45457 .23901 .44219 .25183 .42925 .24162 .44619 Mtetra
.24162 .44619 .25183 .42925 .26502 .41154 .2548 .43041 Mtetra
.2548 .43041 .26502 .41154 .27842 .39042 .26844 .40852 Mtetra
.626 .788 .345 r
.26844 .40852 .27842 .39042 .29184 .36818 .28226 .38331 Mtetra
.753 .874 .453 r
.28226 .38331 .29184 .36818 .3051 .34708 .29599 .35792 Mtetra
.844 .941 .574 r
.29599 .35792 .3051 .34708 .31811 .32868 .30945 .33485 Mtetra
.896 .98 .699 r
.30945 .33485 .31811 .32868 .33086 .31364 .3226 .31552 Mtetra
.898 .978 .807 r
.3226 .31552 .33086 .31364 .3434 .30186 .33543 .30023 Mtetra
.856 .936 .875 r
.33543 .30023 .3434 .30186 .35579 .29274 .34804 .28855 Mtetra
.796 .876 .906 r
.34804 .28855 .35579 .29274 .3681 .28555 .36049 .27964 Mtetra
.743 .824 .914 r
.36049 .27964 .3681 .28555 .38038 .27962 .37287 .27264 Mtetra
.706 .788 .914 r
.37287 .27264 .38038 .27962 .39268 .27442 .38524 .26683 Mtetra
.685 .766 .913 r
.38524 .26683 .39268 .27442 .40501 .26961 .39762 .26169 Mtetra
.673 .754 .912 r
.39762 .26169 .40501 .26961 .41738 .26499 .41004 .25688 Mtetra
.668 .748 .911 r
.41004 .25688 .41738 .26499 .42981 .26043 .42251 .25221 Mtetra
.665 .746 .91 r
.42251 .25221 .42981 .26043 .4423 .25589 .43503 .2476 Mtetra
.664 .745 .91 r
.43503 .2476 .4423 .25589 .45484 .25134 .44761 .24301 Mtetra
.663 .744 .91 r
.44761 .24301 .45484 .25134 .46745 .2468 .46025 .23843 Mtetra
.661 .744 .911 r
.46025 .23843 .46745 .2468 .48011 .24228 .47295 .23389 Mtetra
.657 .742 .913 r
.47295 .23389 .48011 .24228 .49282 .23787 .48571 .22946 Mtetra
.648 .74 .917 r
.48571 .22946 .49282 .23787 .5056 .23368 .49852 .22529 Mtetra
.629 .735 .924 r
.49852 .22529 .5056 .23368 .51844 .22996 .5114 .22166 Mtetra
.59 .723 .936 r
.5114 .22166 .51844 .22996 .53135 .2271 .52435 .21901 Mtetra
.515 .697 .952 r
.52435 .21901 .53135 .2271 .54435 .22566 .53738 .21798 Mtetra
.366 .635 .957 r
.53738 .21798 .54435 .22566 .55745 .22636 .55053 .2194 Mtetra
.09 .487 .898 r
.55053 .2194 .55745 .22636 .57072 .22997 .56383 .22412 Mtetra
0 .226 .685 r
.56383 .22412 .57072 .22997 .58418 .23704 .57735 .23282 Mtetra
.581 .034 0 r
.57735 .23282 .58418 .23704 .59789 .24765 .59114 .24555 Mtetra
.716 .184 0 r
.59114 .24555 .59789 .24765 .61189 .26103 .60524 .26147 Mtetra
.753 .239 0 r
.60524 .26147 .61189 .26103 .62614 .27542 .61963 .27856 Mtetra
.728 .22 .017 r
.61963 .27856 .62614 .27542 .64058 .28818 .63421 .2938 Mtetra
.636 .125 .017 r
.63421 .2938 .64058 .28818 .65506 .29643 .64885 .30385 Mtetra
.436 0 0 r
.64885 .30385 .65506 .29643 .66942 .29814 .66335 .30625 Mtetra
.131 0 0 r
.66335 .30625 .66942 .29814 .68361 .29398 .67764 .30125 Mtetra
0 0 0 r
.67764 .30125 .68361 .29398 .69781 .28839 .69181 .29288 Mtetra
.69181 .29288 .69781 .28839 .71229 .28639 .70611 .28597 Mtetra
.581 .943 .891 r
.70611 .28597 .71229 .28639 .72691 .28508 .72044 .27861 Mtetra
.904 .868 .794 r
.72044 .27861 .72691 .28508 .74081 .27184 .73411 .2607 Mtetra
.938 .772 .649 r
.73411 .2607 .74081 .27184 .75328 .23952 .74659 .22714 Mtetra
.945 .755 .615 r
.74659 .22714 .75328 .23952 .76488 .19858 .75839 .18746 Mtetra
.938 .773 .651 r
.75839 .18746 .76488 .19858 .7768 .16472 .77053 .15507 Mtetra
0 .094 .637 r
.12793 .36716 .13576 .37767 .14518 .38957 .1376 .37671 Mtetra
0 0 .539 r
.1376 .37671 .14518 .38957 .15435 .40499 .14707 .38926 Mtetra
0 .027 .599 r
.14707 .38926 .15435 .40499 .16367 .42079 .15663 .40236 Mtetra
.008 .167 .681 r
.15663 .40236 .16367 .42079 .17347 .43385 .16654 .4139 Mtetra
.172 .259 .713 r
.16654 .4139 .17347 .43385 .18384 .44306 .17681 .42357 Mtetra
.195 .282 .726 r
.17681 .42357 .18384 .44306 .19465 .44935 .18729 .43264 Mtetra
.095 .257 .74 r
.18729 .43264 .19465 .44935 .20575 .45392 .19788 .44204 Mtetra
0 .241 .757 r
.19788 .44204 .20575 .45392 .21717 .45637 .20869 .45071 Mtetra
0 .38 .787 r
.20869 .45071 .21717 .45637 .22907 .45457 .22 .45562 Mtetra
.187 .719 .762 r
.22 .45562 .22907 .45457 .24162 .44619 .23207 .45334 Mtetra
.56 .887 .625 r
.23207 .45334 .24162 .44619 .2548 .43041 .24499 .44199 Mtetra
.738 .912 .544 r
.24499 .44199 .2548 .43041 .26844 .40852 .25861 .42217 Mtetra
.823 .918 .524 r
.25861 .42217 .26844 .40852 .28226 .38331 .27263 .39656 Mtetra
.873 .928 .544 r
.27263 .39656 .28226 .38331 .29599 .35792 .2867 .3688 Mtetra
.907 .946 .593 r
.2867 .3688 .29599 .35792 .30945 .33485 .30057 .34221 Mtetra
.927 .965 .666 r
.30057 .34221 .30945 .33485 .3226 .31552 .3141 .31905 Mtetra
.926 .972 .752 r
.3141 .31905 .3226 .31552 .33543 .30023 .32726 .30027 Mtetra
.895 .955 .832 r
.32726 .30027 .33543 .30023 .34804 .28855 .34011 .28579 Mtetra
.84 .913 .885 r
.34011 .28579 .34804 .28855 .36049 .27964 .35274 .27487 Mtetra
.779 .862 .911 r
.35274 .27487 .36049 .27964 .37287 .27264 .36525 .26655 Mtetra
.731 .82 .92 r
.36525 .26655 .37287 .27264 .38524 .26683 .37769 .25993 Mtetra
.699 .791 .922 r
.37769 .25993 .38524 .26683 .39762 .26169 .39014 .25433 Mtetra
.681 .774 .921 r
.39014 .25433 .39762 .26169 .41004 .25688 .40261 .24926 Mtetra
.672 .765 .921 r
.40261 .24926 .41004 .25688 .42251 .25221 .41512 .24445 Mtetra
.668 .761 .92 r
.41512 .24445 .42251 .25221 .43503 .2476 .42768 .23974 Mtetra
.666 .759 .92 r
.42768 .23974 .43503 .2476 .44761 .24301 .44031 .23508 Mtetra
.664 .757 .92 r
.44031 .23508 .44761 .24301 .46025 .23843 .45299 .23043 Mtetra
.662 .756 .92 r
.45299 .23043 .46025 .23843 .47295 .23389 .46572 .22584 Mtetra
.657 .754 .921 r
.46572 .22584 .47295 .23389 .48571 .22946 .47852 .22137 Mtetra
.647 .75 .925 r
.47852 .22137 .48571 .22946 .49852 .22529 .49138 .21718 Mtetra
.625 .743 .932 r
.49138 .21718 .49852 .22529 .5114 .22166 .50429 .21359 Mtetra
.581 .728 .944 r
.50429 .21359 .5114 .22166 .52435 .21901 .51728 .21107 Mtetra
.495 .694 .957 r
.51728 .21107 .52435 .21901 .53738 .21798 .53034 .21035 Mtetra
.324 .615 .954 r
.53034 .21035 .53738 .21798 .55053 .2194 .54353 .21231 Mtetra
.022 .438 .868 r
.54353 .21231 .55053 .2194 .56383 .22412 .55687 .21792 Mtetra
0 .161 .636 r
.55687 .21792 .56383 .22412 .57735 .23282 .57043 .22789 Mtetra
.614 .083 0 r
.57043 .22789 .57735 .23282 .59114 .24555 .58428 .24232 Mtetra
.735 .217 0 r
.58428 .24232 .59114 .24555 .60524 .26147 .59845 .26027 Mtetra
.771 .262 0 r
.59845 .26027 .60524 .26147 .61963 .27856 .61293 .27952 Mtetra
.75 .236 0 r
.61293 .27952 .61963 .27856 .63421 .2938 .62763 .29674 Mtetra
.654 .117 0 r
.62763 .29674 .63421 .2938 .64885 .30385 .64239 .30821 Mtetra
.395 0 0 r
.64239 .30821 .64885 .30385 .66335 .30625 .65702 .3111 Mtetra
0 0 0 r
.65702 .3111 .66335 .30625 .67764 .30125 .67138 .30532 Mtetra
.482 .852 .616 r
.67138 .30532 .67764 .30125 .69181 .29288 .68555 .29448 Mtetra
.666 .967 .781 r
.68555 .29448 .69181 .29288 .70611 .28597 .69972 .28324 Mtetra
.843 .969 .881 r
.69972 .28324 .70611 .28597 .72044 .27861 .71381 .2706 Mtetra
.918 .832 .745 r
.71381 .2706 .72044 .27861 .73411 .2607 .72731 .24882 Mtetra
.935 .764 .645 r
.72731 .24882 .73411 .2607 .74659 .22714 .73983 .21445 Mtetra
.94 .753 .622 r
.73983 .21445 .74659 .22714 .75839 .18746 .75184 .17613 Mtetra
.932 .773 .66 r
.75184 .17613 .75839 .18746 .77053 .15507 .76419 .1452 Mtetra
0 .26 .767 r
.11998 .35711 .12793 .36716 .1376 .37671 .12993 .36431 Mtetra
0 .156 .697 r
.12993 .36431 .1376 .37671 .14707 .38926 .13972 .37378 Mtetra
0 .2 .717 r
.13972 .37378 .14707 .38926 .15663 .40236 .14962 .38357 Mtetra
.181 .278 .729 r
.14962 .38357 .15663 .40236 .16654 .4139 .15979 .39233 Mtetra
.274 .308 .716 r
.15979 .39233 .16654 .4139 .17681 .42357 .17017 .40045 Mtetra
.259 .285 .698 r
.17017 .40045 .17681 .42357 .18729 .43264 .18057 .40959 Mtetra
.169 .227 .68 r
.18057 .40959 .18729 .43264 .19788 .44204 .19091 .42086 Mtetra
.072 .182 .674 r
.19091 .42086 .19788 .44204 .20869 .45071 .2013 .43318 Mtetra
.083 .24 .728 r
.2013 .43318 .20869 .45071 .22 .45562 .21209 .44326 Mtetra
.317 .486 .868 r
.21209 .44326 .22 .45562 .23207 .45334 .22361 .44705 Mtetra
.692 .805 .935 r
.22361 .44705 .23207 .45334 .24499 .44199 .23606 .44164 Mtetra
.896 .933 .832 r
.23606 .44164 .24499 .44199 .25861 .42217 .24938 .42652 Mtetra
.952 .947 .726 r
.24938 .42652 .25861 .42217 .27263 .39656 .26331 .40363 Mtetra
.963 .942 .669 r
.26331 .40363 .27263 .39656 .2867 .3688 .27749 .37642 Mtetra
.962 .942 .655 r
.27749 .37642 .2867 .3688 .30057 .34221 .2916 .34863 Mtetra
.957 .949 .676 r
.2916 .34863 .30057 .34221 .3141 .31905 .30542 .32319 Mtetra
.944 .959 .726 r
.30542 .32319 .3141 .31905 .32726 .30027 .31887 .30179 Mtetra
.918 .963 .793 r
.31887 .30179 .32726 .30027 .34011 .28579 .33197 .28488 Mtetra
.873 .949 .859 r
.33197 .28488 .34011 .28579 .35274 .27487 .3448 .272 Mtetra
.814 .917 .907 r
.3448 .272 .35274 .27487 .36525 .26655 .35744 .26228 Mtetra
.758 .88 .934 r
.35744 .26228 .36525 .26655 .37769 .25993 .36999 .25475 Mtetra
.716 .848 .945 r
.36999 .25475 .37769 .25993 .39014 .25433 .38251 .24858 Mtetra
.69 .827 .949 r
.38251 .24858 .39014 .25433 .40261 .24926 .39504 .24317 Mtetra
.676 .814 .949 r
.39504 .24317 .40261 .24926 .41512 .24445 .4076 .23815 Mtetra
.67 .807 .949 r
.4076 .23815 .41512 .24445 .42768 .23974 .42022 .23329 Mtetra
.667 .803 .948 r
.42022 .23329 .42768 .23974 .44031 .23508 .43289 .22849 Mtetra
.665 .8 .947 r
.43289 .22849 .44031 .23508 .45299 .23043 .44562 .22373 Mtetra
.663 .796 .946 r
.44562 .22373 .45299 .23043 .46572 .22584 .4584 .21901 Mtetra
.658 .792 .946 r
.4584 .21901 .46572 .22584 .47852 .22137 .47125 .21443 Mtetra
.646 .786 .949 r
.47125 .21443 .47852 .22137 .49138 .21718 .48415 .21015 Mtetra
.621 .776 .955 r
.48415 .21015 .49138 .21718 .50429 .21359 .49711 .20649 Mtetra
.57 .755 .965 r
.49711 .20649 .50429 .21359 .51728 .21107 .51013 .20397 Mtetra
.468 .711 .974 r
.51013 .20397 .51728 .21107 .53034 .21035 .52324 .20335 Mtetra
.274 .609 .955 r
.52324 .20335 .53034 .21035 .54353 .21231 .53646 .20558 Mtetra
0 .401 .838 r
.53646 .20558 .54353 .21231 .55687 .21792 .54983 .21169 Mtetra
0 .118 .595 r
.54983 .21169 .55687 .21792 .57043 .22789 .56343 .22243 Mtetra
.629 .107 0 r
.56343 .22243 .57043 .22789 .58428 .24232 .57731 .2379 Mtetra
.736 .227 0 r
.57731 .2379 .58428 .24232 .59845 .26027 .59152 .25711 Mtetra
.769 .265 0 r
.59152 .25711 .59845 .26027 .61293 .27952 .60606 .2777 Mtetra
.747 .227 0 r
.60606 .2777 .61293 .27952 .62763 .29674 .62083 .29615 Mtetra
.633 .07 0 r
.62083 .29615 .62763 .29674 .64239 .30821 .63568 .30845 Mtetra
.246 0 0 r
.63568 .30845 .64239 .30821 .65702 .3111 .65039 .31154 Mtetra
.482 .899 .848 r
.65039 .31154 .65702 .3111 .67138 .30532 .66481 .30501 Mtetra
.807 .998 .846 r
.66481 .30501 .67138 .30532 .68555 .29448 .67899 .29213 Mtetra
.879 .97 .845 r
.67899 .29213 .68555 .29448 .69972 .28324 .69306 .27733 Mtetra
.897 .885 .812 r
.69306 .27733 .69972 .28324 .71381 .2706 .70699 .26045 Mtetra
.913 .793 .714 r
.70699 .26045 .71381 .2706 .72731 .24882 .72039 .23574 Mtetra
.927 .751 .644 r
.72039 .23574 .72731 .24882 .73983 .21445 .73298 .20116 Mtetra
.933 .749 .63 r
.73298 .20116 .73983 .21445 .75184 .17613 .74521 .16442 Mtetra
.924 .77 .67 r
.74521 .16442 .75184 .17613 .76419 .1452 .75777 .13502 Mtetra
.008 .387 .846 r
.1118 .34844 .11998 .35711 .12993 .36431 .12199 .35361 Mtetra
0 .311 .803 r
.12199 .35361 .12993 .36431 .13972 .37378 .1321 .36028 Mtetra
.143 .345 .805 r
.1321 .36028 .13972 .37378 .14962 .38357 .14236 .36681 Mtetra
.302 .385 .782 r
.14236 .36681 .14962 .38357 .15979 .39233 .15286 .37236 Mtetra
.359 .38 .747 r
.15286 .37236 .15979 .39233 .17017 .40045 .16349 .37772 Mtetra
.325 .332 .713 r
.16349 .37772 .17017 .40045 .18057 .40959 .17405 .38488 Mtetra
.232 .254 .679 r
.17405 .38488 .18057 .40959 .19091 .42086 .1844 .39527 Mtetra
.149 .192 .651 r
.1844 .39527 .19091 .42086 .2013 .43318 .19465 .40821 Mtetra
.154 .202 .66 r
.19465 .40821 .2013 .43318 .21209 .44326 .20512 .4208 Mtetra
.288 .316 .717 r
.20512 .4208 .21209 .44326 .22361 .44705 .21617 .42903 Mtetra
.515 .504 .783 r
.21617 .42903 .22361 .44705 .23606 .44164 .22809 .42942 Mtetra
.735 .686 .804 r
.22809 .42942 .23606 .44164 .24938 .42652 .24092 .42042 Mtetra
.875 .805 .778 r
.24092 .42042 .24938 .42652 .26331 .40363 .2545 .40278 Mtetra
.942 .871 .739 r
.2545 .40278 .26331 .40363 .27749 .37642 .26851 .37918 Mtetra
.965 .908 .709 r
.26851 .37918 .27749 .37642 .2916 .34863 .28263 .35309 Mtetra
.964 .934 .7 r
.28263 .35309 .2916 .34863 .30542 .32319 .29658 .32777 Mtetra
.947 .957 .716 r
.29658 .32777 .30542 .32319 .31887 .30179 .31022 .30544 Mtetra
.916 .979 .756 r
.31022 .30544 .31887 .30179 .33197 .28488 .32352 .28714 Mtetra
.869 .993 .814 r
.32352 .28714 .33197 .28488 .3448 .272 .33653 .27286 Mtetra
.806 .992 .875 r
.33653 .27286 .3448 .272 .35744 .26228 .34932 .26197 Mtetra
.74 .976 .923 r
.34932 .26197 .35744 .26228 .36999 .25475 .36199 .25356 Mtetra
.685 .953 .953 r
.36199 .25356 .36999 .25475 .38251 .24858 .3746 .24678 Mtetra
.65 .933 .969 r
.3746 .24678 .38251 .24858 .39504 .24317 .38722 .24095 Mtetra
.632 .92 .978 r
.38722 .24095 .39504 .24317 .4076 .23815 .39986 .23562 Mtetra
.627 .911 .982 r
.39986 .23562 .4076 .23815 .42022 .23329 .41254 .2305 Mtetra
.627 .906 .984 r
.41254 .2305 .42022 .23329 .43289 .22849 .42528 .22546 Mtetra
.631 .901 .985 r
.42528 .22546 .43289 .22849 .44562 .22373 .43808 .22044 Mtetra
.633 .896 .986 r
.43808 .22044 .44562 .22373 .4584 .21901 .45093 .21546 Mtetra
.631 .888 .987 r
.45093 .21546 .4584 .21901 .47125 .21443 .46384 .21059 Mtetra
.619 .878 .99 r
.46384 .21059 .47125 .21443 .48415 .21015 .4768 .20602 Mtetra
.59 .86 .994 r
.4768 .20602 .48415 .21015 .49711 .20649 .48982 .20208 Mtetra
.526 .827 .999 r
.48982 .20208 .49711 .20649 .51013 .20397 .5029 .1993 Mtetra
.398 .758 .993 r
.5029 .1993 .51013 .20397 .52324 .20335 .51606 .19846 Mtetra
.165 .612 .936 r
.51606 .19846 .52324 .20335 .53646 .20558 .52932 .20054 Mtetra
0 .358 .767 r
.52932 .20054 .53646 .20558 .54983 .21169 .54273 .20659 Mtetra
.468 0 0 r
.54273 .20659 .54983 .21169 .56343 .22243 .55635 .21738 Mtetra
.649 .123 0 r
.55635 .21738 .56343 .22243 .57731 .2379 .57025 .23302 Mtetra
.731 .225 0 r
.57025 .23302 .57731 .2379 .59152 .25711 .58448 .25247 Mtetra
.751 .25 0 r
.58448 .25247 .59152 .25711 .60606 .2777 .59903 .27334 Mtetra
.709 .192 0 r
.59903 .27334 .60606 .2777 .62083 .29615 .61383 .292 Mtetra
.53 0 0 r
.61383 .292 .62083 .29615 .63568 .30845 .62871 .30434 Mtetra
.059 .565 .883 r
.62871 .30434 .63568 .30845 .65039 .31154 .64347 .30719 Mtetra
.704 .911 .967 r
.64347 .30719 .65039 .31154 .66481 .30501 .65794 .29993 Mtetra
.872 .908 .852 r
.65794 .29993 .66481 .30501 .67899 .29213 .67213 .28546 Mtetra
.896 .866 .802 r
.67213 .28546 .67899 .29213 .69306 .27733 .68615 .26798 Mtetra
.892 .81 .76 r
.68615 .26798 .69306 .27733 .70699 .26045 .69998 .24798 Mtetra
.902 .76 .695 r
.69998 .24798 .70699 .26045 .72039 .23574 .71334 .2214 Mtetra
.917 .739 .646 r
.71334 .2214 .72039 .23574 .73298 .20116 .72606 .18725 Mtetra
.924 .743 .64 r
.72606 .18725 .73298 .20116 .74521 .16442 .73851 .15235 Mtetra
.915 .766 .681 r
.73851 .15235 .74521 .16442 .75777 .13502 .75129 .12458 Mtetra
0 .46 .864 r
.10322 .3422 .1118 .34844 .12199 .35361 .11359 .34595 Mtetra
.001 .418 .857 r
.11359 .34595 .12199 .35361 .1321 .36028 .12396 .35054 Mtetra
.19 .473 .891 r
.12396 .35054 .1321 .36028 .14236 .36681 .13452 .35453 Mtetra
.365 .507 .867 r
.13452 .35453 .14236 .36681 .15286 .37236 .14533 .35731 Mtetra
.419 .484 .82 r
.14533 .35731 .15286 .37236 .16349 .37772 .15626 .35985 Mtetra
.371 .414 .776 r
.15626 .35985 .16349 .37772 .17405 .38488 .16709 .36424 Mtetra
.26 .312 .727 r
.16709 .36424 .17405 .38488 .1844 .39527 .17765 .37214 Mtetra
.16 .221 .678 r
.17765 .37214 .1844 .39527 .19465 .40821 .188 .38342 Mtetra
.146 .198 .659 r
.188 .38342 .19465 .40821 .20512 .4208 .19839 .39593 Mtetra
.239 .262 .683 r
.19839 .39593 .20512 .4208 .21617 .42903 .20917 .40625 Mtetra
.408 .392 .73 r
.20917 .40625 .21617 .42903 .22809 .42942 .22065 .41097 Mtetra
.597 .547 .769 r
.22065 .41097 .22809 .42942 .24092 .42042 .23295 .40789 Mtetra
.762 .691 .784 r
.23295 .40789 .24092 .42042 .2545 .40278 .24602 .39668 Mtetra
.877 .807 .777 r
.24602 .39668 .2545 .40278 .26851 .37918 .25965 .37885 Mtetra
.94 .893 .755 r
.25965 .37885 .26851 .37918 .28263 .35309 .27354 .35712 Mtetra
.951 .949 .725 r
.27354 .35712 .28263 .35309 .29658 .32777 .28743 .33446 Mtetra
.909 .976 .69 r
.28743 .33446 .29658 .32777 .31022 .30544 .30113 .31333 Mtetra
.808 .965 .647 r
.30113 .31333 .31022 .30544 .32352 .28714 .31455 .29519 Mtetra
.657 .911 .596 r
.31455 .29519 .32352 .28714 .33653 .27286 .3277 .2805 Mtetra
.486 .828 .544 r
.3277 .2805 .33653 .27286 .34932 .26197 .34065 .26899 Mtetra
0 0 0 r
.34065 .26899 .34932 .26197 .36199 .25356 .35346 .25995 Mtetra
.35346 .25995 .36199 .25356 .3746 .24678 .3662 .25262 Mtetra
.3662 .25262 .3746 .24678 .38722 .24095 .37893 .24632 Mtetra
.37893 .24632 .38722 .24095 .39986 .23562 .39168 .24056 Mtetra
.39168 .24056 .39986 .23562 .41254 .2305 .40448 .23501 Mtetra
.40448 .23501 .41254 .2305 .42528 .22546 .41733 .22951 Mtetra
.41733 .22951 .42528 .22546 .43808 .22044 .43023 .22398 Mtetra
.43023 .22398 .43808 .22044 .45093 .21546 .44319 .21845 Mtetra
.295 .773 .676 r
.44319 .21845 .45093 .21546 .46384 .21059 .4562 .21299 Mtetra
.314 .793 .717 r
.4562 .21299 .46384 .21059 .4768 .20602 .46926 .20778 Mtetra
.306 .794 .75 r
.46926 .20778 .4768 .20602 .48982 .20208 .48237 .20317 Mtetra
.251 .762 .767 r
.48237 .20317 .48982 .20208 .5029 .1993 .49554 .19969 Mtetra
.12 .671 .748 r
.49554 .19969 .5029 .1993 .51606 .19846 .50877 .19813 Mtetra
.098 0 0 r
.50877 .19813 .51606 .19846 .52932 .20054 .5221 .19945 Mtetra
.355 0 0 r
.5221 .19945 .52932 .20054 .54273 .20659 .53555 .2047 Mtetra
.561 0 0 r
.53555 .2047 .54273 .20659 .55635 .21738 .54921 .21463 Mtetra
.682 .14 0 r
.54921 .21463 .55635 .21738 .57025 .23302 .56312 .22935 Mtetra
.736 .219 0 r
.56312 .22935 .57025 .23302 .58448 .25247 .57735 .24783 Mtetra
.734 .227 0 r
.57735 .24783 .58448 .25247 .59903 .27334 .59189 .26768 Mtetra
.654 .139 0 r
.59189 .26768 .59903 .27334 .61383 .292 .60667 .28533 Mtetra
0 .142 .624 r
.60667 .28533 .61383 .292 .62871 .30434 .62155 .29675 Mtetra
.302 .625 .96 r
.62155 .29675 .62871 .30434 .64347 .30719 .63632 .29877 Mtetra
.737 .806 .907 r
.63632 .29877 .64347 .30719 .65794 .29993 .65082 .29067 Mtetra
.853 .81 .807 r
.65082 .29067 .65794 .29993 .67213 .28546 .66503 .27501 Mtetra
.875 .789 .762 r
.66503 .27501 .67213 .28546 .68615 .26798 .67903 .25568 Mtetra
.877 .76 .729 r
.67903 .25568 .68615 .26798 .69998 .24798 .69283 .23363 Mtetra
.89 .736 .685 r
.69283 .23363 .69998 .24798 .71334 .2214 .7062 .20615 Mtetra
.907 .73 .65 r
.7062 .20615 .71334 .2214 .72606 .18725 .71907 .17303 Mtetra
.915 .741 .651 r
.71907 .17303 .72606 .18725 .73851 .15235 .73176 .1402 Mtetra
.907 .766 .694 r
.73176 .1402 .73851 .15235 .75129 .12458 .74476 .11414 Mtetra
0 .412 .716 r
.09412 .33909 .10322 .3422 .11359 .34595 .1046 .34218 Mtetra
0 .404 .738 r
.1046 .34218 .11359 .34595 .12396 .35054 .11513 .34566 Mtetra
.049 .539 .886 r
.11513 .34566 .12396 .35054 .13452 .35453 .12588 .3482 Mtetra
.307 .65 .97 r
.12588 .3482 .13452 .35453 .14533 .35731 .1369 .3493 Mtetra
.41 .648 .955 r
.1369 .3493 .14533 .35731 .15626 .35985 .14807 .3499 Mtetra
.354 .564 .916 r
.14807 .3499 .15626 .35985 .16709 .36424 .15916 .35196 Mtetra
.194 .412 .847 r
.15916 .35196 .16709 .36424 .17765 .37214 .17 .3572 Mtetra
.041 .257 .755 r
.17 .3572 .17765 .37214 .188 .38342 .18058 .36594 Mtetra
.005 .189 .703 r
.18058 .36594 .188 .38342 .19839 .39593 .19109 .3768 Mtetra
.096 .228 .711 r
.19109 .3768 .19839 .39593 .20917 .40625 .2018 .38724 Mtetra
.267 .342 .756 r
.2018 .38724 .20917 .40625 .22065 .41097 .213 .39439 Mtetra
.468 .498 .807 r
.213 .39439 .22065 .41097 .23295 .40789 .22487 .39595 Mtetra
.662 .669 .846 r
.22487 .39595 .23295 .40789 .24602 .39668 .23743 .39089 Mtetra
.82 .832 .858 r
.23743 .39089 .24602 .39668 .25965 .37885 .25057 .37963 Mtetra
.902 .957 .822 r
.25057 .37963 .25965 .37885 .27354 .35712 .26409 .36385 Mtetra
.85 .984 .703 r
.26409 .36385 .27354 .35712 .28743 .33446 .27775 .34587 Mtetra
.644 .869 .502 r
.27775 .34587 .28743 .33446 .30113 .31333 .29137 .32792 Mtetra
0 0 0 r
.29137 .32792 .30113 .31333 .31455 .29519 .30482 .3116 Mtetra
.30482 .3116 .31455 .29519 .3277 .2805 .31808 .29773 Mtetra
.025 0 0 r
.31808 .29773 .3277 .2805 .34065 .26899 .33117 .28639 Mtetra
.131 0 .031 r
.33117 .28639 .34065 .26899 .35346 .25995 .34414 .27717 Mtetra
.192 0 .06 r
.34414 .27717 .35346 .25995 .3662 .25262 .35705 .26947 Mtetra
.223 0 .071 r
.35705 .26947 .3662 .25262 .37893 .24632 .36995 .26269 Mtetra
.233 0 .069 r
.36995 .26269 .37893 .24632 .39168 .24056 .38287 .25637 Mtetra
.23 0 .058 r
.38287 .25637 .39168 .24056 .40448 .23501 .39583 .25017 Mtetra
.217 0 .04 r
.39583 .25017 .40448 .23501 .41733 .22951 .40885 .24393 Mtetra
.198 0 .017 r
.40885 .24393 .41733 .22951 .43023 .22398 .42191 .23756 Mtetra
.175 0 0 r
.42191 .23756 .43023 .22398 .44319 .21845 .43503 .23109 Mtetra
.15 0 0 r
.43503 .23109 .44319 .21845 .4562 .21299 .4482 .22459 Mtetra
.13 0 0 r
.4482 .22459 .4562 .21299 .46926 .20778 .46141 .21827 Mtetra
.122 0 0 r
.46141 .21827 .46926 .20778 .48237 .20317 .47467 .21246 Mtetra
.14 0 0 r
.47467 .21246 .48237 .20317 .49554 .19969 .48797 .20769 Mtetra
.198 0 0 r
.48797 .20769 .49554 .19969 .50877 .19813 .50132 .20473 Mtetra
.305 0 0 r
.50132 .20473 .50877 .19813 .5221 .19945 .51475 .20453 Mtetra
.446 0 0 r
.51475 .20453 .5221 .19945 .53555 .2047 .52828 .20808 Mtetra
.583 .037 0 r
.52828 .20808 .53555 .2047 .54921 .21463 .54199 .21612 Mtetra
.682 .145 0 r
.54199 .21612 .54921 .21463 .56312 .22935 .55593 .22872 Mtetra
.73 .202 0 r
.55593 .22872 .56312 .22935 .57735 .24783 .57015 .2449 Mtetra
.72 .193 0 r
.57015 .2449 .57735 .24783 .59189 .26768 .58467 .26236 Mtetra
.602 .072 0 r
.58467 .26236 .59189 .26768 .60667 .28533 .59941 .27771 Mtetra
0 .266 .746 r
.59941 .27771 .60667 .28533 .62155 .29675 .61425 .28713 Mtetra
.438 .644 .945 r
.61425 .28713 .62155 .29675 .63632 .29877 .62901 .28763 Mtetra
.742 .746 .855 r
.62901 .28763 .63632 .29877 .65082 .29067 .64352 .27847 Mtetra
.834 .754 .775 r
.64352 .27847 .65082 .29067 .66503 .27501 .65776 .26187 Mtetra
.858 .746 .738 r
.65776 .26187 .66503 .27501 .67903 .25568 .67177 .24137 Mtetra
.867 .733 .713 r
.67177 .24137 .67903 .25568 .69283 .23363 .68557 .2182 Mtetra
.882 .724 .681 r
.68557 .2182 .69283 .23363 .7062 .20615 .69901 .19063 Mtetra
.9 .727 .658 r
.69901 .19063 .7062 .20615 .71907 .17303 .71206 .15899 Mtetra
.91 .744 .663 r
.71206 .15899 .71907 .17303 .73176 .1402 .72499 .12837 Mtetra
.902 .772 .708 r
.72499 .12837 .73176 .1402 .74476 .11414 .73819 .10402 Mtetra
.328 0 0 r
.08457 .33846 .09412 .33909 .1046 .34218 .09508 .34155 Mtetra
.338 0 0 r
.09508 .34155 .1046 .34218 .11513 .34566 .10567 .34477 Mtetra
.206 0 0 r
.10567 .34477 .11513 .34566 .12588 .3482 .11649 .34694 Mtetra
.017 .586 .776 r
.11649 .34694 .12588 .3482 .1369 .3493 .12761 .34756 Mtetra
.152 .679 .869 r
.12761 .34756 .1369 .3493 .14807 .3499 .1389 .34744 Mtetra
.082 .62 .856 r
.1389 .34744 .14807 .3499 .15916 .35196 .15016 .34829 Mtetra
0 .424 .75 r
.15016 .34829 .15916 .35196 .17 .3572 .16122 .35169 Mtetra
0 .209 .625 r
.16122 .35169 .17 .3572 .18058 .36594 .17205 .35817 Mtetra
0 .101 .587 r
.17205 .35817 .18058 .36594 .19109 .3768 .18276 .367 Mtetra
0 .124 .648 r
.18276 .367 .19109 .3768 .2018 .38724 .19356 .37649 Mtetra
0 .257 .765 r
.19356 .37649 .2018 .38724 .213 .39439 .20466 .38449 Mtetra
.155 .462 .888 r
.20466 .38449 .213 .39439 .22487 .39595 .21624 .38905 Mtetra
.425 .702 .979 r
.21624 .38905 .22487 .39595 .23743 .39089 .22839 .38886 Mtetra
.623 .916 .979 r
.22839 .38886 .23743 .39089 .25057 .37963 .24107 .38365 Mtetra
.618 .95 .779 r
.24107 .38365 .25057 .37963 .26409 .36385 .25417 .37414 Mtetra
0 0 0 r
.25417 .37414 .26409 .36385 .27775 .34587 .26753 .3618 Mtetra
.26753 .3618 .27775 .34587 .29137 .32792 .28096 .34831 Mtetra
.021 0 .006 r
.28096 .34831 .29137 .32792 .30482 .3116 .29437 .33515 Mtetra
.145 0 .108 r
.29437 .33515 .30482 .3116 .31808 .29773 .30768 .32324 Mtetra
.228 0 .168 r
.30768 .32324 .31808 .29773 .33117 .28639 .32089 .31292 Mtetra
.281 0 .201 r
.32089 .31292 .33117 .28639 .34414 .27717 .33402 .30406 Mtetra
.312 0 .219 r
.33402 .30406 .34414 .27717 .35705 .26947 .34712 .29627 Mtetra
.327 0 .225 r
.34712 .29627 .35705 .26947 .36995 .26269 .36023 .28912 Mtetra
.33 0 .224 r
.36023 .28912 .36995 .26269 .38287 .25637 .37336 .28219 Mtetra
.325 0 .218 r
.37336 .28219 .38287 .25637 .39583 .25017 .38654 .2752 Mtetra
.315 0 .207 r
.38654 .2752 .39583 .25017 .40885 .24393 .39978 .26799 Mtetra
.3 0 .193 r
.39978 .26799 .40885 .24393 .42191 .23756 .41307 .2605 Mtetra
.283 0 .175 r
.41307 .2605 .42191 .23756 .43503 .23109 .42641 .25274 Mtetra
.265 0 .155 r
.42641 .25274 .43503 .23109 .4482 .22459 .43979 .24482 Mtetra
.248 0 .131 r
.43979 .24482 .4482 .22459 .46141 .21827 .45321 .23694 Mtetra
.239 0 .107 r
.45321 .23694 .46141 .21827 .47467 .21246 .46666 .22944 Mtetra
.243 0 .084 r
.46666 .22944 .47467 .21246 .48797 .20769 .48014 .22285 Mtetra
.271 0 .064 r
.48014 .22285 .48797 .20769 .50132 .20473 .49366 .21789 Mtetra
.33 0 .051 r
.49366 .21789 .50132 .20473 .51475 .20453 .50723 .21548 Mtetra
.421 0 .042 r
.50723 .21548 .51475 .20453 .52828 .20808 .52088 .21652 Mtetra
.526 .035 .032 r
.52088 .21652 .52828 .20808 .54199 .21612 .53467 .22172 Mtetra
.621 .108 .005 r
.53467 .22172 .54199 .21612 .55593 .22872 .54866 .23113 Mtetra
.68 .149 0 r
.54866 .23113 .55593 .22872 .57015 .2449 .56289 .24383 Mtetra
.672 .121 0 r
.56289 .24383 .57015 .2449 .58467 .26236 .57738 .2577 Mtetra
.505 0 0 r
.57738 .2577 .58467 .26236 .59941 .27771 .59207 .26962 Mtetra
.014 .42 .861 r
.59207 .26962 .59941 .27771 .61425 .28713 .60686 .27613 Mtetra
.54 .664 .917 r
.60686 .27613 .61425 .28713 .62901 .28763 .62158 .27451 Mtetra
.749 .714 .819 r
.62158 .27451 .62901 .28763 .64352 .27847 .63609 .26409 Mtetra
.821 .72 .754 r
.63609 .26409 .64352 .27847 .65776 .26187 .65035 .24676 Mtetra
.845 .719 .724 r
.65035 .24676 .65776 .26187 .67177 .24137 .6644 .22567 Mtetra
.857 .716 .705 r
.6644 .22567 .67177 .24137 .68557 .2182 .67824 .20213 Mtetra
.875 .717 .683 r
.67824 .20213 .68557 .2182 .69901 .19063 .69179 .17514 Mtetra
.894 .727 .668 r
.69179 .17514 .69901 .19063 .71206 .15899 .70503 .14532 Mtetra
.904 .748 .678 r
.70503 .14532 .71206 .15899 .72499 .12837 .71819 .11697 Mtetra
.897 .78 .724 r
.71819 .11697 .72499 .12837 .73819 .10402 .73161 .09431 Mtetra
.342 0 0 r
.07493 .33765 .08457 .33846 .09508 .34155 .08542 .34097 Mtetra
.353 0 0 r
.08542 .34097 .09508 .34155 .10567 .34477 .09602 .34434 Mtetra
.253 0 0 r
.09602 .34434 .10567 .34477 .11649 .34694 .10685 .34669 Mtetra
.093 0 0 r
.10685 .34669 .11649 .34694 .12761 .34756 .11797 .34757 Mtetra
.007 0 0 r
.11797 .34757 .12761 .34756 .1389 .34744 .12929 .34762 Mtetra
.085 0 0 r
.12929 .34762 .1389 .34744 .15016 .34829 .14062 .34821 Mtetra
.273 0 0 r
.14062 .34821 .15016 .34829 .16122 .35169 .15182 .35068 Mtetra
.442 0 0 r
.15182 .35068 .16122 .35169 .17205 .35817 .16285 .35559 Mtetra
.53 0 0 r
.16285 .35559 .17205 .35817 .18276 .367 .17377 .36262 Mtetra
.526 0 0 r
.17377 .36262 .18276 .367 .19356 .37649 .18472 .37071 Mtetra
.423 0 0 r
.18472 .37071 .19356 .37649 .20466 .38449 .19585 .37843 Mtetra
0 .301 .725 r
.19585 .37843 .20466 .38449 .21624 .38905 .20731 .38435 Mtetra
.005 .518 .859 r
.20731 .38435 .21624 .38905 .22839 .38886 .21919 .38727 Mtetra
.194 .712 .88 r
.21919 .38727 .22839 .38886 .24107 .38365 .23152 .38659 Mtetra
.237 .743 .691 r
.23152 .38659 .24107 .38365 .25417 .37414 .24425 .3824 Mtetra
0 0 0 r
.24425 .3824 .25417 .37414 .26753 .3618 .25727 .37538 Mtetra
.007 0 0 r
.25727 .37538 .26753 .3618 .28096 .34831 .27048 .36662 Mtetra
.12 0 .019 r
.27048 .36662 .28096 .34831 .29437 .33515 .28376 .35719 Mtetra
.202 0 .112 r
.28376 .35719 .29437 .33515 .30768 .32324 .29706 .34793 Mtetra
.259 0 .168 r
.29706 .34793 .30768 .32324 .32089 .31292 .31034 .33926 Mtetra
.296 0 .2 r
.31034 .33926 .32089 .31292 .33402 .30406 .32361 .33127 Mtetra
.316 0 .217 r
.32361 .33127 .33402 .30406 .34712 .29627 .33688 .32377 Mtetra
.324 0 .223 r
.33688 .32377 .34712 .29627 .36023 .28912 .35019 .31648 Mtetra
.322 0 .221 r
.35019 .31648 .36023 .28912 .37336 .28219 .36354 .30909 Mtetra
.313 0 .215 r
.36354 .30909 .37336 .28219 .38654 .2752 .37694 .3014 Mtetra
.298 0 .203 r
.37694 .3014 .38654 .2752 .39978 .26799 .39041 .29327 Mtetra
.279 0 .188 r
.39041 .29327 .39978 .26799 .41307 .2605 .40393 .28467 Mtetra
.257 0 .17 r
.40393 .28467 .41307 .2605 .42641 .25274 .41751 .27563 Mtetra
.234 0 .148 r
.41751 .27563 .42641 .25274 .43979 .24482 .43112 .26627 Mtetra
.212 0 .123 r
.43112 .26627 .43979 .24482 .45321 .23694 .44476 .25679 Mtetra
.196 0 .097 r
.44476 .25679 .45321 .23694 .46666 .22944 .45842 .24754 Mtetra
.191 0 .071 r
.45842 .24754 .46666 .22944 .48014 .22285 .4721 .23902 Mtetra
.206 0 .046 r
.4721 .23902 .48014 .22285 .49366 .21789 .4858 .2319 Mtetra
.25 0 .024 r
.4858 .2319 .49366 .21789 .50723 .21548 .49953 .22703 Mtetra
.325 0 .002 r
.49953 .22703 .50723 .21548 .52088 .21652 .51332 .22525 Mtetra
.422 0 0 r
.51332 .22525 .52088 .21652 .53467 .22172 .52721 .22717 Mtetra
.516 0 0 r
.52721 .22717 .53467 .22172 .54866 .23113 .54126 .23284 Mtetra
.567 0 0 r
.54126 .23284 .54866 .23113 .56289 .24383 .5555 .24144 Mtetra
.504 0 0 r
.5555 .24144 .56289 .24383 .57738 .2577 .56996 .25107 Mtetra
0 .312 .762 r
.56996 .25107 .57738 .2577 .59207 .26962 .5846 .25898 Mtetra
.318 .552 .918 r
.5846 .25898 .59207 .26962 .60686 .27613 .59933 .26216 Mtetra
.613 .64 .854 r
.59933 .26216 .60686 .27613 .62158 .27451 .61401 .25825 Mtetra
.741 .666 .777 r
.61401 .25825 .62158 .27451 .63609 .26409 .62851 .24665 Mtetra
.798 .678 .732 r
.62851 .24665 .63609 .26409 .65035 .24676 .6428 .22899 Mtetra
.823 .684 .711 r
.6428 .22899 .65035 .24676 .6644 .22567 .6569 .20795 Mtetra
.838 .691 .699 r
.6569 .20795 .6644 .22567 .67824 .20213 .67082 .18481 Mtetra
.858 .701 .686 r
.67082 .18481 .67824 .20213 .69179 .17514 .6845 .15904 Mtetra
.88 .719 .678 r
.6845 .15904 .69179 .17514 .70503 .14532 .69794 .13138 Mtetra
.891 .745 .693 r
.69794 .13138 .70503 .14532 .71819 .11697 .71134 .1054 Mtetra
.885 .779 .739 r
.71134 .1054 .71819 .11697 .73161 .09431 .72495 .08446 Mtetra
0 .459 .814 r
.06572 .33295 .07493 .33765 .08542 .34097 .07624 .33617 Mtetra
0 .464 .821 r
.07624 .33617 .08542 .34097 .09602 .34434 .08686 .33941 Mtetra
.063 .552 .892 r
.08686 .33941 .09602 .34434 .10685 .34669 .09771 .34176 Mtetra
.22 .652 .954 r
.09771 .34176 .10685 .34669 .11797 .34757 .10883 .34282 Mtetra
.299 .702 .976 r
.10883 .34282 .11797 .34757 .12929 .34762 .12014 .34308 Mtetra
.256 .685 .963 r
.12014 .34308 .12929 .34762 .14062 .34821 .13151 .34362 Mtetra
.107 .592 .909 r
.13151 .34362 .14062 .34821 .15182 .35068 .1428 .34547 Mtetra
0 .454 .826 r
.1428 .34547 .15182 .35068 .16285 .35559 .15399 .34912 Mtetra
0 .348 .775 r
.15399 .34912 .16285 .35559 .17377 .36262 .1651 .35443 Mtetra
0 .312 .781 r
.1651 .35443 .17377 .36262 .18472 .37071 .17623 .36076 Mtetra
0 .337 .816 r
.17623 .36076 .18472 .37071 .19585 .37843 .18748 .36726 Mtetra
.103 .398 .853 r
.18748 .36726 .19585 .37843 .20731 .38435 .19896 .37296 Mtetra
.245 .481 .886 r
.19896 .37296 .20731 .38435 .21919 .38727 .21073 .37699 Mtetra
.372 .582 .923 r
.21073 .37699 .21919 .38727 .23152 .38659 .22284 .37872 Mtetra
.479 .703 .968 r
.22284 .37872 .23152 .38659 .24425 .3824 .2353 .37792 Mtetra
.55 .834 .998 r
.2353 .37792 .24425 .3824 .25727 .37538 .24804 .37479 Mtetra
.533 .911 .944 r
.24804 .37479 .25727 .37538 .27048 .36662 .26101 .36984 Mtetra
.388 .838 .741 r
.26101 .36984 .27048 .36662 .28376 .35719 .27413 .36373 Mtetra
0 0 0 r
.27413 .36373 .28376 .35719 .29706 .34793 .28734 .35706 Mtetra
.28734 .35706 .29706 .34793 .31034 .33926 .30061 .35022 Mtetra
.03 0 0 r
.30061 .35022 .31034 .33926 .32361 .33127 .31392 .34337 Mtetra
.073 0 0 r
.31392 .34337 .32361 .33127 .33688 .32377 .32729 .33648 Mtetra
.086 0 0 r
.32729 .33648 .33688 .32377 .35019 .31648 .34071 .32938 Mtetra
.076 0 0 r
.34071 .32938 .35019 .31648 .36354 .30909 .3542 .32191 Mtetra
.049 0 0 r
.3542 .32191 .36354 .30909 .37694 .3014 .36776 .31392 Mtetra
.009 0 0 r
.36776 .31392 .37694 .3014 .39041 .29327 .38139 .30533 Mtetra
0 0 0 r
.38139 .30533 .39041 .29327 .40393 .28467 .39508 .29613 Mtetra
.39508 .29613 .40393 .28467 .41751 .27563 .40881 .28636 Mtetra
.40881 .28636 .41751 .27563 .43112 .26627 .42259 .27615 Mtetra
.42259 .27615 .43112 .26627 .44476 .25679 .4364 .26571 Mtetra
.4364 .26571 .44476 .25679 .45842 .24754 .45022 .25534 Mtetra
.45022 .25534 .45842 .24754 .4721 .23902 .46405 .24552 Mtetra
.46405 .24552 .4721 .23902 .4858 .2319 .4779 .23685 Mtetra
.4779 .23685 .4858 .2319 .49953 .22703 .49175 .23007 Mtetra
.49175 .23007 .49953 .22703 .51332 .22525 .50565 .22592 Mtetra
.50565 .22592 .51332 .22525 .52721 .22717 .51962 .22495 Mtetra
0 .525 .778 r
.51962 .22495 .52721 .22717 .54126 .23284 .53371 .22719 Mtetra
0 .466 .853 r
.53371 .22719 .54126 .23284 .5555 .24144 .54796 .23192 Mtetra
.126 .46 .888 r
.54796 .23192 .5555 .24144 .56996 .25107 .56238 .23753 Mtetra
.33 .492 .868 r
.56238 .23753 .56996 .25107 .5846 .25898 .57696 .24171 Mtetra
.506 .532 .817 r
.57696 .24171 .5846 .25898 .59933 .26216 .59161 .24189 Mtetra
.63 .567 .766 r
.59161 .24189 .59933 .26216 .61401 .25825 .60624 .23615 Mtetra
.709 .595 .726 r
.60624 .23615 .61401 .25825 .62851 .24665 .62074 .22397 Mtetra
.756 .615 .703 r
.62074 .22397 .62851 .24665 .6428 .22899 .63506 .20671 Mtetra
.782 .631 .693 r
.63506 .20671 .6428 .22899 .6569 .20795 .64922 .18659 Mtetra
.802 .647 .69 r
.64922 .18659 .6569 .20795 .67082 .18481 .66324 .16475 Mtetra
.826 .666 .685 r
.66324 .16475 .67082 .18481 .6845 .15904 .67707 .14092 Mtetra
.85 .692 .686 r
.67707 .14092 .6845 .15904 .69794 .13138 .69072 .11587 Mtetra
.863 .721 .705 r
.69072 .11587 .69794 .13138 .71134 .1054 .70435 .0925 Mtetra
.857 .754 .749 r
.70435 .0925 .71134 .1054 .72495 .08446 .71816 .07345 Mtetra
.333 .533 .9 r
.05732 .32209 .06572 .33295 .07624 .33617 .06795 .32448 Mtetra
.354 .524 .886 r
.06795 .32448 .07624 .33617 .08686 .33941 .07869 .32686 Mtetra
.415 .538 .872 r
.07869 .32686 .08686 .33941 .09771 .34176 .08962 .32848 Mtetra
.477 .555 .857 r
.08962 .32848 .09771 .34176 .10883 .34282 .1008 .32901 Mtetra
.509 .563 .846 r
.1008 .32901 .10883 .34282 .12014 .34308 .11216 .32885 Mtetra
.506 .554 .84 r
.11216 .32885 .12014 .34308 .13151 .34362 .12359 .32881 Mtetra
.473 .528 .833 r
.12359 .32881 .13151 .34362 .1428 .34547 .13499 .32967 Mtetra
.428 .488 .819 r
.13499 .32967 .1428 .34547 .15399 .34912 .14634 .33178 Mtetra
.393 .445 .796 r
.14634 .33178 .15399 .34912 .1651 .35443 .15765 .33507 Mtetra
.381 .413 .769 r
.15765 .33507 .1651 .35443 .17623 .36076 .16899 .33917 Mtetra
.391 .395 .744 r
.16899 .33917 .17623 .36076 .18748 .36726 .18041 .34356 Mtetra
.414 .391 .725 r
.18041 .34356 .18748 .36726 .19896 .37296 .19199 .34767 Mtetra
.445 .4 .714 r
.19199 .34767 .19896 .37296 .21073 .37699 .20378 .35094 Mtetra
.479 .417 .71 r
.20378 .35094 .21073 .37699 .22284 .37872 .21582 .35289 Mtetra
.513 .441 .713 r
.21582 .35289 .22284 .37872 .2353 .37792 .22812 .35323 Mtetra
.546 .47 .722 r
.22812 .35323 .2353 .37792 .24804 .37479 .24067 .35191 Mtetra
.576 .503 .735 r
.24067 .35191 .24804 .37479 .26101 .36984 .25343 .34909 Mtetra
.603 .536 .752 r
.25343 .34909 .26101 .36984 .27413 .36373 .26637 .34509 Mtetra
.625 .569 .771 r
.26637 .34509 .27413 .36373 .28734 .35706 .27944 .34025 Mtetra
.642 .599 .79 r
.27944 .34025 .28734 .35706 .30061 .35022 .29261 .33486 Mtetra
.657 .625 .806 r
.29261 .33486 .30061 .35022 .31392 .34337 .30587 .32906 Mtetra
.669 .646 .818 r
.30587 .32906 .31392 .34337 .32729 .33648 .31921 .32288 Mtetra
.681 .663 .826 r
.31921 .32288 .32729 .33648 .34071 .32938 .33263 .31628 Mtetra
.694 .677 .829 r
.33263 .31628 .34071 .32938 .3542 .32191 .34613 .30916 Mtetra
.707 .689 .83 r
.34613 .30916 .3542 .32191 .36776 .31392 .3597 .30145 Mtetra
.72 .699 .829 r
.3597 .30145 .36776 .31392 .38139 .30533 .37335 .2931 Mtetra
.733 .708 .827 r
.37335 .2931 .38139 .30533 .39508 .29613 .38707 .28412 Mtetra
.744 .716 .826 r
.38707 .28412 .39508 .29613 .40881 .28636 .40084 .27456 Mtetra
.753 .724 .825 r
.40084 .27456 .40881 .28636 .42259 .27615 .41465 .26454 Mtetra
.759 .729 .825 r
.41465 .26454 .42259 .27615 .4364 .26571 .4285 .25423 Mtetra
.761 .733 .827 r
.4285 .25423 .4364 .26571 .45022 .25534 .44237 .24391 Mtetra
.755 .733 .832 r
.44237 .24391 .45022 .25534 .46405 .24552 .45625 .23398 Mtetra
.739 .727 .841 r
.45625 .23398 .46405 .24552 .4779 .23685 .47014 .22494 Mtetra
.707 .71 .851 r
.47014 .22494 .4779 .23685 .49175 .23007 .48405 .21743 Mtetra
.655 .677 .858 r
.48405 .21743 .49175 .23007 .50565 .22592 .49799 .21206 Mtetra
.584 .622 .856 r
.49799 .21206 .50565 .22592 .51962 .22495 .51198 .20927 Mtetra
.51 .554 .837 r
.51198 .20927 .51962 .22495 .53371 .22719 .52607 .20911 Mtetra
.46 .491 .804 r
.52607 .20911 .53371 .22719 .54796 .23192 .54028 .21098 Mtetra
.454 .456 .77 r
.54028 .21098 .54796 .23192 .56238 .23753 .55465 .21355 Mtetra
.49 .451 .741 r
.55465 .21355 .56238 .23753 .57696 .24171 .56914 .21495 Mtetra
.55 .469 .717 r
.56914 .21495 .57696 .24171 .59161 .24189 .58371 .21312 Mtetra
.614 .497 .697 r
.58371 .21312 .59161 .24189 .60624 .23615 .59828 .20649 Mtetra
.668 .526 .682 r
.59828 .20649 .60624 .23615 .62074 .22397 .61276 .19469 Mtetra
.707 .551 .675 r
.61276 .19469 .62074 .22397 .63506 .20671 .62711 .17877 Mtetra
.733 .573 .674 r
.62711 .17877 .63506 .20671 .64922 .18659 .64135 .16053 Mtetra
.755 .594 .677 r
.64135 .16053 .64922 .18659 .66324 .16475 .65548 .1409 Mtetra
.781 .62 .681 r
.65548 .1409 .66324 .16475 .67707 .14092 .66946 .11976 Mtetra
.806 .65 .688 r
.66946 .11976 .67707 .14092 .69072 .11587 .68332 .09779 Mtetra
.82 .681 .71 r
.68332 .09779 .69072 .11587 .70435 .0925 .69718 .07733 Mtetra
.816 .712 .751 r
.69718 .07733 .70435 .0925 .71816 .07345 .71119 .06044 Mtetra
.475 .504 .808 r
.04964 .30603 .05732 .32209 .06795 .32448 .06047 .30695 Mtetra
.484 .489 .787 r
.06047 .30695 .06795 .32448 .07869 .32686 .07139 .30779 Mtetra
.509 .487 .767 r
.07139 .30779 .07869 .32686 .08962 .32848 .0825 .30797 Mtetra
.535 .488 .75 r
.0825 .30797 .08962 .32848 .1008 .32901 .09382 .30725 Mtetra
.548 .485 .737 r
.09382 .30725 .1008 .32901 .11216 .32885 .1053 .30593 Mtetra
.546 .475 .727 r
.1053 .30593 .11216 .32885 .12359 .32881 .11685 .30464 Mtetra
.532 .458 .718 r
.11685 .30464 .12359 .32881 .13499 .32967 .12839 .30396 Mtetra
.514 .437 .707 r
.12839 .30396 .13499 .32967 .14634 .33178 .13992 .30413 Mtetra
.499 .416 .693 r
.13992 .30413 .14634 .33178 .15765 .33507 .15145 .3051 Mtetra
.49 .398 .679 r
.15145 .3051 .15765 .33507 .16899 .33917 .163 .30661 Mtetra
.488 .386 .665 r
.163 .30661 .16899 .33917 .18041 .34356 .17463 .30837 Mtetra
.491 .378 .653 r
.17463 .30837 .18041 .34356 .19199 .34767 .18638 .31007 Mtetra
.499 .376 .644 r
.18638 .31007 .19199 .34767 .20378 .35094 .19827 .31138 Mtetra
.509 .378 .637 r
.19827 .31138 .20378 .35094 .21582 .35289 .21033 .312 Mtetra
.52 .383 .634 r
.21033 .312 .21582 .35289 .22812 .35323 .22258 .31171 Mtetra
.533 .39 .633 r
.22258 .31171 .22812 .35323 .24067 .35191 .23502 .31038 Mtetra
.545 .399 .634 r
.23502 .31038 .24067 .35191 .25343 .34909 .24765 .30802 Mtetra
.555 .408 .636 r
.24765 .30802 .25343 .34909 .26637 .34509 .26042 .30475 Mtetra
.564 .416 .639 r
.26042 .30475 .26637 .34509 .27944 .34025 .27334 .30071 Mtetra
.571 .424 .642 r
.27334 .30071 .27944 .34025 .29261 .33486 .28636 .29608 Mtetra
.578 .43 .645 r
.28636 .29608 .29261 .33486 .30587 .32906 .29949 .29096 Mtetra
.583 .436 .647 r
.29949 .29096 .30587 .32906 .31921 .32288 .31271 .28539 Mtetra
.589 .442 .65 r
.31271 .28539 .31921 .32288 .33263 .31628 .32601 .27937 Mtetra
.595 .448 .652 r
.32601 .27937 .33263 .31628 .34613 .30916 .3394 .27286 Mtetra
.602 .455 .654 r
.3394 .27286 .34613 .30916 .3597 .30145 .35287 .26584 Mtetra
.609 .462 .657 r
.35287 .26584 .3597 .30145 .37335 .2931 .36642 .25828 Mtetra
.616 .469 .659 r
.36642 .25828 .37335 .2931 .38707 .28412 .38003 .2502 Mtetra
.623 .477 .663 r
.38003 .2502 .38707 .28412 .40084 .27456 .39371 .24164 Mtetra
.629 .485 .667 r
.39371 .24164 .40084 .27456 .41465 .26454 .40743 .23269 Mtetra
.635 .492 .671 r
.40743 .23269 .41465 .26454 .4285 .25423 .4212 .22349 Mtetra
.639 .499 .676 r
.4212 .22349 .4285 .25423 .44237 .24391 .435 .21425 Mtetra
.639 .504 .682 r
.435 .21425 .44237 .24391 .45625 .23398 .44882 .20529 Mtetra
.635 .506 .689 r
.44882 .20529 .45625 .23398 .47014 .22494 .46266 .19702 Mtetra
.623 .503 .696 r
.46266 .19702 .47014 .22494 .48405 .21743 .47653 .18992 Mtetra
.602 .493 .701 r
.47653 .18992 .48405 .21743 .49799 .21206 .49043 .18448 Mtetra
.573 .475 .704 r
.49043 .18448 .49799 .21206 .51198 .20927 .50438 .18105 Mtetra
.541 .451 .703 r
.50438 .18105 .51198 .20927 .52607 .20911 .51842 .17966 Mtetra
.515 .429 .696 r
.51842 .17966 .52607 .20911 .54028 .21098 .53257 .17984 Mtetra
.507 .416 .687 r
.53257 .17984 .54028 .21098 .55465 .21355 .54684 .18054 Mtetra
.522 .417 .677 r
.54684 .18054 .55465 .21355 .56914 .21495 .56124 .18029 Mtetra
.554 .432 .668 r
.56124 .18029 .56914 .21495 .58371 .21312 .57572 .17749 Mtetra
.595 .456 .662 r
.57572 .17749 .58371 .21312 .59828 .20649 .59022 .17094 Mtetra
.635 .482 .658 r
.59022 .17094 .59828 .20649 .61276 .19469 .60467 .16035 Mtetra
.668 .507 .658 r
.60467 .16035 .61276 .19469 .62711 .17877 .61905 .14653 Mtetra
.692 .529 .662 r
.61905 .14653 .62711 .17877 .64135 .16053 .63335 .13087 Mtetra
.713 .552 .67 r
.63335 .13087 .64135 .16053 .65548 .1409 .64758 .11408 Mtetra
.738 .58 .678 r
.64758 .11408 .65548 .1409 .66946 .11976 .66172 .0961 Mtetra
.763 .611 .69 r
.66172 .0961 .66946 .11976 .68332 .09779 .67578 .07749 Mtetra
.776 .643 .714 r
.67578 .07749 .68332 .09779 .69718 .07733 .68985 .0601 Mtetra
.773 .671 .751 r
.68985 .0601 .69718 .07733 .71119 .06044 .70405 .04552 Mtetra
.533 .512 .778 r
.04222 .28812 .04964 .30603 .06047 .30695 .05327 .28737 Mtetra
.537 .497 .759 r
.05327 .28737 .06047 .30695 .07139 .30779 .06442 .28649 Mtetra
.551 .489 .74 r
.06442 .28649 .07139 .30779 .0825 .30797 .07573 .285 Mtetra
.565 .485 .724 r
.07573 .285 .0825 .30797 .09382 .30725 .08722 .28274 Mtetra
.572 .479 .711 r
.08722 .28274 .09382 .30725 .1053 .30593 .09885 .27998 Mtetra
.569 .469 .701 r
.09885 .27998 .1053 .30593 .11685 .30464 .11055 .2772 Mtetra
.56 .455 .692 r
.11055 .2772 .11685 .30464 .12839 .30396 .12227 .27483 Mtetra
.548 .439 .682 r
.12227 .27483 .12839 .30396 .13992 .30413 .13398 .27303 Mtetra
.537 .424 .672 r
.13398 .27303 .13992 .30413 .15145 .3051 .1457 .27175 Mtetra
.53 .41 .661 r
.1457 .27175 .15145 .3051 .163 .30661 .15747 .27082 Mtetra
.527 .399 .65 r
.15747 .27082 .163 .30661 .17463 .30837 .16929 .27006 Mtetra
.525 .391 .64 r
.16929 .27006 .17463 .30837 .18638 .31007 .18121 .2693 Mtetra
.526 .385 .632 r
.18121 .2693 .18638 .31007 .19827 .31138 .19322 .26837 Mtetra
.529 .382 .626 r
.19322 .26837 .19827 .31138 .21033 .312 .20536 .26711 Mtetra
.533 .381 .621 r
.20536 .26711 .21033 .312 .22258 .31171 .21763 .26539 Mtetra
.539 .382 .618 r
.21763 .26539 .22258 .31171 .23502 .31038 .23004 .2631 Mtetra
.544 .385 .616 r
.23004 .2631 .23502 .31038 .24765 .30802 .24258 .2602 Mtetra
.549 .388 .615 r
.24258 .2602 .24765 .30802 .26042 .30475 .25525 .25671 Mtetra
.554 .391 .615 r
.25525 .25671 .26042 .30475 .27334 .30071 .26804 .2527 Mtetra
.558 .394 .615 r
.26804 .2527 .27334 .30071 .28636 .29608 .28093 .24824 Mtetra
.562 .397 .616 r
.28093 .24824 .28636 .29608 .29949 .29096 .29391 .24338 Mtetra
.565 .4 .617 r
.29391 .24338 .29949 .29096 .31271 .28539 .30698 .23818 Mtetra
.568 .404 .618 r
.30698 .23818 .31271 .28539 .32601 .27937 .32014 .23262 Mtetra
.572 .407 .62 r
.32014 .23262 .32601 .27937 .3394 .27286 .33337 .22672 Mtetra
.576 .411 .621 r
.33337 .22672 .3394 .27286 .35287 .26584 .34668 .22045 Mtetra
.58 .416 .624 r
.34668 .22045 .35287 .26584 .36642 .25828 .36007 .21382 Mtetra
.585 .421 .626 r
.36007 .21382 .36642 .25828 .38003 .2502 .37353 .20683 Mtetra
.589 .427 .629 r
.37353 .20683 .38003 .2502 .39371 .24164 .38704 .19951 Mtetra
.594 .433 .633 r
.38704 .19951 .39371 .24164 .40743 .23269 .40062 .19193 Mtetra
.597 .439 .637 r
.40062 .19193 .40743 .23269 .4212 .22349 .41425 .18419 Mtetra
.6 .444 .642 r
.41425 .18419 .4212 .22349 .435 .21425 .42792 .17643 Mtetra
.601 .449 .647 r
.42792 .17643 .435 .21425 .44882 .20529 .44163 .16888 Mtetra
.599 .452 .653 r
.44163 .16888 .44882 .20529 .46266 .19702 .45537 .16185 Mtetra
.592 .452 .659 r
.45537 .16185 .46266 .19702 .47653 .18992 .46915 .1557 Mtetra
.579 .447 .665 r
.46915 .1557 .47653 .18992 .49043 .18448 .48297 .15079 Mtetra
.562 .438 .669 r
.48297 .15079 .49043 .18448 .50438 .18105 .49686 .14738 Mtetra
.542 .425 .67 r
.49686 .14738 .50438 .18105 .51842 .17966 .51082 .14548 Mtetra
.526 .413 .668 r
.51082 .14548 .51842 .17966 .53257 .17984 .52489 .14473 Mtetra
.521 .407 .664 r
.52489 .14473 .53257 .17984 .54684 .18054 .53907 .14434 Mtetra
.531 .41 .66 r
.53907 .14434 .54684 .18054 .56124 .18029 .55337 .14318 Mtetra
.553 .422 .656 r
.55337 .14318 .56124 .18029 .57572 .17749 .56776 .14007 Mtetra
.584 .442 .654 r
.56776 .14007 .57572 .17749 .59022 .17094 .58218 .1341 Mtetra
.616 .465 .653 r
.58218 .1341 .59022 .17094 .60467 .16035 .59661 .12505 Mtetra
.643 .487 .656 r
.59661 .12505 .60467 .16035 .61905 .14653 .611 .11355 Mtetra
.664 .509 .663 r
.611 .11355 .61905 .14653 .63335 .13087 .62536 .10061 Mtetra
.684 .532 .673 r
.62536 .10061 .63335 .13087 .64758 .11408 .63968 .08676 Mtetra
.707 .56 .685 r
.63968 .08676 .64758 .11408 .66172 .0961 .65396 .07193 Mtetra
.73 .591 .7 r
.65396 .07193 .66172 .0961 .67578 .07749 .66819 .05657 Mtetra
.743 .621 .724 r
.66819 .05657 .67578 .07749 .68985 .0601 .68245 .04212 Mtetra
.74 .648 .758 r
.68245 .04212 .68985 .0601 .70405 .04552 .69682 .02977 Mtetra
.573 .552 .793 r
.03455 .27159 .04222 .28812 .05327 .28737 .0458 .26943 Mtetra
.575 .536 .774 r
.0458 .26943 .05327 .28737 .06442 .28649 .05715 .26708 Mtetra
.584 .527 .756 r
.05715 .26708 .06442 .28649 .07573 .285 .06864 .26419 Mtetra
.594 .52 .741 r
.06864 .26419 .07573 .285 .08722 .28274 .08029 .26065 Mtetra
.598 .512 .729 r
.08029 .26065 .08722 .28274 .09885 .27998 .09207 .25668 Mtetra
.595 .502 .719 r
.09207 .25668 .09885 .27998 .11055 .2772 .1039 .25266 Mtetra
.587 .489 .71 r
.1039 .25266 .11055 .2772 .12227 .27483 .11576 .24893 Mtetra
.577 .475 .702 r
.11576 .24893 .12227 .27483 .13398 .27303 .12762 .24558 Mtetra
.568 .461 .692 r
.12762 .24558 .13398 .27303 .1457 .27175 .13951 .24257 Mtetra
.562 .449 .682 r
.13951 .24257 .1457 .27175 .15747 .27082 .15144 .23978 Mtetra
.557 .438 .672 r
.15144 .23978 .15747 .27082 .16929 .27006 .16342 .23709 Mtetra
.555 .428 .663 r
.16342 .23709 .16929 .27006 .18121 .2693 .17548 .23441 Mtetra
.553 .42 .654 r
.17548 .23441 .18121 .2693 .19322 .26837 .18761 .23166 Mtetra
.553 .415 .647 r
.18761 .23166 .19322 .26837 .20536 .26711 .19984 .22877 Mtetra
.553 .411 .641 r
.19984 .22877 .20536 .26711 .21763 .26539 .21216 .22565 Mtetra
.555 .408 .637 r
.21216 .22565 .21763 .26539 .23004 .2631 .22457 .22227 Mtetra
.557 .407 .633 r
.22457 .22227 .23004 .2631 .24258 .2602 .23709 .21857 Mtetra
.559 .407 .631 r
.23709 .21857 .24258 .2602 .25525 .25671 .24971 .21455 Mtetra
.562 .408 .63 r
.24971 .21455 .25525 .25671 .26804 .2527 .26241 .21022 Mtetra
.564 .409 .629 r
.26241 .21022 .26804 .2527 .28093 .24824 .27521 .20562 Mtetra
.566 .41 .629 r
.27521 .20562 .28093 .24824 .29391 .24338 .28809 .20078 Mtetra
.568 .412 .629 r
.28809 .20078 .29391 .24338 .30698 .23818 .30105 .19571 Mtetra
.571 .414 .63 r
.30105 .19571 .30698 .23818 .32014 .23262 .31408 .19044 Mtetra
.573 .416 .631 r
.31408 .19044 .32014 .23262 .33337 .22672 .32719 .18495 Mtetra
.576 .419 .632 r
.32719 .18495 .33337 .22672 .34668 .22045 .34037 .17925 Mtetra
.578 .423 .634 r
.34037 .17925 .34668 .22045 .36007 .21382 .35362 .17334 Mtetra
.582 .427 .637 r
.35362 .17334 .36007 .21382 .37353 .20683 .36693 .16723 Mtetra
.585 .432 .64 r
.36693 .16723 .37353 .20683 .38704 .19951 .38032 .16093 Mtetra
.588 .437 .644 r
.38032 .16093 .38704 .19951 .40062 .19193 .39376 .15448 Mtetra
.591 .442 .648 r
.39376 .15448 .40062 .19193 .41425 .18419 .40726 .14794 Mtetra
.593 .447 .653 r
.40726 .14794 .41425 .18419 .42792 .17643 .42082 .14142 Mtetra
.594 .452 .658 r
.42082 .14142 .42792 .17643 .44163 .16888 .43443 .13508 Mtetra
.592 .455 .664 r
.43443 .13508 .44163 .16888 .45537 .16185 .44808 .12913 Mtetra
.586 .456 .67 r
.44808 .12913 .45537 .16185 .46915 .1557 .46178 .12381 Mtetra
.576 .453 .676 r
.46178 .12381 .46915 .1557 .48297 .15079 .47554 .1194 Mtetra
.563 .447 .68 r
.47554 .1194 .48297 .15079 .49686 .14738 .48936 .11607 Mtetra
.548 .438 .681 r
.48936 .11607 .49686 .14738 .51082 .14548 .50326 .11381 Mtetra
.536 .429 .68 r
.50326 .11381 .51082 .14548 .52489 .14473 .51726 .11236 Mtetra
.532 .424 .677 r
.51726 .11236 .52489 .14473 .53907 .14434 .53137 .11114 Mtetra
.539 .426 .673 r
.53137 .11114 .53907 .14434 .55337 .14318 .54559 .10932 Mtetra
.558 .436 .67 r
.54559 .10932 .55337 .14318 .56776 .14007 .5599 .10603 Mtetra
.583 .452 .668 r
.5599 .10603 .56776 .14007 .58218 .1341 .57427 .10062 Mtetra
.61 .472 .668 r
.57427 .10062 .58218 .1341 .59661 .12505 .58867 .09294 Mtetra
.633 .492 .672 r
.58867 .09294 .59661 .12505 .611 .11355 .60307 .08344 Mtetra
.652 .512 .68 r
.60307 .08344 .611 .11355 .62536 .10061 .61747 .07287 Mtetra
.669 .535 .692 r
.61747 .07287 .62536 .10061 .63968 .08676 .63188 .06156 Mtetra
.691 .562 .705 r
.63188 .06156 .63968 .08676 .65396 .07193 .64627 .04945 Mtetra
.712 .593 .721 r
.64627 .04945 .65396 .07193 .66819 .05657 .66064 .03686 Mtetra
.722 .622 .746 r
.66064 .03686 .66819 .05657 .68245 .04212 .67506 .02488 Mtetra
.719 .648 .778 r
.67506 .02488 .68245 .04212 .69682 .02977 .68957 .01443 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.8354 .67488 m
.8612 .67495 L
.86765 .6806 L
.87808 .7064 L
.88116 .7322 L
.87591 .758 L
.86731 .7838 L
.8612 .79873 L
.85779 .8096 L
.84136 .8354 L
.8354 .8427 L
.8188 .8612 L
.8096 .86908 L
.7838 .88045 L
.758 .86528 L
.75586 .8612 L
.75034 .8354 L
.75254 .8096 L
.758 .78629 L
.75829 .7838 L
.76607 .758 L
.77999 .7322 L
.7838 .72618 L
.79387 .7064 L
.8096 .6928 L
.82484 .6806 L
.8354 .67488 L
s
.242 .83425 m
.2678 .82873 L
.2936 .82577 L
.3194 .82448 L
.3452 .82444 L
.371 .82547 L
.3968 .82756 L
.4226 .83076 L
.4484 .83518 L
.44949 .8354 L
.4742 .84042 L
.5 .84733 L
.5258 .85697 L
.53432 .8612 L
.5516 .87424 L
.55649 .887 L
.5516 .89677 L
.5258 .91117 L
.52087 .9128 L
.5 .9197 L
.4742 .92441 L
.4484 .92673 L
.4226 .92756 L
.3968 .92728 L
.371 .92599 L
.3452 .92366 L
.3194 .92019 L
.2936 .91541 L
.282 .9128 L
.2678 .90955 L
.242 .90217 L
.2162 .89164 L
.20797 .887 L
.19175 .8612 L
.2162 .84218 L
.2381 .8354 L
.242 .83425 L
s
.0872 .37243 m
.11243 .3968 L
.113 .39797 L
.12281 .4226 L
.13036 .4484 L
.13631 .4742 L
.1388 .4869 L
.14144 .5 L
.14591 .5258 L
.14947 .5516 L
.15222 .5774 L
.15421 .6032 L
.15552 .629 L
.15618 .6548 L
.15614 .6806 L
.15526 .7064 L
.15297 .7322 L
.14438 .758 L
.1388 .77883 L
.13697 .7838 L
.113 .80481 L
.0946 .7838 L
.0872 .76739 L
.08208 .758 L
.076 .7322 L
.06992 .7064 L
.06502 .6806 L
.0614 .65735 L
.06101 .6548 L
.05745 .629 L
.05467 .6032 L
.05263 .5774 L
.05134 .5516 L
.0508 .5258 L
.0511 .5 L
.05244 .4742 L
.05528 .4484 L
.06053 .4226 L
.0614 .41949 L
.06772 .3968 L
.0872 .37243 L
s
.5 .44004 m
.5258 .44375 L
.5353 .4484 L
.5516 .45708 L
.56236 .4742 L
.57042 .5 L
.5665 .5258 L
.5516 .54363 L
.53885 .5516 L
.5258 .5557 L
.5 .5538 L
.49403 .5516 L
.4742 .54209 L
.46141 .5258 L
.45209 .5 L
.45396 .4742 L
.4742 .44999 L
.47661 .4484 L
.5 .44004 L
s
.4226 .908 m
.4484 .90294 L
.4742 .89902 L
.5 .89592 L
.5258 .89346 L
.5516 .89157 L
.5774 .89018 L
.6032 .88927 L
.629 .88883 L
.6548 .88888 L
.6806 .88945 L
.7064 .89061 L
.7322 .89246 L
.758 .89523 L
.7838 .89936 L
.8096 .90629 L
.82173 .9128 L
.8096 .93297 L
.79395 .9386 L
.7838 .94142 L
.758 .94708 L
.7322 .95137 L
.7064 .95475 L
.6806 .95743 L
.6548 .95953 L
.629 .9611 L
.6032 .96219 L
.5774 .9628 L
.5516 .96294 L
.5258 .96257 L
.5 .96164 L
.4742 .96007 L
.4484 .95767 L
.4226 .95413 L
.3968 .94858 L
.37465 .9386 L
.3968 .91508 L
.40398 .9128 L
.4226 .908 L
s
.8354 .0825 m
.85836 .0872 L
.8612 .08844 L
.887 .10938 L
.88994 .113 L
.9043 .1388 L
.91075 .1646 L
.91234 .1904 L
.90965 .2162 L
.90157 .242 L
.887 .2645 L
.88386 .2678 L
.8612 .28472 L
.8354 .28988 L
.8096 .28278 L
.78719 .2678 L
.7838 .26007 L
.77273 .242 L
.76398 .2162 L
.76084 .1904 L
.76215 .1646 L
.76841 .1388 L
.78251 .113 L
.7838 .11133 L
.8096 .089 L
.81359 .0872 L
.8354 .0825 L
s
.2162 .05832 m
.242 .05222 L
.2678 .0477 L
.2936 .04422 L
.3194 .04152 L
.3452 .03947 L
.371 .03798 L
.3968 .03699 L
.4226 .03649 L
.4484 .03646 L
.4742 .03691 L
.5 .03786 L
.5258 .03934 L
.5516 .04143 L
.5774 .04423 L
.6032 .04795 L
.629 .05298 L
.6548 .06031 L
.65774 .0614 L
.67692 .0872 L
.6548 .09976 L
.629 .10743 L
.6032 .1128 L
.60204 .113 L
.5774 .11794 L
.5516 .12186 L
.5258 .12475 L
.5 .12684 L
.4742 .12826 L
.4484 .12912 L
.4226 .12948 L
.3968 .12936 L
.371 .12874 L
.3452 .12756 L
.3194 .12568 L
.2936 .12291 L
.2678 .11895 L
.242 .11338 L
.24053 .113 L
.2162 .10752 L
.1904 .09845 L
.17628 .0872 L
.1904 .06772 L
.20609 .0614 L
.2162 .05832 L
s
.9386 .37244 m
.9511 .3968 L
.95754 .4226 L
.962 .4484 L
.9644 .4662 L
.96531 .4742 L
.96778 .5 L
.96957 .5258 L
.97074 .5516 L
.97135 .5774 L
.97139 .6032 L
.97085 .629 L
.96965 .6548 L
.96769 .6806 L
.96473 .7064 L
.9644 .70879 L
.96025 .7322 L
.95231 .758 L
.9386 .76802 L
.93059 .758 L
.92167 .7322 L
.91621 .7064 L
.9128 .68459 L
.91201 .6806 L
.90758 .6548 L
.90714 .629 L
.90561 .6032 L
.90467 .5774 L
.90429 .5516 L
.90448 .5258 L
.90528 .5 L
.90677 .4742 L
.9091 .4484 L
.91258 .4226 L
.9128 .4213 L
.91803 .3968 L
.9386 .37244 L
s
.1904 .16167 m
.2162 .14971 L
.242 .14409 L
.2678 .14432 L
.29082 .1646 L
.29294 .1904 L
.28369 .2162 L
.2678 .23684 L
.26337 .242 L
.242 .26032 L
.22928 .2678 L
.2162 .2735 L
.1904 .28224 L
.1646 .28458 L
.1388 .27518 L
.13329 .2678 L
.12628 .242 L
.13455 .2162 L
.1388 .20904 L
.15289 .1904 L
.1646 .17847 L
.18514 .1646 L
.1904 .16167 L
s
0 g
.03 w
.81523 .77613 Mdot
.37378 .87564 Mdot
.10284 .58899 Mdot
.51102 .49827 Mdot
.59838 .92587 Mdot
.83667 .18619 Mdot
.42777 .08153 Mdot
.93786 .56974 Mdot
.21005 .21419 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.93137 .51722 m
.9409 .51961 L
.94614 .53922 L
.94881 .55882 L
.95023 .57843 L
.95065 .59804 L
.95007 .61765 L
.94822 .63725 L
.94424 .65686 L
.93137 .67038 L
.92639 .65686 L
.92336 .63725 L
.92231 .61765 L
.92236 .59804 L
.92316 .57843 L
.92462 .55882 L
.92689 .53922 L
.93068 .51961 L
.93137 .51722 L
s
.46078 .90546 m
.48039 .90459 L
.5 .90566 L
.51961 .90807 L
.5378 .91176 L
.51961 .92324 L
.5 .92347 L
.48039 .92193 L
.46078 .91817 L
.44652 .91176 L
.46078 .90546 L
s
.93137 .46481 m
.94545 .48039 L
.95028 .5 L
.95098 .50366 L
.95323 .51961 L
.95528 .53922 L
.9567 .55882 L
.95755 .57843 L
.95783 .59804 L
.95752 .61765 L
.95653 .63725 L
.9547 .65686 L
.95257 .67647 L
.95098 .68021 L
.94573 .69608 L
.93137 .70704 L
.92418 .69608 L
.91819 .67647 L
.91535 .65686 L
.91419 .63725 L
.91404 .61765 L
.9145 .59804 L
.91537 .57843 L
.91655 .55882 L
.91805 .53922 L
.91995 .51961 L
.92248 .5 L
.92616 .48039 L
.93137 .46481 L
s
.73529 .90589 m
.7549 .9014 L
.76968 .91176 L
.7549 .92069 L
.73529 .92272 L
.72122 .91176 L
.73529 .90589 L
s
.38235 .88804 m
.40196 .88436 L
.42157 .87855 L
.44118 .88081 L
.46078 .88297 L
.48039 .88535 L
.5 .88801 L
.51961 .89093 L
.52739 .89216 L
.53922 .89387 L
.55882 .89694 L
.57843 .9004 L
.59804 .90438 L
.61765 .90917 L
.62613 .91176 L
.61765 .92929 L
.60886 .93137 L
.59804 .93314 L
.57843 .9356 L
.55882 .93725 L
.53922 .93823 L
.51961 .93859 L
.5 .93835 L
.48039 .94148 L
.46078 .93855 L
.44118 .93484 L
.42634 .93137 L
.42157 .93038 L
.40196 .92532 L
.38235 .91758 L
.37303 .91176 L
.37298 .89216 L
.38235 .88804 L
s
.08824 .52248 m
.10784 .5209 L
.11344 .53922 L
.11728 .55882 L
.11975 .57843 L
.12111 .59804 L
.12133 .61765 L
.12015 .63725 L
.11654 .65686 L
.10784 .66941 L
.09818 .65686 L
.09187 .63725 L
.08824 .61937 L
.08799 .61765 L
.08566 .59804 L
.08443 .57843 L
.0843 .55882 L
.08554 .53922 L
.08824 .52248 L
s
.5 .47562 m
.51961 .4744 L
.52562 .48039 L
.53547 .5 L
.52472 .51961 L
.51961 .52269 L
.50157 .51961 L
.5 .51875 L
.48695 .5 L
.49281 .48039 L
.5 .47562 L
s
.93137 .41967 m
.93735 .42157 L
.94685 .44118 L
.95098 .45624 L
.95284 .46078 L
.95953 .48039 L
.95797 .5 L
.96005 .51961 L
.96164 .53922 L
.96278 .55882 L
.96349 .57843 L
.96375 .59804 L
.96354 .61765 L
.9628 .63725 L
.96146 .65686 L
.96551 .67647 L
.95631 .69608 L
.95164 .71569 L
.95098 .71782 L
.93896 .73529 L
.93137 .73574 L
.93078 .73529 L
.91791 .71569 L
.91176 .69666 L
.91164 .69608 L
.90835 .67647 L
.90681 .65686 L
.9065 .63725 L
.90692 .61765 L
.90773 .59804 L
.90877 .57843 L
.90996 .55882 L
.91131 .53922 L
.91176 .53319 L
.91279 .51961 L
.91451 .5 L
.91663 .48039 L
.91936 .46078 L
.92315 .44118 L
.93003 .42157 L
.93137 .41967 L
s
.83333 .13574 m
.84599 .14706 L
.85294 .16192 L
.85412 .16667 L
.85438 .18627 L
.85294 .19047 L
.83333 .19981 L
.82319 .18627 L
.82033 .16667 L
.82325 .14706 L
.83333 .13574 L
s
.34314 .87054 m
.36275 .8672 L
.38235 .86622 L
.40196 .86648 L
.42157 .86759 L
.44118 .86932 L
.46078 .87153 L
.46901 .87255 L
.48039 .8737 L
.5 .8761 L
.51961 .87885 L
.53922 .88185 L
.55882 .88502 L
.57843 .88835 L
.59804 .8918 L
.60005 .89216 L
.61765 .89499 L
.63725 .89791 L
.65686 .90002 L
.67647 .90044 L
.69608 .8984 L
.71569 .89384 L
.72107 .89216 L
.73529 .8868 L
.7549 .87928 L
.77451 .87512 L
.79412 .87942 L
.7989 .89216 L
.80094 .91176 L
.79412 .9206 L
.77703 .93137 L
.77451 .93252 L
.7549 .93954 L
.73529 .94389 L
.71569 .93898 L
.69608 .93828 L
.67647 .93806 L
.65686 .9389 L
.63725 .94055 L
.61765 .94248 L
.59804 .94429 L
.57843 .94577 L
.55882 .94685 L
.53922 .9475 L
.51961 .94773 L
.5 .94752 L
.48039 .94988 L
.46078 .94854 L
.44118 .94666 L
.42157 .94401 L
Mistroke
.40196 .94039 L
.38235 .93554 L
.36901 .93137 L
.36275 .92939 L
.34314 .92155 L
.32686 .91176 L
.32353 .90885 L
.31458 .89216 L
.32353 .87846 L
.33691 .87255 L
.34314 .87054 L
Mfstroke
.5 .45994 m
.51769 .46078 L
.51961 .46096 L
.53922 .47203 L
.54438 .48039 L
.55106 .5 L
.54686 .51961 L
.53922 .53167 L
.51961 .53796 L
.5 .53573 L
.48052 .51961 L
.48039 .51943 L
.47159 .5 L
.47386 .48039 L
.48039 .47106 L
.49677 .46078 L
.5 .45994 L
s
.08824 .45073 m
.10679 .46078 L
.10784 .4626 L
.1151 .48039 L
.12083 .5 L
.12523 .51961 L
.12745 .53163 L
.12881 .53922 L
.1318 .55882 L
.13409 .57843 L
.13573 .59804 L
.13676 .61765 L
.13718 .63725 L
.13686 .65686 L
.13544 .67647 L
.13177 .69608 L
.12745 .70758 L
.12483 .71569 L
.10784 .72984 L
.0979 .71569 L
.08995 .69608 L
.08824 .69078 L
.08295 .67647 L
.07722 .65686 L
.07295 .63725 L
.07429 .61765 L
.07237 .59804 L
.07109 .57843 L
.07043 .55882 L
.07044 .53922 L
.07124 .51961 L
.073 .5 L
.07617 .48039 L
.08199 .46078 L
.08824 .45073 L
s
.93137 .37007 m
.94072 .38235 L
.94785 .40196 L
.95098 .41329 L
.95413 .42157 L
.96037 .44118 L
.96492 .46078 L
.96798 .48039 L
.96427 .5 L
.96598 .51961 L
.96733 .53922 L
.96832 .55882 L
.96895 .57843 L
.9692 .59804 L
.96906 .61765 L
.96849 .63725 L
.96745 .65686 L
.97003 .67647 L
.96356 .69608 L
.9604 .71569 L
.95589 .73529 L
.95098 .74973 L
.94796 .7549 L
.93137 .76205 L
.92428 .7549 L
.91271 .73529 L
.91176 .73324 L
.90771 .71569 L
.90187 .69608 L
.89936 .67647 L
.89892 .65686 L
.89948 .63725 L
.90047 .61765 L
.90162 .59804 L
.90281 .57843 L
.90398 .55882 L
.90516 .53922 L
.90638 .51961 L
.90773 .5 L
.90929 .48039 L
.91118 .46078 L
.91176 .45553 L
.91336 .44118 L
.91595 .42157 L
.91926 .40196 L
.92411 .38235 L
.93137 .37007 L
s
.20588 .18601 m
.22549 .1746 L
.2451 .18558 L
.2454 .18627 L
.2451 .19849 L
.24286 .20588 L
.22908 .22549 L
.22549 .22895 L
.20588 .23897 L
.18627 .24287 L
.17012 .22549 L
.18187 .20588 L
.18627 .19907 L
.20531 .18627 L
.20588 .18601 L
s
.81373 .0858 m
.83333 .08675 L
.8382 .08824 L
.85294 .09543 L
.86638 .10784 L
.87255 .1192 L
.87668 .12745 L
.88423 .14706 L
.88986 .16667 L
.89216 .17719 L
.8937 .18627 L
.89425 .20588 L
.89216 .21512 L
.88577 .22549 L
.87255 .23439 L
.85294 .2413 L
.83333 .24167 L
.81373 .23101 L
.80795 .22549 L
.7975 .20588 L
.79412 .18735 L
.79395 .18627 L
.79149 .16667 L
.78948 .14706 L
.78701 .12745 L
.78677 .10784 L
.79412 .09504 L
.80516 .08824 L
.81373 .0858 L
s
.34314 .06818 m
.36275 .06715 L
.38235 .06789 L
.40196 .0685 L
.40491 .06863 L
.42157 .06971 L
.44118 .07167 L
.46078 .07521 L
.46153 .08824 L
.46078 .08841 L
.44118 .09208 L
.42157 .09494 L
.40196 .09774 L
.38235 .10086 L
.36275 .10451 L
.34712 .10784 L
.34314 .10905 L
.32353 .11618 L
.30392 .11801 L
.28431 .12173 L
.26471 .11981 L
.25293 .10784 L
.26057 .08824 L
.26471 .08549 L
.28431 .07717 L
.30392 .07255 L
.32353 .06981 L
.33777 .06863 L
.34314 .06818 L
s
.81373 .72969 m
.83333 .71802 L
.85294 .73196 L
.85363 .73529 L
.85294 .75214 L
.85241 .7549 L
.84969 .77451 L
.83907 .79412 L
.83333 .80397 L
.82723 .81373 L
.81607 .83333 L
.81373 .83607 L
.80804 .85294 L
.81191 .87255 L
.81373 .87589 L
.81995 .89216 L
.82153 .91176 L
.81373 .92369 L
.8043 .93137 L
.79412 .9377 L
.77451 .94517 L
.7549 .94898 L
.73529 .9507 L
.71569 .94934 L
.69608 .94895 L
.67647 .94878 L
.65686 .94926 L
.63725 .95032 L
.62708 .95098 L
.61765 .95167 L
.59804 .95302 L
.57843 .95416 L
.55882 .955 L
.53922 .95552 L
.51961 .9557 L
.5 .95553 L
.48039 .95501 L
.46078 .95411 L
.44118 .95279 L
.42157 .95102 L
.42121 .95098 L
.40196 .94935 L
.38235 .94676 L
.36275 .94306 L
.34314 .93797 L
.32414 .93137 L
.32353 .93114 L
.30392 .92564 L
.28678 .91176 L
.28431 .90979 L
Mistroke
.26979 .89216 L
.2727 .87255 L
.28431 .86476 L
.30392 .85805 L
.32353 .8536 L
.33612 .85294 L
.34314 .85251 L
.36275 .85181 L
.38235 .85204 L
.40042 .85294 L
.40196 .85304 L
.42157 .85462 L
.44118 .85678 L
.46078 .8594 L
.48039 .86238 L
.5 .86558 L
.51961 .86889 L
.53922 .87222 L
.54116 .87255 L
.55882 .87524 L
.57843 .87829 L
.59804 .88134 L
.61765 .88429 L
.63725 .88686 L
.65686 .88854 L
.67647 .88856 L
.69608 .88619 L
.71569 .88111 L
.73529 .87365 L
.73717 .87255 L
.7549 .86241 L
.76523 .85294 L
.77451 .83522 L
.77498 .83333 L
.77759 .81373 L
.78074 .79412 L
.78437 .77451 L
.79412 .756 L
.79512 .7549 L
.80864 .73529 L
.81373 .72969 L
Mfstroke
.48039 .45425 m
.5 .44746 L
.51961 .44899 L
.53922 .45871 L
.54197 .46078 L
.5572 .48039 L
.55882 .48474 L
.56226 .5 L
.55955 .51961 L
.55882 .52142 L
.54677 .53922 L
.53922 .54357 L
.51961 .54924 L
.5 .54676 L
.48491 .53922 L
.48039 .53659 L
.46646 .51961 L
.46078 .5034 L
.46018 .5 L
.46078 .48309 L
.46133 .48039 L
.47173 .46078 L
.48039 .45425 L
s
.08824 .39348 m
.1011 .40196 L
.10784 .41378 L
.11132 .42157 L
.11856 .44118 L
.12448 .46078 L
.12745 .47222 L
.12951 .48039 L
.13382 .5 L
.13734 .51961 L
.14019 .53922 L
.14244 .55882 L
.14415 .57843 L
.14536 .59804 L
.14612 .61765 L
.14646 .63725 L
.14647 .65686 L
.14627 .67647 L
.14614 .69608 L
.14198 .71569 L
.13948 .73529 L
.13706 .7549 L
.13621 .77451 L
.13917 .79412 L
.14684 .81373 L
.14706 .81398 L
.15874 .83333 L
.16633 .85294 L
.16207 .87255 L
.14706 .88595 L
.12745 .88357 L
.11386 .87255 L
.10784 .86723 L
.10159 .85294 L
.09564 .83333 L
.09913 .81373 L
.099 .79412 L
.0965 .77451 L
.09157 .7549 L
.08824 .74327 L
.0854 .73529 L
.07917 .71569 L
.07423 .69608 L
.07074 .67647 L
.06865 .65686 L
.06863 .65654 L
.06585 .63725 L
.06354 .61765 L
.06172 .59804 L
.06037 .57843 L
Mistroke
.05948 .55882 L
.05907 .53922 L
.05915 .51961 L
.0598 .5 L
.06114 .48039 L
.06341 .46078 L
.0671 .44118 L
.06863 .4352 L
.07222 .42157 L
.08016 .40196 L
.08824 .39348 L
Mfstroke
.79412 .06722 m
.81373 .06447 L
.83333 .06565 L
.84563 .06863 L
.85294 .07111 L
.87255 .08252 L
.87902 .08824 L
.89216 .1051 L
.89373 .10784 L
.9026 .12745 L
.90928 .14706 L
.91176 .15491 L
.91517 .16667 L
.92034 .18627 L
.92465 .20588 L
.92838 .22549 L
.92954 .2451 L
.93137 .26265 L
.93157 .26471 L
.93373 .28431 L
.93682 .30392 L
.94092 .32353 L
.94555 .34314 L
.95017 .36275 L
.95098 .3663 L
.95567 .38235 L
.96079 .40196 L
.96485 .42157 L
.96771 .44118 L
.96947 .46078 L
.97035 .48039 L
.97013 .5 L
.97059 .50557 L
.97161 .51961 L
.9728 .53922 L
.97368 .55882 L
.97426 .57843 L
.97452 .59804 L
.97444 .61765 L
.974 .63725 L
.97316 .65686 L
.9706 .67647 L
.97059 .69125 L
.97009 .69608 L
.96769 .71569 L
.96451 .73529 L
.96017 .7549 L
.95377 .77451 L
.95098 .78046 L
.93137 .78832 L
Mistroke
.91947 .77451 L
.91176 .76218 L
.9074 .7549 L
.89718 .73529 L
.89216 .72299 L
.88982 .71569 L
.88692 .69608 L
.89011 .67647 L
.89049 .65686 L
.89199 .63725 L
.89216 .63512 L
.89389 .61765 L
.89561 .59804 L
.89711 .57843 L
.89842 .55882 L
.89958 .53922 L
.90066 .51961 L
.90171 .5 L
.90281 .48039 L
.90399 .46078 L
.9053 .44118 L
.90673 .42157 L
.90827 .40196 L
.90984 .38235 L
.91125 .36275 L
.91176 .3534 L
.91201 .34314 L
.91176 .32898 L
.91116 .32353 L
.90843 .30392 L
.90027 .28431 L
.89216 .27482 L
.87255 .26752 L
.85294 .26791 L
.83333 .26706 L
.82449 .26471 L
.81373 .25979 L
.79658 .2451 L
.79412 .24088 L
.78551 .22549 L
.77909 .20588 L
.77549 .18627 L
.77451 .17891 L
.77279 .16667 L
.76919 .14706 L
.76342 .12745 L
.75669 .10784 L
.75753 .08824 L
.77451 .07425 L
.78806 .06863 L
Mistroke
.79412 .06722 L
Mfstroke
.26471 .06402 m
.28431 .05948 L
.30392 .05623 L
.32353 .05384 L
.34314 .05201 L
.36275 .05045 L
.38235 .0534 L
.40196 .0534 L
.42157 .05368 L
.44118 .05421 L
.46078 .05505 L
.48039 .05625 L
.5 .05793 L
.51961 .06024 L
.53922 .06347 L
.55882 .06828 L
.55993 .06863 L
.57018 .08824 L
.55882 .09291 L
.53922 .09806 L
.51961 .10162 L
.5 .10427 L
.48039 .10635 L
.46366 .10784 L
.46078 .10812 L
.44118 .10995 L
.42157 .11192 L
.40196 .11433 L
.38235 .11743 L
.36275 .12133 L
.34314 .12569 L
.33452 .12745 L
.32353 .13142 L
.30392 .1408 L
.29539 .14706 L
.28431 .159 L
.28096 .16667 L
.27397 .18627 L
.26577 .20588 L
.26471 .20826 L
.2527 .22549 L
.2451 .23399 L
.23055 .2451 L
.22549 .24832 L
.20588 .25861 L
.18627 .26455 L
.18532 .26471 L
.16667 .26917 L
.14706 .27445 L
.12745 .27619 L
Mistroke
.11416 .26471 L
.12308 .2451 L
.12745 .23879 L
.13757 .22549 L
.14706 .21031 L
.15526 .20588 L
.16667 .19376 L
.17509 .18627 L
.18627 .17641 L
.19558 .16667 L
.20588 .15606 L
.21132 .14706 L
.21622 .12745 L
.21315 .10784 L
.21726 .08824 L
.22549 .08062 L
.2451 .07053 L
.25033 .06863 L
.26471 .06402 L
Mfstroke
.5 .43625 m
.51961 .43784 L
.52993 .44118 L
.53922 .44568 L
.55717 .46078 L
.55882 .46229 L
.56901 .48039 L
.57361 .5 L
.57188 .51961 L
.56224 .53922 L
.55882 .54333 L
.53922 .55647 L
.53131 .55882 L
.51961 .56043 L
.50296 .55882 L
.5 .55811 L
.48039 .54933 L
.46787 .53922 L
.46078 .53135 L
.45457 .51961 L
.4488 .5 L
.44939 .48039 L
.45736 .46078 L
.46078 .45584 L
.48039 .4412 L
.48044 .44118 L
.5 .43625 L
s
.28431 .04833 m
.30392 .04607 L
.32353 .0444 L
.34314 .04323 L
.36275 .04246 L
.38235 .04203 L
.40196 .04186 L
.42157 .04192 L
.44118 .0422 L
.46078 .04271 L
.48039 .04347 L
.5 .04453 L
.51961 .04595 L
.53922 .04782 L
.54963 .04902 L
.55882 .05015 L
.57843 .05301 L
.59804 .05658 L
.61765 .06102 L
.63725 .06657 L
.64295 .06863 L
.65686 .07483 L
.65691 .08824 L
.65686 .08826 L
.63725 .09482 L
.61765 .1001 L
.59804 .10454 L
.58072 .10784 L
.57843 .10829 L
.55882 .11165 L
.53922 .11433 L
.51961 .11646 L
.5 .11817 L
.48039 .11958 L
.46078 .12084 L
.44118 .12212 L
.42157 .12362 L
.40196 .12556 L
.38687 .12745 L
.38235 .12826 L
.36275 .13264 L
.34314 .13904 L
.32653 .14706 L
.32353 .14893 L
.30464 .16667 L
.30392 .1677 L
.29367 .18627 L
.28431 .20502 L
.28385 .20588 L
.2709 .22549 L
Mistroke
.26471 .23303 L
.2521 .2451 L
.2451 .2508 L
.22549 .26357 L
.22347 .26471 L
.20588 .27309 L
.18627 .28069 L
.17609 .28431 L
.16667 .28802 L
.14706 .29841 L
.14048 .30392 L
.12745 .31803 L
.12434 .32353 L
.12259 .34314 L
.11989 .36275 L
.12233 .38235 L
.12601 .40196 L
.12745 .4207 L
.12769 .42157 L
.1327 .44118 L
.13719 .46078 L
.14107 .48039 L
.14434 .5 L
.14706 .5196 L
.14706 .51961 L
.14952 .53922 L
.15159 .55882 L
.1533 .57843 L
.15463 .59804 L
.1556 .61765 L
.15618 .63725 L
.15636 .65686 L
.15614 .67647 L
.15549 .69608 L
.15449 .71569 L
.15339 .73529 L
.15288 .7549 L
.15426 .77451 L
.15905 .79412 L
.16667 .81193 L
.16774 .81373 L
.18237 .83333 L
.18627 .83729 L
.20588 .85063 L
.21 .85294 L
.22549 .85468 L
.23733 .85294 L
.2451 .85094 L
.26471 .84617 L
.28431 .84267 L
Mistroke
.30392 .84037 L
.32353 .839 L
.34314 .83842 L
.36275 .83853 L
.38235 .83927 L
.40196 .84061 L
.42157 .84249 L
.44118 .84487 L
.46078 .84769 L
.48039 .85086 L
.49244 .85294 L
.5 .8543 L
.51961 .85791 L
.53922 .86159 L
.55882 .86524 L
.57843 .86875 L
.59804 .87202 L
.60135 .87255 L
.61765 .87487 L
.63725 .87722 L
.65686 .87863 L
.67647 .87841 L
.69608 .87579 L
.70949 .87255 L
.71569 .86996 L
.73529 .85867 L
.74118 .85294 L
.75397 .83333 L
.7549 .83085 L
.75936 .81373 L
.76457 .79412 L
.77093 .77451 L
.77451 .76503 L
.7785 .7549 L
.78924 .73529 L
.79412 .72805 L
.80179 .71569 L
.81373 .70495 L
.82547 .69608 L
.83333 .69148 L
.85294 .68468 L
.86777 .67647 L
.87255 .66917 L
.87843 .65686 L
.88369 .63725 L
.88708 .61765 L
.88949 .59804 L
.89123 .57843 L
.89216 .56479 L
.89261 .55882 L
Mistroke
.89392 .53922 L
.89501 .51961 L
.89598 .5 L
.89686 .48039 L
.8977 .46078 L
.89848 .44118 L
.89914 .42157 L
.89957 .40196 L
.89954 .38235 L
.89869 .36275 L
.89653 .34314 L
.8929 .32353 L
.89216 .31915 L
.88592 .30392 L
.87255 .29562 L
.85294 .29147 L
.83333 .28964 L
.81509 .28431 L
.81373 .28371 L
.79412 .27011 L
.78882 .26471 L
.77565 .2451 L
.77451 .24283 L
.76748 .22549 L
.76237 .20588 L
.75896 .18627 L
.75561 .16667 L
.7549 .16338 L
.75018 .14706 L
.74021 .12745 L
.73529 .12417 L
.72387 .10784 L
.71569 .10051 L
.70163 .08824 L
.71569 .07394 L
.72981 .06863 L
.73529 .06527 L
.7549 .05842 L
.77451 .05357 L
.79412 .05001 L
.80241 .04902 L
.81373 .04826 L
.83248 .04902 L
.83333 .04911 L
.85294 .05307 L
.87255 .06076 L
.88589 .06863 L
.89216 .0733 L
.90642 .08824 L
.91176 .09642 L
Mistroke
.91731 .10784 L
.92395 .12745 L
.92909 .14706 L
.93137 .15651 L
.93369 .16667 L
.93785 .18627 L
.94142 .20588 L
.94444 .22549 L
.94724 .2451 L
.94774 .26471 L
.94978 .28431 L
.95098 .29476 L
.95219 .30392 L
.95519 .32353 L
.95861 .34314 L
.96211 .36275 L
.96529 .38235 L
.9678 .40196 L
.96955 .42157 L
.97058 .44118 L
.97059 .44152 L
.97104 .46078 L
.97112 .48039 L
.97596 .5 L
.97728 .51961 L
.97834 .53922 L
.97916 .55882 L
.9797 .57843 L
.97997 .59804 L
.97994 .61765 L
.97959 .63725 L
.97891 .65686 L
.9717 .67647 L
.97644 .69608 L
.97455 .71569 L
.97212 .73529 L
.97059 .74557 L
.96901 .7549 L
.96495 .77451 L
.95942 .79412 L
.95098 .81348 L
.9508 .81373 L
.93137 .81699 L
.92785 .81373 L
.91444 .79412 L
.91176 .78982 L
.90118 .77451 L
.89216 .7635 L
.87255 .76637 L
.86663 .77451 L
Mistroke
.85578 .79412 L
.85294 .79948 L
.84558 .81373 L
.83565 .83333 L
.83333 .83916 L
.83026 .85294 L
.8315 .87255 L
.83333 .88216 L
.83852 .89216 L
.84172 .91176 L
.83333 .92615 L
.82736 .93137 L
.81373 .94074 L
.79412 .94833 L
.78366 .95098 L
.77451 .95317 L
.7549 .95656 L
.73529 .95817 L
.71569 .95848 L
.69608 .95816 L
.67647 .95793 L
.65686 .95818 L
.63725 .95891 L
.61765 .9599 L
.59804 .96094 L
.57843 .96185 L
.55882 .96254 L
.53922 .96298 L
.51961 .96315 L
.5 .96304 L
.48039 .96264 L
.46078 .96192 L
.44118 .96087 L
.42157 .95945 L
.40196 .95762 L
.38235 .95534 L
.36275 .9525 L
.35369 .95098 L
.34314 .94924 L
.32353 .94511 L
.30392 .93958 L
.28431 .93229 L
.28219 .93137 L
.26471 .92436 L
.2451 .91233 L
.2446 .91176 L
.22549 .90119 L
.20588 .89751 L
.18627 .90124 L
.16667 .90821 L
Mistroke
.15429 .91176 L
.14706 .91306 L
.13041 .91176 L
.12745 .91088 L
.10784 .89773 L
.10235 .89216 L
.09033 .87255 L
.08824 .86789 L
.08418 .85294 L
.08148 .83333 L
.08094 .81373 L
.08047 .79412 L
.07863 .77451 L
.07538 .7549 L
.07169 .73529 L
.06863 .71712 L
.06833 .71569 L
.06456 .69608 L
.06122 .67647 L
.05832 .65686 L
.05585 .63725 L
.0538 .61765 L
.05215 .59804 L
.05088 .57843 L
.05 .55882 L
.04949 .53922 L
.04937 .51961 L
.04964 .5 L
.05029 .48039 L
.05133 .46078 L
.05274 .44118 L
.05452 .42157 L
.05674 .40196 L
.0595 .38235 L
.06255 .36275 L
.0651 .34314 L
.06682 .32353 L
.06863 .30437 L
.06867 .30392 L
.07059 .28431 L
.0776 .26471 L
.08824 .24591 L
.08899 .2451 L
.1067 .22549 L
.10784 .22439 L
.12745 .20732 L
.12935 .20588 L
.14706 .19035 L
.15156 .18627 L
.16667 .17186 L
Mistroke
.17074 .16667 L
.18358 .14706 L
.18572 .12745 L
.17957 .10784 L
.17836 .08824 L
.18627 .07854 L
.20224 .06863 L
.20588 .06677 L
.22549 .05938 L
.2451 .05449 L
.26471 .05098 L
.27927 .04902 L
.28431 .04833 L
Mfstroke
.46078 .439 m
.48039 .42825 L
.5 .42452 L
.51961 .42618 L
.53922 .43314 L
.55257 .44118 L
.55882 .4466 L
.57106 .46078 L
.57843 .47259 L
.58103 .48039 L
.58516 .5 L
.58404 .51961 L
.57843 .5362 L
.57687 .53922 L
.55962 .55882 L
.55882 .55939 L
.53922 .56905 L
.51961 .57206 L
.5 .56976 L
.48039 .56213 L
.47452 .55882 L
.46078 .54756 L
.45354 .53922 L
.44227 .51961 L
.44118 .5167 L
.43723 .5 L
.4374 .48039 L
.44118 .46589 L
.44336 .46078 L
.45817 .44118 L
.46078 .439 L
s
.53922 .1262 m
.55882 .12457 L
.57843 .12268 L
.59804 .12054 L
.61765 .11829 L
.63725 .11624 L
.65686 .1151 L
.67647 .1161 L
.69608 .12084 L
.71126 .12745 L
.71569 .13101 L
.72956 .14706 L
.73529 .15889 L
.73786 .16667 L
.74228 .18627 L
.74573 .20588 L
.7501 .22549 L
.7549 .24084 L
.75656 .2451 L
.76621 .26471 L
.77451 .27686 L
.78069 .28431 L
.79412 .29619 L
.80597 .30392 L
.81373 .307 L
.83333 .31217 L
.85294 .31518 L
.87118 .32353 L
.87255 .32473 L
.8851 .34314 L
.88937 .36275 L
.89113 .38235 L
.89184 .40196 L
.89199 .42157 L
.89181 .44118 L
.89144 .46078 L
.89094 .48039 L
.89032 .5 L
.88953 .51961 L
.88846 .53922 L
.88698 .55882 L
.88487 .57843 L
.88177 .59804 L
.87704 .61765 L
.87255 .63017 L
.86938 .63725 L
.85294 .65671 L
.85272 .65686 L
.83333 .66821 L
.82067 .67647 L
Mistroke
.81373 .68284 L
.80036 .69608 L
.79412 .70445 L
.78602 .71569 L
.77451 .73529 L
.77451 .73529 L
.76505 .7549 L
.75731 .77451 L
.7549 .78162 L
.75094 .79412 L
.74487 .81373 L
.73689 .83333 L
.73529 .83619 L
.72043 .85294 L
.71569 .85621 L
.69608 .86487 L
.67647 .86838 L
.65686 .86887 L
.63725 .86745 L
.61765 .86485 L
.59804 .86155 L
.57843 .85785 L
.55882 .85394 L
.5539 .85294 L
.53922 .85002 L
.51961 .84611 L
.5 .8423 L
.48039 .83873 L
.46078 .8355 L
.44602 .83333 L
.44118 .8327 L
.42157 .8304 L
.40196 .82853 L
.38235 .82712 L
.36275 .8262 L
.34314 .82579 L
.32353 .82593 L
.30392 .82665 L
.28431 .82796 L
.26471 .82969 L
.2451 .83121 L
.22549 .83083 L
.20588 .8254 L
.18851 .81373 L
.18627 .81097 L
.17493 .79412 L
.16838 .77451 L
.16667 .76385 L
.16588 .7549 L
.16544 .73529 L
Mistroke
.16582 .71569 L
.16631 .69608 L
.16659 .67647 L
.16658 .65686 L
.16622 .63725 L
.16554 .61765 L
.16453 .59804 L
.1632 .57843 L
.16154 .55882 L
.15957 .53922 L
.15726 .51961 L
.15462 .5 L
.15166 .48039 L
.14837 .46078 L
.14706 .45346 L
.14481 .44118 L
.14104 .42157 L
.13743 .40196 L
.13477 .38235 L
.13433 .36275 L
.13783 .34314 L
.14706 .32416 L
.14765 .32353 L
.16667 .30635 L
.17084 .30392 L
.18627 .29611 L
.20588 .28749 L
.21293 .28431 L
.22549 .27804 L
.2451 .26628 L
.24742 .26471 L
.26471 .25111 L
.27111 .2451 L
.28431 .23067 L
.28829 .22549 L
.30126 .20588 L
.30392 .20121 L
.31255 .18627 L
.32353 .1709 L
.32738 .16667 L
.34314 .15456 L
.35903 .14706 L
.36275 .1457 L
.38235 .14007 L
.40196 .13642 L
.42157 .13401 L
.44118 .13236 L
.46078 .13111 L
.48039 .13001 L
.5 .12887 L
Mistroke
.51961 .12759 L
.52153 .12745 L
.53922 .1262 L
Mfstroke
.22549 .04579 m
.2451 .04227 L
.26471 .03938 L
.28431 .03703 L
.30392 .03516 L
.32353 .03373 L
.34314 .03269 L
.36275 .03199 L
.38235 .03157 L
.40196 .03138 L
.42157 .03138 L
.44118 .03155 L
.46078 .03189 L
.48039 .03241 L
.5 .03314 L
.51961 .03411 L
.53922 .03533 L
.55882 .03685 L
.57843 .03869 L
.59804 .04087 L
.61765 .04338 L
.63725 .04607 L
.65686 .04862 L
.66036 .04902 L
.67647 .05034 L
.69608 .0506 L
.71569 .04902 L
.71578 .04902 L
.73529 .0458 L
.7549 .04175 L
.77451 .03772 L
.79412 .03452 L
.81373 .03286 L
.83333 .03337 L
.85294 .03646 L
.87255 .0423 L
.88815 .04902 L
.89216 .05113 L
.91176 .06464 L
.9159 .06863 L
.92998 .08824 L
.93137 .09111 L
.93741 .10784 L
.94193 .12745 L
.9455 .14706 L
.94883 .16667 L
.95098 .18037 L
.95185 .18627 L
.95443 .20588 L
.95656 .22549 L
Mistroke
.95833 .2451 L
.95994 .26471 L
.9616 .28431 L
.96343 .30392 L
.96544 .32353 L
.96749 .34314 L
.9694 .36275 L
.97059 .37705 L
.97098 .38235 L
.97217 .40196 L
.97302 .42157 L
.97364 .44118 L
.97417 .46078 L
.97472 .48039 L
.98212 .5 L
.98332 .51961 L
.98431 .53922 L
.98507 .55882 L
.9856 .57843 L
.98587 .59804 L
.98587 .61765 L
.9856 .63725 L
.98504 .65686 L
.97781 .67647 L
.98301 .69608 L
.98149 .71569 L
.97959 .73529 L
.97723 .7549 L
.9743 .77451 L
.97067 .79412 L
.97059 .79449 L
.96623 .81373 L
.96131 .83333 L
.95763 .85294 L
.95818 .87255 L
.96125 .89216 L
.95997 .91176 L
.95098 .92532 L
.93137 .93009 L
.91176 .91987 L
.90524 .91176 L
.9111 .89216 L
.91176 .88999 L
.92028 .87255 L
.92245 .85294 L
.91716 .83333 L
.91176 .81917 L
.90739 .81373 L
.89216 .79493 L
.87255 .80011 L
Mistroke
.86276 .81373 L
.85294 .83209 L
.85251 .83333 L
.84702 .85294 L
.84991 .87255 L
.85294 .88047 L
.86137 .89216 L
.87059 .91176 L
.85396 .93137 L
.85294 .93229 L
.83333 .94438 L
.81481 .95098 L
.81373 .95139 L
.79412 .95777 L
.77451 .9626 L
.7549 .96576 L
.73529 .96727 L
.71569 .96749 L
.69608 .96707 L
.67647 .96666 L
.65686 .96668 L
.63725 .96716 L
.61765 .96794 L
.59804 .9688 L
.57843 .9696 L
.55882 .97023 L
.54375 .97059 L
.53922 .97065 L
.51961 .97084 L
.5 .97079 L
.48531 .97059 L
.48039 .97049 L
.46078 .96992 L
.44118 .96906 L
.42157 .9679 L
.40196 .96641 L
.38235 .96456 L
.36275 .9623 L
.34314 .95957 L
.32353 .95628 L
.30392 .95234 L
.29796 .95098 L
.28431 .94771 L
.26471 .94209 L
.2451 .93571 L
.23321 .93137 L
.22549 .93004 L
.20588 .92737 L
.18627 .92929 L
.17552 .93137 L
Mistroke
.16667 .93441 L
.14706 .93839 L
.12745 .93664 L
.11598 .93137 L
.10784 .92552 L
.09442 .91176 L
.08824 .90224 L
.08225 .89216 L
.07345 .87255 L
.06863 .85478 L
.06838 .85294 L
.06653 .83333 L
.06653 .81373 L
.06663 .79412 L
.06563 .77451 L
.06333 .7549 L
.06022 .73529 L
.05686 .71569 L
.05364 .69608 L
.05071 .67647 L
.04902 .66392 L
.04817 .65686 L
.04599 .63725 L
.04411 .61765 L
.04251 .59804 L
.04122 .57843 L
.04023 .55882 L
.03955 .53922 L
.03921 .51961 L
.0392 .5 L
.03955 .48039 L
.04025 .46078 L
.04128 .44118 L
.0426 .42157 L
.04407 .40196 L
.04552 .38235 L
.04673 .36275 L
.04766 .34314 L
.04857 .32353 L
.04902 .31623 L
.04992 .30392 L
.05263 .28431 L
.05757 .26471 L
.06563 .2451 L
.06863 .23953 L
.07834 .22549 L
.08824 .21472 L
.09827 .20588 L
.10784 .19877 L
.12363 .18627 L
Mistroke
.12745 .18516 L
.14459 .16667 L
.14706 .16339 L
.15561 .14706 L
.15264 .12745 L
.14706 .11825 L
.13543 .10784 L
.12745 .09892 L
.12359 .08824 L
.12745 .08207 L
.14706 .06907 L
.14799 .06863 L
.16667 .0598 L
.18627 .0541 L
.20588 .04987 L
.21026 .04902 L
.22549 .04579 L
Mfstroke
.89216 .83233 m
.89257 .83333 L
.89786 .85294 L
.89216 .86674 L
.87255 .86271 L
.86955 .85294 L
.87255 .83961 L
.87715 .83333 L
.89216 .83233 L
s
.48039 .41447 m
.5 .41169 L
.51961 .41339 L
.53922 .41942 L
.54425 .42157 L
.55882 .43078 L
.57081 .44118 L
.57843 .44981 L
.58562 .46078 L
.59435 .48039 L
.59804 .49777 L
.59825 .5 L
.59804 .51607 L
.59759 .51961 L
.59189 .53922 L
.57956 .55882 L
.57843 .56009 L
.55882 .57538 L
.55505 .57843 L
.53922 .5827 L
.51961 .58486 L
.5 .58266 L
.4831 .57843 L
.48039 .57607 L
.46078 .56388 L
.45481 .55882 L
.44118 .54337 L
.43849 .53922 L
.42893 .51961 L
.4242 .5 L
.42405 .48039 L
.42878 .46078 L
.43965 .44118 L
.44118 .43923 L
.46078 .42253 L
.46194 .42157 L
.48039 .41447 L
s
.42157 .1459 m
.44118 .144 L
.46078 .14267 L
.48039 .14159 L
.5 .14056 L
.51961 .13945 L
.53922 .1382 L
.55882 .13679 L
.57843 .13524 L
.59804 .13365 L
.61765 .13222 L
.63725 .13134 L
.65686 .13168 L
.67647 .13449 L
.69608 .14237 L
.70274 .14706 L
.71569 .16333 L
.71727 .16667 L
.72368 .18627 L
.72755 .20588 L
.73149 .22549 L
.73529 .24016 L
.73685 .2451 L
.74452 .26471 L
.7549 .28387 L
.75519 .28431 L
.77041 .30392 L
.77451 .30804 L
.79412 .32313 L
.7947 .32353 L
.81373 .33206 L
.83333 .33686 L
.85294 .34168 L
.85601 .34314 L
.87255 .36095 L
.87352 .36275 L
.88022 .38235 L
.88311 .40196 L
.88437 .42157 L
.8848 .44118 L
.88474 .46078 L
.88434 .48039 L
.88363 .5 L
.88256 .51961 L
.88097 .53922 L
.87864 .55882 L
.87515 .57843 L
.87255 .58911 L
.87055 .59804 L
.86191 .61765 L
Mistroke
.85294 .62909 L
.84322 .63725 L
.83333 .64442 L
.81721 .65686 L
.81373 .65992 L
.79751 .67647 L
.79412 .68064 L
.78245 .69608 L
.77451 .70823 L
.77012 .71569 L
.75965 .73529 L
.7549 .74532 L
.75089 .7549 L
.74329 .77451 L
.73632 .79412 L
.73529 .79707 L
.72934 .81373 L
.71847 .83333 L
.71569 .83668 L
.69608 .85077 L
.68965 .85294 L
.67647 .856 L
.65686 .85705 L
.63725 .85554 L
.61917 .85294 L
.61765 .85262 L
.59804 .84912 L
.57843 .84509 L
.55882 .84083 L
.53922 .83657 L
.52385 .83333 L
.51961 .83252 L
.5 .82887 L
.48039 .82546 L
.46078 .82239 L
.44118 .81969 L
.42157 .81739 L
.40196 .81552 L
.38235 .81407 L
.37728 .81373 L
.36275 .8131 L
.34314 .81255 L
.32353 .81241 L
.30392 .8127 L
.28431 .81335 L
.27569 .81373 L
.26471 .81417 L
.2451 .81441 L
.23423 .81373 L
.22549 .81238 L
Mistroke
.20588 .8046 L
.19377 .79412 L
.18627 .78129 L
.18378 .77451 L
.17942 .7549 L
.178 .73529 L
.17777 .71569 L
.17785 .69608 L
.17783 .67647 L
.17757 .65686 L
.17704 .63725 L
.17623 .61765 L
.17516 .59804 L
.17384 .57843 L
.17227 .55882 L
.17048 .53922 L
.16847 .51961 L
.16667 .50334 L
.16622 .5 L
.16346 .48039 L
.16041 .46078 L
.15718 .44118 L
.15395 .42157 L
.15117 .40196 L
.14962 .38235 L
.15064 .36275 L
.15654 .34314 L
.16667 .32802 L
.17188 .32353 L
.18627 .31324 L
.20453 .30392 L
.20588 .30325 L
.22549 .2934 L
.24197 .28431 L
.2451 .28237 L
.26471 .26873 L
.2698 .26471 L
.28431 .25167 L
.29067 .2451 L
.30392 .22944 L
.30683 .22549 L
.32002 .20588 L
.32353 .20041 L
.33313 .18627 L
.34314 .17504 L
.35336 .16667 L
.36275 .16104 L
.38235 .15317 L
.40196 .14867 L
.41264 .14706 L
Mistroke
.42157 .1459 L
Mfstroke
.9902 .69954 m
.98913 .71569 L
.98758 .73529 L
.98573 .7549 L
.98354 .77451 L
.98095 .79412 L
.97805 .81373 L
.97537 .83333 L
.9743 .85294 L
.97623 .87255 L
.97988 .89216 L
.98051 .91176 L
.97303 .93137 L
.97059 .9352 L
.95098 .95029 L
.9485 .95098 L
.93137 .95202 L
.92625 .95098 L
.91176 .94737 L
.89216 .94378 L
.87255 .94541 L
.85294 .94986 L
.8482 .95098 L
.83333 .95632 L
.81373 .96285 L
.79412 .96864 L
.78673 .97059 L
.77451 .97323 L
.7549 .97627 L
.73529 .97767 L
.71569 .97773 L
.69608 .97707 L
.67647 .97637 L
.65686 .97609 L
.63725 .97632 L
.61765 .97691 L
.59804 .97764 L
.57843 .97835 L
.55882 .97894 L
.53922 .97936 L
.51961 .97957 L
.5 .97958 L
.48039 .97937 L
.46078 .97893 L
.44118 .97824 L
.42157 .9773 L
.40196 .97609 L
.38235 .97458 L
.36275 .97273 L
.34364 .97059 L
Mistroke
.34314 .97053 L
.32353 .96792 L
.30392 .96485 L
.28431 .96133 L
.26471 .95741 L
.2451 .95347 L
.23004 .95098 L
.22549 .95042 L
.20588 .94978 L
.19528 .95098 L
.18627 .95272 L
.16667 .95824 L
.14706 .96292 L
.12745 .96247 L
.10784 .95381 L
.10356 .95098 L
.08824 .9348 L
.0856 .93137 L
.07313 .91176 L
.06863 .9034 L
.06336 .89216 L
.05593 .87255 L
.0516 .85294 L
.05046 .83333 L
.05123 .81373 L
.05206 .79412 L
.05176 .77451 L
.05011 .7549 L
.04902 .74505 L
.04768 .73529 L
.04495 .71569 L
.04217 .69608 L
.03953 .67647 L
.03711 .65686 L
.03494 .63725 L
.03305 .61765 L
.03143 .59804 L
.0301 .57843 L
.02941 .56647 L
.02904 .55882 L
.02827 .53922 L
.02778 .51961 L
.02758 .5 L
.02766 .48039 L
.02802 .46078 L
.02862 .44118 L
.02938 .42157 L
.02941 .42083 L
.03018 .40196 L
.03089 .38235 L
Mistroke
.03141 .36275 L
.03181 .34314 L
.03237 .32353 L
.03356 .30392 L
.03588 .28431 L
.0398 .26471 L
.04577 .2451 L
.04902 .23682 L
.05444 .22549 L
.06683 .20588 L
.06863 .20405 L
.08425 .18627 L
.08824 .18228 L
.10366 .16667 L
.10784 .16039 L
.10977 .14706 L
.10784 .14369 L
.08824 .12938 L
.08495 .12745 L
.06863 .11995 L
.05763 .10784 L
.04916 .08824 L
.06345 .06863 L
.06863 .06463 L
.08824 .05601 L
.10784 .05197 L
.12745 .04948 L
.13152 .04902 L
.14706 .04601 L
.16667 .04222 L
.18627 .03857 L
.20588 .03519 L
.22549 .03213 L
.2451 .02942 L
.24518 .02941 L
.26471 .02709 L
.28431 .02514 L
.30392 .02356 L
.32353 .02234 L
.34314 .02144 L
.36275 .02082 L
.38235 .02045 L
.40196 .02027 L
.42157 .02026 L
.44118 .02039 L
.46078 .02067 L
.48039 .0211 L
.5 .02169 L
.51961 .02247 L
.53922 .02344 L
Mistroke
.55882 .02461 L
.57843 .02598 L
.59804 .02753 L
.61765 .02918 L
.62025 .02941 L
.63725 .03083 L
.65686 .03224 L
.67647 .03309 L
.69608 .03295 L
.71569 .03154 L
.73221 .02941 L
.73529 .02883 L
.7549 .0252 L
.77451 .02133 L
.79412 .01807 L
.81373 .0162 L
.83333 .01628 L
.85294 .01866 L
.87255 .02335 L
.89007 .02941 L
.89216 .03028 L
.91176 .04008 L
.92443 .04902 L
.93137 .0553 L
.942 .06863 L
.95098 .08684 L
.95145 .08824 L
.95623 .10784 L
.95895 .12745 L
.96114 .14706 L
.96338 .16667 L
.9656 .18627 L
.96755 .20588 L
.96911 .22549 L
.97034 .2451 L
.97059 .2497 L
.97136 .26471 L
.97233 .28431 L
.97334 .30392 L
.97441 .32353 L
.97551 .34314 L
.97659 .36275 L
.97766 .38235 L
.97878 .40196 L
.98006 .42157 L
.98158 .44118 L
.98342 .46078 L
.98561 .48039 L
.98929 .5 L
.9902 .51511 L
Mistroke
Mfstroke
.48039 .39778 m
.5 .39585 L
.51961 .39754 L
.53866 .40196 L
.53922 .40266 L
.55882 .41252 L
.57192 .42157 L
.57843 .42734 L
.59088 .44118 L
.59804 .45123 L
.60299 .46078 L
.61052 .48039 L
.61419 .5 L
.61395 .51961 L
.60955 .53922 L
.60043 .55882 L
.59804 .56259 L
.58373 .57843 L
.57843 .58261 L
.55882 .5937 L
.54974 .59804 L
.53922 .59939 L
.51961 .6008 L
.5 .59879 L
.49487 .59804 L
.48039 .59274 L
.46078 .58252 L
.45461 .57843 L
.44118 .56676 L
.434 .55882 L
.42157 .54104 L
.42066 .53922 L
.41267 .51961 L
.40835 .5 L
.40788 .48039 L
.41146 .46078 L
.41955 .44118 L
.42157 .43759 L
.4346 .42157 L
.44118 .41581 L
.46078 .40381 L
.46344 .40196 L
.48039 .39778 L
s
.40196 .16413 m
.42157 .15997 L
.44118 .15751 L
.46078 .15598 L
.48039 .1549 L
.5 .15397 L
.51961 .15306 L
.53922 .15208 L
.55882 .15103 L
.57843 .14997 L
.59804 .149 L
.61765 .14839 L
.63725 .1486 L
.65686 .15063 L
.67647 .15716 L
.68868 .16667 L
.69608 .17717 L
.69991 .18627 L
.70517 .20588 L
.70909 .22549 L
.71362 .2451 L
.71569 .25252 L
.71981 .26471 L
.72813 .28431 L
.73529 .29784 L
.73906 .30392 L
.7538 .32353 L
.7549 .32477 L
.77451 .34286 L
.77487 .34314 L
.79412 .3549 L
.81373 .36246 L
.81484 .36275 L
.83333 .36727 L
.85294 .37589 L
.8587 .38235 L
.86727 .40196 L
.87096 .42157 L
.87255 .43841 L
.87271 .44118 L
.87348 .46078 L
.87347 .48039 L
.87281 .5 L
.87255 .50564 L
.87161 .51961 L
.86967 .53922 L
.86852 .55882 L
.86244 .57843 L
.85294 .59568 L
.85121 .59804 L
Mistroke
.83333 .61622 L
.83162 .61765 L
.81373 .63284 L
.80898 .63725 L
.79412 .65293 L
.79078 .65686 L
.77574 .67647 L
.77451 .67824 L
.76317 .69608 L
.7549 .71022 L
.75216 .71569 L
.7426 .73529 L
.73529 .7515 L
.73403 .7549 L
.72662 .77451 L
.71875 .79412 L
.71569 .80095 L
.70993 .81373 L
.69608 .8295 L
.6903 .83333 L
.67647 .83924 L
.65686 .84156 L
.63725 .84013 L
.61765 .83676 L
.60148 .83333 L
.59804 .83263 L
.57843 .82849 L
.55882 .82418 L
.53922 .81994 L
.51961 .81594 L
.50795 .81373 L
.5 .81248 L
.48039 .80953 L
.46078 .80679 L
.44118 .80433 L
.42157 .80218 L
.40196 .80037 L
.38235 .79891 L
.36275 .79781 L
.34314 .79707 L
.32353 .79671 L
.30392 .79668 L
.28431 .79691 L
.26471 .79704 L
.2451 .79607 L
.2336 .79412 L
.22549 .79188 L
.20588 .77705 L
.20412 .77451 L
.1958 .7549 L
Mistroke
.19296 .73529 L
.19204 .71569 L
.19171 .69608 L
.19143 .67647 L
.19099 .65686 L
.19037 .63725 L
.18956 .61765 L
.18858 .59804 L
.18745 .57843 L
.18627 .55977 L
.18619 .55882 L
.18431 .53922 L
.18219 .51961 L
.17982 .5 L
.17725 .48039 L
.17453 .46078 L
.17178 .44118 L
.16924 .42157 L
.16736 .40196 L
.16695 .38235 L
.16982 .36275 L
.18014 .34314 L
.18627 .3363 L
.20477 .32353 L
.20588 .32285 L
.22549 .31197 L
.24075 .30392 L
.2451 .30135 L
.26471 .28877 L
.27114 .28431 L
.28431 .2739 L
.2948 .26471 L
.30392 .25579 L
.31366 .2451 L
.32353 .2331 L
.32911 .22549 L
.34313 .20588 L
.34314 .20587 L
.35956 .18627 L
.36275 .18342 L
.38235 .17072 L
.39348 .16667 L
.40196 .16413 L
Mfstroke
.9902 .85912 m
.98933 .85294 L
.9888 .83333 L
.99018 .81373 L
.9902 .81347 L
s
.9902 .94225 m
.98239 .95098 L
.97059 .96252 L
.95957 .97059 L
.95098 .97464 L
.93137 .97457 L
.92003 .97059 L
.91176 .96723 L
.89216 .96144 L
.87255 .96121 L
.85294 .96515 L
.83397 .97059 L
.83333 .97083 L
.81373 .97678 L
.79412 .98219 L
.77451 .9865 L
.7549 .98937 L
.74528 .9902 L
s
.70623 .9902 m
.69608 .98963 L
.67647 .98852 L
.65686 .9878 L
.63725 .98765 L
.61765 .98796 L
.59804 .98849 L
.57843 .98907 L
.55882 .98957 L
.53922 .98995 L
.51961 .99016 L
.51288 .9902 L
s
.49631 .9902 m
.48039 .99008 L
.46078 .98977 L
.44118 .98927 L
.42157 .98857 L
.40196 .98766 L
.38235 .98652 L
.36275 .98513 L
.34314 .98345 L
.32353 .98146 L
.30392 .97914 L
.28431 .97651 L
.26471 .97372 L
.2451 .97125 L
.23783 .97059 L
.22549 .97005 L
.21356 .97059 L
.20588 .97158 L
.18627 .97694 L
.16667 .98519 L
.15416 .9902 L
s
.0098 .11528 m
.02387 .12745 L
.02941 .13224 L
.04215 .14706 L
.04902 .16193 L
.04969 .16667 L
.04902 .17496 L
.04608 .18627 L
.03858 .20588 L
.03113 .22549 L
.02941 .23053 L
.02497 .2451 L
.02037 .26471 L
.01727 .28431 L
.01543 .30392 L
.01459 .32353 L
.01435 .34314 L
.01437 .36275 L
.01434 .38235 L
.01417 .40196 L
.01389 .42157 L
.01359 .44118 L
.01338 .46078 L
.01332 .48039 L
.01347 .5 L
.01383 .51961 L
.01441 .53922 L
.01522 .55882 L
.01626 .57843 L
.01753 .59804 L
.01903 .61765 L
.02079 .63725 L
.0228 .65686 L
.02508 .67647 L
.02758 .69608 L
.02941 .70959 L
.03023 .71569 L
.03277 .73529 L
.03475 .7549 L
.03555 .77451 L
.03466 .79412 L
.0323 .81373 L
.02996 .83333 L
.02992 .85294 L
.03368 .87255 L
.04077 .89216 L
.04902 .91089 L
.04946 .91176 L
.05986 .93137 L
.06863 .9459 L
Mistroke
.07212 .95098 L
.08824 .97023 L
.08854 .97059 L
.10784 .98634 L
.1155 .9902 L
Mfstroke
.9902 .382 m
.9885 .36275 L
.98724 .34314 L
.98634 .32353 L
.98573 .30392 L
.9853 .28431 L
.98497 .26471 L
.9846 .2451 L
.98405 .22549 L
.9832 .20588 L
.98205 .18627 L
.98078 .16667 L
.97974 .14706 L
.97906 .12745 L
.97817 .10784 L
.97545 .08824 L
.97059 .0723 L
.96876 .06863 L
.95655 .04902 L
.95098 .04238 L
.93697 .02941 L
.93137 .02519 L
.91176 .01384 L
.90236 .0098 L
s
.73536 .0098 m
.73529 .00982 L
.71569 .01306 L
.69608 .01507 L
.67647 .01584 L
.65686 .01561 L
.63725 .01474 L
.61765 .01355 L
.59804 .01226 L
.57843 .01101 L
.55882 .0099 L
.55703 .0098 L
s
.0098 .05878 m
.02941 .0493 L
.03054 .04902 L
.04902 .04148 L
.06863 .03623 L
.08824 .03289 L
.10784 .03062 L
.11967 .02941 L
.12745 .02864 L
.14706 .02648 L
.16667 .02405 L
.18627 .02148 L
.20588 .01894 L
.22549 .01659 L
.2451 .01448 L
.26471 .01264 L
.28431 .01108 L
.30348 .0098 L
s
.46078 .37699 m
.48039 .37259 L
.5 .37135 L
.51961 .37324 L
.53922 .37793 L
.55309 .38235 L
.55882 .38529 L
.57843 .3972 L
.58522 .40196 L
.59804 .4135 L
.60533 .42157 L
.61765 .43754 L
.61957 .44118 L
.62916 .46078 L
.63601 .48039 L
.63725 .48564 L
.63883 .5 L
.639 .51961 L
.63725 .53568 L
.63642 .53922 L
.62947 .55882 L
.6187 .57843 L
.61765 .58001 L
.60093 .59804 L
.59804 .60036 L
.57843 .61294 L
.56883 .61765 L
.55882 .62045 L
.53922 .62417 L
.51961 .62495 L
.5 .62282 L
.48039 .61835 L
.47775 .61765 L
.46078 .60964 L
.4413 .59804 L
.44118 .59794 L
.42157 .58048 L
.41971 .57843 L
.40462 .55882 L
.40196 .55477 L
.39464 .53922 L
.38737 .51961 L
.38325 .5 L
.38244 .48039 L
.38502 .46078 L
.39121 .44118 L
.401 .42157 L
.40196 .41998 L
.41736 .40196 L
.42157 .39825 L
Mistroke
.44118 .38474 L
.44548 .38235 L
.46078 .37699 L
Mfstroke
.42157 .18306 m
.44118 .17873 L
.46078 .17634 L
.48039 .17492 L
.5 .17393 L
.51961 .1731 L
.53922 .1723 L
.55882 .17154 L
.57843 .17093 L
.59804 .17071 L
.61765 .17145 L
.63725 .17476 L
.65686 .18627 L
.65686 .18628 L
.66962 .20588 L
.67462 .22549 L
.67647 .23494 L
.67875 .2451 L
.68384 .26471 L
.69015 .28431 L
.69608 .2998 L
.69796 .30392 L
.7081 .32353 L
.71569 .33609 L
.72059 .34314 L
.73529 .36131 L
.73662 .36275 L
.7549 .37971 L
.75824 .38235 L
.77451 .39307 L
.79255 .40196 L
.79412 .40256 L
.81373 .40881 L
.83333 .41555 L
.84198 .42157 L
.85206 .44118 L
.85294 .44363 L
.85561 .46078 L
.85682 .48039 L
.85655 .5 L
.85481 .51961 L
.85294 .53223 L
.85103 .53922 L
.84391 .55882 L
.83333 .5728 L
.82781 .57843 L
.81373 .59205 L
.80742 .59804 L
.79412 .61181 L
.78895 .61765 L
Mistroke
.77451 .63514 L
.77299 .63725 L
.75916 .65686 L
.7549 .66316 L
.74723 .67647 L
.73566 .69608 L
.73529 .69673 L
.7265 .71569 L
.7169 .73529 L
.71569 .73787 L
.70942 .7549 L
.70035 .77451 L
.69608 .78235 L
.69106 .79412 L
.67647 .80699 L
.65686 .81361 L
.63725 .81347 L
.61765 .81085 L
.59804 .80702 L
.57843 .80275 L
.55882 .7985 L
.53922 .7945 L
.53723 .79412 L
.51961 .79176 L
.5 .78901 L
.48039 .78628 L
.46078 .78369 L
.44118 .78133 L
.42157 .77923 L
.40196 .77743 L
.38235 .77594 L
.36275 .77475 L
.35818 .77451 L
.34314 .77414 L
.32353 .77377 L
.30392 .77353 L
.28431 .7733 L
.26471 .77258 L
.2451 .76948 L
.22572 .7549 L
.22549 .75474 L
.21655 .73529 L
.21373 .71569 L
.21266 .69608 L
.212 .67647 L
.21133 .65686 L
.21055 .63725 L
.20964 .61765 L
.20864 .59804 L
.2076 .57843 L
Mistroke
.20659 .55882 L
.20588 .54372 L
.20543 .53922 L
.20332 .51961 L
.20099 .5 L
.19848 .48039 L
.19589 .46078 L
.19339 .44118 L
.19136 .42157 L
.19052 .40196 L
.19243 .38235 L
.20129 .36275 L
.20588 .35652 L
.22323 .34314 L
.22549 .34159 L
.2451 .3295 L
.2563 .32353 L
.26471 .31813 L
.28431 .30515 L
.28618 .30392 L
.30392 .28981 L
.31051 .28431 L
.32353 .27215 L
.33081 .26471 L
.34314 .25116 L
.34802 .2451 L
.36275 .22668 L
.3636 .22549 L
.3804 .20588 L
.38235 .20403 L
.40196 .18985 L
.41162 .18627 L
.42157 .18306 L
Mfstroke
.0098 .77008 m
.0105 .7549 L
.00987 .73529 L
.0098 .73362 L
s
.9902 .98157 m
.98354 .9902 L
s
.89879 .9902 m
.89216 .98821 L
.87255 .98496 L
.85294 .98709 L
.83527 .9902 L
s
.0098 .91208 m
.02046 .93137 L
.02941 .94558 L
.03305 .95098 L
.04683 .97059 L
.04902 .97389 L
.06145 .9902 L
s
.9902 .03489 m
.98533 .02941 L
.97059 .01466 L
.96529 .0098 L
s
.0098 .01883 m
.02941 .01245 L
.039 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`21ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool0coooool000Wooooo00<0
0000ooooooooool00oooool4o`0002;ooooo3Ol0000/ooooo`03o`0000000000000000X000003Ooo
ool6000001gooooo0ol00008ooooo`;o00001_ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool2o`0001l06ATI1ol0000L03<c<`P000008P0c<c<=000000h0<c<c3`00
000903<c<`;o00001`0I6AT00ol00000000000000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?oooooooooooooooaX06ATI1ol0000>03<c<aD00000201<C4`K000001/0<c<c1`00
000?04a<C0<00000200c<c<00ol000006ATI01TI6@0501TI6@03o`000000003ooooo00?ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo400I6AT:o`0000h0<c<c1`00
000A04a<C0l00000601<C4`400000003o`0000000000000000@000002@0c<c<7000001T0C4a<0`00
000603<c<`03o`00000I6AT06ATI00D06ATI00?o0000ooooooooool00_ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool901TI6@Oo00004@0c<c<7000000L0C4a<4@00
000?06IVIQD000003P1<C4`9000000h0C4a<3`00000604a<C0030000000c<c<0<c<c00@0<c<c00?o
000001TI6@0I6AT01@0I6AT01Ol0003oooooooooooooool000000=7ooooo0009ooooo`0400000?oo
ooooooooooooo`H06ATI0ol0000A03<c<`L000001`1<C4`7000000h0IVIV5P00000A06IVIPL00000
5`1<C4`7000000l0IVIV0P00000504a<C08000001@0c<c<00ol000006ATI01TI6@0401TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo100I6AT2o`000140<c<c
0`00000;04a<C0<00000201VIVH00ol0000000000000000:000001H0Ogmo3000000<06IVIPL00000
2`1<C4`00ol00000C4a<00000002000000/0IVIV1000000906IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0401TI6@Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo0P0I6AT2o`0000`0<c<c100000000ol000000000
0000000604a<C0D0000000?o00000000000000001P1VIVH400000003o`00001oOgl0Ogmo00@0Ogmo
5P00000C07moO`P000002`1VIVH00ol0000000000000000:000000L0IVIV1@0000000ol000000000
07moO`0307moO`03o`0000000000000000<00000101VIVH00ol0000000000000000404a<C003o`00
000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT00`0I6AT4ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooo`;o00002P0c<c<4000000X0C4a<0`00000806IVIPH00000
101oOgl7000001H0VIVI3@00000>07moO`@000005`1VIVH400000140Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0
0P0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`X0<c<c
0P00000=04a<C0030000001VIVH0IVIV00L0IVIV0P00000707moO`<00000:P2IVIT7000000/0Ogmo
0`00000B06IVIP8000002`1oOgl4000000L0Ogmo0`00000406IVIP03o`00001<C4`0C4a<0080C4a<
00<0000003<c<`0c<c<00P0c<c<01?l000006ATI01TI6@0I6AT4ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooo`T0<c<c00?o000004a<C01<C4`02`1<C4`2000000P0
IVIV0P00000507moO`0400000?l000000000000000X0VIVI5_l0000D09VIV@800000301oOgl01000
003o000000000000000<06IVIP0300000?l00000Ogmo00P0Ogmo00@00000o`000?l000000000102I
VIT300000003o`0000000000Ogmo00@0Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT01?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool903<c<`030000001<C4`0C4a<00T0C4a<0P00
000906IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0202IVIT4o`0001H0/k>c1Ol0
000@09VIV@030000001oOgl0Ogmo00h0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000Ogmo07mo
O`0707moO`8000003@2IVIT00`000000Ogmo07moO`0307moO`050000001VIVH0IVIV06IVIP000000
101<C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo200c<c<00`000000C4a<04a<C00904a<C0030000
001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@?o0000
7P2c/k<00ol00000VIVI09VIV@0?09VIV@030000001oOgl0Ogmo00d0Ogmo00<0000006IVIP1VIVH0
1`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00h0VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00D0000003<c<`0c<c<0
<c<co`00000201TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo200c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1o
Ogl0101oOgl00`000000VIVI09VIV@0509VIV@;o00008@2c/k<00ol00000VIVI09VIV@0?09VIV@03
0000001oOgl0Ogmo00d0Ogmo00<00000o`00001VIVH01P1VIVH00`000000Ogmo07moO`0707moO`03
0000002IVIT0VIVI00H0VIVI1Ol0000509VIV@8000000`1oOgl00`000000IVIV06IVIP0206IVIP05
0000001<C4`0C4a<04a<C?l00000100c<c<00ol000006ATIooooo`03ooooo`0300000?oooooooooo
08_ooooo0_l00012ooooo`002Oooool01000003oooooooooooooool703<c<`030000001<C4`0C4a<
00X0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI
00D0VIVI00?o00000;>c/`2c/k<0702c/k<6o`0000h0VIVI1@00000=07moO`8000001`1VIVH20000
00P0Ogmo00<0000009VIV@2IVIT01@2IVIT2o`0000@0/k>c0ol0000509VIV@050000001oOgl0Ogmo
07moOol00000101VIVH010000000C4a<04a<C000000403<c<`03o`00000I6AWooooo00?ooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooo`L0<c<c00<0000004a<C01<C4`02P1<C4`00ol00000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00ol00000/k>c0;>c/`0E0;>c/`Oo00004@2I
VIT3000000h0Ogmo1000000;06IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102I
VIT00ol00000/k>c0;>c/`070;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1o
Ogl01@000000IVIV06IVIP1VIVH000000080C4a<00<0000003<c<`0c<c<00P0c<c<00ol000006ATI
ooooo`03ooooo`0300000?oooooooooo08Kooooo0_l00004ooooo`;o0000@Oooool000Wooooo00@0
0000oooooooooooooooo200c<c<00`000000C4a<04a<C00:04a<C0030000001VIVH0IVIV00H0IVIV
00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@03o`00002c/k<0/k>c00l0/k>c
1ol0000A09VIV@L000002`1oOgl600000100IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0309VIV@03o`00002c/k<0/k>c00T0/k>c00?o000009VIV@2IVIT00P2IVIT01@000000Ogmo
07moO`1oOgl0000000@0IVIV00@0000004a<C01<C4`000000`0c<c<00ol000006ATIooooo`03oooo
o`0300000?oooooooooo08?ooooo0ol00006ooooo`03o`000?oooooo0000043ooooo0009ooooo`04
00000?ooooooooooooooo`P0<c<c00<0000004a<C01<C4`02`1<C4`00`000000IVIV06IVIP0506IV
IP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`0;0;>c
/`Co00003P2IVIT:000000h0Ogmo0P0000000ol00000000006IVIP0F06IVIP03o`00001oOgl0Ogmo
00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`0;0;>c/`03o`00002IVIT0VIVI
0080VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP040000001<C4`0C4a<000000<0<c<c00?o
000001TI6Oooool00oooool00`00003oooooooooo`20ooooo`?o00002?ooool0102hYLOo0000oooo
ool00010ooooo`002Oooool01@00003oooooooooooooool0000000P0<c<c00<0000004a<C01<C4`0
2`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0
1@2IVIT00ol00000/k>c0;>c/`070;>c/`?o00002`2IVIT700000140Ogmo1`00000:06IVIP`00000
1@1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<0
2`2c/k<00ol00000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH010000000
C4a<04a<C000000303<c<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0O_ooool2o`00
00[ooooo0P2hYLL01?l0003oooooooooool0000oooooo`002Oooool01P00003oooooooooooooool0
6ATI000000P0<c<c0`00000;04a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl00P1o
Ogl00`000000VIVI09VIV@0609VIV@Wo00001`2IVIT7000000X0Ogmo3P00000:06IVIPL00000301<
C4`3000000<0IVIV00<0000007moO`1oOgl00`1oOgl01@000000VIVI09VIV@2IVIWo000000h0/k>c
00?o000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00@0000004a<C01<
C4`000000P0c<c<00ol000006ATIooooo`03ooooo`0300000?oooooooooo07_ooooo0ol0000;oooo
o`<0^:G700Go0000ooooooooooooooooo`00000nooooo`002Oooool01000003oooooooooooooool2
01TI6@03o`00000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT04@2IVIT5000000D0Ogmo00?o0000
0000000000002@00000<06IVIP`000005P1<C4`01_l00000IVIV06IVIP1VIVH00000o`0000<0Ogmo
00D0000009VIV@2IVIT0VIVIo`00000?0;>c/`03o`00002IVIT0VIVI0080VIVI00D0000007moO`1o
Ogl0Ogmo0000000206IVIP040000001<C4`0C4a<00000080<c<c00?o000001TI6Oooool00oooool0
0`00003oooooooooo`1iooooo`;o00003Oooool20;RO_P80^:G700Go0000ooooooooooooooooo`00
000nooooo`002Oooool01000003oooooooooooooool301TI6@030000000c<c<0<c<c00P0<c<c00?o
00000000001<C4`0201<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT03`2IVIT2000000D0Ogmo1P00000806IVIPl0000000?o000004a<C01<C4`03@1<
C4`;000000P0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`050000002IVIT0VIVI09VIVOl0
00003`2c/k<00ol00000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH01000
0000C4a<04a<C000000203<c<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0M_ooool3
o`0000gooooo00P0]YNh0;RO_P2hWkh0^9nn0;RUa`2mYL;o00000;fU`P?ooooo00?o0000oooooooo
ool0>oooool000Wooooo00@00000oooooooooooooooo0`0I6AT00`000000<c<c03<c<`0:03<c<`03
0000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`03
0000002IVIT0VIVI00h0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIPL0
00004@1<C4`>000000/0<c<c1000000404a<C0030000001VIVH0IVIV0080IVIV00@0000007moO`1o
Ogl000000`2IVIT00ol00000/k>c0;>c/`060;>c/`03o`00002c/k<0/k>c00D0/k>c00Go000009VI
V@2IVIT0VIVI0000000307moO`040000001VIVH0IVIV00000080C4a<00D0000003<c<`0c<c?o0000
01TI6@04ooooo`0300000?oooooooooo07Cooooo0_l0000?ooooo`<0]YNh0P2hWkh20;fU`P03o`00
002mYL;ooooo00;ooooo00?o0000ooooooooool0>oooool000Wooooo00@00000oooooooooooooooo
100I6AT00`000000<c<c03<c<`0:03<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00d0VIVI0P00000507moO`800000
101VIVH4000000L0C4a<4@00000M03<c<`03o`00001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0
IVIV0000000307moO`050000002IVIT0VIVI09VIVOl000001P2c/k<00ol00000c<c<o`0000060;>c
/`03o`00002IVIT0VIVI0080VIVI00L0000007moO`1oOgl0Ogmo0000001VIVH000000080C4a<00D0
000003<c<`0c<c?o000001TI6@04ooooo`0300000?oooooooooo077ooooo0ol0000?ooooo`030;2?
]02fUkP0]YNh0080]YNh00L0^9nn0;jN^@2nW[T0_JG2o`00002mYL80aJ_000?ooooo00?o0000oooo
ooooool0>_ooool000Wooooo00@00000oooooooooooooooo1@0I6AT00`000000<c<c03<c<`0903<c
<`03o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI00`0VIVI00<0000007moO`1oOgl00P1oOgl00`00003o00000000000206IV
IP0400000?l000000000000000@0C4a<1`00000H03<c<`l00000200c<c<00`000000C4a<04a<C002
04a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIWo000000D0/k>c
00Go00000<c<c03<c<`0c<c<o`0000060;>c/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl00`00
0000IVIV0000000204a<C0050000000c<c<0<c<co`00000I6AT01?ooool00`00003oooooooooo`1^
ooooo`?o00004Oooool20;2?]0@0]YNh102nW[T01?l00000aJ_00<F[`035Zl03ooooo`03o`000?oo
oooooooo03Wooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00<0000003<c<`0c<c<02@0c
<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1o
Ogl00`000000VIVI09VIV@0;09VIV@030000001oOgl0Ogmo0080Ogmo00@0000006IVIP1VIVH0IVIV
0P00000404a<C0@000003P0c<c<A000000l06ATI0`00000603<c<`050000001<C4`0C4a<04a<C000
00000`1VIVH010000000Ogmo07moO`00000309VIV@03o`00002c/k<0/k>c00<0/k>c00Go00000<c<
c03<c<`0c<c<o`0000060;>c/`05o`00002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV0000
000204a<C0050000000c<c<0<c<co`00000I6AT01?ooool00`00003oooooooooo`1/ooooo`;o0000
4oooool40;2?]080]YNh00<0^YNc0;jN^@2nW[T00P2nW[T01035Zl3o00000<F[`035Zl03ooooo`03
o`000?oooooooooo03Wooooo0009ooooo`0400000?ooooooooooooooo`H06ATI00<0000003<c<`0c
<c<0200c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0;09VIV@03o`00001oOgl0Ogmo0080Ogmo00D0000006IVIP1V
IVH0IVIV0000000304a<C0<000001`0c<c<;000002<06ATI0`00000403<c<`050000001<C4`0C4a<
04a<C?l000000`1VIVH010000000Ogmo07moO`00000209VIV@03o`00002c/k<0/k>c0080/k>c00?o
00000<c<c03<c<`00`3<c<`00ol00000/k>c0;>c/`040;>c/`04o`00002IVIT0VIVI000000<0Ogmo
00Co000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<ol00004ooooo`0300000?oooooooooo
06Wooooo0ol0000Dooooo`80ZhRa0`2`Sk@0102fUkP0^YNc0;ZG/`2jUk<20;jN^@80aZBf00Co0000
0<F[`03@]/00d;K00oooool00ol0003oooooooooo`0hooooo`002Oooool01000003ooooooooooooo
ool701TI6@030000000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`0101<C4`00ol00000000006IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT0302IVIT01@000000Ogmo07mo
O`1oOgoo000000<0IVIV00D0000004a<C01<C4`0C4a<0000000603<c<`0400000?l0003o00000000
03406ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00@00000
07moO`1oOgl000000P2IVIT00ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00<0c<c<00?o
00000;>c/`2c/k<0102c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1VIVH0
00000P1<C4`010000000<c<c03<c<ol00004ooooo`0300000?oooooooooo06Oooooo0_l0000Eoooo
o`040:J3[P2[R;40ZhRa0:^8/@<0/8nd102jUk<01@2nW[T0aZBf0<JT]P36Y;Ko000000<0d;K01?oo
ool00ol0003oooooooooo`0gooooo`002Oooool01000003oooooooooooooool701TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`01@000000IVIV06IVIP1VIVKo000000@0Ogmo
00<0000009VIV@2IVIT03@2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00?o000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0203<c<`8000006@0I6ATB000000X06ATI00<0000003<c<`0c
<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000P2IVIT0
0ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<0102c/k<0
1Ol00000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1VIVH000000P1<C4`010000000<c<c
03<c<ol00004ooooo`0300000?oooooooooo06Cooooo0ol0000Fooooo`80YX>^0`2[R;430;2?]004
0;B?[`2jUk<0^YNc0;ZG/`@0aZBf00Go00000=2f`03@]/00d;K00=_1_`03ooooo`03o`000?oooooo
oooo03Oooooo0009ooooo`0400000?ooooooooooooooo`L06ATI00<0000003<c<`0c<c<01@0c<c<0
0`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000
000509VIV@?o00001`2IVIT00`000000Ogmo07moO`0207moO`040000001VIVH0IVIV000000<0C4a<
00@0000003<c<`0c<c<0<c<c0P00000=01TI6B<00000200I6AT01@000000<c<c03<c<`0c<c<00000
00<0C4a<00@0000006IVIP1VIVH000000P1oOgl010000000VIVI09VIVOl000040;>c/`03o`00003<
c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<0102c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo
00@0000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<ol00004ooooo`0300000?oooooooooo
06;ooooo0_l0000Hooooo`@0YX>^0`2[R;400`2`Sk@0]8n_0;B?[`030;ZG/`050<>L/036Y;H0aZBf
0<JT]_l000000P3@]/020=_1_`Cooooo00?o0000ooooooooool0=_ooool000Wooooo00@00000oooo
oooooooooooo1`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI0_l000030;>c/`03o`00002I
VIT0VIVI00@0VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP050000001<C4`0C4a<04a<C000
00000`0c<c<00`0000006ATI01TI6@0701TI6BX000001`0I6AT00`000000<c<c03<c<`0203<c<`04
0000001<C4`0C4a<00000080IVIV00@0000007moO`1oOgl000000`2IVIT00ol00000/k>c0;>c/`02
0;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<0102c/k<00ol00000VIVI09VIV@02
09VIV@060000001oOgl0Ogmo0000001VIVKo00000P1<C4`010000000<c<c03<c<ol00004ooooo`03
00000?oooooooooo05oooooo0ol0000Iooooo`80XWf/0`2VPjh20:^8/@040:n8[02dSjl0]8n_0;B?
[`80^YNc0P33W;020<JT]P030=6^]Ol00000d;K000<0fl6o00<0h/Nmooooooooool00_ooool00ol0
003oooooooooo`0eooooo`002Oooool01000003oooooooooooooool601TI6@030000000c<c<0<c<c
00@0<c<c00?o000004a<C01<C4`00`1<C4`2000000@0IVIV00<0000007moO`1oOgl00P00000309VI
V@;o00001P2c/k<00ol00000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH0
1@000000C4a<04a<C01<C4`0000000@0<c<c00?o000001TI6@0I6AT01@0I6AT]00000003o`00000I
6AT06ATI00@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080
Ogmo00Go000009VIV@2IVIT0VIVIo`0000040;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000;>c
/`2c/k<0102c/k<00ol00000VIVI09VIV@0209VIV@040000001oOgl0Ogmo00000080IVIV00<00000
04a<C00000000P0c<c<00ol0003oooooooooo`02ooooo`0300000?oooooooooo05gooooo0_l0000J
ooooo`0409ahZ`2ROJ`0XWf/0:9m[0<0YX>^00<0ZhRa0:n8[02_R:`0102dSjl0202jUk<0`ib`0<>L
/033W;00aZBf0=6^]Ol00000g;Rd0P3K`Kl20>;7_@050>G7^Oooooooooooooooool00000=oooool0
00Wooooo00@00000oooooooooooooooo1P0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH01@00003o000007moO`1oOgl0000000@0VIVI00?o
00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`000000
0P1VIVH010000000C4a<04a<C000000403<c<`030000000I6AT06ATI00@06ATI<000000601TI6@05
0000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0
VIVI09VIVOl000001@2c/k<00ol00000c<c<0<c<c002o`0000H0/k>c00?o000009VIV@2IVIT00P2I
VIT010000000Ogmo07moO`00000206IVIP030000001<C4`000000080<c<c00?o0000ooooooooool0
0_ooool00`00003oooooooooo`1Jooooo`?o00006Oooool0102ELj/0W7R[09ahZ`2LN:/30:9m[0<0
YX>^102_R:`30;B?[`@0`ib`0P3A[[D01?l00000g;Rd0=bh]03K`Kl20>;7_@80iLNi0oooool00ol0
003oooooooooo`0dooooo`002Oooool01000003oooooooooooooool501TI6@030000000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`00P1<C4`2000000@0IVIV00D0000007moO`1oOgl0Ogmo00000004
09VIV@03o`00002c/k<0/k>c00L0/k>c00Go000009VIV@2IVIT0VIVI0000000307moO`040000001V
IVH0IVIV00000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0401TI6C800000
1P0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl01000
0000VIVI09VIVOl000060;>c/`;o0000202c/k<00ol00000VIVI09VIV@0309VIV@080000001oOgl0
Ogmo0000001VIVH0000004a<C000000203<c<`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool0Eoooool3o`0001Wooooo00@0SVn[09EcZ`2ELj/0UG>[0`2LN:/40:9m[080YX>^00@0ZH:Y0:n8
[02_R:`0[hR/0P2dSjl00`2lU:d0`ib`0<>L/0020<>L/0030<jV/03A[[Go00000080g;Rd0P3Rakd3
0>G7^@Cooooo00?o0000ooooooooool0<oooool000Wooooo00@00000oooooooooooooooo1@0I6AT0
0`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH0
1@000000Ogmo07moO`1oOgl0000000@0VIVI00?o00000;>c/`2c/k<0202c/k<01Ol00000VIVI09VI
V@2IVIWo00000080Ogmo00D0000006IVIP1VIVKo00000000000204a<C005o`00000c<c<0<c<c03<c
<`0000001@0I6AT00ol0000000000000000b000000D06ATI00D0000003<c<`0c<c<0<c<c00000002
04a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIWo0000402c/k<00ol00000VIVI
09VIV@0309VIV@080000001oOgl0Ogmo0000001VIVH0000004a<C000000203<c<`03o`000?oooooo
oooo00;ooooo00<00000ooooooooool0EOooool2o`0001Gooooo00<0RFf^08Q/[@28K:d00`29KJ`3
08i_Z`80UG>[102LN:/30:9m[0030:J3[P2YPZT0ZH:Y00<0[hR/00@0]8n_0;bD[@2lU:d0_9B]0P33
W;020<jV/0060=6^]Ol00000g;Rd0=bh]03T_[40h/Nm0`3UakT01@3VaKGooooooooooooooooo0000
03Gooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00<0000003<c<`0c<c<00P0c<c<00`00
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00Go000007moO`1oOgl0Ogmoo`000005
09VIV@03o`00002c/k<0/k>c00P0/k>c00Go000009VIV@2IVIT0VIVI0000000207moO`040000001V
IVH0IVIV000000<0C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6CD000001@0I6AT01@000000
<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl010000000VIVI09VIVOl0
000@0;>c/`03o`00002IVIT0VIVI00<0VIVI00P0000007moO`1oOgl0000006IVIP000000C4a<0000
0080<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`1Booooo`?o00004_ooool00`2@
LZh0S72^08a`[P0308U][P<0R6b]0P29KJ`308i_Z`<0UG>[0`2LN:/20:9m[0040:AlY`2YPZT0ZH:Y
0:V2Z@<0[hR/102lU:d01`33W;00cZJ`0<jV/03>Y[00g;Rdo`00003L^;@00P3T_[430>G7^@80i/Fe
1?ooool00ol0003oooooooooo`0booooo`002Oooool01000003oooooooooooooool401TI6@030000
000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`080;>c/`03o`00
002IVIT0VIVI0080VIVI00<0000007moO`0000000P1VIVH01@000000C4a<04a<C01<C4`0000000<0
<c<c00<0000001TI6@0I6AT00`0I6ATf000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<
C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVIo`00000?0;>c/`03o`00002I
VIT0VIVI00<0VIVI00P0000007moO`1oOgl0000006IVIP000000C4a<00000080<c<c00?o0000oooo
ooooool00_ooool00`00003oooooooooo`1@ooooo`;o00004_ooool0102CLjd0T7:^091b[P2@LZh2
08a`[P<0RFf^0`28K:d208U][0<0SVn[0`2ELj/309ahZ`030:9m[02TO:L0Y7bW00@0ZH:Y0P2_R:`0
102fSJ/0_9B]0;bD[@2lU:d40<jV/0030=Va[ol00000i;ja0080i;ja00<0ikn]0>G7^@3VaKD00P3V
aKD01@3Xa;7ooooooooooooooooo000003Cooooo0009ooooo`0400000?ooooooooooooooo`@06ATI
00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00L0/k>c00?o000009VIV@2I
VIT00P2IVIT010000000Ogmo07moO`00000206IVIP040000001<C4`0C4a<000000<0<c<c00<00000
01TI6@0I6AT00`0I6ATg000000H06ATI00@0000003<c<`0c<c<000000`1<C4`010000000IVIV06IV
IP00000207moO`040000002IVIT0VIVIo`0000l0/k>c00?o000009VIV@2IVIT00`2IVIT01P000000
Ogmo07moO`000000IVIV00000080C4a<00<0000003<c<ol000001?ooool00`00003oooooooooo`1=
ooooo`?o00004?ooool309IdZ`80Tg>]0`2@LZh308a`[P<0RFf^0P28K:d308U][0<0SVn[0P2ELj/2
09ahZ`0409egY`2TO:L0Y7bW0:AlY`@0ZH:Y00<0[hR/0;J=Z`2fSJ/00`2lU:d00`37WZh0cZJ`0<jV
/0020=Va[`03o`00003T_[40i;ja0080ikn]0`3VaKD20>S4/@Cooooo00?o0000ooooooooool0<Ooo
ool000Wooooo00@00000oooooooooooooooo0`0I6AT00ol00000<c<c03<c<`0203<c<`050000001<
C4`0C4a<04a<C0000000101VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI
00?o00000;>c/`2c/k<01P2c/k<2o`0000<0VIVI0P00000207moO`04o`00001VIVH0IVIV00000080
C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6CP000001P0I6AT010000000<c<c03<c<`000003
04a<C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVIo`00000<0;>c/`;o0000
1P2IVIT01P000000Ogmo07moO`000000IVIV00000080C4a<00<0000003<c<ol000001?ooool00`00
003oooooooooo`1;ooooo`;o00004_ooool0102GM:T0UWB[09IdZ`2FM:/309=c[@<0T7:^0P2<L:h3
08U][P<0R6b]0P29KJ`308i_Z`0309EcZ`2ELJL0WGNW0080WGNW102TO:L30:V2Z@<0]Xf[0P2lU:d2
0<NN[P80cZJ`0P3I/Jl00ol00000i;ja0>Bn/@020>No[@030>RnZ@3VaKD0j<Ba0080j<Ba00<0j/B^
ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool3
01TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`00000101VIVH00`000000Ogmo07mo
O`0207moO`030000002IVIT0VIVI00D0VIVI00?o00000;>c/`2c/k<00`2c/k<2o`0000@0VIVI00D0
000007moO`1oOgl0Ogmo0000000206IVIP05o`00001<C4`0C4a<00000?l000000P0c<c<00ol00000
6ATI01TI6@0401TI6CP000001P0I6AT010000000<c<c03<c<`00000304a<C0040000001VIVH0IVIV
00000080Ogmo00<0000009VIV@2IVIT00P2IVIT2o`0000L0/k>c0ol0000809VIV@060000001oOgl0
Ogmo0000001VIVH000000P1<C4`00`000000<c<co`000004ooooo`0300000?oooooooooo04Sooooo
0ol0000Booooo`0309QcZ02GM:T0UgBY00@0UWB[0P2CLjd3091b[P80S72^0`29KJh308Q/[@80RFf/
0P2>Kj/00`2=K:L0UG6W09EaY`0309egY`@0Y7bW0P2YPZT00`2aQjT0]Xf[0;J=Z`020;J=Z`050;bD
[@37WZh0aij^0<NN[P3>Y[000P3I/Jl01?l00000hKR]0>Bn/@3W_jd20>RnZ@<0j<Ba0P3Za:h01@3/
aJ_ooooooooooooooooo000003;ooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00D00000
03<c<`0c<c<0<c<c0000000204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1o
Ogl00`000000VIVI09VIV@0709VIV@03o`00002c/k<0/k>c00;o00001@2IVIT01@000000Ogmo07mo
O`1oOgl000000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0401TI6CT0
000000?o000001TI6@0I6AT00`0I6AT01@000000<c<c03<c<`0c<c?o000000<0C4a<00@0000006IV
IP1VIVH000000P1oOgl00`000000VIVI09VIV@0309VIV@;o0000102c/k<00ol00000VIVI09VIV@0:
09VIV@0:0000001oOgl0Ogmo0000001VIVH0000004a<C0000000<c<co`0000Cooooo00<00000oooo
ooooool0AOooool3o`0001;ooooo00@0Ug:W09QcZ02HLjP0V7>X0`2GM:T309IdZ`80Tg>]0`2@LZh0
0`2<L:h0RVb[08IYZ`0208IYZ`<0QFRY0P27J:P308e/Y`<0UG6W0`2MMjL30:AlY`040:V2Z@2aQjT0
/HNY0;67Z@<0]Xf[1037WZh20=Va[`030>6h[Ol00000hKR]0080ikn]0P3X_ZT00`3Z_JH0j<Ba0>S4
/@020>[4[P030>c5Zooooooooooo00;ooooo00?o0000ooooooooool0;oooool000Wooooo00@00000
oooooooooooooooo0P0I6AT01@000000<c<c03<c<`0c<c?o00000080C4a<00?o000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00P0VIVI0_l0000609VIV@03o`00
001oOgl0Ogmo008000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00@0
6ATI>`00000501TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`010000000IVIV06IVIP000003
07moO`030000002IVIT0VIVI00@0VIVI1?l0000=09VIV@0:0000001oOgl0Ogmo0000001VIVH00000
04a<C?l00000<c<co`0000Cooooo00<00000ooooooooool0@oooool2o`0001?ooooo00<0Ug6U09Mb
Y`2GLZL00`2HLjP309MdZ@<0UWB[00<0Tg>]09AbZP2?L:/00P2?L:/208Y/Z`<0QVV[0`25J:T208MX
Z0<0SFbW0`2ELJL309egY`80Y7bW00<0Zh6X0;67Z@2aQjT00P2aQjT20;J=Z`030<6H[@37WZh0aij^
0080aij^00P0djZ_0=Va[`3Q^:go00000>6h[@3T^Z/0ikn]0>RnZ@<0j[fV00D0j<Ba0>[4[P3/aJ/0
k<F[0>k5Z004ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?ooooooooooooooo`80
6ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH0IVIV0080IVIV00<0000007mo
O`1oOgl00`1oOgl00`000000VIVI09VIV@0>09VIV@8000000P1oOgl01@000000IVIV06IVIP1VIVKo
00000080C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0301TI6@03o`0000000000
000003T000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH00000
101oOgl00`000000VIVI09VIV@0D09VIV@0:0000001oOgl0Ogmo0000001VIVH0000004a<C0000000
<c<co`0000Cooooo00<00000ooooooooool0@?ooool3o`0001;ooooo00@0UVnT09MaY@2GLJD0Ug6U
0P2GLZL409QcZ080UgBY0P2FM:/0102GLjP0U7:Z09AbZP2DLZX208m`Z`<0RVb[0P26JJ/308EXZ@<0
QfRX0`2=K:L209EaY`<0WGNW00<0Y7bW0:^1Z02[PJP0102aQjT0102fSJ/0`IR]0<6H[@31V:d20<NN
[P80djZ_00<0fK6_0>6h[Ol000000P3T^Z/20>RnZ@<0j[fV0P3Za:h0103/aJ/0k/FX0>k5Z03`aJH3
ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?ooooooooooooooo`806ATI00D00000
03<c<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000001@1oOgl00`000000VIVI
09VIV@0=09VIV@8000000`1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c
<c<0<c<c0000000501TI6Cd000001P0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@00000
06IVIP1VIVH00000101oOgl00`000000VIVI09VIV@0C09VIV@0:0000001oOgl0Ogmo0000001VIVH0
000004a<C0000000<c<co`0000Cooooo00<00000ooooooooool0?_ooool2o`0001?ooooo00<0UFjS
09I_Y02FKj@00`2GLJD309MbY`<0V7>X0P2GM:T309McZ0<0U7:Z0P2?L:/308Y/Z`<0QVV[0`25J:T2
08MXZ0<0SFbW0`2ELJL209egY`@0Zh6X0`2aQjT40<6H[@040<NN[P3CZZl0djZ_0=>Z[`80hKR]00?o
00000>BjZ`3T^Z/00P3X_ZT30>ZmYP030>bnX`3Za:h0k<F[0080k/FX0P3`aJH3ooooo`03o`000?oo
oooooooo02gooooo0009ooooo`0600000?ooooooooooooooo`0I6AT000000`0c<c<010000000C4a<
04a<C000000406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT02`2IVIT2000000@0
Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATo
000000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0050000001VIVH0IVIV06IVIP000000
101oOgl2000001<0VIVI00[o000007moO`1oOgl0000006IVIP000000C4a<0000000c<c?o00001?oo
ool00`00003oooooooooo`0kooooo`?o00004_ooool0102DKJ<0UFjS09E^X`2EKZ<209I_Y0@0Ug6U
0P2GLZL309QcZ00309MdZ@2ILjL0Ug>X0080Ug>X0`2DLZX308m`Z`80RVb[0`26JJ/308EXZ@80QfRX
0`2=K:L309EaY`0309egY`2RNjP0XW^X00<0Zh6X0P2aQjT00`2kTZ`0`IR]0<6H[@020<6H[@@0djZ_
00<0fk>_0>6h[Ol000000P3T^Z/0103V^ZP0j[fV0>ZmYP3Z_JH20>bnX`80k<F[00@0k/FX0?35YP3`
aJH0l<FV1?ooool00ol0003oooooooooo`0/ooooo`002Oooool01P00003oooooooooooooool06ATI
000000<0<c<c00@0000004a<C01<C4`000000`1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI00P0VIVI1000000307moO`80000000Go000006IVIP00003o00000000000304a<C0030000
000c<c<0<c<c008000001@0I6AU0000000D06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<
04a<C01<C4`0000000<0IVIV00<0000007moO`1oOgl00`1oOgl:000000T0VIVI00X0000007moO`1o
Ogl0000006IVIP000000C4a<0000000c<c?o00001?ooool00`00003oooooooooo`0iooooo`;o0000
5?ooool209A]X`<0UFjS0`2FKj@309MaY@80Ug:W0P2HLjP0102ILZD0VG>W09UcY`2ILjL309McZ0<0
U7:Z0P2?L:/308Y/Z`80QVV[0`25J:T308MXZ080SFbW0P2ELJL0102HM:T0XW^X0:9kZ02RNjP30:^1
Z0040;67Z@2kTZ`0^i:/0;^B[0<0`IR]0`3CZZl20=^c[`030>6h[Ol00000i;Z[0080i[ZX0`3Z_JH2
0>bnX`030>joX@3^aJP0k/FX00<0l<FV00D0l<FTooooooooooooooooo`00000^ooooo`002Oooool0
1P00003oooooooooooooool06ATI000000<0<c<c00@0000004a<C01<C4`000000`1VIVH00`000000
Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI0`00000407moO`<000000`1VIVH00`000000
C4a<04a<C00204a<C00500000?l00000<c<c03<c<`0000001P0I6AT00ol0000000000000000n0000
00D06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00?o0000
0000001oOgl0301oOgl2000000L0VIVI00X0000007moO`1oOgl0000006IVIP000000C4a<0000000c
<c?o00001?ooool00`00003oooooooooo`0fooooo`?o00005Oooool0102CK:80U6fS09A]X`2DKJ<3
09E^X`80UVnT0`2GLJD00`2GLZL0VG6T09UbY@0209UbY@<0VG>W0`2GLjP309AbZP80Sg2[0`2:K:/2
08IYZ`<0QFRY0`27J:P00`2=K:L0SFj[09QdZ@0209QdZ@<0XW^X0`2[PJP40;^B[080`IR]0P3=YK00
1`3CZZl0fk>_0=^c[`3K/jl0i;Z[o`00003T^Z/00P3V^ZP00`3X^ZH0j[fV0>bnX`020>bnX`030>jo
X@3^aJP0k/FX0080l<FV0P3`aJ@01@3a`j7ooooooooooooooooo000002gooooo0009ooooo`060000
0?ooooooooooooooo`0I6AT000000P0c<c<010000000C4a<04a<C000000306IVIP030000001oOgl0
Ogmo00H0Ogmo1P00000607moO`030000001VIVH0IVIV0080IVIV0P00000304a<C08000000`0c<c<0
0`0000006ATI01TI6@0401TI6D<000001@0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0
C4a<04a<C?l000001@1VIVH00`000000Ogmo07moO`0<07moO`030000002IVIT0VIVI00@0VIVI00X0
000007moO`1oOgl0000006IVIP000000C4a<0000000c<c?o00001?ooool00`00003oooooooooo`0c
ooooo`?o00005_ooool00`2CJj40TfbR09=/XP0309A]X`<0UFjS0P2FKj@209MaY@0309Q`X`2ILJ@0
VG6T00<0VG:U0`2ILjL309McZ080U7:Z00<0VWjc099i]02BNK@00`2:Lk<208=]/P<0PFZ_0`25JZd2
08e^Z`<0V7BY102RNjP20:^1Z0050;B=[02kTZ`0^i:/0;^B[031V:d00`3=YK001P3CZZl0fk>_0=^c
[`3K/jl0gkN^o`000080i[ZX0P3X^ZH00`3Z_JH0k;jS0>bnX`020>joX@040?30W`3`aJH0l<FV0?35
YP80l<FT00D0lL>Qooooooooooooooooo`00000]ooooo`002Oooool01P00003oooooooooooooool0
6ATI00000080<c<c00@0000004a<C01<C4`000000P1VIVH00`000000Ogmo07moO`0?07moO`@00000
0`1VIVH2000000<0C4a<0P00000403<c<`030000000I6AT06ATI00@06ATIA000000601TI6@030000
000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0C4a<0P00000406IVIP<00000301oOgl00ol00000
VIVI09VIV@0309VIV@0:0000001oOgl0Ogmo0000001VIVH0000004a<C0000000<c<co`0000Cooooo
00<00000ooooooooool0<Oooool2o`0001Kooooo00@0TVZQ09=[X@2CJj40Tf^Q0P2CK:8309A]X`<0
UFjS0P2FKj@00`2GLJD0V72S09Q`X`0309UaY0<0VG:U0`2ILjL209McZ0<0VWjc0`2BNK@208Yc/`<0
Pffb0P21JZl308EZ[@<0SFj[0`2HM:T30:9kZ0030:^1Z02dSJ`0]8f/00<0^i:/103=YK030=^c[`80
gkN^00<0i;Z[o`00003V^ZP00P3X^ZH30>bnX`80k[nQ00<0l<2O0?35YP3`aJH00P3`aJ@20?73X@05
0?71Woooooooooooooooool00000;?ooool000Wooooo00H00000oooooooooooooooo01TI6@000002
03<c<`040000001<C4`0C4a<00000080IVIV00<0000007moO`1oOgl03@1oOgl2000000D0IVIV0P00
000404a<C0030000000c<c<0<c<c0080<c<c00<00000o`00000I6AT01@0I6AT00ol0000000000000
0012000000H06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00304a<C0030000001V
IVH0IVIV00@0IVIV1000000807moO`030000002IVIT0VIVI00<0VIVI00X0000007moO`1oOgl00000
06IVIP000000C4a<0000000c<c?o00001?ooool00`00003oooooooooo`0^ooooo`?o00005_ooool0
0`2BJJ40TVZQ099ZX@0309=[X@<0TfbR0P2DKJ<309E^X`0309I_Y02HKZ80V72S0080V72S0`2ILJ@3
09UbY@<0VG>W00<0Ug>X09n0/P2OP;800`2JO[<2099i]0<0RW>c0P23KK82085Z[`<0QFZ]0`2=KZ/3
09QdZ@80XW^X00@0ZhJ^0;B=[02dSJ`0]8f/0`2kTZ`01@38XK40cJF`0<fU/03=YK00e[2b0080fk>_
0P3O]jh00`3Q^Jko00000>JjZ0020>RjYP040>ZmY@3/_Z<0k;jS0>joX@80l<2O00@0lL6M0?35YP3`
aJ@0l<FT0P3a`j400`3a`Iooooooooooo`02ooooo`03o`000?oooooooooo02Wooooo0009ooooo`06
00000?ooooooooooooooo`0I6AT000000P0c<c<010000000C4a<04a<C000000206IVIP030000001o
Ogl0Ogmo00`0Ogmo00<0000006IVIP1VIVH00P1VIVH3000000@0C4a<0P00000303<c<`8000001`0I
6AU7000000H06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00304a<C0030000001V
IVH0IVIV00L0IVIV1@00000407moO`030000002IVIT0VIVI0080VIVI00X0000007moO`1oOgl00000
06IVIP000000C4a<0000000c<c?o00001?ooool00`00003oooooooooo`0/ooooo`;o00005?ooool0
0`2@J:40TFVQ095YX@03099YX@80TVZQ102CJj4209=/XP<0U6fS0P2EKZ<209Q^XP<0V72S0`2ILJ@3
09UbY@80VG>W00@0XX6`09n0/P2OP;80Wh2b0`2JO[<2099i]0<0RW>c0P23KK83085Z[`<0QFZ]0P2=
KZ/309QdZ@030:9kZ02[QZh0ZhJ^00@0]8f/00<0^i:/0<RQ/@38XK400P3=YK030=J`/P050=^c[`3O
]jh0gkN^0>6i[_l000000P3X^ZH30>ZmY@80k[nQ0P3``9l01@3a`Id0l/2L0?35Y03`aJ@0lL>Q0080
lL6O00D0l;nLooooooooooooooooo`00000[ooooo`002Oooool01P00003oooooooooooooool06ATI
00000080<c<c00@0000004a<C01<C4`000000P1VIVH00`000000Ogmo07moO`0;07moO`03o`00001V
IVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`2000000@0<c<c00<0000001TI6@0I6AT01P0I
6AU700000003o`00000I6AT06ATI00@06ATI00?o000003<c<`0c<c<00P0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV00/0IVIV00D0000007moO`1oOgl0Ogmo0000000509VIV@030000
001oOgl000000080IVIV0P00000203<c<`05o`000?ooooooooooooooo`000000:oooool3o`0001Co
oooo0`2@J:42095YX@<0TVVQ0`2BJZ4309=[X@80TfbR0`2DKJ<00`2EKZ<0UVfQ09Q^XP0209Q^XP<0
V72S0`2ILJ@209UbY@<0XX6`0`2OP;8309Yn/`<0TWVd0P2:Lk<308=]/P80PFZ_0`25JZd308e^Z`80
V7BY0`2[QZh40;B=[0050;^B[038XK40b:6a0<RQ/@3=YK000`3F/;820=ng[P80hKV^00?o00000>Rj
YP3X^ZH00`3Z_JD20>joX@030?30W`3a`Id0lL6M0080l/2L0P3a`j420?71W`030?2oW?oooooooooo
00;ooooo00?o0000ooooooooool0:?ooool000Wooooo00H00000oooooooooooooooo01TI6@000002
03<c<`040000001<C4`0C4a<00000080IVIV00<0000007moO`1oOgl02@1oOgl2000000<0IVIV00?o
00000000001<C4`00`1<C4`2000000D0<c<c00<00000o`00000I6AT0100I6AT00`00003o00000000
0019000000H06ATI00<0000003<c<`0c<c<00P0c<c<00ol0000000000000000404a<C004o`000000
00000000000000X0IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@050000001oOgl0Ogmo0000
001VIVH00P00000203<c<`05o`000?ooooooooooooooo`000000:Oooool2o`0001Cooooo00<0SfRQ
091XX@2@J:400`2@J:43095YX@<0TVVQ0P2BJZ4309=[X@80TfbR0P2DKJ<00`2EJj00UVfQ09I]X@03
09Q^XP<0V72S0`2ILJ@00`2ILZD0Xh6^0:>1[P030::1/0<0Wh2b00<0VWjc0:N]f`2EWm/00P2EWm/2
08:=eP<0MGg=0P1dM<D308EZ[@<0SFj[00<0V7BY09eo/P2MOk800`2[QZh30;B=[0@0b:6a103F/;80
1`3K]k@0gkN^0>6i[P3Q^Jko00000>>l[`3X^ZH00`3Z_JD00`3]`:@0l<2O0?30W`020?71W@80l/2L
0P3a`j40103a`Il0l;nL0?2oW03`_IX4ooooo`03o`000?oooooooooo02Oooooo0009ooooo`060000
0?ooooooooooooooo`0I6AT000000P0c<c<010000000C4a<04a<C000000206IVIP030000001oOgl0
Ogmo00P0Ogmo00<0000006IVIP1VIVH00P1VIVH010000000C4a<04a<C01<C4`3000000@0<c<c0`00
000601TI6Dd000001P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00D0C4a<1000
000606IVIP050000001oOgl0Ogmo07moO`000000102IVIT01@000000Ogmo07moO`000000IVIV0080
00000P0c<c<01Ol0003oooooooooooooool0000002Kooooo0ol0000Dooooo`<0SfRQ1@2@J:43095Y
X@<0TVVQ0P2BJZ4309=[X@0309=/XP2DJYl0UF^P0080UF^P0P2FKJ4309Q^XP<0V72S0P2ILJ@0102S
Ojd0Xh6^0:>1[P2SPJh30::1/080Wh2b00@0];GI0:N]f`2W[M/0YjgK0`2EWm/208:=eP80MGg=0P1d
M<D307ec_@<0S7Rg0`2MOk830:^6[P80]8f/00<0`Ifc0<RQ/@38XK400P38XK400`3B[kH0e[2b0=J`
/P020=^g]0050=ng[P3Q^Jh0hKV^o`00003S_:l00`3Z_JD20>g0Y080l<2O00D0lL6M0?;0W03b`9`0
l/2L0?6nVP020?71W`80l;nL00<0l;fJooooooooool00_ooool00ol0003oooooooooo`0Wooooo`00
2Oooool01@00003oooooooooooooool0000000<0<c<c00@0000004a<C01<C4`000000P1VIVH00`00
0000Ogmo07moO`0707moO`03o`00001VIVH0IVIV0080IVIV00D0000004a<C01<C4`0C4a<00000005
03<c<`8000001`0I6AU@000000H06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C008
04a<C0<00000101VIVH010000000Ogmo07moO`00000509VIV@090000001oOgl0000006IVIP000000
C4a<0000000c<c?o000000?ooooo00<00000ooooooooool08_ooool2o`0001?ooooo00<0SVRS08iX
XP2>J:801@2?J:45091XX@80TFVQ0`2BJJ42099ZX@80Tf^Q00<0TfVN09AZW`2DJYl00`2EJj0309I]
X@<0V6jR0P2HL:<00`2ILJ@0Xgn]0:=o[@030:>1[P<0XX6`00@0Wh2b0;Bef@2d]MT0];GI0P2W[M/3
09FOf`<0PXgF0P1eOLd207Ada@80OG>m0`2<N;L309eo/P<0ZhJ^00@0]8f/0<6M/`31WK<0`Ifc0P38
XK420=:_]P040=J`/P3K]k@0fkNd0=^g]080hKV^00<0hkb_o`00003S_:l00`3Z_JD20>g0Y0030>o3
Y@3a`Id0lL6M00<0l/2L00@0lKjJ0?71W`3a`Il0l;nL0P3`_IX00`3`^iOoooooooooo`02ooooo`03
o`000?oooooooooo02Kooooo0009ooooo`0500000?ooooooooooooooo`0000000`0c<c<00`000000
C4a<o`00000306IVIP030000001oOgl0Ogmo00L0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<
C0030000000c<c<0<c<c0080<c<c0P00000701TI6E8000001`0I6AT00ol00000000003<c<`0503<c
<`8000002`1<C4`01@000000IVIV06IVIP1VIVKo00000080Ogmo00<0000009VIV@2IVIT00`2IVIT0
2@000000Ogmo0000001VIVH0000004a<C0000000<c<co`000003ooooo`0300000?oooooooooo01oo
oooo0ol0000Booooo`0408eYY02>J:<0SVRS08iXX`80SVRR1@2?J:45091XX@<0TFVQ0P2BJJ400`2B
JZ40TVRN09=YWP0209=YWP80U6ZO102EJj0209I]X@<0V6jR00<0V72S0:9mZ`2SOjd00`2SOjd30:>1
[P030::1/02m^]L0];GI00<0];GI00<0YjgK0:FmjP2Q_>`00P2Q_>`01@2G^Nl0VKW^08VdlP29]?80
07OJ0080M7C50`1mLkd308ah]`<0WGnb0P2[QZh40<6M/`040<RQ/@3B[kH0dZnf0=:_]P@0fkNd00L0
gK^f0>6i[P3S_:oo00000>>l[`3V`[40j[fU0080kL2T0P3_`jD20?71W@80l/2L0P3a_YX00`3`_9T0
l;nL0?2oW0020?2mVP030?2kUooooooooooo00?ooooo00?o0000ooooooooool09Oooool000Wooooo
00D00000oooooooooooooooo0000000303<c<`030000001<C4`0000000<0IVIV00<0000007moO`1o
Ogl01`1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00?o000003<c<`0c<c<00P0c<c<00`00
00006ATI01TI6@0501TI6ED000001`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<
00P0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`03o`00002IVIT0VIVI00<0VIVI00T00000
07moO`000000IVIV0000001<C4`0000003<c<ol000000oooool00`00003oooooooooo`0Looooo`?o
00004Oooool00`2=JjL0SFZU08eZY@0208eYY0<0SVRS0P2>J:8508mXX@D0T6RQ0`2AJJ40102BJJ40
TFNN099XWP2BJ9h309=YWP80U6ZO102EJj0209I]X@80V6jR00@0XGbZ0:9mZ`2ROJ/0XWf[0`2SOjd2
0:>1[P040<6ke02m^]L0_K[G0;fje`80];GI00@0Z;gY0:FmjP2V_>T0Y[cY0`2R^n/209VikP80RKCb
00<0SkOa021eh`0PMN<00P1mLkd308ah]`<0WGnb00<0ZhJ^0;FH^@2eV;T00`31WK<40=:_]P030=Rh
^@3K]k@0fkNd0080gK^f0P3S_:l01?l00000i/:a0>K2/@3Z_JD20>g0Y080kl>U00@0l<FV0?;0W03b
`9`0l/2L0P3a_YX0103`_9T0l;nL0?2oW03`_IX20?2kU`030?6iU?oooooooooo00;ooooo00?o0000
ooooooooool09Oooool000Wooooo00D00000oooooooooooooooo0000000303<c<`030000001<C4`0
000000<0IVIV00<0000007moO`1oOgl01`1oOgl010000000IVIV06IVIP00000304a<C0050000000c
<c<0<c<c03<c<`0000001`0I6AUG000000L06ATI00<0000003<c<`0c<c<01P0c<c<3000000P0C4a<
00@0000006IVIP1VIVH000000P1oOgl00`000000VIVI09VIV@0309VIV@090000001oOgl0000006IV
IP000000C4a<0000000c<c?o000000?ooooo00<00000ooooooooool06_ooool2o`00013ooooo00<0
SW2/08i]Z@2>KJT00P2=JjL208eZY@80SFVT0`2>J:<308iXXP@0SfRQ1@2@J:42095YX@03091VW@2A
Iih0TFNN0080TVRN0`2CJIh309AZW`<0UF^P0P2FKJ400`2HKZ80XGbZ0:5lZP030:9mZ`<0Xgn]00@0
Xh6^0<6ke031^m@0`K_D0P2m^]L00`2Y_^T0Z;gY0:Rmj0040:Jlj@030::kj`2S^nX0W;[]00<0W;[]
0P2?]o400`0PMN<0E7gN05AmgP0308ah]`80WGnb00@0XI740;FH^@2eV;T0]IRi0`31WK<00`3<[K/0
dZnf0=:_]P030=Rh^@060=^g]03M^kH0gK^f0>32^P3S_:oo00000P3V`[40103YbkH0kL2T0>g0Y03_
`jD20?35YP<0l/2L00H0lKjJ0?2lV@3`_9T0kkZH0?2oW03`_IX20?2kU`030?6iU?oooooooooo00?o
oooo00?o0000ooooooooool09?ooool000Wooooo00D00000oooooooooooooooo0000000303<c<`03
0000001<C4`000000080IVIV00<0000007moO`1oOgl0201oOgl010000000IVIV06IVIP00000204a<
C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0100I6AUH000000P06ATI00<0000003<c
<`0c<c<0200c<c<400000003o`00001<C4`0C4a<0080C4a<00H0000006IVIP1VIVH0000007moO`00
000509VIV@030000001oOgl0Ogmo0080000000@0C4a<0000000c<c?o00000oooool00`00003ooooo
ooooo`0Gooooo`?o00003Oooool00`2AM[40Sg:^08mb[P0308i`[080SVfY0P2=JjL208eZY@<0SFVT
0`2>J:<208iXXPD0SfRQ0`2@J:40102?IId0T6JM091VW@2@IYd2095WWP80TVRN102CJIh209AZW`<0
UF^P00<0UVfQ09mjZ@2QO:X00P2QO:X30:9mZ`<0Xgn]1031^m@0102m^]L0ZKkY0:Vmj02Y_NP20:Rm
j080Y[cY0P2V_>P20:>kjP80W;[]00H0Wk[/09Bil02D^O00U;W`021eh`1DOMh30868d@<0XI74102e
V;T01@31WK<0c:fk0<b]^`3<[K/0dZnf00<0f;Ri0P3M^kH20>32^P;o00000P3V`[420>W;]P80kl>U
0P3`aJH0103_aJL0l/2L0?;0W03a_YX20?2lV@040>njV03`_IX0l;fJ0?2kU`80lKVD00<0lKRBoooo
ooooool00oooool00ol0003oooooooooo`0Sooooo`002Oooool01@00003oooooooooooooool00000
00<0<c<c00<0000004a<C00000000P1VIVH00`000000Ogmo07moO`0807moO`030000001VIVH00000
00<0C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6@0300000?l00000000005P00000200I6AT2
000000d0<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV0000001oOgl0000000D0VIVI00<0
000007moO`1oOgl00P000000101<C4`0000003<c<ol00003ooooo`0300000?oooooooooo01Kooooo
0_l0000;ooooo`0309Im]@2CNK<0TgVc0080TGJa0P2?LZh308i`[080SVfY0`2=JjL208eZY@80SFVT
0`2>J:<208iXXPD0SfRQ00@0T6RQ08iTW@2?IId0SfFM0`2@IYd2095WWP<0TVRN0`2CJIh209AZW`80
UF^P00@0WGRX09mjZ@2ONZT0WgZY0`2QO:X30:9mZ`030:=o[@32^m<0`[_C0080`K_D00D0ZKkX0:Vm
i`2Y_NL0ZKgX0:VkiP040:Rli`030:Jlj02W^^L0YK_Y00<0YK_Y0P2O^^`00`2D^O00V[[^09ZjkP02
05AmgP80PHSA102QTL@20;FH^@030;fZaP3<[K/0c:fk0080c:fk0`3H^;T20=^n_0?o000000<0h<:j
o`00003V`[400`3YbkH20>o3Y@040?35YP3_aJL0klFW0>o5Y`80lKjJ00<0l;bI0>njV03_^YP00P3`
_IX01@3`^iL0lKVD0?6iU03a^980l[R?00Cooooo00?o0000ooooooooool08oooool000Wooooo00D0
0000oooooooooooooooo0000000303<c<`030000001<C4`000000080IVIV00<0000007moO`1oOgl0
201oOgl00`000000IVIV0000000304a<C0050000000c<c<0<c<c03<c<`000000100I6AUL000000X0
6ATI0P00000;03<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP000000Ogmo0000000509VI
V@030000001oOgl0Ogmo0080000000@0C4a<0000000c<c?o00000oooool00`00003oooooooooo`0F
ooooo`03o`000?oooooo000000Sooooo00<0V82h09Im]@2FOKD00P2CNK<3095f/@80Sg:^0`2>L:`2
08i]Z@80SF^W0P2=JZD208eYY0<0SVRS0P2>J:8408mXX@0308eTW@2>I9d0SVBM0080SfFM0`2@IYd3
095WWP80TVRN0`2CJIh209AZW`0309E[X02MN:P0WGRX00<0WgZY0`2QO:X20:9mZ`040<:jd`32^m<0
`[_C0<:kd`@0ZKgW102Y^nH20:Rli`040:Vii@2W^^L0Yk[W0:Nji`80YK_Y00D0Y[WV0::jjP2R^^X0
X[[Z09ZjkP0209njj`8004o30P21R=430:6Aa0040;FH^@2mZ/H0_J[60;fZaP80c:fk0P3B^<40103H
^;Wo0000o`000?l000040>32^P030>C?`_l00000jL^f0080jL^f00<0jmBn0?35YP3`aJH00`3_aJL2
0?6nVP040?2lV@3_^YP0kkZH0>jgUP80l;^G0P3a^I@00`3a^980l[R?0?:hS`04ooooo`03o`000?oo
oooooooo02;ooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<010000000C4a<04a<
C000000206IVIP030000001oOgl0Ogmo00L0Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000
<c<c03<c<`0c<c<0000000@06ATIGP00000;01TI6@<000002@0c<c<02@000000C4a<04a<C01<C4`0
000006IVIP000000Ogmo0000000609VIV@040000001oOgl0000006IVIP80000000<0<c<co`000?oo
ool00_ooool00`00003oooooooooo`0Fooooo`04o`000?ooooooooooo`0000?ooooo00<0V8Fm09V3
^P2IPkX00P2HP;P309Im]@80TgVc0P2AM[4208mb[P<0SW2/0P2>KJT208e[Y`80SFZU0P2=JJ@308iX
X`0408iXXP2;HYd0S6>M08aSW@<0SFBM0P2>I9d208mUW@@0T6JM0P2AIih2099XWP<0TfVN00<0U6ZO
09]fZ02MN:P00P2MN:P309mjZ@<0XGbZ00D0XWf[0<:jd`32^]<0`[[C0<:kd`030:Vmi`D0ZK_V0P2Y
^><30:Vii@030:Nji`2Y]n<0Y[WV00<0Y[WV00<0X[[Z0:FhiP2O^^/00`2O^^/00`2E^_40DHg[056=
j`020:6Aa00309bSfP2mZ/H0_J[60080_J[600<0c:fk0=:h`Ol000000_l000030=^n_0030=o9``3P
`[X0h<:j0080i<o200<0jL^fo`00003YbkH00P3[e;h20?35YP<0klFW00<0kLBZ0?2lV@3`_9T00P3_
^YP00`3^]iH0l;^G0?2kU`020?6iU0030?6hTP3b^8l0l[R?00Cooooo00?o0000ooooooooool08_oo
ool000Wooooo00D00000oooooooooooooooo0000000203<c<`040000001<C4`0C4a<00000080IVIV
00<0000007moO`1oOgl01`1oOgl010000000IVIV06IVIP00000204a<C0040000000c<c<0<c<c0000
00D06ATI00?o0000000000000000G@00000<01TI6@<000001`0c<c<02?l00000000004a<C0000000
IVIV0000001oOgoo00001P2IVIT01?l00000Ogmo0000001VIVH20000000303<c<ol0003ooooo00;o
oooo00<00000ooooooooool05_ooool00ol0003ooooo09>9aP0209F6`@<0V8Fm0P2IPkX309R0^080
UWfe0P2CNK<2095f/@80Sg:^0`2>L:`208i]Z@80SF^W00@0SFZU08MQX028HIh0R66N0`29HIh208]R
W@80S6>M0`2=I9d208iTW@<0SfFM0`2@IYd2095WWP80TVRN0P2CJIh0102JM:L0VgJX09]fZ02KMZP3
09ehZ0<0WgZY0P2QO:X30<:jd`030:Zmj02Y_NL0ZK_V00D0ZK_V00<0ZKOR0:Vhh`2Y^><00P2Y^><0
0`2Y^ND0Z[?O0:Zcg`020:Vgh`80Y[WV0P2Y]>420:FhiP80Wk[[0P2T^>L00`2L^^d0DHg[056=j`03
09bSfP80_J[60ol000020=:h`@030=G1aP3K_[`0fkjl0080glW300<0h<:j0>C?`P3Tcl800P3Uh/l0
1@3YbkKo00000>_D_P3[e;h0imk;00<0klFW0P3]a:X20?2lV@060>njV03^]iH0k[NF0>jfU03`^iL0
lKVD0P3a^9820?:hS`030?>hSOoooooooooo00;ooooo00?o0000ooooooooool08Oooool000Wooooo
00D00000oooooooooooooooo0000000203<c<`040000001<C4`0C4a<00000080IVIV00<0000007mo
O`1oOgl01`1oOgl010000000IVIV06IVIP00000204a<C0040000000c<c<0<c<c000000D06ATIH@00
000>01TI6@<000001@0c<c<01`000000C4a<0000001VIVH0000007moO`0000000`2IVIT01ol00000
VIVI09VIV@000000Ogmo0000001VIVH00P0000000`0c<c?o0000ooooo`02ooooo`0300000?oooooo
oooo01Gooooo00?o000009:=b`2CRLH00P2CRLH209F6`@<0V8Fm0P2IPkX209R0^080UWfe0P2CNK<0
102AM[40RFb/08MXZ@27J:T308IVYP80QVBS0P26HZ4208MQX080R66N0`29HIh208]RW@80S6>M0`2=
I9d308iTW@80SfFM0`2@IYd2095WWP80TVRN0`2JM:L309]fZ0<0WGRX0`2ONZT01@2QO:X0`;WC0<2i
d`32^]<0Z[gX00H0ZK_V0P2Y]^820:VghP80ZKSS0P2Z/=`00`2Z/ml0ZjWE0:^_f`030:^_f`030:Vd
h@2][]P0ZKCQ00<0ZKCQ00@0Y;SW0:VfhP2S^^T0Xk[Y0P03Jm`0102LXm[o0000o`000?l000020;nf
d@80d[S10P3E`LH01P3K_[`0glW30=o9``3ObL<0iMg=0>C?`P<0iN;?00<0jmBno`00003[e;h00P3W
g//20>o5Y`<0kLBZ00<0jL6/0?2lV@3_^YP00P3^]iH00`3^]Y@0lKVD0?6iU0020?6hTP80l[R?00<0
lkR=ooooooooool00oooool00ol0003oooooooooo`0Pooooo`002Oooool01@00003ooooooooooooo
ool000000080<c<c00@0000004a<C01<C4`000000P1VIVH00`000000Ogmo07moO`0707moO`040000
001VIVH0IVIV00000080C4a<00@0000003<c<`0c<c<00000100I6AUS000001006ATI00<0000003<c
<`0c<c<00P0c<c<01`000000C4a<0000001VIVH0000007moO`0000000`2IVIT01ol00000VIVI09VI
V@000000Ogmo0000001VIVH00P0000000`0c<c?o0000ooooo`02ooooo`0300000?oooooooooo01Go
oooo00?o000009:=b`2BSL/00P2CRLH209F6`@<0V8Fm0P2IPkX0102HP;P0TGRc08md/@2?M;4208a`
[P80RFb/0P27J:T308IVYP80QVBS0P26HZ4208MQX080R66N0`29HIh208]RW@80S6>M0`2=I9d308iT
W@80SfFM0`2@IYd2095WWP03099XWP2HLZH0VWBW0080VWBW0`2KMZP309ehZ080WgZY00@0_[OC0<2i
d`30^M<0`;WC0P2Z_>L00`2Y^nH0Z;OS0:Rgh`040:VfhP030:R/fP2Y[MX0ZJgJ0080ZJgJ00<0Z[3L
0:ZTd02[ZMD00P2[ZMD20:^_f`040:jUc`2][]P0[JkH0:f^f080ZKCQ00D0[ZoH0:VfhP2Y]^80ZKKR
0:>jj@03o`000080RZWZ0`2o]]401@3B^<40eL760=G1aP3E`LH0f/o>00<0glW300@0iMg=0>7hf03Q
n=P0iN;?0P3Gn>401P3[e;ko00000>ONb`3Wg//0fn?L0>o5Y`80kLBZ0P3Y`J`20>njV0050>jgUP3^
]Y@0k[JD0>jdT`3a^I@00P3a^9820?:hS`030?>hS@3d^8[ooooo00?ooooo00?o0000ooooooooool0
8?ooool000Wooooo00D00000oooooooooooooooo0000000203<c<`060000001<C4`0C4a<0000001V
IVH000002`1oOgl01@000000IVIV0000001<C4`000000080<c<c00<0000001TI6@0I6AT00`0I6ATa
000000/06ATI9`0000000ol000006ATI01TI6@0>01TI6@03o`00000c<c<0<c<c0080<c<c00H00000
04a<C0000000000007moO`00000209VIV@03o`00002c/k?o00000080VIVI00L0000007moO`00003o
00000000000c<c?o000000?ooooo00<00000ooooooooool05Oooool01?l0003ooooo09:=b`2BSL/2
09>9aP80UHK100@0V8Fm091l^@2BN[H0TWZf0P2AN;<208md/@80S72^0P29K:`208MXZ@<0QVJV0P26
I:<208IRX@80Qf6P0P28HIh308UQWP<0Rf:M0P2<Hid208eTW@<0SVBM0P2?IId3091VW@03095WWP2F
LJH0V7:V0080V7:V0`2JM:L309]fZ080WGRX00P0WgZY0;jgd`2n]m<0_[OC0<2id`2[_NL0Z[cW0:Rh
i0@0Z;OS00<0ZKKR0:N/fP2X[=X00P2X[=X20:V]fP040:ROc@2ZY=00ZZC@0:ZTd080ZjWE102^YLl0
0`2][]P0/JG=0:j_f0030:j_f0?o000000<0Z;WU0:jhh@00A;h00`2:ZNX00`2o]]40_KkJ0;fnfP03
0=G1aP80f/o>00@0glW30>GMc@3UgLd0hOSH0P2ZmlL01@3Gn>40U?7T09Cai02DlNCo00000080fn?L
0P3]a:X30>W1[080kkZH00<0k[NF0>jfU03^]Y@00P3^]9<00`3a^980l[R?0?:hS`020?>hS@030?Bh
R_oooooooooo00?ooooo00?o0000ooooooooool07oooool000Wooooo00D00000oooooooooooooooo
0000000203<c<`060000001<C4`0C4a<0000001VIVH000002`1oOgl01@000000IVIV0000001<C4`0
00000080<c<c00<0000001TI6@0I6AT00P0I6AT/00000003o`0000000000000001406ATI00?o0000
0000000000008`00000@01TI6@060000000c<c<0<c<c03<c<`000000C4a<0P0000001@1oOgl00000
09VIV@2IVIWo00000080/k>c00Co000009VIV@000000Ogmo0`0000000`0c<c?o0000ooooo`02oooo
o`0300000?oooooooooo01Gooooo00Co0000ooooo`28PlL0R8?70P29Ol8208em_@80T7bi0P2BN[H3
095h/`80SgBa0P2<L:h208U/[080QfRY0`26IZH208ITX`80QV:Q0P27HJ0208QQWP<0RF6N0P2;HYd2
08aSW@80SFBM0`2>I9d208mUW@80T6JM00<0UFnU09IaYP2FLJH00`2HLZH309YdY`<0VgJX00<0WGRX
0;^ed`2n]m<00P2n]m<0102/`>P0ZkgW0:VjiP2Y^^H20:Rhi080Z;OS00H0YZkM0:N/fP2W[=X0YjcJ
0:R/fP2VW<`40:ROc@80ZZC@00<0ZjWE0:fLa`2]W<L00`2^YLl30;6Uc@?o00000`2_/m/30:jhh@<0
L:Ca102m_]X00`3E`LH0f/o>0=[?cP020=oXfP060>GMc@3Qn=P0Z_O70:[ga`2U`Nd0YKg[0`2S^n/0
1@2H]>_o00000;oNk`2og^l0kLBZ00<0jL6/00<0i;b^0>jgUP3^]iH00P3^]Y@20>jdT`030?6hTP3b
^8l0l[R?0080lkR=00<0m;R:ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`002Oooool0
1@00003oooooooooooooool000000080<c<c00H0000004a<C01<C4`0000006IVIP00000;07moO`05
0000001VIVH0000004a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6B/00000600I6ATT0000
00l06ATI00H0000003<c<`0c<c<0<c<c0000001<C4`20000000507moO`000000VIVI09VIVOl00000
0P2c/k<01?l00000VIVI0000001oOgl30000000303<c<ooooooooooo00;ooooo00<00000oooooooo
ool05Oooool01?l0003oooooooooo`28PlL208Uo`P80SGfm0`2@O;T2099j]P80TGRc0P2?M;4208a`
[P80RFb/0P27J:T308IVYP80QVBS0P26HZ4208MQX080R66N0`29HIh208]RW@80S6>M0P2=I9d308iT
W@0308mUW@2CKZD0UFnU0080UFnU0P2FLJH309QbYP<0VWBW0P2KMZP01@2h/]@0^kGC0;^ed`2k]M<0
_[OC00<0Z[cW00<0ZK[V0:Jdh`2V/Ml00P2V/Ml30:J^g@030:N/fP2TW<h0YYc<0080YYc<0`2XWld0
0`2ZY=00ZYG00:fLa`030:fLa`030:jUc`2`Vl40/9_100;o000000D0]Yo10;BZc`2dZ/l0]:[?0:nc
f`020;Fae@80[[SQ00@0];SM072Tl@1`Y?40L:Ca0P2m_]X20;c>j0040=[?cP3Oj=X0gnSJ0<kof080
NmZM00<0YL3]0:Jnj`2U_N/00P2U_N/01P2S^n/0X;GW09F/i_l00000_mk_08k5nP<0jL6/0P3T_:h2
0>jgUP80k[JD0P3^]9<0103^/i40l[R?0?:hS`3c^8d20?BhRP030?FhR?oooooooooo00?ooooo00?o
0000ooooooooool07_ooool000Wooooo00D00000oooooooooooooooo0000000203<c<`060000001<
C4`0C4a<0000001VIVH00000101oOgl3000000@0Ogmo00<0000006IVIP0000000P1<C4`010000000
<c<c03<c<`00000301TI6BX00000200I6AT;o`0000L06ATI9P00000=01TI6@050000000c<c<0<c<c
0000001<C4`00P000000101oOgl0000009VIVOl000040;>c/`03o`00002IVIT0000000<0000000<0
<c<cooooooooool00_ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo0080R8?70P29
Ol8208em_@80T7bi0P2BN[H2095h/`80SgBa0P2<L:h208U/[080QfRY0`26IZH208ITX`80QV:Q0P27
HJ0208QQWP<0RF6N0P2;HYd208aSW@80SFBM0P2>I9d00`2BK:@0TfjU09=^Y@0309E_Y@<0UW6V0`2H
LZH209YdY`0509]fZ02h/]@0^;;D0;Rbe02k]M<00`2/`>P00`2Z_>L0YkSU0:Jdh`020:Jdh`<0Y[7O
00<0YZkM0::OdP2TW<h00P2TW<h30:JLc0030:ROc@2VSkd0ZYG00080ZYG00P2]W<L01@2^TKSo0000
o`000?l00000/JG=00<0]Yo100<0]:[?0;ZWaP2e/MD00P2e/MD01P2l//l0];SM0;Bhg@2d^=d0/;gS
04fOm@<0_<kX0P2djOL01@3Oj=X0c_oH07_JW@1kfYd0Z;kZ00<0Y[k[00<0YKg[0:Bjj02T^^P00P2P
]NL0102E[>Ko000008k5nP2>aOX20>W1[080i;b^00@0gkN_0>jgUP3^]Y@0k[JD0P3^]9<0103^/i40
l[R?0?:hS`3c^8d20?BhRP030?FhR?oooooooooo00Cooooo00?o0000ooooooooool07Oooool000Wo
oooo00D00000oooooooooooooooo0000000203<c<`060000001<C4`0C4a<0000001VIVH000000`1o
Ogl01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c
03<c<`00000301TI6BP0000000?o000001TI6@0I6AT0100I6AT3o`0000/0<c<c0_l0000701TI6B@0
000000Co000000000000000000002P0I6AT010000000<c<c0000001<C4`20000000407moO`000000
VIVIo`0000@0/k>c00?o000009VIV@0000000`0000000`0c<c?oooooooooo`02ooooo`0300000?oo
oooooooo01Cooooo00Co0000oooooooooooooooo0P1iPLh208Uo`P80SGfm0P2@O;T0102BN[H0S7bl
08]i^P2;NKX208Qe]`80Pfnd0P1oJ[4207eU[@<0QVJV0P26I:<208IRX@80Qf6P0P28HIh308UQWP80
Rf:M00@0S6>M08iXXP2@JZ<0T6ZS0`2BK:@209=^Y@@0UFnU0P2FLJH309QbYP0309YdY`2d/=@0];3D
00<0^;;D0P2`a>T00`2/`>P0ZKcW0:Nhi@020:Nhi@030:Jdh`2QZmd0XJ_M0080XJCH0`2RWm820:BL
cP80YYc<00@0XXbl0:J?_@2VSkd0YXnm0P2ZUL03o`0000030:jA^02`Vl40/9_100@0]Yo10`2jYlH0
1@2e/MD0_;;?0;bbc`2l//l0];SM0080^[_J00<0/;gS00n@hP2lc^P00P2djOL01P1ki]T000000000
002Y_^T0Z;kZ0:Rmj@@0Y[cY00<0Y;[X0:6eiP2L[^@00P2L[^@01P2@X^7o000004jFl@1>U_40jL6/
0>Bl[P80gkN_0P3^]Y@30>jdT`040>jcT@3b^8l0l[R?0?>hS@80m;R:00<0mKR80?NiQ_ooool01Ooo
ool00ol0003oooooooooo`0Looooo`002Oooool01@00003oooooooooooooool000000080<c<c00H0
000004a<C01<C4`0000006IVIP00000307moO`050000002IVIT0VIVI09VIV@0000000`1oOgl00`00
0000IVIV0000000204a<C0040000000c<c<0<c<c000000<06ATI:000000601TI6@03o`00000c<c<0
<c<c00h0<c<c0_l0000601TI6BT00000200I6AT010000000<c<c0000001<C4`20000000407moO`00
0000VIVIo`0000@0/k>c00?o000009VIV@0000000`0000000`0c<c?oooooooooo`02ooooo`030000
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00`1iPLh0Ngg907]mb@02089la080R7bo
0P2<O;`208]i^P80R7Fg0P23Kk@307mZ/@0407eU[@1lHZX0O6:Z07aRZP80OF2W0P1oH:@2089PX`80
R66N0P29HIh00`28Hj80RfJR08]VXP0208iXXP80T6ZS0`2BK:@309=^Y@<0UFnU0P2FLJH209QbYP03
0;6]e02d/=@0];3D0080];3D00<0^;;D0;34j@2`a>T00P2[_nP20:Vli`030:Nhi@2S/N80Xk7R00<0
XJ_M0P2QY=P0102RWm80VXg509j;_`2NRkl40::<_0050:J?_Ol0003o0000o`00002ZRK800`2^TKP0
0`2`Vl40]9Be0;BD]@020;JO`@80_9bh0P2jYlH30;bbc`80a;K<00D0^[_J0;nofP2o_mX0/koS0;K1
h`040:joi`030:Vnj@2Z_^P0Z[kX0080Z;gY0P2V_>T0102U^NP0XKGV0:6eiP2Q]NH309b^i003092R
hOl00000CYKa0080i;b^0P3O]jl20>jfU080k[BC0P3^/i40103_/hl0lkR=0?>hS@3d^8X20?FhR003
0?NiQ_oooooooooo00Cooooo00?o0000ooooooooool07?ooool000Wooooo00D00000oooooooooooo
oooo0000000203<c<`060000001<C4`0C4a<0000001VIVH000000`1oOgl00`000000VIVI09VIV@02
09VIV@060000001oOgl0Ogmo0000001VIVH000000P1<C4`010000000<c<c03<c<`00000301TI6BL0
00001P0I6AT00ol00000<c<c03<c<`0203<c<`_o0000100c<c<00ol000006ATI01TI6@0401TI6BX0
00001P0I6AT010000000<c<c0000001<C4`20000000407moO`000000VIVIo`0000@0/k>c00?o0000
09VIV@0000000`0000000`0c<c?oooooooooo`02ooooo`0300000?oooooooooo01Cooooo00?o0000
ooooooooool00_ooool207V1cP80Ngg900<0PWc408Ql_`28O;l00`2<O;`208]i^P80R7Fg0P23Kk@2
07mZ/@80OFF]0P1lHZX207ePY`80Of2T0P22H:<208ERXP<0R6>R0P2;IZ8208iXXP<0T6ZS0`2BK:@2
09=^Y@<0UFnU0P2FLJH40;6]e080];3D00H0]<_[0:o4j@2_a>T0[lCY0:^oj02X^nL30:Fgi@<0Xk7R
00@0XJ_M09RLeP2HTld0V9?=0P2JSLD309j;_`050::<_?l0003o0000o`00002UPjl00`2ZRK830:jA
^0<0]9Be00D0]Yo10;bL^02lW;P0_9bh0;ZWaP020<:X`0040;bbc`34]/`0a;K<0<Bfc0<0_koJ0`2f
`N<20:joi`80[/3W0P2Z_^P30:Nlj0<0YKWX00<0XKGV09^^i02DXml00P2DXml01@29U]Wo0000015R
f00AH]P0i;b^0080gkN_00@0fk>_0>jfU03^]9<0k[BC0P3^/i40103_/hl0lkR=0?>hS@3d^8X20?Fh
R0030?NiQP3h^X?ooooo00Gooooo00?o0000ooooooooool06oooool000Wooooo00D00000oooooooo
oooooooo0000000203<c<`030000001<C4`000000080IVIV00@0000007moO`1oOgl000001@2IVIT0
10000000Ogmo07moOol0000206IVIP030000001<C4`000000080<c<c00@0000001TI6@0I6AT06ATI
9P00000601TI6@03o`00000c<c<0<c<c0080<c<c00?o000004a<C01<C4`02@1<C4`00ol00000<c<c
03<c<`0203<c<`03o`00000I6AT06ATI00<06ATI:P0000000ol000006ATI01TI6@0301TI6@030000
000c<c<0<c<c00<0000000<0Ogmo00000?l000000P2c/k<01?l00000/k>c0;>c/ol0000209VIV@80
000000<0C4a<00000?ooool00oooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo00<0EHSV07]mb@1kOLT00P22O<@208Ql_`80S7bl0P2;NKX208Qe]`80Pfnd0P1oJ[4207eU[@80
O6:Z0P1mH:L207mPY080PV2S0P25HZ8308QSXP80RfJR0P2>J:83091ZX`<0TVbT0P2CKZD309E_Y@03
09IaYP2^ZM<0[ZWC00<0/JgD102dbn/00`2_a>T0Z[oX0:Zoj0020:Rki`030:Fgi@2O/>@0Wk3T0080
VjON0`2HW=H209RCc@80VXg50ol00000102RS;`0WWj_0:F3[`2UPjl40:Z9/P030:jA^02aRZd0/HZ]
0080]9Be102lW;P30<:X`0<0a;K<0P3<_L`0102o_mX0`lGK0<?5f`2f`N<30;O4i080[/3W0`2Z_^P0
0`2W_>P0Y[[X0:Jjj0030:6ei`80VjkT0`2DXml00`29U]Wo0000015Rf0020=ng[`<0fk>_0P3^]9<2
0>jcT@050>ncS`3c^8d0lkR=0?BhRP3e^8P00P3g^HH00`3h^X?oooooooooo`05ooooo`03o`000?oo
oooooooo01[ooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<00ol00000C4a<0000
000206IVIP040000001oOgl0Ogmo000000H0VIVI00<0000007moO`0000000P1VIVH00`000000C4a<
0000000203<c<`040000000I6AT06ATI01TI6BD0000000?o000001TI6@0I6AT00`0I6AT01?l00000
<c<c03<c<`0c<c<2o`0000@0C4a<1ol0000204a<C0?o00000P0c<c<00ol000006ATI01TI6@0301TI
6B/00000100I6AT00`000000<c<c03<c<`030000000307moO`00003o00000080/k>c0_l000020;>c
/`06o`00002IVIT000000000001<C4`000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Cooooo00@0EHSV05Z6hP1ZRMl0JXWO0P28O;l208al_080RgVj0P28MKL208=_]0<0OfZa
00@0OFF]07aRZP1lHZX0O6:Z0P1mH:L00`1oH:@0PV2S089PX`0208ERXP<0R6>R0`2;IZ8208iXXP80
T6ZS0`2BK:@209=^Y@80UFnU00<0ZjGA0:jYd`2^ZM<00P2^ZM<00`2a[M@0^mG]0;_Ek@020;C;j`80
[L?Z00<0Z[oX0:Nkj02S]nL00P2S]nL309n`i080VjON0P2HW=H0102HTlgo0000o`000?l0000209j;
_`0309Mk/P2NOZl0WWj_00<0YH>_0P2ZRK801@2/PZP0/HZ]0;6:[@2aRZd0]9Be0080^Y:]0`2lW;P0
1@34Wk80`ZS00<b^_03<[[`0a;K<00<0c;g<00@0e<S>0<?5f`35bmh0aL_N0P2ga>@20;K5iP80[/3W
00<0Z[kX0:Vmj02Y_NP00`2V^^P0102Q]NL0VjoU09>Sh02CXn0308^Ff@80PHSA00?o0000015Rf03O
]jl00`3K/jl20>jdT`040>jcT@3_/hl0kk>?0?2cS@80m;R:00D0mKR80?NiQP3g^HH0n;Z30?VkP@06
ooooo`03o`000?oooooooooo01[ooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<0
0`000000C4a<0000000206IVIP040000001oOgl0Ogmo000000H0VIVI00<0000007moO`0000000P1V
IVH00`000000C4a<0000000203<c<`040000000I6AT06ATI01TI6BH00000100I6AT01Ol00000<c<c
03<c<`0c<c?o000000<0C4a<0ol0000706IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c
<c<00_l0000401TI6BX00000100I6AT00`000000<c<c03<c<`030000000307moO`00003o00000080
/k>c0_l000020;>c/`06o`00002IVIT000000000001<C4`000001?ooool00`00003oooooooooo`0D
ooooo`03o`000?oooooooooo00Kooooo00<0FXKR06Z9g`1ZRMl00P1jS]/208:@f080PHgG00<0NHOE
06eld@1]O=400`1TLL/207eU[@80O6:Z0P1mH:L207mPY080PV2S0P25HZ8308QSXP80RfJR0P2>J:83
091ZX`80TVbT00<0TfjU0:ROcP2XWlh00`2[YM420:jYd`80`n;^00H0]m3]0;78j`2ab>/0/LS[0:g3
jP2Z_nT30:Nkj0030:>gi`2L/^L0W;;W0080U:OS0P2<V=X3o`00000308Yo`P2@NkP0T7^h00<0Ug^b
0`2NOZl20:F3[`030:Z9/P2/PZP0[8:X00<0/HZ]102jTZd00`2lW;P0a9nb0<BO/P030<b^_080ekVl
00<0c;g<0=C8cP3Db<h00`35bmh01034cn80]/GV0;K5iP2daNL30:g0j0030:Vmj02W^nP0X[OW00<0
X[OW0P2K[nD209>Sh0<0RiKI00@0PHSAo`000000=K`0gkN_0`3K/jl20>jdT`040>jcT@3_/hl0kk>?
0?2cS@80m;R:00H0mKR80?NiQP3g^HH0n;Z30?VkP@3j_7l6ooooo`03o`000?oooooooooo01Wooooo
0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<01@000000C4a<0000001VIVH000000080
Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo0000000206IVIP050000001<C4`0000003<c
<`0000000`0I6ATU000000@06ATI00Go000003<c<`0c<c<0<c<co`00000304a<C004o`00001VIVH0
IVIV06IVIPOo000000@0IVIVo`000?l0003o00000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000@0
6ATI00?o00000000000000009`00000301TI6@030000000c<c<0<c<c00@0000000@0VIVIo`00002c
/k?o00000P3<c<`01?l00000/k>c0;>c/ol000020000000304a<C000003ooooo00?ooooo00<00000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`03001fdP1ZRMl0JXWO0080NXkK0P22T=P2
086=e`0307V7e@1]O=40KGcA0080I77;0P1QJL@206AU_P80OF2W0P1oH:@2089PX`80QF:R0`28Hj82
08]VXP80SVRR0`2@JZ<00`2BK:@0Y9W:0:ROcP030:ROcP050:^Ud@3?om80b_;/0<[bk033h^h00`2g
d>d00`2ab>/0[<;Y0:c2j@020:Zoj@040:Nkj02S^NP0XkWX0:>ij080W;;W0ol00000102<V=X0R8W>
08R9cP2:Ol83091k^0<0Ug^b0P2NOZl20:F3[`@0[8:X0P2aRZd40;ZB[@<0a9nb00<0cjN_0<b^_03<
[[`00P3G^K`30=C8cP040=WCd`35bmh0a<oR0<C?hP@0]<GW00<0[L3X0:^oj02[_nP00P2W^nP20::g
i`0309faiP2BYN80TZGR0080QYGK0`1nQ]420868d@04o`00003K/jl0fk>_0=^c[`80f:n_0P3^/i42
0>ncS`040?2cS@3d^8X0mKR80?FhR080mkV600<0n;Z30?VkP@3j_7l01_ooool00ol0003ooooooooo
o`0Iooooo`002Oooool01@00003oooooooooooooool000000080<c<c00D0000004a<C0000000IVIV
0000000207moO`03o`00002IVIT0VIVI00H0VIVI00<0000007moO`0000000P1VIVH01@000000C4a<
0000000c<c<0000000<06ATI9000000401TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`2o`00
0080IVIV0_l0000707moO`05o`00001VIVH0IVIV06IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c
<c?o000000@06ATI:@0000001_l000006ATI01TI6Ol00000000003<c<`@0000000<0VIVIo`000?l0
0000103<c<`00ol00000/k>co`0000020000000304a<C000003ooooo00?ooooo00<00000oooooooo
ool04oooool00ol0003oooooooooo`0<ooooo`80>:Kd0P1</oT2046_mP0301^Gj01]O=40KGcA0080
I77;00<0HFW406AU_P1TIKh00P1YI;T207mPY080PV2S0P25HZ8308QSXP80RfJR0P2>J:82091ZX`04
09nAa@2TVLX0Y9W:0:BIbP80Z9o>00@0`?:O0<_mhP3;oN80b_;/0P2mfnl20;O@k@80[lK[00<0[<;Y
0:Vnj@2W_>T00P2W_>T20:>ij00309ffjOl0003o00000080PI[R0P1bQ=H208R9cP80RWo20P2@NkP3
09Mk/P80WWj_00<0YH>_0:EkYP2UNjH00`2/PZP00`2aRZd0]XVV0;J9YP030;ZB[@050<>FZ034Wk80
cjN_0<nW[`3<[[`00`3G^K`01P3SbKd0e<S>0=WCd`3Idm<0fMcI0<C?hP80`=3V0P2daNL20;74j003
0:^oj02Y_NP0Y;WX0080Y;WX0`2M/NH209:UhP80QYGK0P1nQ]4207Ykb00306Q[`_l00000fk>_00<0
f:n_0P3^/i40103_/hl0l;>=0?2cS@3a]8/20?FhR080mkV600@0n;Z30?VkP@3j_7l0nkem1_ooool0
0ol0003oooooooooo`0Hooooo`002Oooool01@00003oooooooooooooool000000080<c<c00D00000
04a<C0000000IVIV0000000207moO`030000002IVIT0VIVI00H0VIVI00<0000007moO`0000000P1V
IVH01@000000C4a<0000000c<c<0000000<06ATI9000000401TI6@05o`00000c<c<0<c<c03<c<ol0
00000P1<C4`01?l00000IVIV06IVI_l0000207moO`Oo000000<0Ogmoo`000?l000000P1VIVH00ol0
0000C4a<o`00000303<c<`03o`00000I6AT06ATI00806ATI:P00000301TI6@030000000c<c<00000
00<0000000<0VIVIo`000?l00000103<c<`00ol00000/k>co`0000020000000304a<C000003ooooo
00?ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`04009Sf00<RN8038WR
04jVn080J:Gd0P00M=<01000FLH0HFW4065Ya01TIKh206UT^@80LFJf0P22H:<208ERXP<0R6>R00@0
RfJR09>0_02JRL00VXW0102OTLD20:BIbP040>SbU`2GdFd0bogR0<_mhP80a>O_00D0^M;]0;?;k02c
bn`0/l_/0:o6j`020:c1j@80ZKkY00<0YkcY0:BkjOl000000_l000000`2M]^T0TJcX096/j002086J
hP0307:4eP1^LlL0KW?70080MV^i0P2@NkP309Mk/P0309in[`2LMJH0YG^V0080YG^V0`2/PZP00`2a
RZd0]XVV0;J9YP020;ZB[@80`iJX00<0a9nb0<nW[`3?Yjl00`3G^K`20>?9_@060>cK`@3Idm<0fMcI
0=WLf@3Ch>40`=3V0`2jcNP00`2aa>P0[/;Y0:Vmj0020:Vmj0030:Bij02O]>L0U:WU0080U:WU0P25
V=h207N4d`<0OXKA00@0NW_806Q[`P004Z;o00000`3H[jl20>jcT@040>ncS`3`/hd0l;>=0?6dR`80
mKR800L0mkV60?RjP`3h^X<0nK^10?ZlO`3k_Gd0o;mj00Kooooo00?o0000ooooooooool05oooool0
00Wooooo00D00000oooooooooooooooo0000000203<c<`050000001<C4`0000006IVIP0000000P1o
Ogl010000000VIVI09VIV@2IVIT2o`0000<0VIVI00<0000007moO`0000000P1VIVH01@000000C4a<
0000000c<c<0000000<06ATI9000000401TI6@04o`00000c<c<0<c<co`000080C4a<00Go000006IV
IP1VIVKo000007moO`02o`0000L0VIVI00Ko000007moO`1oOgoo000006IVI_l0000204a<C005o`00
000c<c<0<c<c03<c<ol000000`0I6ATZ000000<06ATI00<0000003<c<`0000000`0000000ol00000
/k>co`0000040<c<c003o`00002c/k?o00000080000000<0C4a<00000?ooool00oooool00`00003o
ooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00@00V?H001?c@0`NN@0GH7M0P1XYO@0101J
T>X0<FWH001?a`00ClL206AU_P0306UT^@1aI[H0LFJf0080NVZe0P23L;H308]h^080Th2l0`2JRL03
09nAa@030:BIbP3XlYL0j?:G0080`ok<00<0c?;[0<CWk`2id^d00P2id^d0102cbn`0[/?Y0:k3j@2/
`NT20:Znj0?o000000@0Y;_Y0:6ijP2F/n/0U[?[0P20Y>X20628hP80LXCF00<0KW?707I[^@1fJkT0
0`23Jjl0102GNk80TFnY09aeYP2LMJH30:EkYP<0[8:X0`2fRJH0102jTZd0`iJX0<>FZ033UZP30<nW
[`030=fe[P3G^K`0hlVm0080hlVm00@0k=_10>kZb03Ig=T0dn3Q0P39gNP20;[=j080]<WZ0P2^`^T0
0`2Y_NP0Y[_X0:Jkj00209ndi`<0U:WU0P25V=h0101gQ=<0LWK8079fb01bM/P207Ykb00306Q[`_l0
0000f:n_0080f:n_00<0eJf_0>ncS`3_/hl00P3`/hd0103a]8/0lkF90?NiQP3g^HH20?RjP`040?Vk
P@3j_7l0nkem0?boNPKooooo00?o0000ooooooooool05oooool000Wooooo00D00000oooooooooooo
oooo0000000203<c<`070000001<C4`0000006IVIP000000Ogmo0000000309VIV@04o`00002c/k<0
/k>co`0000<0VIVI00L0000007moO`000000IVIV0000001<C4`000000080<c<c00@0000001TI6@0I
6AT06ATI8P00000401TI6@07o`00000c<c<0<c<c03<c<ol00000C4a<o`00000206IVIP03o`00001o
Ogoo000000<0VIVI0ol0000409VIV@06o`00001oOgl0Ogmoo`00001VIVKo00000P1<C4`01?l00000
<c<c03<c<ol0000401TI6BT000000`0I6AT00`000000<c<c0000000300000003o`00002c/k?o0000
00@0c<c<00Oo00000;>c/`2c/k?o00000000001<C4`0000000Cooooo00<00000ooooooooool04ooo
ool00ol0003oooooooooo`0?ooooo`8004;40P0TF<h0201MPMd0Jg_A05iYaP1NJLH0<FWH001?a`00
E]00I6Fn0P1YI;T00`1aI[H0NVZe07YZ]@0308=`]P80RgRh0`2CP;`309Z9`00409nAa@3gj;D0m_6W
0>SbU`80`ok<00D0c?;[0<;Ij`32fN/0`]W[0;WBk@020;;6j@030:k3j@2/_nSo000000;o000000@0
Z[kX0:Rmj@2V_>T0Y[cY0P2Q^NX209Jcj`80P:CZ00<0H8SR04AWd014Im000P1^LlL207I[^@80Pf^_
0P2AKjT209aeYP@0YG^V0P2/PZP30;J9YP@0`iJX0P3?Yjl20=fe[P80kLV^00L0hlVm0>cK`@3/fl40
k^[80>OcdP3Jln00bMgX0080_]G[0P2dbNX01P2_a>T0ZkoY0:^oj@2[_nT0Y[_X0::hj0<0V:kW0P27
WN8207>6f080MhCC0P1bM/P207=_`00406Q[`P0008_o00000=R_[`80eJf_0P3_/hl20?2cS@050?6d
R`3c]HT0mkV60?NiQP3h^X<00P3i^h40103j_7l0nkem0?boNP3m`GP6ooooo`03o`000?oooooooooo
01Kooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<01`000000C4a<0000001VIVH0
000007moO`0000000P2IVIT00ol00000/k>c0;>c/`020;>c/`0:o`00002IVIT0VIVI0000001oOgl0
000006IVIP000000C4a<00000080<c<c00@0000001TI6@0I6AT06ATI8P00000401TI6@06o`00000c
<c<0<c<co`00001<C4co00000P1VIVH00ol00000Ogmoo`00000309VIV@;o00000P2c/k<3o`000080
VIVI00Ko000007moO`1oOgoo000006IVI_l0000204a<C004o`00000c<c<0<c<co`0000<06ATI:@00
000301TI6@030000000c<c<0000000<0000000Go00000;>c/ol00000c<c<o`0000030<c<c006o`00
002c/k?o00000000001<C4`000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo
013ooooo00<004;4001?c@0TF<h00P1=H/P01P1[Nm40GVW6049?^P12CkX02T71001Fd080JFBi0P1a
I[H207YZ]@80Pg2f0`2;N;P209>0_080VXW000D0l>C10?OX]@3flJL0m_6W0=o]R`020=OghP030=3M
hP32fN/0`]W[0080^l[V00@0//KYo`000?l0003o00000P2[_^P30:Vmj0030:Jlj@2U_>T0W[W[0080
W[W[0P2</>h0101WVNd0:VcL02Y/g014Im02045C_P80MV^i0P23Jjl2095_Z@<0W7FV0`2UNjH00`2/
PZP0/8:S0;J9YP020;J9YP030;n>X`33UZP0`iJX0080cj2V00<0cjN_0=fe[P3M]Jh00P3]bJh0103i
h:d0k=_10>kZb03Wlm820=[ch0040<_Xj`2neN/0]Lc[0;G<j`<0[lCY00<0ZkoY0:Rmj02X_NP00P2R
^>P309R^i`80QigR00@0LhKH06Ibb`1VL//0IW;;0P1bM/P01@1cKl00K6Nl06aW_00008_o00000080
eJf_0P3_/hl20?2cS@050?6dR`3c]HT0mkV60?NiQP3h^X<00P3i^h401@3j_7l0nkem0?boNP3m`GP0
o/9f00Kooooo00?o0000ooooooooool05Oooool000Wooooo00D00000oooooooooooooooo00000002
03<c<`070000001<C4`0000006IVIP000000Ogmo0000000209VIV@03o`00002c/k<0/k>c0080/k>c
00[o000009VIV@2IVIT0000007moO`000000IVIV0000001<C4`000000P0c<c<0100000006ATI01TI
6@0I6ATR000000@06ATI00Ko000003<c<`0c<c?o000004a<C?l0000206IVIP04o`00001oOgoo0000
09VIV@;o00001`2c/k<02?l00000VIVI09VIVOl00000Ogmoo`00001VIVKo00000P1<C4`01?l00000
<c<c03<c<ol0000301TI6BT000000`0I6AT00`000000<c<c0000000300000005o`00002c/k?o0000
0<c<c?l000000`3<c<`01_l00000/k>co`0000000000C4a<000000Cooooo00<00000ooooooooool0
4_ooool00ol0003oooooooooo`0Cooooo`0302AHcP1=H/P0CF;80080Ff6o0P12CkX0100X>:d02T71
01YUfP0JIMX2075V]P80NVZe0`23L;H208]h^00309>0_028jO40R>Wa0080l>C100<0mnRe0?KaZ`3O
kH/00P3Gmn80103@gN80b<_L0<S;g038bm`3o`0000040:o1i`2__nH0[koV0:noiP80ZkkX00<0ZKgX
0:Rmj02X_NP00P2U_>T00`2N^N/0VkS]09^hk@0208>^l00504V>k@0ZK=`0:VcL04AWd011Dkh00P1F
D[8208=[[`<0TFnY0P2LMJH30:EkYP<0/8:S00<0]XVV0;n>X`2oSZ<00P33UZP20<nPYP030<nW[`3M
]Jh0kLV^0080kLV^00H0nN2]0?KaZ@3VnJ`0fOk20=[ch03;j>/20;cIkP030;G<j`2_aNX0[lGZ00<0
[<7Y00@0Z;gX0:Fjj02L/nP0W;?X0`2<YND207B=g@80GG;?0P1VL//206EW`080Lfo000H0K6Nl0000
M`3E[Joo00000=F][`3CZk020?2cS@80lKB;00D0lkF90?BgQ`3g^HH0n;Z30?VkP@020?ZlO`050?^m
O@3l_gX0oL5h0?k2MP3oa7D01Oooool00ol0003oooooooooo`0Eooooo`002Oooool01@00003ooooo
ooooooooool000000080<c<c00T0000004a<C0000000IVIV0000001oOgl0000009VIVOl000001P2c
/k<00ol00000VIVIo`00000207moO`070000001VIVH0000004a<C0000000<c<c0000000301TI6B80
00000`0I6AT01_l00000<c<c03<c<ol00000C4a<o`000080IVIV00?o000007moOol000000P2IVIT0
0ol00000/k>c0;>c/`05o`000080/k>c00So000009VIV@2IVIWo000007moOol00000IVIVo`000080
C4a<00Co000003<c<`0c<c?o00000`0I6ATY000000806ATI00<0000003<c<`0000000`000002o`00
00040<c<c?l00000i^KVo`0000<0c<c<0_l000020000000304a<C000003ooooo00;ooooo00<00000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03000c]`0TF<h0CF;80080Ff6o00D0GVW6
049?^P0X>:d0:3R]004`/`0201YUfP80?W_R00<0GiC/08=`]P23L;H00P1j/oL208cEo`80i_CB0P3`
i<420?KaZ`040:39F03Um=@0gMWB0=K7c0?o000000@0aL?H0;S3hP2g`>00]l3P0P2__nH0102__^D0
ZkgW0:^mi`2[_NL20:Rmj0<0Y;cZ0`2K^>d208>^l080BHk]00<00473045C_P11Dkh00P1FD[8208=[
[`80TFnY0P2LMJH20:EkYP050:MjXP2`PZ<0/8:S0;22X`2fRJH00P2oSZ<20<>FZ080cj2V0P3M]Jh2
0>g9[P80nN2]00H0m_6Y0>Ki[03Io/80d?cR0<?Yl02lfNh20;?<k@<0[lGZ00<0[<7Y0:Vnj@2Y_^T0
0P2U^^P209bcj0<0S:GU0P1dSMd01@1ML/l0Deo105=O`@1VL//0IFO000<0KfNj00<0K6Nl0000Rol0
00000P3CZk020?2cS@80lKB;00D0lkF90?BgQ`3d]hL0n;Z30?VkP@020?ZlO`060?^mO@3l_gX0oL5h
0?k2MP3oa7D0olIc1Oooool00ol0003oooooooooo`0Dooooo`002Oooool01@00003ooooooooooooo
ool000000080<c<c00T0000004a<C0000000IVIV0000001oOgl0000009VIVOl000001P2c/k<03?l0
0000VIVI09VIV@000000Ogmo0000001VIVH0000004a<C0000000<c<c000000<06ATI8P00000301TI
6@06o`00000c<c<0<c<co`00001<C4co00000P1VIVH01Ol00000Ogmoo`00002IVIWo00000080/k>c
00?o00000<c<c03<c<`00`3<c<`01?l00000/k>c0;>c/ol0000209VIV@07o`00001oOgoo000006IV
I_l00000C4a<o`00000203<c<`03o`00000I6AT06ATI00806ATI00?o00000000000000009@000002
01TI6@030000000c<c<0000000<000000_l000001@3<c<co00000>KViP3Vi^Ko00000080c<c<0_l0
00020000000304a<C000003ooooo00;ooooo00<00000ooooooooool04_ooool00ol0003ooooooooo
o`0Dooooo`05000c]`1=H/P0CF;805]Q_`1CE;H00P12CkX01@0X>:d00C2c01Pj]P0H>[H004fi0080
?W_R0P1OU>`00`1j/oL0?;j`03bn/0020=7Df`80h<k600@0lMjm0?KaZ`2PbEP0iOCD0ol000001P3F
al`0aL?H0<G3f035`mP0aKoD0;O0h080^;oO0`2__^D30:^mi`80Z;gX102T_>X209ZikP80OJkc00@0
<8G[000HV@007:L0@E>n0P1FD[80101aG:X0Pf^_095_Z@2AKjT209aeYP030:EkYP2WNZ80YgZR00<0
/8:S00@0]XVV0;n>X`2oSZ<0_hjS0`3?X:H00`3P/JH0gKF^0>g9[P020?WP[@050?KaZ@3VnJ`0fOk2
0=3lhP33jO000P2feO000`2cc>d0[LC[0:_1j@030:_1j@030:Vnj@2W_>P0XKOX0080XKOX0P2D[NP2
07bHh`80GGWF00D0GG;?05=O`@1CGl40Deo106EW`00306mW^P05079W]`0007L0eJf_o`00003CZk00
0P3`/hd20?6dR`060?>eR@3d]hL0m;N70?RjP`3i^h40n[ao0P3k_Gd01P3l_gX0oL5h0?k2MP3oa7D0
olIc0?o8L`Gooooo00?o0000ooooooooool04oooool000Wooooo00D00000oooooooooooooooo0000
000203<c<`090000001<C4`0000006IVIP000000Ogmo0000002IVIWo000000H0/k>c00co000009VI
V@2IVIT0000007moO`000000IVIV0000001<C4`0000003<c<`00000301TI6B8000000`0I6AT01_l0
0000<c<c03<c<ol00000C4a<o`000080IVIV00Go000007moOol00000VIVIo`0000020;>c/`03o`00
003<c<`0c<c<00<0c<c<00Co00000;>c/`2c/k?o00000P2IVIT01ol00000Ogmoo`00001VIVKo0000
04a<C?l000000P0c<c<00ol000006ATI01TI6@0201TI6BP000000P0I6AT00`000000<c<c00000003
000000;o000000D0c<c<o`00003Vi^H0i^KVo`0000020<c<c0;o00000P0000000`1<C4`00000oooo
o`02ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00`0008T0;TNj02i7
^P0205]Q_`0603]1[@12CkX0:3R]02DbZ001<;<063Zf0P14El401@01Q=/0K;?j06bcnP1//oX0Wn[j
00<0dMCK0P3Pc/H01@3flJ/0gnf;o`000?l00000gMWB0080e/O<0P3B_lL01035`mP0aKoD0<Foe036
_M830;Rog`030:nni@2__^@0[kkT0080ZkgW102X_NP20:BljP<0V[W^0P1n/?@00`0XQ^/001RI000L
Y`0205IB/P80LEbZ0P2AKjT00`2LMJH0Vg6R0:MjXP030:MjXP80/8:S102oSZ<20<nPYP80h;6V00L0
m<ZT0>g9[P3ih:d0nN2]0?KaZ@2QfGL0_oW]0080]mod00<0]]G`0:o8k02_b>`00P2]a>/20:_1j@80
ZKkY0P2W_>P0102Q]nP0Vk?X08RTi`28Y>L306N7gP0305eieP15G<D0GG;?0080Deo100H0Fe^i06EW
`01_IkX0KfNj079W]`0006D20=>[/004o`00003CZk00l;>=0?6dR`80lkF90P3d]hL00`3f^8D0nK^1
0?ZlO`020?^mO@070?boNP3m`GP0o/9f0?o4M@3oaW<0olQc0?o>M004ooooo`03o`000?oooooooooo
01?ooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<010000000C4a<0000001VIVH2
00000080VIVI00?o00000;>c/`2c/k<01@2c/k<00ol00000VIVI09VIV@020000000406IVIP000000
C4a<00000080<c<c00<0000001TI6@0I6AT08P00000301TI6@08o`00000c<c<0<c<co`00001<C4co
000006IVI_l0000207moO`;o00000P2c/k<00ol00000c<c<0<c<c0050<c<c006o`00002c/k<0/k>c
o`00002IVIWo00000P1oOgl01Ol00000IVIVo`00001<C4co00000080<c<c00Co000001TI6@0I6AT0
6ATI:000000201TI6@80000000@0C4a<00000000000000000ol000040>KViP04o`00003<c<co0000
o`0000@000000oooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00H003>g
02i7^P16C[L0Ff6o05=D]P0k@Jd202Ph[@0402DbZ00H>[H0A5O104AG`@80Mgo>00D0K;?j0:V[f02Y
ZmP0ZJ_H0=7Df`020>3>aP?o00000P3Tc/400`3M`;/0e/O<0=:oa`020=:oa`030=:k``35_m@0a[gB
0080a[gB00@0^;oO0;Zng@2j_]d0[kkT0P2`_^@20:^mi`@0Z;gX0P2T_>X00`2J^Nh0WK_]09fkk@02
08Fdm00403ZDl@0007/001bW05IB/P80LEbZ0P29IjD209]aXP@0YgZR0P2`PZ<40;n>X`80cj2V0P3P
/JH01@3dbZ@0oN>H0?gSV03QiGX0/mAS0080/nSg00D0]mod0;3<k`2`c>l0[lS/0:_1jP030:_0j@80
ZKkY00@0Z;cX0:Bjj02T^^P0Y;[X0P2K/nP208RTi`80IhON00<0@V;=05eieP15G<D00P1CGl4205]K
^@<0KfNj00L0LVNg0000M`3CZk00dj^`o`00003CZk00lKB;0080lkF90P3d]hL0103f^8D0nK^10?Zl
O`3k_Gd20?boNP070?g1N03n`WH0olAe0?o6L`3ob7<0olid0?oAM`04ooooo`03o`000?oooooooooo
01;ooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<010000000C4a<0000001VIVH2
00000080VIVI00?o00000;>c/`2c/k<01@2c/k<00ol00000VIVI09VIV@020000000406IVIP000000
C4a<00000080<c<c00<0000001TI6@0I6AT08P00000301TI6@0<o`00000c<c<0<c<co`00001<C4co
000006IVI_l00000Ogmoo`00002IVIWo00000P2c/k<00ol00000c<c<0<c<c0060<c<c00<o`00002c
/k<0/k>co`00002IVIWo000007moOol00000IVIVo`00001<C4co00000P0c<c<01?l000006ATI01TI
6@0I6ATX000000806ATI00?o00000000001<C4`00`000003o`0000@0i^KV00?o00000<c<c?l00000
0_l00003000000?ooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`0;0:hg
000^AkX0ATjg04I>]`1CE;H0>d6]02HaYP0X>:d09C:X03e3[P0H>[H00P14El401@1gOlh0ZJ_H0:V[
f02YZmP0`k3800?o000000<0lMjm0=;[QP3Tc/400P3Tc/40103M`;/0f[Vg0=Zi]`3B_lL20=:k``06
0=>i`@36_M80a[gB0<JmdP38_M00^[kM0P2k_]`00`2`_^@0/KkT0;6ni0030:^mi`030:Rmj02Y_NP0
YKcZ0080YKcZ00<0WK_]0:2lk02?^?800`2?^?8010007:L0EU:b05IB/P1aG:X208UWY@<0Vg6R0`2W
NZ800`2`PZ<0^8NQ0;n>X`020;n>X`80c9ZR00@0cj2V0>2aYP3dbZ@0m<ZT0P3mhiP00`3QiGX0Yn_j
0;?Xm`020:o@lP030;3<k`2/`n/0[<?[0080Zl7Z00@0Zl3Y0:Vmj02Y_NP0ZKgX0P2X_>P0102T^^P0
XKOX09B]j02D[NP207RHi@<0CG?G00H0@V;=04ELa@11C[T0@Dji05=O`@1KFkT206eR]P0306mW^P1b
IkL0001U0080dj^`00?o00000=>[/03a]8/00P3c]HT20?BgQ`050?JhQ@3h^X<0n[ao0?^mO@3l_gX0
0P3m`GP0203n`WH0olAe0?o6L`3ob7<0olid0?oAM`3oe7/0omN20_ooool00ol0003oooooooooo`0B
ooooo`002Oooool01@00003oooooooooooooool000000080<c<c00@0000004a<C0000000IVIV0P00
000209VIV@03o`00002c/k<0/k>c00D0/k>c00?o000009VIV@2IVIT00P000000101VIVH0000004a<
C?l0000203<c<`030000000I6AT06ATI028000000`0I6AT02?l00000<c<c03<c<ol00000C4a<o`00
001VIVKo00000P1oOgl2o`000080/k>c00?o00000<c<c03<c<`01P3<c<`03?l00000/k>c0;>c/ol0
0000VIVIo`00001oOgoo000006IVI_l00000C4a<o`000080<c<c00Co000001TI6@0I6AT06ATI:000
00001@0I6AT0000003<c<`000000C4a<00<000000ol000040>KViP04o`00003<c<co0000o`0000@0
00000oooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00<00RZ^02i7^P16
C[L00P12B;800`0k@Jd09S6V02DbZ00203e3[P80A5O10P1gOlh3o`0000070<>`b03Oc/L0glk70??b
^@3BjhH0iL>e0>C>`@020=g0^`80f[Vg0`3B^l<20=>i`@030<JmdP38_M00b;g@00<0^kkL00D0_KoK
0;6ni02a_^@0/KkT0:^mi`020:bmi`80ZKgX00<0YKcZ0:Jmj@2V_NT00P2P_>`208nhlP80VK_`00<0
4bVV05IB/P1aG:X00P29IjD309]aXP<0YgZR00<0/8:S0;R7X@2hQj400P2oSZ<20<bJXP80h;6V00D0
m<ZT0?gSV03mhiP0hNEj0:O[nP020:cBm0040:o@lP2[a>`0ZlC/0:c3j`@0Z[kX0P2Y_NP0102Y^nL0
Yk[W0:Nji`2W^^L20:6gj080U:gX0P1hV>D204ece`03049Rc@0/A[X0;4Jj0080@Dji0P1KFkT206eR
]P03079W]`0005@0dj^`0080dj^`00?o00000?6dR`3c]HT00P3d]hL20?JhQ@050?RjP`3j_7l0nkem
0?boNP3m`GP00P3n`WH01`3oa7D0olQc0?o;L`3ocW@0om5g0?oDN`3oeh800oooool00ol0003ooooo
ooooo`0Aooooo`002Oooool01@00003oooooooooooooool000000080<c<c00@0000004a<C0000000
IVIV0P00000209VIV@03o`00002c/k<0/k>c00D0/k>c00?o000009VIV@2IVIT00P000000101VIVH0
000004a<C000000203<c<`030000000I6AT06ATI028000000`0I6AT01?l00000<c<c03<c<ol00002
04a<C0;o00000P1oOgl00ol00000VIVIo`0000020;>c/`03o`00003<c<`0c<c<00@0c<c<00go0000
0;>c/`2c/k<0/k>co`00002IVIWo000007moOol00000IVIVo`00001<C4co00000080<c<c00Co0000
01TI6@0I6AT06ATI:00000001@0I6AT0000003<c<`000000C4a<00<000000ol000040>KViP04o`00
003<c<co0000o`0000@000000oooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01So
oooo00X00RZ^04I>]`12B;80@TRb02/j[P0V<JH09c>X02DbZ00m@jh0J6Bj0ol00000102HS<@0`k38
0<>`b033/<P20=o>a`030=;[QP3U`kD0iL>e0080gL2k0`3J^KL00`3J][@0d[_30=>i`@020=>i`@05
0=Fi_P38_M00b[g>0<ZmcP2k_]`00`2m_m/01@2a_^@0/[kS0;:nh`2/_NL0[;kV00<0ZKgX00@0Y[gY
0:Nmj@2W_NT0YkgY0P2S_>/0102I^o00X;c]000LY`0C:JH2075LZP80RFNU0P2KLJ830:MjXP<0^8NQ
00@0_hjS0<bJXP3<VZ80c9ZR0P3P/JH01@3dbZ@0oN>H0?gSV02WdOH0ZLC]00<0ZlG]00<0ZlC/0:Zo
j@2Z_nT00`2Z_^P20:VkiP<0ZK_W00<0Yk[W0:Ffi@2U]^D00P2M/^H208ZUiP80IHWQ00<0<5_=04ec
e`12H/d00P0/A[X00`11C[T0DU:d05]K^@0206eR]P80NVZf0`3CZk000`3C[K7o00000?>eR@020?Bg
Q`80m[R500H0n;Z30?ZlP@3k_Gd0o;mj0?g1N03n`WH20?o4M@060?o8L`3obg<0olid0?oAM`3oe7/0
omN21?ooool00ol0003oooooooooo`0@ooooo`002Oooool01@00003oooooooooooooool000000080
<c<c00@0000004a<C0000000IVIV0P0000000`2IVIWo00000;>c/`080;>c/`0;o`00002IVIT00000
07moO`000000IVIV0000001<C4`0000003<c<`0000000`0I6ATR000000<06ATI00So000003<c<`0c
<c?o000004a<C?l00000IVIVo`000080Ogmo0_l000020;>c/`03o`00003<c<`0c<c<00@0c<c<00[o
00000;>c/`2c/k?o000009VIVOl00000Ogmoo`00001VIVKo00000P1<C4`01?l00000<c<c03<c<ol0
000301TI6BL000000P0I6AT00`000000<c<c0000000300000004o`00002c/k?o0000o`0000D0i^KV
0ol00004000000?ooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`040000
K`0/@[H0ATjg0498/P80:cZ^00D09c>Xo`000?l0003o000006QT^P0409R<a0050<>`b03Oc/L0glk7
0??b^@3BjhH00P3U`kD0103O^K00gL2k0=Zi]`3J^KL20=Zf]0<0dkW10P3E^Kh30<ZmcP030<bmc02m
_m/0_KoK0080_[oJ00<0/[kS0;>nh`2c_^<00P2/_^H30:Vmj080YkgY00L0Z;gX0:JmjP2V_NX0Y[gZ
0:2lk@2T_N/04bVV0080LEbZ0P29IjD309]aXP80YgZR0`2hQj401@2oSZ<0c9ZR0<bJXP3<VZ80h:jS
0080m<ZT00<0oN>H0:S3k@2Ya>d00P2Ya>d0102[aNd0Z[oY0:Zoj@2Z_nT40:ZkiP030:VkiP2Y]n80
Z;OT00<0Z;OT00@0YKKU0:B^g`2JZN80VZWR0P21V^83055hfP05031Kc@0SBL40;4Jj02a6^P11C[T0
0P1BD[@206eR]P80NVZf00<0001U0=>[/03C[K400P3C[K401?l00000m;N70?BgQ`3f^8D20?RjP`0;
0?ZlP@3k_Gd0o;mj0?g1N03n`WH0olAe0?o6L`3ob7<0ol]c0?o>M03odGL00P3oeh801@3jdYgooooo
oooooooooooo000001;ooooo0009ooooo`0500000?ooooooooooooooo`0000000P0c<c<010000000
C4a<0000001VIVH20000000309VIVOl00000/k>c0080/k>c1?l000020;>c/`0;o`00002IVIT00000
07moO`000000IVIV0000001<C4`0000003<c<`0000000`0I6ATR000000<06ATI00So000003<c<`0c
<c?o000004a<C?l00000IVIVo`000080Ogmo00?o000009VIVOl000000P2c/k<4o`0000030<c<c?l0
0000/k>c0080/k>c00Oo000009VIVOl00000Ogmoo`00001VIVKo00000080C4a<00Co000003<c<`0c
<c?o00000`0I6ATW000000806ATI00<0000003<c<`0000000`0000001Ol00000/k>co`000?l00000
i^KV00?o000000@0i^KVo`000?l0003o00000`000004ooooo`0300000?oooooooooo017ooooo00?o
0000ooooooooool06?ooool0100006l0;4:f02a2]P12B;83o`00000302LcZ019D;L0?D>^0080J6Bj
0P2HS<@20;b_c@030=o>a`3cl[T0lo:i0080iL>e0P3O^K000`3M/jd0f[Vg0=Zf]0020=Zf]0030=Zd
/P3C^L40eKVn0080eKVn00@0ekVl0<ZmcP3<_L`0c;g<0P3>_LX01@2n_mX0`;oI0<2of@2c_^<0/koR
00<0[;kV00@0ZKgX0:Zmj02Z_NP0Z[gX0P2X_NP01`2V_NX0YkgY0:Nmj@2T_N/04bVV04m7Z01aG:X0
0P29IjD309]aXP030:MjXP2]OZ40^8NQ0080^8NQ103<VZ80103P[Z<0n<nO0?gSV03mhiP30:Vnj080
ZKkY00<0Z[oY0:Zji@2Z^^D00`2Z^nH20:Zfh@80ZKOR0P2X]n@0102X[m`0Y:kO0:B^g`2T[]l209ZY
hP80PI[R0P1AN=X01P0`Fld08dW1018b/00/A[X0<3na045>^@80DU:d0P1]H[H207YZ]P050=>[/03C
[K40djfa0=>]/Ol000000P3d]hL0303f^8D0n;Z30?RjP`3j_840nkin0?boNP3m`GP0o/9f0?o4M@3o
aW<0olQc0?o>M080om5g00<0omN20?oHS`3jdYd01?ooool00ol0003oooooooooo`0?ooooo`002Ooo
ool01@00003oooooooooooooool000000080<c<c00@0000004a<C0000000IVIV0P0000000`2IVIWo
00000;>c/`020;>c/`04o`00003<c<`0c<c<o`000080/k>c00_o000009VIV@000000Ogmo0000001V
IVH0000004a<C0000000<c<c0000000301TI6B8000000`0I6AT01_l00000<c<c03<c<ol00000C4a<
o`000080IVIV00?o000007moOol000000P2IVIT00ol00000/k>c0;>c/`030;>c/`05o`00002c/k<0
/k>c0;>c/ol000000P2IVIT01Ol00000Ogmoo`00001VIVKo00000080C4a<00Co000003<c<`0c<c?o
00000`0I6ATW000000806ATI00<0000003<c<`0000000`0000002Ol00000/k>co`000?l00000i^KV
o`00003ooooo00000>KViP03o`0000<000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Wooooo0ol00000100aB;T0:cZ^018^[00W<jP204U@]`80J6Bj00@0V8c40;b_c@2l[ld0
_:o=0P3Uk]@00`3^e[/0iL>e0=ni/0020=ni/0040=fc[@3L/J/0f[Jd0=Zf]080f[Bb0P3L];001@3E
^Kh0ekVl0=Ni_03H^KX0c;g<00<0c[g:0`30_mT30;>ohP060:bniP2]_^H0[KkV0:fniP2Z_NP0Z[gW
0`2Y_NP0102W_NT0Z;gX0:Nmj@0005P204m7Z080RFNU0P2KLJ80102KLZ<0[GjQ0:enX@2]OZ420;R7
X@030<FCXP3<VZ80c9ZR0080h:jS00<0n<nO0?;SO@2Y_NP00P2Y_^P01P2Y^N@0ZKWU0:Vii@2Y^ND0
Z[[U0:Zcg`<0Z[CP00<0Z[KQ0:V[f02Y[MX00P2Y[MX30:R_g0040:B^g`2SXm@0UikI09NNf@80NXgJ
0P14J=401P1AN=X0<5_=02=9`@0B<[00;4Jj030o/@80DU:d0P1]H[@207YZ]P@0djfa00@0e:nco`00
003d]hL0m[R50P3h^X<03`3j_840nkin0?g1N`3m`GP0o/9f0?o4M@3oaW<0olQc0?o>M03odGL0omAk
0?oGPP3of8l0n]:M0>k4Y`02ooooo`?o00004?ooool000Wooooo00D00000oooooooooooooooo0000
000203<c<`040000001<C4`0000006IVIP80000000D0VIVIo`00002c/k<0/k>co`0000040<c<c003
o`00002c/k?o00000080VIVI0P000000101VIVH0000004a<C000000203<c<`030000000I6AT06ATI
02<000000`0I6AT01_l00000<c<c03<c<ol00000C4a<o`000080IVIV00?o000007moOol000000P2I
VIT00ol00000/k>c0;>c/`040;>c/`;o00000P2IVIT01Ol00000Ogmoo`00001VIVKo00000080C4a<
00Co000003<c<`0c<c?o0000100I6ATV00000005o`00000I6AT06ATI0000000c<c<010000002o`00
00030<c<c?l0003o000000<0oooo1?l00003000000Cooooo00<00000ooooooooool04Oooool00ol0
003oooooooooo`0Fooooo`?o000000Wooooo02a2]P0/@[H0<DRi01Q1_@0[>Zh05Cfj02LcZ019D;L0
0`23PLP30;b_c@040>G^e03XbKL0h[b`0>G3]@80gkV`0P3M/jd20=baZ`030=Zf]03J];80f[Bb0080
g;B`0`3G^K`00`3H^KX0f[Vh0<jmbP020<jmbP050=2nb@30_mT0`KoH0<6of02c_n800`2d_n830:fn
iP80Z[gW0`2Y_NP20:Rmj0030:Nmj@0C:JH0CdNX0080OV6V0`2KLZ<30:enX@030;R7X@35Tj80aI>R
0080c9ZR0P3P[Z<0103hcil0l^=m0:Vhi02Y^>@30:Vii0030:Vii@2Y/Md0Z[?O0080Z[?O00<0Z[CP
0:VXeP2YZmP00P2YZmP00`2Y[MX0ZJ3=0:VPc@020:NRd@<0Xj?D0P2GW]T207Z=fP80A6SA00L054G2
00@a]00B<[004S:`030o/@1;C;40DU:d0080KF:d0`25L[H20=>]/@80e:nc00<0m;N7o`00003f^8D0
0P3h^X<0303j_840nkin0?g1N`3n`gP0o/9f0?o4M@3ob7<0ol]c0?o>M03odGL0omAk0?oGPP80n]:M
00<0k/BWo`000?l000000_ooool00ol0003oooooooooo`0>ooooo`002Oooool01@00003ooooooooo
ooooool000000080<c<c00@0000004a<C0000000IVIV0P0000001@2IVIWo00000;>c/`2c/k?o0000
00@0c<c<00Go00000;>c/`2c/k?o000009VIV@020000000406IVIP000000C4a<00000080<c<c00<0
000001TI6@0I6AT08`00000301TI6@07o`00000c<c<0<c<c03<c<ol00000C4a<o`00000206IVIP05
o`00001oOgoo0000o`00002IVIT01_l0000209VIV@;o000000D0Ogmoo`00001VIVH0IVIVo`000002
04a<C004o`00000c<c<0<c<co`0000@06ATI9`00000201TI6@030000000c<c<0000000<000000_l0
00000`3<c<co0000o`0000030?ooo`Co00000`000004ooooo`0300000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool2o`0000Cooooo0P0E@Kh20358^@0301Q1_@0B;Z`05Cfj0080BE2g0`23
PLP01P2l[ld0iNkD08oSW`3XbKL0h[b`0=jc[@80gkV`00@0gK>]0=baZ`3L/J/0g;6[0P3J];830=bd
/0040=fd[P3G^K`0f;Vj0=Ri^P80f[Vh00D0c[g:0=2nb@3@_/T0dKk70<6of0030<?0e`050;BohP2e
_n80]KoR0:fniP2^_^H00`2Z_NL50:Vmj00401<YYP1?AjP0OV6V07iQYP<0Vg:S0`2]OZ400`2hQj40
aI>R0<FCXP020<bJXP040>2^X`3hcil0n<nO0:Vgh`<0ZKST00<0ZKWT0:V_g02Y[m`00P2Y/Md00`2Z
/ml0ZJKC0:VXeP020:VXeP030:V[f02YWLX0ZJ3=00<0ZJ3=0P2WX]40102SXm@0XYG709J@b`2FT</2
07Z1cP80AEk800D054G2000LYP0B<[004S:`030o/@0204]</@03059B]01]H[@0QG:f0080QG:f00@0
NW:n0=>]/@3D[k<0e:nc0P3d]hL04?l00000n;Z30?RjP`3j_840nkin0?g1N`3n`gP0olId0?o4M@3o
b7<0ol]c0?o>M03odGL0omN20?oHS`3jdYd20>k4Y`050>NnZoooooooooooooooool000004?ooool0
00Wooooo00D00000oooooooooooooooo0000000203<c<`040000001<C4`0000006IVIP80000000D0
VIVIo`00002c/k<0/k>co`0000040<c<c005o`00002c/k<0/k>co`00002IVIT00P000000101VIVH0
000004a<C000000203<c<`040000000I6AT06ATIo`0002800000100I6AT01?l00000<c<c03<c<ol0
000204a<C004o`00001VIVH0IVIVo`000080Ogmo00?o000009VIV@2IVIT0102IVIT2o`000080Ogmo
0_l0000206IVIP04o`00001<C4`0C4a<o`000080<c<c00?o000001TI6@0I6AT00P0I6ATW00000080
6ATI00<0000003<c<`0000000`000002o`0000030<c<c?l0003o000000<0oooo1?l00003000000Co
oooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`?o00001oooool01P0E@Kh0
<63A031Pd@0H@Kd003g101Dm^P80DGcN0P23PLP20;7>k`0408oSW`3XbKL0h[b`0>:l/080g[>]00<0
gkV`0=fc[@3L/J/00P3L/J/0103M/:T0f[Bb0=bd/03L];020=fd[P80f;Vj0`3J^KP01@3K^[L0d;k9
0=6na`3A_/L0dkk60080`l3G0P34`=L00`2e_n80][oQ0;Joh@020:jniP030:Zmi`2[_NL0ZkgW00D0
ZKgX00<0CdNX07iQYP1nHJH00`2KLZ<30:enX@040;R7X@35Tj80aI>R0<FCXP80h:jS00@0n<nO0?;S
O@2Y[=T0ZJcI0`2Y[]/0102Y[m`0Z:7>0:VSd@2YXm430:VVd`030:VXeP2XVLL0ZIg:0080ZIg:0P2Y
X<d00`2WT[l0YYC30:JD``030::Ea`80UY3;0P1jPLh204ENb00501A5`P007:H04S:`01lc[00`?k40
0P1;C;4206eR]080QG:f00L0NW:n0=B_/`3D[k<0e:nc0=Ja]03f^8Go00000080n;Z300d0n[b10?^n
OP3m`G/0o/=h0?o6M03ob6l0o<aW0?W>I03fd680l]=R0?3LK`3hi8D0o>:S0080k/BW00D0ikj[oooo
ooooooooooooo`00000@ooooo`002Oooool01@00003oooooooooooooool000000080<c<c00@00000
04a<C0000000IVIV0P0000001@2IVIWo00000;>c/`2c/k?o000000@0c<c<00Go00000;>c/`2c/k?o
000009VIV@020000000406IVIP000000C4a<00000080<c<c00<0000001TI6@0I6AT09000000301TI
6@04o`00000c<c<0<c<co`0000<0C4a<00?o000006IVIP1VIVH00_l000000`1oOgoo0000o`000004
o`0000<0Ogmo00Go000006IVIP1VIVH0IVIVo`00000204a<C004o`00000c<c<0<c<co`0000@06ATI
9`00000301TI6@030000000c<c<0000000<000000_l000000`3<c<co0000o`0000030?ooo`Co0000
0`000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0000[ooooo
00L0002>01E1_P0`H=40<63A01QdhP00?L405Cfj00<0DGcN00D0/Lk_0>oN`03XbKL0j<Vg0>:l/003
0=jc[@80gK>]0P3L/J/20=f`Z@80g;B`0`3M]:h0103O]:d0f;Vj0=Zi^03J^KP20=^j]`050=fj]P3A
_/L0dkk60=>naP3D_lD00`34`=L00`35`MH0][oQ0;Noh@030:jniP<0ZkgW0`2Y_NP0102Y_>L0CdNX
04m7Z01nHJH409]bX`80[GjQ1035Tj820>2^X`030?S?W`3bhgd0ZJcI0080ZJcI00<0ZJkK0:RNc02X
XLh00P2XXLh20:VSd@030:VVd`2WU/@0Z9W70080Z9W700<0ZIg:0:N?_02WT[l00`2WT[l20:JD``80
XYG700@0UY3;09J3_01oM[l0OgJo0P15G/P01@01=;L001bV000LYP0B<[00<3na0080Bdba00<0LVFe
06eR]025L[H00P25L[H0102ZC000e:nc0=Ja]03F/K@20?JhQ@0@o`00003j_840n[b10?^nOP3m`G/0
o/=h0?o6M03ob6l0o<aW0?W>I03fd680l]=R0?3LK`3hi8D0o>:S0>k4Y`80ikj[00D0lLj^oooooooo
ool0]nfIo`00000?ooooo`002Oooool02`00003oooooooooooooool06ATI0000000c<c<0000004a<
C0000000IVIV0080000000D0VIVIo`00002c/k<0/k>co`0000050<c<c006o`00002c/k?o000009VI
V@000000Ogmo0P0000001@1<C4`0000003<c<`0c<c<0000000806ATI9000000401TI6@04o`00000c
<c<0<c<co`0000<0C4a<00Go000006IVIP1VIVH0IVIVo`00000807moO`05o`00001VIVH0IVIV06IV
I_l000000`1<C4`01?l00000<c<c03<c<ol0000401TI6BL000000`0I6AT00`000000<c<c00000003
000000?o000000<0i^KVo`00003oool00P3oool4o`0000<000001?ooool00`00003oooooooooo`0@
ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`805e[B0P0`H=4201QdhP04001Qb@1AO=h0
fN?M0>7Bb080gl:l00<0j<Vg0>:l/03N/jd00P3N/jd0103L[jX0g;6[0=baZ`3L/J/20=f`Z@040=j`
Z03L];00gKB^0=fd[P80gkB]00<0h;F[0=Zi^03K^[L00P3K^[L0103M^[H0dkk60=>naP3C_/H20=Bo
a@030<C0e`35`MH0aL7F00<0]koQ00@0[[kV0:jni@2^_^D0ZkgW0P2[_>H30:Zli`04000BV`1?AjP0
OV6V07iQYP<0Vg:S0P2]OZ440<FCXP040=b/Y@3P[Z<0n<nO0:V[f080ZJcI00H0Yic:0:RNc02XW/`0
Z9k<0:RQcP2VT;h20:NC`@<0YiK400<0Z9W70:J<^@2WSk`00P2WSk`30:NB_`040:JD``2UR;H0XHNi
0:67^@80UX>l0P1oM[l205IL_@0504ENb0007:H001bV000OY@0O<j`00P1;C;42079U]@<0QG:f00D0
NW:n0=B_/`3F/K@0e[6d0?JhQ@020?RjP`0<o`00003j_840nkin0?g1N`3n`gP0olId0?o8K`3lc6L0
nLiT0?K@HP3bdf80n>B50P3lhZ<0203_cK40ikj[0>NnZ`3acZh0m>jI00000?oooooo00003oooool0
00Wooooo00/00000oooooooooooooooo01TI6@000000<c<c0000001<C4`0000006IVIP0200000005
09VIVOl00000/k>c0;>c/ol000001@3<c<`01_l00000/k>co`00002IVIT0000007moO`80000000D0
C4a<0000000c<c<0<c<c0000000201TI6B@0000000?o000001TI6@0I6AT00P0I6AT00ol00000<c<c
03<c<`02o`000080C4a<00Co000006IVIP1VIVH0IVIV2?l0000206IVIP;o00000P1<C4`2o`000080
<c<c00?o000001TI6@0I6AT00P0I6ATW000000@06ATI00<0000003<c<`0000000`000003o`000003
0>KVi_l00000oooo0080oooo1?l00003000000Cooooo00<00000ooooooooool04?ooool00ol0003o
ooooooooo`09ooooo`?o00004_ooool201MJdP0505nSm@2`goL0/=og0;3Om`3Ihmd00P3Qd/P20=o2
_080h[b`0P3N/jd20=b_ZP80g;6[0`3M/:T0103N/:P0gk6V0=fd[P3M]:h20=nd[@040>2eZ`3Q]ZX0
fkZg0=^j]`80gKZf00<0g[^d0=>naP3D_lD00P3D_lD01@3F`<D0aL7F0<K1eP36`MH0]koQ0080]l3Q
00@0[[kU0:jmi@2^_ND0[[gU0P2[_>H0102Z_>L0Z[[U0:Zji@004Y/207iQYP<0Vg:S00<0[GjQ0;R:
Y@35Tj800P35Tj820=b/Y@040?S?W`3bhgd0YiW80:NIb0<0Yic:00<0Z9k<0:F>_02VT;h00P2VT;h2
0:NC`@030:NFa02VRKH0YXbi0080YXbi0P2WSk`20:NB_`030:J7/`2UR;H0YHRf00<0XHNi0P2FPk`2
07mf_`80EUbm00D00Bjb000LYP003Y`07c>/04I;/P0204]</@05079U]@2DO[T0U7ji09An^@2GRlD0
0`3F/K@0103H][H0n;Z30?RjPol000020?^nOP0:0?g1N`3n`gP0olId0?o8K`3lc6L0nLiT0?;CHP3`
eVD0n>B50?cRX`80klfa00@0ikj[0?7>[P3acZh0m>jI0_ooool00ol0003oooooooooo`0=ooooo`00
2Oooool02`00003oooooooooooooool06ATI0000000c<c?o000004a<C0000000IVIV0080000000D0
VIVIo`00002c/k<0/k>co`0000050<c<c006o`00002c/k?o000009VIV@000000Ogmo0P0000001@1<
C4`0000003<c<`0c<c<0000000806ATI9@00000501TI6@04o`00000c<c<0<c<c03<c<`;o000000@0
C4a<o`000?l0003o0000201VIVH2o`0000<0C4a<00Co000003<c<`0c<c<0<c<c0_l0000401TI6BL0
0000100I6AT01P000000<c<c00000000003o0000000000?o000000<0i^KVo`00003oool00P3oool4
o`0000<000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo0ol0000F
ooooo`05000HW01;T^l0Bi;_0;3Om`3Ihmd00P3Qd/P30=o2_0040=^g]@3N/jd0g[>]0=jc[@80g:nZ
00@0fjjX0=baZ`3M/:T0gK2Y0P3N/:P20=naYP040=fd[P3O]:d0h;F[0>2eZ`80hKJZ00@0fkZg0=fj
]P3N^k@0g[^d0P3O_;@01@3D_lD0e/350=K0a@3G`<@0a/7F0080al;E00<0]l3Q0;Noh02g_n000P2^
_ND02@2^^n<0Zk[T0:^ji02[^^@0Z[[U0:Vbg`004Y/0HeN_07iQYP0309]bX`030:enX@2hRZD0^8ZU
0080aI>R0P3L[:D00`3lfZ40YYS70:NIb0020:NIb0030:NLbP2TRkX0YHjl0080YHjl0P2VT;h0102W
Tl40YHJd0:J9]P2VRKH30:J<^@030:N?_02VQK40YXNc0080YXNc0`2UR;H20:67^@80UX>l0`1oM[l0
201FG;d00Bjb000<W0007:H03BVX01lc[016Bk80Bdba0P1bIKD309An^@0409N;a@3F/K@0f;Jf0=Rf
]P80n;Z300d0n[b1o`00003m`G/0oL5k0?k3N03oaW@0o/Y[0?c<I`3icV@0l]=R0?3LK`3hi8D0o>:S
0080klfa00<0iL:d0?7>[P3dkYT00oooool00ol0003oooooooooo`0=ooooo`002Oooool03`00003o
ooooooooooooool06ATI0000000c<c<0000004a<C0000000IVIV0000001oOgl00000o`0000020;>c
/`03o`00003<c<`0c<c<00<0c<c<00go00000;>c/`2c/k?o00000000001oOgl0000006IVIP000000
C4a<0000000c<c<0000000<06ATI9@00000501TI6@03o`00000c<c<0<c<c0080<c<c00Co000004a<
C01<C4`0C4a<2?l0000404a<C005o`00000c<c<0<c<c03<c<ol000001@0I6ATV00000003o`00000I
6AT06ATI00806ATI00@0000003<c<`000000C4a<0`000004o`0000@0oooo00?o00000>KVi_l00000
0_l000000`000000IVIV00000003ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool0
0oooool3o`0001[ooooo00<0046o09:om@2haN@00P2haN@00`3Qd/P0gl:l0=o2_0020=^g]@80g[>]
0P3L[jX20=^^Z0<0gK2Y0P3N/:P20=naYP80gkB]00@0h;F[0>6fZP3Q]ZX0hKJZ0P3M^[H20=jk]080
gkbd0`3F`<D00`3G`<@0el740<O2e@020<O1e0040;Noh02g_Mh0]kgN0;NmgP80[[_S00D0Zk[T0:Zb
gP2Z/]h0ZK;O000BV`0206=G[`80Vg:S00D0WWZ[0;R:Y@2hRZD0^8ZU0<FCXP030=b/Y@050?cJX@2V
V<L0YiW80:NIb02SRKP00`2TRkX20:F>_0040:J@_P2TQ;80YHJd0:F6]0<0YXVf0P2VS;T30:J5/@<0
YXNc0P2UR;H0102QQkT0Wgb]09Mh[`2GN:l308I^/00606eN/@1FG;d00Bjb000<W0007jD03BVX0P16
Bk82079U]@<0U7ji00T0Uh_50=Ja]03H][H0f;Jf0=^k^03h^X<0n[b10?^nO_l000000P3n`gP01`3o
aW@0o/Y[0?c<I`3icV@0l]=R0?STQ@2]_^H00P3_cK420>G2]0030?7>[P3dkYWooooo00;ooooo00?o
0000ooooooooool03Oooool000Wooooo00l00000oooooooooooooooo01TI6@000000<c<c0000001<
C4`0000006IVIP000000Ogmo00000?l000000P2c/k<00ol00000c<c<0<c<c0030<c<c00=o`00002c
/k<0/k>co`0000000000Ogmo0000001VIVH0000004a<C0000000<c<c0000000301TI6BH000001@0I
6AT2o`0000<0<c<c0ol0000904a<C0?o00000`0c<c<00ol000006ATI01TI6@0401TI6@03o`000000
0000000002<000001@0I6AT010000000<c<c0000001<C4`3000000Co0000103oool00ol00000i^KV
o`000002o`0000030000001VIVH0000000?ooooo00<00000ooooooooool03oooool01?l0003ooooo
ooooooooool3o`0001kooooo0`2haN@20<>kd`060=o2_03K]kD0fkNe0=^g]@3G/;00g[>]0P3L[jX2
0=^^Z0040=b]Y`3M/:T0gK2Y0=j`Z0<0gk6V00<0hK:V0=nd[@3P]J/00`3Q]ZX00`3S]jT0gKZf0=jk
]0030=nl]0050>6m/`3F`<D0el340=O0a03G`L@00`37`M@20<Nod`030;NmgP2f]]T0[K?M0080[K?M
00H0Z[;N0:RTdP2WY=<0YjCC000BV`1SEjl309ijZ`<0^8ZU00H0aI>R0=b/Y@3L[:D0o=ZQ0;;5A`2S
QkL40:>9^080Y8^j00@0YHjl0:>2/02TQ;80Y8Bb0`2UQ[@20:J9]P030:J<^@2UPjl0YH>_0080YXFa
0`2VQk<0102UR;H0Xgj[09ml[@2OO:d209Mh[`<0QVj`0P1]G[400`0N>;8000RI000>W00200dYZ007
04I;/P1kKkX0Nfnj07]_^P2DO[T0ZI:n0;V/c@020=Rf]P<0fk^h00@0n[b10?^nOP3m`G_o00000P3o
aW@0103lc6L0nLiT0?K@HP3`eVD30:fniP040>o=/@3U`[@0iL:d0=7ZQ@Cooooo00?o0000oooooooo
ool03Oooool000Wooooo00l00000oooooooooooooooo01TI6@000000<c<c0000001<C4`0000006IV
IP000000Ogmo00000?l000000P2c/k<00ol00000c<c<0<c<c0030<c<c00=o`00002c/k<0/k>co`00
00000000Ogmo0000001VIVH0000004a<C0000000<c<c0000000301TI6BH0000000?o000001TI6@0I
6AT0100I6AT2o`0000@0<c<c0ol0000304a<C0?o0000100c<c<2o`0000H06ATI9P00000601TI6@04
0000000c<c<0000004a<C0<000001?l000040?ooo`03o`00003Vi^Ko000000;o000000<0000006IV
IP0000000oooool00`00003oooooooooo`0?ooooo`Co00008_ooool0102haN@0`k_C0<>kd`33^m<3
0=^g]@80ek2`00<0eZb^0=b_ZP3L[jX00P3K[ZP20=b]Y`80g[2X0P3O/JH20>6bYP80h;F[0P3Q]ZX2
0>>gZ@040>BhZ@3N^k@0gkbd0=nl]080hKfc00H0h[jc0=O0a03G`L@0el740=S1``37`M@30<Nod`<0
][KI00<0[K?M0:^VdP2XY=800P2XY=80102WY=<001:K06=G[`1SEjl209ijZ`<0^8ZU0`3L[:D0103l
fZ40XhNg0:>7]`2SQkL30:>9^0040:B;^P2RP:h0Xh:`0:>2/0<0Y8Bb0P2UQ[@00`2VRKH0YH6]0:F3
[`020:F3[`<0YXFa00@0YXNc0:AnZP2SOZ/0Xgj[0`2OO:d209Mh[`<0QVj`00@0KEja01hh/P0029T0
00bL0P0=:JP01016Bk80Nfnj07]_^P1kKkX30:VB_P030;V/c@3H][H0fk^h0080fk^h00X0n[b10?^n
OP3m`G_o00000?o6M03ob6l0o<aW0?W>I03fd680D6O<0P2]_^H20:fZe0030>G2]03`ekP0dNZ500Co
oooo00?o0000ooooooooool03Oooool000Wooooo00l00000oooooooooooooooo01TI6@000000<c<c
0000001<C4`0000006IVIP000000Ogmo00000?l000000P2c/k<00ol00000c<c<0<c<c0030<c<c00=
o`00002c/k<0/k>co`0000000000Ogmo0000001VIVH0000004a<C0000000<c<c0000000301TI6BP0
00001`0I6AT00ol00000<c<c03<c<`0403<c<`?o00001P0c<c<00ol000006ATI01TI6@0501TI6BH0
00001P0I6AT00`000000<c<c0000000204a<C0<000001?l000040?ooo`03o`00003Vi^Ko000000;o
000000<0000006IVIP0000000oooool00`00003oooooooooo`0?ooooo`;o00009?ooool2025WfP04
0<>kd`33/LP0`k780=^g]@<0ek2`0P3F[:h20=^^Z0<0g:fW0P3N/:P20=naYP80hK:V00@0h[>U0>6f
ZP3Q]ZX0hKJZ0P3S]jT00`3T^:T0gkbd0=nl]0030>6m/`030>:n/`3S_k<0el740080f<730P3H`<<0
1@37_m<0aK[@0<Fjd02f]]T0/ZW?00<0ZjKB00@0Z:CB0:BB`P2TT/80Y9;20P1SEjl309ijZ`80^8ZU
00D0dJZ`0=b/Y@3L[:D0o=ZQ0::6]P030:>7]`040:>9^02QOZd0XX2^0::0[P<0Xh:`0P2TQ;80102U
Q[@0Y7n[0:F1[@2UPJd30:F3[`<0YXFa0P2TOZX30:=nZ`80Wgb]0P2GN:l308I^/00806eN/@1<Bjl0
7SRb0008V@003Y`03BVX04=>]`16Bk8307]_^P80ZI:n00@0a[340=^k^03K^kP0fk^h0P3P`[X02@3k
_Wh0oL5k0?k3N?l00000olQ_0?c<I`3icV@0l]=R04]lh0030:fZe0030;[<j03`ekP0dNZ500Kooooo
00?o0000ooooooooool03?ooool000Wooooo01800000oooooooooooooooo01TI6@000000<c<c0000
001<C4`0000006IVIP000000Ogmo0000002IVIWo00000;>c/ol000050<c<c005o`00002c/k<0/k>c
o`00002IVIT00P0000001P1VIVH0000004a<C0000000<c<c000000<06ATI:@00000701TI6@?o0000
2P0c<c<2o`0000L06ATI9@0000000ol000006ATI01TI6@0401TI6@05o`00000c<c<0<c<c0000001<
C4`00P0000000`1oOgl00000o`000003o`0000@0oooo00?o00000>KVi_l000000_l00003000000?o
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`05025WfP33/LP0`k780<>a
b031Z/<00P3G/;030=J/[P80fjjX0`3L[JL00`3M[ZH0gk6V0=naYP020>6bYP80h[>U0P3Q]ZX20>>g
Z@80i;RY00@0iKVX0=nl]03Q_K<0hKfc0P3R_[<20>>o/`070=S1``3H`<<0f<330=S0``3E_L80aK[@
0;n^b@030;:Yc`030:^VdP2VU<80Y9;200<0Y9;200<001ZX06=G[`2NNZ/00P2NNZ/01@2hRZD0dJZ`
0=6Z/03AZ[00o=ZQ0080XXJf0P2SQkL00`2POJ`0XGj]0:5n[@030::0[P80Xh:`0P2TQ;820:AoZ`<0
YH6]0`2UPjl00`2VQK40Y7fX0:AnZP020:AnZP80Xgj[0P2OO:d209Mh[`<0QVj`0P1]G[401P1<Bjl0
01^T0002U0008JL03BVX04=>]`<0Nfnj00D0ZI:n0<J`a036/<@0imK40=^k^0030>32^P070>K;_03m
`G/0o/=h0?o6M?l00000o<aW0?W>I00206Z1e`0404]lh02]Z]@0^/cX0;[<j0Sooooo00?o0000oooo
ooooool03?ooool000Wooooo01800000oooooooooooooooo01TI6@000000<c<c0000001<C4`00000
06IVIP000000Ogmo0000002IVIWo00000;>c/ol000050<c<c005o`00002c/k<0/k>co`00002IVIT0
0P0000001P1VIVH0000004a<C0000000<c<c000000<06ATI:`00000801TI6@[o00001`0I6ATW0000
00L06ATI00D0000003<c<`0c<c<0000004a<C0020000000307moO`00003o000000?o0000103oool0
0ol00000i^KVo`000002o`0000<000000oooool00`00003oooooooooo`0Booooo`03o`000?oooooo
oooo02;ooooo00<08V3E0<>ab031Z/<00P31Z/<01P3G/;00eZb^0=J/[P3F[:h0eJ^]0=^^Z080g:fW
0P3M[ZH20=naYP80hK:V0P3R/jD0103T]:@0hKJZ0>>gZ@3S]jT20>BhZ@050>FiZ03V^ZP0i[ZX0>6m
/`3R_[<00`3S_k<01@3S`;<0f<330=S0``3H`<<0eKg200<0_jk900<0/ZW?0:bG`P2VU<800P2VU<83
0:BB`P0309n2]0006ZP0HeN_0080WWZ[00L0^8ZU0=6Z/03AZ[00dJZ`0?3f[P2RQ[H0Wgb[00<0X7f/
0`2QOZd20::0[P80Xh:`00<0Y8Bb0:=mZP2TOj/00P2TOj/20:F1[@80YH>_00<0Y7bW0:AmZ02TOJP0
0`2TOZX20:=nZ`0409ml[@2MMJD0Ug6V09MaYP<0S6ZV00<0OF6W06eN/@1<Bjl00P006j@2000QY`04
04=>]`2<Pl@0S8?408b3a0<0a[3400@0imK40>32^P3P`[X0h<:j0P3Vbk`01P3/e[d0o/=h0?o6M03n
bV_o00000?W>I0Cooooo00<0^/cXooooooooool01oooool00ol0003oooooooooo`0<ooooo`002Ooo
ool04P00003oooooooooooooool06ATI0000000c<c<0000004a<C0000000IVIV0000001oOgl00000
09VIVOl00000/k>co`0000D0c<c<00Go00000;>c/`2c/k?o000009VIV@020000000606IVIP000000
C4a<0000000c<c<000000`0I6AT]000001H06ATI9`00000701TI6@060000000c<c<0<c<c03<c<`00
0000C4a<0P0000000`1oOgl00000o`000003o`0000@0oooo00?o00000>KVi_l000000_l000030000
00?ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`04029Pe@31Z/<0`J[3
0<6Z``<0eZb^0P3EZjd30=b]Y`80gJjV00@0gZnU0=naYP3Q/ZH0hK:V0P3R/jD01@3T]:@0iKFT0>>g
Z@3S]jT0i;RY0080iKVX0P3V^ZP00`3X_:P0h[jc0>>o/`020>>o/`80hl2c00H0f<330=Fm`P3E_L80
d;Bn0;n^b@2gW[l30:bG`P80YYC200P0Y9;209n3]02OP[@0Wh:d09n3]0006ZP0WWZ[0:FKb`@0dJZ`
00@0l?J^09mlZ`2OO:/0Wgb[0`2POJ`20:5n[@80XX2^00@0Xh:`0:=lZ@2SOJX0XgfZ0`2TOj/20:F1
[@<0Y7bW0`2TOJP20:AnZP040:=nZ`2QMj@0WGFU09eeY@80Ug6V0`2<JZH207eQY`80C4^_00D001^T
0001U0008JL0A5W304=>]`0308b3a0050<J`a03We/@0mnn]0>[WP@3P`[X00`3Vbk`01@3/e[d0lnBl
0?o6M03nbV_o000000oooooo00?o0000ooooooooool03?ooool000Wooooo00H00000oooooooooooo
oooo01TI6@00000203<c<`0:0000001<C4`000000000001oOgl0000009VIVOl00000/k>co`0000D0
c<c<00Go00000;>c/`2c/k?o000009VIV@020000000606IVIP000000C4a<0000000c<c<000000`0I
6AT`000001806ATI9P0000000ol000006ATI01TI6@0501TI6@080000000c<c<0<c<c03<c<`000000
C4a<0000001VIVH200000003o`00002c/k?o000000;o0000103oool00ol00000i^KVo`000002o`00
00<000000oooool00`00003oooooooooo`0Dooooo`;o00008_ooool200i?b`040<6Z``2nY/00_ZK0
0=J/[P<0eJ^]0P3L[JL20=f^YP80gZnU0P3Q/ZH20>:cY@80i;BT0P3U]J@20>BhZ@050>FiZ03V^ZP0
i[ZX0>JjZ03X_:P00`3S_k<30>?0/`040>:n/`3E_L80d;Bn0=2d_P<0]ijo00@0[9O20:F8]P2QQ;D0
XHBe0P2OPk@309n2]004000JZ02UVl/0YI_;0:FKb`80dJZ`00<0l?J^09mkZ`2ONj/00P2OO:/30:1m
[080XGj]00@0XX2^0:9jZ02SO:T0XgbY0`2SOJX20:AoZ`030:F1[@2TO:L0Y7bW0080Y7bW0`2TOJP2
0:AnZP80XGNT0`2MMJD209MaYP80S6ZV0P1mHJL01`1]EjP0C4^_038m[P006j@0006D000QY`14FL<0
0P2<Pl@20:VVd`040>OFa03gkjd0mnNc0>G0/P80i/^l0P3/e[d01@3ci;`0mO2e0<k[Q`2OcV;o0000
00kooooo00?o0000ooooooooool03?ooool000Wooooo00H00000oooooooooooooooo01TI6@000002
03<c<`0:0000001<C4`000000000001oOgl0000009VIVOl00000/k>co`0000D0c<c<00Go00000;>c
/`2c/k?o000009VIV@020000000606IVIP000000C4a<0000000c<c<000000`0I6ATc000000`06ATI
0P0000000ol0000000000000000T000000H06ATI00<00000o`00000c<c<00`0c<c<010000000C4a<
0000001VIVH200000003o`00002c/k?o000000;o0000103oool00ol00000i^KVo`000002o`0000<0
00000oooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo00D03To;0;jV`02n
Y/00_ZK00=J/[P030=F[[@040=J[[@3L[JL0gJjV0=f^YP80gZnU00@0h;2U0>6bYP3R/jD0h[>U0P3T
]:@20>FeY080i;RY00<0iKVX0>JjZ03V^ZP00P3X_:P00`3Y_JP0hknc0>>o/`030>?0/`050>:n/`3@
];h0d;Bn0=2d_P37YkT00P2gW[l20:F8]P80XHBe0`2OPk@209n2]00609n3]0006ZP0YI_;0:FKb`3A
Z[00WWZ[0`2ONj/209mlZ`<0X7f/00@0XGj]0:5iY`2RNZP0XWZX0`2SO:T20:=mZP80Y7n[1P2TO:L2
0:AmZ0040:AnZP2RN:@0XGNT0:5gY0<0WGFU0P2GLJH308aZYP80OF6W00D0KENX038m[P0b?Jh001VV
000NZ@0204AI``<0ZJKC00L0d]_O0>_gZ03gik<0iL2b0=R^[@3Vbk`0k=Jm0080lnBl00D0mO2e09o>
H_ooooooooooo`00000=ooooo`03o`000?oooooooooo00cooooo0009ooooo`0600000?oooooooooo
ooooo`0I6AT000000P0c<c<020000000C4a<000000000000Ogmo0000002IVIWo00000P2c/k<00ol0
0000c<c<0<c<c0020<c<c005o`00002c/k<0/k>co`00002IVIT00P0000001P1VIVH0000004a<C000
0000<c<c000000<06ATI=P00000601TI6B/000001P0I6AT00`000000<c<c03<c<`0303<c<`050000
001<C4`0C4a<0000001VIVH00P0000000ol00000/k>co`000002o`0000@0oooo00?o00000>KVi_l0
00000_l00003000000?ooooo00<00000ooooooooool05oooool00ol0003oooooooooo`0Oooooo`04
000c^`0>Cl/0_ZK00;jV`0<0eJ^]0P3FZjd00`3L[JL0gJjV0=j_Y@020=j_Y@050>2`Y@3Q/ZH0h[>U
0>:cY@3T]:@00`3U]J@00`3V]j<0iKVX0>FiZ0020>JjZ080j;bX00<0jKfX0>VoZ03S_k<00P3S`;<2
0>:n/`060=fh/`3@];h0ajNi0<NW^@2gW[l0[Xne0`2UR;H20:64]@80Wh>d00H0Wh:d09ai[02LNJ/0
W7V[0:FKb`2MNJ/209ijZ`<0Wg^[0`2OO:/0102POJ`0X7RW0:5iY`2QNJL20:9jZ0<0XgbY0P2SOJX0
0`2TOj/0Y7^V0:AkYP050:AlY`80Y7fX0P2RN:@30:5gY080WGFU0P2GLJH308aZYP80OF6W0P1]EjP0
0`0b?Jh0=4Ri000IYP0304effP040:VVd`3Bfml0d]_O0?OW/`80iL2b00H0f:j]0=1U003/e[d0lnBl
0?G`]@3>jhL4ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool000Wooooo
00H00000oooooooooooooooo01TI6@00000203<c<`080000001<C4`000000000001oOgl0000009VI
VOl000020;>c/`03o`00003<c<`0c<c<0080c<c<00Go00000;>c/`2c/k?o000009VIV@0200000006
06IVIP000000C4a<0000000c<c<000000`0I6AUV000000H06ATI00<0000003<c<`0c<c<00`0c<c<0
10000000C4a<04a<C000000206IVIP80000000?o00000;>c/ol000000_l000040?ooo`03o`00003V
i^Ko000000;o00000`000003ooooo`0300000?oooooooooo01Sooooo00?o0000ooooooooool07ooo
ool01@00<k/0_ZK00;bS`02lXl00eJ^]00<0eZ^]0P3M[ZH20=j_Y@80h;2U00@0h[:U0>:cY@3R/jD0
i;BT0P3U]J@20>JgX`030>RhX`3V^ZP0i[ZX0080j;bX0P3Y_JP00`3Y_jP0j/2Y0>?0/`020>:n/`80
gKRc0`37YkT30:j?]@80YHRf0P2QQ;D0102OPk@0VgV/09ai[02LNJ`209aiZ`<0WGV[0P2NNZ/309mk
Z`80Wgb[0P2PN:L20:5iY`<0XWZX0P2SO:T00`2SOJX0Y7ZV0:AkYP020:AkYPD0Y7bW00@0Y7fX0:=h
X`2RN:@0XWRT0`2QMj@309eeY@80Ug6V0P2<JZH207eQY`80KENX00@0IEF[038m[P0dB;T035?>0`1=
M]X0103Bfml0joNX0?OW/`3U`;830=R^[@030??T_03el;D0k?JU00Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooool201TI6@0:0000
000c<c<0000004a<C0000000IVIV0000001oOgl00000o`000080/k>c00?o00000<c<c03<c<`00P3<
c<`01ol00000/k>c0;>c/ol00000VIVI0000001oOgl00P0000001@1<C4`0000003<c<`0c<c<00000
00806ATII00000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00<0<c<c00/0000004a<
C01<C4`0C4a<o`00001VIVH0000007moO`00003o00000;>c/`03o`0000@0oooo1?l0000200000003
06IVIP00003ooooo00;ooooo00<00000ooooooooool06Oooool2o`0001oooooo00D003>k0;bS`02l
Xl00_:?00=F[[@030=J[[@040=N/[@3M[ZH0gZnU0=j_Y@80h;2U0P3R/ZD20>BdY080iKFT0P3V]j<0
0`3X^:<0jKZS0>JjZ0020>RlZ0040>VmZ03Y_jP0jKnX0>[0Z@80jKnZ00D0h[jc0=fh/`3M^;<0eJna
0<NW^@020;bI/`80[Xne00@0YHRf09mn[P2LNjd0W7^]0P2KNJ`209ai[0<0W7V[0P2MNJ/209ijZ`<0
Wg^[00@0Wgb[09mgYP2PN:L0X7RW0`2QNJL20:9jZ080XgbY0P2TNZH30:AkYPD0Y7bW0P2SN:<30:9h
Y080XGNT0`2MMJD209MaYP80S6ZV0`1mHJL00`1]EjP0IEF[06EEZ`0203A8^@0300aCcP1/[_P0Z^?j
0080dM?K0P3U`;820=R^[@030>S5/@3T`;?ooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooool201TI6@0:0000000c<c<00000
04a<C0000000IVIV0000001oOgl00000o`000080/k>c00?o00000<c<c03<c<`00P3<c<`01ol00000
/k>c0;>c/ol00000VIVI0000001oOgl00P0000001@1<C4`0000003<c<`0c<c<0000000806ATII@00
000501TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`010000000IVIV0000
001oOgl2o`0000040;>c/ol0003o0000o`0000@0oooo1?l000020000000306IVIP00003ooooo00;o
oooo00<00000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03000c^`2lXl00_:?000<0
eZ^]0P3G[:d30=j_Y@80h;2U0P3R/ZD20>BdY080iKFT00D0i[NS0>RhX`3X^:<0jKZS0>^lY0020>Rl
Z0040>VmZ03Y_jP0j/2Y0>[0Z@80jKnZ0P3M^;<20=F_/@<0_9Vc00@0[Xne0:N4[`2OOZh0Wgj^0P2L
Njd309]i[080W7V/0P2LNJ/209eiZ`80WWZ[0P2ONj/00`2NMjH0WgNV09mgYP030:1hY`80XGVW0P2R
NZP0102SO:T0XgVU0:AjYP2TNZH40:AkYP<0Y7bW0`2SN:<30:9hY080XGNT0P2MMJD00`2MLZ80V6nS
09Q_X`0208mZX`<0QFBT0P1]EjP00`1UEJ/0LVBc079T/`0206j2eP<0dM?K00H0bjfl0>G0/P3H[Zd0
f:j]0>S5/@000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool000Wo
oooo00@00000oooooooooooooooo0P0I6AT02P000000<c<c0000001<C4`0000006IVIP000000Ogmo
00000?l000020;>c/`03o`00003<c<`0c<c<0080c<c<00Oo00000;>c/`2c/k?o000009VIV@000000
Ogmo0080000000D0C4a<0000000c<c<0<c<c0000000201TI6F@000001P0I6AT010000000<c<c03<c
<`0c<c<2000000@0C4a<00P0000006IVIP1VIVH0000007moO`00003o00000;>c/`?o0000103oool4
o`000080000000<0IVIV00000?ooool00_ooool00`00003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00<0_:?00;VS`P2iXl800P3FZjd20=N/[@040=R^[@3N[jD0gZnU0>2`Y@<0h[:U00<0
hkBU0>FeY03U]J@00P3V]j<20>RhX`030>VjX`3[_:@0jkbT0080jKfX00<0jKnX0>[0Z@3Y_jX00P3Y
_jX0103V_:/0gKRc0=F_/@3E[k430;bI/`80YhB_0`2OOZh209ak[@80VgV/0P2LNJ`209aiZ`0409ei
Z`2LMJL0WGJV09efYP<0WWNV0`2OMjH20:1hY`80XGVW00@0XWZX0:9iY@2SNJD0XgVU0`2TNZH30:Ak
YP030:AlY`2SN:<0XgRS00@0XgRS0P2RN:@20:5gY0<0WG:R0P2HKj<208mZX`<0QFBT00<0OEnV06eG
Z01UEJ/00`1bI;<206j2eP030=7Cf`3;[K`0bjfl0080f:j]0P3XaK4;ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo0P0I6AT02`00
0000<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIWo00000080/k>c00Go00000<c<c03<
c<`0c<c<o`0000020;>c/`04o`00002IVIT0000007moO`80000000D0C4a<0000000c<c<0<c<c0000
000201TI6F<000001P0I6AT01@000000<c<c03<c<`0c<c<0000000D0C4a<00T0000006IVIP1VIVH0
IVIV0000001oOgl00000o`00002c/k<00_l000001P3Vi^Ko00000?ooo`3ooooo00000>KViP?o0000
0`000004ooooo`0300000?oooooooooo01gooooo00?o0000ooooooooool07?ooool40;VS`P030=J[
[@3G[:d0f:j]0080f:j]0P3P/:D20>:bY@80hkBU0P3U]J@00`3V]j<0j;RS0>RhX`020>VjX`80jkbT
00@0k;jT0>VoZ03Y_jP0j/2Y0P3Y_jX20>JlZ`80eJna0P3<Xjl20;bI/`<0YhB_0P2OOZh209ak[@80
VgV/0P2LNJ`0102LNJ/0VgFW09aeY`2LMJL309efYP80WWNV0`2OMjH20:1hY`80XGVW0P2RNJD30:=i
Y@80Y7ZV0P2TNjH00`2TN:<0XgRS0:=hX`050:=hX`80XWRT00<0XGNT0:1dXP2MLZ800P2MLZ8209Q_
X`<0SfZS0P25I:@207eOYP80IEF[0P1bI;<209Z7_@<0bjfl00@0b::b0=R^[@3XaK4000002oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
ooooo`806ATI00/0000003<c<`000000C4a<0000001VIVH0000007moO`000000VIVIo`0000020;>c
/`05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01?l00000VIVI0000001oOgl20000000504a<C000
0000<c<c03<c<`0000000P0I6AUQ00000003o`00000I6AT06ATI00<06ATI00<00000o`00000c<c<0
0P0c<c<00ol00000C4a<04a<C00204a<C0800000101VIVH01@000000Ogmo00000?l00000/k>c00;o
000000H0i^KVo`00003oool0ooooo`00003Vi^H3o`0000<000001?ooool00`00003oooooooooo`0N
ooooo`;o00007Oooool20;VS`P030;NTaP3G[:d0ejb]00<0f:j]0P3P/:D20>:bY@80hkBU00<0iKJU
0>FeY03V]j<00P3X^:<01P3Y^Z<0jkbT0>^lY03[_:@0k;jT0>g1Y@80j/2Y0P3Y_jX20>JlZ`050>2e
[03E[k40c:>_0<bS[`2lVK<00P2dSZl20:N4[`80Wgj^0P2LNjd0102KNJ`0VGFY09UeZ02IMJP209]e
Y`<0W7FW0P2MMZH309igYP80WgNV0P2PN:L0102QNJL0XWRU0:9iY@2RNJD30:=iY@80Y7ZV00<0Y7^V
0:AhX`2TN:<01`2SN:<20:9hY0<0X7BR0P2MLZ8209Q_X`<0SfZS0P25I:@207eOYP0307eRZ@1UEJ/0
LVBc0080LVBc0P2JQkd00`3;[K`0b::b0<RR/P020>S5/@gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooool201TI6@0;0000000c<c<0
000004a<C0000000IVIV0000001oOgl0000009VIVOl000000P2c/k<01Ol00000c<c<0<c<c03<c<co
00000080/k>c00Co000009VIV@000000Ogmo0P0000001@1<C4`0000003<c<`0c<c<0000000806ATI
HP00000501TI6@050000000c<c<0<c<c03<c<`000000101<C4`00`000000IVIV06IVIP0306IVIP06
0000001oOgl0Ogmo00000?l00000/k>c0_l000001P3Vi^Ko00000?ooo`3ooooo00000>KViP?o0000
0`000004ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool06_ooool40;NTaP050=N/
[@3H[Zd0f:j]0=R^[@3J/:h00P3R/ZD20>>dY@80iKJU00D0ikRU0>JgX`3X^:<0j;RS0>VjX`020>^l
Y080k;jT00@0kL6U0>k3YP3Y_jX0jKnZ0P3V_:/20>2e[0<0c:>_0`2dSZl20:N4[`0409mn[P2KNJ`0
VGJ[09UfZ`80VGFY0P2IMJP209]eY`<0W7FW0P2MMZH309igYP80WgNV00@0X7RW0:5hY@2RN:D0XWRU
0`2RNJD20:=iY@80Y7ZV0`2TN:<70:=hX`030:9hY02RMZ80X7BR0080X7BR0`2MLZ8209Q_X`80SfZS
0P25I:@207eOYP80OF:Y0`1bI;<00`2JQkd0Zh^c0<RR/P020<RR/P030>70^03XaK7ooooo00gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooo
ooooool201TI6@030000000c<c<000000080C4a<0P000000101oOgl0000009VIVOl000030;>c/`03
o`00003<c<co000000<0/k>c00Co000009VIV@000000Ogmo0P0000001@1<C4`0000003<c<`0c<c<0
000000806ATIHP00000401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`2000000D0IVIV00L0
000007moO`1oOgl0Ogmo00000?l00000/k>c00;o00000P3Vi^H2o`000080i^KV0ol00003000000Co
oooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`<0]jC60`3H[Zd20=Z`[P80
h[:U0P3S]:D20>FfY@050>NhY@3X^jH0j;RS0>RhX`3Y^Z<00P3[_:@01P3/_Z@0kL6U0>g1Y@3^`jH0
k/BW0>VoZP80i[b[0P3P]J`00`3G[:`0c:>_0<bS[`030;B>[`040:N4[`2RP:h0VgV/09]i[080VGJ[
0P2IMJT209UeZ0<0VgFW0P2LMJL309efYP80WWNV00@0WgNV09mgY@2QN:D0XGRU0`2RN:D20:9iY@80
XgVU00<0Y7ZV0:=iY02TN:<00P2TN:<60:=hX`@0XWJR0P2PM:8309ebXP80V6nS0P2?JZ<308ETY003
07eOYP1mHZT0OF:Y00<0S76_0`2[Rk<00`38X[80hL2h0>70^00@ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo0P0I6AT01`000000
<c<c03<c<`000000C4a<0000001VIVH00P00000209VIV@05o`00002c/k<0/k>c0;>c/ol00000102c
/k<01?l00000VIVI0000001oOgl20000000504a<C0000000<c<c03<c<`0000000P0I6AUQ000000@0
6ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVH0IVIV00D0IVIV00`0000007mo
O`1oOgl0Ogmo00000?l00000/k>co`00003<c<co00000>KVi_l000030>KViP06o`00003<c<co0000
o`0000000000C4a<1?ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo01[ooooo00@0
]jC60;>Vb`2cY//0f:j]0`3J/:h00`3K/jl0h[:U0>>dY@030>FfY@030>NhY@3X^jH0j;^V0080jKZS
00<0jkbT0>bnY03/_Z@00P3]`JD01P3^`jH0k/BW0>_2Z@3[`ZT0i[b[0>2e[080ejb/00<0c:>_0<>J
[@33VZd00P2dSZl20::0[P80VgV/0P2IMZ/309UeZ@80VGFX0P2KMJL309aeY`80WGJV0P2NMjH209mg
Y@80XGRU0`2RN:D20:9iY@80XgVU0`2SNJ@30:AhX`@0XgRS1@2RMZ820:1dXP<0WG:R0P2HKj<308mZ
X`80QFBT0P1mGjH207eRZ@80S76_0`2[Rk<00`38X[80hL2h0>70^00@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo0P0I6AT01`00
0000<c<c03<c<`000000C4a<0000001VIVH00P00000209VIV@03o`00002c/k<0/k>c00H0/k>c00Co
000009VIV@000000Ogmo0P0000001@1<C4`0000003<c<`0c<c<0000000806ATIH000000401TI6@05
0000000c<c<0<c<c03<c<ol000000`1<C4`00ol00000IVIV06IVIP0506IVIP8000000`1oOgl01P00
003o00000;>c/ol00000c<c<o`0000@0i^KV0_l000001@3<c<co0000o`0000000000C4a<00Cooooo
00<00000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`<0/jK;00<0f:j]0=Z`[P3J/:h0
0P3K/jl20>>dY@80iKJU0P3W^:D20>RkYP040>^nYP3[_:@0jkbT0>bnY080kL6U0P3^`jH00`3^a:L0
jl:Y0>_2Z@020>2e[080ejb/0`33VZd00`2dSZl0[hZ_0::0[P020::0[P80VgV/0P2IMZ/209UeZ@80
VGFX0P2KMJL309aeY`0409efYP2MMZL0WWNV09igYP80WgNU0`2QN:D20:9hY@80XWVU00<0XgVU0:=i
Y02SNJ@00P2SNJ@30:AhX`<0XgRS00<0XgNR0:9fXP2RMZ800`2RMZ820:1dXP<0WG:R0P2HKj<308mZ
X`80QFBT0P1mGjH207eRZ@<0S76_0P2[Rk<20>70^1;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool201TI6@070000000c<c<0<c<c
0000001<C4`0000006IVIP0200000080VIVI00?o00000;>c/`2c/k<01P2c/k<01?l00000VIVI0000
001oOgl20000000504a<C0000000<c<c03<c<`0000000P0I6AUP000000@06ATI00D0000003<c<`0c
<c<0<c<c0000000204a<C0030000001VIVH0IVIV00<0IVIV0`00000507moO`0600000?l00000/k>c
o`00003<c<co0000103Vi^H00ol00000c<c<0<c<c002o`0000030000001<C4cooooo00?ooooo00<0
0000ooooooooool09?ooool2o`0001[ooooo00@0/jK;0:fXd`3J/:h0f[2^0`3K/jl01@3M][00hkBU
0>FfY@3U]ZD0ikRU00<0j;^V00@0jkjV0>c2Y`3[_:@0k;jT0P3]`JD00`3^`jH0k/BW0>_2Z@020>_2
Z@040>JlZ`3P]J`0ejb/0=N/[0<0`iZ]0`2_RZl20::0[P80VgV/0P2IMZ/209UeZ@80VGFX0P2KMJL2
09aeY`0309]fZ02MMZL0WGJW0080WWNV0`2OMjD20:5hY@80XWRU00<0XWVU0:=iY@2SNJ@0102SNJ@3
0:AhX`80XgRS0`2SMj840:9fXP<0X7BR0P2MLZ8209]gZ@<0Tg:Z0P29KJ`207eOYP80OF:Y0`2<LJl0
102[Rk<0ajfo0<N]_`3Q`;PCooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool000Wooooo00@00000oooooooooooooooo0`0I6AT02@000000<c<c0000001<C4`0000006IVIP00
0000Ogmo0000000209VIV@03o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT00P000000101V
IVH0000004a<C000000203<c<`040000000I6AT06ATI01TI6Eh00000100I6AT01@000000<c<c03<c
<`0c<c<000000080C4a<00@0000006IVIP1VIVH0IVIV0`00000707moO`030000002IVIT0VIVI00;o
00000P3<c<`01?l00000i^KV0>KVi_l000020<c<c0?o00000P000004ooooo`0300000?oooooooooo
02Kooooo00?o0000ooooooooool05oooool30:fXd`030=Z`[P3K/jl0fk>_0080gKJ`00@0gk^c0>Ff
Y@3U]ZD0ikRU0P3X^jH20>^nYP030>c2Y`3^aJT0k;jT0080kL6U00@0k/>V0>k4Y`3[`ZT0jl:Y0P3V
_:/20=N/[080cjB/0P33VZd30:n:[`80XX2^0P2KNJ`209UfZ`80VGFY00@0VGFX09MeZ`2IMZT0VGJY
0`2KMZP209efY`<0WWNV0P2OMjD20:5hY@80XWRU0P2SNJD50:=iY0<0Y7RS0P2SN:<30:=gXPD0XWJR
0P2PM:800`2MLZ80XGZX09]gZ@0209]gZ@80Tg:Z0P29KJ`208=//0<0OF:Y00<0S76_0:>>_P37[Kl0
0P37[KlDooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@0
0000oooooooooooooooo0`0I6AT02@000000<c<c0000001<C4`0000006IVIP000000Ogmo00000002
09VIV@03o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT00P000000101VIVH0000004a<C000
000203<c<`040000000I6AT06ATI01TI6Ed00000100I6AT01@000000<c<c03<c<`0c<c<000000080
C4a<00D0000006IVIP1VIVH0IVIV0000000:07moO`030000002IVIT0VIVI00;o00000P3<c<`02?l0
0000i^KV0>KVi_l00000c<c<o`00002c/k?o00000`000004ooooo`0300000?oooooooooo02Oooooo
00?o0000ooooooooool05oooool00`2]Z=<0Y:cM0:B/g@020=^c[`80gKJ`0P3O^k<20>NhY@80j;^V
0P3[_ZH0103/`ZL0k/FY0?39ZP3`bJX20>k3YP030>k4Y`3[`ZT0jl:Y0080i[b[00D0g[B]0=N/[03?
Y:`0cjB/0<>J[@020;jF[P80[hZ_00@0XX2^09n2]02GN[80UgZb0P2EMjl209If[@<0UgF[0P2IMZT2
09]fZ0<0WGJW0P2NMjH209mgY@80XGRU00<0XWRU0:9iYP2SNJD00P2SNJD50:=iY080Y7RS0P2SN:<3
0:=gXPD0XWJR00@0X7BR0:EmZ02QNZP0XGZX0`2KMjT209=bZP80RFf/0P23K;0308Ue]P<0Xhjn0P37
[KlEooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool000Wooooo00@00000
oooooooooooooooo0`0I6AT02@000000<c<c0000001<C4`0000006IVIP000000Ogmo0000000209VI
V@03o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT00P000000101VIVH0000004a<C0000002
03<c<`040000000I6AT06ATI01TI6Ed00000100I6AT010000000<c<c03<c<`00000304a<C0040000
001VIVH0IVIV000000/0Ogmo00<0000009VIV@2IVIT00_l000020<c<c003o`00003Vi^Ko00000080
c<c<00?o00000;>c/ol0000010000003ooooo`0300000?oooooooooo02Sooooo00?o0000oooooooo
ool06?ooool20:B/g@030=^c[`3M][00gk^c0080gk^c0P3W^:D00`3X^jH0jkjV0>^nYP020>c2Y`05
0>k5Z@3`bJX0l<VZ0?7=[@3^a:L00P3[`ZT20>JlZ`80g[B]00<0ejb/0<nT[03?Y:`00`2nUZh0102_
RZl0[Xnf09n2]02OP[@209Mj/P80UGN_0P2FMZd309MeZ`80VGJY0`2KMZP209efY`80WWNV0P2OMjD0
102QN:D0XGVW0:9iYP2RNJH30:=iY@D0XgVT00@0Y7RS0:=iY02SN:<0XgRS0`2SMj850:9fXP80YGfX
0`2QNZP209]gZ@<0Tg:Z0P29KJ`208=//0<0RGFf0P2SS[h00`37[Kooooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo
0`0I6AT02@000000<c<c0000001<C4`0000006IVIP000000Ogmo0000000209VIV@03o`00002c/k<0
/k>c00<0/k>c00Co000009VIV@2IVIT0VIVI0P000000101VIVH0000004a<C000000203<c<`040000
000I6AT06ATI01TI6Ed000000`0I6AT010000000<c<c03<c<`00000304a<C0040000001VIVH0IVIV
000000`0Ogmo00H0000009VIV@2IVIWo00000;>c/ol000020<c<c007o`00003<c<`0c<c<0<c<c?l0
0000/k>co`000004000000?ooooo00<00000ooooooooool0:Oooool2o`0001Sooooo0P2C[nT20=ff
/0<0gk^c00<0h[nf0>RkYP3X^jH00P3[_ZH00`3/`ZL0k/FY0?39ZP020?39ZP040?7=[@3ad:l0k/nc
0>_2Z@80i[b[0P3N]:d30<nT[0030<^R[P2nUZh0_YJ^0080[Xnf0`2OP[@209Mj/P80UGN_0P2FMZd2
09MeZ`80VGJY0`2KMZP209efY`80WWNV00@0WgNU0:1jZ02QNJL0XGVW0`2RNJH20:=iY@@0XgVT00<0
XgVU0:=iY02SNJ@00`2SN:<20:=gXP@0XWJR00<0YWjX0:EmZ02UOJP00`2QNZP309]gZ@80Tg:Z0P29
KJ`208=//0<0RGFf00<0Xhjnooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00[o000003<c<`0c<c<00000
04a<C0000000IVIV0000001oOgl000000P2IVIT00ol00000/k>c0;>c/`020;>c/`0:o`00002IVIT0
VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00@0000001TI6@0I6AT06ATIG0000004
01TI6@04o`00000c<c<0<c<c00000080C4a<00@0000006IVIP1VIVH000003P1oOgl00`000000VIVI
09VIV@02o`0000H0c<c<0_l000000`000000Ogmo00000002000000?ooooo00<00000ooooooooool0
:oooool00ol0003oooooooooo`0Fooooo`80TjoY00<0gKJ`0=nk/`3O^k<00P3R_kH01P3Ta[T0j;^V
0>^nYP3[_ZH0k<:W0>k5Z@80l<VZ0P3acJd01@3ad:l0k/nc0>S9]P3XbKH0i[b[0080g[B]00H0eZf^
0<nT[03;XZh0bj:^0;jF[P2oWKH30:j?]P80Wh:d0P2GN[8209Eg[`80UWJ]0`2GMJ/209UfZ@80VgJX
0P2MMZL0102NMjH0WWZZ0:1jZ02PNZP20:5iY`<0XWVV0`2SNJD20:=iY080XgVU0P2SNJ@30:=hX`<0
XgNR0P2RMZ820:InZ0<0YGfX0P2QNZP309]gZ@80Tg:Z0P29KJ`308=//00308Ue]_oooooooooo01[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01000003ooooo
ooooooooool301TI6@0:0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo00000080VIVI
00Co00000;>c/`2c/k<0/k>c0_l0000209VIV@070000001oOgl0000006IVIP000000C4a<00000002
03<c<`040000000I6AT06ATI01TI6E`000000`0I6AT010000000<c<c03<c<`00000204a<C0040000
001VIVH0IVIV000000@0Ogmo0P00000907moO`060000002IVIT0VIVIo`00002c/k?o0000103<c<`3
o`0000030000001oOgl00000008000000oooool00`00003oooooooooo`0/ooooo`03o`000?oooooo
oooo01Kooooo00<0LZgf0=nk/`3O^k<00`3R_kH00`3Ta[T0i/fm0>K=_@020>c2Y`050>k5Z@3`bJX0
l<VZ0?7=[@3ad:l00P3^ck<20>S9]P80g[B]0P3F[Jh00`3?Y:`0bj:^0<^R[P030;nM]P80[Xnf00@0
Wh:d09RAb`2<QLH0S8G60P2EMjl209If[@<0UgF[0P2IMZT209]fZ00409efY`2LNZ`0WWZZ09ijZP80
X7ZX0`2QNJL20:9iYP<0XgVU00@0XgVT0:=jYP2SNJD0XgVU0`2SNJ@20:=hX`<0XgNR00<0XWJR0:Mo
Z@2VOZP00P2VOZP20:EmZ080XGZX0P2KMjT00`2Who_oooooooooo`0Sooooo`05o`000?oooooooooo
ooooool000002oooool000Wooooo00@00000oooooooooooooooo0`0I6AT02P000000<c<c03<c<`00
0000C4a<0000001VIVH0000007moO`00000309VIV@03o`00002c/k?o000000@0VIVI00L0000007mo
O`000000IVIV0000001<C4`000000080<c<c00@0000001TI6@0I6AT06ATIG000000301TI6@040000
000c<c<0<c<c00000080C4a<00@0000006IVIP1VIVH000000P1oOgl200000080VIVI00<0000007mo
O`1oOgl01P1oOgl01_l00000VIVI09VIVOl00000/k>co`0000@0c<c<00Go00000;>c/ol000000000
07moO`03000000?ooooo00<00000ooooooooool0;Oooool00ol0003oooooooooo`0Gooooo`030=nk
/`3R_kH0h[nf0080i<Ji0P3VcKd0103Xe/<0k/FY0?39ZP3`bJX20?7=[@030?7@[`3^ck<0j<Vf0080
j<Vf00@0gkni0=jd[@3F[Jh0eZf^0`3;XZh01@3>ZkH0_iff0;nM]P2^SkH0[jG>00<0V97;00<0S8G6
08]n`02;O/000P2>O;/309=k]P80Ug^b0P2JNZl209aj[080WWZZ0`2PNZP20:5iY`80XWVV0P2SNJD0
0`2SNjP0XgZV0:=jYP030:=iY@80XgVT0P2SN:<20:=gXP030:N1ZP2WOjT0YgnY00<0YWjX0P2UOJP0
0`2QNZP0`N_booooo`0Xooooo`04o`000?ooooooooooo`0000_ooooo0009ooooo`0400000?oooooo
ooooooooo`@06ATI00<0000003<c<`0000000P1<C4`01@000000IVIV0000001oOgl0000000<0VIVI
00?o000009VIV@2IVIT00`2IVIT01`000000Ogmo0000001VIVH0000004a<C00000000P0c<c<01000
00006ATI01TI6@0I6AUK000000<06ATI00@0000003<c<`0c<c<000000P1<C4`010000000IVIV06IV
IP00000207moO`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl01@1oOgl010000000VIVI
09VIVOl000020;>c/`07o`00003<c<`0c<c<o`00002c/k?o000009VIV@030000000304a<C000003o
oooo00;ooooo00<00000ooooooooool0;_ooool2o`0001Sooooo00<006>n0>:o]P3Ta[T00P3VcKd2
0>SF``030>WPb@3Xjm00l<VZ0080lLf]00@0lM2_0>k?/`3XbKH0j<Vf0P3O_kT30=J][P060=://P3;
XZh0cZ^f0<j[]P2oWKH0bKW;0`2_YLh209RAb`80S8G60P2;O/0208il^`80Tg^f0P2GNk8209Yj[`80
W7Z/0`2NNZX20:1jZ080XGVW00<0XWVV0:9mZP2SNjP00P2SNjP20:=jYP<0XgVU0P2SNJ@20:=hX`<0
Yh6Z0`2WOjT20:InZ080YGfX00<0b_;/ooooooooool0:Oooool00ol0003oooooo`00000;ooooo`00
2Oooool01@00003ooooooooooooooooo000000<06ATI00<0000003<c<`0000000P1<C4`01@000000
IVIV0000001oOgl0000000T0VIVI00L0000007moO`000000IVIV0000001<C4`000000080<c<c00@0
000001TI6@0I6AT06ATIF@0000001Ol000006ATI01TI6@0I6AT000000080<c<c00@0000004a<C01<
C4`000000P1VIVH01?l00000Ogmo07moOol0000709VIV@030000001oOgl0Ogmo00D0Ogmo00@00000
09VIVOl0003o00000P2c/k<2o`000080/k>c00?o000009VIV@0000000P0000000`1<C4`00000oooo
o`02ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool05oooool00`3Ta[T0i/fm0>SF
``020>SF``080>WPb@3Xjm00h_GG0>;ee`3Hn]l0c?SX0<;[l@3XbKH30=no^@050=Ff^`3F[Jh0dZbb
0=://P3;XZh00P3>ZkH30<Vib`040:nUcP29g_h0RMkn08WNoP80A:kg0P2;O/0208il^`<0Tg^f0P2G
Nk8209Yj[`80W7Z/0P2NNZX20:1jZ0040:5iY`2QOZd0XWfZ0:9mZP<0Xg^X0`2SNZH20:=iY@80XgVT
00<0XgRS0:N2Z`2WPZ/00P2WPJX30:MoZ@80YWjX00<0YGfX0<[bk?ooool0:oooool00ol0003ooooo
o`00000;ooooo`002Oooool01@00003ooooooooooooooooo000000<06ATI00<0000003<c<`000000
0P1<C4`01@000000IVIV0000001oOgl0000000T0VIVI00L0000007moO`000000IVIV0000001<C4`0
00000080<c<c00@0000001TI6@0I6AT06ATIFP00000301TI6@040000000c<c<0<c<c00000080C4a<
00@0000006IVIP1VIVH000000P1oOgl00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0
Ogmo00@0000009VIV@2IVIWo00001P2c/k<00ol00000VIVI000000020000000304a<C000003ooooo
00;ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Iooooo`030>SF``3Yh<T0j>_@
0080h_GG00<0f?[O0<chj032jo400`2bdO00103O_kT0eKJk0=Ff^`3F[Jh20=://P<0cZ^f00@0fl[9
0<Vib`33n>`0`oS/1oooool00`0nRnd0SWbk08il^`0209=k]P80Ug^b0P2JNZl209aj[080WWZZ00@0
X7ZX09n0/@2QOZd0XGj]0`2ROJX30:=kZ080XgZV0P2SNJD00`2SNJ@0Yh>^0:N2Z`020:N2Z`<0Yh6Z
0P2WOjT00`2VOZP0b_SYooooo`0^ooooo`03o`000?oooooo000000[ooooo0009ooooo`0500000?oo
ooooooooooooool000000`0I6AT020000000<c<c03<c<`000000C4a<0000001VIVH000000P1oOgl0
0`000000VIVI09VIV@0609VIV@070000001oOgl0000006IVIP000000C4a<0000000203<c<`030000
000I6AT06ATI00806ATIF@00000201TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IV
IP040000001oOgl0Ogmo000000P0VIVI00<0000007moO`1oOgl01P1oOgl010000000VIVI09VIVOl0
00040;>c/`03o`00002IVIT0VIVI00<0000000<0C4a<00000?ooool00_ooool00`00003ooooooooo
o`0booooo`03o`000?oooooooooo027ooooo00<0/]7`09fik03E][/00P3E][/30=://P040=Jh_03>
ZkH0fl[90=_:b@80e?oD2_ooool00`1MSNH0MhcK07N<f`0209Mk/P80VWZ_0P2LNZ`0102NNZX0WH:f
09n0/@2OP;420:5n[@<0XWfZ0`2SNjP20:=jYP80XgVU0P2WPjh30:N2Z`<0Yh6Z0P2WOjT00`2no>Go
ooooooooo`0_ooooo`;o00002_ooool000Wooooo00D00000ooooooooooooooooo`00000301TI6@08
0000000c<c<0<c<c0000001<C4`0000006IVIP00000207moO`030000002IVIT0VIVI00D0VIVI00H0
000007moO`1oOgl0000006IVIP00000204a<C0040000000c<c<0<c<c000000<06ATI00<00000o`00
00000000E@00000301TI6@07o`00000c<c<0<c<c03<c<`000000C4a<0000000206IVIP040000001o
Ogl0Ogmo000000P0VIVI00?o000007moO`1oOgl01P1oOgl010000000VIVI09VIVOl000040;>c/`04
o`00002IVIT0000007moO`80000000<0C4a<00000?ooool00_ooool00`00003oooooooooo`0coooo
o`;o00008_ooool209fik0040=Ff^`3?]/80ckK20=://P80e[Rl00@0hn7A0=_:b@3Dom@0e?oD3Ooo
ool00`1gS=/0Qh[?08N:c`0209:7a@80V8Bl0P2MP[H209n0/@<0XGj]0P2ROJX30:=kZ080XgZV00<0
XgVU0:N6/@2WPjh00P2WPjh30:N2Z`80Yh6Z00<0YgnY0;kliOooool0<?ooool3o`0000[ooooo0009
ooooo`0500000?ooooooooooooooool000000`0I6AT020000000<c<c03<c<`000000C4a<0000001V
IVH000000P1oOgl00`000000VIVI09VIV@0509VIV@060000001oOgl0Ogmo0000001VIVH000000P1<
C4`010000000<c<c03<c<`00000401TI6EL000000`0I6AT01P000000<c<c03<c<`000000C4a<0000
0080IVIV00@0000007moO`1oOgl000002@2IVIT00`000000Ogmo07moO`0707moO`040000002IVIT0
VIVIo`000080/k>c0_l000000`2IVIT0000007moO`020000000304a<C000003ooooo00;ooooo00<0
0000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`0607R]m03?]/80ckK20<nf`P3?c=H0
e[Rl0P3ShM400`2VlK7oooooooooo`0?ooooo`80Qh[?0P2BQlD0102HQ;`0WH:f09f2]P2MP[H209n0
/@80XGj]0`2ROJX20:=kZ0030:=jYP2VR;@0YhJa0080YhJa0P2WPjh30:N2Z`030:N1ZP2OmMGooooo
02kooooo1?l0000=ooooo`002Oooool01@00003ooooooooooooooooo000000<06ATI00P0000003<c
<`0c<c<0000004a<C0000000IVIV00000080Ogmo00<0000009VIV@2IVIT01@2IVIT01P000000Ogmo
07moO`000000IVIVo`000080C4a<00@0000003<c<`0c<c<000001P0I6AUE000000<06ATI00P00000
03<c<`0c<c<0000004a<C0000000IVIVo`0000<0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000
Ogmo07moO`0207moO`<000000P1oOgl01?l00000VIVI09VIV@2IVIT2o`0000<0VIVI00H0000007mo
O`000000000004a<C0000003ooooo`0300000?oooooooooo03Kooooo00?o0000ooooooooool07ooo
ool00ol0000007S=0<nf`P020<o<eP030:Kgj03ShM7ooooo01Cooooo0P2BQlD209R4_080WH:f0P2O
P;420:5n[@<0XWfZ00@0Xg^X0:F<^P2VR;@0YXRd0`2WQ[420:N3[P80Yh:[00<0ImB/ooooooooool0
;?ooool3o`00017ooooo0009ooooo`0500000?ooooooooooooooool000000`0I6AT01P000000<c<c
03<c<`000000C4a<00000080IVIV00@0000007moO`1oOgl000001P2IVIT01P000000Ogmo07moO`00
0000IVIV00000080C4a<00D0000003<c<`0c<c<0<c<c0000000601TI6E<000000`0I6AT01P000000
<c<c03<c<`000000C4a<00000080IVIV00@0000007moO`1oOgl000002@2IVIT01P000000Ogmo07mo
O`1oOgoo0000000000<0IVIV00@0000007moO`1oOgl000001P2IVIT010000000Ogmo0000001VIVH2
000000Cooooo00<00000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`04o`000?oooooo
oooo0<o<eQ_ooooo00<0C:Gh09f2]P2MP[H00P2OP;400`2QOZd0WYO<0:>A`P020:>A`P80YHbj0`2V
R;@20:N6/@030:N3[P00003ooooo02cooooo1?l0000Dooooo`002Oooool01000003ooooooooooooo
ool401TI6@060000000c<c<0<c<c0000001<C4`000000P1VIVH010000000Ogmo07moO`00000609VI
V@040000001oOgl0Ogmo00000080IVIV00<0000004a<C00000000`0c<c<00`0000006ATI01TI6@07
01TI6A80000000?o0000000000000000>P00000401TI6@080000000c<c<0<c<c0000001<C4co0000
06IVIP00000207moO`030000002IVIT0VIVI00P0VIVI00@0000007moO`1oOgl000001P1VIVH01000
0000Ogmo07moO`00000509VIV@04o`00001oOgl0000006IVIP8000001?ooool00`00003ooooooooo
o`0hooooo`;o00007_ooool00ol0003oooooooooo`0Nooooo`0307nWkP2EWm/0UIoK00<0WYO<0`2S
TL820:F<^P80YXRd00<0YhJaooooooooool0:_ooool4o`0001Sooooo0009ooooo`0400000?oooooo
ooooooooo`@06ATI00H0000003<c<`0c<c<0000004a<C000000206IVIP040000001oOgl0Ogmo0000
00H0VIVI00@0000007moO`1oOgl000000P1VIVH010000000C4a<04a<C?l0000203<c<`03o`000000
00006ATI02006ATI=P00000401TI6@080000000c<c<0<c<c0000001<C4`0000006IVIP00000207mo
O`030000002IVIT0VIVI00P0VIVI00@0000007moO`1oOgl000001P1VIVH010000000Ogmo07moO`00
000309VIV@8000000P1oOgl010000000IVIV000000000004ooooo`0300000?oooooooooo03[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`80UIoK0`2NUl`20:>A`P80YHbj
00<0YXRdooooooooool0:?ooool4o`0001cooooo0009ooooo`0400000?ooooooooooooooo`@06ATI
00H0000003<c<`0c<c<0000004a<C000000206IVIP040000001oOgl0Ogmo000000H0VIVI00@00000
07moO`1oOgl000000P1VIVH010000000C4a<04a<C000000403<c<`800000:@0I6AT[000000@06ATI
00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207moO`030000002IVIT0VIVI00P0
VIVI00@0000007moO`1oOgl000001`1VIVH01P000000Ogmo07moO`000000VIVI000000@0Ogmo00@0
000006IVIP00000000001?ooool00`00003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0DOooool3o`00023ooooo0009ooooo`0400000?ooooooooooooooo`@06ATI
00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207moO`030000002IVIT0VIVI00D0
VIVI00@0000007moO`1oOgl000000P1VIVH010000000C4a<04a<C000000503<c<`030000000I6AT0
6ATI02d06ATI9000000401TI6@080000000c<c<0<c<c0000001<C4`0000006IVIP00000207moO`03
0000002IVIT0VIVI00P0VIVI00@0000007moO`1oOgl00000201VIVH01@000000Ogmo07moO`1oOgl0
000000@0Ogmo00D0000006IVIP000000C4a<00000004ooooo`0300000?oooooooooo03cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co00008oooool000Wooooo00@00000
oooooooooooooooo100I6AT010000000<c<c03<c<`00000204a<C0030000001VIVH000000080Ogmo
00<0000009VIV@2IVIT01@2IVIT010000000Ogmo07moO`00000206IVIP030000001<C4`0C4a<0080
00001@0c<c<00ol0000000000000000K000001P06ATI7000000401TI6@04o`00000c<c<0<c<c0000
0080C4a<00<0000006IVIP0000000P1oOgl00`000000VIVI09VIV@0809VIV@04o`00001oOgl0Ogmo
o`0000<0IVIV0`00000306IVIP03o`00001oOgl0Ogmo00D0Ogmo00D0000006IVIP000000C4a<0000
0004ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo1?l0
000Wooooo`002Oooool01000003oooooooooooooool401TI6@040000000c<c<0<c<c00000080C4a<
00<0000006IVIP0000000P1oOgl00`000000VIVI09VIV@0509VIV@040000001oOgl0Ogmo00000080
IVIV00<0000004a<C01<C4`00P1<C4`200000240<c<c2P00000E01TI6A@000001@0I6AT010000000
<c<c03<c<`00000204a<C0030000001VIVH000000080Ogmo00<0000009VIV@2IVIT01`2IVIT01000
0000Ogmo07moO`00000206IVIP8000000`1<C4`010000000IVIV06IVIP00000707moO`050000001V
IVH0000004a<C00000001?ooool00`00003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0AOooool4o`0002_ooooo0009ooooo`0400000?ooooooooooooooo`@06ATI
00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207moO`030000002IVIT0VIVI00H0
VIVI00@0000007moO`1oOgl000000P1VIVH00`000000C4a<04a<C00304a<C0800000:@0c<c<70000
01406ATI4000000601TI6@030000000c<c<000000080C4a<00<0000006IVIP0000000`1oOgl00`00
0000VIVI09VIV@0609VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH00`000000C4a<04a<C003
04a<C0040000001VIVH0IVIV000000D0Ogmo00H0000006IVIP000000C4a<0000000c<c<4ooooo`03
00000?oooooooooo043ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o
0000;oooool000Wooooo00@00000oooooooooooooooo100I6AT010000000<c<c03<c<`00000204a<
C0030000001VIVH000000080Ogmo00<0000009VIV@2IVIT01P2IVIT01@000000Ogmo07moOol00000
00000080IVIV0P00000504a<C00300000?l00000000000L0000000?o00000000000000003`000000
0ol00000000000000003000000h0<c<c1`00000>01TI6@T00000200I6AT010000000<c<c03<c<`00
000204a<C0030000001VIVH0000000<0Ogmo00<0000009VIV@2IVIT01@2IVIT01@000000Ogmo07mo
O`1oOgl000000080IVIV00<0000004a<C01<C4`01@1<C4`010000000IVIV06IVIP00000207moO`80
00000P1VIVH01@000000C4a<0000000c<c?o000000?ooooo00<00000ooooooooool0@Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo1?l0000booooo`002Oooool01000003o
ooooooooooooool401TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl0
0`000000VIVI09VIV@0609VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<
C00T04a<C0L000003P0c<c<3000001/06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000
001VIVH0000000<0Ogmo00<0000009VIV@2IVIT01@2IVIT01@000000Ogmo07moO`1oOgl000000080
IVIV00<0000004a<C01<C4`01@1<C4`01_l00000IVIV06IVIP1VIVKo0000000000@0IVIV00D00000
04a<C0000000<c<co`000003ooooo`0300000?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oo
oooooooo03_ooooo1?l0000fooooo`002Oooool01000003oooooooooooooool401TI6@040000000c
<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl00`000000VIVI09VIV@0709VIV@050000
001oOgl0Ogmo07moO`000000101VIVH3000000d0C4a<4`00000:04a<C0L000002P0c<c<4000001H0
6ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV000000<0Ogmo00<00000
09VIV@2IVIT0102IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00<0000004a<C01<C4`01P1<
C4`00`000000IVIV06IVIP0706IVIP050000001<C4`0000003<c<ol000000oooool00`00003ooooo
ooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0003[ooooo
0009ooooo`0400000?ooooooooooooooo`<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C003
0000001VIVH000000080Ogmo00<0000009VIV@2IVIT01`2IVIT01@000000Ogmo07moO`1oOgl00000
00L0IVIV3@00000C06IVIPP000002@1<C4`5000000T0<c<c1@00000@01TI6@03o`00000c<c<0<c<c
0080<c<c00@0000004a<C01<C4`000000P1VIVH010000000Ogmo07moO`00000709VIV@070000001o
Ogl0Ogmo07moO`000000IVIVo`00000504a<C0;o00000`1<C4`00`000000IVIV06IVIP0506IVIP06
0000001<C4`0C4a<0000000c<c?o00000oooool00`00003oooooooooo`15ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo0009ooooo`0400000?oooooooooo
ooooo`<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH000000080Ogmo00<0
000009VIV@2IVIT0202IVIT01P000000Ogmo07moO`1oOgoo0000000001T0IVIV2000000<06IVIP03
o`0000000000000000<00000201<C4`00ol00000000000000002000000P0<c<c00?o000000000000
00000`00000901TI6@8000000`0c<c<200000080C4a<00@0000006IVIP1VIVKo00000`1oOgl00`00
0000VIVI09VIV@0409VIV@050000001oOgl0Ogmo07moOol000000P1VIVH010000000C4a<04a<C01<
C4`2o`00000303<c<ol00000C4a<0080C4a<00<0000006IVIP1VIVH01@1VIVH01P000000C4a<04a<
C0000000<c<co`0000?ooooo00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo033ooooo0ol00012ooooo`002Oooool01000003oooooooooooooool301TI6@05
0000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV0000000207moO`030000002IVIT0VIVI
00P0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0<06IVIPX00000201oOgl;0000
00L0IVIV1P00000704a<C0@000002P0c<c<9000000@0<c<c00<0000004a<C01<C4`00P1<C4`01000
0000IVIV06IVIP00000307moO`030000002IVIT0VIVI00@0VIVI00D0000007moO`1oOgl0Ogmo0000
000206IVIP040000001<C4`0C4a<o`0000<0<c<c00Go000004a<C01<C4`0C4a<0000000706IVIP06
0000001<C4`0C4a<0000000c<c?o00000oooool00`00003oooooooooo`17ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0;?ooool4o`0004Gooooo0009ooooo`0400000?oooooooooo
ooooo`<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo
00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00L0IVIV
1000000M07moO`L000001P1VIVH4000000L0C4a<1`00000?03<c<`030000001<C4`0C4a<0080C4a<
00@0000006IVIP1VIVH000000`1oOgl00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo0080
Ogmo00<0000006IVIP0000000`1<C4`00ol00000<c<c03<c<`0203<c<`05o`00001<C4`0C4a<04a<
C00000001P1VIVH01P000000C4a<04a<C0000000<c<co`0000?ooooo00<00000ooooooooool0B?oo
ool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0400000?oooooo
ooooooooo`<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080
Ogmo00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0407moO`03o`0000000000000000<0
000000?o00000000000000002`1oOglF000000L0Ogmo0P0000001?l00000000000000000000406IV
IP@0000000?o00000000000000001`1<C4`01000003o000000000000000803<c<`80000000?o0000
04a<C01<C4`00P1<C4`01?l00000IVIV06IVIP00000307moO`030000002IVIT0VIVI00D0VIVI00D0
000007moO`1oOgl0Ogmo0000000206IVIP050000001<C4`0C4a<04a<C?l00000100c<c<01Ol00000
C4a<04a<C01<C4`0000000H0IVIV00H0000004a<C01<C4`0000003<c<ol00003ooooo`0300000?oo
oooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000COoo
ool000Wooooo00@00000oooooooooooooooo0`0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<
00@0000006IVIP1VIVH000000P1oOgl00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo01@0
Ogmo1000000F09VIV@L000001P1oOgl4000000L0IVIV0`00000804a<C0P00000101<C4`300000003
06IVIP00003o000000@0Ogmo00<0000009VIV@2IVIT01@2IVIT01@000000Ogmo07moO`1oOgl00000
0080IVIV00D0000004a<C01<C4`0C4a<o`00000403<c<`05o`00001<C4`0C4a<04a<C00000001P1V
IVH01P000000C4a<04a<C0000000<c<co`0000?ooooo00<00000ooooooooool0Boooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001Aooooo`002Oooool01000003ooooo
ooooooooool301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@000000IVIV06IVIP1VIVH0
00000080Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0B07moO`8000003P2IVIT8
000000/0VIVI1P00000407moO`L000000`1VIVH7000000X0C4a<0`00000306IVIP030000001oOgl0
Ogmo0080Ogmo0P00000809VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH010000000C4a<04a<
C01<C4`5o`0000@0C4a<00<0000006IVIP1VIVH0101VIVH01@000000C4a<04a<C0000000<c<c00Co
oooo00<00000ooooooooool0C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01go
oooo1?l0001Dooooo`002Oooool01000003oooooooooooooool401TI6@050000000c<c<0<c<c03<c
<`0000000P1<C4`010000000IVIV06IVIP00000207moO`030000002IVIT0VIVI00L0VIVI00<00000
07moO`1oOgl04@1oOgl00`000000VIVI09VIV@0909VIV@03o`0000000000000000800000202c/k<8
00000003o`00002IVIT0VIVI00H0VIVI100000000ol00000Ogmo07moO`0407moO`@0000000?o0000
06IVIP1VIVH00`1VIVH:000000D0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@09
09VIV@040000001oOgl0Ogmo00000080IVIV00<0000004a<C01<C4`02P1<C4`00`000000IVIV06IV
IP0406IVIP050000001<C4`0C4a<0000000c<c<01?ooool00`00003oooooooooo`1=ooooo`;o0000
2?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000oooooooooooooooo
100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVKo00000`1oOgl00ol0
0000000009VIV@0509VIV@8000004P1oOgl00`000000VIVI09VIV@0809VIV@0300000?l00000/k>c
01D0/k>c2000000509VIV@H00000101oOgl:000000H0IVIV100000001_l00000Ogmo07moO`00003o
0000000000@0VIVI1000000409VIV@040000001oOgl0Ogmoo`000080IVIV00?o000004a<C01<C4`0
2P1<C4`00`000000IVIV06IVIP0406IVIP050000001<C4`0C4a<0000000c<c<01?ooool00`00003o
ooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0005co
oooo0009ooooo`0400000?ooooooooooooooo`@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<
C0040000001VIVH0IVIV000000D0Ogmo0`00000209VIV@030000001oOgl0Ogmo0180Ogmo00<00000
09VIV@2IVIT01P2IVIT2000000h0/k>c3?l000060;>c/`L00000102IVIT7000000L0Ogmo1P000003
07moO`@000000`2IVIT4000000@0/k>c0P00000209VIV@050000001oOgl0Ogmo07moO`0000000P1V
IVH00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00@0IVIV00D0000004a<C01<C4`00000
03<c<`04ooooo`0300000?oooooooooo053ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Booooo`?o0000H?ooool000Wooooo00@00000oooooooooooooooo1@0I6AT01@000000<c<c
03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000001`1oOgl2000001D0Ogmo00<0000009VI
V@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`Ko0000303<c<`6o`0000L0/k>c1`00000409VI
VA000000102IVIT3000000T0/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`050000001VIVH0
IVIV06IVIP0000002@1<C4`00`000000IVIV06IVIP0506IVIP050000001<C4`0C4a<04a<C0000000
1?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`0006?ooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00D0000003<c<`0c<c<0
<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000007@1oOgl00`000000VIVI09VIV@0509VI
V@030000002c/k<0/k>c00L0/k>c00?o00000<c<c03<c<`05P3<c<`7o`0000L0/k>c1`00000=09VI
V@80000000?o00000000002c/k<02`2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00<00000
06IVIP1VIVH00P1VIVH00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00H0IVIV00D00000
04a<C01<C4`0C4a<00000004ooooo`0300000?oooooooooo05;ooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0001Wooooo`002Oooool01000003oooooooooooooool501TI6@050000000c
<c<0<c<c03<c<`0000000`1<C4`01P000000IVIV06IVIP1VIVKo0000000000h0Ogmo1000000907mo
O`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01`2c/k<00ol00000c<c<0<c<c00M0<c<
c0Oo00001`2c/k<=00000100/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`030000001VIVH0
IVIV0080IVIV00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP050000001<C4`0
C4a<04a<C00000001?ooool00`00003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo
1?l0001[ooooo`002Oooool01000003oooooooooooooool601TI6@050000000c<c<0<c<c03<c<`00
00000`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00L0Ogmo1000000406IVIP@0
00001P1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00?o00000<c<c03<
c<`0303<c<`:o`0000h0c<c<1?l0000D0;>c/`Oo00001P2c/k<010000000VIVI09VIV@00000307mo
O`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0706IV
IP050000001<C4`0C4a<04a<C00000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo
000000Gooooo0ol0001_ooooo`002Oooool01000003oooooooooooooool701TI6@050000000c<c<0
<c<c03<c<ol000000`1<C4`00ol00000IVIV06IVIP0206IVIP0600000?l0000000000000001oOgoo
00000`00000<06IVIP030000001oOgl0Ogmo00@0Ogmo00<00000o`00002IVIT0102IVIT00`00003o
0000000000060;>c/`;o00002`3<c<`2o`0000X0i^KV1Ol0000=0<c<c0?o0000402c/k<00ol00000
c<c<0<c<c0050<c<c003o`00002c/k<0/k>c00<0/k>c00@0000009VIV@2IVIT000000`1oOgl00`00
0000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH01`1VIVH01@00
0000C4a<04a<C01<C4`0000000Cooooo00<00000ooooooooool0E_ooool2o`000003ooooool0003o
000000;o0000L_ooool000Wooooo00D00000ooooooooooooooooo`00000601TI6@050000000c<c<0
<c<c03<c<`0000000`1<C4`00`000000IVIV06IVIP0606IVIP030000001VIVH0IVIV00h0IVIV00?o
00000000001oOgl01P1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c0_l0
000;0<c<c003o`00003Vi^H0i^KV00X0i^KV00?o00000<c<c03<c<`03P3<c<`00ol00000/k>c0;>c
/`0?0;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<0102c/k<010000000VIVI09VI
V@00000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0706IVIP050000001<C4`0C4a<04a<C00000001?ooool00`00003oooooooooo`1Gooooo`;o
0000M_ooool000Wooooo00D00000ooooooooooooooooo`00000601TI6@030000000c<c<0<c<c0080
<c<c00D0000004a<C01<C4`0C4a<0000000J06IVIP8000001P1oOgl00`000000VIVI09VIV@0509VI
V@8000001`2c/k<00ol00000c<c<0<c<c0090<c<c0Ko00001@3Vi^H00ol00000c<c<0<c<c00>0<c<
c003o`00002c/k<0/k>c0140/k>c1Ol000050;>c/`8000000P2IVIT01@000000Ogmo07moO`1oOgl0
000000@0IVIV00<0000004a<C01<C4`01@1<C4`2000000H0IVIV00H0000004a<C01<C4`0C4a<0000
000c<c<4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0600000?ooooooooooooooo`00003o
00001P0I6AT01@000000<c<c03<c<`0c<c<0000000@0C4a<00<0000006IVIP1VIVH03@1VIVH40000
00P0IVIV0`00000407moO`<000001P2IVIT00`000000/k>c0;>c/`050;>c/`?o00003P3<c<`5o`00
0140c<c<00?o00000;>c/`2c/k<06P2c/k<010000000VIVI09VIV@2IVIT200000080Ogmo0P000003
06IVIP030000001<C4`0C4a<00P0C4a<0P00000206IVIP800000101<C4`00`000000<c<cooooo`03
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0600000?ooooooooooooooo`00003o00001P0I
6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00?o00000000001VIVH01@1V
IVH7000000@0C4a<0P0000000ol00000000006IVIP0606IVIP<00000101oOgl3000000@0VIVI00@0
0000o`000000000000001P2c/k<4o`0001X0c<c<1_l0000J0;>c/`80000000Go000009VIV@2IVIT0
VIVIo`00000307moO`040000001VIVH0IVIV06IVIP8000003@1<C4`2000000D0C4a<00?o000003<c
<`0c<c<01?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool20000
0003o`00000I6AT06ATI00<06ATI00<0000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<
C0H000003`1<C4`3000000L0IVIV1000000307moO`@00000102IVIT3000000L0/k>c1ol000020<c<
c17o00002`2c/k<?00000080/k>c1000000309VIV@<000000`1oOgl01@000000IVIV06IVIP1VIVH0
000001D0C4a<0P00000203<c<`Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
oooooooooooo0`0000000ol000006ATI01TI6@0301TI6@030000000c<c<0<c<c00<0<c<c00<00000
04a<C01<C4`06P1<C4`4000000L0IVIV0`00000407moO`<00000102IVIT7000000L0/k>c0_l0000>
0;>c/`h000003`2IVIT2000000@0VIVI0`00000407moO`80000000@0IVIV0000000000000000101<
C4`8000000P0C4a<0P00000403<c<`05o`000?ooooooooooooooo`000000dOooool000Wooooo00@0
0000oooooooooooooooo100000000ol000006ATI01TI6@0301TI6@03o`0000000000<c<c00<0<c<c
00<0000004a<C01<C4`03@1<C4`00ol0000000000000000400000003o`0000000000C4a<00H0C4a<
1000000606IVIP@000000`1oOglR000000T0VIVI6P00000207moO`P000000`1<C4`200000003o`00
00000000<c<c00L0<c<c1000000204a<C08000001@0c<c<00ol0003oooooooooo`02ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`@0000000?o000001TI6@0I6AT0
100I6AT00`000000<c<c03<c<`0303<c<`03o`0000000000000000T0C4a<0`00000903<c<`<00000
201<C4`00ol00000000000000003000000@0IVIV00?o00000000000000001000000707moOb000000
5P1oOgl6000000@0IVIV00<0000004a<C01<C4`00P1<C4`200000100<c<c00?o00000000000c<c<0
1@0c<c<00ol000006ATIooooo`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooo`D0000000?o000001TI6@0I6AT0100I6AT00`000000<c<c03<c<`0503<c<`<00000
0`1<C4`3000000l0<c<c1`00000704a<C0L00000101VIVHA000000T0Ogmo8`00000406IVIPH00000
0`1<C4`2000000H0<c<c2?l0000;03<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo1@0000000ol000006ATI01TI6@0501TI6@030000
000c<c<0<c<c00L0<c<c0`00000I03<c<`L000001`1<C4`;000000X0IVIV2@00000;06IVIQ`00000
1`1<C4`2000000D0<c<c0ol0000801TI6@;o0000200c<c<01?l000006ATI01TI6@0I6AT4ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`H000000_l0000601TI6@03
0000000c<c<0<c<c0100<c<c3ol0000:03<c<`L000002`1<C4`800000003o`0000000000000000L0
000000?o00000000000000002@00000L04a<C0L000000`0c<c<4o`0000d06ATI0_l0000403<c<`;o
0000100I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`L0
000000?o000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0;03<c<`Co00003`0I6AT7o`0000X0
<c<cA@00000703<c<`?o00004`0I6AT4o`0000H06ATI1?ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003oooooooooooooool800000003o`00000I6AT06ATI00D06ATI00<0000003<c<`0c
<c<01`0c<c<3o`0001X06ATI2_l0001803<c<`Co00002P0I6AT4o`0001806ATI00Go0000oooooooo
oooooooo0000003Aooooo`002Oooool01000003oooooooooooooool900000003o`00000I6AT06ATI
00D06ATI0_l0000603<c<`03o`00000I6AT06ATI02D06ATI5_l0000203<c<b?o00001P0c<c<7o`00
00T06ATI1Ol00004000000?o00003P0I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo
0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo0<oooooo0009oooookH00000dOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool000Wooooo]_l0000AoooookKo00002_ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooo`@000009_ooool:000002gooooo00?o00000000000000001`00000Dooooo`<000007Ooo
ool2000000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00Co0000ooooooooool000008ooo
ool70000047ooooo5000000;ooooo``000002oooool2000000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`0000007Oooool7000000kooooo<000000Vooooo`<000003?ooool6
000000Oooooo00<00000ooooooooool01_ooool00`00003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Dooooo`T000003Oooool80000033ooooo2`0000000ol0003oooooooooo`0Boooo
o`H000005Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00D00000oooo
ooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03?ooool700000003o`000?oooooooooo00kooooo1`00000;oooo
obP000003ooooolD00000003o`000?oooooooooo00Oooooo30000007ooooo`<000001Oooool00ol0
00000000ooooo`06ooooo`0400000?l0003oooooo`0000[ooooo0009ooooo`03o`000?oooooooooo
03[ooooo9_l00?mBooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool40000
017ooooo1`000007ooooo`/00000:?ooool;000001oooooo0`00000<ooooo`<000001oooool20000
00Gooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0`ooooo`[o003o9_ooool9o`00odWooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`<000003oooool6000000Sooooo1P00000;ooooobP000002oooool70000013o
oooo2000000Booooo`@000001Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?ooool4o`00ocWooooo
1Ol00?m4ooooo`03o`000?oooooooooo00oooooo00Ko0000oooooooooooooooo00000?l000020000
00kooooo00@00000o`000000000000002_ooool01000003o0000000000000006ooooo`D0000000?o
00000000000000000`000007ooooo`D000007?ooool00`00003o000000000004000000_ooooo4000
000;ooooo`80000000?o00000000000000001`000007ooooo`8000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool09oooool5o`00od;ooooo1?l00?m0ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooool000002oooool7000000[ooooo10000007ooooo`<000001oooool;000000Gooooo5@00
000>ooooo`L000007?ooool3000000cooooo0`000006ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo027ooooo1_l00?m;ooooo`?o003o?Oooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0000000_ooooo00<00000ooooooooool03?ooool3000000Oooooo10000007
ooooo`<000009Oooool7000000kooooo1000000Dooooo`@000004_ooool2000000Gooooo00D00000
oooooooooooooooo00000005ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool08?ooool00ol00?ooooooooooo`1Aooooo`03o`00oooooooo
oooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`0300000?oooooo
oooo00cooooo00<00000ooooooooool01_ooool2000000Sooooo0`00000>ooooo`So00006Oooool4
000000kooooo00?o0000ooooooooool03oooool2000000Wooooo00?o00000000000000001P000006
ooooo`0300000?oooooooooo00?ooooo00Go0000oooooooooooooooo00000004ooooo`0300000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool0
0ol00?ooooooooooo`0Vooooo`?o0000:Oooool00ol00?ooooooooooo`0jooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`8000002?ooool0
0`00003o0000ooooo`04ooooo`0400000?l000000000000000Kooooo2ol00008ooooo`_o00004_oo
ool00`00003oooooooooo`0<ooooo`<000003?ooool00`00003o0000ooooo`08ooooo`0300000?l0
003ooooo00Sooooo00?o00000000000000001?ooool00ol000000000ooooo`03ooooo`0500000?oo
ooooooooooooo`0000001?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01oooooo00?o003oooooooooool09_ooool5o`0002Wooooo00?o
003oooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<0
0000ooooooooool02_ooool2000000Sooooo0P000006ooooo`0300000?oooooooooo00Gooooo0ol0
000Nooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`07ooooo`8000002?ooool3000000kooooo0P000004ooooo`0500000?ooooooooooooooo`000000
0oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`0Wooooo`Go0000:Ooo
ool00ol00?ooooooooooo`0Iooooo`Go003o6oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00<00000ooooooooool02_ooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00Cooooo0P000007ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?oo
ool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00D00000oooooooooooooooo
00000003ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`;o003o:Oooool5o`0002Wooooo0_l0
0?lGooooo`?o003o1Oooool3o`00oaSooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`06ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo00Gooooo0_l0000Qooooo`?o00004Oooool2000000gooooo0`00
0007ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01Oooool9o`0000Gooooo00<0
0000ooooooooool00_ooool01@00003ooooooooooooooooo000000?ooooo00D00000oooooooooooo
oooo00000004ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01oooooo
00?o003oooooooooool09oooool3o`0002Sooooo0_l00?lHooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo
00<00000ooooooooool02_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`Oo00004_ooool2000000cooooo
0`00000;ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool00_ooool01@00003ooooo
ooooooooool0000000?ooooo00D00000oooooooooooooooo00000004ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo023ooooo0_l00?m@ooooo`;o003o6Oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`07ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool7o`0001Go
oooo1000000:ooooo`@000003oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00;o
oooo00@00000ooooooooool000000oooool01@00003oooooooooooooool0000000Cooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool08_ooool2o`00odcooooo0_l00?lJoooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00<00000ooooooooool02oooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`0@oooo
o`?o00004_ooool:000000_ooooo0`00000Dooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
oooooooooooo00000003ooooo`0500000?ooooooooooooooo`0000000oooool01@00003ooooooooo
oooooooo000000[ooooo0009ooooo`03o`000?oooooooooo02Cooooo1?l00?m5ooooo`?o003o6ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool01Ooo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool03?oo
ool4o`0000[ooooo2@0000000ol000000000ooooo`0=ooooo`L000006?ooool00`00003ooooooooo
o`03ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`02ooooo`0500000?ooooooooooooooo`0000000oooool01000003oooooooooo`000003ooooo`05
00000?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool0:?ooool5o`00ocKo
oooo2_l00?lNooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0000000Wooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`Co00001oooool70000017ooooo2000000>ooooo`/000001_ooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool01000003oooooooooo`000003
ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool0;Oooool9
o`00obWooooo1?l00?lXooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000Wooooo0P00000<ooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`06ooooo`Wo00001ooo
ool4000000[ooooo3P00000;ooooo`/000002oooool4000000?ooooo00<00000ooooooooool00ooo
ool01@00003ooooooooooooooooo000000oooooo00?o0000ooooooooool00_ooool01@00003ooooo
ooooooooool0000000;ooooo00@00000ooooooooool000000oooool01@00003ooooooooooooooooo
000000[ooooo0009ooooo`03o`000?oooooooooo03Kooooo3_l00?l=ooooo`ko003o:oooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool01Ol0
003ooooooooooooooooo000000[ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool04_ooool200000003o`000000003o
oooo00?ooooo0P0000000ol00000000000000005000000_ooooo3P00000Jooooo`06o`000?oooooo
ooooooooo`00003o00000oooool01@00003ooooooooooooooooo0000013ooooo00Go0000oooooooo
oooooooo00000003ooooo`0400000?oooooooooo000000;ooooo00D00000oooooooooooooooo0000
0003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Cooooo3Ol00?lh
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool02?ooool00ol000000000ooooo`09
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0@
ooooo`8000001?ooool4000000Oooooo3P00000Boooooa4000001Oooool00`00003oooooooooo`02
ooooo`0500000?ooooooooooooooo`0000000oooool00ol0003oooooooooo`0>ooooo`05o`000?oo
ooooooooooooo`0000000oooool01000003oooooooooo`000002ooooo`0500000?oooooooooooooo
o`0000000oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`28ooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00?ooooo00<00000ooooooooool02Oooool2000000Sooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00kooooo0P000003ooooo`<0
00001?ooool70000017ooooo3`00000Aooooo`8000001?ooool00`00003oooooooooo`02ooooo`04
00000?oooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooo`0000000oooool01000003oooooooooo`000002ooooo`0500000?oo
ooooooooooooo`0000000oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Wooooo`So003oFOooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool01Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool02?ooool>000002;ooooo00?o0000ooooooooool00_ooool01@00003ooooooooo
ooooool0000000?ooooo00D00000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000Oo
oooo00Go0000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000;ooooo00@00000
ooooooooool000000oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0S
ooooo`Co003o2?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00<00000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00;ooooo00<00000
ooooooooool00_ooool00`00003oooooooooo`0<ooooo`8000000oooool2000000Cooooo00<00000
o`00000000001?ooool4000000;o000000<00000ooooooooool05?oooolE000000Kooooo00<00000
ooooooooool00_ooool01@00003oooooooooooooool0000000;ooooo00D00000oooooooooooooooo
o`000005ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000ooooooooool000000_ooool01000003oooooooooo`000003ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo0_l00?l=ooooo`03o`00oooooooo
oooo05Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo00Gooooo00<00000ooooooooool00_ooool01@00003ooooooooooooooooo000000kooooo00<0
0000ooooooooool00_ooool01000003oooooooooooooool3000000Cooooo0`00000;oooooa800000
5Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooo
oooo00000002ooooo`0500000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01000003oooooooooo`000002ooooo`0400000?oo
oooooooo000000;ooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003ooooo
ooooo`0Pooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0Doooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`02ooooo`0500000?ooooooooooooooo`0000003_ooool00ol0003oooooooooo`02ooooo`05
00000?ooooooooooooooo`0000001?ooool3000000Oooooo1`00000Xooooo`<000000oooool00`00
003oooooooooo`02ooooo`05o`000?ooooooooooooooo`0000000_ooool01000003oooooooooool0
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
ooooool0000000;ooooo00L00000oooooooooooooooo00000?ooool0000000;ooooo00D00000oooo
ooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0Nooooo`;o003o4_ooool00ol0
0?ooooooooooo`0GoooooaT0okK18_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo
00Oooooo00?o0000ooooooooool01?ooool00ol000000000ooooo`02ooooo`0500000?oooooooooo
ooooo`0000003oooool01@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00_oo
ool00`00003oooooooooo`03ooooo`D000001?oooolI0?nf`AGooooo00H00000oooooooooooooooo
o`0000000002ooooo`0500000?ooooooooooooooo`0000000_ooool01000003oooooooooool00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
ool0000000?ooooo00H00000ooooooooool00000ooooo`000002ooooo`0500000?oooooooooooooo
ool000002_ooool000Wooooo00?o0000ooooooooool07?ooool2o`00oaCooooo00?o003ooooooooo
ool05?oooolO0?nf`Aoooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Gooooo00D00000ooooooooooooooooo`000004ooooo`0300000?oooooooooo
00gooooo00D00000oooooooooooooooo00000003ooooo`05o`000?ooooooooooooooo`0000001?oo
ool2000000Kooooo403o]/4G000000[ooooo00<00000ooooooooool00_ooool01000003ooooooooo
o`000003ooooo`0400000?oooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo00000003oooo
o`0600000?oooooooooo00000?ooool000000_ooool01@00003ooooooooooooooooo000000[ooooo
0009ooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool05?ooool00ol00?oooooooooo
o`0AooooobD0okK17?ooool00ol00?ooooooooooo`09ooooo`?o00003?ooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003ooooooooo
o`05ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00_ooool01@00003ooooooooo
ooooool0000000Gooooo0ol00008ooooo`0400000?oooooooooo000000Cooooo00@00000oooooooo
ool000001?ooool00`00003oooooooooo`03ooooo`D0okK13P00000B0?nf`@Gooooo0P000009oooo
o`0500000?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0000000;ooooo00@0
0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go0000oooooooooooooooo00000003ooooo`0600000?oooooooooo00000?ooool000000_ooool0
1@00003ooooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo01_ooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0>ooooob/0okK16Oooool00ol00?ooooooooooo`08
ooooo`Go00002oooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo00<00000
ooooooooool00_ooool01@00003oooooooooooooool0000000Cooooo0_l00003ooooo`03o`000?oo
oooooooo00Cooooo00D00000oooooooooooooooo00000003ooooo`0400000?oooooooooo000000Co
oooo00@00000oooooooooooooooo1P3o]/400ol0000000000?nf`@0R0?nf`@Cooooo0P000007oooo
o`0300000?oooooooooo00;ooooo00@00000ooooooooool000000_ooool01000003oooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00L00000oooooooooooooooo00000?oooooo000000;o
oooo00@00000ooooooooool000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Jooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02ooooola0?nf`AKo
oooo00?o003oooooooooool02?ooool5o`0000_ooooo00?o003oooooooooool03Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000000003ooooo00?ooooo00<00000ooooooooool00P000003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`0400000?oooooooooo000000?ooooo00@00000oooo
ooooool000001?ooool00ol0003ooooo0?nf`@040?nf`@<0000000?o00000?nf`@3o]/409P3o]/43
ooooo`0300000?oooooooooo00Gooooo00D00000oooooooooooooooo00000002ooooo`0400000?oo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol0003oooooooooooooool0000000?ooooo00<00000oooo
o`0000000_ooool01000003oooooooooo`000002ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`08oooo
ocL0okK14oooool00ol00?ooooooooooo`08ooooo`Go00002oooool00ol00?ooooooooooo`0=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`04oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool01@00003o0000ooooooooool0
000000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`0400000?oooooo
oooo000000?ooooo00@00000ooooooooool000000oooool00`000000okK10?nf`@040?nf`@030000
003o]/40okK102d0okK100<00000ooooooooool01Oooool01@00003oooooooooooooool0000000;o
oooo00@00000ooooooooool000000_ooool01@00003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool00_l00007ooooo`05o`000?ooooooooooooooo`0000000oooool00`00003ooooo0000
0002ooooo`0400000?oooooooooo000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Gooooo>`3o
]/4Booooo`03o`00oooooooooooo00Wooooo0ol0000<ooooo`03o`00oooooooooooo00gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool00_ooool2000000?ooooo0P000003ooooo`0300000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`0400000?oooooooooo000000?ooooo
00D00000ooooooooool00000ooooo`020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/40;`3o]/400`00003oooooooooo`05ooooo`0500000?ooooooooooooooo`0000000_ooool01000
003oooooooooo`000002ooooo`0400000?ooooooooooo`0000Kooooo0_l00009ooooo`03o`000?oo
oooooooo00;ooooo00@00000ooooooooool000000_ooool00`00003ooooo00000002ooooo`040000
0?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0
2?ooool3o`0000cooooo00?o003oooooooooool01Ooooolm0?nf`A7ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1?ooool00`00003oooooooooo`02ooooo`03o`000000003ooooo00?ooooo00<00000ooooooooool0
0_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000000;ooooo00D00000oooooooooooooooo00000002oooo
o`05o`000?ooool0okK10?nf`@0000001P3o]/400`000000okK10?nf`@0a0?nf`@0300000?oooooo
oooo00Cooooo00D00000oooooooooooooooo00000002ooooo`0400000?oooooooooo000000;ooooo
00@00000oooooooooooo00004Oooool00ol0003oooooooooo`02ooooo`0400000?oooooooooo0000
00;ooooo00<00000ooooo`0000000_ooool01000003oooooooooool0000:ooooo`002Oooool00ol0
003oooooooooo`0Fooooo`03o`00oooooooooooo00Sooooo1Ol0000;ooooo`03o`00oooooooooooo
00?ooooo@P3o]/4>ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooo00000002ooooo`0500000?oo
ooooooooooooo`0000000_ooool01@000000okK10?nf`@3o]/40000000H0okK100<000000?nf`@3o
]/40<@3o]/400`000000okK10?nf`@04ooooo`0500000?ooooooooooooooo`0000000_ooool01000
003oooooooooo`000002ooooo`0400000?ooooooooooo`00017ooooo00?o0000ooooooooool00_oo
ool01000003oooooooooo`000002ooooo`0300000?ooool0000000;ooooo00@00000oooooooooooo
00002_ooool000Wooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`09ooooo`Go0000
2_ooool00ol00?ooooooooooo`02ooooodH0okK13?ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`050000
0?ooooooooooooooo`0000001?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00<00000ooooo`0000000oooool01000003ooooo0?nf`@0000030?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/40<P3o]/400`000000okK10?nf`@020?nf`@;ooooo00D00000oooo
oooooooooooo00000002ooooo`0400000?oooooooooo000000;ooooo00D00000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo00?ooooo00@00000ooooooooool000000_ooool00`00003o
oooo00000002ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool02Oooool5o`0000[ooooo00Co003oooooooooooooooooB03o]/4;oooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00<00000ooooooooool00_ooool01@00003oooooooooooooool0
000000Gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo00Go0000oooooooooooooooo00000002ooooo`0500000?oooooooooo00000?ooool0
0P3o]/401@000000okK10?nf`@3o]/40000000D0okK100<000000?nf`@3o]/40=03o]/400`000000
okK10?nf`@020?nf`@03ooooo`00003ooooo00;ooooo00D00000oooooooooooooooo00000002oooo
o`0400000?oooooooooo000000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04
ooooo`0800000?oooooooooo00000?ooool00000ooooo`000002ooooo`0400000?ooooooooooo`00
00[ooooo0009ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool3o`0000[o
oooo00Co003oooooooooooooooooBP3o]/4;ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
oooooooooooo00000003ooooo`0300000?oooooooooo00;ooooo00?o000000000?ooool00oooool0
0`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00P000002
ooooo`05o`000?oooooooooo00000?ooool00P3o]/401@000000okK10?nf`@3o]/40000000D0okK1
00<000000?nf`@3o]/40=@3o]/400`000000okK10?nf`@030?nf`@0500000?ooooooooooooooo`00
00000oooool01000003oooooooooo`000002ooooo`0500000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`05ooooo`0800000?oooooooooo00000?ooool00000ooooo`000002ooooo`04
00000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01Cooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`1<0?nf`@[ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00`00003o
ooooooooo`02ooooo`0500000?ooooooooooooooo`0000000oooool00`00003oooooooooo`03oooo
o`0300000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool3o`0000;ooooo00D00000oooo
oooooooooooo00000002ooooo`05o`000?ooool0okK10?nf`Ol000000`3o]/400ol00000okK10?nf
`@030?nf`@030000003o]/40okK103H0okK100<000000?nf`@3o]/400`3o]/401@00003ooooooooo
ooooool0000000?ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`02ooooo`;o
00002_ooool00ol0003oooooooooo`06ooooo`0800000?oooooooooo00000?ooool00000ooooo`00
0002ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01Cooooo00?o
003oooooooooool05oooool00ol00?oooooo0?nf`@1?0?nf`@Sooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01@00003oooooooooooooool0000000?ooooo00D00000oooooooooooooooo00000005ooooo`03
00000?oooooooooo00Oooooo00?o0000ooooooooool00ol00004ooooo`0500000?oooooooooooooo
o`0000000_ooool01@000000okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@0g0?nf`@03o`00003o]/40okK100@0okK100D000000?nf`Ooooooooooo0000
0003ooooo`0400000?oooooooooo000000;ooooo00<00000ooooooooool00oooool2o`0000Gooooo
0ol00009ooooo`0800000?oooooooooo00000?ooool00000ooooo`000002ooooo`0400000?oooooo
ooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool05Oooool2
o`00o`03ooooo`3o]/40okK10500okK12?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`0400000?oooooo
ooooo`0000?ooooo00Go0000oooooooooooooooo00000005ooooo`03o`000?oooooooooo00Wooooo
0_l00006ooooo`05o`000?ooooooooooooooo`0000000_ooool01@000000okK10?nf`@3o]/400000
00<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0i0?nf`@030000003o]/40okK1
00<0okK100D000000?nf`@3o]/7ooooo00000003ooooo`0400000?oooooooooo000000?ooooo00<0
0000ooooooooool01?ooool5o`0000cooooo00P00000ooooooooool00000ooooo`00003oooooo`00
00;ooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool05?ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo05@0okK11oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`0400000?oooooooooo000000?ooooo00D00000ooooooooooooooooo`000005ooooo`0300000?oo
oooooooo00oooooo0P000003ooooo`0500000?ooooooooooooooo`0000000P3o]/401@000000okK1
0?nf`@3o]/40000000H0okK100<000000?nf`@3o]/40>@3o]/400`000000okK10?nf`@030?nf`@05
0000003o]/40okK10?nf`@0000000oooool01000003oooooooooo`000004ooooo`0300000?oooooo
oooo01Cooooo00P00000ooooooooool00000ooooo`00003ooooo000000;ooooo00@00000oooooooo
oooo00002_ooool000Wooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo05H0okK11oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`0400000?oooooooooo0000
00?ooooo00D00000oooooooooooooooo00000005ooooo`0300000?oooooooooo00gooooo0P000003
ooooo`8000000_ooool200000080okK100D000000?nf`@3o]/40okK1000000060?nf`@030000003o
]/40okK103X0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@0500000?oo
ooooooooooooo`0000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo
00P00000ooooooooool00000ooooo`00003ooooo000000;ooooo00@00000oooooooooooo00002_oo
ool000Wooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo05P0okK11oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o0000
ooooooooool03oooool01Ol0003oooooooooooooool0000000;ooooo00D00000oooooooooooooooo
00000003ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool03?ooool2000000Cooooo
00D00000oooooooooooooooo000000030?nf`@050000003o]/40okK10?nf`@0000001P3o]/400`00
0000okK10?nf`@0l0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@00
003oooooooooooooool0000000?ooooo00<00000ooooooooool00_ooool2000001?ooooo00@00000
ooooooooool000000_ooool01@00003ooooo00000?ooool0000000;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo05X0okK11_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o
0000ooooooooool03oooool01Ol0003oooooooooooooool0000000;ooooo00D00000oooooooooooo
oooo00000002ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool02?ooool4000000Co
oooo0P0000001?ooool00000o`00000000030?nf`@050000003o]/40okK10?nf`@0000001P3o]/40
0`000000okK10?nf`@0m0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/40
1@00003oooooooooooooool0000000?ooooo00<00000ooooooooool00oooool5000000kooooo00@0
0000ooooooooool000000_ooool01@00003ooooo00000?ooool0000000;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0>ooooo`;o003o
0_oooomK0?nf`@Kooooo0_l00?l?ooooo`;o003o5?ooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooo`0000000_ooool01@00003oooooooooooooool0000000;ooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`04ooooo`<000001_ooool2000000;ooooo00<00000oooo
ooooool00P3o]/400`00003o00000?nf`@020?nf`@030000003o]/40okK100@0okK100?o00000?nf
`@3o]/40?P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100D00000oooo
oooooooooooo00000004ooooo`03o`000000003ooooo00Oooooo1`000007ooooo`0400000?oooooo
oooo000000;ooooo00D00000ooooo`00003ooooo00000002ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01Kooooo0_l00?l:ooooo`Co003o1?oooomL0?nf`@Oooooo0_l0
0?l<ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
ooooool0000000;ooooo00D00000oooooooooooooooo00000002ooooo`0300000?oooooooooo00Ko
oooo1P000007ooooo`8000000oooool01000003oooooooooooooool2000000@0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@0o0?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/400P3o]/401@00003oooooooooooooool0000000Gooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`04ooooo`0400000?oooooooooo000000;ooooo00D00000ooooo`00003ooooo
00000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Sooooo0ol0
0?l3ooooo`Co003o1ooooomN0?nf`@Sooooo0_l00?l9ooooo`03o`00oooooooooooo01Gooooo00?o
0000ooooooooool03oooool01?l0003oooooooooo`000003ooooo`0400000?oooooooooo000000;o
oooo00<00000ooooooooool04Oooool3000000Cooooo00D00000oooooooooooooooo000000050?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40@@3o]/400`000000okK10?nf`@030?nf
`@030000003o]/40okK100<0okK100Co0000ooooooooool000001_ooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo00Cooooo00X00000ooooooooool00000ooooo`00003ooooo00000?oo
ool000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`?o
003o2_oooomP0?nf`@Wooooo0ol00?l3ooooo`?o003o6?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooo000000?ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`0=
ooooo`@000000oooool4000000?ooooo00L00000o`00003o]/40okK100000?l00000000000H0okK1
00<000000?nf`@3o]/40@P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK1
00@000000?nf`Ooooooooooo0P000004ooooo`03o`0000000000000000gooooo00<00000oooooooo
ool00oooool02P00003oooooooooool0003ooooo00000?ooool00000ooooo`000002ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02OoooooHP3o]/4;ooooo`?o003o6ooo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000?ooooo00@00000ooooooooool0
00000_ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool00_ooool3000000<0okK100<000000?nf`@3o]/401@3o]/400`00003o00000?nf`@140?nf`@03
0000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@03ooooo`03
00000?oooooooooo00Cooooo1`000006ooooo`0300000?oooooooooo00?ooooo00X00000oooooooo
ool00000ooooo`00003ooooo00000?ooool000000_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Vooooof<0okK1:Oooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooo000000;ooooo00@00000ooooooooool000000oooool00`00003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo0P000003ooooo`80000000?ooooo0?nf`@3o]/400P3o]/400`000000
okK10?nf`@050?nf`@030000003o]/40okK104H0okK100?o00000?nf`@3o]/40103o]/400ol00000
okK10?nf`@020?nf`@030000003o]/7ooooo00?ooooo0P00000;ooooo`<000001?ooool00`00003o
ooooooooo`02ooooo`0:00000?oooooooooo00000?ooool00000ooooo`00003ooooo000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09_oooomT0?nf`BSooooo00?o
0000ooooooooool03oooool01?l0003oooooooooo`000002ooooo`0400000?oooooooooo000000?o
oooo00<00000ooooooooool02_ooool00`00003oooooooooo`02ooooo`8000000oooool2000000?o
oooo0P3o]/42000000H0okK100?o00000000003o]/40B03o]/400`000000okK10?nf`@050?nf`@03
0000003o]/40okK10080okK100?o00000?nf`Oooool01?ooool00ol0003oooooooooo`0;ooooo`05
00000?ooooooooooooooo`0000001?ooool02P00003oooooooooo`00003ooooo00000?ooool00000
ooooo`000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Gooooo
IP3o]/4Wooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooool000000_ooool01000003o
ooooooooo`000003ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo0P3o]/400`000000okK10?nf`@050?nf
`@030000003o]/40okK104T0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf
`@8000001Oooool3000000[ooooo00D00000oooooooooooooooo00000004ooooo`0:00000?oooooo
oooo00000?ooool00000ooooo`00003ooooo000000;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool09?oooomW0?nf`BOooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooo`000002ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`02ooooo`0400000?ooooooooooooooo`8000001?ooool00`3o]/4000000000
00070?nf`@030000003o]/40okK104/0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@040?nf`@0300000?oooooooooo00Gooooo1P000005ooooo`0400000?oooooooooo000000Cooooo
00X00000ooooooooool00000ooooo`00003ooooo00000?ooool000000_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0TooooofP0okK19_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooo000000;ooooo00@00000ooooooooool000000_ooool00`00003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00D00000oooooooooooooooo00000005ooooo`80
00001`3o]/42000004h0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@050?nf`@03
00000?oooooooooo00[ooooo0P000003ooooo`0500000?ooooooooooooooo`0000001?ooool01@00
003oooooooooo`00003ooooo0080000000Gooooo00000?ooooooooooo`00000:ooooo`002Oooool0
0ol0003oooooooooo`0SooooofT0okK19_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooo000000;ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`08ooooo`050000
0?ooooooooooooooo`0000000_ooool00ol000000000ooooo`03ooooo`8000001`3o]/4200000540
okK100<000000?nf`@3o]/401@3o]/400ol0000000000?nf`@040?nf`@04ooooo`00000000000000
00_ooooo00@00000oooooooooooo00000oooool00`00003oooooooooo`02ooooo`0500000?oooooo
oooo00000?ooool00P0000001Oooool00000oooooooooooo000000[ooooo0009ooooo`03o`000?oo
oooooooo02?oooooJP3o]/4Uooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooool00000
0_ooool01000003oooooooooo`000002ooooo`0300000?oooooooooo00Sooooo00D00000oooooooo
oooooooo00000002ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01@3o]/420000
05<0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@030?nf`@?ooooo0`000008oooo
o`0400000?oooooooooo000000?ooooo00?o0000ooooooooool00_ooool01@00003oooooooooo`00
003ooooo0080000000Gooooo00000?ooooooooooo`00000:ooooo`002Oooool00ol0003ooooooooo
o`0Rooooof`0okK19?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000;ooooo
00@00000ooooooooool000000_ooool00`00003oooooooooo`07ooooo`0500000?oooooooooooooo
o`0000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00D0okK100<000000?nf
`@3o]/40E03o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK100<0okK11Oooool40000
00Gooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`03ooooo`0400000?ooool0
0000ooooo`8000000_ooool00`00003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0Q
ooooofd0okK19?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000;ooooo00@0
0000ooooooooool000000_ooool00`00003oooooooooo`07ooooo`0400000?oooooooooo000000;o
oooo00<00000ooooooooool00_ooool00ol0003oooooooooo`040?nf`@03o`0000000000okK105L0
okK100<000000?nf`@3o]/401`3o]/42000000<0okK12Oooool00ol000000000ooooo`03ooooo`03
00000?ooool0000000;ooooo00<00000ooooooooool00oooool01000003ooooo00000?ooool20000
00;ooooo00<00000ooooool000002_ooool000Wooooo00?o0000ooooooooool08Ooooom^0?nf`B?o
oooo00?o0000ooooooooool03oooool01?l0003oooooooooo`000002ooooo`0400000?oooooooooo
000000;ooooo00<00000ooooooooool01oooool01000003oooooooooo`000002ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool00`3o]/400`000000okK10?nf`@1I0?nf`@030000003o
]/40okK100P0okK10P0000020?nf`@[ooooo00L00000oooooooooooooooo00000?ooool0000000;o
oooo00<00000ooooooooool00oooool01000003ooooo00000?ooool2000000;ooooo00<00000oooo
ool000002_ooool000Wooooo00?o0000ooooooooool08?oooom_0?nf`B?ooooo00?o0000oooooooo
ool03oooool01?l0003oooooooooo`000002ooooo`0400000?oooooooooo000000;ooooo00<00000
ooooooooool01oooool01000003oooooooooo`000002ooooo`0500000?ooooooooooooooo`000000
0_ooool30?nf`@030000003o]/40okK105/0okK100<000000?nf`@3o]/402@3o]/42000000_ooooo
00H00000ooooooooool00000ooooo`000002ooooo`0300000?oooooooooo00?ooooo00@00000oooo
o`00003ooooo0P000002ooooo`0300000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo
023oooooL03o]/4Rooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooool000000_ooool0
1P00003oooooooooo`00003ooooo000000[ooooo00<00000ooooo`0000000_ooool00`00003ooooo
ooooo`02ooooo`0300000?oooooooooo0080okK100<000000?nf`@3o]/40G@3o]/400ol00000okK1
0?nf`@0:0?nf`@0300000?oooooooooo00Wooooo00So0000ooooooooool00000ooooo`00003ooooo
000000Kooooo00X00000ooooo`0000000000ooooo`00003ooooo00000?oooooo00002_ooool000Wo
oooo00?o0000ooooooooool07ooooomb0?nf`B7ooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooo`000002ooooo`0600000?oooooooooo00000?ooool000002_ooool00`00003ooooo0000
0002ooooo`0500000?ooooooooooooooo`0000000_ooool20?nf`@03o`00003o]/40okK105h0okK1
0P00000<0?nf`@<000002?ooool02000003oooooooooo`00003ooooo00000?ooool000001_ooool0
2P00003ooooo00000000003ooooo00000?ooool00000ooooool0000:ooooo`002Oooool00ol0003o
ooooooooo`0=ooooo`03o`00oooooooooooo00koooooL`3o]/4Fooooo`03o`00oooooooooooo00So
oooo00?o0000ooooooooool03oooool01?l0003oooooooooo`000002ooooo`0600000?oooooooooo
00000?ooool000002_ooool00`00003ooooo00000002ooooo`0600000?ooooooooooooooo`00003o
oooo0`3o]/400`000000okK10?nf`@0b0?nf`@@00000:P3o]/400`000000okK10?nf`@0:0?nf`@;o
oooo10000004ooooo`0800000?oooooooooo00000?ooool00000ooooo`000002ooooo`06o`000?oo
ooooooooooooo`00003ooooo0P0000001_ooool00000ooooo`00003oooooo`0000[ooooo0009oooo
o`03o`000?oooooooooo00gooooo00?o003oooooooooool03_oooomd0?nf`AGooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000;ooooo00<00000
ooooo`0000000_ooool00`00003oooooooooo`08ooooo`0300000?ooool0000000;ooooo00@00000
ooooooooool000000_ooool20?nf`@030000003o]/40okK102`0okK11`0000040?nf`@L00000903o
]/400`000000okK10?nf`@0:0?nf`@Gooooo00?o0000ooooooooool00_ooool01`00003ooooo0000
0?ooool00000ooooo`0000000_ooool2o`0000?ooooo00T00000ooooool0003ooooo00000?ooool0
0000ooooool000002_ooool000Wooooo00?o0000ooooooooool03?ooool00ol00?ooooooo`00o`0>
ooooogD0okK15?ooool00ol00?ooooooo`00o`09ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooool000000_ooool00`00003ooooo00000002ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooo`0000000_ooool01@00003oooooooooo`00003ooooo00<0okK100<000000?nf`@3o]/40
:`3o]/400`000000okK10?nf`@0@0?nf`@03o`00003o]/40okK10280okK10P00000:0?nf`@Kooooo
00d00000oooooooooooooooo00000?ooool00000ooooo`00003ooooo00000?oooooo000000;ooooo
00Go0000ooooooooool00000ooooo`0300000004ooooo`00003oooooo`0000[ooooo0009ooooo`03
o`000?oooooooooo00_ooooo00Go003oooooooooooooooooo`00o`0=ooooocL0okK11`3ooolg0?nf
`A?ooooo00Co003ooooooooooooo003o2Oooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooo000000;ooooo00<00000ooooo`0000000_ooool00`00003oooooooooo`08ooooo`0300000?oo
ool0000000;ooooo00D00000ooooooooool00000ooooo`030?nf`@030000003o]/40okK102T0okK1
00<00000o`00003o]/401@3o]/470?ooo`L0okK10P00000T0?nf`@030000003o]/40okK100L0okK1
1_ooool03@00003oooooooooooooool00000ooooo`00003ooooo00000?ooool00000ooooool00000
0_ooool01Ol0003oooooooooo`00003ooooo00<000000oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
2_oooolc0?nf`@l0oooo=03o]/4Aooooo`05o`00ooooooooooooooooool00?l02Oooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooo000000;ooooo00<00000ooooo`0000000_ooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooo`0000000_ooool01@00
003oooooooooo`00003ooooo00<0okK100<000000?nf`@3o]/409`3o]/42000000@0okK13`3oool5
0?nf`@8000008`3o]/42000000P0okK11_ooool03000003oooooooooo`00003ooooo00000?ooool0
0000ooooo`00003oooooo`0000;ooooo00Go0000ooooooooool00000ooooo`03000000?ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`05
ooooo`;o003o2Ooooolb0?nf`A<0oooo<P3o]/4@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000;ooooo00D0
0000ooooo`00003ooooo00000005ooooo`8000001Oooool01@00003ooooo00000?ooool0000000;o
oooo00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@0V0?nf`@030000003o]/40okK10080
okK11@3oool;000000<0oooo1@3o]/400ol00000okK10?nf`@0R0?nf`@030000003o]/40okK100D0
okK11_ooool01000003oooooooooooooool200000005ooooo`0000000000ooooool000001?ooool0
0ol0003oooooooooo`04000000?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo<03o]/4G0?oo
oc00okK14?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooo`000002ooooo`0500000?ooool00000ooooo`0000001?oo
ool01000003oooooooooo`000004ooooo`0500000?ooool00000ooooo`0000000_ooool00`000000
okK10?nf`@020?nf`@030000003o]/40okK102H0okK100?o00000?nf`@3o]/400`3oool01000003o
000000000000000;0?ooo`03o`000000000000000080oooo103o]/400`000000okK10?nf`@0R0?nf
`@04o`00000000000000000000<0okK11oooool00`00003oooooooooo`0200000005ooooo`000000
0000ooooool000001?ooool00ol0003oooooooooo`04000000?ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Oooooo;`3o]/4J0?ooobl0okK13oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool03oooool01?l0003oooooooooo`000002ooooo`0500000?oo
ool00000ooooo`0000001?ooool01@00003oooooooooooooool0000000?ooooo00D00000ooooo`00
003ooooo00000002ooooo`030000003o]/40okK10080okK100<000000?nf`@3o]/409@3o]/400`00
0000okK10?nf`@030?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`3o]/40
0`000000okK10?nf`@0U0?nf`@<0000000<0okK1ooooooooool01?ooool00`00003oooooooooo`02
00000005ooooo`0000000000ooooool000001?ooool00ol0003oooooooooo`04000000?ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo;`3o]/4L0?ooobh0okK13_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03oooool01_l0003oooooooooo`00
003ooooo000000;ooooo00<00000ooooo`0000000oooool00`00003oooooooooo`03ooooo`04o`00
0?oooooooooo000000;ooooo00H00000ooooo`00003ooooo0?nf`@0000030?nf`@030000003o]/40
okK102@0okK100<000000?nf`@3o]/400`3oool00`000000oooo0?ooo`030?ooo`/00000103oool2
00000080oooo0`3o]/42000002P0okK100<00000o`000?ooool01?ooool00`00003oooooooooo`02
00000005ooooo`0000000000ooooool000001Oooool00ol0003ooooo00000003000000?ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo;P3o]/4N0?ooobd0okK13_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03oooool01_l0003oooooooooo`00
003ooooo000000;ooooo00<00000ooooo`0000000_ooool00`00003oooooooooo`04ooooo`040000
0?oooooooooo000000;ooooo00H00000ooooo`00003ooooo0?nf`@0000030?nf`@030000003o]/40
okK102<0okK100<000000?nf`@3o]/400`3oool00ol00000oooo0?ooo`020?ooo`8000002`3oool3
000000<0oooo0P0000000`3oool0okK10?nf`@020?nf`@030000003o]/40okK102H0okK100?ooooo
00000?ooool00oooool00`00003oooooooooo`0200000006ooooo`0000000000ooooool0003ooooo
0_l00003ooooo`03o`00000000000000008000000oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Ooo
ool]0?nf`B00oooo;03o]/4>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Ooo
ool00ol0003oooooooooo`0?ooooo`06o`000?oooooooooo00000?ooool000000_ooool00`00003o
oooo00000002ooooo`0300000?oooooooooo00Cooooo00@00000ooooooooool000000_ooool01P00
003ooooo00000?ooool0okK1000000<0okK100<000000?nf`@3o]/408`3o]/400`000000okK10?oo
o`020?ooo`030000003oool0oooo0080oooo00?o00000?ooo`3oool00`3oool8000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?nf`@020?nf`@030000003o]/40okK102H0okK100?o
oooo00000?ooool00oooool00`00003oooooooooo`0200000006ooooo`0000000000ooooool0003o
oooo0_l00003ooooo`03o`00000000000000008000000oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1Oooool]0?nf`B00oooo;03o]/4>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`06o`000?oooooooooo00000?ooool000000_ooool00`00
003ooooo00000002ooooo`0300000?oooooooooo00Gooooo00<00000ooooo`0000000_ooool01P00
003ooooo00000?ooool0okK1000000<0okK100<000000?nf`@3o]/408P3o]/400`000000okK10?nf
`@020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000080?ooo`800000
0P3oool01P000000oooo0?ooo`3oool000000?ooo`@0okK100<000000?nf`@3o]/409@3o]/42oooo
o`0300000?oooooooooo00;ooooo00D00000ooooo`0000000000ooooo`0200000006ooooool0003o
ooooo`000?oooooo00000_ooool00ol00000000000000002000000?ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Cooooo:`3o]/4S0?ooob/0okK13_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo00?o0000ooooooooool03oooool01_l0003oooooooooo`00003ooooo000000;o
oooo00<00000ooooo`0000000_ooool00`00003oooooooooo`05ooooo`0600000?oooooooooo0000
0?ooool000000_ooool00`000000okK1000000030?nf`@030000003o]/40okK10280okK100D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo008000000`3oool7000000<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?nf`@030?nf`@03o`00003o]/40okK102@0okK1
0_ooool00`00003oooooooooo`02ooooo`03o`000?ooool000000080000000Gooooo00000?l0003o
ooooo`000002ooooo`05o`000?ooooooooooooooool000000`000003ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`04ooooobX0okK1403oool9o`00o``0oooo:`3o]/4<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`06o`000?oooooooooo0000
0?ooool000000_ooool01@00003ooooo00000?oooooo000000Wooooo00D00000ooooo`00003ooooo
00000002ooooo`030000003o]/40000000<0okK100<000000?nf`@3o]/408@3o]/400`000000oooo
0?ooo`020?ooo`05o`00003oool0oooo0?ooo`0000000P3oool00ol00000oooo0?ooo`03000000L0
oooo0P0000020?ooo`03o`00003oool0oooo008000000P3oool00`000000oooo0?nf`@020?nf`@03
0000003o]/40okK102D0okK10_ooool01P00003oooooooooooooool00000ooooo`<0000000Gooooo
00000?l0003oooooo`000003ooooo`04o`000?ooooooooooo`0000<000000oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool00_ooool[0?nf`@h0oooo0_l00?l90?ooo`;o003o2P3oool[0?nf`@cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00Ko
0000ooooooooool00000ooooo`000002ooooo`0500000?ooool00000ooooo`0000002Oooool01@00
003ooooo00000?ooool0000000;ooooo00<000000?nf`@0000000`3o]/400`000000okK10?nf`@0Q
0?nf`@030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00@000000?ooo`3oool0oooo1ol000020?ooo`80000000<0oooo0000003oool00P3oool010000000
oooo0000003oool30?nf`@030000003o]/40okK102D0okK10_ooool01P00003oooooooooooooool0
0000ooooo`<0000000Gooooo00000?l0003oooooo`000003ooooo`04o`000?ooooooooooo`0000<0
00000oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool00_oooolZ0?nf`@l0oooo00?o003o0?ooo`3oool0
2P3oool00ol00?l0oooo0?ooo`080?ooobX0okK13?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool03oooool02_l0003oooooooooo`00003ooooo0000
0?ooool00000ooooo`000002ooooo`0400000?ooooooooooooooo`?o00001?ooool01`00003ooooo
00000?ooool00000ooooo`0000000P3o]/401@000000okK10?nf`@3o]/4000000240okK100<00000
0?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo
o`000002o`0000L0oooo0_l000020?ooo`030000003oool000000080oooo00D000000?ooo`3ooooo
00000?ooo`030?nf`@030000003o]/40okK102@0okK10oooool01@00003oooooooooo`00003ooooo
00@0000000?oooooo`000?l000001Oooool00ol0003oooooo`00000200000005ooooo`00003ooooo
ooooool000002_ooool000Wooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00;ooooo:P3o]/4>0?ooo`03o`00o`3oool0oooo00`0oooo00?o003o0?oo
o`3oool01`3ooolZ0?nf`@cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00oooooo00[o0000ooooooooool00000ooooo`00003ooooo00000?ooool0
00000_ooool01000003oooooooooool00003ooooo`0;o`000?ooooooooooooooo`00003ooooo0000
0?oooooo0000ooooo`0000000P3o]/401@000000okK10?nf`@3o]/4000000240okK100D000000?oo
o`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?ooool000000`3oool7
o`000080oooo00Ko00000?ooo`3ooooo00000?ooo`0000020?ooo`040000003oool0oooo000000@0
okK100<000000?nf`@3o]/408`3o]/43ooooo`0500000?oooooooooo00000?ooool0100000000ooo
oooo0000o`000005ooooo`03o`000?oooooo00000080000000Gooooo00000?ooooooooooo`00000:
ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00Co003ooooo
oooooooooooo:@3o]/4>0?ooo`03o`00o`3oool0oooo00d0oooo00?o003o0?ooo`3oool0203ooolY
0?nf`@cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo00oooooo00[o0000ooooooooool00000ooooo`00003ooooo00000?ooool000000_ooool01000
003oooooooooool00004ooooo`0:o`000?oooooooooo00000?ooool00000ooooo`00003ooooo0000
0080okK100D000000?nf`@3o]/40okK10000000Q0?nf`@050000003oool0oooo0?ooo`0000000`3o
ool00`000000ooooo`0000020?ooo`030000003ooooo00000080oooo00?o00000?ooo`3oool01@3o
ool3o`000080oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00<0okK1
00<000000?nf`@3o]/408`3o]/43ooooo`0500000?oooooooooo00000?ooool0100000001Ooooooo
0000o`000?oooooo000000?ooooo00?o0000ooooool000000P0000001Oooool00000oooooooooooo
000000[ooooo0009ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03?ooool01?l0
0?oooooooooooooooolY0?nf`@d0oooo00?o003o0?ooo`3oool03`3oool00ol00?l0oooo0?ooo`07
0?ooobT0okK13?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool03oooool02_l0003oooooooooo`00003ooooo00000?ooool00000ooooo`000002oooo
o`0400000?ooooooooooo`0000Cooooo00[o0000ooooooooool00000ooooo`00003ooooo00000?oo
ool000000P3o]/401@000000okK10?nf`@3o]/4000000240okK100D000000?ooo`3oool0oooo0000
00030?ooo`070000003oool000000?ooo`000000ooooo`0000020?ooo`03o`00003oool0oooo00P0
oooo0_l000001@3oool000000?ooo`3oool000000080oooo00@000000?ooo`000000oooo0`3o]/40
0`000000okK10?nf`@0S0?nf`@?ooooo00D00000ooooooooool00000ooooo`0400000004ooooool0
003o0000ooooo`;o00000oooool2o`000080000000Gooooo00000?ooooooooooo`00000:ooooo`00
2Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo00Co003ooooooooooooo
oooo:@3o]/4<0?ooo`03o`00o`3oool0oooo0140oooo00?o003o0?ooo`3oool01P3ooolY0?nf`@co
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00oo
oooo00co0000ooooooooool00000ooooo`00003ooooo00000?ooool00000ooooo`000002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool01`00003ooooo0000003o]/400000
0?nf`@0000000`3o]/400`000000okK10?nf`@0N0?nf`@030000003oool0oooo0080oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`030000003ooooo00000080oooo00?o00000?ooo`3oool0
1Ol000030?ooo`05o`00003ooooo00000?ooo`0000000P3oool00ol00000oooo000000020?ooo`03
0000003o]/40okK10080okK100<000000?nf`@3o]/408P3o]/43ooooo`0500000?oooooooooo0000
0?ooool0100000001?l0003oooooo`000?l00002ooooo`05o`000?ooooooooooo`000?ooool00P00
00001Oooool00000oooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool03?ooool01?l00?oooooooooooooooolY0?nf`@`0oooo00?o003o0?ooo`3oool0
4@3oool00ol00?l0oooo0?ooo`060?ooobT0okK13?ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00?ooooo00?o0000ooooooooool03oooool03?l0003oooooooooo`00003ooooo0000
0?ooool00000ooooo`00003ooooo000000;ooooo00?o0000ooooooooool01?ooool03?l0003ooooo
ooooo`00003ooooo00000?ooool000000?nf`@000000okK1000000<0okK100<000000?nf`@3o]/40
7P3o]/400`000000oooo0?ooo`020?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000
ooooo`000080oooo00Co00000?ooo`3ooooo00001@3oool01?l00000oooo0?ooool000020?ooo`05
o`00003oool000000?ooo`0000000P3oool00`000000oooo000000040?nf`@03o`00003o]/40okK1
0280okK10oooool01@00003oooooooooo`00003ooooo00@0000000Co0000ooooool0003o00000ooo
ool01?l0003oooooooooool0000200000005ooooo`00003oooooooooool000002_ooool000Wooooo
00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`04o`00ooooooooooooooooobP0
okK13@3oool00ol00?l0oooo0?ooo`060?ooo`?o0000203oool00ol00?l0oooo0?ooo`070?ooobP0
okK13?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool03oooool03?l0003oooooooooo`00003ooooo00000?ooool00000ooooo`00003ooooo000000;o
oooo00?o0000ooooooooool01?ooool03?l0003oooooooooo`00003ooooo00000?ooool000000?nf
`@000000okK1000000<0okK100<000000?nf`@3o]/407P3o]/400`000000oooo0?ooo`020?ooo`0:
0000003oool0oooo0000003oool000000?ooo`000000ooooo`000080oooo00Co00000?ooo`3ooooo
00001@3oool01?l00000oooo0?ooool000020?ooo`05o`00003oool000000?ooo`0000000P3oool0
10000000oooo0000003oool30?nf`@030000003o]/40okK10280okK10oooool01@00003ooooooooo
o`00003ooooo00@0000000Co0000ooooool0003o00000oooool01?l0003oooooooooool000020000
0005ooooo`00003oooooooooool000002_ooool000Wooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`04o`00ooooooooooooooooobP0okK13@3oool00ol00?l0oooo0?ooo`05
0?ooo`Go0000203oool00ol00?l0oooo0?ooo`060?ooobP0okK13?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03oooool03?l0003oooooooooo`00
003ooooo00000?ooool00000ooooo`00003ooooo000000;ooooo00?o0000ooooooooool01?ooool0
3?l0003oooooooooo`00003ooooo00000?ooool000000?nf`@000000okK1000000<0okK100<00000
0?nf`@3o]/407P3o]/400`000000oooo0?ooo`020?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000ooooo`000080oooo00Co00000?ooo`3ooooo00001P3oool02_l00000oooo0?ooool0
0000ooooo`00003oool000000?ooo`0000020?ooo`040000003oool000000?ooo`<0okK100<00000
0?nf`@3o]/408P3o]/43ooooo`0500000?oooooooooo00000?ooool0100000001?l0003oooooo`00
0?l00003ooooo`04o`000?ooooooooooo`0000@000000_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooo`3o]/40
:03o]/4=0?ooo`03o`00o`3oool0oooo00D0oooo1Ol000080?ooo`03o`00o`3oool0oooo00H0oooo
:03o]/4<ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol0003ooooo
ooooo`0?ooooo`0>o`000?oooooooooo00000?ooool00000ooooo`00003ooooo00000?ooool00000
ooooool00008ooooo`09o`000?ooool00000ooooo`00003ooooo0000003o]/4000000080okK100@0
00000?nf`@3o]/400000803o]/400`000000oooo0?ooo`020?ooo`0<0000003oool0oooo0000003o
ool000000?ooo`000000ooooo`00003ooooo00000P3oool00ol00000oooo0?ooo`050?ooo`04o`00
003oool0ooooo`000080oooo00Oo00000?ooo`000000oooo0000003ooooo00000080oooo00<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@0Q0?nf`@?ooooo00D00000ooooooooool00000oooo
o`04000000;o000000?oooooo`000?ooool00oooool3o`0000<0000000Cooooo00000?oooooo0000
2_ooool000Wooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
ool0okK102P0okK13@3oool00ol00?l0oooo0?ooo`050?ooo`Go0000203oool00ol00?l0oooo0?oo
o`060?ooobP0okK13?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o
0000ooooooooool03oooool03_l0003oooooooooo`00003ooooo00000?ooool00000ooooo`00003o
oooo00000?oooooo00002?ooool02Ol0003ooooo00000?ooool00000ooooo`000000okK100000002
0?nf`@040000003o]/40okK100000200okK100<000000?ooo`3oool00P3oool030000000oooo0?oo
o`000000oooo0000003oool000000?ooool00000ooooo`000080oooo00?o00000?ooo`3oool01P3o
ool03?l00000oooo0?ooool00000ooooo`00003oool000000?ooo`000000oooo00000080oooo00<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@0Q0?nf`@?ooooo00D00000oooooooooooo0000
ooooo`04000000;o000000?oooooo`000?ooool00oooool4o`00000600000?ooool0000000000?oo
oooo00002_ooool000Wooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03
o`00ooooool0okK102P0okK13@3oool00ol00?l0oooo0?ooo`060?ooo`?o00002@3oool00ol00?l0
oooo0?ooo`060?ooobP0okK13?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool03oooool03_l0003oooooooooo`00003ooooo00000?ooool00000oooo
o`00003ooooo00000?oooooo00002?ooool02Ol0003ooooo00000?ooool00000ooooo`000000okK1
000000020?nf`@040000003o]/40okK100000200okK100<000000?ooo`3oool00P3oool030000000
oooo0?ooo`000000oooo0000003oool000000?ooool00000ooooo`000080oooo00?o00000?ooo`3o
ool01P3oool03?l00000oooo0?ooool00000ooooo`00003oool000000?ooo`000000oooo00000080
oooo00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@0Q0?nf`@?ooooo00D00000oooooooo
ool00000ooooo`04000000;o000000?oooooo`000?ooool00oooool3o`000080000000Gooooo0000
0000003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00kooooo00?o003oooooo`3o]/40:03o]/4=0?ooo`03o`00o`3oool0oooo0180oooo00?o003o0?oo
o`3oool01P3ooolX0?nf`@cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03oooo
o`03o`000?oooooooooo00oooooo00ko0000ooooooooool00000ooooo`00003ooooo00000?ooool0
0000ooooo`00003oooooo`0000Wooooo00_o0000ooooo`00003ooooo0000003o]/4000000?nf`@00
0000okK1000000030?nf`@030000003o]/40okK101d0okK100<0oooo0000003oool00`3oool03000
0000oooo0?ooo`000000oooo0000003oool000000?ooool00000ooooo`000080oooo00?o00000?oo
o`3oool0103oool02?l00000oooo0?ooool00000ooooo`00003oool000000P3oool00`000000oooo
o`0000020?ooo`030000003o]/40okK10080okK100<000000?nf`@3o]/408@3o]/43ooooo`050000
0?oooooooooo00000?ooool010000003o`0000Gooooo00Go0000ooooool000000000ooooo`030000
0003ooooool0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0X0?nf`@h0oooo00?o003o0?ooo`3oool0403oool00ol00?l0
oooo0?ooo`070?ooobP0okK13?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool03oooool03_l0003oooooooooo`00003ooooo00000?ooool00000oooo
o`00003ooooo00000?oooooo00001?ooool3o`0000;ooooo00_o0000ooooo`00003ooooo00000?oo
ool000000?nf`@000000okK1000000030?nf`@030000003o]/40okK101d0okK100<0oooo0000003o
ool00`3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooool000020?ooo`03o`00
003oool0oooo00Co000000<0ooooo`00003oool00P3oool01Ol00000ooooo`00003oool000000080
oooo00<000000?ooo`0000000P3oool00`000000okK10?nf`@020?nf`@030000003o]/40okK10240
okK10oooool01@00003oooooooooo`00003ooooo00@000000ol000001ooooooo0000o`000?l0003o
ooooo`000?ooool00_l00003000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02P0okK13P3oool0
0ol00?l0oooo0?ooo`0@0?ooo`03o`00o`3oool0oooo00L0oooo:03o]/4<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`0>o`000?oooooo
oooo00000?ooool00000ooooo`00003ooooo00000?ooool00000ooooool00002ooooo`;o00000_oo
ool03_l0003oooooooooool0003ooooo00000?ooool00000ooooo`000000okK10000003o]/400000
0`3o]/400`000000okK10?nf`@0M0?nf`@030?ooo`000000oooo00<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo00000080oooo00Co00000?ooo`3ooooo00001@3oool00ol00000oooo0?oo
o`020?ooo`05o`00003ooooo00000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000
003o]/40okK10080okK100<000000?nf`@3o]/408@3o]/43ooooo`0500000?oooooooooo00000?oo
ool010000003o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`0000<000000_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool0:@3o]/4>0?ooo`03o`00o`3oool0oooo00l0oooo00?o003o0?oo
o`3oool01P3ooolY0?nf`@cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03oooo
o`03o`000?oooooooooo00oooooo00ko0000ooooooooool00000ooooo`00003ooooo00000?ooool0
0000ooooo`00003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?oo
ool00000ooooo`00003ooooo0000003o]/4000000?nf`@0000000`3o]/400`000000okK10?nf`@0N
0?nf`@030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00020?ooo`04o`00003oool0ooooo`0000H0oooo0ol000001`3ooooo00000?ooo`3oool000000?oo
o`0000000P3oool010000000oooo0?ooo`0000030?nf`@030000003o]/40okK10280okK10_ooool0
1P00003oooooooooooooool00000ooooo`@000000ol000001ooooooo0000ooooool0003oooooo`00
0?ooool00_l00003000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02T0okK13`3oool00ol00?l0
oooo0?ooo`0=0?ooo`03o`00o`3oool0oooo00L0oooo:@3o]/4<ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`0>o`000?oooooooooo0000
0?ooool00000ooooo`00003ooooo00000?ooool00000ooooool00002ooooo`03o`000?oooooooooo
00;ooooo00go0000ooooool0003ooooo00000?ooool00000ooooo`000000okK10000003o]/400000
00<0okK100<000000?nf`@3o]/407P3o]/400`3oool000000?ooo`030?ooo`060000003oool0oooo
0000003oool000000P3oool010000000oooo0?ooool000020?ooo`Ko0000103oool00ol00000oooo
000000020?ooo`03o`00003oool000000080oooo00<000000?nf`@3o]/400P3o]/400ol00000okK1
0?nf`@0R0?nf`@;ooooo00L00000ooooooooool00000ooooo`00003ooooo00<000000ol000001_oo
oooo0000oooooooooooo0000ooooo`?o00000`000002ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?oooooo0?nf`@0X
0?nf`A00oooo0_l00?l;0?ooo`;o003o2P3ooolY0?nf`@cooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00ko0000ooooooooool00000oooo
o`00003ooooo00000?ooool00000ooooo`00003oooooo`0000;ooooo00?o0000ooooooooool00_oo
ool03Ol0003oooooo`000?ooool00000ooooo`00003ooooo0000003o]/4000000?nf`@0000000`3o
]/400`000000okK10?nf`@0N0?nf`@030?ooo`000000oooo00<0oooo00L000000?ooo`3oool00000
o`00003oool000000080oooo0P0000000`3ooooo0000o`0000060?ooo`Co000000D0oooo00000?l0
0000oooo000000020?ooo`040000003oool0oooo000000@0okK100<000000?nf`@3o]/408P3o]/42
ooooo`0700000?oooooooooo00000?ooool00000ooooo`03000000?o000000Koooooo`000?oooooo
ooooo`000?ooool3o`0000<000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooo`3o]/40:03o]/4B0?ooo`03
o`00o`3oool0oooo00L0oooo00?o003o0?ooo`3oool02P3ooolY0?nf`@cooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00ko0000oooooooo
ool00000ooooo`00003ooooo00000?ooool00000ooooo`00003oooooo`0000;ooooo00?o0000oooo
ooooool00_ooool03Ol0003oooooo`000?ooool00000ooooo`00003ooooo0000003o]/4000000?nf
`@0000000`3o]/400`000000okK10?nf`@0N0?nf`@80oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`04o`0000000000oooo0?ooo`80000000<0ooooo`000?l000001?l0
00040?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000103o]/400`000000
okK10?nf`@0R0?nf`@;ooooo00L00000ooooooooool00000ooooo`00003ooooo00<000000ol00000
1_oooooo0000oooooooooooo0000ooooo`?o00000`000002ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool03oooool00ol00?oooooo0?nf
`@0Y0?nf`A80oooo1Ol00?l20?ooo`;o003o303ooolZ0?nf`@cooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo013o0000ooooooooool00000
ooooo`00003ooooo00000?ooool00000ooooo`00003oooooo`000?oooooo00001Oooool01ol0003o
ooooooooool0003ooooo00000?ooool00P0000001@3o]/4000000?nf`@3o]/4000000080okK100<0
00000?nf`@3o]/407`3o]/420?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000040?nf`@030000003o]/40okK102<0okK100?ooooo00000?ooool00_ooool0
0`00003ooooo0000000300000003o`000?oooooo000000;o00001?ooool4o`0000<000000_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00oooooo00?o003oooooo`3o]/40:@3o]/4G0?ooo`;o003o3P3ooolZ0?nf`@cooooo00Co003ooooo
oooooooooooo0ol00005ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03oooool0
4?l0003oooooooooo`00003ooooo00000?ooool00000ooooo`00003ooooo00000?oooooo0000oooo
ool00005ooooo`07o`000?ooooooooooo`000?ooool00000ooooo`02000000050?nf`@000000okK1
0?nf`@0000000P3o]/400`000000okK10?nf`@0O0?nf`@80oooo00?o00000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000030?ooo`060000003oool0oooo0?ooo`00003o00001`0000000`3oool0
0000000000020?ooo`8000000`3oool00ol00000okK10?nf`@020?nf`@030000003o]/40okK102<0
okK100?ooooo00000?ooool00_ooool00`00003ooooo0000000300000003o`000?oooooo000000;o
00001?ooool4o`0000<000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooo`3o]/40:P3o]/4U0?ooob/0okK1
3?ooool00ol00?ooooooooooo`05o`0000Cooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0?ooooo`0@o`000?oooooooooo00000?ooool00000ooooo`00003ooooo00000?ooool00000
ooooool0003oooooo`0000Gooooo00Oo0000oooooooooooo0000ooooo`00003ooooo0080000000D0
okK10000003o]/40okK1000000020?nf`@030000003o]/40okK10200okK100<0oooo0000003oool0
103oool01P000000oooo0?ooo`3ooooo000000000080oooo00?o00000000000000002@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0S
0?nf`@03ooooo`00003ooooo00;ooooo00P00000ooooo`0000000000o`000000003o0000ooooo`?o
00001?ooool4o`0000<000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooo`3o]/40:`3o]/4S0?ooob/0okK1
3?ooool00ol00?ooooooooooo`05o`0000Cooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0?ooooo`0@o`000?oooooooooo00000?ooool00000ooooo`00003ooooo00000?ooool00000
ooooool0003oooooo`0000Gooooo00Oo0000oooooooooooo0000ooooo`00003ooooo0080000000D0
okK10000003o]/40okK1000000020?nf`@030000003o]/40okK10280okK100<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool3000000<0oooo0`0000030?ooo`030000
003oool0oooo00<0oooo00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@0T0?nf`@030000
0?oooooooooo00;ooooo00<00000ooooo`0000000`0000000ol0003oooooo`000002o`0000Cooooo
1?l00003000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00ooooool0okK102/0okK18P3oool[0?nf`@gooooo00?o
003oooooooooool01Ol00004ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03ooo
ool01_l0003oooooooooo`00003ooooo000000;ooooo0P0000001_ooool00000ooooool0003ooooo
o`0000Kooooo00go0000ooooool0003ooooo00000?ooool00000ooooo`000000okK10000003o]/40
000000<0okK100<000000?nf`@3o]/408@3o]/400`3oool000000?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool3000000D0oooo00?o00000?ooo`3oool00`3oool0
0`000000okK10?nf`@030?nf`@030000003o]/40okK102<0okK100?o0000ooooooooool00_ooool0
1000003ooooo00000?ooool3000000;o000000?oooooo`000?l000001?ooool4o`0000<000000_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooo
oooo00Gooooo0ol00007ooooo`03o`00ooooool0okK102`0okK1803oool/0?nf`@gooooo00Co003o
oooooooooooooooo0ol00005ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03ooo
ool01?l0003oooooooooo`000002ooooo`0:00000?ooool0000000000?ooool00000ooooool0003o
ooooo`0000Kooooo00go0000ooooool0003ooooo00000?ooool00000ooooo`000000okK10000003o
]/40000000<0okK100<000000?nf`@3o]/408P3o]/400`3oool00000000000040?ooo`0300000?l0
000000000080oooo00?o00000000000000000`0000030?ooo`D000000`3oool200000003o`00003o
]/40okK100<0okK100<000000?nf`@3o]/408P3o]/42000000Gooooo00@00000ooooo`00003ooooo
0`000002o`000003ooooool0003o000000Cooooo1?l00003000000;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`04ooooo`Go00001_oo
ool00ol00?oooooo0?nf`@0]0?nf`Ah0oooo;@3o]/4=ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000;ooooo
00X00000ooooo`0000000000ooooo`00003oooooo`000?oooooo00001_ooool03Ol0003oooooo`00
0?ooool00000ooooo`00003ooooo0000003o]/4000000?nf`@0000000`3o]/400`000000okK10?nf
`@0S0?nf`@80oooo00<000000?ooo`3oool0103oool2000000H0oooo0`0000060?ooo`8000000P3o
ool50?nf`@030000003o]/40okK10280okK100<000000?nf`@3o]/401Oooool01000003ooooo0000
0?ooool3000000;o000000?oooooo`000?l000001?ooool4o`0000<000000_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Cooooo1Ol0
0006ooooo`03o`00ooooool0okK102h0okK1703oool^0?nf`@gooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooool00000
0_ooool01000003ooooo00000?ooool200000005ooooool0003oooooooooool000001Oooool03Ol0
003oooooooooool000000000ooooo`00003ooooo0000003o]/4000000?nf`@0000000`3o]/400`00
0000okK10?nf`@0T0?nf`@80oooo00<000000?ooo`3oool01@3oool3000000X0oooo0P0000030?oo
o`D0okK100<000000?nf`@3o]/408P3o]/401?l00000okK10?nf`@3o]/44ooooo`0600000?oooooo
ooooo`000000003ooooo0P000003o`000003ooooool0003ooooo00?ooooo1?l00003000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`04ooooo`Go00001_ooool00ol00?ooooooooooo`0_0?nf`AT0oooo<03o]/4=ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooo000000;ooooo00@00000ooooo`00003ooooo0P0000001Ooooooo0000oooooooooooo0000
00Gooooo00go0000oooooooooooo000000000?ooool00000ooooo`000000okK10000003o]/400000
00<0okK100<000000?nf`@3o]/409@3o]/420?ooo`800000203oool3000000<0oooo0`0000001?l0
0000oooo0?ooo`3oool60?nf`@03o`00003o]/40okK10280okK100<000000?nf`@3o]/400P3o]/43
ooooo`0700000?oooooooooo00000?ooool00000ooooo`02000000?o000000?oooooo`000?ooool0
0oooool4o`0000<000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`07ooooo`03o`00oooooooooooo00Gooooo0ol00007ooooo`03o`00oooooooooooo0340okK15@3o
oola0?nf`@kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00oooooo00Co0000ooooooooool000000_ooool01000003ooooo00000?ooool200000005
ooooool0003oooooooooool000001Oooool03Ol0003oooooooooool000000000ooooo`00003ooooo
0000003o]/4000000?nf`@0000000`3o]/400`000000okK10?nf`@0W0?nf`@80oooo00<000000?oo
o`3oool0203oool3000000D0oooo1P3o]/42000002D0okK100@000000?nf`@3o]/40okK11?ooool0
1`00003oooooooooo`00003ooooo00000?ooool00P000003o`000003ooooool0003ooooo00?ooooo
1?l00003000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo03<0okK14@3ooolc0?nf`@kooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Co
0000ooooooooool000000_ooool01000003ooooo00000?ooool200000005ooooool0003ooooooooo
ool000001Oooool03Ol0003oooooooooool000000000ooooo`00003ooooo0000003o]/4000000?nf
`@0000000`3o]/400`000000okK10?nf`@0Y0?nf`@030?ooo`000000000000h0oooo1`3o]/400`00
0000okK10?nf`@0T0?nf`@030000003o]/40okK10080okK10oooool02000003oooooooooooooool0
0000ooooo`00003ooooo0P000003o`000003ooooool0003ooooo00?ooooo1?l00003000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`0?ooooo`04o`00oooooooooooooooooc@0okK13@3ooole0?nf`@kooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo017o0000oooooooooooo
oooo00000?ooool00000ooooo`00003ooooo00000?ooool00000ooooool0003oooooo`000005oooo
o`05o`000?ooooooooooo`000?ooool00P0000001_ooool00000ooooo`000000okK1000000<0okK1
00<000000?nf`@3o]/40:`3o]/400`3oool000000?ooo`0:0?ooo`L0okK10P00000V0?nf`@03o`00
003o]/40okK100<0okK10_ooool01@00003oooooooooooooool0000000;ooooo0P0000000oooool0
0000o`000002o`000003ooooool0003ooooo00?ooooo1?l00003000000;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`04o`00
ooooooooooooooooocP0okK11@3ooolh0?nf`@oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo017o0000oooooooooooooooo00000?ooool0
0000ooooo`00003ooooo00000?ooool00000ooooool0003oooooo`000005ooooo`05o`000?oooooo
ooooo`000?ooool00P0000001_ooool00000ooooo`000000okK1000000<0okK100<000000?nf`@3o
]/40;@3o]/401000003o00000000000000030?ooo`L0okK11000000W0?nf`@030000003o]/40okK1
00<0okK100?ooooo00000?l000001?ooool00`00003oooooooooo`0200000003ooooo`00003o0000
00;o000000?oooooo`000?ooool00oooool4o`0000<000000_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00kooooo00Co003ooooooooo
ooooooooM@3o]/4?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`0?ooooo`0Ao`000?ooooooooooooooo`00003ooooo00000?ooool00000ooooo`00
003ooooo00000?oooooo0000ooooool000001Oooool01Ol0003oooooooooool0003ooooo00800000
00Kooooo00000?ooool000000?nf`@0000030?nf`@030000003o]/40okK10340okK12P00000Z0?nf
`@030000003o]/40okK100@0okK100<00000ooooooooool00oooool01000003oooooooooooooool2
00000003ooooo`00003o000000;o000000?oooooo`000?ooool00oooool4o`0000<000000_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool00_oooomd0?nf`@oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00ko0000oooooooooooooooo00000?oo
ool00000ooooo`00003ooooo00000?ooool00000o`0000?ooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooooooool0003ooooo0080000000Cooooo00000?ooool000000P3o]/4010000000okK1
0?nf`@00001V0?nf`@030000003o]/40okK100@0okK100<00000ooooooooool00_ooool2000000?o
oooo00Go0000ooooo`0000000000ooooo`03o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ool000000_l00003000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;oooooL`3o]/4@ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0?ooooo`0>
o`000?ooooooooooooooo`00003ooooo00000?ooool00000ooooo`00003ooooo00000?l00003oooo
o`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`0200000004ooooo`00003o
oooo00000080okK100@000000?nf`@3o]/400000I@3o]/400`000000okK10?nf`@030?nf`@030000
0?l0003ooooo00?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0200000006oooo
ool0003o0000o`000?oooooo00000oooool00ol0003oooooo`000002o`0000<000000_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool00ooooomb0?nf`A3ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo00ko0000oooooooooooooooo00000?ooool0
0000ooooo`00003ooooo00000?ooool00000o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0
003oooooooooool0003ooooo0080000000Oooooo00000?ooool00000ooooo`3o]/4000000080okK1
00<000000?nf`@3o]/40H`3o]/400`000000okK10?nf`@030?nf`@030000003o]/7ooooo00?ooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`0200000006ooooool0003o0000o`000?oo
oooo00000oooool00ol0003oooooo`000002o`0000<000000_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01?oooom`0?nf`A7ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo00oooooo00ko0000oooooooooooooooo00000?ooool00000ooooo`00003ooooo
00000?ooool00000o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003o
oooo0080000000Cooooo00000?ooool000000_ooool010000000okK10?nf`@00001T0?nf`@030000
003o]/40okK100<0okK100<000000?nf`Oooool00_ooool2000000Cooooo00@00000oooooooooooo
oooo0P0000001_oooooo0000o`000?l0003oooooo`0000?ooooo00?o0000ooooool000000_l00003
000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00CoooooK`3o]/4Booooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooo
ooooo`0000000_ooool02000003ooooo00000?ooool00000ooooo`00003o00000oooool01?l0003o
ooooooooool00003ooooo`08o`000?ooool0000000000?ooool00000ooooo`000002ooooo`040000
003o]/40okK1000006<0okK100<000000?nf`@3o]/400`3o]/400ol00000okK1ooooo`02ooooo`03
00000?oooooooooo00?ooooo00P00000oooooooooooooooo00000?ooool00000ooooo`;o000000Co
ooooo`000?oooooo00000_ooool00ol0003oooooo`000002o`0000<000000_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Ooooom^0?nf`A;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooooooo00000002ooooo`080000
0?ooool00000ooooo`00003ooooo00000?l00003ooooo`04o`000?ooooooooooo`0000?ooooo00So
0000ooooo`0000000000ooooo`00003ooooo000000;ooooo00@000000?nf`@3o]/400000HP3o]/40
0ol00000okK10?nf`@030?nf`@060000003o]/40okK1ooooo`00003o00001?ooool2000000Cooooo
00@00000ooooo`00003ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`00
0?l0003o00000`000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooofd0okK14oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03oooool01Ol0
003oooooooooooooool0000000;ooooo00P00000ooooool0003ooooo00000?ooool00000o`0000Co
oooo00?o0000ooooool000000oooool02?l0003ooooo00000000003ooooo00000?ooool000000_oo
ool010000000okK10?nf`@00001R0?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/7o
oooo00000005ooooo`0300000?oooooooooo00Cooooo00@00000ooooo`00003ooooo0_l000000ooo
oooo0000ooooo`02o`0000?ooooo0ol00003000000;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
ooooK@3o]/4Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00/00000ooooo`00003ooooo00000?ooool0
0000ooooo`00003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00So0000ooooo`000000
0000ooooo`00003ooooo000000;ooooo00@000000?nf`@3o]/400000H@3o]/400`000000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000001?ooool2000000Kooooo00D00000ooooooooool0
0000ooooo`02o`000004ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000P000003
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`06ooooof`0okK11Oooool7o`00o`Sooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool02`00003ooooo00000?ooool00000ooooo`00003ooooo00000?oooooo000000Wo
oooo00So0000ooooo`0000000000ooooo`00003ooooo000000;ooooo00@00000ooooo`3o]/400000
H03o]/400`000000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`Ol000000oooool2000000Ko
oooo00<00000o`000?ooool00_ooool01P00003oooooo`000?l0003oooooo`0000Gooooo00Co0000
oooooooooooo00000P000003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07ooooofX0okK11?ooool2
o`00o`Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`0;00000?ooool0
0000ooooo`00003ooooo00000?ooool00000ooooool000002Oooool02?l0003ooooo00000000003o
oooo00000?ooool000000_ooool01000003oooooooooo`00001P0?nf`@030000003o]/40okK10080
okK100D000000?nf`@3o]/40okK100000003ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool00oooool01P00003oooooo`000?l0003oooooo`0000Gooooo00Co0000oooooooooooo0000
0P000003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`07ooooofT0okK11?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool02@00003ooooo0000
0?ooool00000ooooo`00003ooooo00000002ooooo`03o`000?oooooooooo00Kooooo00So0000oooo
o`0000000000ooooo`00003ooooo000000;ooooo00@00000ooooooooool00000G`3o]/400`000000
okK10?nf`@030?nf`@050000003o]/40okK1ooooo`0000000_ooool00`00003oooooooooo`03oooo
o`8000001_ooool01P00003oooooo`000?l0003oooooo`0000Gooooo00?o0000ooooool000000`00
0003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`08ooooofP0okK10oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`03
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool03000003oooooooooo`00
003ooooo00000?ooool00000ooooo`00003oooooo`0000Oooooo00?o0000ooooooooool00P000000
1?ooool00000ooooo`000002ooooo`0500000?ooooooooooooooo`000000GP3o]/400`000000okK1
0?nf`@020?nf`@050000003o]/40okK10?nf`@0000000_ooool01000003oooooooooooooool30000
00Oooooo00P00000oooooooooooo0000ooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_l000000oooool0000000000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooofL0okK11?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool03000003oooooooooo`00003ooooo00000?ooool00000ooooo`00003oooooo`0000Oooooo00?o
0000ooooooooool00P0000001?ooool00000ooooo`000002ooooo`0500000?ooooooooooooooo`00
0000G@3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000_ooool01Ol0
003oooooooooooooool0000000[ooooo00P00000oooooooooooo0000ooooool0003oooooo`0000;o
oooo0_l000001Ooooooo0000o`000000003ooooo008000000_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool02OoooomV0?nf`@?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00`00000ooooooooool00000ooooo`00003ooooo00000?ooool00000
ooooool00007ooooo`03o`000?oooooooooo0080000000Cooooo00000?ooool000000_ooool01@00
003oooooooooooooool0000005d0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@00
0002ooooo`0500000?ooooooooooooooo`0000002oooool02P00003oooooooooool0003oooooo`00
0?oooooo0000ooooool00003ooooo`;o000000<00000ooooo`0000000P0000000ooooooo0000oooo
o`09ooooo`002Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool02_oooomT0?nf`@?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00X00000ooooooooool00000ooooo`00003ooooo00000?oo
ool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`80000000Cooooo
00000?ooool000000_ooool01P00003oooooooooooooool00000oooooe/0okK100<000000?nf`@3o
]/400P3o]/4010000000okK10?nf`@000003ooooo`0400000?oooooooooo000000cooooo00H00000
oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l000000`00003ooooo
0000000200000003ooooool0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo00[ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooof80okK11?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool02P00003ooooooooo
o`00003ooooo00000?ooool00000ooooo`000002ooooo`03o`000?oooooooooo00?ooooo00[o0000
ooooooooool00000ooooo`00003ooooo00000?ooool000000_ooool01@00003oooooooooooooool0
000000;oooooFP3o]/400`000000okK10?nf`@020?nf`@04o`00003o]/40okK1000000;ooooo00@0
0000ooooooooool000003_ooool01P00003oooooooooool0003oooooo`0000Gooooo00?o0000oooo
ool000000`0000001?ooool00000ooooool0000:ooooo`002Oooool00ol0003oooooooooo`0:oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?oooomP0?nf`@Cooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00T00000oooo
o`00003ooooo00000?ooool00000o`00000000000oooool01?l0003oooooooooooooool2o`0000;o
oooo00L00000ooooo`00003ooooo00000?ooool0000000;ooooo00D00000oooooooooooooooo0000
0003oooooeP0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@000002ooooo`040000
0?oooooooooo000000Cooooo0`000008ooooo`0600000?ooooooooooo`000?oooooo00001Oooool0
0ol0003oooooo`00000300000004ooooo`00003oooooo`0000[ooooo0009ooooo`03o`000?oooooo
oooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<oooooel0okK11?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
1@00003ooooo00000?ooool0000000;ooooo0P000004ooooo`03o`000?oooooo000000Cooooo00L0
0000ooooo`00003ooooo00000?ooool0000000;ooooo00D00000oooooooooooooooo00000003oooo
oeP0okK100<000000?nf`@3o]/400P3o]/4010000000okK1ooooo`000002ooooo`0400000?oooooo
oooo000000;ooooo0P000003ooooo`0300000?oooooooooo00Gooooo00Ko0000oooooooooooo0000
ooooool00005ooooo`03o`000?oooooo000000<0000000Cooooo00000?oooooo00002_ooool000Wo
oooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00go
ooooGP3o]/43ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`0:00000?oooooooooo00000?ooool00000ooooo`00003ooooo000000Cooooo
00?o0000ooooooooool00_ooool02000003oooooooooo`00003ooooo00000?ooool000000_ooool0
1@00003oooooooooooooool0000000CoooooEP3o]/400`000000okK10?nf`@020?nf`@040000003o
]/40okK1000000;ooooo00@00000ooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00L00000ooooooooooooooooo`000?oooooo000000?ooooo00Go0000
ooooool000000000ooooo`0200000004ooooo`00003oooooo`0000[ooooo0009ooooo`03o`000?oo
oooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0>oooooe`0okK11?oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000000ooo
ool02000003oooooooooo`00003ooooo00000?ooool000000_ooool00`00003oooooooooo`06oooo
o`0800000?oooooooooo00000?ooool00000ooooo`000002ooooo`0500000?ooooooooooooooo`00
00001OoooomE0?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/401000003oooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Oooooo00<00000ooooooooool01Oooool01000003ooooooooo
ool00002ooooo`?o00000_ooool00ol000000000ooooo`0200000004ooooo`00003oooooo`0000[o
oooo0009ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0@oooooeX0okK11?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`0000000oooool02000003oooooooooo`00003ooooo00000?ooool000000_ooool0
0ol0003oooooooooo`06ooooo`0800000?oooooooooo00000?ooool00000ooooo`000002ooooo`05
00000?ooooooooooooooo`0000001_oooomC0?nf`@030000003o]/40okK10080okK100@000000?nf
`Oooool000000_ooool01000003oooooooooo`000002ooooo`0300000?oooooooooo00Gooooo00<0
0000ooooooooool01Oooool01000003oooooooooool00007ooooo`03o`000000003ooooo00800000
00Cooooo00000?oooooo00002_ooool000Wooooo00?o0000ooooooooool03?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo017oooooF03o]/45ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool03oooool00ol0003ooooo00000003ooooo`0800000?oooooooooo00000?oo
ool00000ooooo`000002ooooo`0300000?oooooooooo00Kooooo00P00000ooooooooool00000oooo
o`00003ooooo000000;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04oooooe80
okK100H000000?nf`@3o]/40okK10000003o]/42ooooo`0300000?ooool0000000;ooooo00@00000
ooooooooool000002?ooool00`00003oooooooooo`06ooooo`0400000?ooooooooooo`0000Gooooo
00[o0000ooooo`0000000000ooooo`00003ooooo00000?oooooo00002_ooool000Wooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;oooooE@3o]/47
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003ooooo00000003
ooooo`0400000?oooooooooo000000;ooooo00<00000ooooo`0000000_ooool00`00003ooooooooo
o`05ooooo`0600000?oooooooooo00000?ooool000000_ooool01000003oooooooooo`000003oooo
o`0300000?oooooooooo00GoooooD03o]/400`000000okK10?nf`@020?nf`@07o`000?oooooooooo
ooooo`00003ooooo00000002ooooo`0400000?oooooooooo000000Sooooo00?o0000ooooooooool0
1_ooool01000003oooooooooool00005ooooo`05o`000?ooool0000000000?ooool00P000002oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Doooooe<0okK11oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`0000000oooool01000003oooooooooo`000002ooooo`0300000?ooool0
000000;ooooo00<00000ooooooooool01Oooool01P00003oooooooooo`00003ooooo000000;ooooo
00@00000ooooooooool000001?ooool2000000KoooooC`3o]/401P000000okK10?nf`@3o]/7ooooo
000000;ooooo00<00000ooooo`0000000_ooool01000003oooooooooo`000009ooooo`0300000?oo
oooooooo00Oooooo00@00000oooooooooooo00000_ooool2o`0000;ooooo0P0000000oooool00000
00000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00cooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Foooooe00okK12?ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l02Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0000000?ooooo00@00000ooooooooool000000_ooool00`00003ooooo
00000002ooooo`0300000?oooooooooo00Gooooo00H00000ooooooooool00000ooooool00002oooo
o`0400000?oooooooooo000000Kooooo00<00000ooooooooool01Ooooom=0?nf`@030000003o]/40
okK100;ooooo00P00000ooooooooool00000ooooo`00003oooooo`0000?ooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`03ooooo`8000000oooool00ol0003oooooooooo`02o`0000Co
oooo0P0000000oooool0000000000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Gooooodh0okK1
2?ooool00ol00?ooooooooooo`05ooooo`?o00002Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo00000004ooooo`030000
0?ooool0000000;ooooo00<00000ooooo`0000000oooool00`00003oooooooooo`04ooooo`060000
0?oooooooooo00000?ooool000000_ooool01@00003oooooooooooooool0000000Kooooo0`000005
oooood/0okK100<000000?nf`@3o]/400_ooool01P00003oooooooooo`00003ooooo000000;ooooo
00@00000ooooooooool000002_ooool01P00003ooooooooooooooooo0000000000;ooooo00@00000
ooooooooool000001oooool200000004ooooo`00003ooooo000000;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01WoooooC03o]/49ooooo`03o`00oooooooooooo00Cooooo1Ol00007ooooo`03o`00oooo
oooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oo
ool0000000;ooooo00<00000ooooo`0000000oooool00`00003oooooooooo`04ooooo`0400000?oo
oooooooo000000;ooooo00<00000ooooo`0000000oooool00`00003oooooooooo`07oooooa<00000
00?o00000000000000000`00000g0?nf`@050000003o]/7oooooooooo`0000000_ooool01P00003o
ooooooooool0003ooooo000000;ooooo00<00000ooooooooool02Oooool01000003oooooooooo`00
0005ooooo`0400000?oooooooooo000000Gooooo00Oo0000ooooo`00003ooooo00000?ooool00000
00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01[oooooBP3o]/4:ooooo`03o`00oooooooooooo00Co
oooo1Ol00007ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`04ooooo`0300000?ooool0000000;ooooo00<00000ooooo`0000000oooool00`00003o
ooooooooo`04ooooo`0400000?oooooooooo000000;ooooo00@00000oooooooooooo00000_ooool0
0ol000000000ooooo`0>oooooa80okK12`00000/0?nf`@0500000?ooooooooooooooo`0000000_oo
ool01P00003oooooooooo`00003ooooo000000;ooooo00<00000ooooooooool02Oooool01000003o
ooooooooo`000005ooooo`0400000?oooooooooo000000Cooooo0P0000001_ooool00000ooooo`00
003ooooo000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01coooooAP3o]/4;ooooo`03o`00oooo
oooooooo00Gooooo1Ol00007ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`04ooooo`0300000?ooool0000000;ooooo00<00000ooooo`0000000ooo
ool00`00003oooooooooo`04ooooo`0400000?oooooooooo000000;ooooo00@00000ooooooooool0
00001?ooool2000000oooooo6`3o]/47000002@0okK100<00000ooooooooool00_ooool01000003o
ooooooooo`000002ooooo`0300000?ooool0000000;ooooo00<00000ooooooooool02?ooool01000
003oooooooooo`000007ooooo`0500000?oooooooooo00000?ooool00P000003ooooo`0500000?oo
ool00000ooooo`0000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07_oooom40?nf`@cooooo00?o
003oooooooooool01_ooool3o`0000Sooooo00?o003oooooooooool05Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00?ooooo00L00000oooooooooooooooo00000?ooool0000000;o
oooo00@00000ooooooooool000001_ooool01@00003oooooooooooooool0000000;ooooo00@00000
ooooooooool000001Oooool00`00003oooooooooo`0=ooooob40okK11`00000L0?nf`@03ooooo`00
003ooooo00;ooooo00@00000ooooooooool000000_ooool00`00003ooooo00000002ooooo`030000
0?oooooooooo00Wooooo00@00000ooooooooool000002?ooool01000003oooooooooo`000004oooo
o`0300000?oooooooooo008000000oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l08ooooom00?nf`@kooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool01`00003oooooooooooooool00000ooooo`0000000_ooool01000003ooooooooo
o`000006ooooo`0500000?ooooooooooooooo`0000000_ooool01000003oooooooooo`000006oooo
o`03o`0000000000000001P00000703o]/400`00003o000000000004000001<0okK100?ooooo0000
000000001?ooool01?l0003oooooooooo`000002ooooo`0300000?ooool0000000;ooooo00<00000
ooooooooool02?ooool01?l0003oooooooooool00004ooooo`8000000oooool00ol0003ooooooooo
o`05ooooo`0500000?ooool00000o`00000000000oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o02Kooooo?03o]/4?ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00?ooooo00L00000oooooooooooooooo00000?ooool0000000;ooooo00@00000oooooooo
ool000001_ooool01@00003oooooooooooooool0000000;ooooo00D00000oooooooooooooooo0000
000Hooooo`P0okK12P00000I0?nf`@@000003@3o]/42ooooo`0300000?oooooooooo00?ooooo00D0
0000oooooooooooooooo00000002ooooo`0300000?ooool0000000;ooooo00<00000ooooooooool0
1oooool01000003oooooooooo`000003ooooo`8000000_ooool01@00003oooooooooooooool00000
00Kooooo00D00000ooooo`00003ooooo00000003ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01;ooooo00?o003oooooooooool09_oooolj0?nf`A3ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool01000003oooooooooo`000002ooooo`0400000?oooooooooo000000;ooooo00<0
0000ooooooooool01Oooool01@00003oooooooooooooool0000000;ooooo00@00000oooooooooooo
oooo0`00000Foooooa40okK12`00000B0?nf`@<000002@3o]/400oooool0000000000006ooooo`04
00000?oooooooooo000000;ooooo00<00000ooooo`0000000oooool00`00003oooooooooo`07oooo
o`0400000?oooooooooo000000;ooooo00<00000ooooooooool00oooool01@00003ooooooooooooo
ool0000000Cooooo00H00000ooooooooool00000ooooo`000003ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03kooooo=@3o]/4Booooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo
00@00000ooooooooool000000_ooool01000003oooooooooo`000002ooooo`0300000?oooooooooo
00Kooooo00@00000ooooooooool000000oooool2000000Cooooo0P0000000ol00000000000000006
00000003o`0000000000000000l0000000?o00000000000000004P3o]/4400000140okK12P000007
ooooo`0500000?ooooooooooooooo`0000000_ooool00`00003ooooo00000003ooooo`0300000?oo
oooooooo00Kooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`05ooooo`060000
0?ooooooooooooooo`00003ooooo0`000002ooooo`0700000?ooool00000ooooool0003oooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`11ooooobl0okK15Oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`0400000?oooooooooo000000;ooooo00@00000ooooooooool000000_ooool00`00003ooooo
ooooo`06ooooo`0400000?oooooooooo000000Gooooo00<00000ooooooooool07Oooool40?nf`@/0
00002`3o]/47000000h0okK13Oooool01@00003oooooooooooooool0000000;ooooo00<00000oooo
o`0000000oooool00`00003oooooooooo`06ooooo`0400000?oooooooooo000000;ooooo00<00000
ooooooooool01_ooool01Ol0003oooooooooool00000000000Gooooo00L00000ooooo`00003ooooo
00000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo033ooooo5?l00?lY0?nf`ASooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool01000003oooooooooo`000002ooooo`0400000?oooooooooo0000
00;ooooo00<00000ooooooooool01oooool01000003oooooooooo`000005ooooo`<000004Oooool<
000000;ooooo303o]/47000000/0okK10`0000080?nf`@oooooo00D00000oooooooooooooooo0000
0002ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool01Oooool01000003ooooo
ooooo`000002ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool01`00003o
oooo00000?ooool00000ooooool000002_ooool000Wooooo00?o0000ooooooooool0;?ooool4o`00
oaCooooo2Ol00?lM0?nf`A_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Ioooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool01000003oooooooooo`000002
ooooo`0600000?oooooooooo00000?ooool000002_ooool01@00003oooooooooooooool0000000Oo
oooo4@00000<ooooo`X000002`3o]/43000000/0okK1100000000`3o]/7oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00@00000ooooooooool000000_ooool01000003oooooooooo`000008
ooooo`0400000?oooooooooo000000;ooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`05ooooo`0300000?ooool0000000;ooooo00<00000ooooool000002_ooool000Wooooo00?o0000
ooooooooool09_ooool6o`00oakooooo0`3o]/45o`00oaD0okK17_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`0400000?oooooooooo000000;ooooo00H00000ooooooooool00000ooooo`00000;ooooo`06
00000?ooooooooooooooool000000000:_ooool20?nf`@80000000?o00000000000000000P000007
0?nf`@80000000?o00000000000000000`0000050?nf`@;ooooo00<00000o`000000000010000009
ooooo`8000000oooool01@00003o0000ooooooooool0000000;ooooo00Go0000oooooooooooooooo
00000006ooooo`0500000?l0003oooooooooool000000_ooool00`00003oooooooooo`02ooooo`<0
00001?ooool00`00003oooooooooo`05ooooo`0300000?ooool0000000;ooooo00<00000ooooool0
00002_ooool000Wooooo00?o0000ooooooooool09?ooool2o`00obOooooo1@3o]/44o`00o`h0okK1
8Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`0400000?oooooooooo000000;ooooo00H00000oooooooo
ool00000ooooo`00000;ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool03?oooolM
00000003ooooo`3o]/40okK100@0okK11`0000080?nf`@<000002oooool9000000Cooooo00D00000
oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`0000001_ooool01@00003ooooo
ooooooooool0000000;ooooo00D00000ooooooooooooooooo`000002ooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool01Oooool00`00003ooooo00000002ooooo`0300000?oooooo0000
00[ooooo0009ooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool0<?ooool3o`00o`03
0?nf`Ooooooooooo02Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool01000003oooooooooo`000002oooo
o`0400000?oooooooooo000000;ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00Oooooo1000000Mooooo`L000000oooool40?nf`@@000001oooool4
000001?ooooo00D00000oooooooooooooooo00000003ooooo`0500000?ooooooooooooooo`000000
1_ooool00`00003oooooooooo`02ooooo`0300000?ooool0000000Cooooo00D00000oooooooooooo
oooo00000004ooooo`0300000?oooooooooo00?ooooo00@00000ooooooooool000000_ooool00`00
003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo03Co
oooo0ol00?lZooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00@00000ooooooooool000000_ooool01000
003oooooooooo`000002ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01?ooool0
1ol00000000000000000003ooooo00000?l000000P00000;ooooo`@0000000?o0000000000000000
200000001?l00000000000000000000:ooooo`<0000000?o0000ooooooooool01Oooool400000003
o`0000000000000000Cooooo1`000009ooooo`80000000Go0000ooooooooooooooooo`000003oooo
o`0500000?ooooooooooooooo`0000001oooool01@00003oooooooooooooool0000000;ooooo00D0
0000oooooooooooooooo00000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool0
0oooool01000003oooooooooo`000002ooooo`0300000?oooooo000000[ooooo0009ooooo`03o`00
0?oooooooooo027ooooo00?o003oooooooooool0>?ooool2o`00obSooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool01000003oooooooooo`000003ooooo`03o`000?ooool0000000;ooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Wooooo1000000Cooooo`X0
00001?ooool7000000Oooooo10000007ooooo`T000001?ooool2000000;ooooo00<00000o`000?oo
ool00oooool00`00003oooooooooo`05ooooo`0500000?ooooooooooooooo`0000000_ooool01@00
003oooooooooooooool0000000Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`03
ooooo`0400000?oooooooooo000000;ooooo00?o0000ooooool000002_ooool000Wooooo00?o0000
ooooooooool08?ooool00ol00?ooooooooooo`0kooooo`;o003o9_ooool00ol00?ooooooooooo`07
ooooo`;o003o8?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00@00000
ooooooooool000000oooool01000003oooooooooo`000002ooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool04_ooool20000027ooooo10000007ooooo`@000001oooool7000000Wooooo
10000002ooooo`8000001?ooool2000000Sooooo00D00000oooooooooooooooo00000002ooooo`03
00000?oooooooooo00;ooooo10000005ooooo`0300000?oooooooooo00?ooooo00@00000oooooooo
ool000001?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo`03
o`00oooooooooooo01cooooo0ol0000Nooooo`03o`00oooooooooooo02?ooooo0_l00?l6ooooo`;o
003o8_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00D00000oooooooo
oooooooo00000002ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0Booooo`0300000?oooooooooo00Wooooo00?o00000000000000004P000007
ooooo`L000001?ooool7000000Oooooo2@000005ooooo`0300000?oooooooooo00;ooooo0P00000;
ooooo`0400000?oooooooooo000000?ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00D00000oooooooooooooooo00000003ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool06_oo
ool5o`0001kooooo00?o003oooooooooool09?ooool3o`00o`03ooooool00?oo003o02Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`0500000?ooooooooooooooo`000000
0_ooool01000003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00<00000oooooooo
ool04Oooool00`00003oooooooooo`08ooooo`0300000?l0003ooooo01Cooooo2P000004ooooo`L0
00001?ooool00ol00000000000000004000000Wooooo100000000ol0003oooooooooo`03000000Go
oooo10000004ooooo`0400000?oooooooooo000000?ooooo00?o0000ooooooooool02Oooool00`00
003oooooooooo`04ooooo`0500000?ooooooooooooooo`0000000oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01Wooooo1Ol0000Noooo
o`03o`00oooooooooooo02Oooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00D00000oooooooooooooooo00000002ooooo`0500000?oooooo
ooooooooo`0000001?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo01;ooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`0=ooooo`So00002_ooool4000000Oooooo1`00
0004ooooo`T000001?ooool3000000Cooooo10000004ooooo`8000000_ooool01000003ooooooooo
o`000003ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01?ooool01@00003ooooo
ooooooooool0000000?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
8oooool00ol00?ooooooooooo`0Hooooo`Go00007oooool00ol00?ooooooooooo`1=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01?ooool01@00003oooooooooooooool0000000;o
oooo00D00000oooooooooooooooo00000004ooooo`D000005Oooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo00[ooooo1?l00008ooooo`Oo00001oooool7000000Oooooo1`000006oooo
o`@000001?ooool3000000Wooooo00D00000oooooooooooooooo00000002ooooo`05o`000?oooooo
ooooooooo`0000002Oooool00`00003oooooooooo`06ooooo`0400000?oooooooooo000000?ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09?ooool2o`00oaWooooo0ol0
000MooooobKo003o;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<0
0000ooooooooool00_ooool01000003oooooooooo`000003ooooo`0300000?oooooooooo01_ooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`08ooooo`?o00004oooool8o`0000Kooooo
100000001?l000000000000000000006ooooo`H000001_ooool2000000cooooo00D00000oooooooo
oooooooo00000003ooooo`0500000?ooooooooooooooo`0000002?ooool00`00003oooooooooo`06
ooooo`0400000?oooooooooo000000?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool09_ooool3o`00obcooooo2_l00?l00ooooooo003oo`00o`0Sooooo`Go003o:?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00_ooool0
1000003oooooooooo`000004ooooo`03o`000?oooooooooo00gooooo10000009ooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`Ko00002?oo
ool6000000[ooooo00<00000o`000?ooool03Oooool01@00003oooooooooooooool0000000?ooooo
00D00000oooooooooooooooo00000008ooooo`0300000?oooooooooo00Kooooo00@00000oooooooo
ool000000oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Yooooo`;o
003o8Oooool9o`00o`Wooooo0_l00?lZooooo`Co003o9?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Gooooo00<00000ooooooooool00_ooool01000003oooooooooo`000004oooo
o`0300000?oooooooooo00Sooooo10000004ooooo`<000001oooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool4o`0000[ooooo2P000007oooo
o`?o00001_ooool01@00003oooooooooooooool0000000?ooooo00D00000oooooooooooooooo0000
0008ooooo`0300000?oooooooooo00Kooooo00@00000ooooooooool000000oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0[ooooo`?o003o6_ooool4o`00oa7ooooo00?o
003oooooooooool0;_ooool4o`00ob3ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`0300000?oooooooooo00;ooooo00@00000ooooooooool000001Oooool00`00003ooooo
ooooo`04ooooo`<000002oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`oo00002oooool5o`0001?ooooo
0ol00003ooooo`03o`000?oooooooooo00Cooooo00D00000oooooooooooooooo00000002ooooo`03
00000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`07ooooo`04
00000?oooooooooo000000?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0;_ooool4o`00oaCooooo0_l00?lAooooo`Co003o=Oooool00ol00?ooooooooooo`0Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`0000001_ooool01@00003oooooooooooooool00000
00?ooooo0P000004ooooo`0300000?l0000000000080000000?o0000ooooooooool03Oooool20000
00Gooooo00<00000o`00000000001Oooool00ol000000000ooooo`06ooooo`03o`000?oooooooooo
00[ooooo0_l0000=ooooo`;o00003oooool00ol0003oooooooooo`0>ooooo`;o00001oooool00ol0
003oooooooooo`03ooooo`0500000?ooooooooooooooo`0000000_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01oooool01000003oooooooooo`00
0003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03;ooooo2Ol00?l:
ooooo`03o`00oooooooooooo00gooooo1?l00?l?ooooo`?o00009oooool00ol00?ooooooooooo`0M
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`0000001_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool06?ooool2000000Kooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`05ooooo`?o00002oooool3o`0000Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01000003oooooooooo`000003ooooo`0500000?ooooooooooooooo`000000
2?ooool00ol000000000ooooo`05ooooo`0500000?ooooooooooooooo`0000000oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0kooooo`[o003o3?ooool4o`00oa;ooooo
1Ol0000Uooooo`03o`00oooooooooooo01kooooo00?o0000ooooooooool03oooool01?l0003ooooo
ooooo`000006ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`0Iooooo`<000001?ooool3000000Cooooo0`000007ooooo`Co00002_ooool9o`00017o
oooo00?o0000ooooooooool04_ooool5o`0000Gooooo0P0000000oooool0000000000003ooooo`05
00000?ooooooooooooooo`0000002oooool00`00003oooooooooo`03000000?ooooo00<00000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`13ooooo`ko
003o5_ooool5o`0002Cooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooo`0000001_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo
00;ooooo00?o000000000?ooool01oooool;00000003o`000000003ooooo00Kooooo00<00000oooo
ooooool01?ooool3000000Cooooo0P0000000ol000000000ooooo`06ooooo`Co00007Oooool4o`00
01cooooo00Go000000000?oooooooooo00000003ooooo`80000000Co0000oooooooooooo00003Ooo
ool2000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`12ooooo`03o`00oooooooooooo02;ooooo1Ol0000Rooooo`;o003o8_ooool0
0ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`0000001_ooool00`00003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo0`000003ooooo`8000003Oooool3000000Cooooo00?o
00000000000000001oooool00`00003oooooooooo`05ooooo`<000002?ooool3o`0001Cooooo1_l0
000Nooooo`8000001?ooool01000003oooooooooo`000004ooooo`8000005?ooool00`00003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo047ooooo0_l0
0?lUooooo`?o00007_ooool5o`00obCooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`06ooooo`<000004_ooool4000000?ooooo10000004ooooo`<000001oooool4000000Oooooo5?l0
0007oooooaH000000oooool4000000?ooooo0`0000000oooool0000000000004ooooo`0300000?oo
oooooooo01?ooooo00<00000ooooooooool00_ooool00`00003oooooo`00000:ooooo`002Oooool0
0ol0003oooooooooo`13ooooo`;o003o?oooool5o`00obWooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`0Nooooo`<000001?ooool4000000?ooooo1`000004ooooo`L000001_oooolE
000001Kooooo0`000004ooooo`<000000oooool01000003oooooooooooooool3000000Cooooo2`00
0006ooooo`0300000?oooooooooo00?ooooo00<00000ooooool000002_ooool000Wooooo00?o0000
ooooooooool0AOooool3o`00ocOooooo1Ol00?l^ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool02_ooool300000003o`0000000000000000@0000000?o00000000000000000P000007
ooooo`0400000?l000000000000000Cooooo1`000003oooooa4000004_ooool600000003o`000000
0000000001d0000000Cooooo00000000000000000oooool200000003o`000000003ooooo00[ooooo
00<00000o`00000000000`000004ooooo`8000000_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`18ooooo`[o003o9?ooool9o`00oc?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool00ooo
ool00ol00000000000000006ooooo`<000003oooool4000000Oooooo10000007ooooo`L000001ooo
oolH000000Oooooo6@000003ooooo`@000000oooool3000001Sooooo00<00000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1BooooobCo003o??ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`05ooooo`H000005_ooool3000000Sooooo2P000004ooooobH000006Oooool3
000000Cooooo0`000007ooooo`P000002oooool00`00003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool30000
00_ooooo2000000:ooooo`h000003_oooolW000000Cooooo0`000007ooooo`<000002?ooool20000
00Wooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003o
ooooooooo`04ooooo`8000004_ooool4000000?ooooo00<00000o`00000000001@00000;ooooo`X0
00003_ooool200000003o`0000000000000000T000009oooool4000000Kooooo1000000=ooooo`03
o`0000000000000000H000001_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003ooooo
ooooo`06ooooo`8000003?ooool4000000oooooo1`00000>oooood<000001oooool30000023ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`<000006_ooool>000004?ooooo1`00000:ooooo`D000004_ooool00ol0003oooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02?ooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00<00000
ooooooooool0:OoooolC000000;ooooo0_l0000R000000Kooooo1000000<ooooo`D000001Oooool3
000000kooooo00Co0000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo]_l0000AoooookKo00002_ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0529101 0.482317 0.000519493 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -9 -9 ]
[.15608 -0.0125 9 0 ]
[.28836 -0.0125 -3 -9 ]
[.28836 -0.0125 3 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -6 -9 ]
[.55291 -0.0125 6 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06672 -24 -4.5 ]
[-0.0125 .06672 0 4.5 ]
[-0.0125 .17062 -24 -4.5 ]
[-0.0125 .17062 0 4.5 ]
[-0.0125 .27452 -24 -4.5 ]
[-0.0125 .27452 0 4.5 ]
[-0.0125 .37842 -24 -4.5 ]
[-0.0125 .37842 0 4.5 ]
[-0.0125 .48232 -6 -4.5 ]
[-0.0125 .48232 0 4.5 ]
[-0.0125 .58622 -18 -4.5 ]
[-0.0125 .58622 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.15608 0 m
.15608 .61803 L
s
.28836 0 m
.28836 .61803 L
s
.42063 0 m
.42063 .61803 L
s
.55291 0 m
.55291 .61803 L
s
.68519 0 m
.68519 .61803 L
s
.81746 0 m
.81746 .61803 L
s
.94974 0 m
.94974 .61803 L
s
0 .06672 m
1 .06672 L
s
0 .17062 m
1 .17062 L
s
0 .27452 m
1 .27452 L
s
0 .37842 m
1 .37842 L
s
0 .48232 m
1 .48232 L
s
0 .58622 m
1 .58622 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(2.5)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(7.5)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(10)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(12.5)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(17.5)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06672 m
.00625 .06672 L
s
[(-800)] -0.0125 .06672 1 0 Mshowa
0 .17062 m
.00625 .17062 L
s
[(-600)] -0.0125 .17062 1 0 Mshowa
0 .27452 m
.00625 .27452 L
s
[(-400)] -0.0125 .27452 1 0 Mshowa
0 .37842 m
.00625 .37842 L
s
[(-200)] -0.0125 .37842 1 0 Mshowa
0 .48232 m
.00625 .48232 L
s
[(0)] -0.0125 .48232 1 0 Mshowa
0 .58622 m
.00625 .58622 L
s
[(200)] -0.0125 .58622 1 0 Mshowa
.125 Mabswid
0 .0927 m
.00375 .0927 L
s
0 .11867 m
.00375 .11867 L
s
0 .14465 m
.00375 .14465 L
s
0 .1966 m
.00375 .1966 L
s
0 .22257 m
.00375 .22257 L
s
0 .24854 m
.00375 .24854 L
s
0 .30049 m
.00375 .30049 L
s
0 .32647 m
.00375 .32647 L
s
0 .35244 m
.00375 .35244 L
s
0 .40439 m
.00375 .40439 L
s
0 .43037 m
.00375 .43037 L
s
0 .45634 m
.00375 .45634 L
s
0 .50829 m
.00375 .50829 L
s
0 .53427 m
.00375 .53427 L
s
0 .56024 m
.00375 .56024 L
s
0 .04075 m
.00375 .04075 L
s
0 .01477 m
.00375 .01477 L
s
0 .61219 m
.00375 .61219 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06672 m
1 .06672 L
s
.99375 .17062 m
1 .17062 L
s
.99375 .27452 m
1 .27452 L
s
.99375 .37842 m
1 .37842 L
s
.99375 .48232 m
1 .48232 L
s
.99375 .58622 m
1 .58622 L
s
.125 Mabswid
.99625 .0927 m
1 .0927 L
s
.99625 .11867 m
1 .11867 L
s
.99625 .14465 m
1 .14465 L
s
.99625 .1966 m
1 .1966 L
s
.99625 .22257 m
1 .22257 L
s
.99625 .24854 m
1 .24854 L
s
.99625 .30049 m
1 .30049 L
s
.99625 .32647 m
1 .32647 L
s
.99625 .35244 m
1 .35244 L
s
.99625 .40439 m
1 .40439 L
s
.99625 .43037 m
1 .43037 L
s
.99625 .45634 m
1 .45634 L
s
.99625 .50829 m
1 .50829 L
s
.99625 .53427 m
1 .53427 L
s
.99625 .56024 m
1 .56024 L
s
.99625 .04075 m
1 .04075 L
s
.99625 .01477 m
1 .01477 L
s
.99625 .61219 m
1 .61219 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.07672 .29202 L
.12963 .36955 L
.18254 .4267 L
.23545 .47291 L
.28836 .51084 L
.34127 .53158 L
.39418 .54435 L
.44709 .55766 L
.5 .57772 L
.55291 .58869 L
.60582 .59225 L
.65873 .59497 L
.71164 .59704 L
.76455 .5987 L
.81746 .60009 L
.87037 .60128 L
.92328 .60235 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.07672 .29202 Mdot
.12963 .36955 Mdot
.18254 .4267 Mdot
.23545 .47291 Mdot
.28836 .51084 Mdot
.34127 .53158 Mdot
.39418 .54435 Mdot
.44709 .55766 Mdot
.5 .57772 Mdot
.55291 .58869 Mdot
.60582 .59225 Mdot
.65873 .59497 Mdot
.71164 .59704 Mdot
.76455 .5987 Mdot
.81746 .60009 Mdot
.87037 .60128 Mdot
.92328 .60235 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0001Sooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Jooooo`?o00006_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Fooooo`?o00001?ooool2o`0001Cooooo0ol00002ooooo`Go0000
0oooool00ol0003oooooooooo`02ooooo`?o00004oooool3o`0000?ooooo0ol0000Cooooo`?o0000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`007ooo
ool01?l0003oooooooooool0000Hooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Hooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000004oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`000004ooooo`007oooool01?l0003oooooooooool0000Iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`007ooo
ool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`007oooool01?l0003oooooooooool0000Gooooo`05
o`000?ooooooooooooooool000001oooool4o`0001Wooooo1?l0000Looooo`03o`000?oooooooooo
00Gooooo1?l0000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool4o`0001Cooooo00Co
0000oooooooooooooooo1?l0000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool4o`0000Gooooo000Oooooo`04o`000?ooooooooooo`0001Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool2o`0000Cooooo00Co0000oooo
oooooooo00004oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo01Cooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`008?ooool2o`0001Wooooo0ol0
0008ooooo`Go00006?ooool5o`0001Oooooo1Ol00007ooooo`Go00005_ooool00ol0003ooooooooo
o`03ooooo`;o00005Oooool00ol0003oooooooooo`02ooooo`?o00002?ooool5o`0001?ooooo00Co
0000oooooooooooooooo1Ol0000Cooooo`04o`000?ooooooooooooooo`Go00001oooool5o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Kooooool0
00001@000001ooooo`006oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00<00000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
0@000001ooooo`006oooool00`00003oooooooooo`02ooooo`?oo`008?ooool00ol0003ooooooooo
o`0Pooooo`0300000?oooooooooo01oooooo00?o0000ooooooooool07oooool00`00003ooooooooo
o`0Pooooo`03o`000?oooooooooo01oooooo00<00000ooooooooool07oooool00ol0003ooooooooo
o`0:ooooo`4000000Oooool001_ooooo00@00000oooooooooooooooo1Ooo000Oooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00[ooooo0@000001ooooo`006oooool01000003o0000ooooooooool5ool001oooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02Oooool1o`00004000000Oooool001_ooooo00@00000oooooooooooooooo1Ooo
000Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`02
ooooo`?oo`008?ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001oooo
o`006oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01kooooo00<0001ooooooooo
ool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
7_ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool01?oo
ool00`00003oooooooooo`0Nooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool0
0`00003o0000ooooo`04ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool08?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1
o`00004000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Noooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`05ooooo`03
00000?oooooooooo01gooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool07Oooool00`0007ooooooooooo`0Pooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`400000
0Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool01Ooo
ool00`00003oooooooooo`0Mooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07Oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0:ooooo`4000000Oooool000Go000000?oooooo`000?ooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00
003o00000000O`050000O`030000000007l0001o0?L0001o0Ol000010000007ooooo0007ooooo`?o
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
7?ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0:ooooo`4000000Oooool000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo01cooooo00<0001oooooooooool08?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000
007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo
0@000001ooooo`006oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01_ooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?l0003ooooo00Oooooo00<00000
ooooooooool06oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`09ooooo`7o00000@000001ooooo`006oooool00`00
003oooooooooo`07ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool08?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000
007ooooo000Kooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool06oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`0Kooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo01[ooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000K
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0P
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0P
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:
ooooo`4000000Oooool001_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Joooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003o0000ooooo`08ooooo`03
00000?oooooooooo01[ooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool02?ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo
0@000001ooooo`006oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01Wooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool06Oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo023ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001oooo
o`006oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01Wooooo00<0001ooooooooo
ool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02_ooool10000007ooooo000Kooooo`0300000?l0003ooooo00Wooooo00<00000ooooooooool0
6Oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`09ooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`0:ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000K
ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0P
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0P
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:
ooooo`4000000Oooool001_ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Hoooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0:ooooo`03
00000?oooooooooo01Sooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo0007ooooo`?o0000
1?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0
6?ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0:ooooo`4000000Oooool000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`0:ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool08?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000
007ooooo0005o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l02`0007l0
0`000000001o0000O`3a0000O`7o00000@000001ooooo`001_ooool4o`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00_ooooo00<0
0000ooooooooool05oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool000Kooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool02oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo
0@000001ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01Oo
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool02_ooool10000007ooooo0008ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool05oooool00`0007oooooo
ooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0Fooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Koooo
o`0300000?l0003ooooo00cooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0Poooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Poooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09oooo
o`7o00000@000001ooooo`006oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01Ko
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo00cooooo
00<00000ooooooooool05_ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool03Oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo023ooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo01Gooooo00<0001o
ooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo00gooooo00<00000oooo
ooooool05Oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool03Oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo023ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`00
6oooool00`00003o0000ooooo`0=ooooo`0300000?oooooooooo01Gooooo00<0001oooooooooool0
8?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
8?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool03_ooool00`00003ooooooooo
o`0Dooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0>
ooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Koooo
o`0300000?oooooooooo00kooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Poooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Poooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:oooo
o`4000000Oooool001_ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Dooooo`03
0000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0>ooooo`030000
0?oooooooooo01Cooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?l0
003ooooo00oooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Pooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01?ooooo00<0001o
ooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool04oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo023ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool0
8?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
8?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2_ooool10000007ooooo0008ooooo`?o00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oo
oooooooo013ooooo00<00000ooooooooool04_ooool00`0007ooooooooooo`0Pooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Ooo
ool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo01;ooooo
00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool02_ooool10000007ooooo0005o`000003ooooool0003o000000?o00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000000
07l0400007l00`000000001o0000O`3/0000O`7o00000@000001ooooo`001_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0`00003oooooooooo`0@ooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool08?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool1
0000007ooooo0007ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool04_oo
ool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0:ooooo`4000000Oooool000Sooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0@ooooo`?oo`00
4_ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0:ooooo`4000000Oooool000Wooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00oooooo1Ooo000Aooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`Goo`004Oooool0
0`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool03oooool5ool0
017ooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?l0003ooooo013o
oooo0ooo000Booooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo01?ooooo00<00000ooooooooool03oooool00`0007ooooooooooo`0Pooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0?ooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Dooooo`0300000?oooooo
oooo00kooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo
01Gooooo00<00000ooooooooool03Oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_o
oooo00<00000ooooooooool05Oooool00`00003oooooooooo`0=ooooo`030000Oooooooooooo023o
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023o
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[o
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00cooooo
00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?l0003ooooo01Oooooo00<0
0000ooooooooool02oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`09ooooo`7o00000@000001ooooo`006oooool0
0`00003oooooooooo`0Gooooo`0300000?oooooooooo00_ooooo00<0001oooooooooool08?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool02_ooool00`00
07ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool06?ooool00`00003o
ooooooooo`0:ooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Iooooo`0300000?oooooooooo00Wooooo00<0001oooooooooool08?ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo
000Kooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool02?ooool00`0007oooooooooo
o`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0:ooooo`4000000Oooool001_ooooo00<00000o`000?ooool06_ooool00`00003oooooooooo`08
ooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo00Wooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo
01_ooooo00<00000ooooooooool01oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_o
oooo00<00000ooooooooool07?ooool00`00003oooooooooo`06ooooo`030000Oooooooooooo023o
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023o
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[o
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Looooo`0400000?oo003oo`00ool000Go
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo01cooooo
1Ooo0004ooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`001_ooool5o`0000?ooooo0_l0
0004ooooo`;o00001Oooool00`00003oooooooooo`0Looooo`Goo`001?ooool00`0007oooooooooo
o`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0:ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool07?ooool5ool000Co
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool02_ooool10000007ooooo0005o`0000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00
000007l07@0007l3ool00=l0001o0Ol000010000007ooooo0009ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000
ooooooooool08?ooool00`00003oooooooooo`02ooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo027ooooo00D00000oooooooooooo
oooo0000O`0Rooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0:ooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0R
ooooo`0400000?oooooooooo0000Ob;ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`001oooool3o`0000Cooooo0_l00004
ooooo`;o00001Oooool00`00003oooooooooo`0Sooooo`0300000?ooool0001o02;ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001
ooooo`006oooool00`00003oooooooooo`0Tooooo`030000000007oooooo027ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001oooo
o`006oooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo023ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`00
6oooool00`00003o0000ooooo`0Uooooo`030000O`00003ooooo023ooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0Ol000010000007ooooo
000Kooooo`0300000?oooooooooo02Gooooo00<0001oooooo`0000008?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000K
ooooo`0300000?oooooooooo02Gooooo00@0001oooooooooool000007oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000K
ooooo`0300000?oooooooooo02Gooooo00D0001ooooooooooooooooo0000000Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool09Oooool00`0007ooooooooooo`02ooooo`0400000?oo003o
o`00ool001[ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooo
oooo00;ooooo1Ooo000Iooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool09Oooool00`00
07ooooooooooo`02ooooo`Goo`006Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?l0003ooooo02Go
oooo00<0001oooooooooool00_ooool5ool001Wooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo02Gooooo00<0001oooooooooool00oooool3ool00003ooooo`00003ooooo01Oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo00Sooooo00<0
0000ooooooooool05Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0001o
ooooooooool02Oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool09Oooool00`0007ooooooooooo`0:ooooo`0300000?oooooooooo01?ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001oooo
o`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo00_ooooo0P00000Cooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`40
00000Oooool001_ooooo00<00000o`000?ooool09Oooool00`0007ooooooooooo`0=ooooo`030000
0?oooooooooo013ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo00Wooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0
001oooooooooool03_ooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000
ooooooooool09Oooool00`0007ooooooooooo`0?ooooo`0300000?oooooooooo00kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001
ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo013ooooo00@00000ool0
0?oo003oo`003?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0001ooooo
ooooool04?ooool5ool000_ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00[ooooo0@000001ooooo`005?ooool2o`0000Gooooo00<00000oooooooo
ool09Oooool00`0007ooooooooooo`0@ooooo`Goo`002oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool09Oooool00`0007ooooooooooo`0@ooooo`Go
o`002oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02_ooool10000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000000
07l0>@0007l3ool000030000O`00000000000<00001o0Ol000010000007ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool09Oooool00`0007ooooooooooo`0Gooooo`03
00000?oooooooooo00Kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo00[ooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo02Gooooo00<0001oooooooooool06?ooool00`00003oooooooooo`05ooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`40
00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Uooooo`03
0000Oooooooooooo01Wooooo0P000005ooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool001Cooooo0_l00005ooooo`030000
0?oooooooooo02Gooooo00<0001oooooooooool06oooool00`00003oooooooooo`02ooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000ooooooooool09Oooool00`0007ooooooooooo`0Looooo`8000000_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0001oooooooooool07_ooool0
1000003oo`00ool00?oo000Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_oo
ool10000007ooooo000Kooooo`0300000?l0003ooooo02Gooooo00<0001oooooooooool07_ooool5
ool001oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Pooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`7o00000@000001
ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo01kooooo1Ooo000Ooooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`03
00000?oooooooooo02Gooooo00<0001oooooooooool07_ooool5ool0008000007Oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Uooooo`030000Oooooooooooo01oooooo0ooo0003ooooo`<000006_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Uooooo`030000Oooooooooooo023ooooo00<0001oooooooooool01Oooool2000000;ooooo0ooo
000Cooooo`030000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo000K
ooooo`0300000?oooooooooo02Gooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`07
ooooo`0300000?oo003oo`0000?oo`004_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo
023ooooo00<0001oooooooooool02?ooool5ool001;ooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000o`000?ooool09Oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo00Sooooo1Ooo0005000000Gooooo0ooo0005ooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool09Oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo00Wooooo
0ooo0006ooooo`@000001Ooo0004ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
8?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0001oooooooooool08?oo
ool00`0007ooooooooooo`0Fooooo`Goo`001?ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooo
oooo023ooooo00<0001oooooooooool05_ooool5ool000<0000000?ooooo0000Ooooool08?ooool0
0`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool09Oooool00`00
07ooooooooooo`0Pooooo`030000Oooooooooooo01Oooooo0ooo0004ooooo`@000000oooool3ool0
01Wooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Go
oooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo0080
00001Ooo000Hooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003o0000
ooooo`0Uooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`02ooooo`Goo`006?ooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`7o00000@000001ooooo`006ooo
ool00`00003oooooooooo`0Uooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`02ooooo`Goo`000P00000Fooooo`030000Oooooooooooo023ooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`03ooooo`?oo`000oooool3000001?ooooo00<0001o
ooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0001ooooo
ooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00cooooo0`0000001?oo
ooooo`00ool00?oo000<ooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo00[ooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Uooooo`030000Oooooooooooo023ooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0?ooooo`Goo`002oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:ooooo`4000000Oooool000Ko
oooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool09Oooool00`0007oo
ooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001oooooooooool03oooool5ool00003
00000?oooooooooo00Sooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02_ooool10000007ooooo0007ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo02Gooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo00oooooo1Ooo00000oooool0000000000003000000Cooooo0ooo000Q
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0:
ooooo`4000000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0O@0007l3ool000L0001o0`00
0005ool000X0001o0ooo000;0000O`?oo`00E@0007l1o`00004000000Oooool000Wooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo023ooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Mooooo`Goo`001@000004ooooo`Goo`002Oooool5ool000Cooooo
00<0001oooooooooool00_ooool3ool000_ooooo0ooo000<ooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool02_ooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool09Oooool00`0007ooooooooooo`0Pooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07Oooool5ool000Gooooo10000005ool000T000001Ooo0005000000?ooooo1Ooo0009oooo
o`Goo`002_ooool3ool000_ooooo0ooo000:ooooo`?oo`001Oooool00`0007ooooooooooo`0:oooo
o`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Uooooo`030000Oooo
oooooooo023ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`?oo`002_oo
ool5ool000Wooooo1Ooo0004ooooo`040000O`0000000000000000Goo`002@000005ool000D00000
1?ooool5ool000Wooooo1Ooo0008ooooo`Goo`001?ooool00`0007ooooooooooo`03ooooo`?oo`00
1?ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oo
oooooooo02Gooooo00<0001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool02_ooool3ool000_ooooo0ooo0005ooooo`040000Oooo
ooooooooooooo`Goo`002Oooool5ool000Gooooo10000005ool000T000001Ooo0008000000Goo`00
1@000004ooooo`Goo`000oooool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool08?ooool00`0007ooooooooooo`02ooooo`?oo`002oooool3ool000[ooooo1Ooo
0009ooooo`Goo`002?ooool5ool000Cooooo00<0001o0000000000000P000005ool000?ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo023ooooo00<0001o
ooooooooool07_ooool3ool000_ooooo0ooo000:ooooo`?oo`001Oooool00`0007ooooooooooo`02
ooooo`Goo`000oooool10000007ooooo000Kooooo`0300000?l0003ooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ooo0003oooo
o`7o00000@000001ooooo`006ooooooo000000D000000Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.43346, -1034.93, \
0.0727967, 7.4143}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(full2\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classification", "Section"],

Cell[CellGroupData[{

Cell["Scalar covariance models", "Subsection"],

Cell[CellGroupData[{

Cell["Which models", "Subsubsection"],

Cell[BoxData[{
    \(\(model1\  = \ scalar1;\)\), "\[IndentingNewLine]", 
    \(\(model2\  = \ scalar2;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate classification data", "Subsubsection"],

Cell[BoxData[{
    \(\(pts\  = \ 150;\)\), "\n", 
    \(\(reg1\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model1];\)\), "\n", 
    \(\(reg2\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model2];\)\)}], "Input"],

Cell[BoxData[{
    \(\(class\  = 
        Partition[\(If[#[\([1]\)]\  < \ #[\([2]\)], \ 1, 
                0] &\)\  /@ \ \(({Flatten[reg1], \ Flatten[reg2]}\  // \ 
                Transpose)\), pts + 1];\)\), "\n", 
    \(\(classPlot\  = 
        ListDensityPlot[class, \ 
          ColorFunction -> \((If[# == 1, RGBColor[0, 0, #], \ 
                  RGBColor[1, 0, #]] &)\), \ Mesh -> False, \ 
          MeshRange -> {{0, 1}, {0, 1}}, nF, nS];\)\)}], "Input"],

Cell[BoxData[
    \(\(idealPlot\  = 
        Show[Graphics[{Blue, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, Red, Blue, \ nS]\ , AspectRatio -> Automatic, \ 
          Frame \[Rule] True, \ nF, \ nS];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{idealPlot, \ classPlot}], yS, 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
0000017ooooo]Ol0000;ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003ooooooooo
o`2aooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooo
oooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool0
0`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooomW0000o`D0o`00@@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooof40003o3@3o000o0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000
oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
A@000?l40?l001@0003o4`3o000m0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo@P000?l>0?l000P0003o6@3o000l0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00@00000ooooooooooooooooC@000?lC0?l004`0003o1?ooool00`00003oooooooooo`0?ooooo`04
o`000?oooooooooooooood00003o<`3o000j0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00@00000ooooooooooooooooA`000?lO0?l004H0003o1?ooool00`00003oooooooooo`0?oooo
o`04o`000?oooooooooooooood00003o<`3o000j0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000ooooooooooooooooA@000?lT0?l004<0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?oooooooooooooooch0003o=@3o000j0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00@00000oooooooooooooooo@P000?lZ0?l00400003o1?ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooocd0003o=`3o000i0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00@00000oooooooooooooooo?`000?l_0?l003h0003o1?ooool00`00003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooc`0003o>@3o000h0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo?0000?le0?l003/0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooocT0003o?03o000h0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00@00000oooooooooooooooo>P000?li0?l003T0003o1?ooool00`00
003oooooooooo`0?ooooo`04o`000?ooooooooooooooocP0003o?P3o000g0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo>@000?lk0?l003P0003o1?ooool0
0`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocL0003o@03o000f0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo=`000?lo0?l003H0003o1?oo
ool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocL0003o@03o000f0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo=@000?m30?l003@0003o
1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocH0003o@@3o000f0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo=0000?m50?l003<0
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocD0003o@`3o000e0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo<P000?m80?l0
0380003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooc@0003oA03o000e
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo<@000?m:
0?l00340003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooc40003oB03o
000d0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo<000
0?m<0?l00300003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooc00003o
B`3o000b0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
;`000?m>0?l002l0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0
003oC03o000b0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooo
oooo;P000?mA0?l002d0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooo
obh0003oCP3o000a0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooo
oooooooo;@000?mC0?l002`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooobh0003oCP3o000a0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooo
oooooooooooo;0000?mE0?l002/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooobd0003oD03o000`0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000
oooooooooooooooo:`000?mG0?l002X0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob`0003oDP3o000_0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo:P000?mI0?l002T0003o1?ooool00`00003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooobX0003oE@3o000^0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00@00000oooooooooooooooo:@000?mK0?l002P0003o1?ooool00`00003oooooooooo`0?ooooo`04
o`000?ooooooooooooooobT0003oF03o000/0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00@00000oooooooooooooooo:0000?mL0?l002P0003o1?ooool00`00003oooooooooo`0?oooo
o`04o`000?ooooooooooooooobL0003oG03o000Z0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000oooooooooooooooo:0000?mM0?l002L0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobH0003oGP3o000Y0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00@00000oooooooooooooooo9`000?mO0?l002H0003o1?ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobD0003oH@3o000W0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00@00000oooooooooooooooo9P000?mP0?l002H0003o1?ooool00`00003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooobD0003oH@3o000W0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo9@000?mR0?l002D0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooobD0003oH`3o000U0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00@00000oooooooooooooooo90000?mS0?l002D0003o1?ooool00`00
003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0003oI@3o000T0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo90000?mT0?l002@0003o1?ooool0
0`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003oJP3o000Q0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo8`000?mV0?l002<0003o1?oo
ool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003oJ`3o000P0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo8`000?mV0?l002<0003o
1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oK@3o000O0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo8P000?mX0?l00280
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oKP3o000N0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo8@000?mY0?l0
0280003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oL@3o000K
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo8@000?mZ
0?l00240003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oL@3o
000K0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo8000
0?m/0?l00200003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o
L`3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
80000?m/0?l00200003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00
003oM03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooo
oooo7`000?m^0?l001l0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ob00003oM03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooo
oooooooo7P000?m_0?l001l0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooal0003oMP3o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooo
oooooooooooo7P000?m_0?l001l0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooal0003oM`3o000G0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000
oooooooooooooooo7@000?ma0?l001h0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooal0003oM`3o000G0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo7@000?le0?l000L0003o=@3o000N0000o`Cooooo00<00000ooooooooool0
3oooool01?l0003ooooooooooooooolN0000ogT0o`005P000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`0400000?oooooooooooooooad0003o<@3o000?0000oc80o`007@000?l4ooooo`03
00000?oooooooooo00oooooo00Co0000oooooooooooooooo7P000?mi0?l001H0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolL0000oc00o`0050000?l_0?l0
01d0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003oN@3o000F
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo70000?l_
0?l001H0003o;P3o000M0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooo
oolN0000ogT0o`005P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooa`0003o;@3o000J0000obd0o`0070000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo7P000?lc0?l000/0003o>`3o000F0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00@00000oooooooooooooooo70000?l/0?l001`0003o;03o000L0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooolM0000oc80o`003`000?li0?l001H0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolL0000ob`0
o`007@000?l[0?l001`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oad0003o<@3o000B0000ocL0o`005P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooooa`0003o:P3o000P0000ob/0o`006`000?l4ooooo`0300000?oooooooooo
00oooooo00Co0000oooooooooooooooo7@000?l`0?l001@0003o=@3o000G0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6`000?lZ0?l00280003o:P3o000K
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolK0000oc40o`005`00
0?lc0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oolK0000obX0o`008P000?lZ0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooa/0003o<@3o000G0000oc<0o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooa/0003o:@3o000T0000obT0o`006`000?l4ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?l_0?l001X0003o<@3o000H0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6P000?lZ0?l002@0
003o:@3o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolK0000
obl0o`006`000?l`0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003o
oooooooooooooolJ0000obT0o`009P000?lX0?l001/0003o1?ooool00`00003oooooooooo`0?oooo
o`04o`000?oooooooooooooooaX0003o;`3o000L0000obl0o`006@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooaX0003o:@3o000V0000obP0o`006`000?l4
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo6P000?l_0?l001d0003o;P3o
000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6P00
0?lX0?l002L0003o:03o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolJ0000obh0o`007P000?l]0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01000003ooooooooooooooolJ0000obP0o`009`000?lX0?l001/0003o1?ooool00`00003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooaT0003o;`3o000N0000ob`0o`006`000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooaX0003o:03o000X0000obP0
o`006P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo6@000?l_0?l0
01l0003o:`3o000K0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooo
oooooooo6P000?lX0?l002P0003o:03o000J0000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooolI0000obl0o`007`000?l[0?l001/0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01000003ooooooooooooooolJ0000obL0o`00:@000?lX0?l001X0003o1?ooool0
0`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003o;`3o000O0000obT0o`007@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooaX0003o9`3o
000Y0000obP0o`006P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
60000?l`0?l001l0003o:@3o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00<00000ooooooooool0
3oooool01?l0003ooooooooooooooolH0000oc00o`007`000?lY0?l001d0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01000003ooooooooooooooolJ0000obL0o`00:@000?lX0?l001X0
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooaP0003o<03o000O0000
obP0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooo
oaX0003o9`3o000Y0000obP0o`006P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
oooooooooooo60000?l`0?l001h0003o:@3o000N0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000oooooooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00<00000
ooooooooool03oooool01?l0003ooooooooooooooolG0000oc40o`007P000?lY0?l001h0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolJ0000obL0o`00:@00
0?lX0?l001X0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooaL0003o
<@3o000N0000obT0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oo
oooooooooooooaX0003o:03o000X0000obP0o`006P000?l4ooooo`0300000?oooooooooo00oooooo
00Co0000oooooooooooooooo5`000?lb0?l001d0003o:@3o000N0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo6P000?lX0?l002P0003o9`3o000K0000o`Co
oooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolG0000oc80o`0070000?lZ0?l0
01h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolJ0000
obP0o`009`000?lX0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooaL0003o<`3o000K0000obX0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`0400000?oooooooooooooooaX0003o:03o000W0000obP0o`006`000?l4ooooo`0300000?oooooo
oooo00oooooo00Co0000oooooooooooooooo5`000?lc0?l001X0003o:`3o000N0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6P000?lY0?l002H0003o:03o
000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolG0000ocD0o`00
60000?l[0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooo
oooooolJ0000obT0o`009P000?lX0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooaL0003o=@3o000G0000ob`0o`007P000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`0400000?oooooooooooooooa/0003o:@3o000T0000obT0o`006`000?l4ooooo`03
00000?oooooooooo00oooooo00Co0000oooooooooooooooo60000?le0?l001@0003o;P3o000N0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6`000?lZ0?l0
0280003o:P3o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolH
0000ocD0o`0050000?l^0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003ooooooooooooooolK0000ob/0o`008@000?lZ0?l001/0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?oooooooooooooooaP0003o=P3o000B0000obl0o`007P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`0400000?oooooooooooooooa`0003o:`3o000O0000ob/0o`006`00
0?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo60000?lh0?l000h0003o
<P3o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
70000?l/0?l001d0003o:`3o000L0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooo
oooooooooolI0000ocT0o`002`000?lc0?l001d0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003ooooooooooooooolL0000obd0o`006`000?l/0?l001`0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003oM`3o000M0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00@00000oooooooooooooooo70000?l^0?l001P0003o;P3o000L0000
o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolJ0000ogH0o`007@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooa`0003o;`3o000E
0000obl0o`007@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo6P00
0?mh0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oolL0000oc40o`004@000?la0?l001d0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooa/0003oM`3o000K0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo7@000?ld0?l000/0003o<`3o000M0000o`Cooooo00<00000ooooooooool0
3oooool01?l0003ooooooooooooooolK0000ogL0o`006`000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`0400000?oooooooooooooooad0003oL@3o000N0000o`Cooooo00<00000oooooooo
ool03oooool01?l0003ooooooooooooooolK0000ogL0o`006`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`0400000?oooooooooooooooah0003oL03o000N0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003ooooooooooooooolM0000ogD0o`006`000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooah0003oK`3o000O0000o`Cooooo00<00000
ooooooooool03oooool01?l0003ooooooooooooooolN0000og@0o`006`000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`0400000?oooooooooooooooah0003oK`3o000O0000o`Cooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolN0000ogD0o`006P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooal0003oKP3o000O0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooolO0000og@0o`006P000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooob00003oK03o000P0000o`Co
oooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolP0000og<0o`006P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooob00003oK03o000P0000
o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolP0000og<0o`006P000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooob40003oJ`3o000P
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolP0000og<0o`006P00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooob40003oJP3o
000Q0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolQ0000og40o`00
6`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooob80003o
J03o000R0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolR0000og00
o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooob<0
003oI`3o000R0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolT0000
ofh0o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooo
ob<0003oIP3o000S0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolU
0000of/0o`007@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooo
ooooob@0003oI@3o000S0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooo
oolV0000ofT0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
ooooooooob@0003oI03o000T0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolW0000ofP0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oo
ooooooooooooobD0003oHP3o000U0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooo
oooooooooolX0000ofH0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`040000
0?ooooooooooooooobH0003oH@3o000U0000o`Cooooo00<00000ooooooooool03oooool01?l0003o
oooooooooooooolX0000ofH0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?ooooooooooooooobL0003oG`3o000V0000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooolY0000of@0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`0400000?ooooooooooooooobP0003oG@3o000W0000o`Cooooo00<00000ooooooooool03oooool0
1?l0003ooooooooooooooolZ0000of40o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`0400000?ooooooooooooooobP0003oG03o000X0000o`Cooooo00<00000ooooooooool03ooo
ool01?l0003oooooooooooooool/0000oed0o`0090000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?ooooooooooooooobT0003oF`3o000X0000o`Cooooo00<00000ooooooooool0
3oooool01?l0003oooooooooooooool]0000oe/0o`009@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`0400000?ooooooooooooooobX0003oF@3o000Y0000o`Cooooo00<00000oooooooo
ool03oooool01?l0003oooooooooooooool^0000oeT0o`009P000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`0400000?ooooooooooooooob/0003oE`3o000Z0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003oooooooooooooool_0000oeH0o`00:0000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?ooooooooooooooob`0003oE@3o000[0000o`Cooooo00<00000
ooooooooool03oooool01?l0003ooooooooooooooola0000oe<0o`00:@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`0400000?ooooooooooooooobd0003oDP3o000]0000o`Cooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooola0000oe<0o`00:@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooobh0003oD03o000^0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooolb0000oe40o`00:P000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooobl0003oCP3o000_0000o`Co
oooo00<00000ooooooooool03oooool01?l0003ooooooooooooooold0000od`0o`00;@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooc00003oC03o000`0000
o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooole0000odX0o`00;P000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooc80003oB@3o000a
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolg0000odH0o`00<000
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooc<0003oA`3o
000b0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolh0000od<0o`00
<P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooocD0003o
@`3o000d0000o`Cooooo00<00000ooooooooool03oooool01?l0003oooooooooooooooli0000ocl0
o`00=@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?ooooooooooooooocL0
003o?`3o000f0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolj0000
ocX0o`00>@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooo
ocP0003o?@3o000g0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolj
0000ocX0o`00>@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooo
ooooocX0003o>@3o000i0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooo
oolm0000obh0o`00@P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooc`0003o=03o000l0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
ooooooln0000obT0o`00AP000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oo
ooooooooooooocd0003o<P3o000m0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooo
oooooooooolo0000obH0o`00B0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`040000
0?oooooooooooooood00003o;@3o000o0000o`Cooooo00<00000ooooooooool03oooool01?l0003o
oooooooooooooom10000ob80o`00BP000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooood<0003o:03o00110000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooom20000oal0o`00C0000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`0400000?ooooooooooooooodD0003o8`3o00140000o`Cooooo00<00000ooooooooool03oooool0
1?l0003ooooooooooooooom40000oa/0o`00CP000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`0400000?oooooooooooooood/0003o5`3o001:0000o`Cooooo00<00000ooooooooool03ooo
ool01?l0003ooooooooooooooom40000oa/0o`00CP000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooe40003o2`3o001@0000o`Cooooo00<00000ooooooooool0
3oooool01?l0003ooooooooooooooom50000oaT0o`00C`000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04
o`000?ooooooooooooooodH0003o5P3o001A0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
ooooooooooooA`000?lD0?l00580003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooo
oom80000oa40o`00E0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooodX0003o
3@3o001F0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooC0000?l:0?l005L0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Co
oooo00<00000ooooooooool03oooool01?l0003ooooooooooooooom=0000o`L0o`00F@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00
003oooooooooo`0?ooooo`04o`000?ooooooooooooooodd0003o1`3o001I0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooo
oooo00oooooo00Co0000ooooooooooooooooC`000?l20?l005`0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_oo
ool00`00003oooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Ooo
ool00ol0003oooooooooo`09ooooo`002_oooone0000017ooooo]Ol0000;ooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Full covariance models", "Subsection"],

Cell[CellGroupData[{

Cell["Which models", "Subsubsection"],

Cell[BoxData[{
    \(\(model1\  = \ full1;\)\), "\[IndentingNewLine]", 
    \(\(model2\  = \ full2;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate classification data", "Subsubsection"],

Cell[BoxData[{
    \(\(pts\  = \ 150;\)\), "\n", 
    \(\(reg1\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model1];\)\), "\n", 
    \(\(reg2\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model2];\)\)}], "Input"],

Cell[BoxData[{
    \(\(class\  = 
        Partition[\(If[#[\([1]\)]\  < \ #[\([2]\)], \ 1, 
                0] &\)\  /@ \ \(({Flatten[reg1], \ Flatten[reg2]}\  // \ 
                Transpose)\), pts + 1];\)\), "\n", 
    \(\(classPlot\  = 
        ListDensityPlot[class, \ 
          ColorFunction -> \((If[# == 1, RGBColor[0, 0, #], \ 
                  RGBColor[1, 0, #]] &)\), \ Mesh -> False, \ 
          MeshRange -> {{0, 1}, {0, 1}}, nF, nS];\)\)}], "Input"],

Cell[BoxData[
    \(\(idealPlot\  = 
        Show[Graphics[{Blue, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, Red, Blue, \ nS]\ , AspectRatio -> Automatic, \ 
          Frame \[Rule] True, \ nF, \ nS];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{idealPlot, \ classPlot}], yS, 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
0000017ooooo]Ol0000;ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003ooooooooo
o`2aooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooo
oooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool0
0`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@0
0000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooo
oooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?oo
ool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooodP0003o8`3o00120000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo@@000?l_0?l003d0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01000003ooooooooooooooom=0000oa<0o`00C0000?l4ooooo`03
00000?oooooooooo00oooooo00Co0000oooooooooooooooo?`000?le0?l003T0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooom70000oal0o`00AP000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo?`000?le0?l003T0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooom50000ob@0o`00@`000?l4
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo?@000?li0?l003L0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooom20000obX0o`00@000
0?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo>P000?ln0?l003D0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolo0000obl0o`00
?P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo>@000?m00?l003@0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003oooooooooooooooll0000ocD0
o`00>`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo>0000?m30?l0
0380003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolj0000
ocT0o`00>@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo=`000?m5
0?l00340003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003oooooooooooooooli
0000oc/0o`00>0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo=P00
0?m70?l00300003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oolg0000ocl0o`00=P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
=P000?m70?l00300003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooo
oooooole0000od<0o`00=0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo=@000?m80?l00300003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooold0000odD0o`00<`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooo
oooooooo=0000?m:0?l002l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003o
oooooooooooooolb0000odP0o`00<P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
oooooooooooo<P000?m=0?l002h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003ooooooooooooooola0000odX0o`00<@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo<@000?m?0?l002d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003oooooooooooooool`0000od`0o`00<0000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo<0000?m@0?l002d0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01000003oooooooooooooool_0000odh0o`00;`000?l4ooooo`0300000?oooooooooo00oooooo
00Co0000oooooooooooooooo;`000?mB0?l002`0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003oooooooooooooool^0000oe40o`00;@000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo;P000?mE0?l002X0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003oooooooooooooool]0000oe<0o`00;0000?l4ooooo`0300000?oooooooooo
00oooooo00Co0000oooooooooooooooo;P000?mE0?l002X0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01000003oooooooooooooool/0000oeD0o`00:`000?l4ooooo`0300000?oooooo
oooo00oooooo00Co0000oooooooooooooooo;@000?mG0?l002T0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003oooooooooooooool[0000oeL0o`00:P000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo;0000?mH0?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01000003ooooooooooooooolZ0000oeT0o`00:@000?l4ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo:P000?mK0?l002P0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01000003ooooooooooooooolY0000oe/0o`00:0000?l4ooooo`03
00000?oooooooooo00oooooo00Co0000oooooooooooooooo:@000?mM0?l002L0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolX0000oe`0o`00:0000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:0000?mO0?l002H0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolX0000oed0o`009`000?l4
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9`000?mP0?l002H0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolW0000oel0o`009P00
0?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9P000?mR0?l002D0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolV0000of00o`00
9P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9P000?mR0?l002D0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolU0000of80
o`009@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9@000?mT0?l0
02@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolT0000
of<0o`009@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo90000?mW
0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolT
0000of@0o`0090000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8P00
0?mY0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oolS0000ofH0o`008`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
8@000?m[0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooo
oooooolS0000ofH0o`008`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo80000?m]0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooolR0000ofP0o`008P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooo
oooooooo80000?m^0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003o
oooooooooooooolQ0000ofT0o`008P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
oooooooooooo7`000?m_0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003ooooooooooooooolQ0000ofX0o`008@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo7`000?m_0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooolP0000of`0o`0080000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo7P000?ma0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01000003ooooooooooooooolP0000of`0o`0080000?l4ooooo`0300000?oooooooooo00oooooo
00Co0000oooooooooooooooo7P000?mb0?l001d0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003ooooooooooooooolO0000ofh0o`007`000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo7P000?md0?l001/0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003ooooooooooooooolN0000ofl0o`007`000?l4ooooo`0300000?oooooooooo
00oooooo00Co0000oooooooooooooooo7@000?me0?l001/0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01000003ooooooooooooooolN0000ofl0o`007`000?l4ooooo`0300000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7@000?mf0?l001X0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003ooooooooooooooolM0000og40o`007P000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo7@000?mf0?l001X0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01000003ooooooooooooooolM0000ocD0o`001`000?le0?l001h0003o
1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003oM`3o000I0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo7@000?la0?l000l0
003o<P3o000M0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolM0000
ogL0o`006@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooo
oa`0003o<03o000D0000obl0o`007@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
oooooooooooo6`000?mi0?l001T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003ooooooooooooooolL0000obl0o`005P000?l^0?l001d0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?oooooooooooooooa/0003oNP3o000H0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00@00000oooooooooooooooo70000?l]0?l001X0003o;@3o000L0000o`Cooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolK0000ocD0o`002`000?lj0?l001P0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolL0000ob`0o`00
70000?l/0?l001`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0
003o=03o000?0000ocL0o`0060000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`040000
0?oooooooooooooooa`0003o;03o000M0000ob/0o`0070000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo6`000?lb0?l001<0003o=@3o000H0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00@00000oooooooooooooooo70000?lZ0?l00200003o:`3o000K0000
o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolK0000oc40o`005`000?lc
0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolK
0000obX0o`008P000?lZ0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa/0003o<@3o000H0000oc80o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`0400000?oooooooooooooooa/0003o:P3o000R0000obX0o`006`000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo6`000?la0?l001P0003o<P3o000G0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6`000?lY0?l002@0003o
:@3o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolK0000obl0
o`006`000?la0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooolJ0000obX0o`0090000?lY0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04
o`000?oooooooooooooooa/0003o;`3o000K0000oc40o`005`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`0400000?oooooooooooooooaX0003o:@3o000V0000obP0o`006`000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?l^0?l001d0003o<03o000G
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6P000?lY
0?l002H0003o:03o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooo
oolK0000obh0o`007@000?l`0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooolJ0000obP0o`009`000?lX0?l001/0003o1?ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooa/0003o;@3o000O0000obl0o`005`000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooaX0003o:03o000W0000obP0o`00
6`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?l]0?l001l0
003o;`3o000G0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooo
oooo6P000?lX0?l002P0003o:03o000J0000o`Cooooo00<00000ooooooooool03oooool01?l0003o
oooooooooooooolK0000obd0o`007`000?l_0?l001L0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003ooooooooooooooolJ0000obP0o`00:0000?lX0?l001X0003o1?ooool00`00
003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o;@3o000O0000obl0o`005`000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooaX0003o9`3o000Y
0000obP0o`006P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo6`00
0?l]0?l001l0003o;`3o000G0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000
oooooooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00<00000ooooooooool03ooo
ool01?l0003ooooooooooooooolK0000obd0o`007`000?l_0?l001L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01000003ooooooooooooooolJ0000obL0o`00:@000?lX0?l001X0003o
1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o;@3o000O0000obl0
o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooaX0
003o9`3o000Y0000obP0o`006P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooo
oooooooo6`000?l]0?l001l0003o;`3o000G0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00@00000oooooooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003ooooooooooooooolK0000obd0o`007`000?l_0?l001L0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolJ0000obL0o`00:@000?lX
0?l001X0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o;@3o
000O0000obl0o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooaX0003o9`3o000Y0000obP0o`006P000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo6`000?l]0?l001l0003o;`3o000G0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00@00000oooooooooooooooo6P000?lX0?l002P0003o:03o000J0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooolK0000obd0o`007`000?l_0?l001L0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolJ0000obP0
o`00:0000?lW0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oa/0003o;P3o000N0000obl0o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooooaX0003o:03o000W0000obP0o`006`000?l4ooooo`0300000?oooooooooo
00oooooo00Co0000oooooooooooooooo6`000?l^0?l001h0003o;`3o000G0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6P000?lX0?l002L0003o:03o000K
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolM0000obd0o`007000
0?l`0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oolJ0000obT0o`009P000?lX0?l001/0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooad0003o;@3o000L0000obl0o`0060000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooaX0003o:@3o000V0000obP0o`006`000?l4ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?l_0?l001X0003o;`3o000H0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo6`000?lY0?l002@0
003o:@3o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolM0000
oc00o`0060000?l`0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003o
oooooooooooooolK0000obX0o`008P000?lZ0?l001/0003o1?ooool00`00003oooooooooo`0?oooo
o`04o`000?oooooooooooooooad0003o<03o000H0000oc00o`0060000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooa/0003o:`3o000Q0000obX0o`006`000?l4
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?la0?l001H0003o<@3o
000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo7000
0?l[0?l001l0003o:`3o000K0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolM0000oc80o`005@000?la0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01000003ooooooooooooooolL0000ob`0o`007@000?l[0?l001`0003o1?ooool00`00003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooad0003o=03o000@0000oc<0o`006@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooa`0003o;@3o000K0000ob`0
o`0070000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?lg0?l0
00`0003o=03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooo
oooooooo70000?l^0?l001P0003o;P3o000L0000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooolM0000ocT0o`001`000?lg0?l001T0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01000003ooooooooooooooolL0000obl0o`005@000?l_0?l001d0003o1?ooool0
0`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003oM@3o000J0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo70000?la0?l00140003o<@3o
000M0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooolN0000ogD0o`00
6P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooad0003o
=03o000;0000oc<0o`007@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo7P000?me0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooolM0000og40o`007P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooo
oooooooo7P000?md0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003o
oooooooooooooolN0000og00o`007P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
oooooooooooo7P000?md0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003ooooooooooooooolN0000ofl0o`007`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo7P000?mb0?l001d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooolN0000ofl0o`007`000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo7`000?ma0?l001d0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01000003ooooooooooooooolO0000ofh0o`007`000?l4ooooo`0300000?oooooooooo00oooooo
00Co0000oooooooooooooooo7`000?m`0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003ooooooooooooooolP0000of`0o`0080000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo7`000?m_0?l001l0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003ooooooooooooooolP0000of`0o`0080000?l4ooooo`0300000?oooooooooo
00oooooo00Co0000oooooooooooooooo7`000?m_0?l001l0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01000003ooooooooooooooolQ0000of/0o`0080000?l4ooooo`0300000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7`000?m_0?l001l0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003ooooooooooooooolQ0000ofX0o`008@000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo7`000?m^0?l00200003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01000003ooooooooooooooolR0000ofP0o`008P000?l4ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m]0?l00200003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01000003ooooooooooooooolS0000ofL0o`008P000?l4ooooo`03
00000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m/0?l00240003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolS0000ofH0o`008`000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m[0?l00280003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolT0000ofD0o`008`000?l4
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m[0?l00280003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolT0000of@0o`009000
0?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mX0?l002@0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolU0000of80o`00
9@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mW0?l002D0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolV0000of40
o`009@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mW0?l0
02D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolW0000
oel0o`009P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mW
0?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolX
0000oed0o`009`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8P00
0?mU0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oolX0000oe`0o`00:0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
8P000?mT0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooo
oooooolY0000oe/0o`00:0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo8P000?mT0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooolZ0000oeT0o`00:@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooo
oooooooo90000?mQ0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003o
ooooooooooooool[0000oeL0o`00:P000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooo
oooooooooooo90000?mP0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000
003oooooooooooooool/0000oeD0o`00:`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo9@000?mO0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003oooooooooooooool]0000oe80o`00;@000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo9@000?mO0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01000003oooooooooooooool^0000oe00o`00;P000?l4ooooo`0300000?oooooooooo00oooooo
00Co0000oooooooooooooooo9@000?mN0?l002X0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01000003oooooooooooooool_0000odh0o`00;`000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo9P000?mK0?l002`0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003oooooooooooooool`0000od`0o`00<0000?l4ooooo`0300000?oooooooooo
00oooooo00Co0000oooooooooooooooo9`000?mI0?l002d0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01000003ooooooooooooooolb0000odT0o`00<@000?l4ooooo`0300000?oooooo
oooo00oooooo00Co0000oooooooooooooooo:@000?mG0?l002d0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01000003ooooooooooooooolc0000odL0o`00<P000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo;0000?mC0?l002h0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01000003ooooooooooooooole0000od<0o`00=0000?l4ooooo`030000
0?oooooooooo00oooooo00Co0000oooooooooooooooo;P000?m@0?l002l0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01000003ooooooooooooooolg0000ocl0o`00=P000?l4ooooo`03
00000?oooooooooo00oooooo00Co0000oooooooooooooooo<@000?m<0?l00300003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolh0000ocd0o`00=`000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo<@000?m<0?l00300003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolj0000ocT0o`00>@000?l4
ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo=@000?m70?l00340003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01000003oooooooooooooooll0000oc@0o`00?000
0?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo>0000?m30?l00380003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooolm0000oc80o`00
?@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo?0000?lm0?l003@0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooom00000obd0
o`00?`000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo@0000?lg0?l0
03H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooom30000
obP0o`00@@000?l4ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooA@000?l`
0?l003P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooom5
0000ob<0o`00A0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooC000
0?lQ0?l00400003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooo
oom;0000oaL0o`00BP000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
C0000?lQ0?l00400003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooo
oooooomA0000o`/0o`00D0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0
003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooo
oooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo
00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
00000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/
0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooo
oooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo[0000?l4oooo
o`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooooooooooooooo
[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?ooool00`00003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00@00000oooo
oooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooooj`0003o1?oo
ool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oooooooooooooo
oj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Cooooo00<00000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00@00000oooooooooooooooo[0000?l4ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0400000?oo
oooooooooooooj`0003o1?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01000003ooooooooooooooon/0000o`Co
oooo00<00000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00<00000ooooooooool0/Oooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0
/Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
2Oooool000[ooooo00<00000ooooooooool0/Oooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo]@00000AoooookGo00002oooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation (slow)", "Section"],

Cell[CellGroupData[{

Cell["Both classes", "Subsection"],

Cell[BoxData[
    \(\(\(AnnularAllPlot[c1, rr1, rr2, #] &\)\  /@ \ em;\)\)], "Input"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{675, 713},
WindowMargins->{{221, Automatic}, {-17, Automatic}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 48, 0, 62, "Title"],
Cell[1805, 53, 275, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2105, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2172, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2250, 71, 36, 0, 43, "Subsubsection"],
Cell[2289, 73, 166, 4, 63, "Input"],
Cell[2458, 79, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2669, 87, 53, 0, 43, "Subsubsection"],
Cell[2725, 89, 207, 4, 63, "Input"],
Cell[2935, 95, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068, 102, 40, 0, 49, "Subsection"],
Cell[3111, 104, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3211, 110, 36, 0, 49, "Subsection"],
Cell[3250, 112, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3429, 120, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3490, 124, 77, 0, 49, "Subsection"],
Cell[3570, 126, 893, 17, 255, "Input"],
Cell[4466, 145, 857, 17, 255, "Input"],

Cell[CellGroupData[{
Cell[5348, 166, 43, 0, 43, "Subsubsection"],
Cell[5394, 168, 299, 6, 79, "Input"],
Cell[5696, 176, 628, 10, 175, "Input"],
Cell[6327, 188, 296, 5, 95, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6672, 199, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6749, 203, 50, 0, 43, "Subsubsection"],
Cell[6802, 205, 613, 9, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7452, 219, 65, 0, 43, "Subsubsection"],
Cell[7520, 221, 1145, 19, 223, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8726, 247, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8803, 251, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8872, 255, 70, 1, 47, "Input"],
Cell[8945, 258, 21391, 327, 296, 893, 69, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30385, 591, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[30470, 595, 55, 0, 43, "Subsubsection"],
Cell[30528, 597, 159, 4, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30724, 606, 39, 0, 35, "Subsubsection"],
Cell[30766, 608, 160, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30963, 615, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[31027, 619, 251, 5, 79, "Input"],
Cell[31281, 626, 130588, 3202, 296, 38325, 2058, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[161942, 3836, 66, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[162033, 3840, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[162127, 3844, 68, 0, 43, "Subsubsection"],
Cell[162198, 3846, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[162332, 3854, 51, 0, 35, "Subsubsection"],
Cell[162386, 3856, 87, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[162522, 3863, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[162589, 3867, 83, 1, 47, "Input"],
Cell[162675, 3870, 70, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[162794, 3877, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[162854, 3881, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[162917, 3885, 79, 1, 47, "Input"],
Cell[162999, 3888, 365858, 8936, 408, 228110, 7232, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[528906, 12830, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[528967, 12834, 78, 1, 47, "Input"],
Cell[529048, 12837, 472465, 12691, 408, 274231, 10241, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1001562, 25534, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1001695, 25541, 66, 1, 47, "Input"],
Cell[1001764, 25544, 52113, 1115, 186, 6928, 553, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1053938, 26666, 35, 0, 49, "Subsection"],
Cell[1053976, 26668, 66, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1054091, 26675, 64, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1054180, 26679, 75, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1054280, 26683, 68, 0, 43, "Subsubsection"],
Cell[1054351, 26685, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1054485, 26693, 57, 0, 35, "Subsubsection"],
Cell[1054545, 26695, 83, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1054677, 26702, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1054744, 26706, 81, 1, 47, "Input"],
Cell[1054828, 26709, 70, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1054947, 26716, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1055007, 26720, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1055070, 26724, 79, 1, 47, "Input"],
Cell[1055152, 26727, 410935, 10140, 408, 242031, 8052, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1466136, 36873, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1466197, 36877, 78, 1, 47, "Input"],
Cell[1466278, 36880, 457796, 12287, 408, 270326, 9969, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1924123, 49173, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1924256, 49180, 66, 1, 47, "Input"],
Cell[1924325, 49183, 49326, 1007, 186, 5715, 464, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1973712, 50197, 35, 0, 49, "Subsection"],
Cell[1973750, 50199, 64, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1973863, 50206, 67, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1973955, 50210, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1974049, 50214, 68, 0, 43, "Subsubsection"],
Cell[1974120, 50216, 98, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1974255, 50224, 51, 0, 35, "Subsubsection"],
Cell[1974309, 50226, 87, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1974445, 50233, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1974512, 50237, 83, 1, 47, "Input"],
Cell[1974598, 50240, 70, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1974717, 50247, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1974777, 50251, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1974840, 50255, 79, 1, 47, "Input"],
Cell[1974922, 50258, 446244, 11263, 408, 254295, 8890, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2421215, 61527, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2421276, 61531, 78, 1, 47, "Input"],
Cell[2421357, 61534, 580156, 16810, 408, 324011, 13645, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3001562, 78350, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3001695, 78357, 66, 1, 47, "Input"],
Cell[3001764, 78360, 39368, 851, 186, 5328, 426, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3041193, 79218, 35, 0, 49, "Subsection"],
Cell[3041231, 79220, 66, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3041346, 79227, 65, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3041436, 79231, 75, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3041536, 79235, 68, 0, 43, "Subsubsection"],
Cell[3041607, 79237, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3041741, 79245, 57, 0, 35, "Subsubsection"],
Cell[3041801, 79247, 83, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3041933, 79254, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3042000, 79258, 81, 1, 47, "Input"],
Cell[3042084, 79261, 55, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3042188, 79268, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3042248, 79272, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3042311, 79276, 79, 1, 47, "Input"],
Cell[3042393, 79279, 384702, 9138, 408, 229288, 7216, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3427144, 88423, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3427205, 88427, 78, 1, 47, "Input"],
Cell[3427286, 88430, 565089, 16379, 408, 321547, 13369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3992424, 104815, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3992557, 104822, 66, 1, 47, "Input"],
Cell[3992626, 104825, 55439, 1159, 186, 6754, 553, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4048126, 105991, 35, 0, 49, "Subsection"],
Cell[4048164, 105993, 64, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4048277, 106000, 33, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4048335, 106004, 46, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4048406, 106008, 37, 0, 43, "Subsubsection"],
Cell[4048446, 106010, 119, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4048602, 106017, 53, 0, 35, "Subsubsection"],
Cell[4048658, 106019, 271, 7, 79, "Input"],
Cell[4048932, 106028, 466, 9, 111, "Input"],
Cell[4049401, 106039, 272, 5, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4049710, 106049, 41, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[4049776, 106053, 104, 2, 47, "Input"],
Cell[4049883, 106057, 170716, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4220660, 108553, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4220729, 108557, 37, 0, 43, "Subsubsection"],
Cell[4220769, 108559, 115, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4220921, 108566, 53, 0, 35, "Subsubsection"],
Cell[4220977, 108568, 271, 7, 79, "Input"],
Cell[4221251, 108577, 466, 9, 111, "Input"],
Cell[4221720, 108588, 272, 5, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4222029, 108598, 41, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[4222095, 108602, 104, 2, 47, "Input"],
Cell[4222202, 108606, 170570, 2487, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4392845, 111101, 35, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4392905, 111105, 34, 0, 49, "Subsection"],
Cell[4392942, 111107, 85, 1, 47, "Input"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

