(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4317730,     109455]*)
(*NotebookOutlinePosition[   4318429,     109479]*)
(*  CellTagsIndexPosition[   4318385,     109475]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Mixture-of-Gaussians example #2", "Title"],

Cell[TextData[{
  "This notebook illustrates Gaussian mixture modeling for some 2d synthetic \
data, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Special data generation functions", "Subsection"],

Cell[BoxData[
    \(\(withinRectangle[p_, \ r_] := \n\t
        Module[{rx1, \ ry1, \ rx2, \ ry2, \ x, 
            y}, \n\t\t{rx1, \ ry1, \ rx2, \ ry2}\  = \ r; \n\t\t{x, y}\  = \ 
            p; \n\t\tIf[
            rx1\  < \ x\  < \ rx2\  && \ 
              ry1\  < \ y\  < \ ry2, \n\t\t\tTrue, \ False]];\)\)], "Input"],

Cell[BoxData[
    \(withinRegion2[p_] := \n\t
      If[\n\t\t\t\ withinRectangle[p, \ {0.2, \ 0.6, \ 0.8, \ 0.8}]\  || \ 
          withinRectangle[p, \ {0.2, \ 0.2, \ 0.8, \ 0.4}]\  || \ 
          withinRectangle[p, \ {0.8, \ 0.0, \ 1.0, \ 1.0}], \n\t\tTrue, \ 
        False]\)], "Input"],

Cell[BoxData[
    \(\(region1Data[n_] := \n\t
        Module[{count, \ xd, p}, \n\t\tcount\  = \ 1; \n\t\txd\  = \ 
            Table[0, \ {n}]; \n\t\tWhile[
            count\  <= \ 
              n, \n\t\t\tp\  = \ {Random[Real, \ {0. , 1. }], \ 
                Random[Real, \ {0. , 1. }]}; \n\t\t\tIf[
              withinRegion2[p] == 
                False, \n\t\t\t\txd[\([\(count++\)]\)]\  = \ p]]; \n\t
          xd];\)\)], "Input"],

Cell[BoxData[
    \(\(region2Data[
          n_] := \n\t\tModule[{count, \ xd, p}, \n\t\tcount\  = \ 
            1; \n\t\txd\  = \ Table[0, \ {n}]; \n\t\tWhile[
            count\  <= \ 
              n, \n\t\t\tp\  = \ {Random[Real, \ {0. , 1. }], \ 
                Random[Real, \ {0. , 1. }]}; \n\t\t\tIf[
              withinRegion2[p] == True, \n\t\t\t\txd[\([\(count++\)]\)]\  = \ 
                p]]; \n\txd];\)\)], "Input"],

Cell[BoxData[
    \(\(RR\  := \ Random[Real, \ {0. , \ 1. }];\)\)], "Input"],

Cell[BoxData[
    \(\(TransformProbabilityVector[prob_] := \n\t
        Module[{s\  = \ 0, \ len}, \n\t\tlen\  = \ 
            Length[prob] - 1; \n\t\tJoin[
            Table[s\  = \ s\  + \ prob[\([i]\)], \ {i, \ 1, \ 
                len}], \ {1}]];\)\)], "Input"],

Cell[BoxData[
    \(\(PickOne[\ priors_] := \n\t
        Module[{r}, \n\t\tr\  = \ 
            RR; \n\t\((Position[\(\((r\  <= \ #)\) &\)\  /@ \ 
                    TransformProbabilityVector[priors], \ True]\  // \ 
                Flatten)\)\  // \ First];\)\)], "Input"],

Cell[BoxData[
    \(\(GenerateFromMixturePDF[{mu_, \ sigma_, \ priors_}] := \n\t
        Module[{k, \ d, \ class}, \n\t\tk\  = \ Length[priors]; \n\t\td\  = \ 
            Length[mu[\([1]\)]]; \n\t\ \ class\  = \ 
            PickOne[priors]; \n\t\ \ Random[
            MultinormalDistribution[mu[\([class]\)], \ 
              sigma[\([class]\)]\ IdentityMatrix[d]]]\ \n\t\t];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{{class1Color, 
                Rectangle[{0, 0}, {1, 1}]}, \ {class2Color, \ 
                Rectangle[{0.8, 0}, {1, 1}], \ 
                Rectangle[{0.2, 0.6}, {0.8, 0.8}], \ 
                Rectangle[{0.2, 0.2}, \ {0.8, 0.4}]}}], \ 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize interlocking regions in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Saved data definition", "Subsubsection"],

Cell[BoxData[
    \(\(poly\  = {Partition[\ {0, 0, 8, 0, 8, 2, 2, 2, 2, 4, 8, 4, 8, 6, 2, 
                6, 2, 8, 8, 8, 8, 10, 0, 10}, 2]/10. };\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Draw polygonal region", "Subsubsection"],

Cell[BoxData[
    \(\(drawPolygonalRegion[polyL_, \ pr_, \ color_:  LightPink, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[Graphics[{color, Polygon\  /@ \ polyL}], 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, \ 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
            opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(drawAntiPolygonalRegion[polyL_, \ pr_, \ color_:  LightPink, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[
            Graphics[{{color, 
                  Rectangle[{pr[\([1, 1]\)], 
                      pr[\([2, 1]\)]}, {pr[\([1, 2]\)], 
                      pr[\([2, 2]\)]}]}, {RGBColor[1, 1, 1], 
                  Polygon\  /@ \ polyL}}], 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, \ 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
            opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for polygonal region", "Subsubsection"],

Cell[BoxData[
    \(\(PolygonalAllPlot[
          polyL_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ drawPolygonalRegion[
              polyL, \ pr, LightPink, \ nF, nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for polygonal region", "Subsubsection"],

Cell[BoxData[
    \(\(AntiPolygonalAllPlot[
          polyL_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ drawAntiPolygonalRegion[
              polyL, \ pr, LightPink, \ nF, nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data generation and visualization", "Section"],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.78571 .02381 m
.78571 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.21429 .59524 m
.21429 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.21429 .21429 m
.21429 .40476 L
.78571 .40476 L
.78571 .21429 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK
0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3o
oglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
f`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo
=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0
oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
om/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?oo
OcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg
0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3o
ogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomo
f`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0
oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
ocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?oo
OcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK
0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3o
oglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
f`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo
=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0
oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
ocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?oo
Om/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg
0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3o
ogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomo
f`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0
oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
om/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?oo
OcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK
0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3o
oglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
f`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo
=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ region1Data[n1];\)\), "\n", 
    \(\(data2\  = \ region2Data[n2];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.20183 .46302 Mdot
.67824 .02205 Mdot
.12988 .84729 Mdot
.66147 .44558 Mdot
.60349 .87708 Mdot
.12244 .10975 Mdot
.10174 .55448 Mdot
.16871 .51071 Mdot
.11836 .78879 Mdot
.19863 .03539 Mdot
.50507 .90191 Mdot
.19841 .12917 Mdot
.30812 .54859 Mdot
.10647 .56488 Mdot
.0472 .24523 Mdot
.20657 .47342 Mdot
.45471 .9345 Mdot
.29581 .43359 Mdot
.31818 .44045 Mdot
.10698 .40801 Mdot
.6147 .40937 Mdot
.51803 .83469 Mdot
.34072 .95584 Mdot
.59021 .58775 Mdot
.49303 .18954 Mdot
.76325 .17264 Mdot
.15836 .75347 Mdot
.63052 .90898 Mdot
.10756 .26337 Mdot
.31906 .54771 Mdot
.42453 .41568 Mdot
.13832 .46475 Mdot
.08492 .55146 Mdot
.32172 .04447 Mdot
.29604 .86941 Mdot
.77567 .55209 Mdot
.55245 .90602 Mdot
.70428 .20153 Mdot
.49215 .17595 Mdot
.70261 .84226 Mdot
.41637 .96305 Mdot
.26933 .48855 Mdot
.32695 .81318 Mdot
.18266 .53379 Mdot
.54369 .88373 Mdot
.03074 .44621 Mdot
.41201 .09552 Mdot
.42471 .07842 Mdot
.10818 .69195 Mdot
.45825 .90721 Mdot
.05605 .82149 Mdot
.12586 .16434 Mdot
.46749 .54418 Mdot
.14054 .72727 Mdot
.15807 .74562 Mdot
.04216 .04512 Mdot
.1658 .77004 Mdot
.11664 .86735 Mdot
.67681 .41662 Mdot
.22836 .49961 Mdot
.19404 .37958 Mdot
.18212 .66832 Mdot
.07799 .22504 Mdot
.70482 .13394 Mdot
.78845 .5755 Mdot
.71395 .19186 Mdot
.07326 .96296 Mdot
.32308 .02393 Mdot
.60846 .88018 Mdot
.0617 .51146 Mdot
.65133 .90298 Mdot
.18003 .85202 Mdot
.11658 .87925 Mdot
.44199 .04828 Mdot
.12871 .03415 Mdot
.42634 .90811 Mdot
.51045 .14417 Mdot
.55276 .03774 Mdot
.58427 .59061 Mdot
.30727 .83974 Mdot
.42784 .94092 Mdot
.07971 .55368 Mdot
.30894 .91657 Mdot
.10061 .60783 Mdot
.33995 .16912 Mdot
.50653 .02702 Mdot
.53274 .4492 Mdot
.1023 .28843 Mdot
.66291 .46 Mdot
.78523 .43888 Mdot
.24487 .50928 Mdot
.71533 .8754 Mdot
.08156 .24944 Mdot
.14723 .79088 Mdot
.27455 .19218 Mdot
.5869 .88727 Mdot
.29342 .82951 Mdot
.34444 .51605 Mdot
.2214 .02537 Mdot
.25278 .0801 Mdot
.70424 .50871 Mdot
.05217 .40283 Mdot
.55075 .85223 Mdot
.22102 .10387 Mdot
.70857 .11799 Mdot
.15611 .58368 Mdot
.01414 .59948 Mdot
.6178 .9731 Mdot
.11895 .23121 Mdot
.57544 .58008 Mdot
.74467 .20262 Mdot
.53345 .10856 Mdot
.56521 .08479 Mdot
.04898 .19971 Mdot
.4189 .4913 Mdot
.04465 .59043 Mdot
.79129 .5084 Mdot
.22566 .91852 Mdot
.3673 .99004 Mdot
.63958 .01452 Mdot
.37253 .55196 Mdot
.6004 .80501 Mdot
.16233 .55226 Mdot
.63985 .84556 Mdot
.28235 .84571 Mdot
.46549 .88844 Mdot
.24564 .53818 Mdot
.16502 .70953 Mdot
.0797 .50878 Mdot
.05886 .10641 Mdot
.12219 .47267 Mdot
.1575 .7979 Mdot
.6469 .57443 Mdot
.12896 .31293 Mdot
.03644 .71683 Mdot
.3912 .98366 Mdot
.75254 .93492 Mdot
.3213 .48468 Mdot
.70348 .83831 Mdot
.73375 .03336 Mdot
.44463 .05172 Mdot
.06324 .05826 Mdot
.10856 .93996 Mdot
.73213 .56377 Mdot
.39527 .11145 Mdot
.11694 .70895 Mdot
.63587 .94041 Mdot
.04474 .44688 Mdot
.20105 .89849 Mdot
.18363 .55239 Mdot
.14762 .85004 Mdot
.08488 .60263 Mdot
.6798 .50099 Mdot
.55499 .55376 Mdot
.44785 .835 Mdot
.03525 .83002 Mdot
.61093 .97649 Mdot
.47312 .13626 Mdot
.07724 .83038 Mdot
.06181 .72712 Mdot
.17638 .95232 Mdot
.07441 .44163 Mdot
.15093 .13211 Mdot
.26243 .54703 Mdot
.16042 .72937 Mdot
.6417 .56074 Mdot
.34374 .88883 Mdot
.17838 .43428 Mdot
.11094 .59409 Mdot
.55013 .9238 Mdot
.38355 .96167 Mdot
.52409 .86604 Mdot
.24242 .83937 Mdot
.0918 .11981 Mdot
.14593 .55065 Mdot
.75175 .42223 Mdot
.23747 .54639 Mdot
.34604 .45931 Mdot
.14957 .47502 Mdot
.01345 .91456 Mdot
.78286 .96359 Mdot
.5552 .427 Mdot
.24537 .84574 Mdot
.35755 .16914 Mdot
.78669 .46243 Mdot
.03101 .2556 Mdot
.58129 .80069 Mdot
.466 .81879 Mdot
.34572 .94515 Mdot
.62386 .86905 Mdot
.77039 .1113 Mdot
.4615 .04487 Mdot
.76957 .86931 Mdot
.19808 .07842 Mdot
.10729 .34151 Mdot
.47362 .46266 Mdot
.0938 .22636 Mdot
.51794 .87501 Mdot
.73674 .17336 Mdot
.73856 .01551 Mdot
.55028 .92728 Mdot
.33195 .42341 Mdot
.69792 .81362 Mdot
.23446 .0917 Mdot
.55279 .42062 Mdot
.5098 .86317 Mdot
.18765 .44956 Mdot
.4015 .14222 Mdot
.20215 .73863 Mdot
.64197 .8534 Mdot
.41018 .469 Mdot
.14567 .74822 Mdot
.72898 .01091 Mdot
.19249 .39036 Mdot
.33729 .85888 Mdot
.68551 .01529 Mdot
.28513 .53649 Mdot
.36818 .45599 Mdot
.20374 .05535 Mdot
.39416 .8171 Mdot
.06787 .29733 Mdot
.65537 .816 Mdot
.32789 .94731 Mdot
.63258 .94182 Mdot
.53428 .93134 Mdot
.35725 .41514 Mdot
.02662 .688 Mdot
.59491 .14204 Mdot
.01417 .19271 Mdot
.62182 .98255 Mdot
.45328 .55376 Mdot
.63274 .04302 Mdot
.6304 .90151 Mdot
.04763 .89117 Mdot
.10809 .58474 Mdot
.50758 .81814 Mdot
.06803 .12998 Mdot
.21519 .89159 Mdot
.1169 .31666 Mdot
.56647 .54406 Mdot
.62046 .09103 Mdot
.12269 .26309 Mdot
.08318 .93479 Mdot
.23693 .42751 Mdot
.02495 .81461 Mdot
.04468 .94346 Mdot
.66161 .41688 Mdot
.4684 .4092 Mdot
.05096 .33565 Mdot
.7852 .03145 Mdot
.70744 .02972 Mdot
.20769 .4159 Mdot
.17282 .46264 Mdot
.27712 .8695 Mdot
.69461 .06324 Mdot
.23596 .54365 Mdot
.30769 .47109 Mdot
.02054 .42651 Mdot
.60654 .81623 Mdot
.22553 .40487 Mdot
.02765 .97916 Mdot
.16022 .47289 Mdot
.45709 .09678 Mdot
.15921 .61589 Mdot
.11287 .37873 Mdot
.64377 .98373 Mdot
.09503 .38977 Mdot
.6834 .4836 Mdot
.2402 .85364 Mdot
.00995 .84317 Mdot
.08978 .39056 Mdot
.74065 .19025 Mdot
.39365 .1501 Mdot
.42185 .40665 Mdot
.31878 .03772 Mdot
.51382 .86351 Mdot
.51367 .03014 Mdot
.17273 .2135 Mdot
.57697 .12386 Mdot
.74108 .79704 Mdot
.52897 .4165 Mdot
.20834 .14078 Mdot
.02496 .54319 Mdot
.50149 .52285 Mdot
.30161 .95253 Mdot
.13868 .74883 Mdot
.3878 .94199 Mdot
.68894 .95473 Mdot
.74736 .05169 Mdot
.67379 .42134 Mdot
.18211 .88868 Mdot
.1215 .96464 Mdot
.68754 .48534 Mdot
.72389 .03246 Mdot
.46962 .11411 Mdot
.76819 .83999 Mdot
.77087 .14958 Mdot
.03063 .79811 Mdot
.10689 .71843 Mdot
.47865 .12231 Mdot
.28334 .19976 Mdot
.12639 .41478 Mdot
.12618 .60031 Mdot
.6147 .54233 Mdot
.34551 .46053 Mdot
.12502 .62191 Mdot
.32365 .90254 Mdot
.05011 .71258 Mdot
.76055 .81791 Mdot
.45431 .01777 Mdot
.37766 .43559 Mdot
.33793 .40766 Mdot
.75316 .88346 Mdot
.16909 .15885 Mdot
.05387 .52714 Mdot
.16693 .29445 Mdot
.38984 .58011 Mdot
.39658 .46674 Mdot
.02872 .04096 Mdot
.59761 .17428 Mdot
.26576 .14769 Mdot
.10648 .97903 Mdot
.06241 .4617 Mdot
.05099 .13951 Mdot
.11545 .55757 Mdot
.22401 .53147 Mdot
.12734 .54263 Mdot
.05148 .16343 Mdot
.07474 .09073 Mdot
.61065 .44381 Mdot
.17926 .90388 Mdot
.2004 .53403 Mdot
.06272 .1975 Mdot
.02104 .04388 Mdot
.40058 .59027 Mdot
.61465 .46532 Mdot
.3673 .52945 Mdot
.41152 .17581 Mdot
.35861 .96851 Mdot
.34738 .93443 Mdot
.13416 .87662 Mdot
.5097 .4211 Mdot
.12549 .0778 Mdot
.56561 .16897 Mdot
.74839 .53855 Mdot
.05461 .7157 Mdot
.13634 .46008 Mdot
.64068 .44999 Mdot
.01199 .57366 Mdot
.69388 .10583 Mdot
.49248 .16236 Mdot
.5782 .03783 Mdot
.11476 .55234 Mdot
.48314 .12675 Mdot
.06995 .82683 Mdot
.16051 .18651 Mdot
.57251 .15848 Mdot
.40712 .1046 Mdot
.26937 .54224 Mdot
.76449 .80972 Mdot
.41335 .8816 Mdot
.48193 .09832 Mdot
.05279 .44798 Mdot
.19669 .21161 Mdot
.44418 .54262 Mdot
.1336 .69625 Mdot
.18462 .01018 Mdot
.77683 .43809 Mdot
.41033 .19065 Mdot
.37328 .54669 Mdot
.53434 .09157 Mdot
.09997 .53915 Mdot
.19366 .51309 Mdot
.40702 .0848 Mdot
.04354 .52831 Mdot
.0244 .70427 Mdot
.15219 .07994 Mdot
.29337 .42069 Mdot
.30382 .06975 Mdot
.24849 .89326 Mdot
.2339 .1988 Mdot
.19131 .43918 Mdot
.13646 .41601 Mdot
.73116 .1633 Mdot
.53024 .48515 Mdot
.37921 .42909 Mdot
.16965 .76503 Mdot
.36562 .51806 Mdot
.25411 .18051 Mdot
.18411 .08868 Mdot
.32493 .42699 Mdot
.65186 .43948 Mdot
.19828 .02079 Mdot
.45731 .84769 Mdot
.35268 .56611 Mdot
.0879 .4284 Mdot
.05633 .27976 Mdot
.66414 .48286 Mdot
.34902 .06567 Mdot
.16054 .05469 Mdot
.69343 .19719 Mdot
.69708 .11523 Mdot
.04274 .62256 Mdot
.3851 .90168 Mdot
.68392 .56669 Mdot
.53318 .52181 Mdot
.55853 .48586 Mdot
.22442 .56562 Mdot
.36677 .52349 Mdot
.51753 .4602 Mdot
.47507 .92919 Mdot
.4846 .82784 Mdot
.09977 .03731 Mdot
.01089 .86371 Mdot
.42774 .41472 Mdot
.07151 .01362 Mdot
.21313 .83929 Mdot
.69493 .48032 Mdot
.22967 .54133 Mdot
.211 .55126 Mdot
.1397 .51383 Mdot
.57028 .16426 Mdot
.15263 .54097 Mdot
.71508 .13606 Mdot
.21445 .06649 Mdot
.07162 .51572 Mdot
.01882 .21425 Mdot
.41058 .94743 Mdot
.39405 .85764 Mdot
.18941 .80095 Mdot
.08468 .61859 Mdot
.12759 .29504 Mdot
.77105 .89577 Mdot
.56106 .13288 Mdot
.60347 .9075 Mdot
.3632 .91062 Mdot
.75744 .96677 Mdot
.51868 .91674 Mdot
.26941 .47036 Mdot
.04882 .60654 Mdot
.65613 .55306 Mdot
.13733 .26414 Mdot
.44021 .07054 Mdot
.45698 .41438 Mdot
.7375 .02038 Mdot
.47789 .54022 Mdot
.16033 .7742 Mdot
.32415 .44526 Mdot
.74638 .83144 Mdot
.28749 .95816 Mdot
.01869 .82086 Mdot
.41233 .88149 Mdot
.57619 .42118 Mdot
.0346 .57044 Mdot
.70553 .9139 Mdot
.70065 .13499 Mdot
.68337 .5734 Mdot
.4144 .18246 Mdot
.69537 .86938 Mdot
.5928 .16849 Mdot
.02546 .88 Mdot
.08007 .42672 Mdot
.62858 .89337 Mdot
.65473 .01849 Mdot
.28992 .07594 Mdot
.10087 .30864 Mdot
.31999 .88258 Mdot
.49827 .14996 Mdot
.30433 .01238 Mdot
.58884 .55487 Mdot
.23406 .57586 Mdot
.03634 .02905 Mdot
.60789 .94691 Mdot
.37181 .02036 Mdot
.32777 .88077 Mdot
.01758 .98839 Mdot
.77267 .56176 Mdot
.70345 .98581 Mdot
.19363 .01669 Mdot
.47919 .41975 Mdot
.30291 .14124 Mdot
.77181 .06172 Mdot
.58799 .05483 Mdot
.77493 .82731 Mdot
.16739 .36368 Mdot
.33236 .04809 Mdot
.76827 .42461 Mdot
.62851 .12418 Mdot
.37439 .8575 Mdot
.58966 .03999 Mdot
.05385 .62805 Mdot
.15451 .67351 Mdot
.77604 .80147 Mdot
.77959 .43858 Mdot
.38092 .1207 Mdot
.33688 .48285 Mdot
.24055 .02336 Mdot
.09584 .34005 Mdot
.53721 .03339 Mdot
.12027 .18111 Mdot
.61689 .82151 Mdot
.08076 .49654 Mdot
.12449 .20176 Mdot
.61308 .14879 Mdot
.17247 .92051 Mdot
.7881 .83835 Mdot
.27616 .93792 Mdot
.2607 .81476 Mdot
.16569 .76661 Mdot
.63401 .98345 Mdot
.56305 .49672 Mdot
.56442 .12636 Mdot
.10911 .34275 Mdot
.51562 .45363 Mdot
.31855 .95386 Mdot
.68561 .89962 Mdot
.30576 .54235 Mdot
.5863 .56668 Mdot
.75335 .18145 Mdot
.02363 .81051 Mdot
.09589 .55304 Mdot
.14202 .35994 Mdot
.25365 .9585 Mdot
.60084 .87638 Mdot
.64752 .19502 Mdot
.02434 .31951 Mdot
.12788 .91126 Mdot
.26119 .14786 Mdot
.11406 .11055 Mdot
.1751 .58503 Mdot
.15837 .35434 Mdot
.6252 .82111 Mdot
.20509 .61697 Mdot
.03416 .93492 Mdot
.54777 .43175 Mdot
.01962 .62521 Mdot
.42969 .51069 Mdot
.74863 .48715 Mdot
.32544 .40994 Mdot
.58334 .89232 Mdot
.20483 .31479 Mdot
.04649 .45449 Mdot
.02214 .50977 Mdot
.01231 .87476 Mdot
.03208 .74558 Mdot
.66074 .49529 Mdot
.15821 .37132 Mdot
.15847 .67349 Mdot
.6967 .41723 Mdot
.69344 .96366 Mdot
.04251 .47817 Mdot
.04366 .26828 Mdot
.08149 .50307 Mdot
.32728 .59529 Mdot
.13166 .25744 Mdot
.62078 .18786 Mdot
.18434 .87676 Mdot
.48109 .90329 Mdot
.44839 .43493 Mdot
.34443 .5499 Mdot
.41454 .17645 Mdot
.22099 .41595 Mdot
.04646 .52939 Mdot
.01511 .78196 Mdot
.11698 .19117 Mdot
.69264 .02451 Mdot
.79239 .95094 Mdot
.1484 .92538 Mdot
.11175 .4058 Mdot
.36648 .79517 Mdot
.36118 .02301 Mdot
.73677 .58363 Mdot
.63712 .53569 Mdot
.14644 .89152 Mdot
.59025 .12162 Mdot
.5787 .93077 Mdot
.16084 .51347 Mdot
.41427 .92003 Mdot
.03709 .68753 Mdot
.35298 .80335 Mdot
.05642 .0642 Mdot
.64227 .48889 Mdot
.11654 .11042 Mdot
.06183 .37708 Mdot
.52803 .16984 Mdot
.63983 .01041 Mdot
.48672 .92397 Mdot
.30656 .83862 Mdot
.67073 .84622 Mdot
.03826 .36713 Mdot
.15321 .6836 Mdot
.61537 .52356 Mdot
.08525 .13625 Mdot
.58873 .20248 Mdot
.32581 .86138 Mdot
.1391 .94643 Mdot
.02906 .03257 Mdot
.45857 .11001 Mdot
.6159 .54514 Mdot
.01033 .03138 Mdot
.03479 .49862 Mdot
.7797 .4239 Mdot
.6504 .46767 Mdot
.20164 .36746 Mdot
.30471 .82099 Mdot
.31784 .87175 Mdot
.30418 .79941 Mdot
.15992 .83127 Mdot
.30788 .01576 Mdot
.66498 .86197 Mdot
.22832 .49982 Mdot
.3706 .07236 Mdot
.10121 .75196 Mdot
.13859 .40358 Mdot
.52118 .08841 Mdot
.62907 .03997 Mdot
.63087 .01971 Mdot
.33099 .03402 Mdot
.56632 .15281 Mdot
.28742 .89836 Mdot
.15863 .50459 Mdot
.02282 .54244 Mdot
.51975 .47442 Mdot
.38214 .53253 Mdot
.19856 .45021 Mdot
.40393 .79757 Mdot
.09916 .39701 Mdot
.16981 .6912 Mdot
.44885 .47581 Mdot
.28893 .51961 Mdot
.45132 .85524 Mdot
.08936 .53281 Mdot
.49976 .85724 Mdot
.61815 .09966 Mdot
.20447 .43627 Mdot
.20465 .38803 Mdot
.55994 .1373 Mdot
.48038 .59469 Mdot
.79396 .41213 Mdot
.18562 .32228 Mdot
.25052 .5496 Mdot
.637 .54527 Mdot
.44234 .1188 Mdot
.39971 .9085 Mdot
.10599 .63913 Mdot
.45905 .1012 Mdot
.12641 .90472 Mdot
.25648 .85879 Mdot
.28134 .0684 Mdot
.77564 .50117 Mdot
.0805 .29987 Mdot
.18701 .8762 Mdot
.49073 .98493 Mdot
.21919 .92633 Mdot
.12618 .26763 Mdot
.19443 .48954 Mdot
.65489 .10807 Mdot
.07869 .0303 Mdot
.58419 .7984 Mdot
.40699 .91239 Mdot
.47646 .89497 Mdot
.01196 .72997 Mdot
.6646 .93413 Mdot
.17546 .15741 Mdot
.12229 .64927 Mdot
.51077 .05914 Mdot
.0534 .62877 Mdot
.34132 .95813 Mdot
.12978 .30183 Mdot
.05293 .42398 Mdot
.12762 .56205 Mdot
.34074 .95904 Mdot
.01642 .58009 Mdot
.08984 .33895 Mdot
.56044 .02 Mdot
.51731 .58623 Mdot
.70823 .50826 Mdot
.26481 .88034 Mdot
.31689 .17978 Mdot
.31028 .58989 Mdot
.62692 .58124 Mdot
.15249 .65451 Mdot
.13682 .63054 Mdot
.31821 .84531 Mdot
.01113 .67534 Mdot
.69105 .09526 Mdot
.47061 .82471 Mdot
.64014 .03854 Mdot
.65812 .91966 Mdot
.34971 .08415 Mdot
.53686 .44248 Mdot
.18673 .47904 Mdot
.37612 .88526 Mdot
.10163 .52379 Mdot
.70819 .95579 Mdot
.36828 .88144 Mdot
.0297 .49224 Mdot
.76 .08466 Mdot
.37237 .18848 Mdot
.19544 .69964 Mdot
.11113 .83898 Mdot
.73305 .94773 Mdot
.20275 .66548 Mdot
.71315 .4653 Mdot
.43294 .59062 Mdot
.2098 .94843 Mdot
.16494 .57718 Mdot
.62916 .04474 Mdot
.24429 .91402 Mdot
.50144 .95649 Mdot
.61557 .92919 Mdot
.77849 .50099 Mdot
.19243 .34838 Mdot
.11887 .65055 Mdot
.69267 .94076 Mdot
.66159 .02095 Mdot
.20104 .97448 Mdot
.05582 .08196 Mdot
.41275 .48329 Mdot
.29178 .07727 Mdot
.07264 .79696 Mdot
.62039 .06612 Mdot
.57437 .97436 Mdot
.48381 .08008 Mdot
.78154 .44836 Mdot
.07815 .23386 Mdot
.03583 .69103 Mdot
.77656 .16639 Mdot
.16597 .11007 Mdot
.10139 .08139 Mdot
.58179 .1259 Mdot
.15872 .66211 Mdot
.04058 .93877 Mdot
.34135 .52272 Mdot
.18588 .55813 Mdot
.02971 .45787 Mdot
.28657 .55707 Mdot
.64403 .81488 Mdot
.56731 .47625 Mdot
.49511 .16257 Mdot
.53654 .52768 Mdot
.13754 .92922 Mdot
.5741 .80316 Mdot
.78638 .4163 Mdot
.14127 .23058 Mdot
.48743 .4059 Mdot
.3727 .96914 Mdot
.0782 .88801 Mdot
.65037 .11997 Mdot
.4859 .59629 Mdot
.51891 .87959 Mdot
.5459 .1509 Mdot
.04128 .48349 Mdot
.183 .17196 Mdot
.04896 .24016 Mdot
.18437 .91624 Mdot
.09459 .0824 Mdot
.11597 .03804 Mdot
.45579 .90826 Mdot
.73485 .09284 Mdot
.19876 .93214 Mdot
.02556 .76999 Mdot
.66891 .0689 Mdot
.58413 .9767 Mdot
.12974 .44248 Mdot
.19286 .4138 Mdot
.28744 .85881 Mdot
.41402 .50239 Mdot
.42118 .55378 Mdot
.7353 .44329 Mdot
.72948 .17481 Mdot
.16098 .45679 Mdot
.16355 .80446 Mdot
.78779 .15943 Mdot
.04361 .37179 Mdot
.17887 .9255 Mdot
.56332 .09918 Mdot
.33508 .16054 Mdot
.15194 .53559 Mdot
.25891 .55632 Mdot
.6412 .11083 Mdot
.2251 .19434 Mdot
.47213 .17553 Mdot
.72303 .5126 Mdot
.77222 .49015 Mdot
.25565 .12721 Mdot
.59666 .12642 Mdot
.13487 .25275 Mdot
.24012 .91143 Mdot
.50411 .84579 Mdot
.46165 .19902 Mdot
.33659 .93647 Mdot
.01931 .34795 Mdot
.28855 .93011 Mdot
.06121 .14359 Mdot
.18862 .37539 Mdot
.04819 .28305 Mdot
.31128 .42229 Mdot
.03868 .9253 Mdot
.03254 .48237 Mdot
.42801 .1518 Mdot
.16617 .57896 Mdot
.73527 .91101 Mdot
.32955 .17023 Mdot
.55646 .54542 Mdot
.28509 .8992 Mdot
.52307 .85254 Mdot
.778 .93172 Mdot
.42394 .19184 Mdot
.55317 .58327 Mdot
.66585 .85071 Mdot
.03116 .98624 Mdot
.75599 .91947 Mdot
.49828 .14351 Mdot
.02211 .577 Mdot
.71048 .20199 Mdot
.48894 .79608 Mdot
.12881 .15384 Mdot
.56584 .56077 Mdot
.144 .77098 Mdot
.06042 .18864 Mdot
.1317 .20378 Mdot
.34013 .97685 Mdot
.53352 .79902 Mdot
.30852 .86198 Mdot
.72847 .55339 Mdot
.18938 .24084 Mdot
.13877 .062 Mdot
.68278 .4192 Mdot
.78883 .07535 Mdot
.15906 .61038 Mdot
.73474 .94559 Mdot
.63892 .0228 Mdot
.14253 .84423 Mdot
.59211 .17637 Mdot
.44994 .43484 Mdot
.79348 .11083 Mdot
.30068 .81465 Mdot
.55614 .85925 Mdot
.66026 .01768 Mdot
.71306 .54066 Mdot
.5756 .52487 Mdot
.1402 .26159 Mdot
.19001 .25728 Mdot
.33416 .04104 Mdot
.28338 .56808 Mdot
.12703 .81818 Mdot
.61332 .5602 Mdot
.24494 .54967 Mdot
.26145 .20117 Mdot
.18953 .08113 Mdot
.08124 .93408 Mdot
.73728 .90285 Mdot
.07644 .07592 Mdot
.62005 .09447 Mdot
.45332 .50591 Mdot
.55306 .48637 Mdot
.56436 .46045 Mdot
.24294 .16326 Mdot
.06322 .09193 Mdot
.7034 .44794 Mdot
.49419 .41255 Mdot
.19326 .86611 Mdot
.07464 .31776 Mdot
.50048 .8475 Mdot
.19757 .58822 Mdot
.34384 .15395 Mdot
.4621 .85048 Mdot
.58796 .5324 Mdot
.18002 .06854 Mdot
.03245 .36714 Mdot
.77296 .82265 Mdot
.0138 .21964 Mdot
.3054 .88897 Mdot
.28276 .53164 Mdot
.06081 .32845 Mdot
.16259 .60081 Mdot
.33406 .4874 Mdot
.03846 .58862 Mdot
.17123 .62898 Mdot
.7459 .06679 Mdot
.12022 .31033 Mdot
.72876 .05764 Mdot
.68473 .01235 Mdot
.57597 .44702 Mdot
.68554 .01262 Mdot
.25171 .94982 Mdot
.52892 .58396 Mdot
.16932 .01955 Mdot
.43076 .95211 Mdot
.60308 .55526 Mdot
.38983 .19406 Mdot
.32083 .80119 Mdot
.75316 .86049 Mdot
.3322 .89858 Mdot
.05565 .48979 Mdot
.15332 .95243 Mdot
.17115 .05772 Mdot
.47667 .98544 Mdot
.20799 .06818 Mdot
.13473 .76352 Mdot
.64043 .12916 Mdot
.08821 .35524 Mdot
.27934 .45162 Mdot
.79286 .45638 Mdot
.07598 .51336 Mdot
.7936 .84482 Mdot
.66867 .09111 Mdot
.03648 .68758 Mdot
.03805 .95214 Mdot
.24101 .41978 Mdot
.58906 .1142 Mdot
.67051 .16489 Mdot
.11807 .83693 Mdot
.0519 .33338 Mdot
.08404 .84408 Mdot
.18391 .86859 Mdot
.15724 .19082 Mdot
.37732 .80084 Mdot
.42748 .20393 Mdot
.74717 .04885 Mdot
.2189 .8101 Mdot
.1768 .48652 Mdot
.03201 .90322 Mdot
.60206 .98943 Mdot
.39297 .18914 Mdot
.17293 .84327 Mdot
.23308 .09449 Mdot
.7636 .13922 Mdot
.45842 .0113 Mdot
.15647 .50731 Mdot
.30891 .82746 Mdot
.46339 .81312 Mdot
.34069 .49775 Mdot
.24722 .13011 Mdot
.17756 .64467 Mdot
.02394 .04543 Mdot
.40416 .51526 Mdot
.17789 .37656 Mdot
.20719 .94448 Mdot
.61092 .43107 Mdot
.68895 .80206 Mdot
.63183 .98795 Mdot
.13533 .21601 Mdot
.07144 .79538 Mdot
.0214 .29389 Mdot
.37269 .98352 Mdot
.41481 .88864 Mdot
.0879 .69671 Mdot
.44454 .87125 Mdot
.32074 .49276 Mdot
.1715 .95408 Mdot
.33096 .43565 Mdot
.52759 .94503 Mdot
.12258 .06619 Mdot
.66824 .18513 Mdot
.4339 .04667 Mdot
.0357 .93511 Mdot
.12296 .54411 Mdot
.39941 .86761 Mdot
.44115 .43508 Mdot
.01642 .54574 Mdot
.13689 .65259 Mdot
.02374 .11829 Mdot
.12633 .61981 Mdot
.29337 .79541 Mdot
.7915 .87771 Mdot
.01368 .11006 Mdot
.45281 .49271 Mdot
.3224 .82363 Mdot
.75493 .15067 Mdot
.741 .04219 Mdot
.12047 .80666 Mdot
.10077 .24585 Mdot
.22865 .023 Mdot
.76856 .41241 Mdot
.46391 .86253 Mdot
.43668 .18961 Mdot
.71311 .83015 Mdot
.22133 .57681 Mdot
.78767 .85153 Mdot
.58153 .48715 Mdot
.28653 .01007 Mdot
.36269 .47395 Mdot
.50817 .58786 Mdot
.08129 .40805 Mdot
.18566 .76166 Mdot
.07228 .9601 Mdot
.22798 .85507 Mdot
.28376 .89397 Mdot
.20913 .5307 Mdot
.07078 .50715 Mdot
.42433 .13923 Mdot
.15038 .23545 Mdot
.75559 .92349 Mdot
.09405 .60606 Mdot
.55627 .40259 Mdot
.1254 .69988 Mdot
.27712 .04038 Mdot
.21615 .52342 Mdot
0 0 1 r
.98825 .56093 Mdot
.78201 .394 Mdot
.28208 .7383 Mdot
.87604 .23506 Mdot
.85319 .65894 Mdot
.83632 .27847 Mdot
.85514 .10782 Mdot
.41287 .71612 Mdot
.39774 .27793 Mdot
.20725 .6584 Mdot
.25436 .70338 Mdot
.83169 .97745 Mdot
.34157 .65241 Mdot
.95243 .96186 Mdot
.73012 .75863 Mdot
.65357 .38382 Mdot
.40901 .67064 Mdot
.56752 .68338 Mdot
.2595 .23912 Mdot
.5535 .6395 Mdot
.21176 .20824 Mdot
.96088 .57608 Mdot
.9514 .70654 Mdot
.43116 .70322 Mdot
.31014 .38033 Mdot
.74683 .73103 Mdot
.8614 .46987 Mdot
.45619 .28832 Mdot
.80658 .40813 Mdot
.90921 .76526 Mdot
.60888 .39473 Mdot
.85224 .6539 Mdot
.74023 .71938 Mdot
.40586 .37538 Mdot
.95316 .73516 Mdot
.7443 .70247 Mdot
.91755 .36363 Mdot
.82528 .9274 Mdot
.62152 .30705 Mdot
.87148 .57787 Mdot
.94849 .51318 Mdot
.90852 .8329 Mdot
.85401 .33243 Mdot
.83458 .15204 Mdot
.28443 .68295 Mdot
.60163 .64595 Mdot
.9703 .34871 Mdot
.69407 .26171 Mdot
.73578 .73873 Mdot
.87196 .4161 Mdot
.76225 .78614 Mdot
.57417 .28003 Mdot
.96274 .62427 Mdot
.98263 .28537 Mdot
.72551 .701 Mdot
.88381 .51453 Mdot
.97993 .95247 Mdot
.34572 .75023 Mdot
.8483 .64704 Mdot
.73804 .26963 Mdot
.42872 .68433 Mdot
.85199 .46973 Mdot
.85412 .70941 Mdot
.25978 .71486 Mdot
.96315 .38349 Mdot
.27955 .40016 Mdot
.56608 .37909 Mdot
.63961 .22816 Mdot
.96057 .8944 Mdot
.63215 .68364 Mdot
.34576 .72823 Mdot
.36318 .71772 Mdot
.80936 .86524 Mdot
.50044 .75352 Mdot
.9082 .34961 Mdot
.58835 .72863 Mdot
.98105 .65832 Mdot
.89664 .89671 Mdot
.49386 .65078 Mdot
.49584 .33279 Mdot
.36413 .756 Mdot
.89769 .59436 Mdot
.83909 .91051 Mdot
.82935 .26037 Mdot
.85086 .07581 Mdot
.4273 .25998 Mdot
.92364 .5994 Mdot
.77071 .71302 Mdot
.86322 .12846 Mdot
.62109 .32827 Mdot
.51674 .26201 Mdot
.69104 .6255 Mdot
.93992 .44529 Mdot
.81731 .59048 Mdot
.71913 .61946 Mdot
.3589 .67338 Mdot
.31526 .63698 Mdot
.88696 .46751 Mdot
.81922 .43401 Mdot
.47013 .75083 Mdot
.84784 .27077 Mdot
.80217 .4891 Mdot
.95108 .79346 Mdot
.818 .26596 Mdot
.41385 .34813 Mdot
.45422 .25804 Mdot
.93651 .77342 Mdot
.66081 .6279 Mdot
.63445 .26422 Mdot
.81354 .72889 Mdot
.75149 .39488 Mdot
.98906 .46828 Mdot
.6738 .27524 Mdot
.55567 .657 Mdot
.69763 .31328 Mdot
.38209 .24913 Mdot
.51966 .37053 Mdot
.58917 .66516 Mdot
.91704 .88957 Mdot
.8643 .61291 Mdot
.49202 .37358 Mdot
.66025 .34439 Mdot
.63007 .75821 Mdot
.69292 .61066 Mdot
.8338 .41926 Mdot
.59313 .65862 Mdot
.82038 .37311 Mdot
.8104 .05896 Mdot
.5129 .76656 Mdot
.73601 .21119 Mdot
.50488 .2594 Mdot
.328 .69067 Mdot
.93284 .18353 Mdot
.80529 .91431 Mdot
.81272 .32506 Mdot
.53643 .22996 Mdot
.24002 .71852 Mdot
.85193 .34366 Mdot
.53373 .64319 Mdot
.71864 .71908 Mdot
.98789 .41235 Mdot
.52564 .23419 Mdot
.67616 .3196 Mdot
.37109 .33521 Mdot
.94772 .59072 Mdot
.61869 .75152 Mdot
.78885 .2082 Mdot
.40879 .78873 Mdot
.94072 .67515 Mdot
.86287 .8775 Mdot
.46694 .30364 Mdot
.76683 .24567 Mdot
.73934 .68581 Mdot
.25121 .32848 Mdot
.53455 .29819 Mdot
.74203 .78638 Mdot
.28361 .71696 Mdot
.84969 .30461 Mdot
.83926 .80959 Mdot
.84263 .08344 Mdot
.56269 .72502 Mdot
.98704 .94413 Mdot
.57928 .34763 Mdot
.80489 .59681 Mdot
.71422 .25057 Mdot
.3198 .76422 Mdot
.71737 .29664 Mdot
.46595 .59997 Mdot
.94227 .18544 Mdot
.28274 .71954 Mdot
.54222 .30295 Mdot
.9715 .76002 Mdot
.38857 .27625 Mdot
.82118 .37392 Mdot
.56362 .25376 Mdot
.33184 .71099 Mdot
.79527 .32968 Mdot
.68943 .77297 Mdot
.47331 .6123 Mdot
.91212 .02923 Mdot
.59008 .30843 Mdot
.48439 .6865 Mdot
.86912 .7564 Mdot
.65933 .38452 Mdot
.54756 .78417 Mdot
.42934 .38554 Mdot
.2679 .768 Mdot
.82945 .0869 Mdot
.51534 .23655 Mdot
.97876 .17777 Mdot
.32923 .78345 Mdot
.30837 .38698 Mdot
.70939 .73371 Mdot
.89802 .79247 Mdot
.27141 .33193 Mdot
.4014 .77248 Mdot
.34203 .79249 Mdot
.83932 .96748 Mdot
.86083 .79872 Mdot
.95301 .01606 Mdot
.4091 .66804 Mdot
.6914 .67432 Mdot
.46302 .24881 Mdot
.90486 .50025 Mdot
.9068 .30515 Mdot
.57263 .69796 Mdot
.72351 .72067 Mdot
.75218 .65908 Mdot
.78937 .65283 Mdot
.63494 .7297 Mdot
.68949 .71528 Mdot
.95618 .9848 Mdot
.34335 .30766 Mdot
.54418 .64503 Mdot
.44621 .66652 Mdot
.80147 .92702 Mdot
.72939 .35233 Mdot
.9778 .53572 Mdot
.64425 .23786 Mdot
.5221 .6607 Mdot
.84258 .96988 Mdot
.78291 .31817 Mdot
.74301 .68111 Mdot
.95777 .91373 Mdot
.37369 .21391 Mdot
.91224 .81695 Mdot
.52131 .23423 Mdot
.75205 .7472 Mdot
.97039 .8057 Mdot
.70742 .76921 Mdot
.84278 .11186 Mdot
.81524 .97164 Mdot
.3055 .36802 Mdot
.45135 .76753 Mdot
.92024 .54311 Mdot
.858 .215 Mdot
.72176 .67122 Mdot
.47744 .63855 Mdot
.96077 .78054 Mdot
.90739 .04449 Mdot
.93333 .20436 Mdot
.83858 .90532 Mdot
.69981 .33867 Mdot
.94667 .73839 Mdot
.60191 .7721 Mdot
.46236 .31933 Mdot
.36801 .2414 Mdot
.91874 .52904 Mdot
.83909 .4248 Mdot
.24699 .6429 Mdot
.62776 .64914 Mdot
.48365 .77611 Mdot
.42993 .2578 Mdot
.84321 .91214 Mdot
.91466 .39291 Mdot
.88855 .61181 Mdot
.97541 .25196 Mdot
.81001 .90254 Mdot
.63233 .65698 Mdot
.88508 .62037 Mdot
.59538 .69243 Mdot
.98673 .01836 Mdot
.9726 .79133 Mdot
.98738 .54917 Mdot
.80452 .62954 Mdot
.78772 .26467 Mdot
.89284 .6345 Mdot
.89631 .62594 Mdot
.39331 .72964 Mdot
.95365 .80799 Mdot
.71802 .23511 Mdot
.43334 .6811 Mdot
.36699 .29268 Mdot
.79624 .69658 Mdot
.31763 .28701 Mdot
.8801 .66703 Mdot
.64325 .39453 Mdot
.85276 .87855 Mdot
.83721 .68814 Mdot
.54493 .60135 Mdot
.43428 .7212 Mdot
.97521 .57205 Mdot
.69144 .29862 Mdot
.21098 .21596 Mdot
.78064 .32885 Mdot
.2408 .66273 Mdot
.38877 .63825 Mdot
.34058 .73415 Mdot
.91704 .59493 Mdot
.89603 .45487 Mdot
.58701 .30655 Mdot
.35601 .63402 Mdot
.31316 .78004 Mdot
.63186 .29287 Mdot
.66903 .27114 Mdot
.27895 .24983 Mdot
.82017 .8659 Mdot
.91114 .2296 Mdot
.70212 .25766 Mdot
.30273 .63249 Mdot
.47275 .75679 Mdot
.4125 .61975 Mdot
.94612 .67093 Mdot
.92383 .81353 Mdot
.31396 .35046 Mdot
.27834 .32428 Mdot
.58256 .28046 Mdot
.20962 .24526 Mdot
.83321 .41409 Mdot
.7547 .33667 Mdot
.89957 .59076 Mdot
.70078 .66538 Mdot
.43931 .27805 Mdot
.89102 .32666 Mdot
.76089 .22668 Mdot
.69859 .74753 Mdot
.2253 .30888 Mdot
.32727 .36318 Mdot
.89722 .26268 Mdot
.28807 .28746 Mdot
.57452 .25201 Mdot
.4582 .61646 Mdot
.24271 .31738 Mdot
.79387 .66284 Mdot
.93091 .03666 Mdot
.65265 .7394 Mdot
.48487 .62071 Mdot
.78396 .68686 Mdot
.53799 .26428 Mdot
.45808 .63216 Mdot
.51999 .78339 Mdot
.26854 .61345 Mdot
.57928 .75653 Mdot
.20916 .74074 Mdot
.91682 .02694 Mdot
.89406 .42893 Mdot
.44578 .78696 Mdot
.48489 .33269 Mdot
.96809 .43276 Mdot
.55826 .31555 Mdot
.2634 .31273 Mdot
.9625 .11466 Mdot
.66192 .75821 Mdot
.38815 .23225 Mdot
.8293 .80053 Mdot
.7976 .06205 Mdot
.81615 .90614 Mdot
.50196 .77292 Mdot
.31488 .33792 Mdot
.21522 .23435 Mdot
.67321 .3973 Mdot
.96629 .49469 Mdot
.28556 .60106 Mdot
.41312 .71298 Mdot
.412 .62682 Mdot
.54346 .63438 Mdot
.44667 .73796 Mdot
.91512 .68704 Mdot
.86298 .88083 Mdot
.50923 .24998 Mdot
.88385 .24251 Mdot
.84077 .50012 Mdot
.9685 .5 Mdot
.36618 .29798 Mdot
.46908 .25982 Mdot
.28152 .27948 Mdot
.43095 .76956 Mdot
.87002 .43665 Mdot
.85323 .07449 Mdot
.89171 .92685 Mdot
.49686 .76671 Mdot
.43244 .67683 Mdot
.44964 .30987 Mdot
.73717 .26084 Mdot
.34245 .37926 Mdot
.83544 .85645 Mdot
.97016 .60155 Mdot
.92035 .57502 Mdot
.49343 .62465 Mdot
.98224 .13313 Mdot
.6496 .74406 Mdot
.61084 .77208 Mdot
.68599 .75623 Mdot
.48046 .61371 Mdot
.97723 .97926 Mdot
.44816 .68584 Mdot
.96394 .98161 Mdot
.49328 .3777 Mdot
.8997 .18182 Mdot
.50625 .38864 Mdot
.48487 .38449 Mdot
.56281 .73684 Mdot
.92802 .39513 Mdot
.58907 .74543 Mdot
.67861 .23214 Mdot
.22707 .73616 Mdot
.86198 .14079 Mdot
.56959 .22153 Mdot
.4177 .71965 Mdot
.32191 .35192 Mdot
.85525 .78567 Mdot
.72256 .36302 Mdot
.85078 .23203 Mdot
.87231 .61869 Mdot
.85671 .80616 Mdot
.33845 .60089 Mdot
.81224 .11084 Mdot
.82561 .75591 Mdot
.95166 .86901 Mdot
.39605 .33269 Mdot
.84608 .24863 Mdot
.51743 .63794 Mdot
.97512 .06248 Mdot
.53095 .21432 Mdot
.72853 .30132 Mdot
.87264 .06249 Mdot
.60537 .3649 Mdot
.62044 .31223 Mdot
.45757 .36059 Mdot
.25615 .28776 Mdot
.63603 .35656 Mdot
.89771 .06505 Mdot
.96533 .8269 Mdot
.88732 .17369 Mdot
.91577 .8027 Mdot
.34507 .61089 Mdot
.36994 .77419 Mdot
.47715 .2097 Mdot
.81223 .8488 Mdot
.55157 .3972 Mdot
.2163 .7765 Mdot
.45139 .6946 Mdot
.83656 .01212 Mdot
.44354 .21639 Mdot
.82131 .74279 Mdot
.77475 .72417 Mdot
.70318 .65696 Mdot
.36206 .73194 Mdot
.46797 .28336 Mdot
.95956 .40832 Mdot
.62161 .28105 Mdot
.38901 .726 Mdot
.85147 .41442 Mdot
.83918 .84286 Mdot
.42824 .73994 Mdot
.45888 .34143 Mdot
.92325 .14951 Mdot
.29694 .27151 Mdot
.20963 .40002 Mdot
.94399 .1031 Mdot
.52555 .35335 Mdot
.36506 .75987 Mdot
.94184 .20026 Mdot
.85848 .10796 Mdot
.8961 .9119 Mdot
.60284 .78592 Mdot
.47273 .65385 Mdot
.51758 .72325 Mdot
.82022 .04972 Mdot
.88167 .72417 Mdot
.80664 .23403 Mdot
.89488 .08721 Mdot
.212 .66853 Mdot
.53597 .59866 Mdot
.37214 .28091 Mdot
.39157 .27358 Mdot
.86802 .7512 Mdot
.56155 .23366 Mdot
.97654 .03684 Mdot
.28218 .34578 Mdot
.56409 .22637 Mdot
.75129 .2694 Mdot
.87347 .50839 Mdot
.88712 .48136 Mdot
.90076 .37461 Mdot
.33284 .26479 Mdot
.44483 .26287 Mdot
.77909 .31572 Mdot
.30075 .65759 Mdot
.89582 .79753 Mdot
.75261 .31932 Mdot
.47204 .37005 Mdot
.23513 .24024 Mdot
.77752 .25679 Mdot
.91007 .71105 Mdot
.91573 .49989 Mdot
.82495 .76379 Mdot
.36939 .32209 Mdot
.78776 .7595 Mdot
.63029 .36778 Mdot
.97426 .46188 Mdot
.51348 .23101 Mdot
.44167 .21773 Mdot
.86765 .45646 Mdot
.95987 .61473 Mdot
.97581 .16265 Mdot
.8265 .46457 Mdot
.92955 .25893 Mdot
.39463 .25664 Mdot
.78547 .35 Mdot
.90801 .88374 Mdot
.72691 .71778 Mdot
.93532 .48564 Mdot
.72955 .2818 Mdot
.55049 .2388 Mdot
.93428 .92199 Mdot
.79997 .43058 Mdot
.31582 .59993 Mdot
.53439 .64973 Mdot
.98974 .53096 Mdot
.26999 .25897 Mdot
.3259 .32718 Mdot
.29964 .28894 Mdot
.49964 .216 Mdot
.84012 .20159 Mdot
.82139 .15411 Mdot
.82185 .61334 Mdot
.71647 .37797 Mdot
.56167 .36417 Mdot
.93612 .74806 Mdot
.61509 .39756 Mdot
.78344 .77441 Mdot
.97621 .38305 Mdot
.28445 .64378 Mdot
.98187 .50694 Mdot
.9689 .68576 Mdot
.95388 .4913 Mdot
.96787 .11806 Mdot
.92779 .48306 Mdot
.34379 .39974 Mdot
.36508 .70417 Mdot
.21593 .31132 Mdot
.30067 .7102 Mdot
.72889 .67603 Mdot
.94707 .32027 Mdot
.5918 .60629 Mdot
.45259 .64508 Mdot
.96779 .3089 Mdot
.96403 .88225 Mdot
.72005 .27843 Mdot
.27628 .24879 Mdot
.50023 .3565 Mdot
.81388 .5939 Mdot
.8359 .45871 Mdot
.97779 .51795 Mdot
.95826 .21951 Mdot
.28132 .65929 Mdot
.77129 .31259 Mdot
.8681 .37682 Mdot
.25846 .26499 Mdot
.75694 .351 Mdot
.61962 .21724 Mdot
.29691 .6162 Mdot
.98845 .86138 Mdot
.87528 .22054 Mdot
.97928 .35045 Mdot
.85437 .96523 Mdot
.95128 .90169 Mdot
.70437 .77532 Mdot
.80734 .264 Mdot
.55168 .2607 Mdot
.82223 .40033 Mdot
.4758 .37638 Mdot
.83315 .05968 Mdot
.61162 .40135 Mdot
.87206 .14819 Mdot
.27718 .36487 Mdot
.75782 .62614 Mdot
.34094 .60009 Mdot
.21594 .37524 Mdot
.50891 .20956 Mdot
.84154 .24245 Mdot
.6164 .64843 Mdot
.27638 .35231 Mdot
.50876 .71638 Mdot
.81389 .59921 Mdot
.30262 .35094 Mdot
.31479 .39946 Mdot
.56247 .35208 Mdot
.63903 .24958 Mdot
.44375 .74477 Mdot
.84513 .23809 Mdot
.80727 .44343 Mdot
.26001 .77154 Mdot
.93542 .38189 Mdot
.94219 .74041 Mdot
.90603 .48352 Mdot
.22252 .32417 Mdot
.59 .32371 Mdot
.87881 .17207 Mdot
.26827 .77797 Mdot
.93359 .78038 Mdot
.6372 .64807 Mdot
.79823 .05172 Mdot
.8824 .5584 Mdot
.96342 .42967 Mdot
.3022 .2445 Mdot
.8246 .48605 Mdot
.51948 .36422 Mdot
.93599 .32378 Mdot
.93493 .53888 Mdot
.20604 .70202 Mdot
.94229 .69407 Mdot
.37164 .22577 Mdot
.43262 .33965 Mdot
.42343 .36839 Mdot
.23668 .22432 Mdot
.87895 .35116 Mdot
.83588 .77899 Mdot
.68271 .63934 Mdot
.88379 .09472 Mdot
.46098 .74527 Mdot
.88524 .52138 Mdot
.41339 .67013 Mdot
.95271 .0598 Mdot
.52463 .32877 Mdot
.83212 .67963 Mdot
.52104 .26607 Mdot
.626 .73488 Mdot
.43 .6618 Mdot
.46749 .61181 Mdot
.35066 .35061 Mdot
.85341 .63729 Mdot
.35537 .7335 Mdot
.86287 .30416 Mdot
.44267 .63255 Mdot
.96537 .03055 Mdot
.62451 .67014 Mdot
.85835 .28512 Mdot
.63095 .38272 Mdot
.83618 .8256 Mdot
.23573 .65346 Mdot
.861 .80486 Mdot
.7296 .62909 Mdot
.53038 .62997 Mdot
.88963 .25705 Mdot
.29923 .39881 Mdot
.58244 .74875 Mdot
.97585 .69407 Mdot
.34595 .61403 Mdot
.58712 .77898 Mdot
.72923 .71936 Mdot
.81581 .70692 Mdot
.35741 .78337 Mdot
.7126 .68026 Mdot
.91342 .64172 Mdot
.97356 .9511 Mdot
.38756 .74966 Mdot
.65336 .27819 Mdot
.64661 .60456 Mdot
.89575 .79633 Mdot
.51234 .39069 Mdot
.50222 .36002 Mdot
.84179 .35772 Mdot
.84791 .84235 Mdot
.93623 .55159 Mdot
.90001 .42904 Mdot
.55329 .28036 Mdot
.46792 .27672 Mdot
.70127 .60034 Mdot
.81425 .1866 Mdot
.90443 .74775 Mdot
.44887 .34268 Mdot
.41915 .7746 Mdot
.94142 .50768 Mdot
.83513 .46429 Mdot
.8473 .65901 Mdot
.61089 .66248 Mdot
.8726 .72813 Mdot
.91779 .84948 Mdot
.65493 .77704 Mdot
.25719 .62887 Mdot
.79591 .11115 Mdot
.86832 .25187 Mdot
.90173 .93739 Mdot
.73478 .7145 Mdot
.69075 .59995 Mdot
.92049 .43028 Mdot
.89813 .27193 Mdot
.75752 .62181 Mdot
.332 .30735 Mdot
.22129 .27559 Mdot
.87884 .33627 Mdot
.81027 .26592 Mdot
.83064 .8598 Mdot
.92271 .59767 Mdot
.88592 .51116 Mdot
.86318 .60386 Mdot
.54098 .30631 Mdot
.32498 .20617 Mdot
.23808 .25951 Mdot
.83227 .70411 Mdot
.39764 .38991 Mdot
.46512 .78243 Mdot
.77707 .61441 Mdot
.86934 .15962 Mdot
.91561 .93628 Mdot
.68734 .68658 Mdot
.2995 .30648 Mdot
.82457 .51424 Mdot
.90279 .83473 Mdot
.49247 .3884 Mdot
.7971 .74757 Mdot
.61333 .23859 Mdot
.87168 .80148 Mdot
.88484 .80842 Mdot
.80592 .66883 Mdot
.89332 .8243 Mdot
.21566 .64679 Mdot
.78753 .21692 Mdot
.26968 .63613 Mdot
.95668 .55724 Mdot
.63231 .71193 Mdot
.68196 .67635 Mdot
.43776 .67858 Mdot
.86985 .26696 Mdot
.90336 .69991 Mdot
.69573 .61343 Mdot
.62438 .35232 Mdot
.93262 .66617 Mdot
.82432 .89595 Mdot
.39637 .22718 Mdot
.88858 .21899 Mdot
.94616 .54302 Mdot
.9861 .94167 Mdot
.50696 .24497 Mdot
.9744 .67366 Mdot
.8635 .97039 Mdot
.52483 .76683 Mdot
.7658 .61933 Mdot
.23964 .35331 Mdot
.36634 .37312 Mdot
.98971 .97048 Mdot
.5579 .28534 Mdot
.47468 .21346 Mdot
.93596 .3883 Mdot
.50954 .79191 Mdot
.34959 .66186 Mdot
.21935 .77392 Mdot
.21984 .79364 Mdot
.88874 .52979 Mdot
.78958 .21149 Mdot
.52432 .72111 Mdot
.89711 .28061 Mdot
.56914 .33748 Mdot
.39498 .63227 Mdot
.29112 .32523 Mdot
.8956 .85463 Mdot
.94262 .45444 Mdot
.54205 .76869 Mdot
.4281 .72353 Mdot
.62676 .74706 Mdot
.76512 .34239 Mdot
.94067 .78957 Mdot
.85808 .65856 Mdot
.58449 .39928 Mdot
.98974 .7869 Mdot
.63309 .24739 Mdot
.76709 .68211 Mdot
.40177 .33589 Mdot
.72727 .75122 Mdot
.21663 .6708 Mdot
.83836 .57349 Mdot
.84544 .58941 Mdot
.21507 .33591 Mdot
.8035 .00982 Mdot
.8789 .97375 Mdot
.40558 .35543 Mdot
.86062 .85624 Mdot
.55033 .75621 Mdot
.84205 .53012 Mdot
.24199 .7191 Mdot
.61979 .69287 Mdot
.66427 .71076 Mdot
.22401 .34725 Mdot
.29644 .78446 Mdot
.84586 .71517 Mdot
.82902 .30077 Mdot
.21903 .59809 Mdot
.79874 .84431 Mdot
.98522 .26065 Mdot
.33115 .66961 Mdot
.8566 .6752 Mdot
.22942 .62646 Mdot
.25129 .6009 Mdot
.44275 .74679 Mdot
.43786 .7472 Mdot
.49634 .2336 Mdot
.59315 .65799 Mdot
.25098 .79143 Mdot
.55697 .69331 Mdot
.58235 .64774 Mdot
.50585 .31849 Mdot
.30496 .63225 Mdot
.23893 .71136 Mdot
.26906 .22747 Mdot
.96278 .15221 Mdot
.7216 .35098 Mdot
.5108 .64888 Mdot
.91716 .81009 Mdot
.65659 .78708 Mdot
.77059 .31243 Mdot
.66672 .28398 Mdot
.51188 .2791 Mdot
.84764 .03279 Mdot
.80391 .43228 Mdot
.80527 .04629 Mdot
.43895 .64525 Mdot
.27899 .66597 Mdot
.60354 .64932 Mdot
.78983 .22684 Mdot
.57968 .71916 Mdot
.83756 .04205 Mdot
.96198 .39664 Mdot
.83535 .69789 Mdot
.31362 .40183 Mdot
.70028 .7427 Mdot
.90065 .52566 Mdot
.83167 .08743 Mdot
.45895 .63909 Mdot
.90373 .71027 Mdot
.50309 .29539 Mdot
.89532 .35024 Mdot
.56312 .30999 Mdot
.60744 .39706 Mdot
.81264 .37199 Mdot
.45837 .38266 Mdot
.97514 .13713 Mdot
.56775 .67912 Mdot
.27171 .62337 Mdot
.92284 .67628 Mdot
.36952 .3761 Mdot
.42056 .72656 Mdot
.95815 .24311 Mdot
.59812 .36438 Mdot
.49497 .68326 Mdot
.91742 .01394 Mdot
.3246 .32593 Mdot
.98478 .32786 Mdot
.86623 .46595 Mdot
.65711 .70865 Mdot
.68221 .21481 Mdot
.755 .21068 Mdot
.92064 .6521 Mdot
.47825 .22241 Mdot
.30106 .32434 Mdot
.84425 .89885 Mdot
.87926 .92997 Mdot
.94881 .28767 Mdot
.93867 .10458 Mdot
.89441 .10151 Mdot
.36347 .25799 Mdot
.47441 .31821 Mdot
.66042 .63133 Mdot
.67022 .29238 Mdot
.87085 .89138 Mdot
.97223 .03028 Mdot
.83605 .5432 Mdot
.94618 .93233 Mdot
.90004 .42129 Mdot
.84013 .97797 Mdot
.95948 .0964 Mdot
.26982 .22244 Mdot
.94827 .36109 Mdot
.31384 .2803 Mdot
.82373 .39749 Mdot
.91302 .7502 Mdot
.91388 .96639 Mdot
.81917 .17731 Mdot
.24501 .34097 Mdot
.25512 .67456 Mdot
.52971 .6062 Mdot
.32681 .30879 Mdot
.9439 .52154 Mdot
.75786 .35392 Mdot
.51255 .66955 Mdot
.68365 .35307 Mdot
.92086 .59306 Mdot
.90822 .31334 Mdot
.87568 .42836 Mdot
.9876 .04911 Mdot
.28381 .76196 Mdot
.29186 .32948 Mdot
.55469 .32093 Mdot
.82418 .5117 Mdot
.77927 .39165 Mdot
.9465 .26335 Mdot
.79494 .57566 Mdot
.9491 .22404 Mdot
.88236 .76799 Mdot
.32891 .7286 Mdot
.97535 .03563 Mdot
.67603 .62541 Mdot
.88728 .93598 Mdot
.82497 .63338 Mdot
.56817 .21718 Mdot
.79395 .7899 Mdot
.45836 .25828 Mdot
.8088 .76408 Mdot
.81621 .36952 Mdot
.51387 .74227 Mdot
.42304 .33294 Mdot
.58827 .68975 Mdot
.74488 .35308 Mdot
.89544 .2562 Mdot
.92627 .5792 Mdot
.92925 .15237 Mdot
.91793 .12969 Mdot
.56414 .61521 Mdot
.9784 .67479 Mdot
.6589 .36882 Mdot
.62993 .26847 Mdot
.64062 .33957 Mdot
.23142 .72768 Mdot
.9301 .55684 Mdot
.20668 .40025 Mdot
.63274 .77524 Mdot
.96404 .41622 Mdot
.30513 .75263 Mdot
.42225 .67413 Mdot
.9398 .81263 Mdot
.80586 .48267 Mdot
.95125 .8113 Mdot
.59582 .6155 Mdot
.83707 .30665 Mdot
.60971 .27539 Mdot
.93196 .32132 Mdot
.47743 .66757 Mdot
.88314 .44164 Mdot
.8718 .06187 Mdot
.26637 .24589 Mdot
.94661 .96733 Mdot
.81327 .42607 Mdot
.82702 .52836 Mdot
.34565 .7487 Mdot
.93408 .09653 Mdot
.46404 .69664 Mdot
.86972 .78633 Mdot
.80186 .70139 Mdot
.97879 .28512 Mdot
.33004 .33138 Mdot
.50519 .77321 Mdot
.30518 .62428 Mdot
.80031 .09687 Mdot
.47355 .27748 Mdot
.27749 .26376 Mdot
.91527 .52056 Mdot
.86342 .4272 Mdot
.95765 .78881 Mdot
.92297 .91188 Mdot
.76539 .31537 Mdot
.98271 .2784 Mdot
.96056 .06021 Mdot
.8418 .58744 Mdot
.42539 .63356 Mdot
.95424 .32362 Mdot
.41055 .35143 Mdot
.80447 .78303 Mdot
.75918 .26299 Mdot
.84161 .47095 Mdot
.34359 .61963 Mdot
.87584 .77488 Mdot
.55696 .23528 Mdot
.9118 .46107 Mdot
.45084 .38922 Mdot
.88408 .16375 Mdot
.42248 .70642 Mdot
.73767 .27989 Mdot
.9432 .2636 Mdot
.96434 .71663 Mdot
.38949 .682 Mdot
.81569 .56235 Mdot
.69821 .62189 Mdot
.92437 .98144 Mdot
.39653 .66381 Mdot
.752 .25904 Mdot
.9051 .96914 Mdot
.51838 .31514 Mdot
.89899 .45048 Mdot
.80495 .42553 Mdot
.49825 .65071 Mdot
.66701 .63275 Mdot
.23975 .34769 Mdot
.42765 .2337 Mdot
.293 .22737 Mdot
.96341 .76805 Mdot
.47825 .79203 Mdot
.95672 .23107 Mdot
.32953 .77239 Mdot
.51575 .29435 Mdot
.79509 .83329 Mdot
.93889 .17607 Mdot
.59881 .70857 Mdot
.75613 .24896 Mdot
.47321 .70593 Mdot
.91345 .74582 Mdot
.83214 .06426 Mdot
.56605 .69495 Mdot
.69305 .35102 Mdot
.5355 .68535 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`0`ooooo`?oo`006_ooool3ool000?o
oooo0ooo000Yooooo`?oo`00<Oooool3ool000[ooooo0ooo0009ooooo`?oo`004oooool30000o`Ko
oooo0ol00?l]ooooo`4000000Oooool0000300000?oooooooooo013ooooo0ooo000Looooo`Goo`00
6?ooool5ool00003oooooooo003oo`0000?oo`009oooool5ool002oooooo1Ooo0008ooooo`Goo`00
1oooool7ool000oooooo1@000?l4ooooo`Go003o4oooool30000oaKooooo0@000001ooooo`0000<0
0000ooooooooool03oooool5ool001_ooooo1ooo000Fooooo`Goo`0000?oooooool00?oo00001?oo
000Vooooo`Goo`00;oooool:ool000?ooooo1Ooo0007ooooo`Soo`003_ooool50000o`Cooooo1Ol0
0?lBooooo`D0003o1oooool3o`00o`Kooooo0ol00?l2ooooo`4000000Oooool0000300000?oooooo
oooo00oooooo1Ooo000Hooooo`_oo`005Oooool5ool00003oooooooo003oo`0000Coo`003_ooool3
ool001Cooooo1_oo000Iooooo`?oo`004Oooool=ool00003oooooooo003oo`0000Coo`001oooool8
ool000kooooo1@000?l4ooooo`Go003o4_ooool50000o`Kooooo1Ol00?l4ooooo`Go003o0Oooool1
0000007ooooo00000`00003oooooooooo`0?ooooo`Goo`005oooool=ool000?ooooo2?oo000:oooo
o`?oo`000oooool8ool000Sooooo1ooo000Cooooo`Goo`006Oooool5ool000oooooo5_oo0007oooo
o`Ooo`003oooool30000o`Kooooo0ol00?lCooooo`D0003o1_ooool5o`00o`Cooooo1Ol00?l1oooo
o`4000000Oooool0000300000?oooooooooo00Kooooo0ooo0007ooooo`?oo`006?ooool5ool000;o
oooo1_oo0002ooooo`[oo`004?ooool8ool000Kooooo2?oo000Cooooo`Goo`002oooool3ool000_o
oooo1Ooo000?oooooa[oo`001Oooool5ool002kooooo00Co003o0000o`000?l0003o1oooool5o`00
o`Cooooo1Ol00?l1ooooo`4000000Oooool0000400000?oo003oo`00ool000?ooooo1_oo0008oooo
o`?oo`005_ooool5ool000?ooooo1Ooo0002ooooo`[oo`004oooool5ool000Kooooo2?oo000Doooo
o`?oo`002oooool6ool000Wooooo1Ooo000?oooooa_oo`0000?oooooool00?oo00001_oo0009oooo
o`?oo`003oooool30000o`oooooo1_l00?l7ooooo`Go003o0`000?l01?oooooo003oo`00ool00?l2
ooooo`4000000Oooool000Goo`0000?oooooool00?oo00001Ooo0007ooooo`Goo`002_ooool3ool0
00Wooooo0ooo0005ooooo`?oo`000oooool:ool001?ooooo1_oo0005ooooo`Ooo`008oooool7ool0
00;ooooo0ooo0004ooooo`?oo`004Oooool6ool000?ooooo0ooo0002oooooaCoo`002Oooool5ool0
00gooooo1@000?l>ooooo`Wo003o1_ooool2o`00o`D0003o1Oooool10000007ooooo0005ool00003
oooooooo003oo`0000Goo`001oooool5ool000;ooooo0ooo0002ooooo`Ooo`003oooool5ool000?o
oooo2?oo000Dooooo`Ooo`001Oooool3ool002Kooooo1ooo00000oooooooo`00ool00003ool00004
oooooooo003oo`00ool000Cooooo1_oo0009ooooo`Koo`003?ooool@ool000Wooooo1Ooo000=oooo
o`D0003o3_ooool:o`00o`Gooooo0_l00?l60000o`Cooooo0@000001ooooo`001Ooo00000ooooooo
o`00ool00004ool000Sooooo1Ooo00000oooooooo`00ool0000;ool000oooooo1Ooo000Cooooo`?o
o`002?ooool8ool002oooooo1_oo00000oooooooo`00ool00008ool000;ooooo2?oo0007ooooo`So
o`003oooool3ool00003oooooooo003oo`0000Ooo`002?ooool5ool000_ooooo1`000?l?ooooo`Wo
003o1Oooool2o`00o`H0003o1?ooool10000007ooooo00000`00003oo`00ool0000:ool000Sooooo
0ooo0002ooooo`goo`003oooool5ool001;ooooo1Ooo0007ooooo`Woo`006Oooool3ool000Gooooo
0ooo000<ooooo`?oo`000_ooool:ool000;ooooo2?oo0007ooooo`Soo`005?ooool9ool000Sooooo
0ooo0003ooooo`<0003o1Oooool70000o`oooooo0ol00?l2ooooo`Go003o1_ooool2o`00o`D0003o
1?ooool10000007ooooo00000`00003oooooooooo`0;ool000cooooo3?oo000Aooooo`?oo`004ooo
ool5ool000Oooooo2Ooo000Hooooo`Koo`000_ooool5ool0017ooooo0ooo00000oooooooo`00ool0
0003ool000;ooooo2?oo0007ooooo`Soo`005oooool7ool000cooooo1@000?l01?oooooo003oo`00
ool00?l50000oa3ooooo1Ol00?l2ooooo`?o003o2Oooool01Ol00?l0003o0000o`000?oo003o00<0
003o0Oooool10000007ooooo00000`00003oooooooooo`0;ool000gooooo0ooo0002ooooo`?oo`00
:_ooool5ool000Sooooo2?oo000Hooooo`Ooo`0000?oooooool00?oo00000ooo000Fooooo`?oo`00
1?ooool6ool000Sooooo1ooo000Iooooo`Ooo`002_ooool00ol00?l0003o0000o`030000o`Co003o
1@000?l@ooooo`Go003o3oooool3o`00o`D0003o0@000001ooooo`0000<00000ooooooooool02ooo
000Nooooo`Koo`001oooool3ool001;ooooo0ooo0009ooooo`Soo`006?ooool=ool0023ooooo0ooo
0008ooooo`Goo`006?ooool3ool00003oooooooo003oo`0000Coo`002Oooool2o`00o`D0003o1Ol0
0?l30000oa7ooooo1Ol00?lBooooo`D0003o0@000001ooooo`0000@00000oooooooooooooooo1?oo
0002ooooo`?oo`000oooool3ool001Sooooo2?oo0005ooooo`Goo`007_ooool7ool001Wooooo1ooo
00001?ooooooo`00ool00?oo000;ooooo`?oo`004_ooool5ool000Sooooo0ooo000Hooooo`Goo`00
00?oooooool00?oo00000ooo0009ooooo`?o003o0`000?l8o`00oa?ooooo0ol00?l:ooooo`;o003o
0`000?l4ooooo`D0003o0@000001ooooo`0000<00000ooooooooool02oooool6ool001;ooooo0ooo
0002ooooo`Soo`001Oooool5ool0027ooooo0ooo000Looooo`Goo`003_ooool5ool0017ooooo1Ooo
000Jooooo`?oo`001_ooool5ool00003oooooooo003oo`0000?oo`000oooool3ool000?ooooo2ol0
0?l30000o`03o`00oooooooooooo00Gooooo0`000?l00ol00?ooooooooooo`0Aooooo`;o003o1@00
0?l3o`00o`06ooooo`000?l0003o0000ooooool000000Oooool0000300000?oooooooooo00[ooooo
1ooo000=ooooo`?oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00006ool000Gooooo
1ooo000Sooooo`?oo`006Oooool3ool000oooooo1Ooo000Aooooo`Goo`001Oooool3ool0017ooooo
1Ooo0005ooooo`Goo`0000?oooooool00?oo00000_oo0003ooooo`Goo`000_ooool9o`00o`03oooo
o`000?l0003o00<0003o1_ooool50000o`04o`00ooooooooooooooooo`?o003o3?ooool2o`00o`D0
003o1?l00?l4ooooo`4000000Oooool0000300000?oooooooooo00[ooooo1ooo000<ooooo`[oo`00
0_ooool9ool000Cooooo1ooo000?ooooo`?oo`000oooool3ool000Wooooo1Ooo000Gooooo`?oo`00
4?ooool5ool001;ooooo0ooo0005ooooo`Goo`002_ooool3ool000?ooooo1Ooo0006ooooo`?oo`00
00?oooooool00?oo00000ooo0003ooooo`Goo`000_ooool9o`00o`03ooooo`000?l0003o00<0003o
1_ooool50000o`03o`00oooooooooooo00Go003o2oooool2o`00o`D0003o1?l00?l4ooooo`400000
0Oooool0000300000?oooooooooo00[ooooo1_oo000=ooooo`[oo`001oooool5ool000?ooooo1ooo
000>ooooo`Goo`0000?oooooool00?oo00000ooo0008ooooo`Goo`000oooool3ool0013ooooo1Ooo
000@ooooo`?oo`006oooool5ool000Wooooo1Ooo0002ooooo`Goo`002_ooool5ool000?ooooo1Ooo
0002ooooo`So003o0_ooool50000o`;ooooo0ol00?l00oooool0003o0000o`030000o`03o`00oooo
oooooooo00Go003o3?ooool2o`00o`<0003o1Ol00?l4ooooo`4000000Oooool0000300000?oooooo
oooo00_ooooo0ooo0003ooooo`?oo`002Oooool5ool00004oooooooo003oo`00ool000Sooooo1Ooo
00000oooooooo`00ool00007ool000kooooo2ooo0008ooooo`Goo`000_ooool5ool000_ooooo0ooo
00000oooooooo`00ool00003ool002kooooo1Ooo0009ooooo`Goo`000oooool3ool000_ooooo1Ooo
0004ooooo`?oo`000_ooool2ool000?o003o1oooool30000o`;ooooo1Ol00?l01Oooool0003o0000
o`000?oo003o00?ooooo1Ol00?lBooooo`?o003o1Oooool10000007ooooo00000`00003ooooooooo
o`0;ooooo`?oo`000_ooool5ool000?ooooo0ooo0003ooooo`Goo`001?ooool3ool000Cooooo3_oo
0008ooooo`?oo`001?ooool;ool000Wooooo0ooo0003ooooo`Goo`002_ooool:ool000Sooooo0ooo
000Tooooo`?oo`002_ooool5ool001;ooooo0ooo0009ooooo`Goo`003?ooool6o`00o`Wooooo0ol0
0?lKooooo`4000000Oooool0000300000?oooooooooo00[ooooo1Ooo00000oooooooo`00ool00003
ool00003oooooooo003oo`0000Coo`000_ooool5ool000?ooooo1Ooo0004ooooo`Woo`002oooool5
ool000Cooooo2Ooo000;ooooo`?oo`000_ooool5ool000Kooooo0ooo00000oooooooo`00ool00003
ool00004oooooooo003oo`00ool000Sooooo1Ooo000Cooooo`?oo`006oooool3ool001Oooooo0ooo
0005ooooo`Goo`002oooool7o`00obOooooo0@000001ooooo`0000<00000ooooooooool02_ooool5
ool00003oooooooo003oo`0000[oo`000_ooool5ool000?ooooo1Ooo0005ooooo`Soo`002oooool5
ool000Gooooo1_oo000<ooooo`Goo`000_ooool3ool000Kooooo2_oo000<ooooo`Goo`001oooool3
ool000Sooooo1Ooo000cooooo`Goo`001?ooool5ool000Oooooo00Co003o0000o`000?l0003o1_l0
0?l9ooooo`?o003o7?ooool10000007ooooo00000`00003oooooooooo`0:ooooo`Koo`0000Gooooo
ool00?oo003oo`00ooooo`07ool000?ooooo0ooo0004ooooo`Goo`001?ooool8ool000Sooooo0ooo
00000oooooooo`00ool00003ool000Kooooo1?oo000=ooooo`Goo`002oooool5ool00004oooooooo
003oo`00ool000gooooo1Ooo0006ooooo`Soo`001?ooool5ool000cooooo0ooo000;ooooo`?oo`00
5_ooool5ool000Gooooo0ooo0007ooooo`03o`00o`000?l0003o00<0003o1?l00?l9ooooo`Go003o
6oooool10000007ooooo00000`00003oooooooooo`0;oooooa3oo`003?ooool3ool000Gooooo1_oo
0009ooooo`Goo`0000Coooooool00?oo003oo`006?ooool5ool000_ooooo1Ooo000Booooo`?oo`00
1oooool9ool000?ooooo1Ooo000;ooooo`Goo`002Oooool5ool000;ooooo0ooo000:ooooo`?oo`00
0oooool5ool000oooooo00?o003o0000o`000?l00`000?l3o`00o`Sooooo1ol00?lKooooo`400000
0Oooool0000300000?oooooooooo00cooooo2Ooo00001?ooooooo`00ool00?oo000Fooooo`Goo`00
2Oooool6ool001gooooo0ooo000=ooooo`Goo`002Oooool3ool000Gooooo0ooo0007ooooo`Woo`00
1?ooool3ool000cooooo1Ooo0009ooooo`Goo`0000?oooooool00?oo00000ooo0008ooooo`Goo`00
0oooool3ool000Wooooo0`000?l4ooooo`03o`00o`000?l0003o00<0003o0_l00?l8ooooo`So003o
1oooool30000o`Cooooo0`000?l:ooooo`4000000Oooool0000300000?oooooooooo00cooooo2Ooo
000Kooooo`?oo`002_ooool6ool002gooooo1Ooo0008ooooo`Goo`000oooool5ool000Oooooo2?oo
0003ooooo`Goo`002oooool5ool000Wooooo1Ooo00000oooooooo`00ool00003ool000Sooooo1Ooo
000>ooooo`D0003o1?ooool01?l00?l0003o0000o`000?l;ooooo`Co003o0`000?l7ooooo`D0003o
0_ooool50000o`Wooooo0@000001ooooo`0000<00000ooooooooool03?ooool4ool00004oooooooo
003oo`00ool002Oooooo1ooo000^ooooo`Goo`002?ooool6ool000;ooooo1Ooo000;ooooo`?oo`00
1?ooool5ool000_ooooo1Ooo000:ooooo`?oo`000_ooool5ool000Sooooo1Ooo000>ooooo`D0003o
4oooool3o`00o`D0003o1_ooool50000o`;o003o1@000?l9ooooo`4000000Oooool0000300000?oo
ooooo`0000;oo`002Oooool5ool000kooooo0ooo000:ooooo`?oo`003?ooool7ool002kooooo1Ooo
0009ooooo`Koo`000_ooool5ool000[ooooo0ooo0005ooooo`Goo`002oooool5ool000Kooooo0ooo
0007ooooo`Goo`002?ooool3ool000oooooo1@000?l<ooooo`?o003o1Oooool2o`00o`D0003o1_oo
ool60000o`03o`00o`000?l0003o00<0003o2Oooool10000007ooooo00000`00003oo`00ool00003
ool000Sooooo1Ooo000<ooooo`Koo`002?ooool5ool000_ooooo1Ooo000^ooooo`Ooo`002_ooool5
ool000?ooooo0ooo000:ooooo`Goo`001Oooool3ool000cooooo1Ooo0002ooooo`Soo`001_ooool5
ool001;ooooo0ooo0004ooooo`03ool00?l00?l0003o0080003o0ol00?l6ooooo`So003o1_ooool5
0000o`Oooooo1@000?l2o`00o`<0003o2_ooool10000007ooooo00000`00003oo`00ool00003ool0
00Sooooo1Ooo000;ooooo`Ooo`002?ooool5ool000_ooooo1Ooo000]ooooo`Soo`002_ooool7ool0
00kooooo1Ooo000<ooooo`?oo`001_ooool3ool000;ooooo2Ooo0006ooooo`Goo`004Oooool5ool0
00;ooooo00?oo`00o`00ool00?l01ol00?l4ooooo`Wo003o1oooool30000o`Sooooo1@000?l2o`00
o`04ooooool00?oo003oo`00o`Wooooo0@000001ooooo`0000<00000ool00?oo00001Ooo0007oooo
o`?oo`001oooool3ool000;ooooo1ooo0008ooooo`Goo`003?ooool3ool002kooooo1ooo0007oooo
o`?oo`0000?oooooool00?oo00001_oo000=ooooo`Goo`002oooool5ool000[ooooo2Ooo0007oooo
o`Ooo`003_ooool5ool000;ooooo00?oo`00o`00ool00?l01ol00?l4ooooo`Wo003o4oooool30000
o`;o003o00?oooooo`00ool00?l01?l00?l7ooooo`4000000Oooool0000300000?ooooooo`0000Ko
o`003oooool5ool00003oooooooo003oo`0000Coo`002_ooool3ool003_ooooo2?oo0008ooooo`Go
o`0000?oooooool00?oo00001ooo000<ooooo`?oo`002_ooool7ool000[ooooo2?oo0008ooooo`So
o`003Oooool5ool000;ooooo00?oo`00o`00ool00?l01ol00?l4ooooo`So003o6_ooool7o`00o`Ko
oooo0@000001ooooo`0000@00000oooooooooooooooo1Ooo000?ooooo`Goo`000_ooool4ool002Go
oooo0ooo000Pooooo`Soo`002Oooool5ool000?ooooo2?oo000Dooooo`coo`001oooool:ool000So
oooo2?oo000>ooooo`?oo`001?ooool01Ooo003o003oo`00ool00?oooooo00?o003o1_ooool3o`00
oakooooo1ol00?l6ooooo`4000000Oooool0000400000?ooooooooooooooo`Goo`002Oooool3ool0
00?ooooo1Ooo000Jooooo`?oo`002oooool7ool001oooooo1Ooo000<ooooo`Goo`001?ooool8ool0
01;ooooo3_oo0005ooooo`_oo`002Oooool7ool002Wooooo0ol00?l=ooooo`<0003o2Oooool6o`00
o`Kooooo0@000001ooooo`0000<00000ooooooooool00_ooool3ool000Wooooo1Ooo0003ooooo`?o
o`003_ooool3ool000Wooooo1Ooo0009ooooo`Soo`007oooool5ool000gooooo0ooo0007ooooo`Ko
o`004_ooool>ool000Gooooo2_oo000<ooooo`Coo`00:Oooool5o`00o`_ooooo1@000?l:ooooo`?o
003o00Coooooo`00ool00?oo003o0oooool10000007ooooo00000`00003oooooooooo`0>ooooo`Go
o`0000Coooooool00?oo003oo`003oooool5ool000Sooooo1Ooo0009ooooo`Soo`008?ooool3ool0
01Oooooo1ooo000Aooooo`ooo`001Oooool8ool000gooooo1ooo000Wooooo`Go003o2oooool50000
o`cooooo0`000?l3o`00o`;ooooo0@000001ooooo`0000<00000ooooooooool02_ooool3ool00003
oooooooo003oo`0000Soo`003_ooool5ool000Sooooo1ooo0007ooooo`Ooo`002_ooool3ool0023o
oooo0ooo000:ooooo`Ooo`004_ooool5ool000;ooooo0ooo00001?ooooooo`00ool00?oo0007oooo
o`Ooo`003?ooool9ool000[ooooo0ooo000Iooooo`Go003o2oooool50000o`_ooooo1@000?l2o`00
o`;ooooo0@000001ooooo`0000<00000ooooooooool02Oooool9ool00003oooooooo003oo`0000?o
o`003_ooool5ool000Wooooo1ooo0007ooooo`?oo`003?ooool5ool001Sooooo0ooo0003ooooo`Go
o`002Oooool5ool000?ooooo0ooo00001?ooooooo`00ool00?oo000:ooooo`Goo`001_ooool3ool0
00[ooooo0ooo000=ooooo`Woo`002Oooool5ool001Oooooo1Ol00?l=ooooo`<0003o3?ooool50000
o`;o003o0_ooool10000007ooooo00000`00003oooooooooo`09ooooo`Soo`000_ooool5ool000oo
oooo0ooo000<ooooo`Goo`002oooool5ool000Kooooo1Ooo000Gooooo`Goo`000_ooool5ool000Wo
oooo1Ooo0002ooooo`Woo`002Oooool5ool000Gooooo1Ooo000Iooooo`Woo`002Oooool5ool001Oo
oooo1ol00?lJooooo`D0003o00Go003ooooooooooooooooo00000001ooooo`0000<00000oooooooo
ool02Oooool8ool000?ooooo0ooo000Oooooo`Goo`002_ooool7ool000Gooooo1Ooo000Fooooo`Ko
o`000_ooool5ool000[ooooo0ooo0003ooooo`Woo`001_ooool3ool00004oooooooo003oo`00ool0
00Kooooo1Ooo00001?ooooooo`00ool00?oo000Fooooo`?oo`0000Coooooool00?oo003oo`002Ooo
ool7ool001Kooooo2?l00?l;ooooo`?o003o3?ooool30000o`Gooooo0@000001ooooo`0000<00000
ooooooooool02_ooool7ool000oooooo0ooo000Dooooo`?oo`002oooool7ool000Kooooo0ooo0009
ooooo`?oo`002_ooool7ool000?ooooo1Ooo000?ooooo`Woo`001Oooool5ool000;ooooo0ooo0004
ooooo`[oo`009?ooool9ool000_ooooo0ol00?l01?oooooo003oo`00ool00?l4ooooo`Oo003o2_oo
ool3o`00o`<0003o1_ooool30000o`Wooooo0@000001ooooo`0000<00000ooooooooool03Oooool3
ool000oooooo1Ooo0008ooooo`Goo`005?ooool7ool0017ooooo1Ooo0009ooooo`Koo`001?ooool5
ool000oooooo2?oo0006ooooo`Goo`0000?oooooool00?oo00000ooo0004ooooo`?oo`0000?ooooo
ool00?oo00000ooo000Tooooo`Woo`002_ooool9o`00o`Gooooo1Ol00?l:ooooo`;o003o1@000?l4
ooooo`D0003o2?ooool10000007ooooo00000`00003oooooooooo`0Oooooo`Goo`001oooool7ool0
01Cooooo1Ooo000@ooooo`Ooo`002Oooool5ool000Gooooo1Ooo000?ooooo`Goo`002Oooool5ool0
0003oooooooo003oo`0000Coo`001oooool5ool002Cooooo2Ooo00001?ooooooo`00ool00?oo0006
ooooo`Wo003o1_ooool3o`00o`_ooooo0_l00?l50000o`Cooooo1@000?l8ooooo`4000000Oooool0
000300000?oooooooooo00[ooooo0ooo000Booooo`Goo`001oooool7ool000oooooo0ooo000Foooo
o`Soo`002_ooool3ool000Oooooo0ooo000?ooooo`Goo`002oooool3ool000;ooooo1_oo0008oooo
o`?oo`003_ooool3ool000kooooo0ooo0004ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`05
ool000Gooooo2Ol00?l5ooooo`Go003o0`000?l8ooooo`03o`00o`000?l0003o00<0003o1?ooool5
0000o`?o003o1Oooool10000007ooooo00000`00003oooooooooo`09ooooo`Goo`004?ooool5ool0
00Sooooo1ooo000>ooooo`Goo`005Oooool7ool00004oooooooo003oo`00ool002?ooooo1Ooo000A
ooooo`Goo`000_ooool3ool001?ooooo1Ooo000<ooooo`Goo`002Oooool7ool000Kooooo0ol00?l0
1?oooooo003oo`00ool00?l6ooooo`Co003o1@000?l9ooooo`<0003o1_ooool30000o`Go003o1?oo
ool10000007ooooo00000`00003oooooooooo`09ooooo`Goo`004?ooool5ool000Wooooo1ooo000=
ooooo`Goo`005Oooool<ool002;ooooo1Ooo0006ooooo`?oo`001oooool6ool00003oooooooo003o
o`0000?oo`004_ooool5ool000cooooo1Ooo0005ooooo`_oo`004oooool4o`00o`D0003o5Oooool5
o`00o`Cooooo0@000001ooooo`0000<00000ooooooooool02Oooool5ool0013ooooo1Ooo000<oooo
o`Goo`003?ooool5ool001Cooooo3Ooo000;ooooo`?oo`003oooool3ool000;ooooo1Ooo0005oooo
o`Goo`001_ooool6ool00003oooooooo003oo`0000Coo`004Oooool5ool000cooooo1_oo0003oooo
o`_oo`005Oooool3o`00o`D0003o3?ooool30000o`Kooooo1Ol00?l4ooooo`4000000Oooool00003
00000?oooooooooo00[ooooo0ooo000Booooo`?oo`003Oooool5ool000gooooo0ooo000Boooooa3o
o`002_ooool5ool000gooooo2_oo0006ooooo`Goo`001_ooool5ool000;ooooo1ooo000Aooooo`?o
o`003?ooool8ool000;ooooo2Ooo0008ooooo`<0003o3Oooool3o`00o`<0003o0_l00?l:ooooo`D0
003o1_ooool4o`00o`Cooooo0@000001ooooo`0000<00000ooooooooool07_ooool3ool000kooooo
1Ooo000@ooooo`?oo`003_ooool;ool000;ooooo0ooo000;ooooo`Koo`003?ooool:ool000Kooooo
1Ooo0007ooooo`?oo`000oooool7ool0023ooooo4_oo0008ooooo`D0003o3?ooool:o`00o`Sooooo
1@000?l6ooooo`Go003o0oooool10000007ooooo00000`00003oooooooooo`0Mooooo`Goo`001ooo
ool3ool000Cooooo0ooo000@ooooo`Goo`003Oooool8ool001?ooooo1_oo000<ooooo`[oo`001ooo
ool3ool000kooooo1ooo000@ooooo`?oo`003Oooool>ool000cooooo1@000?l=ooooo`[o003o1_oo
ool00ol00?l0003o0000o`030000o`Kooooo1Ol00?l3ooooo`4000000Oooool0000300000?oooooo
oooo00gooooo0ooo000=ooooo`Goo`001_ooool5ool001Kooooo1Ooo000=ooooo`Goo`003?ooool3
ool000?ooooo0ooo0002ooooo`Goo`000oooool3ool000Oooooo0ooo0002ooooo`Coo`006?ooool6
ool000?ooooo0ooo000:ooooo`Goo`003Oooool;ool000gooooo00?o003o0000o`000?l00`000?l@
ooooo`Oo003o1Oooool3o`00o`<0003o0_l00?l5ooooo`Go003o0oooool10000007ooooo00000`00
003oooooool00002ool000[ooooo1Ooo000<ooooo`Goo`001_ooool5ool001Kooooo1Ooo0002oooo
o`?oo`002Oooool3ool000cooooo1Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`00
00[oo`002oooool5ool001Sooooo0ooo0004ooooo`Goo`002Oooool5ool000Wooooo0ooo0004oooo
o`Soo`003Oooool2o`00o`<0003o4oooool5o`00o`Gooooo2?l00?l6ooooo`?o003o1?ooool10000
007ooooo00000`00003oo`00ool00003ool000Wooooo1Ooo000;ooooo`Goo`001_ooool6ool000oo
oooo0ooo0005ooooo`?oo`000_ooool5ool001Oooooo1Ooo00000oooooooo`00ool0000@ool000_o
oooo1Ooo000Oooooo`Goo`001?ooool3ool000;ooooo1Ooo0003ooooo`?oo`000_ooool5ool000?o
oooo1ooo000>ooooo`Go003o5?ooool3o`00o`Kooooo2?l00?l=ooooo`4000000Oooool000030000
0?oo003oo`0000?oo`001_ooool8ool000_ooooo1Ooo0006ooooo`Goo`003oooool6ool000Sooooo
1ooo000EoooooaSoo`000oooool3ool000Gooooo1Ooo000Oooooo`Goo`000oooool5ool000;ooooo
0ooo0003ooooo`Goo`0000?oooooool00?oo00000ooo0003ooooo`Goo`004Oooool3o`00oaoooooo
1_l00?l>ooooo`4000000Oooool0000300000?oo003oo`0000?oo`001Oooool9ool000_ooooo2?oo
0003ooooo`Goo`003oooool7ool000Cooooo2ooo000Eooooo`?oo`0000?oooooool00?oo00000ooo
00000oooooooo`00ool0000:ool000?ooooo1Ooo0005ooooo`?oo`006?ooool3ool000Kooooo0ooo
0004ooooo`Goo`002?ooool;ool000Cooooo1?oo000Hooooo`?o003o6Oooool5o`00o`kooooo0@00
0001ooooo`0000<00000oooooooo00000_oo0006ooooo`Woo`003?ooool8ool000?ooooo0ooo000@
ooooo`Ooo`000oooool<ool000Sooooo0ol00?l>ooooo`Goo`000_ooool3ool00003oooooooo003o
o`0000?oo`001Oooool5ool001oooooo1Ooo000<ooooo`Goo`002?ooool:ool000Gooooo1Ooo000F
ooooo`Go003o5oooool6o`00o`kooooo0@000001ooooo`0000<00000ooooooooool02?ooool9ool0
00gooooo1ooo000Cooooo`?o003o00?oooooool00?oo00001?oo0003ooooo`Goo`000_ooool5ool0
00Oooooo1Ol00?l>ooooo`?oo`001oooool5ool000Gooooo1Ooo0003o`00o`Kooooo0ol00?lCoooo
o`Goo`003Oooool3ool000[ooooo2Ooo0003ooooo`?o003o0ooo00030000o`Oooooo0ol00?l:oooo
o`Go003o5_ooool7o`00o`kooooo0@000001ooooo`0000@00000oooooooooooooooo0ooo0005oooo
o`?oo`0000Coooooool00?oo003oo`003_ooool7ool000Sooooo0ooo0004ooooo`?oo`001Ol00?l2
ooooo`?oo`001?ooool5ool000?ooooo0ooo0008ooooo`Go003o2Oooool3o`00o`cooooo1Ooo0006
ooooo`?oo`000`000?l2o`00o`Cooooo1Ol00?l3ooooo`?o003o3?ooool5ool001cooooo1ooo0002
ooooo`Go003o00?oo`000000o`000?l00`000?l5ooooo`05o`00o`000?l0003o0000ool00?l02Ooo
ool5o`00oaKooooo1_l00?l?ooooo`4000000Oooool0000300000?oooooooooo00Goo`006_ooool6
ool000Oooooo1Ooo0002ooooo`Coo`001Ol00?l:ooooo`?oo`003oooool5o`00o`Sooooo1Ol00?l<
ooooo`?oo`0000Coooooo`00ool00?oo003o1Oooool50000o`04o`00ooooooooooooooooo`Ko003o
0_ooool5o`00o`Kooooo0`000?l3ooooo`?oo`001_ooool3o`00o`oooooo0`000?l3ooooo`Goo`00
0oooool5o`00o`03ool000000?l0003o00<0003o1Oooool50000o`[ooooo0ol00?l2ooooo`?o003o
4_ooool5o`00oa3ooooo0@000001ooooo`0000<00000oooooooo00001Ooo000Looooo`Goo`001_oo
ool5ool000;ooooo1?oo0005o`00oagooooo0ol00?l9ooooo`Go003o3oooool5o`00o`Cooooo1@00
0?l00ol00?ooooooooooo`07o`00o`;ooooo1Ol00?l5ooooo`D0003o2_ooool5o`00o`gooooo1@00
0?l:ooooo`Go003o00?ooooo0000o`000?l00`000?l4ooooo`03o`00o`000?l0003o00<0003o3_oo
ool5o`00o`05ooooool00?oo003oo`00ooooool00`000?l:ooooo`?o003o1?ooool3o`00o`[ooooo
0@000001ooooo`0000<00000ool00?oo00001Ooo000=ooooo`?oo`003?ooool5ool000Kooooo1Ooo
0002ooooo`Coo`001Ol00?l3ooooo`?o003o1oooool30000oaWooooo1Ol00?l?ooooo`Go003o1?oo
ool50000o`?ooooo1_l00?l3ooooo`Go003o1Oooool50000o`03o`00oooooooooooo00Oooooo1Ol0
0?l=ooooo`D0003o2oooool3o`00o`?ooooo0`000?l5ooooo`03o`00o`000?l0003o00<0003o3_oo
ool9o`00o`D0003o3Oooool30000o`Co003o2Oooool10000007ooooo00000`00003oo`00ool00004
ool000gooooo2?oo0008ooooo`Goo`001oooool3ool000Cooooo0ooo0005o`00o`;ooooo1Ol00?l5
ooooo`D0003o0_ooool30000oaCooooo0ol00?l4ooooo`<0003o2Oooool5o`00o`Gooooo1@000?l2
ooooo`Go003o1Oooool3o`00o`Kooooo1@000?l00ol00?ooooooooooo`07ooooo`Go003o0_ooool3
o`00o`Sooooo1@000?lBooooo`?o003o1?ooool2o`00o`<0003o3oooool9o`00o`D0003o3?ooool5
0000o`?o003o2Oooool10000007ooooo00000`00003oo`00ool00003ool000kooooo2Ooo0003oooo
o`?oo`000_ooool5ool0017ooooo0ol00?l3ooooo`Go003o1?ooool60000o`03ooooo`000?l0003o
00<0003o4_ooool5o`00o`;ooooo1@000?l9ooooo`?o003o1_ooool50000o`?ooooo0ol00?l01?oo
oooo003oo`00ool00?l3ooooo`?o003o1?ooool2o`00o`<0003o0_l00?l:ooooo`?o003o0_ooool5
o`00o`Sooooo0`000?lBooooo`Go003o1?ooool50000o`gooooo1Ol00?l00ooooooo003oo`00o`02
o`00o`D0003o0oooool3o`00o`Kooooo1`000?l00ol00?ooooooooooo`07ooooo`4000000Oooool0
000300000?ooooooo`0000;oo`003oooool9ool000;ooooo1Ooo0002ooooo`Koo`004?ooool3o`00
o`;ooooo1Ol00?l4ooooo`H0003o00?ooooo0000o`000?l00`000?lBooooo`Go003o00?oooooo`00
o`000?l010000?l5ooooo`<0003o2_ooool50000o`;ooooo0`000?l00ooooooo003oo`00o`09o`00
o`;ooooo0`000?l4o`00oa3ooooo1Ol00?l7ooooo`?o003o2?ooool3o`00o`Sooooo1Ol00?l4oooo
o`D0003o00Coooooo`00ool00?oo003o2?ooool5o`00o`?ooooo1?l00?l30000o`?ooooo1Ol00?l5
ooooo`P0003o2Oooool10000007ooooo00000`00003oooooooooo`0Aooooo`Woo`000_ooool5ool0
00;ooooo1ooo000>ooooo`Go003o0_ooool3o`00o`Gooooo1@000?l2ooooo`D0003o4_ooool7o`00
o`D0003o1?ooool50000o`[ooooo0`000?l2ooooo`D0003o3?l00?l50000o`;o003o2_ooool3o`00
o`Cooooo1Ol00?l6ooooo`Go003o1_ooool5o`00o`Oooooo1Ol00?l4ooooo`D0003o1Ol00?l7oooo
o`Go003o0oooool5o`00o`Gooooo1Ol00?l6ooooo`L0003o2Oooool10000007ooooo00000`00003o
ooooooooo`09ooooo`?oo`001Oooool8ool000?ooooo1Ooo0002ooooo`Ooo`002?ooool3ool000?o
oooo1Ol00?l2ooooo`?o003o1?ooool2o`00o`<0003o1?ooool30000oa?ooooo1?l00?l01?oooooo
003oo`00ool00?l30000o`Gooooo1@000?l?ooooo`D0003o3?l00?l50000o`03o`00oooooooooooo
00Sooooo1Ol00?l4ooooo`Go003o1Oooool5o`00o`Kooooo1Ol00?l8ooooo`?o003o1_ooool30000
o`03ooooool00?oo003o00?o003o1_ooool6o`00o`?ooooo1_l00?l4ooooo`Go003o2?ooool50000
o`Wooooo0@000001ooooo`0000<00000ooooooooool02?ooool5ool000Cooooo1Ooo0002ooooo`?o
o`000_ooool3ool000Cooooo1_oo0007ooooo`Goo`0000?oooooo`00ool00?l01?l00?l00ooooooo
003oo`00o`03o`00o`;ooooo0ol00?l30000o`Oooooo0ol00?l?ooooo`Go003o00?oooooo`00ool0
0?l00ol00?l6ooooo`D0003o3oooool70000o`[o003o1@000?l00ol00?ooooooooooo`08ooooo`Go
003o1?ooool5o`00o`Gooooo1Ol00?l6ooooo`Go003o2_ooool3o`00o`Sooooo1Ol00?l5ooooo`Ko
003o1?ooool7o`00o`Cooooo0ol00?l:ooooo`<0003o2_ooool10000007ooooo00000`00003ooooo
ooooo`08ooooo`Goo`001Oooool4ool00003oooooooo003oo`0000?oo`002_ooool3ool000Sooooo
1Ooo0006o`00o`;ooooo1Ol00?l2ooooo`;o003o1@000?l2o`00o`?ooooo1Ol00?l>ooooo`[o003o
2?ooool30000o`Oooooo0ol00?l7ooooo`L0003o1?l00?l3ooooo`?o003o0`000?l00ol00?oooooo
ooooo`09ooooo`Go003o0_ooool30000o`Co003o1_ooool3o`00o`Sooooo0ol00?l8ooooo`<0003o
1?l00?l8ooooo`?o003o1_ooool6o`00o`Gooooo1_l00?l@ooooo`D0003o2Oooool10000007ooooo
00000`00003oooooooooo`08ooooo`Goo`001Oooool:ool000Kooooo0ooo000<ooooo`Goo`001Ol0
0?l3ooooo`Go003o0_ooool2o`00o`D0003o0ol00?l2ooooo`Go003o3_ooool9o`00oa;ooooo1Ol0
0?l8ooooo`D0003o00?o003oooooooooool01Oooool3o`00o`Cooooo0ol00?l8ooooo`?o003o0_oo
ool50000o`;o003o4Oooool3o`00o`Sooooo1@000?l3o`00oa7ooooo1_l00?l2ooooo`?o003o00?o
ooooo`00ool00?l00ol00?l@ooooo`D0003o00Coooooo`00ool00?oo003o1Oooool10000007ooooo
00000`00003oooooooooo`04ooooo`?oo`0000?oooooool00?oo00000ooo0005ooooo`[oo`001Ooo
ool5ool000cooooo0ooo00000ooooooo003oo`00o`03o`00o`Cooooo0ol00?l4ooooo`03o`00o`00
0?l0003o00<0003o0ol00?l2ooooo`Go003o3oooool8o`00oa;ooooo1Ol00?l8ooooo`D0003o3?oo
ool7o`00o`cooooo1@000?l2o`00oa3ooooo1Ol00?l7ooooo`D0003o0ol00?lBooooo`Go003o00?o
ooooo`00ool00?l00ol00?l01?oooooo003oo`00ool00?l30000o`kooooo1@000?l5o`00o`Cooooo
0@000001ooooo`0000<00000ooooooooool00oooool5ool00004oooooooo003oo`00ool000Kooooo
1Ooo00001?ooooooo`00ool00?oo0006ooooo`Goo`003?ooool3ool000;ooooo0ol00?l6ooooo`?o
003o1Oooool30000o`Co003o0oooool3o`00o`oooooo0`000?l00ooooooo003oo`00o`05o`00o`Oo
oooo1?l00?l4ooooo`04o`00o`000?l0003o0000o`?o003o1oooool01Ol00?l0003o0000o`000?oo
003o00_ooooo2?l00?l<ooooo`D0003o0_l00?l>ooooo`Oo003o1oooool50000o`Go003o4?ooool5
o`00o`03ooooool00?oo003o00?o003o0_ooool00ol00?l0003o0000o`030000o`Kooooo0ol00?l5
ooooo`<0003o00?oooooo`00ool00?l00ol00?l4ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo1Ooo000;ooooo`?oo`001?ooool3ool00003oooooooo003oo`0000Ooo`002_ooool5ool0
00Wooooo1Ol00?l4ooooo`Oo003o5?ooool50000o`03ooooool00?oo003o00Go003o1Oooool9o`00
o`D0003o0ol00?l5ooooo`Oo003o2?ooool:o`00o`gooooo0`000?l3o`00o`_ooooo2_l00?l3oooo
o`?o003o1P000?l00ooooooo003oo`00o`03o`00o`_ooooo0ol00?l2ooooo`?o003o0_ooool5o`00
o`03ooooool00?oo003o00D0003o1Oooool5o`00o`04ooooo`000?l0003o0000o`Cooooo1?l00?l3
0000o`;ooooo0@000001ooooo`0000<00000ooooooooool00oooool5ool0017ooooo3ooo0009oooo
o`Goo`002Oooool5o`00o`03ooooool00?oo003o00Co003o0`000?l=ooooo`?o003o1Oooool50000
o`?ooooo1Ol00?l5ooooo`Wo003o1@000?l3o`00o`Gooooo2Ol00?l2ooooo`go003o3_ooool5o`00
o`_ooooo2_l00?l3ooooo`Co003o1`000?l7o`00o`?ooooo2_l00?l7ooooo`05o`00o`000?l0003o
0000ooooool00_l00?l50000o`03o`00oooooooooooo00;ooooo1Ol00?l50000o`Cooooo0_l00?l5
0000o`7ooooo0@000001ooooo`0000<00000ooooooooool01?ooool3ool00004oooooooo003oo`00
ool000kooooo3ooo0009ooooo`Goo`002Oooool;o`00o`D0003o2oooool5o`00o`Cooooo1@000?l3
ooooo`Go003o1Oooool9o`00o`D0003o0ol00?l5oooooaGo003o4?ooool30000o`;o003o3?ooool8
o`00o`Gooooo1?l00?l70000o`So003o00?oooooo`00ool00?l02Ol00?l7ooooo`D0003o0ol00?l3
0000o`;o003o1?ooool4o`00o`H0003o1_ooool50000o`7ooooo0@000001ooooo`0000<00000oooo
ooooool01oooool5ool000gooooo3ooo000:ooooo`?oo`002oooool3o`00o`03ooooool00?oo003o
00Co003o1@000?l01?oooooo003oo`00ool00?l7ooooo`Go003o1Oooool30000o`Gooooo0ol00?l7
ooooo`Wo003o0`000?l3o`00o`Oooooo4_l00?lAooooo`D0003o00?o003oooooooooool01?ooool3
o`00o`?ooooo1ol00?l6ooooo`Go003o1P000?l00ooooooo003oo`00o`05o`00o`03ooooool00?oo
003o00Wo003o00Coooooo`00ool00?oo003o0oooool50000o`03ooooool00?oo003o00Go003o1Ooo
ool3o`00o`H0003o1_ooool50000o`7ooooo0@000001ooooo`0000<00000ooooooooool01oooool5
ool000kooooo0ooo00000oooooooo`00ool00007ool001Cooooo0ol00?l6ooooo`Go003o00?ooooo
0000o`000?l00`000?l5o`00o`Kooooo1Ol00?l<ooooo`Go003o2oooool3o`00o`?ooooo0ol00?l;
ooooo`ko003o3Oooool30000o`;ooooo1@000?l00ol00?ooooooooooo`03ooooo`Ko003o0_ooool3
o`00o`Wooooo1ol00?l30000o`Cooooo1Ol00?l00ooooooo003oo`00o`08o`00o`03ooooool00?oo
003o00?o003o0_ooool50000o`?ooooo1Ol00?l8ooooo`D0003o2?ooool30000o`;ooooo0@000001
ooooo`0000<00000ooooooooool01oooool7ool0013ooooo2?oo000Dooooo`Go003o1_ooool3o`00
o`?ooooo0`000?l6o`00o`04ooooo`000?l0003o0000o`?ooooo0ol00?l8ooooo`?o003o00?ooooo
o`00ool00?l01?l00?l9ooooo`?o003o1?ooool3o`00o`<0003o2?ooool30000o`?o003o0_ooool3
o`00o`04ooooool00?oo003oo`00o`?ooooo1Ol00?l4ooooo`D0003o00?ooooo0000o`000?l00`00
0?l3ooooo`[o003o2Oooool3o`00o`03ooooool00?l0003o0080003o1Ol00?l6ooooo`?o003o0ooo
ool6o`00o`;ooooo1ol00?l3ooooo`<0003o1?ooool01Ol00?l0003o0000o`000?oo003o00Wooooo
0`000?l8ooooo`<0003o0oooool10000007ooooo00000`00003oooooooooo`08ooooo`Ooo`004?oo
ool3ool001Sooooo1Ol00?l<ooooo`Wo003o1@000?l<ooooo`co003o1oooool5o`00o`?ooooo0_l0
0?l50000o`Kooooo1@000?l7ooooo`Go003o00?oooooo`00ool00?l01Ol00?l3ooooo`D0003o0_l0
0?l30000o`?ooooo1?l00?l30000o`Co003o2?ooool5o`00o`D0003o0ol00?lDooooo`So003o2_oo
ool50000oa?ooooo1@000?l2ooooo`4000000Oooool0000300000?oooooooooo00Sooooo1ooo000[
ooooo`Go003o1_ooool3o`00o`?ooooo2?l00?l00oooool0003o0000o`030000o`cooooo3?l00?l7
ooooo`Go003o0oooool2o`00o`D0003o1_ooool50000o`Oooooo0_l00?l30000o`03ooooool00?oo
003o00Go003o0oooool50000o`Co003o1?ooool3o`00o`D0003o0ol00?l8ooooo`Go003o1@000?lG
ooooo`[o003o2?ooool50000o`[ooooo0`000?l6ooooo`D0003o0_ooool10000007ooooo00000`00
003oooooooooo`08ooooo`Ooo`002_ooool3ool001oooooo0ol00?l6ooooo`Go003o0_ooool9o`00
o`D0003o00?o003oooooooooool02Oooool5o`00o`03ooooool00?oo003o00Co003o1oooool5o`00
o`03ooooool00?oo003o00;o003o1@000?l6ooooo`D0003o1oooool00ol00?l0003o0000o`030000
o`Oo003o1?ooool30000o`Go003o1?ooool3o`00o`D0003o0_l00?l9ooooo`Go003o1@000?lGoooo
o`Go003o00?oooooo`00ool00?l00ol00?l7ooooo`D0003o2Oooool50000o`Cooooo1P000?l2oooo
o`4000000Oooool0000400000?ooooooooooooooo`?oo`001?ooool6ool000[ooooo1Ooo000>oooo
o`?oo`005_ooool5o`00o`?ooooo2Ol00?l30000o`;o003o2oooool4o`00o`Cooooo0ol00?l9oooo
o`?o003o00?oooooo`00ool00?l01?l00?l30000o`Sooooo10000?l8ooooo`D0003o00?oooooo`00
ool00?l00ol00?l8ooooo`Ko003o1?ooool2o`00o`D0003o3?ooool5o`00o`<0003o6Oooool3o`00
o`;ooooo1Ol00?l8ooooo`<0003o2_ooool50000o`Cooooo1@000?l01?l00?ooooooooooo`000001
ooooo`0000<00000ooooooooool01Ooo0004ooooo`?oo`000oooool3ool000Kooooo1Ooo0003oooo
o`?oo`001oooool5ool001Gooooo1Ol00?l4ooooo`go003o2_ooool5o`00oaCooooo2?l00?l7oooo
o`L0003o0_ooool3o`00o`;ooooo1@000?l?ooooo`Ko003o1_ooool50000o`[ooooo0ol00?l01?oo
oooo003oo`00ool00?lPooooo`Go003o5Oooool50000o`Cooooo1@000?l01?l00?ooooooooooo`00
0001ooooo`0000<00000ooooooooool01Ooo0009ooooo`Ooo`000oooool5ool000;ooooo1Ooo0006
ooooo`Goo`005_ooool3o`00o`Kooooo1ol00?l01?oooooo003oo`00ool00?l:ooooo`Ko003o5?oo
ool5o`00o`Wooooo20000?l00ooooooo003oo`00o`03o`00o`;ooooo0`000?lAooooo`Go003o1_oo
ool50000o`?ooooo0ol00?l3ooooo`Oo003o6_ooool30000o`Gooooo0ol00?lGooooo`<0003o1_oo
ool30000o`05o`00ooooooooooooooooo`0000000Oooool0000300000?oooooooooo00Goo`002Ooo
ool8ool000?ooooo0ooo0003ooooo`Koo`001Oooool5ool002;ooooo0ol00?l?ooooo`Ko003o5Ooo
ool6o`00o`Oooooo20000?l00ooooooo003oo`00o`04o`00oaGooooo1Ol00?l6ooooo`D0003o0_oo
ool5o`00o`;ooooo2?l00?lHooooo`D0003o0_ooool3o`00o`04ooooool00?oo003oo`00o`Wooooo
0ol00?lIooooo`4000000Oooool0000400000?ooooooooooooooo`?oo`002_ooool8ool000;ooooo
0ooo0004ooooo`Koo`001_ooool3ool002?ooooo0ol00?l5ooooo`<0003o1Ol00?l2ooooo`Go003o
6?ooool5o`00o`Kooooo1`000?l2ooooo`Oo003o2Oooool4o`00o`Kooooo1Ol00?l8ooooo`<0003o
0oooool5o`00o`;ooooo2?l00?lHooooo`H0003o2Ol00?l7ooooo`Go003o6?ooool10000007ooooo
00000`00003oooooooooo`0?ooooo`Ooo`0000?oooooool00?oo00000ooo0002ooooo`Ooo`005?oo
ool6o`00oa7ooooo1Ol00?l3ooooo`D0003o1Ol00?l2ooooo`?o003o5Oooool3o`00o`03ooooool0
0?oo003o00?o003o1oooool30000o`Kooooo1_l00?l2ooooo`<0003o0oooool6o`00o`Cooooo1Ol0
0?l?ooooo`Go003o0oooool7o`00oaSooooo1`000?l8o`00o`Oooooo1Ol00?l>ooooo`?o003o1ooo
ool10000007ooooo00000`00003oooooooooo`0Booooo`?oo`000_ooool5ool00003oooooooo003o
o`0000Goo`004_ooool2ool000So003o1oooool3o`00o`Kooooo1Ol00?l3ooooo`D0003o1Ol00?lI
ooooo`[o003o2oooool30000o`;ooooo1ol00?l50000o`;ooooo1_l00?l3ooooo`Ko003o4?ooool4
o`00o`Kooooo0ol00?l8ooooo`@0003o0ol00?l;ooooo`H0003o2?l00?l7ooooo`;o003o0`000?l=
ooooo`Go003o1_ooool10000007ooooo00000`00003oooooooooo`0Aooooo`?oo`000oooool5ool0
0003oooooooo003oo`0000Goo`004Oooool3ool000So003o00Coooooo`00ool00?oo003o0_ooool5
o`00o`Gooooo1Ol00?l3ooooo`D0003o1Ol00?lIooooo`Go003o00?oooooo`00ool00?l00`000?l6
ooooo`P0003o00?oooooo`00ool00?l01Ol00?l50000o`;ooooo1_l00?l3ooooo`Ko003o4?ooool5
o`00o`oooooo1P000?l3o`00o`_ooooo1@000?l3o`00o`04ooooool00?oo003oo`00o`Wooooo1@00
0?l<ooooo`Go003o1_ooool10000007ooooo00000`00003oooooooooo`02ooooo`?oo`002oooool5
ool000?ooooo0ooo00000oooooooo`00ool00006ool000gooooo0ooo00001?ooooooo`00ool00?oo
000=o`00o`03ooooool00?oo003o00?o003o1_ooool3o`00o`Gooooo0`000?l5o`00o`Cooooo0ol0
0?lCooooo`Oo003o1@000?l4ooooo`T0003o0_ooool3o`00o`03ooooo`000?l0003o00D0003o0ooo
ool4o`00o`Cooooo1Ol00?l<ooooo`?o003o0_ooool5o`00o`cooooo0ol00?l60000o`Co003o2ooo
ool30000oa7ooooo1@000?l3ooooo`<0003o00Coooooo`00ool00?oo003o0_ooool5o`00o`Kooooo
0@000001ooooo`0000@00000oooooooooooooooo1Ooo000:ooooo`Goo`001oooool8ool000cooooo
2Ooo0006o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l01_l00?l00oooool0003o
0000o`040000o`?ooooo0`000?l9ooooo`Go003o4oooool6o`00o`D0003o1?ooool90000o`Gooooo
1`000?l4ooooo`?o003o1_ooool3o`00o`cooooo1Ol00?l00ooooooo003oo`00o`03o`00o`_ooooo
1?l00?l60000o`Co003o1?ooool3o`00oaSooooo1@000?l2ooooo`D0003o0_l00?l30000o`04oooo
ool00?oo003oo`00o`Oooooo0@000001ooooo`0000@00000oooooooooooooooo1Ooo0007ooooo`So
o`001oooool7ool000gooooo1Ooo00001Oooooooo`00ool00?oo003ooooo00Go003o00?oooooo`00
ool00?l01?l00?l00ooooooo003oo`00o`05o`00o`P0003o00?ooooo0000o`000?l00`000?l8oooo
o`Go003o5_ooool3o`00o`D0003o1?ooool80000o`;o003o1?ooool50000o`Gooooo1Ol00?l5oooo
o`?o003o3?ooool5o`00o`;ooooo0ol00?l<ooooo`Go003o10000?l7o`00o`03ooooool00?oo003o
00?o003o4oooool3o`00o`;ooooo0`000?l3ooooo`D0003o00?o003o0000o`000?l00`000?l5oooo
o`<0003o0_ooool10000007ooooo00001000003oooooooooooooool5ool000Kooooo2?oo0009oooo
o`?oo`004?ooool5ool000Gooooo1Ol00?l2ooooo`Ko003o0_ooool5o`00o`P0003o00?ooooo0000
o`000?l010000?l7ooooo`Go003o1?ooool3o`00o`Gooooo0`000?l7ooooo`Co003o0`000?l6o`00
o`<0003o0_ooool5o`00o`?ooooo1@000?l5ooooo`Go003o1?ooool5o`00o`_ooooo1Ol00?lAoooo
o`Go003o0oooool>o`00o`Sooooo0ol00?l7ooooo`Go003o1oooool50000o`03o`00o`000?l0003o
00<0003o1?ooool50000o`7ooooo0@000001ooooo`0000<00000ooooooooool00_ooool3ool000Go
oooo1ooo000Pooooo`?oo`001Oooool30000o`?o003o0oooool5o`00o`03ooooool00?oo003o00Co
003o20000?l00oooool0003o0000o`050000o`Oooooo1?l00?l3ooooo`?o003o0`000?l2ooooo`D0
003o1oooool3o`00o`;ooooo2?l00?l4ooooo`Go003o1?ooool30000o`Kooooo1Ol00?l4ooooo`Go
003o3?ooool3o`00oa?ooooo1?l00?l3ooooo`ko003o1oooool5o`00o`?ooooo2?l00?l8ooooo`<0
003o0_l00?l50000o`Cooooo1@000?l1ooooo`4000000Oooool0000300000?oooooooooo00Wooooo
2?oo0004ooooo`Goo`007_ooool50000o`03o`00oooooooooooo00;ooooo1Ol00?l00ooooooo003o
o`00o`04o`00o`L0003o00?oooooo`00ool00?l01P000?l7ooooo`Go003o0_ooool2o`00o`D0003o
00?ooooo0000o`000?l00`000?l00ol00?ooooooooooo`09ooooo`So003o1?ooool5o`00o`Wooooo
0`000?l2ooooo`?o003o1Oooool5o`00o`;ooooo0`000?l>ooooo`?o003o3?ooool5o`00o`;ooooo
2Ol00?l01?oooooo003oo`00ool00?l8ooooo`Go003o0_ooool9o`00o`Wooooo0ol00?l2ooooo`<0
003o1Oooool50000o`7ooooo0@000001ooooo`0000<00000ooooooooool02Oooool7ool000Cooooo
2_oo000Jooooo`D0003o1Oooool30000o`03o`00oooooooooooo00Go003o0_ooool30000o`?ooooo
1?l00?l50000o`Oooooo1Ol00?l2ooooo`;o003o1@000?l00oooool0003o0000o`030000o`;o003o
00?oooooo`00ool00?l01?l00?l3ooooo`So003o1Oooool3o`00o`Wooooo1@000?l:ooooo`?o003o
0_ooool50000o`cooooo1Ol00?l;ooooo`Co003o0`000?l01Ooooooo003oo`00ool00?oooooo00?o
003o3Oooool5o`00o`;ooooo2?l00?lHooooo`<0003o0_ooool10000007ooooo00000`00003ooooo
ooooo`09ooooo`Goo`001_ooool;ool001Wooooo1@000?l4ooooo`D0003o0oooool6o`00o`Kooooo
1Ol00?l30000o`Sooooo1Ol00?l3ooooo`03o`00o`000?l0003o00<0003o0_ooool30000o`_o003o
0oooool6o`00oa;ooooo1@000?l?ooooo`D0003o0_ooool3o`00o`Oooooo1Ol00?l;ooooo`?o003o
1@000?lDooooo`Go003o0_ooool5o`00ob3ooooo0@000001ooooo`0000@00000oooooooooooooooo
0ooo0006ooooo`?oo`001oooool;ool001?ooooo0ooo0004ooooo`H0003o00?ooooo0000o`000?l0
10000?l5ooooo`Go003o1Oooool5o`00o`Kooooo0ol00?l3ooooo`?o003o1_ooool30000o`?o003o
00?oooooo`00ool00?l02ol00?lKooooo`D0003o00?o003oooooooooool03?ooool50000o`03oooo
ool00?oo003o00?o003o1_ooool5o`00o`cooooo0_l00?l50000o`;ooooo0ol00?l?ooooo`Go003o
0oooool3o`00o`;ooooo0`000?l01?oooooo003oo`00ool00?l?ooooo`Go003o1?ooool10000007o
oooo00000`00003oooooooooo`05ool0013ooooo2_oo000Booooo`Goo`001Oooool;0000o`Gooooo
1Ol00?l2ooooo`Wo003o1?ooool5o`00o`gooooo0`000?l2o`00o`05ooooool00?oo003oo`00oooo
ool02?l00?l?ooooo`?o003o2?ooool2o`00o`<0003o0ol00?l9ooooo`<0003o0_ooool30000o`;o
oooo1Ol00?l2ooooo`H0003o0_l00?l3ooooo`<0003o0_l00?l2ooooo`<0003o00?o003o0000o`00
0?l010000?l00ooooooo003oo`00o`03o`00o`kooooo1Ol00?l3ooooo`?o003o00?ooooo0000o`00
0?l00`000?l4o`00o`gooooo1ol00?l3ooooo`4000000Oooool0000300000?oooooooooo00Goo`00
4?ooool3ool000;ooooo1?oo000;ooooo`?oo`001Oooool5ool000Gooooo2P000?l5ooooo`Ko003o
00?oooooo`00ool00?l02Ol00?l3ooooo`Go003o3?ooool50000o`03o`00oooooooooooo00Cooooo
1_l00?l9ooooo`?o003o0oooool5o`00o`Kooooo2Ol00?l8ooooo`D0003o0ol00?l3ooooo`Go003o
00?ooooo0000o`000?l01P000?l3ooooo`D0003o0_l00?l:0000o`;ooooo1Ol00?l?ooooo`?o003o
0oooool5o`00o`D0003o1?l00?l=ooooo`Oo003o0oooool10000007ooooo00000`00003ooooooooo
o`05ool000oooooo1Ooo000;ooooo`?oo`0000?oooooool00?oo00000ooo0004ooooo`Goo`001Ooo
ool90000o`Kooooo1Ol00?l2ooooo`_o003o0oooool5o`00o`_ooooo1P000?l00ol00?oooooooooo
o`07ooooo`?o003o2?ooool5o`00o`;ooooo1Ol00?l6ooooo`Wo003o2?ooool50000o`Co003o0ooo
ool3o`00o`;ooooo20000?l3ooooo`D0003o0_l00?l90000o`?ooooo1Ol00?l<ooooo`?o003o1_oo
ool5o`00o`D0003o1?l00?l7ooooo`<0003o0oooool7o`00o`?ooooo0@000001ooooo`0000@00000
oooooooooooooooo0ooo000@ooooo`Goo`002_ooool;ool000Cooooo0ooo0007ooooo`P0003o1_oo
ool5o`00o`;ooooo2ol00?l4ooooo`?o003o3?ooool60000o`Wooooo1Ol00?l7ooooo`Go003o00?o
ooooo`00ool00?l01?l00?l6ooooo`So003o0oooool30000o`?ooooo1@000?l4o`00o`Sooooo2000
0?l3ooooo`D0003o0_l00?l90000o`Cooooo0ol00?l<ooooo`Go003o1Oooool5o`00o`05ooooo`00
0?l0003o0000ooooool01Ol00?l5ooooo`D0003o0oooool5o`00o`Cooooo0@000001ooooo`0000<0
0000ooooooooool01Oooool4ool000_ooooo1Ooo000:ooooo`coo`001_ooool3ool000Sooooo0`00
0?l8ooooo`?o003o1?ooool4o`00o`;ooooo1Ol00?lBooooo`D0003o2_ooool5o`00o`Oooooo2ol0
0?l6ooooo`Go003o1_ooool50000o`03o`00oooooooooooo00<0003o1Ol00?l9ooooo`H0003o1Ooo
ool30000o`;o003o0_ooool30000o`04o`00o`000?l0003o0000oaCooooo1Ol00?l6ooooo`?o003o
1oooool5o`00o`Cooooo1@000?l<ooooo`4000000Oooool0000300000?oooooooooo00Cooooo1_oo
000;ooooo`?oo`002oooool5ool00003oooooooo003oo`0000Coo`001Oooool5ool0017ooooo1Ol0
0?l3ooooo`Go003o00?oooooo`00ool00?l00ol00?lCooooo`<0003o0_ooool3o`00o`Kooooo2?l0
0?l4ooooo`[o003o1oooool5o`00o`Kooooo1@000?l2o`00o`;ooooo1_l00?l3ooooo`<0003o3ooo
ool5o`00oaKooooo0`000?l4ooooo`Go003o4?ooool5o`00o`Cooooo1@000?l<ooooo`4000000Ooo
ool0000300000?oooooooooo00Cooooo1ooo000Iooooo`?oo`0000?oooooool00?oo00001Ooo0005
ooooo`Goo`004Oooool5o`00o`?ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Oooooo0`000?l=
ooooo`Go003o1_ooool8o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ool00?l00ol00?l7
ooooo`Go003o1_ooool50000o`;o003o0_ooool5o`00o`?ooooo1@000?l>ooooo`Go003o5Oooool5
0000o`04o`00ooooooooooooooooo`?o003o3_ooool8o`00o`Gooooo0`000?l=ooooo`4000000Ooo
ool0000300000?oooooooooo00Cooooo2?oo00001?ooooooo`00ool00?oo000Hoooooa7oo`000ol0
0?l>ooooo`Go003o0oooool5o`00o`;ooooo0ol00?l7ooooo`D0003o2?ooool3o`00o`03ooooool0
0?oo003o00?o003o2Oooool:o`00o`?ooooo1Ol00?l8ooooo`?o003o2?ooool30000o`?o003o0_oo
ool5o`00o`?ooooo1@000?l=ooooo`Go003o5Oooool60000o`;o003o2Oooool3o`00o`Kooooo2?l0
0?lFooooo`4000000Oooool0000300000?oooooooooo00Gooooo3?oo000;ooooo`?oo`002Oooool@
ool000Go003o3_ooool3o`00o`Gooooo1?l00?l7ooooo`?o003o0_ooool60000o`Kooooo2_l00?l9
ooooo`_o003o0_ooool5o`00o`[ooooo0ol00?l8ooooo`?o003o1?ooool3o`00o`Cooooo1@000?l<
ooooo`Go003o5_ooool60000o`;o003o2?ooool5o`00o`Gooooo1Ol00?l6ooooo`?o003o4?ooool1
0000007ooooo00000`00003oooooooooo`07ooooo`[oo`002_ooool5ool000Wooooo0ooo00000ooo
ooooo`00ool00008ool00003ooooool00?oo003o00?o003o5_ooool5o`00o`Gooooo1Ol00?l00ooo
ool0003o0000o`040000o`Kooooo1Ol00?l00ooooooo003oo`00o`02o`00o`Kooooo0`000?l00ooo
oooo003oo`00o`08o`00o`?ooooo0ol00?l:ooooo`Go003o3_ooool3o`00o`Cooooo00Co003o0000
o`000?l0003o3Oooool5o`00oaKooooo1@000?l3o`00o`Sooooo1Ol00?l5ooooo`Go003o1Oooool5
o`00o`?ooooo0ol00?l01?oooooo003oo`00ool00?l5ooooo`4000000Oooool0000300000?oooooo
oooo00Sooooo0ooo00000oooooooo`00ool00003ool000[ooooo1Ooo000=ooooo`_oo`001Ol00?lF
ooooo`Go003o1Oooool5o`00o`;ooooo1@000?l6ooooo`Go003o00?oooooo`00ool00?l00ol00?l4
ooooo`D0003o3?l00?l>ooooo`Go003o3Oooool5o`00o`;ooooo1_l00?l<ooooo`Go003o5oooool3
0000o`?o003o2Oooool5o`00o`Kooooo0ol00?l6ooooo`05o`00o`000?l0003o0000ool00?l00_oo
ool9o`00o`Cooooo0@000001ooooo`0000<00000ooooooooool03Oooool3ool000Gooooo1Ooo0000
0oooooooo`00ool00003ool000kooooo2ooo0003o`00oaOooooo1Ol00?l5ooooo`Go003o0oooool3
0000o`Gooooo1_l00?l2ooooo`Go003o0oooool60000o`03ooooool00?oo003o00_o003o3?ooool5
o`00o`gooooo1Ol00?l2ooooo`Ko003o3Oooool3o`00o`oooooo0`000?lFooooo`?o003o4?ooool5
0000o`;ooooo2Ol00?l4ooooo`4000000Oooool0000300000?oooooooooo01Cooooo1ooo00001?oo
ooooo`00ool00?oo000Cooooo`Soo`006Oooool5o`00o`Kooooo0ol00?l;ooooo`Go003o1?ooool5
o`00o`;ooooo1`000?l2ooooo`go003o3?ooool3o`00o`Wooooo0ol00?l2ooooo`go003o5oooool3
o`00o`Cooooo1@000?lSooooo`Go003o1@000?l2ooooo`Wo003o1?ooool10000007ooooo00000`00
003oooooooooo`0Dooooo`Ooo`005oooool8ool001Oooooo2?l00?lCooooo`Go003o1Oooool3o`00
o`?ooooo1P000?l4ooooo`co003o1oooool3o`00o`Oooooo0`000?l3ooooo`<0003o0ol00?l00ooo
oooo003oo`00o`09o`00o`04ooooool00?oo003oo`00oa?ooooo1Ol00?l3ooooo`D0003o00?o003o
ooooooooool01_ooool30000oaKooooo1_l00?l50000o`?ooooo0`000?l01?oooooo003oo`00ool0
0?l5ooooo`4000000Oooool0000300000?oooooooooo00[ooooo0ooo0007ooooo`Soo`005_ooool5
ool000<0003o4Oooool3o`00o`;ooooo1Ol00?l30000o`;o003o1?ooool3o`00o`_ooooo1Ol00?l;
ooooo`D0003o2?ooool9o`00o`Kooooo1Ol00?l00ooo003oooooooooo`02ooooo`D0003o00?ooooo
0000o`000?l00`000?l3o`00o`?ooooo1Ol00?l3ooooo`Go003o4_ooool5o`00o`?ooooo1@000?l0
0ol00?ooooooooooo`05ooooo`D0003o5Oooool7o`00o`<0003o0oooool50000o`Sooooo0@000001
ooooo`0000<00000ooooooooool02Oooool5ool000Oooooo2Ooo0005ooooo`?oo`003Oooool3ool0
00D0003o00Coooooool00?oo003oo`002oooool5o`00o`03ooooool00?oo003o00;o003o1@000?l0
1?l00?ooooooooooooooool5o`00o`_ooooo0ol00?l=ooooo`<0003o1oooool3ool000Cooooo0ol0
0?l7ooooo`Go003o0_oo0003ooooo`D0003o00?ooooo0000o`000?l00`000?l3o`00o`?ooooo1Ol0
0?l3ooooo`Go003o4_ooool5o`00o`Cooooo0`000?l2o`00o`Kooooo00?o003o0000o`000?l00`00
0?lEooooo`So003o1Oooool50000o`Sooooo0@000001ooooo`0000<00000ooooooooool02Oooool5
ool000Gooooo0ooo00000oooooooo`00ool00006ool000?ooooo1Ooo000?ooooo`D0003o1Ooo000:
ooooo`Go003o00?oooooo`00ool00?l00_l00?l50000o`04o`00oooo003oo`00ool000Go003o4_oo
ool3ool000_ooooo0ooo00000oooooooo`00ool00003ool000gooooo1Ol00?l2ool000?ooooo1@00
0?l00oooool0003o0000o`030000o`?o003o1?ooool3o`00o`Cooooo1Ol00?lCooooo`?o003o1_oo
ool3o`00o`Cooooo1?l00?l50000oaKooooo1_l00?l6ooooo`D0003o2?ooool10000007ooooo0000
0`00003oooooooooo`09ooooo`Goo`001?ooool5ool00003oooooooo003oo`0000Goo`000oooool5
ool000oooooo1@000?l5ool000[ooooo1Ol00?l2ooooo`?o003o1@000?l4ool000Go003o4Oooool5
ool000Wooooo2ooo000=ooooo`?o003o0ooo0004ooooo`<0003o0oooool30000o`?o003o00?oo`00
ooooooooool02_ooool3o`00oaWooooo0ooo0004ooooo`?oo`001_l00?l30000ob;ooooo0_l00?l3
0000o`Gooooo0ol00?l1ooooo`4000000Oooool0000300000?oooooooooo00[ooooo0ooo0005oooo
o`Goo`000_ooool6ool00003oooooooo003oo`0000Goo`003?ooool3ool00005ooooo`000?l0003o
0000ooooool01Ooo000;ooooo`?o003o1oooool30000o`Koo`000ol00?l01?ooooooo`00ool00?oo
000>ooooo`Koo`001Oooool?ool000Kooooo0ooo0005ooooo`?oo`003Oooool3o`00o`;oo`002Ooo
ool3ool00004oooooooo003oo`00ool001Oooooo1Ooo00000oooooooo`00ool00003ool000_o003o
0_ooool3o`00o`?ooooo0ol00?lEooooo`?o003o0`000?l3ooooo`Go003o0@000001ooooo`0000<0
0000ooooooooool04_ooool5ool000;ooooo1Ooo00000oooooooo`00ool00005ool000cooooo3Ooo
00001?ooooooo`00ool00?oo000Eooooo`Soo`0000?oooooool00?oo00000ooo000=ooooo`Ooo`00
0oooool@ool000Gooooo1Ooo000Dooooo`Goo`002?ooool:ool00004oooooooo003oo`00ool0017o
oooo2ooo0005o`00o`;ooooo2_l00?l00ooooooo003oo`00o`03o`00oaCooooo0_l00?l50000o`;o
oooo1Ol00?l10000007ooooo00000`00003oooooooooo`0Cooooo`?oo`001?ooool3ool000;ooooo
1ooo000<oooooa;oo`002oooool3ool000?ooooo0ooo00000oooooooo`00ool00004ool000;ooooo
1Ooo000>ooooo`Koo`000ooooolCool000;ooooo1Ooo0003ooooo`?oo`001?ooool3ool000Sooooo
0ooo0009ooooo`ooo`003?ooool3ool00003oooooooo003oo`0000[oo`000ol00?l3ooooo`[o003o
00?oooooo`00ool00?l00ol00?l4ooooo`<0003o3_ooool00ol00?l0003o0000o`030000o`;ooooo
1Ol00?l10000007ooooo00001000003oooooooooooooool3ool000Kooooo0ooo0005ooooo`?oo`00
2_ooool7ool000cooooo4_oo000:ooooo`Goo`0000?oooooool00?oo00002Ooo0002ooooo`Goo`00
3_ooool6ool000?ooooo1Ooo0002ooooo`goo`0000?oooooool00?oo00000ooo0002ooooo`Goo`00
0_ooool5ool001?ooooo3ooo000;ooooo`Goo`0000?oooooool00?oo00002?oo00060000o`03oooo
ool00?oo003o00So003o0`000?l3o`00o`?ooooo1@000?l>ooooo`D0003o0oooool3o`00o`7ooooo
0@000001ooooo`0000<00000ooooooooool01Ooo0004ooooo`Goo`000oooool7ool000Sooooo1Ooo
000>ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00003oooooooo003oo`0000?oo`00
2_ooool5ool00003oooooooo003oo`0000Woo`000oooool3ool000?ooooo0ooo000:ooooo`Coo`00
1Oooool3ool000?ooooo1Ooo0003ooooo`Goo`000_ooool3ool000?ooooo1_oo00000oooooooo`00
ool00003ool001Cooooo3_oo000;ooooo`koo`0000?ooooo0000o`000?l01P000?l9o`00o`L0003o
0oooool50000o`;ooooo0ol00?l:ooooo`<0003o2?ooool10000007ooooo00000`00003ooooooooo
o`05ool000Cooooo1Ooo0003ooooo`Soo`005Oooool3ool000gooooo1Ooo000;ooooo`Goo`0000?o
ooooool00?oo00002Ooo0008ooooo`Goo`006Oooool3ool000Cooooo1Ooo0007ooooo`Ooo`0000?o
ooooool00?oo00000ooo0005ooooo`?oo`003oooool6ool00004oooooooo003oo`00ool000cooooo
3Ooo00000ooooooo003o0000o`070000o`03ooooool00?oo003o00Co003o0_ooool80000o`03oooo
ool00?l0003o00@0003o00?oooooo`00ool00?l00ol00?l8ooooo`Go003o1oooool10000007ooooo
00000`00003oooooooooo`05ool000Cooooo1Ooo0003ooooo`Soo`005?ooool5ool000Cooooo0ooo
0005ooooo`Goo`003?ooool5ool00003oooooooo003oo`0000Ooo`002Oooool5ool000kooooo1Ooo
000>ooooo`?oo`001oooool8ool000;ooooo0ooo0005ooooo`Goo`003oooool3ool001?ooooo0ooo
00000oooooooo`00ool00005ool000;ooooo00?o003o0000o`000?l01P000?l00ol00?ooooooo`00
o`04o`00o`;ooooo20000?l00ooooooo003oo`00o`030000o`03o`00oooooooo003o00Co003o2?oo
ool6o`00o`Kooooo0@000001ooooo`0000@00000oooooooooooooooo0ooo0006ooooo`?oo`001Ooo
ool7ool001Cooooo3Ooo0004ooooo`Goo`003?ooool5ool000?ooooo1ooo0009ooooo`Goo`003Ooo
ool7ool001Oooooo1ooo000;ooooo`Goo`002?ooool3ool001oooooo1ooo00000ooooooo003o0000
o`060000o`;o003o0_ooool3o`00o`Cooooo1`000?l00ooooooo003oo`00o`04o`00o`03ooooool0
0?oo003o00?o003o2?ooool6o`00o`Kooooo0@000001ooooo`0000<00000ooooooooool04Oooool3
ool00004oooooooo003oo`00ool000Wooooo0ooo0009ooooo`goo`001Oooool3ool000gooooo1Ooo
0002ooooo`Soo`002Oooool5ool000gooooo1ooo000Eooooo`Ooo`003Oooool5ool000Oooooo1Ooo
000Dooooo`?oo`002?ooool7ool00003ooooo`000?l0003o00<0003o1?l00?l:ooooo`;o003o1P00
0?l4o`00o`?ooooo0ol00?l:ooooo`Go003o1_ooool10000007ooooo00000`00003oooooooooo`04
ooooo`?oo`0000?oooooool00?oo00000ooo0003ooooo`Goo`002oooool5ool000Wooooo3?oo000F
ooooo`?oo`000oooool8ool000Wooooo1Ooo000=ooooo`Ooo`005?ooool7ool000Gooooo0ooo0006
ooooo`Goo`001oooool7ool000Wooooo0ooo0005ooooo`Goo`001oooool7ool000;ooooo0`000?l4
o`00o`_ooooo1?l00?l50000o`cooooo0ol00?l5ooooo`?o003o1oooool10000007ooooo00000`00
003oooooooooo`03ooooo`_oo`000_ooool5ool000_ooooo1Ooo000<ooooo`Soo`004_ooool3ool0
00Sooooo1ooo000;ooooo`?oo`003oooool5ool001Gooooo1Ooo0006ooooo`Goo`001Oooool5ool0
00Gooooo2_oo0007ooooo`Goo`001?ooool5ool000Oooooo1ooo0002ooooo`Go003o3_ooool3o`00
o`P0003o2?ooool5o`00o`kooooo0@000001ooooo`0000<00000ooooooooool00oooool;ool000;o
oooo1Ooo000;ooooo`Goo`002oooool8ool001;ooooo1Ooo0008ooooo`Goo`00<oooool3ool00003
oooooooo003oo`0000Coo`001_ooool5ool000Gooooo1Ooo0004ooooo`_oo`001oooool5ool000Co
oooo1Ooo0008ooooo`Goo`000oooool5o`00oa7ooooo2@000?l7ooooo`;o003o0`000?l>ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo2ooo0003ooooo`?oo`003Oooool3ool000Gooooo
0ooo0004ooooo`Soo`004_ooool5ool000Sooooo1Ooo0009ooooo`?oo`009_ooool:ool000Oooooo
1Ooo0006ooooo`?oo`001Oooool5ool00003oooooooo003oo`0000?oo`001oooool5ool000Gooooo
0ooo0009ooooo`Soo`0000Coooooo`00ool00?oo003o1Oooool3o`00o`Kooooo0ol00?l2ooooo`P0
003o1oooool00ol00?l0003o0000o`030000o`gooooo0@000001ooooo`0000<00000ooooooooool0
0oooool=ool001;ooooo0ooo0003ooooo`Goo`000oooool8ool001;ooooo1Ooo0009ooooo`?oo`00
0oooool4ool000;ooooo1Ooo000Uooooo`[oo`001Oooool6ool000oooooo1Ooo0002ooooo`?oo`00
2Oooool3ool001;ooooo2Ooo0007ooooo`Go003o1?ooool5o`00o`?ooooo00?o003o0000o`000?l0
1P000?l5ooooo`D0003o1Oooool3o`00o`Gooooo0@000001ooooo`0000<00000ooooooooool00ooo
ool>ool0013ooooo1Ooo0002ooooo`Soo`0000?oooooool00?oo00001Ooo000Cooooo`?oo`003ooo
ool6ool00003oooooooo003oo`0000?oo`006_ooool3ool000Sooooo2Ooo0005ooooo`Goo`002ooo
ool3ool000Cooooo0ooo0002ooooo`Goo`002oooool3ool0013ooooo2?oo0005ooooo`Oo003o1?oo
ool5o`00o`?ooooo0_l00?l80000o`Cooooo1@000?l4ooooo`Go003o1?ooool10000007ooooo0000
0`00003oooooooooo`03ooooo`Goo`0000?oooooool00?oo00001_oo000@ooooo`Koo`0000?ooooo
ool00?oo00001ooo0003ooooo`Goo`009?ooool6ool00003oooooooo003oo`0000?oo`001?ooool3
ool00004oooooooo003oo`00ool000kooooo1Ooo0008ooooo`Goo`002?ooool5ool000[ooooo1Ooo
0006ooooo`Ooo`002_ooool5ool0013ooooo1ooo0004ooooo`So003o1?ooool01Ol00?l0003o0000
o`000?oo003o00;ooooo1Ol00?l00oooool0003o0000o`030000o`Gooooo0`000?l5ooooo`So003o
0Oooool10000007ooooo00000`00003oooooooooo`04ooooo`?oo`001Oooool5ool000gooooo2Ooo
0002ooooo`Soo`000oooool5ool0013ooooo0ooo0008ooooo`?oo`001_ooool6ool000;ooooo0ooo
0004ooooo`Woo`003Oooool5ool000Sooooo1Ooo0008ooooo`Goo`002_ooool5ool000Gooooo2?oo
000:ooooo`Goo`004?ooool6ool000Gooooo1_l00?l30000o`?o003o1@000?l00ooooooo003oo`00
o`03o`00o`;ooooo1@000?l=ooooo`Wo003o0@000001ooooo`0000<00000ooooooooool03Oooool3
ool000gooooo5?oo0003ooooo`Koo`003_ooool5ool000Kooooo1Ooo0006ooooo`Coo`0000Cooooo
ool00?oo003oo`001_ooool9ool000Oooooo0ooo0003ooooo`Goo`002Oooool3ool000[ooooo0ooo
000;ooooo`Goo`001Oooool7ool000_ooooo1Ooo000@ooooo`Goo`001_ooool5o`00o`D0003o0_l0
0?l50000o`03ooooool00?oo003o00?o003o0oooool30000o`oooooo2?l00?l10000007ooooo0000
0`00003oooooooooo`08ooooo`?oo`004_ooool5ool00003oooooooo003oo`0000_oo`0000Gooooo
ool00?oo003oo`00ooooo`06ool000gooooo1Ooo0006ooooo`Goo`002_ooool5ool000Gooooo2Ooo
0006ooooo`Goo`000oooool3ool000Wooooo1Ooo000:ooooo`?oo`002oooool3ool000Kooooo1Ooo
000>ooooo`?oo`004_ooool3ool000Sooooo1?l00?l50000o`;o003o1@000?l00ooooooo003oo`00
o`03o`00oaSooooo1Ol00?l10000007ooooo00000`00003oooooooooo`05ooooo`Ooo`004Oooool5
ool000?ooooo2?oo0003ooooo`Goo`0000?oooooool00?oo00000ooo000=ooooo`Goo`001_ooool5
ool000Cooooo0ooo0003ooooo`Goo`001_ooool3ool00004oooooooo003oo`00ool000Oooooo1Ooo
000?ooooo`Goo`002Oooool5ool001Cooooo0ooo00001?ooooooo`00ool00?oo0006ooooo`?oo`00
7?ooool30000o`Oooooo1@000?l3o`00o`<0003o0oooool3o`00o`Sooooo0ol00?l?ooooo`?o003o
0Oooool10000007ooooo00000`00003oooooooooo`04ooooo`Soo`004_ooool3ool000Cooooo2?oo
00000oooooooo`00ool00005ool00003oooooooo003oo`0000?oo`003_ooool3ool000Sooooo1_oo
00000oooooooo`00ool00003ool000;ooooo1Ooo000;ooooo`?oo`001_ooool5ool000oooooo1ooo
0004ooooo`Soo`005oooool5ool00003oooooooo003oo`0000Koo`006_ooool50000o`;ooooo0ol0
0?l2ooooo`<0003o1Ol00?l4ooooo`Go003o00Coooooo`00ool00?oo003o0_ooool7o`00oa3ooooo
0@000001ooooo`0000<00000ooooooooool01?ooool:ool001Sooooo1_oo00000oooooooo`00ool0
0007ool00004oooooooo003oo`00ool000oooooo0ooo000:ooooo`[oo`000oooool3ool000_ooooo
1Ooo0006ooooo`?oo`004Oooool7ool000;ooooo3?oo000>ooooo`?oo`000oooool>ool000_ooooo
0ooo0004ooooo`?oo`001Oooool50000o`03ooooool00?oo003o00?o003o3Oooool:o`00o`03oooo
ool00?oo003o00Ko003o3oooool10000007ooooo00000`00003oooooooooo`04ooooo`_oo`007_oo
ool:ool0017ooooo1Ooo0009ooooo`[oo`004Oooool5ool000Oooooo0ooo000Booooo`Goo`000_oo
ool=ool000cooooo1Ooo0002ooooo`koo`002_ooool5ool000;ooooo1Ooo0003ooooo`03o`00o`00
0?l0003o00<0003o00?oooooo`00ool00?l00ol00?l=ooooo`[o003o00?oooooo`00ool00?l01_l0
0?l01?oooooo003oo`00ool00?l;ooooo`4000000Oooool0000300000?oooooooooo00?ooooo3?oo
0003ooooo`?oo`006?ooool:ool0017ooooo1Ooo0009ooooo`Woo`004_ooool6ool000Gooooo1Ooo
000Aooooo`Goo`000_ooool7ool00003oooooooo003oo`0000?oo`003?ooool5ool000;ooooo1?oo
00000oooooooo`00ool00006ool000_ooooo1Ooo0002ooooo`Goo`000oooool2o`00o`<0003o0_oo
ool5o`00o`kooooo0ol00?l00ooooooo003oo`00o`03o`00o`;ooooo3_l00?l8ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo3?oo0002ooooo`Goo`006?ooool3ool00003oooooooo003o
o`0000?oo`001_ooool3ool000Sooooo1Ooo0009ooooo`[oo`004_ooool5ool000Gooooo1Ooo000B
ooooo`?oo`001?ooool<ool000cooooo1Ooo00000oooooooo`00ool00003ool000;ooooo1?oo000>
ooooo`Goo`000_ooool5ool000?ooooo1Ol00?l3ooooo`?o003o00Coooooo`00ool00?oo003o4?oo
ool6o`00o`?ooooo0ol00?l00ooooooo003oo`00o`06o`00o`Oooooo0@000001ooooo`0000<00000
ooooooooool00oooool6ool000;ooooo0ooo0003ooooo`Goo`007Oooool3ool000Kooooo1Ooo0008
ooooo`?oo`002_ooool;ool0017ooooo1Ooo0005ooooo`Goo`006oooool5ool00004oooooooo003o
o`00ool000kooooo0ooo0002ooooo`Goo`0000Coooooool00?oo003oo`004Oooool3ool000Cooooo
1Ooo0003ooooo`?o003o1oooool5o`00o`kooooo2?l00?l6ooooo`Wo003o1_ooool10000007ooooo
00000`00003oooooooooo`04ooooo`Goo`001oooool7ool0017ooooo1?oo000@ooooo`Goo`005_oo
ool3ool000;ooooo1Ooo000@ooooo`Goo`001oooool3ool001cooooo1Ooo000Gooooo`[oo`005ooo
ool6ool000cooooo1Ol00?l>ooooo`So003o1oooool;o`00o`?ooooo0@000001ooooo`0000<00000
ooooooooool00_ooool7ool000Kooooo2?oo000@ooooo`Soo`003Oooool5ool00004oooooooo003o
o`00ool001Oooooo1Ooo000@ooooo`Goo`0000Coooooool00?oo003oo`000_ooool5ool001cooooo
0ooo000Iooooo`?oo`0000?oooooool00?oo00000ooo0003ooooo`Coo`004?ooool8ool000[ooooo
1Ol00?l6ooooo`?o003o1Oooool8o`00o`?ooooo0ol00?l4ooooo`Wo003o0_ooool10000007ooooo
00001000003oooooooooooooool7ool000Gooooo2_oo000<ooooo`?oo`0000?oooooool00?oo0000
1ooo0003ooooo`?oo`001oooool3ool00003oooooooo003oo`0000?oo`005oooool3ool0017ooooo
2_oo00000oooooooo`00ool00003ool003cooooo1Ooo0002ooooo`Koo`0000Coooooool00?oo003o
o`002oooool9ool000Kooooo0`000?l01?oooooo003oo`00ool00?l6ooooo`Oo003o0oooool6o`00
o`?ooooo1_l00?l3ooooo`So003o0_ooool10000007ooooo00001000003oooooooooooooool5ool0
00Kooooo2_oo000<ooooo`koo`000_ooool5ool000[ooooo1Ooo000Hooooo`?oo`000oooool3ool0
00Sooooo1_oo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`00?Oooool3ool0
00?ooooo2ooo000;ooooo`Soo`001Oooool50000o`Wooooo2?l00?l;ooooo`Oo003o1Oooool5o`00
o`;ooooo0@000001ooooo`0000@00000oooooooooooooooo1Ooo0006ooooo`[oo`003?ooool5ool0
0003oooooooo003oo`0000Koo`000_ooool5ool000[ooooo1Ooo0008ooooo`?oo`003?ooool5ool0
0003oooooooo003oo`0000?oo`001_ooool5ool000?ooooo1Ooo0002ooooo`?oo`00A?ooool;ool0
00kooooo1Ooo0005ooooo`D0003o2Oooool8o`00o`Gooooo0`000?l3ooooo`;o003o0`000?l2o`00
o`Cooooo1Ol00?l3ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0ooo0007ooooo`Wo
o`000oooool3ool000Oooooo1Ooo00000oooooooo`00ool00005ool000?ooooo1Ooo0002ooooo`?o
o`001_ooool3ool000Sooooo1Ooo000;ooooo`Goo`0000?oooooool00?oo00000ooo0006ooooo`Go
o`001?ooool3ool0017ooooo0ooo0006ooooo`?oo`002Oooool3ool000Wooooo0ooo000Fooooo`Co
o`0000?oooooool00?oo00000ooo000?ooooo`?oo`001_ooool50000o`[ooooo1ol00?l4ooooo`D0
003o0oooool50000o`03o`00oooooooooooo00;ooooo1Ol00?l3ooooo`4000000Oooool000030000
0?oooooooooo00Sooooo3?oo0003ooooo`Goo`001oooool3ool000?ooooo0ooo0007ooooo`?oo`00
0_ooool5ool0013ooooo1Ooo000:ooooo`Koo`0000?oooooool00?oo00000ooo0006ooooo`Goo`00
5oooool5ool000Cooooo1Ooo0007ooooo`Goo`001oooool5ool001_ooooo0ooo000Jooooo`<0003o
3Oooool5o`00o`03ooooo`000?l0003o00H0003o0oooool50000o`Gooooo1Ol00?l3ooooo`400000
0Oooool0000300000?oooooooooo00Oooooo2?oo00001?ooooooo`00ool00?oo0004ooooo`Goo`00
6oooool8ool000gooooo1_oo000:ooooo`Goo`000_ooool5ool000Oooooo0ooo000Hooooo`Goo`00
1?ooool6ool000Kooooo1Ooo0007ooooo`Goo`00=oooool50000o`04ooooo`000?l0003o0000o`So
oooo0_l00?l<0000o`?ooooo1@000?l6ooooo`Ko003o0Oooool10000007ooooo00000`00003ooooo
ooooo`07ooooo`Soo`001_ooool7ool001Cooooo0ooo0002ooooo`_oo`002oooool6ool000_ooooo
1Ooo0002ooooo`Woo`007_ooool5ool000Cooooo1_oo0006ooooo`Soo`001?ooool5ool003Oooooo
2P000?l8ooooo``0003o0_l00?l3ooooo`<0003o2Oooool5o`00o`4000000Oooool0000300000?oo
oooooooo00Oooooo2?oo0005ooooo`Ooo`003?ooool3ool000Gooooo4Ooo0002ooooo`?oo`001_oo
ool5ool000gooooo0ooo0004ooooo`Woo`007_ooool3ool000Kooooo1Ooo0007ooooo`Soo`001?oo
ool3ool000?ooooo0ooo000Mooooo`?oo`004_ooool:0000o`Sooooo2@000?l8o`00o`[ooooo1ol0
0?l10000007ooooo00000`00003oooooooooo`02ooooo`?oo`000oooool6ool000Kooooo1ooo000;
ooooo`Goo`001?oooolAool00003oooooooo003oo`0000?oo`000oooool8ool000;ooooo0ooo000>
ooooo`Woo`005oooool3ool000kooooo0ooo000;ooooo`Goo`001?ooool3ool000;ooooo1Ooo000B
ooooo`?oo`001_ooool5ool001;ooooo0`000?l00oooool0003o0000o`030000o`Sooooo20000?l0
0ooooooo003oo`00o`07o`00o`Sooooo2?l00?l10000007ooooo00000`00003oooooooooo`06ool0
00?ooooo0ooo0008ooooo`Soo`000oooool4ool000?ooooo1Ooo0004ooooo`_oo`000_ooool:ool0
00;ooooo2Ooo00000oooooooo`00ool00003ool000kooooo2?oo000>ooooo`?oo`000oooool7ool0
01?ooooo1_oo0002ooooo`Goo`000oooool5ool00003oooooooo003oo`0000?oo`004Oooool5ool0
00Gooooo1Ooo000Eooooo`D0003o2_ooool30000o`Kooooo2?l00?l30000o`Gooooo1ol00?l1oooo
o`4000000Oooool0000300000?ooooooo`0000Koo`003oooool7ool000;ooooo1_oo0002ooooo`Go
o`001Oooool3ool000;ooooo0ooo0004ooooo`[oo`0000?oooooool00?oo00002?oo00000ooooooo
o`00ool00006ool000cooooo1_oo000>ooooo`Goo`0000?oooooool00?oo00001_oo000Booooo`So
o`000_ooool3ool000Cooooo1Ooo00000oooooooo`00ool00003ool0017ooooo1Ooo0005ooooo`Go
o`005?ooool50000oa?ooooo2?l00?l50000o`Cooooo1_l00?l2ooooo`4000000Oooool000030000
0?ooooooo`0000Koo`003_ooool@ool00003oooooooo003oo`0000Koo`000oooool3ool000Gooooo
0ooo00000oooooooo`00ool0000Bool000;ooooo2Ooo0003ooooo`?oo`001?ooool5ool0013ooooo
1Ooo00000oooooooo`00ool00006ool001;ooooo2?oo0009ooooo`Goo`0000?oooooool00?oo0000
0ooo000Aooooo`Goo`001_ooool3ool000Gooooo0ooo000=ooooo`D0003o4oooool8o`00o`D0003o
1Oooool6o`00o`7ooooo0@000001ooooo`0000<00000oooooooo00001_oo000<oooooacoo`0000?o
ooooool00?oo00000ooo0003ooooo`Goo`0000?oooooool00?oo00003Ooo0007ooooo`Soo`000_oo
ool5ool000?ooooo1Ooo000:ooooo`?oo`000oooool=ool001?ooooo2?oo0002ooooo`?oo`0000?o
ooooool00?oo00001_oo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool000kooooo
0ooo00001?ooooooo`00ool00?oo000:ooooo`Goo`003?ooool50000oa?ooooo2?l00?l50000o`Ko
oooo1Ol00?l1ooooo`4000000Oooool0000300000?oooooooooo00Goo`003?oooolBool00003oooo
oooo003oo`0000Soo`0000?oooooool00?oo00000ooo0003ooooo`Goo`000_ooool=ool000;ooooo
0ooo0003ooooo`Soo`000_ooool5ool000?ooooo1Ooo0009ooooo`Goo`000oooool9ool001Gooooo
2?oo0002ooooo`coo`000oooool3ool00003oooooooo003oo`0000?oo`004?ooool5ool000Wooooo
1Ooo000=ooooo`<0003o2_ooool3o`00o`Sooooo0ol00?l30000o`;o003o1P000?l4ooooo`Go003o
0Oooool10000007ooooo00000`00003oooooooooo`0Aoooooa;oo`0000?oooooool00?oo00002?oo
00000oooooooo`00ool00004ool000;ooooo1Ooo0003ooooo`_oo`000_ooool5ool000?ooooo1_oo
0003ooooo`Goo`000oooool5ool000Wooooo1Ooo0004ooooo`Goo`006?ooool8ool000;ooooo2ooo
0005ooooo`Soo`004?ooool5ool000Wooooo1Ooo0007ooooo`<0003o3oooool5o`00o`Wooooo1@00
0?l2o`00o`03ooooo`000?l0003o00<0003o1?ooool4o`00o`7ooooo0@000001ooooo`0000<00000
ooooooooool04OoooolCool00004oooooooo003oo`00ool000;ooooo0ooo0003ooooo`Goo`000ooo
ool3ool00004oooooooo003oo`00ool000?ooooo2?oo0002ooooo`Goo`003Oooool5ool000?ooooo
0ooo000:ooooo`Goo`001?ooool5ool001Sooooo2Ooo00000oooooooo`00ool0000:ool000?ooooo
2Ooo0004ooooo`?oo`002Oooool5ool000Sooooo1Ooo0007ooooo`D0003o3_ooool5o`00o`Wooooo
1@000?l00ol00?ooooooooooo`050000o`Cooooo1Ol00?l10000007ooooo00000`00003ooooooooo
o`0Booooo`?oo`000_ooool=ool000cooooo1Ooo0006ooooo`Goo`001_ooool3ool000?ooooo1Ooo
000>ooooo`Goo`004?ooool3ool000Kooooo0ooo000Jooooo`goo`0000?oooooool00?oo00001Ooo
0003ooooo`Soo`001?ooool5ool000Wooooo1Ooo0007ooooo`Goo`001oooool50000o`kooooo1Ol0
0?l9ooooo`D0003o0oooool50000o`Cooooo1Ol00?l10000007ooooo00000`00003oooooool00002
ool000?ooooo0ooo000Aooooo`_oo`003Oooool3ool000Oooooo1Ooo000<ooooo`Goo`003_ooool5
ool003Wooooo2_oo0003ooooo`Goo`000oooool5ool000Oooooo1Ooo0009ooooo`Goo`001oooool5
ool000Oooooo1@000?l3ooooo`<0003o2Oooool3o`00o`_ooooo0`000?l5ooooo`<0003o0_ooool8
o`00o`4000000Oooool0000300000?oo003oo`0000Woo`004?ooool5ool000;ooooo0ooo0008oooo
o`?oo`003Oooool6ool000_ooooo1Ooo000>ooooo`Goo`00>_ooool3ool00003oooooooo003oo`00
00?oo`001?ooool3ool000Gooooo1Ooo0006ooooo`Goo`002Oooool5ool000Sooooo0ooo00000ooo
ooooo`00ool000030000o`?ooooo0`000?l3ooooo`D0003o4oooool3o`00o`Wooooo2ol00?l1oooo
o`4000000Oooool0000300000?oo003oo`0000Woo`004Oooool3ool000gooooo1Ooo000;ooooo`So
o`002_ooool5ool000oooooo0ooo0008ooooo`?oo`00<_ooool6ool000kooooo1Ooo0005ooooo`Go
o`002_ooool3ool000cooooo0_oo00050000o`Sooooo1@000?l5ooooo`?o003o2_ooool3o`00o`<0
003o1_ooool9o`00o`Cooooo0@000001ooooo`0000<00000ool00?oo00002Ooo000Oooooo`Ooo`00
2oooool8ool000_ooooo0ooo000Jooooo`Goo`009?ooool3ool000Cooooo0ooo0002ooooo`Goo`00
2oooool3ool000;ooooo1Ooo0005ooooo`Goo`003?ooool3ool000[ooooo0_oo00050000o`Sooooo
1@000?l4ooooo`Go003o2Oooool2o`00o`D0003o1Oooool9o`00o`Cooooo0@000001ooooo`0000<0
0000oooooooo00002?oo000Booooo`?oo`002_ooool:ool000Wooooo2?oo000Xooooo`Goo`008Ooo
ool7ool000;ooooo1Ooo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool000Kooooo
1Ooo00000oooooooo`00ool00003ool000Kooooo0ooo000<ooooo`Goo`002Oooool2ool000D0003o
2Oooool40000o`Cooooo1Ol00?l9ooooo`;o003o1@000?l5ooooo`So003o1Oooool10000007ooooo
00000`00003oooooool00005ool00003oooooooo003oo`0000?oo`003_ooool5ool000Wooooo2ooo
0002ooooo`?oo`001?ooool6ool001?ooooo0ooo000Cooooo`Ooo`001_ooool3ool001?ooooo2_oo
0002ooooo`Goo`0000?oooooool00?oo00002?oo0005ooooo`Goo`000_ooool3ool001Kooooo1Ooo
000:ooooo`;oo`000`000?l4ooooo`?o003o0oooool50000o`?ooooo1Ol00?l4ooooo`?o003o0ooo
ool00ol00?l0003o0000o`030000o`;ooooo0ol00?l01?oooooo003oo`00ool00?l9ooooo`400000
0Oooool0000300000?oooooooooo00?oo`000_ooool7ool000gooooo1Ooo0009ooooo`_oo`0000?o
ooooool00?oo00000ooo000Kooooo`Goo`004oooool7ool000Cooooo1Ooo000:ooooo`?oo`001?oo
ool;ool000;ooooo1Ooo0002ooooo`Woo`001Oooool5ool001_ooooo1Ooo000Booooo`Go003o0_oo
ool60000o`?ooooo0ol00?l4ooooo`Go003o0_ooool50000o`;ooooo1Ol00?l<ooooo`4000000Ooo
ool0000300000?oooooooooo00Gooooo1ooo000=ooooo`Koo`002Oooool3ool000;ooooo1Ooo0000
0oooooooo`00ool00003ool000;ooooo0`000?lFooooo`Goo`0000Coooooool00?oo003oo`004Ooo
ool5ool000Cooooo1Ooo0009ooooo`Koo`000_ooool:ool000Cooooo0ooo0005ooooo`Ooo`001_oo
ool3ool001gooooo0ooo000@ooooo`So003o0_ooool60000o`[ooooo1Ol00?l00oooool0003o0000
o`030000o`?ooooo1Ol00?l<ooooo`4000000Oooool0000300000?ooooooo`0000;oo`000oooool7
ool000kooooo2?oo0008ooooo`?oo`0000Coooooool00?oo003oo`000_ooool5ool00003ooooo`00
0?l0003o00<0003o1Oooool30000o`Oooooo0ol00?l3ooooo`?oo`000ol00?l3ool000Co003o3Ooo
ool5ool000Cooooo1Ooo0006ooooo`?o003o1ooo00000oooooooo`00ool00005ool000;ooooo1_l0
0?l7ooooo`Koo`006Oooool6o`00oa[ooooo2Ol00?l3ooooo`D0003o2_ooool6o`00o`D0003o00?o
003oooooooooool01Ol00?l3ooooo`?o003o1_ooool10000007ooooo00000`00003oo`00ool00003
ool000?ooooo1Ooo0009ooooo`?oo`000oooool9ool000Kooooo1Ooo0006ooooo`?oo`000_ooool5
0000o`Cooooo1@000?l5ooooo`Go003o0oooool00ooo003o003oo`00o`03o`00o`03ool00?l00?oo
003o00Co003o3Oooool3ool000Kooooo0ooo0006ooooo`Go003o1_oo0002ooooo`?oo`001?ooool8
o`00o`Oooooo0ooo000?ooooo`?o003o2?ooool8o`00oaWooooo2?l00?l5ooooo`<0003o0_ooool3
o`00o`Kooooo1_l00?l50000o`04o`00ooooooooooooooooo`?o003o0oooool5o`00o`Gooooo0@00
0001ooooo`0000<00000ool00?oo00000ooo0006ooooo`?oo`001oooool@ool000Kooooo1Ooo000;
ooooo`D0003o1?ooool50000o`Gooooo1Ol00?l4ooooo`Go003o00?oo`00o`00ool00?l01?l00?lO
ooooo`Go003o1_oo0008ooooo`<0003o1_l00?l9ooooo`?o003o3?ooool5o`00o`Oooooo2?l00?lI
ooooo`So003o2Oooool5o`00o`Kooooo0ol00?l00ooooooo003oo`00o`030000o`;o003o2Oooool5
o`00o`Gooooo0@000001ooooo`0000<00000ool00?oo00000ooo0005ooooo`Goo`001_ooool9ool0
00;ooooo1Ooo0006ooooo`Goo`003?ooool30000o`Gooooo1@000?l5ooooo`Go003o1?ooool5o`00
o`03ool00?l00?oo003o00Co003o7oooool5o`00o`;ooooo0ooo0008ooooo`D0003o1Ol00?l8oooo
o`Go003o2oooool5o`00o`Oooooo2?l00?lJooooo`Oo003o2Oooool5o`00o`?ooooo0ol00?l5oooo
o`Ko003o2Oooool5o`00o`Gooooo0@000001ooooo`0000<00000oooooooo00000_oo0006ooooo`Go
o`001_ooool9ool000?ooooo0ooo0006ooooo`Goo`005_ooool30000o`;ooooo0ol00?l2ooooo`?o
003o1_ooool3o`00o`?ooooo1_l00?lNooooo`So003o2_ooool50000o`Co003o0_ooool30000o`Co
oooo0_l00?l30000o`_ooooo1Ol00?l8ooooo`;o003o0`000?l00ol00?ooooooooooo`0Aooooo`?o
003o2?ooool5o`00o`Sooooo1Ol00?l2ooooo`Go003o1_ooool3o`00o`Sooooo1_l00?l6ooooo`40
00000Oooool0000300000?oooooooooo00Sooooo1Ooo0007ooooo`Soo`003?ooool5ool000Wooooo
0ooo000>ooooo`Go003o1?ooool3o`00o`[ooooo1_l00?lLooooo`[o003o2Oooool50000o`Gooooo
1@000?l3ooooo`03o`00o`000?l0003o00<0003o2oooool3o`00o`Wooooo00?o003o0000o`000?l0
0`000?lBooooo`Go003o2?ooool5o`00o`Oooooo1_l00?l00ooooooo003oo`00o`03o`00oa3ooooo
1Ol00?l8ooooo`4000000Oooool0000300000?oooooooooo00Sooooo1?oo0007ooooo`Soo`001?oo
ool4ool000Gooooo1Ooo0008ooooo`Goo`003Oooool5o`00o`?ooooo1Ol00?l9ooooo`04o`00o`00
0?l0003o0000o`;o003o3oooool3o`00o`Wooooo2ol00?l:ooooo`<0003o1_ooool50000o`Cooooo
1@000?lGooooo`03o`00o`000?l0003o00<0003o0oooool3o`00o`Sooooo0_l00?l30000o`Co003o
2?ooool5o`00o`Oooooo3?l00?l@ooooo`Go003o2?ooool10000007ooooo00001000003ooooooooo
ooooool3ool000?ooooo1Ooo0007ooooo`Goo`001_ooool6ool000Cooooo1Ooo0008ooooo`Goo`00
3Oooool2o`00o`<0003o0oooool4o`00o`<0003o1oooool50000o`03o`00oooooooooooo00cooooo
1Ol00?l8ooooo`ko003o4?ooool50000o`Cooooo1@000?lCooooo`<0003o00?oooooo`00o`000?l0
1@000?l00ooooooo003oo`00o`03o`00o`Kooooo0_l00?l50000o`?o003o2?ooool5o`00o`Oooooo
3Ol00?l?ooooo`Go003o2?ooool10000007ooooo00000`00003oooooooooo`05ool000;ooooo1ooo
0005ooooo`Goo`001_ooool6ool000Cooooo1ooo0006ooooo`Goo`000oooool30000o`Gooooo0ol0
0?l50000o`;ooooo0ol00?l50000o`Kooooo1@000?l?ooooo`Go003o2?ooool?o`00oa3ooooo0`00
0?l6ooooo`<0003o4?ooool3o`00o`D0003o0_l00?l50000o`03ooooool00?oo003o00Go003o1?oo
ool2o`00o`D0003o0_l00?l5ooooo`?o003o0_ooool3o`00o`Wooooo3Ol00?l>ooooo`Go003o2?oo
ool10000007ooooo00000`00003oooooooooo`05ool000;ooooo2?oo0005ooooo`?oo`001oooool8
ool000?ooooo1ooo0006ooooo`?oo`000oooool50000o`?ooooo1?l00?l50000o`?ooooo0_l00?l5
0000o`Kooooo1@000?l;ooooo`<0003o1_l00?l4ooooo`?o003o0_ooool3o`00o`?ooooo2?l00?l6
ooooo`?o003o8_ooool00ol00?l0003o0000o`060000o`;o003o1@000?l00ooooooo003oo`00o`06
o`00o`?ooooo0_l00?l50000o`Kooooo1Ol00?l?ooooo`_o003o3_ooool5o`00o`Sooooo0@000001
ooooo`0000<00000ooooooooool01Ooo0003ooooo`Ooo`004?ooool8ool000Cooooo1Ooo000<oooo
o`D0003o0oooool4o`00o`D0003o1?ooool00ol00?l0003o0000o`030000o`Oooooo0`000?l3o`00
o`Sooooo1@000?l4o`00o`<0003o00?oooooo`00ool00?l02?l00?l3ooooo`Oo003o1Oooool8o`00
oakooooo2@000?l3o`00o`<0003o0oooool7o`00o`?ooooo0ol00?l30000o`Oooooo1Ol00?l2oooo
o`<0003o3_ooool7o`00o`kooooo1Ol00?l8ooooo`4000000Oooool0000400000?oooooooooooooo
o`?oo`001_ooool5ool000_ooooo0ooo0005ooooo`Goo`001?ooool5ool000cooooo1@000?l3oooo
o`Co003o1@000?l4ooooo`03o`00o`000?l0003o00<0003o0_l00?l7ooooo`Go003o1_ooool00ol0
0?l0003o0000o`030000o`?o003o1@000?l6o`00o`<0003o00?o003oooooool00?l00_l00?l2oooo
o`?o003o1?ooool=o`00oa_ooooo20000?l4o`00o`Sooooo1Ol00?l4ooooo`?o003o2Oooool5o`00
o`03ooooo`000?l0003o00<0003o1?ooool3o`00o`Oooooo1Ol00?l@ooooo`?o003o2Oooool10000
007ooooo00000`00003oooooooooo`0;ooooo`?oo`002oooool5ool000Cooooo1Ooo0005ooooo`?o
o`003_ooool30000o`;ooooo1_l00?l50000o`Cooooo00?o003o0000o`000?l00`000?l3o`00o`Ko
oooo1Ol00?l5ooooo`;o003o1@000?l3o`00o`D0003o1Ol00?l50000o`Go003o1oooool?o`00oa[o
oooo1`000?l4o`00o`[ooooo0ol00?lBooooo`?o003o0_ooool50000o`?ooooo1Ol00?l6ooooo`Go
003o0_ooool3o`00oaOooooo0@000001ooooo`0000<00000ooooooooool06Oooool5ool000Gooooo
0ooo0008ooooo`?oo`002?ooool3o`00o`Gooooo1Ol00?l2ooooo`D0003o0ol00?l2ooooo`04o`00
o`000?l0003o0000o`Co003o1_ooool5o`00o`Gooooo0ol00?l30000o`Cooooo20000?l2o`00o`D0
003o1Ol00?l7ooooo`oo003o2_ooool3o`00o`kooooo1@000?l5o`00obCooooo1@000?l3ooooo`Go
003o1_ooool5o`00o`03ooooool00?oo003o00?o003o5_ooool10000007ooooo00000`00003ooooo
ooooo`0Iooooo`Soo`003?ooool5ool000Kooooo1Ol00?l4ooooo`Go003o0oooool30000o`Go003o
1?ooool5o`00o`Oooooo0ol00?l6ooooo`Go003o1_ooool80000o`03o`00o`000?l0003o00<0003o
1Ol00?l6ooooo`<0003o3Ol00?l4ooooo`<0003o0_ooool01?l00?l0003o0000o`000?l:o`00o`Wo
oooo1Ol00?lUooooo`<0003o0oooool6o`00o`Oooooo0ol00?l2ooooo`Go003o5_ooool10000007o
oooo00000`00003oooooooooo`0Jooooo`Soo`0000Coooooool00?oo003oo`001oooool5ool000Ko
oooo1Ol00?l2ooooo`Oo003o1_ooool5o`00o`Gooooo0ol00?l4ooooo`?o003o2oooool3o`00o`[o
oooo1@000?l2o`00o`<0003o00?oooooo`00ool00?l00_l00?l2ooooo`03o`00o`000?l0003o00H0
003o2ol00?l4ooooo`D0003o00?ooooo0000o`000?l00`000?l:o`00o`Wooooo0ol00?lLooooo`?o
003o3Oooool5o`00o`gooooo0ol00?l30000oaGooooo0@000001ooooo`0000<00000ooooooooool0
7?ooool>ool000?ooooo1Ooo0006ooooo`Go003o00?oooooo`00ool00?l01Ol00?l7ooooo`Go003o
00Coooooo`00ool00?oo003o1oooool5o`00oaOooooo1@000?l4o`00o`03ooooool00?oo003o00?o
003o00?oooooo`00o`000?l020000?l2ooooo`[o003o0oooool50000o`03ooooo`000?l0003o00<0
003o2_l00?l?ooooo`?o003o5Oooool5o`00o`cooooo1_l00?l=ooooo`03o`00o`000?l0003o00<0
003o5?ooool10000007ooooo00000`00003oooooooooo`0Looooo`ooo`000oooool3ool000Kooooo
1Ol00?l2ooooo`Go003o2Oooool4o`00o`03ooooool00?oo003o00?o003o1_ooool5o`00oaSooooo
0`000?l01?oooooo003oo`00ool00?l2ooooo`Go003o00?oooooo`00o`000?l020000?l=o`00o`;o
oooo2`000?l:o`00o`kooooo1Ol00?l:ooooo`?o003o1oooool5o`00o`cooooo0ol00?l30000o`ko
oooo1@000?l>ooooo`?o003o0oooool10000007ooooo00000`00003oooooooooo`0Mooooo`Coo`00
00?oooooool00?oo00002?oo000:ooooo`Go003o0oooool5o`00o`Sooooo1Ol00?l00ooooooo003o
o`00o`03o`00o`Kooooo1?l00?l30000o`[ooooo0`000?l7ooooo`?o003o2?ooool5o`00o`03oooo
ool00?l0003o00L0003o1ol00?l2ooooo`Go003o0oooool90000o`[o003o3oooool5o`00o`Wooooo
1Ol00?l6ooooo`Go003o2oooool3o`00o`D0003o3Oooool50000o`gooooo1Ol00?l2ooooo`400000
0Oooool0000300000?oooooooooo02?ooooo2_oo0008ooooo`03ool00?l00?oo003o00?o003o1?oo
ool5o`00o`Oooooo0`000?l2o`00o`03ooooool00?oo003o00?o003o1oooool2o`00o`D0003o2?oo
ool50000o`?o003o0_ooool8o`00o`Gooooo00Co003o0000o`000?l0003o0_ooool01?l00?l0003o
0000o`000?l3ooooo`Go003o1Oooool5o`00o`Gooooo1@000?l5o`00o`;ooooo1Ol00?l?ooooo`Go
003o2Oooool5o`00o`Oooooo1Ol00?l:ooooo`?o003o1@000?l3ooooo`?o003o2?ooool30000o`04
ooooo`000?l0003o0000o`[ooooo1Ol00?l2ooooo`4000000Oooool0000300000?oooooooooo02Oo
oooo1_oo0003ooooo`?oo`0000?oooooool00?oo00000ol00?l30000o`?ooooo1Ol00?l6ooooo`D0
003o00?o003oooooooooool00ol00?l5ooooo`<0003o0_ooool50000o`Sooooo1@000?l4o`00o`03
ooooool00?oo003o00Oo003o1?ooool50000o`Kooooo0`000?l4o`00o`Kooooo0ol00?l5ooooo`03
o`00o`000?l0003o00<0003o2ol00?l?ooooo`Go003o0_ooool3o`00o`Gooooo1Ol00?l7ooooo`Oo
003o2?ooool3o`00o`D0003o0_ooool5o`00o`[ooooo1@000?l3o`00o`Kooooo1Ol00?l2ooooo`40
00000Oooool0000300000?oooooooooo02Sooooo1Ooo0002ooooo`Soo`0000?o003o0000o`000?l0
0`000?l2ooooo`Go003o0`000?l3ooooo`D0003o2_ooool50000o`03ooooo`000?l0003o00<0003o
00?o003oooooooooool01Oooool50000o`?o003o0`000?l8o`00o`Cooooo1@000?l5ooooo`D0003o
0_l00?l?ooooo`;o003o0`000?l00ooooooo003oo`00o`07o`00oa3ooooo1_l00?l00ooooooo003o
o`00o`03o`00o`Gooooo0ol00?l8ooooo`So003o2?ooool3o`00o`<0003o0oooool5o`00o`[ooooo
1@000?l4o`00o`Cooooo10000?l01Ol00?ooooooooooooooool00000007ooooo00000`00003ooooo
ool00002ool002Gooooo1_oo0002ooooo`Soo`0000?o003o0000o`000?l00`000?l3ooooo`?o003o
1@000?l2ooooo`D0003o2_ooool50000o`;ooooo0`000?l3o`00o`Oooooo0`000?l3o`00o`D0003o
1ol00?l4ooooo`D0003o1Oooool50000oa7ooooo1Ol00?l2ooooo`So003o3Oooool30000o`Ko003o
00?oooooo`00ool00?l01?l00?l@ooooo`Oo003o2oooool30000o`?ooooo1Ol00?l8ooooo`L0003o
1?l00?l3ooooo`H0003o0oooool10000007ooooo00000`00003oo`00ool00003ool002Cooooo1_oo
0002ooooo`Goo`0000Coooooool00?oo003o003o1@000?l6ooooo`D0003o0oooool30000o`_ooooo
1@000?l3ooooo`Go003o1Oooool30000o`;ooooo0ol00?l50000o`04o`00o`000?l0003o0000o`;o
003o1_ooool30000o`Kooooo1@000?l<ooooo`<0003o0oooool3o`00o`Kooooo1Ol00?l<ooooo`D0
003o1?l00?l00ooooooo003oo`00o`09o`00o`kooooo1Ol00?l4ooooo`?o003o0oooool50000o`?o
oooo0ol00?l8ooooo`L0003o1Ol00?l3ooooo`H0003o0oooool10000007ooooo00000`00003oo`00
ool00003ool002Cooooo1_oo0003ooooo`?oo`001Oooool01?l00?l0003o0000o`000?l7ooooo`D0
003o1Oooool3o`00o`[ooooo0`000?l4ooooo`Go003o1?ooool50000o`;ooooo0_l00?l:0000o`co
oooo0`000?l2ooooo`<0003o1?ooool30000o`Gooooo1@000?l<ooooo`Ko003o2_ooool50000o`?o
003o00?oooooo`00ool00?l02ol00?l3ooooo`<0003o2?ooool3o`00o`Cooooo1Ol00?l2ooooo`D0
003o3_ooool50000o`Ko003o1?ooool60000o`?ooooo0@000001ooooo`0000<00000ool00?oo0000
2Ooo000Mooooo`Koo`006?ooool30000o`Gooooo1Ol00?lAooooo`?o003o1Oooool50000o`Gooooo
0`000?l00ol00?l0003o0000o`030000o`;o003o1oooool2o`00o`D0003o1oooool50000o`Cooooo
1@000?l>ooooo`Go003o2Oooool50000o`;o003o0_ooool=o`00o`;ooooo1@000?l01?oooooo003o
o`00ool00?l:ooooo`Go003o0_ooool50000o`gooooo00?o003o0000o`000?l00`000?l5o`00o`Co
oooo0_l00?l40000o`Cooooo0@000001ooooo`0000<00000oooooooo00002_oo000@ooooo`?oo`00
2Oooool5ool00004oooooooo003oo`00ool001gooooo1Ol00?l8ooooo`?o003o3_ooool50000o`Ko
oooo0ol00?l50000o`?o003o1Oooool3o`00o`D0003o1oooool50000o`Cooooo1@000?l2ooooo`<0
003o0_l00?l7ooooo`Go003o2_ooool30000o`;o003o0oooool=o`00o`;ooooo1@000?l5o`00o`Wo
oooo1_l00?l2ooooo`<0003o3Oooool3o`00o`<0003o0_ooool3o`00o`Cooooo1Ol00?l6ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo2?oo000?ooooo`Goo`002?ooool:ool001cooooo
1Ol00?l7ooooo`Go003o3_ooool30000o`Oooooo1?l00?l30000o`Co003o1Oooool3o`00o`D0003o
1oooool50000o`;ooooo1P000?l00ol00?oooooo0000o`040000o`;o003o0oooool30000o`Go003o
2_ooool5o`00o`Cooooo0ol00?l3ooooo`Go003o0oooool50000o`Go003o2_ooool5o`00oa;ooooo
1Ol00?l4ooooo`?o003o0oooool6o`00o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
ool8ool000_ooooo0ooo00000oooooooo`00ool00003ool000Cooooo0ooo0002ooooo`?oo`0000?o
ooooool00?oo00000ooo000Mooooo`?o003o2?ooool5o`00oaWooooo0ol00?l2ooooo`Go003o0`00
0?l2ooooo`Co003o0`000?l9ooooo`<0003o0_ooool80000o`03o`00o`000?l0003o00<0003o0_l0
0?l2ooooo`D0003o0ol00?l;ooooo`Go003o2_ooool5o`00o`Cooooo0`000?l00ooooooo003oo`00
o`06o`00o`Oooooo00Go003o0000o`000?l0003oo`00o`0Booooo`Go003o0oooool5o`00o`;ooooo
1ol00?l4ooooo`4000000Oooool0000300000?oooooooooo00?ooooo1ooo000:ooooo`[oo`0000?o
ooooool00?oo00001Ooo0005ooooo`Goo`000oooool3ool000?o003o7oooool5o`00oaoooooo0ol0
0?l50000o`;ooooo0ol00?lAooooo`P0003o00?o003o0000o`000?l00`000?l2o`00o`;ooooo1@00
0?l?ooooo`?o003o2?ooool3o`00o`03ooooool00?oo003o00?o003o2?ooool5o`00o`<0003o1_oo
ool50000o`oooooo0`000?l01?oooooo003oo`00ool00?l4ooooo`Go003o0oooool6o`00o`Cooooo
0@000001ooooo`0000<00000ooooooooool00_ooool3ool00004oooooooo003oo`00ool000_ooooo
1Ooo00001Oooooooo`00ool00?oo003ooooo00Soo`001_ooool3ool000?ooooo0ooo0005o`00o`[o
oooo0ol00?lBooooo`?o003o2?ooool3o`00oa3ooooo0ol00?l2ooooo`?o003o1`000?lDooooo`P0
003o0_l00?l30000o`;o003o0oooool50000oaWooooo1Ol00?l00ooooooo003oo`00o`03o`00o`[o
oooo00?o003o0000o`000?l00`000?l5ooooo`D0003o3_ooool50000o`Oooooo1Ol00?l4ooooo`Go
003o1?ooool10000007ooooo00001000003oooooooooooooool5ool000kooooo1Ooo0004ooooo`Wo
o`001Oooool3ool000Cooooo0ooo0005o`00o`Wooooo1Ol00?lKooooo`Go003o3?ooool30000o`Co
003o0_ooool2o`00o`P0003o5?ooool60000o`?o003o0oooool30000o`?ooooo0`000?l8ooooo`<0
003o3oooool5o`00o`03ooooool00?oo003o00?o003o2_ooool00ol00?l0003o0000o`030000o`?o
003o00?oooooo`00o`000?l010000?l01?oooooo003oo`00ool00?l:ooooo`D0003o2?ooool5o`00
o`Cooooo0ol00?l5ooooo`4000000Oooool0000400000?ooooooooooooooo`Goo`001?ooool3ool0
00Sooooo0ooo0004ooooo`Woo`001Oooool5ool000?ooooo0ooo0005o`00o`Kooooo0`000?l5o`00
o`[ooooo0ol00?l5ooooo`?o003o1_ooool5o`00o`[ooooo00?o003o0000o`000?l00`000?l3o`00
o`Gooooo1`000?lIooooo`?o003o0oooool50000o`Kooooo0`000?l3ooooo`H0003o3Oooool5o`00
o`03ooooool00?oo003o00?o003o0oooool3o`00o`Gooooo1@000?l6o`00o`<0003o00?oooooo`00
ool00?l00ol00?l9ooooo`D0003o00?o003oooooooooool01_ooool5o`00o`_ooooo0@000001oooo
o`0000@00000oooooooooooooooo3Ooo000>ooooo`Koo`002?ooool5ool000Cooooo0ooo0003o`00
o`Kooooo1@000?l5o`00o`Sooooo1Ol00?l3ooooo`Go003o1Oooool5o`00o`Wooooo0_l00?l50000
o`?o003o1oooool50000o`Kooooo0ol00?lFooooo`D0003o1Oooool50000o`;ooooo1`000?l3oooo
o`?o003o1oooool9o`00o`?ooooo1Ol00?l5ooooo`<0003o2_l00?l30000o`?o003o2Oooool50000
o`;o003o1oooool5o`00o`<0003o2?ooool10000007ooooo00000`00003oooooooooo`02ooooo`go
o`002oooool7ool000Wooooo1Ooo000@ooooo`D0003o1_l00?l2ooooo`Co003o00?oooooo`00ool0
0?l00ol00?l3ooooo`Go003o1Oooool4o`00o`[ooooo0_l00?l50000o`;o003o2Oooool30000o`Ko
oooo1Ol00?lAooooo`<0003o00?ooooo0000o`000?l00`000?l5ooooo`D0003o0_ooool70000o`;o
oooo1Ol00?l4ooooo`[o003o1?ooool5o`00o`Sooooo1Ol00?l01?oooooo003oo`00ool00?l50000
o`;o003o2Oooool50000o`;o003o1oooool4o`00o`D0003o1oooool10000007ooooo00000`00003o
ooooooooo`05ooooo`[oo`002_ooool7ool000_ooooo0ooo000Aooooo`H0003o1Ol00?l00ooooooo
003oo`00o`09o`00o`?ooooo1Ol00?l4ooooo`Go003o2_ooool3o`00o`D0003o0_l00?lAooooo`Ko
003o0`000?l<ooooo`D0003o00Cooooo0000o`000?l0003o1_ooool50000o`?ooooo1P000?l2oooo
o`Go003o0oooool<o`00o`?ooooo1Ol00?l9ooooo`?o003o1Oooool50000o`03o`00oooooooooooo
00Sooooo1@000?l2o`00o`Sooooo0ol00?l50000o`Oooooo0@000001ooooo`0000<00000oooooooo
ool01Oooool;ool000Wooooo1Ooo0006ooooo`?oo`006?ooool00ol00?l0003o0000o`030000o`Go
003o00?oooooo`00ool00?l01?l00?l01?oooooo003oo`00ool00?l5ooooo`?o003o1Oooool5o`00
o`Cooooo0ol00?l3ooooo`?o003o1P000?l2o`00oa3ooooo1Ol00?l50000o`Oooooo0ol00?l00ooo
ool0003o0000o`030000o`_ooooo0`000?l6ooooo`<0003o0oooool5o`00o`?ooooo3?l00?l4oooo
o`Co003o4Oooool50000o`Kooooo0ol00?l3ooooo`<0003o0_l00?l<ooooo`D0003o1oooool10000
007ooooo00000`00003oooooool00002ool000Cooooo0ooo0002ooooo`Koo`002?ooool5ool000Go
oooo1Ooo00001?ooooooo`00ool00?oo000Booooo`L0003o00Coooooo`00ool00?oo003o0_ooool6
o`00o`Wooooo0`000?l01Ooooooo003oo`00ool00?oooooo00Go003o0oooool5o`00o`?ooooo00?o
003o0000o`000?l01@000?l2o`00oa7ooooo1?l00?l50000o`Kooooo1Ol00?l50000o`03o`00oooo
oooooooo00Sooooo0ol00?l=ooooo`?o003o1?ooool<o`00o`Cooooo1Ol00?l8ooooo`?o003o1_oo
ool30000o`Gooooo1_l00?lDooooo`<0003o2?ooool10000007ooooo00000`00003oo`00ool00003
ool000Wooooo1Ooo0009ooooo`?oo`001_ooool:ool0013ooooo1`000?l8ooooo`Co003o2Oooool5
0000o`So003o1?ooool6o`00o`?ooooo1`000?l2o`00oa?ooooo0_l00?l50000o`Kooooo1Ol00?l0
1?ooool0003o0000o`000?l3o`00o`Sooooo1Ol00?lBooooo`So003o00?oooooo`00ool00?l00_l0
0?l4ooooo`Go003o1oooool5o`00o`cooooo1ol00?lOooooo`4000000Oooool0000300000?oo003o
o`0000?oo`002Oooool5ool001;ooooo2_oo000?ooooo`03o`00o`000?l0003o00<0003o5oooool5
0000o`Wo003o0oooool6o`00o`?ooooo1P000?l2o`00oaGooooo0_l00?l30000o`Oooooo1Ol00?l2
ooooo`Go003o1oooool6o`00oa7ooooo2?l00?l2ooooo`Go003o0oooool5o`00o`Oooooo1Ol00?l<
ooooo`Oo003o4Oooool3o`00o`_ooooo0@000001ooooo`0000<00000ool00?oo00000ooo000:oooo
o`?oo`005?ooool3ool00003oooooooo003oo`0000?oo`002?ooool2ool000?o003o00?oooooo`00
ool00?l01@000?l:ooooo`?o003o2_ooool50000o`Wo003o1?ooool5o`00o`Cooooo0`000?l2o`00
o`;ooooo0ol00?lNooooo`Go003o0_ooool5o`00o`Kooooo1ol00?l01?oooooo003oo`00ool00?l=
ooooo`Go003o0oooool7o`00o`Cooooo0ol00?l8ooooo`Go003o3?ooool6o`00o`kooooo2?l00?l:
ooooo`4000000Oooool0000300000?ooooooo`0000;oo`009oooool3ool000Sooooo0_oo0008o`00
o`<0003o2_ooool5o`00o`[ooooo0`000?l:o`00o`Gooooo0ol00?l6ooooo`[o003o4?ooool30000
o`[ooooo1Ol00?l3ooooo`?o003o1oooool6o`00o`03ooooool00?oo003o00?o003o2_ooool30000
o`Co003o0_ooool8o`00oa3ooooo1Ol00?l<ooooo`?o003o3oooool9o`00o`[ooooo0@000001oooo
o`0000<00000ooooooooool01Oooool3ool001gooooo0ooo00001?ooooooo`00ool00?oo0008oooo
o`;oo`002_l00?l;ooooo`Go003o3Oooool3o`00o`03ooooool00?oo003o00?o003o3oooool4o`00
o`@0003o0_l00?l01?oooooo003oo`00ool00?l;ooooo`D0003o2Oooool5o`00o`?ooooo0ol00?l7
ooooo`05o`00o`000?l0003o0000ool00?l00_ooool5o`00o`Wooooo1@000?l2o`00o`?ooooo2Ol0
0?l:ooooo`?o003o0oooool5o`00oaCooooo0_l00?l30000o`Cooooo2Ol00?l:ooooo`4000000Ooo
ool0000300000?oooooooooo00Cooooo1Ooo000Jooooo`[oo`001oooool2ool000Go003o00Cooooo
o`00ool00?oo003o3?ooool5o`00o`kooooo0`000?l9ooooo`?o003o2?ooool3o`00o`H0003o1ol0
0?l9ooooo`D0003o2_ooool3o`00o`;ooooo1_l00?l5ooooo`03o`00o`000?l0003o00<0003o0_oo
ool5o`00o`Wooooo1@000?l4ooooo`<0003o2?l00?l8ooooo`Go003o0_ooool5o`00o`Wooooo0ol0
0?l7ooooo`;o003o1@000?l2ooooo`Wo003o2oooool10000007ooooo00000`00003oooooooooo`04
ooooo`Goo`003oooool3ool000Oooooo2ooo0008ooooo`;oo`000ol00?lBooooo`?o003o1?ooool3
0000o`Oooooo1@000?l7ooooo`Go003o2?ooool2o`00o`H0003o2?l00?l5ooooo`?o003o1@000?l>
ooooo`Oo003o1?ooool2o`00o`D0003o0_ooool5o`00o`Wooooo1@000?l3ooooo`D0003o00?o003o
ooooool00?l01?l00?l8ooooo`Go003o0_ooool5o`00o`Sooooo1Ol00?l6ooooo`;o003o1@000?l2
ooooo`Oo003o3Oooool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`003_ooool5ool0
00Kooooo2ooo000Uooooo`D0003o1_ooool50000o`;ooooo0ol00?l2ooooo`Go003o2_ooool60000
o`03ooooool00?oo003o00Go003o1?ooool5o`00o`<0003o1oooool30000o`Gooooo1ol00?l4oooo
o`;o003o1@000?l3ooooo`Ko003o1?ooool4o`00o`<0003o00Co003ooooooooooooooooo1@000?l2
ooooo`Go003o2?ooool5o`00o`?ooooo1?l00?l8ooooo`Go003o1_ooool2o`00o`D0003o0_ooool5
o`00o`oooooo0@000001ooooo`0000<00000ooooooooool01Oooool3ool000oooooo1Ooo0006oooo
o`_oo`001?ooool3ool001Wooooo0`000?l2ooooo`D0003o1_ooool50000o`03ooooool00?oo003o
00?o003o00?oooooo`00ool00?l00ol00?l;ooooo`@0003o0oooool7o`00o`?ooooo1Ol00?l9oooo
o`D0003o0oooool7o`00o`Gooooo0ol00?l30000o`;o003o1?ooool5o`00o`;ooooo2?l00?l4oooo
o`D0003o00?o003oooooooooool00ol00?l7ooooo`Ko003o1?ooool5o`00o`Oooooo1_l00?l6oooo
o`03o`00o`000?l0003o00<0003o0oooool3o`00o`Oooooo0ol00?l6ooooo`4000000Oooool00003
00000?oooooooooo01Oooooo1Ooo0006ooooo`Coo`000_ooool7ool00003oooooooo003oo`0000?o
o`005oooool50000o`03ooooo`000?l0003o00<0003o0ol00?l4ooooo`<0003o0_ooool5o`00o`;o
oooo0ol00?lEooooo`Go003o0oooool5o`00o`Wooooo1@000?l3ooooo`Go003o2?ooool7o`00o`Co
oooo1Ol00?l2ooooo`Go003o2?ooool30000o`;o003o2oooool5o`00o`;ooooo0`000?l00ooooooo
003oo`00o`03o`00o`Sooooo1Ol00?l7ooooo`04o`00o`000?l0003o0000o`gooooo1Ol00?l5oooo
o`4000000Oooool0000300000?oooooooooo01Sooooo0ooo0006ooooo`Goo`000oooool<ool001?o
oooo0ol00?l00oooool0003o0000o`030000o`;ooooo0`000?l5o`00o`Sooooo1Ol00?lEooooo`?o
003o0_ooool5o`00o`?ooooo1ol00?l01?ooool0003o0000o`000?l2ooooo`H0003o0oooool5o`00
o`[ooooo1Ol00?l4ooooo`Go003o0_ooool5o`00o`Sooooo1Ol00?l;ooooo`Go003o00?ooooo0000
o`000?l00`000?l5o`00o`Sooooo1?l00?l30000o`Cooooo1Ol00?l<ooooo`<0003o0ol00?l5oooo
o`4000000Oooool0000300000?oooooooooo00?ooooo0ooo000Kooooo`Ooo`000_ooool;ool0017o
oooo1_l00?l50000o`Gooooo1?l00?l30000o`Kooooo1Ol00?l6ooooo`?o003o1_ooool3o`00o`;o
oooo1Ol00?l2ooooo`?o003o0oooool8o`00o`/0003o1Oooool3o`00o`Cooooo1Ol00?l3ooooo`?o
003o1_ooool3o`00o`Cooooo0ol00?l3ooooo`?o003o1?ooool3o`00o`cooooo1Ol00?l00oooool0
003o0000o`030000o`Go003o2Oooool2o`00o`D0003o0oooool5o`00o`_ooooo1@000?l2o`00o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_ooool5ool001[ooooo3ooo00001?ooooooo`00
ool00?oo0006ooooo`<0003o2?ooool7o`00o`04ooooo`000?l0003o0000o`Kooooo0ol00?l50000
o`Kooooo1?l00?l5ooooo`Go003o0_ooool7o`00o`03ooooool00?oo003o00?o003o1Oooool6o`00
o`<0003o0_l00?l:0000o`cooooo1ol00?l3ooooo`<0003o3Oooool3o`00o`03ooooool00?oo003o
00?o003o4_ooool4o`00o`;ooooo1@000?l5o`00o`[ooooo1P000?l3ooooo`Go003o1?ooool3o`00
o`Cooooo1@000?l00ol00?ooooooooooo`04ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1Ooo000Kooooo`goo`002_ooool50000o`Oooooo1ol00?l;ooooo`;o003o1@000?l6ooooo`Go
003o1?ooool5o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l00ol00?l4ooooo`Ko
003o1@000?l00ol00?l0003o0000o`080000o`Wooooo2_l00?l2ooooo`D0003o0_ooool3o`00o`Ko
oooo2_l00?lAooooo`Go003o0oooool30000o`;ooooo1_l00?l7ooooo`L0003o1?ooool3o`00o`Co
oooo1Ol00?l3ooooo`D0003o1oooool10000007ooooo00000`00003oooooooooo`07ool001gooooo
2ooo0009ooooo`03o`00o`000?l0003o00<0003o1oooool7o`00o`Wooooo0ol00?l00oooool0003o
0000o`030000o`Kooooo1Ol00?l4ooooo`Go003o00?oooooo`00ool00?l01_l00?l2ooooo`?o003o
00Goooooo`00ool00?oo003oooooo`06o`00o`D0003o00?o003oooooo`000?l00P000?l2ooooo`<0
003o2Oooool;o`00o`;ooooo1@000?l00ooooooo003oo`00o`03o`00o`Gooooo2_l00?lAooooo`Go
003o0_ooool30000o`Gooooo1Ol00?l6ooooo`H0003o3?ooool5o`00o`?ooooo00Co003o0000o`00
0?l0003o2?ooool10000007ooooo00000`00003oooooool00006ool001oooooo2Ooo000:ooooo`03
o`00o`000?l0003o00<0003o2?ooool6o`00o`Cooooo0`000?l00ooooooo003oo`00o`03o`00o`04
ooooo`000?l0003o0000o`Gooooo1ol00?l5ooooo`?o003o0_ooool7o`00o`Kooooo2ol00?l50000
o`?o003o1Oooool3o`00o`Sooooo2_l00?l3ooooo`D0003o00?oooooo`00ool00?l00ol00?l5oooo
o`Wo003o1oooool3o`00o`?ooooo0ol00?l2ooooo`Go003o00?ooooo0000o`000?l00`000?l4oooo
o`Go003o0_ooool3o`00o`03ooooo`000?l0003o00<0003o3?ooool6o`00o`;ooooo1Ol00?l8oooo
o`4000000Oooool0000300000?ooooooo`0000Coo`006Oooool3ool000Wooooo0ooo000<ooooo`;o
003o0`000?l:ooooo`Go003o0oooool50000o`[o003o0oooool7o`00o`Wooooo1_l00?l4ooooo`?o
003o0_ooool5o`00o`04ooooool00?oo003oo`00o`;ooooo00Co003o0000o`000?l0003o1Ol00?l3
ooooo`Go003o1oooool9o`00o`Gooooo0`000?l2ooooo`;o003o0`000?l6ooooo`?o003o00Cooooo
o`00ool00?oo003o1oooool5o`00o`03ooooool00?oo003o00?o003o0_ooool3o`00o`L0003o1?oo
ool5o`00o`03ooooool00?oo003o00;o003o1@000?l=ooooo`?o003o0`000?l2ooooo`<0003o0_l0
0?l4ooooo`<0003o0Oooool10000007ooooo00000`00003oooooool00004ool001Sooooo1Ooo0005
ooooo`?oo`004?ooool3o`00o`Oooooo0`000?l2ooooo`?o003o1?ooool50000o`co003o00?ooooo
o`00ool00?l00ol00?l:ooooo`Go003o1Oooool5o`00o`03ooooool00?oo003o00;o003o0`000?l6
ooooo`<0003o1?l00?l3ooooo`Go003o2?ooool8o`00o`_ooooo1@000?lCooooo`Go003o00?ooooo
o`00ool00?l00ol00?l4ooooo`P0003o1Oooool3o`00o`;ooooo1?l00?l50000o`Cooooo0ol00?l6
ooooo`;o003o2P000?l3o`00o`03ooooo`000?l0003o00<0003o0@000001ooooo`0000<00000oooo
ooooool00ooo000=ooooo`?oo`002Oooool5ool000Cooooo1Ooo000@ooooo`<0003o1Oooool50000
o`Sooooo1@000?l01Ooooooo003oo`00ool00?oooooo00go003o00?oo`00ooooooooool01oooool5
o`00o`Gooooo1Ol00?l2ooooo`;o003o1@000?l3ool00003ooooo`000?l0003o00<0003o0ol00?l3
ooooo`Go003o2oooool5o`00o`_ooooo1@000?lCooooo`Go003o00?oooooo`00ool00?l00ol00?l4
ooooo`L0003o2oooool4o`00o`D0003o0oooool5o`00o`Kooooo00?o003o0000o`000?l020000?l4
o`00o`D0003o0@000001ooooo`0000<00000ooooooooool01?ooool3ool000Sooooo1Ooo0008oooo
o`Goo`001?ooool6ool000kooooo1@000?l4ooooo`D0003o1oooool2ool000<0003o0ooo0004oooo
o`Oo003o00Coooooo`00ool00?oo003o0ooo0007ooooo`03ool00?l00?oo003o00?o003o1Oooool5
o`00o`Cooooo1@000?l4ool000D0003o0_l00?l01Oooooooo`00ool00?oo003ooooo00?o003o2?oo
ool3ool000;ooooo0ol00?l<ooooo`D0003o4oooool01Ooo003o003oo`00ool00?ooo`0000;ooooo
0ol00?l5ooooo`D0003o1_ooool3o`00o`Gooooo1?l00?l30000o`?ooooo1_l00?l7ooooo`X0003o
1?l00?l50000o`4000000Oooool0000300000?oooooooooo00?ooooo1Ooo0007ooooo`Goo`002Ooo
ool3ool000Gooooo1ooo0006ooooo`?oo`001?ooool50000o`Cooooo1@000?l7ooooo`coo`000_oo
ool5o`00o`[oo`000oooool3ool000?o003o1oooool3o`00o`Gooooo1@000?l4ool000D0003o0_oo
ool5ool000Sooooo1ooo000Aooooo`<0003o1_ooool3ool000_ooooo1Ooo0006ooooo`?oo`000_oo
ool30000o`Kooooo1Ol00?l4ooooo`Oo003o0oooool6o`00o`04ooooool00?oo003oo`00o`Cooooo
0`000?l2o`00o`<0003o1Ol00?l01_ooool0003o0000o`000?oooooo0000007ooooo00000`00003o
ooooooooo`03ooooo`Goo`001oooool5ool000[ooooo0ooo0005ooooo`Ooo`001?ooool5ool000?o
oooo1@000?l5ooooo`<0003o2?ooool=ool000;ooooo0ol00?l<ool000;ooooo1Ooo000Aooooo`<0
003o1Ooo00001?ooool0003o0000o`000?l3ooooo`Goo`001oooool;ool001Kooooo1Ooo000:oooo
o`Goo`001Oooool5ool000[ooooo1Ol00?l4ooooo`So003o0_ooool5o`00o`03ooooool00?oo003o
00?o003o1_ooool3o`00o`?ooooo0ol00?l6ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1_oo0008ooooo`?oo`002_ooool5ool000Gooooo1ooo0003ooooo`Goo`001?ooool30000oa;o
oooo3?oo0005ooooo`coo`000_ooool5ool001Gooooo0ooo0008ooooo`Goo`001oooool<ool001Go
oooo1Ooo000;ooooo`?oo`001?ooool7ool000[ooooo1ol00?l00ooooooo003oo`00o`0>o`00o`03
ooooool00?l0003o0080003o00?o003oooooooooool01Oooool3o`00o`03ooooool00?oo003o00?o
003o1Oooool10000007ooooo00001000003oooooooooooooool6ool001Kooooo1Ooo0006ooooo`Ko
o`000oooool5ool000?ooooo1Ooo000Eooooo`Woo`001?ooool5ool000;ooooo1Ooo0003ooooo`?o
o`003_ooool3ool0017ooooo0ooo0008ooooo`coo`005Oooool6ool0013ooooo2?oo000;oooooaKo
003o0_ooool50000o`03o`00oooooooooooo00H0003o1ol00?l5ooooo`4000000Oooool000040000
0?ooooooooooooooo`Goo`005oooool5ool000Oooooo1Ooo0004ooooo`?oo`001?ooool5ool000So
oooo0ooo0009ooooo`?oo`000_ooool6ool000Cooooo0ooo0004ooooo`?oo`0000Coooooool00?oo
003oo`004?ooool5ool001cooooo1Ooo00000oooooooo`00ool00004ool000Sooooo1_oo0007oooo
o`Koo`003_ooool8ool000kooooo4_l00?l4ooooo`D0003o0_l00?l80000o`Ko003o1Oooool10000
007ooooo00001000003oooooooooooooool5ool000Gooooo0ooo000@ooooo`Goo`001oooool3ool0
00cooooo1Ooo0007ooooo`Goo`001oooool5ool000;ooooo1Ooo000>ooooo`Goo`003oooool5ool0
00Wooooo0ooo000Gooooo`Koo`000_ooool3ool00003oooooooo003oo`0000Koo`001oooool5ool0
00gooooo1ooo000@ooooo`Go003o00?oooooo`00ool00?l00_l00?l3ooooo`Go003o0oooool00ol0
0?l0003o0000o`030000o`;o003o20000?l00ol00?ooooooo`00o`02o`00o`Kooooo0@000001oooo
o`0000<00000ooooooooool01_oo0004ooooo`Goo`004?ooool5ool001Kooooo0ooo0008ooooo`Go
o`001oooool6ool00003oooooooo003oo`0000?oo`003_ooool5ool000oooooo1_oo0007ooooo`Go
o`005ooooolCool000Oooooo1Ooo000=ooooo`Soo`004?ooool3o`00o`[ooooo1Ol00?l2ooooo`;o
003o0`000?l3o`00o`P0003o2oooool10000007ooooo00000`00003oooooooooo`06ool000Cooooo
2?oo000=ooooo`Goo`008Oooool5ool000Oooooo2ooo000?ooooo`Goo`004?ooool9ool000?ooooo
1Ooo000Goooooa?oo`002?ooool3ool000kooooo2Ooo000>ooooo`?o003o3?ooool5o`00o`03oooo
ool00?oo003o00Go003o0_ooool60000o`04ooooool00?oo003oo`00o`Sooooo0@000001ooooo`00
00<00000ooooooooool02?oo0002ooooo`[oo`002oooool5ool000Gooooo0ooo000Jooooo`?oo`00
1_ooool=ool0013ooooo0ooo000Aooooo`[oo`000_ooool5ool001Sooooo2_oo00000oooooooo`00
ool00004ool000kooooo0ooo0006ooooo`?oo`0000?oooooool00?oo00001ooo000<ooooo`Go003o
2oooool5o`00o`;ooooo0ol00?l;ooooo`Go003o1oooool10000007ooooo00001000003ooooooooo
ooooool8ool000;ooooo2_oo000;ooooo`?oo`001Oooool5ool0027ooooo3_oo000Pooooo`?oo`00
0_ooool9ool000?ooooo1_oo000Hooooo`Ooo`005Oooool5ool000Cooooo1Ooo0003ooooo`Koo`00
00Cooooo0000o`000?l0003o2?ooool5o`00o`_ooooo2Ol00?l<ooooo`Go003o1oooool10000007o
oooo00000`00003oooooooooo`04ooooo`Goo`001Oooool7ool000Sooooo0ooo0008ooooo`Goo`00
8Oooool=ool0023ooooo1Ooo0002ooooo`Soo`001Oooool5ool001Sooooo0ooo000Fooooo`Ooo`00
1?ooool5ool000Cooooo1Ooo00050000o`Oooooo1Ol00?l<ooooo`Wo003o2oooool5o`00o`Oooooo
0@000001ooooo`0000<00000ooooooooool01?ooool5ool000Kooooo1_oo0006ooooo`Koo`001ooo
ool5ool000_ooooo0ooo0006ooooo`?oo`002_ooool9ool002Cooooo1Ooo0006ooooo`?oo`001_oo
ool5ool0033ooooo2?oo0004ooooo`Goo`000oooool6ool000D0003o2?ooool6o`00o`cooooo1ol0
0?l<ooooo`?o003o2?ooool10000007ooooo00001000003oo`00ool00?oo0004ooooo`?oo`002Ooo
ool5ool000Cooooo1ooo0003ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000Oooooo
1Ooo0004ooooo`Goo`001oooool>ool0027ooooo1Ooo000<ooooo`Soo`007oooool3ool000kooooo
1ooo0006ooooo`?oo`000oooool7ool000D0003o2Oooool6o`00o`_ooooo1ol00?lGooooo`400000
0Oooool000Goo`004?ooool5ool000?ooooo3_oo0004ooooo`Goo`001_ooool5ool000Cooooo1_oo
0005ooooo`Goo`000_ooool9ool0027ooooo1Ooo000:ooooo`Soo`007oooool5ool000Gooooo0ooo
0005ooooo`Goo`003_ooool8ool000D0003o0ol00?l4ooooo`Oo003o3?ooool5o`00oaSooooo0@00
0001ooooo`001Ooo000@ooooo`Goo`000oooool?ool000?ooooo1_oo0005ooooo`Goo`001?ooool6
ool000Gooooo1Ooo0002ooooo`Woo`008_ooool6ool000Oooooo1_oo00001?ooooooo`00ool00?oo
0005ooooo`?oo`005_ooool5ool000?ooooo1_oo0004ooooo`Goo`003_ooool5ool00003oooooooo
003oo`0000D0003o1?l00?l3ooooo`Oo003o4?ooool3o`00oaKooooo0@000001ooooo`001Ooo000@
ooooo`Goo`001?ooool3ool000;ooooo2_oo0002ooooo`Ooo`001Oooool3ool000;ooooo2Ooo0005
ooooo`Goo`000oooool8ool002;ooooo1ooo0006ooooo`_oo`000oooool5ool001Gooooo1Ooo0002
ooooo`Ooo`001Oooool3ool0013ooooo0ooo00001?ooooooo`00ool00?oo00050000o`Co003o0ooo
ool6o`00o`04ooooo`000?l0003o0000o`Oooooo0`000?l2ooooo`Go003o5Oooool10000007ooooo
00001000003oo`00ool00?oo000Booooo`?oo`002_ooool:ool000?ooooo1_oo0009ooooo`coo`00
1?ooool5ool000Kooooo0ooo0002ooooo`?oo`002?ooool3ool000;ooooo0ooo000=ooooo`Soo`00
1_ooool5ool00003oooooooo003oo`0000?oo`000oooool6ool001Cooooo1Ooo0002ooooo`Ooo`00
7?ooool4ool000<0003o1Ol00?l00ooooooo003oo`00o`04o`00o`;ooooo1@000?l5ooooo`D0003o
00?oooooo`00ool00?l00ol00?lEooooo`4000000Oooool0000300000?oooooooooo027ooooo0ooo
00000oooooooo`00ool00003ool000Cooooo1Ooo0009ooooo`goo`001?ooool5ool000;ooooo0ooo
0002ooooo`Ooo`001_ooool:ool000cooooo2?oo0006ooooo`_oo`000oooool7ool001?ooooo1Ooo
0002ooooo`Koo`005?ooool3ool000Kooooo1Ooo0003ooooo`?o003o00?oooooo`00ool00?l01Ol0
0?l2ooooo`D0003o1Oooool50000o`03ooooool00?oo003o00?o003o4Oooool3o`00o`7ooooo0@00
0001ooooo`0000@00000ool00?oo003oo`009Oooool3ool000Kooooo0ooo00001?ooooooo`00ool0
0?oo0006ooooo`goo`001?ooool5ool00003oooooooo003oo`0000_oo`001_ooool:ool000cooooo
2?oo0006ooooo`_oo`001?ooool6ool001?ooooo1Ooo0002ooooo`Goo`005?ooool5ool000Kooooo
0ooo0003ooooo`co003o0_ooool50000o`Gooooo1@000?l2ooooo`?o003o4Oooool5o`00o`400000
0Oooool000Goo`006oooool3ool0013ooooo1ooo0006ooooo`Koo`0000?oooooool00?oo00000ooo
0002oooooaGoo`001_ooool;ool000cooooo1ooo0006ooooo`coo`001?ooool5ool000oooooo0ooo
0002ooooo`?oo`000oooool5ool000Gooooo0ooo000<ooooo`Goo`0000Coooooool00?oo003oo`00
1oooool=o`00o`?ooooo0`000?l7ooooo`<0003o3Oooool3o`00o`Oooooo1Ol00?l10000007ooooo
0005ool001[ooooo1Ooo000>ooooo`Soo`003_ooool3ool000;ooooo5Ooo0008ooooo`?oo`000_oo
ool6ool000Wooooo0ooo00000oooooooo`00ool00003ool000Oooooo2ooo0005ooooo`?oo`003ooo
ool5ool000Oooooo1Ooo0004ooooo`Goo`002oooool:ool000Kooooo3?l00?lMooooo`Go003o1_oo
ool5o`00o`4000000Oooool000Goo`006_ooool5ool00004oooooooo003oo`00ool000[ooooo2?oo
000Coooooa;oo`004Oooool5ool000Sooooo1Ooo00001?ooooooo`00ool00?oo000:ooooo`Woo`00
4_ooool3ool000;ooooo1Ooo0008ooooo`?oo`001Oooool5ool00004oooooooo003oo`00ool000So
oooo0ooo00000oooooooo`00ool00003ool000Kooooo2?l00?lQooooo`Go003o1oooool3o`00o`7o
oooo0@000001ooooo`0000<00000ool00?oo00001_oo000Fooooo`[oo`002Oooool7ool0017ooooo
3Ooo00000oooooooo`00ool00005ool0017ooooo1Ooo0008ooooo`Goo`004?ooool6ool001;ooooo
2ooo000@ooooo`[oo`002oooool5ool000;ooooo0ooo0002ooooo`Ko003o1oooool6o`00oaGooooo
1Ol00?l;ooooo`4000000Oooool0000300000?oo003oo`0000Ooo`005Oooool:ool000Wooooo1_oo
000Aooooo`Soo`000_ooool3ool000;ooooo2?oo0008ooooo`?oo`001_ooool3ool00004oooooooo
003oo`00ool000Gooooo1Ooo000@ooooo`Goo`000oooool3ool000gooooo2_oo000Booooo`?oo`00
00?oooooool00?oo00000ooo0007ooooo`?oo`000_ooool3ool000;ooooo1Ooo000=ooooo`So003o
2Oooool3o`00o`Wooooo0ol00?l01?oooooo003oo`00ool00?l8ooooo`4000000Oooool000030000
0?oo003oo`0000Ooo`005Oooool:ool000Wooooo1_oo000Aooooo`Goo`002oooool7ool000Oooooo
1_oo0007ooooo`Goo`001Oooool3ool0017ooooo1Ooo0002ooooo`Goo`002Oooool:ool001Wooooo
1Ooo0006ooooo`Goo`001_ooool5ool000gooooo2?l00?l8ooooo`Go003o2oooool5o`00o`Oooooo
0@000001ooooo`0000<00000oooooooo00001ooo0002ooooo`?oo`001_ooool3ool000Oooooo1Ooo
00001?ooooooo`00ool00?oo000;ooooo`Coo`004_ooool5ool000Sooooo2_oo00001?ooooooo`00
ool00?oo0003ooooo`Ooo`001_ooool5ool000_ooooo0ooo000;ooooo`Goo`000_ooool5ool000So
oooo2ooo000Jooooo`?oo`001oooool5ool000Kooooo1Ooo000=ooooo`So003o2?ooool6o`00o`[o
oooo1Ol00?l7ooooo`4000000Oooool0000300000?oooooooooo00?ooooo0ooo0002ooooo`Goo`00
1?ooool5ool000Oooooo0ooo0005ooooo`?oo`001oooool5ool000Gooooo0ooo0007ooooo`?oo`00
00Coooooool00?oo003oo`000oooool3ool000;ooooo2_oo00000oooooooo`00ool00003ool000;o
oooo1ooo0006ooooo`Goo`002_ooool5ool000_ooooo0ooo0003ooooo`Goo`002?ooool5ool000;o
oooo0ooo0003ooooo`?oo`007oooool5ool000Oooooo0ooo000?ooooo`Go003o0`000?l7ooooo`Oo
003o2Oooool5o`00o`Oooooo0@000001ooooo`0000<00000ooooooooool02?ooool5ool000Cooooo
1Ooo000>ooooo`Goo`001_ooool5ool000Cooooo1Ooo0005ooooo`Goo`001Oooool5ool00003oooo
oooo003oo`0000Koo`000oooool5ool000?ooooo1_oo0006ooooo`Goo`002_ooool7ool0013ooooo
0ooo0008ooooo`Koo`001oooool5ool001oooooo0ooo0002ooooo`?oo`003Oooool30000o`Sooooo
00?o003o0000o`000?l00`000?l3ooooo`?o003o00?oooooo`00ool00?l01?l00?l8ooooo`Go003o
2?ooool10000007ooooo00000`00003oooooooooo`08ooooo`Goo`001?ooool5ool000kooooo1Ooo
0006ooooo`Goo`0000?oooooool00?oo00001_oo0005ooooo`Goo`001Oooool5ool00003oooooooo
003oo`0000?oo`001?ooool7ool000Gooooo1_oo0004ooooo`Goo`002_ooool8ool001[ooooo1Ooo
0008ooooo`Goo`003?ooool3ool001Cooooo1Ooo000;ooooo`D0003o00Cooooo0000o`000?l0003o
1?ooool50000o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Kooooo1ol00?l8ooooo`400000
0Oooool0000300000?oooooooooo00Cooooo0ooo0002ooooo`?oo`001_ooool3ool000_ooooo0ooo
00000oooooooo`00ool00003ool000Kooooo1?oo00000oooooooo`00ool00007ool000Gooooo1Ooo
0005ooooo`Koo`0000Coooooool00?oo003oo`000_ooool9ool000Sooooo1Ooo0004ooooo`?oo`00
3?ooool7ool000Cooooo0ooo000Cooooo`Goo`002?ooool5ool000;ooooo0ooo0006ooooo`Goo`00
2oooool3ool000Gooooo1Ooo0008ooooo`?o003o2P000?l3ooooo`D0003o0_ooool5o`00o`;ooooo
0ol00?l6ooooo`So003o2?ooool10000007ooooo00000`00003oooooooooo`03ooooo`Goo`005ooo
ool5ool00004oooooooo003oo`00ool000Kooooo1Ooo00000oooooooo`00ool00006ool000Oooooo
0ooo0006ooooo`Koo`001Oooool8ool000[ooooo2?oo0005ooooo`?oo`001Oooool4ool00003oooo
oooo003oo`0000Coo`000_ooool5ool000[ooooo0ooo0006ooooo`?oo`000_ooool3ool000Cooooo
1Ooo00000oooooooo`00ool00003ool000Gooooo1Ooo000:ooooo`Goo`001?ooool5ool000Oooooo
1?l00?l:0000o`Cooooo0`000?l3ooooo`Go003o2oooool7o`00o`Wooooo0@000001ooooo`0000<0
0000ooooooooool00oooool5ool001Oooooo1Ooo000:ooooo`Goo`0000?oooooool00?oo00000ooo
0007ooooo`?oo`002Oooool6ool000Gooooo2?oo0004ooooo`?oo`000oooool9ool000?ooooo1Ooo
0003ooooo`Koo`0000?oooooool00?oo00000ooo0002ooooo`Goo`002Oooool5ool000Wooooo1Ooo
0003ooooo`Goo`0000?oooooool00?oo00000ooo0005ooooo`Goo`002_ooool5ool000Gooooo0ooo
0008ooooo`Go003o0`000?l00ol00?l0003o0000o`030000o`_ooooo0ol00?l5ooooo`<0003o1?oo
ool5o`00o`_ooooo0@000001ooooo`0000<00000oooooooo00000_oo00000oooooooo`00ool00003
ool001Oooooo1Ooo000:ooooo`Goo`000_ooool3ool000Oooooo1Ooo0009ooooo`Coo`001_ooool7
ool000Cooooo1Ooo0003ooooo`Woo`000_ooool5ool000?ooooo1_oo00000oooooooo`00ool00003
ool000;ooooo1Ooo0009ooooo`Goo`002Oooool5ool000?ooooo1Ooo00000oooooooo`00ool00003
ool000Kooooo0ooo0003ooooo`?oo`001?ooool6ool000oooooo1ol00?l2ooooo`;o003o0`000?l0
0ol00?ooooooooooo`08ooooo`Go003o0oooool50000o`Cooooo1Ol00?l:ooooo`4000000Oooool0
000300000?oo003oo`0000?oo`0000Coooooool00?oo003oo`006?ooool5ool000_ooooo1?oo0009
ooooo`Woo`003oooool3ool00004oooooooo003oo`00ool000Oooooo1Ooo0006ooooo`Ooo`0000?o
ooooool00?oo00000ooo0003ooooo`Koo`000_ooool3ool000Cooooo0ooo00001?ooooooo`00ool0
0?oo0006ooooo`Goo`002Oooool5ool000?ooooo1Ooo0002ooooo`?oo`003?ooool5ool000?ooooo
1Ooo000?ooooo`So003o0_ooool6o`00o`[ooooo1Ol00?l3ooooo`D0003o1Oooool5o`00o`Wooooo
0@000001ooooo`0000<00000ool00?oo00000ooo000Looooo`Goo`002Oooool7ool000Oooooo2_oo
000>ooooo`Goo`002_ooool5ool000Oooooo1ooo00001?ooooooo`00ool00?oo0005ooooo`Coo`00
3Oooool5ool000Kooooo0ooo000;ooooo`?oo`001?ooool5ool000Cooooo0ooo000:ooooo`Goo`00
0oooool5ool000;ooooo0ooo000:ooooo`Oo003o0oooool6o`00o`[ooooo1Ol00?l3ooooo`D0003o
0_l00?l3ooooo`Go003o2Oooool10000007ooooo00000`00003oo`00ool00003ool000?ooooo0ooo
000Gooooo`?oo`000oooool3ool000?ooooo2?oo0007ooooo`[oo`003_ooool5ool000_ooooo0ooo
0009ooooo`Ooo`004Oooool3ool000Gooooo1Ooo0005ooooo`?oo`005?ooool3ool000Cooooo1Ooo
0009ooooo`Goo`001?ooool3ool000;ooooo1Ooo0009ooooo`Go003o1_ooool4o`00o`cooooo0ol0
0?l5ooooo`<0003o1?l00?l2ooooo`Go003o2Oooool10000007ooooo00000`00003oooooool00002
ool000?ooooo1Ooo000Iooooo`Ooo`000_ooool8ool000Kooooo1_oo00001?ooooooo`00ool00?oo
000?ooooo`Goo`006?ooool6ool000kooooo1ooo0004ooooo`Goo`001?ooool5ool000oooooo0ooo
0008ooooo`Goo`002_ooool3ool000[ooooo1Ooo0009ooooo`Co003o0oooool3o`00oa3ooooo0ol0
0?l8ooooo`Go003o0oooool3o`00o`[ooooo0@000001ooooo`0000<00000ooooooooool01Oooool5
ool001Sooooo2?oo0002ooooo`Ooo`0000Coooooool00?oo003oo`000_ooool6ool000oooooo0ooo
0003ooooo`?oo`006_ooool5ool000gooooo2?oo0005ooooo`?oo`000_ooool8ool000Cooooo0ooo
0007ooooo`Goo`001oooool5ool001Oooooo1Ooo0002ooooo`?oo`000oooool5o`00o`;ooooo1Ol0
0?l;ooooo`<0003o1Ol00?l7ooooo`Go003o0`000?l=ooooo`4000000Oooool0000300000?oooooo
oooo00Gooooo1Ooo0009ooooo`?oo`003?ooool8ool000?ooooo2ooo00000oooooooo`00ool00003
ool000oooooo1Ooo000:ooooo`Koo`004?ooool3ool000Wooooo0ooo0002ooooo`Soo`002Oooool9
ool000?ooooo1Ooo0006ooooo`Goo`002?ooool5ool001Kooooo1Ooo00000oooooooo`00ool00003
ool000;ooooo1Ol00?l2ooooo`Go003o2_ooool70000o`;o003o0oooool3o`00o`;ooooo0ol00?l5
0000o`cooooo0@000001ooooo`0000<00000ooooooooool01?ooool6ool000Sooooo1Ooo0003oooo
o`?oo`001Oooool7ool000Kooooo0ooo00000oooooooo`00ool00003ool00003oooooooo003oo`00
00?oo`003Oooool7ool000Wooooo2?oo000Jooooo`Goo`0000?oooooool00?oo00001Ooo000:oooo
o`Woo`000oooool5ool000Kooooo1Ooo0009ooooo`Goo`005?ooool5ool000;ooooo1Ooo0002oooo
o`Go003o0_ooool5o`00o`[ooooo20000?l8o`00o`Cooooo1@000?l<ooooo`4000000Oooool00003
00000?oooooooooo00Cooooo1ooo0007ooooo`Goo`000_ooool5ool000Gooooo0ooo000=ooooo`Go
o`000_ooool3ool000gooooo2?oo0009ooooo`Soo`002?ooool3ool000Sooooo0ooo0004ooooo`Go
o`000_ooool3ool000gooooo2?oo0004ooooo`Goo`001oooool3ool000;ooooo1?oo0004ooooo`Go
o`001?ooool3ool000gooooo1Ooo0002ooooo`Goo`000oooool3o`00o`Cooooo0ol00?l;ooooo`P0
003o2?l00?l4ooooo`D0003o1oooool30000o`;ooooo0@000001ooooo`0000<00000ooooooooool0
1?ooool8ool000Kooooo1Ooo0002ooooo`Goo`001Oooool3ool000kooooo1_oo000@ooooo`Ooo`00
2_ooool8ool000Oooooo1Ooo0006ooooo`Goo`000oooool5ool0017ooooo1Ooo0009ooooo`?oo`00
1_ooool3ool000?ooooo1_oo0003ooooo`Goo`000oooool5ool000Sooooo0ooo00000oooooooo`00
ool00003ool000?ooooo0ooo000Jooooo`L0003o2?l00?l5ooooo`<0003o1oooool50000o`7ooooo
0@000001ooooo`0000<00000ooooooooool01Oooool7ool000Oooooo0ooo0003ooooo`Goo`001?oo
ool5ool000oooooo1Ooo0008ooooo`?oo`001?ooool5ool000[ooooo2Ooo0008ooooo`Goo`000_oo
ool3ool00003oooooooo003oo`0000?oo`001?ooool3ool0017ooooo1Ooo000Booooo`Goo`000_oo
ool6ool000Cooooo0ooo0004ooooo`Goo`001oooool5ool00004oooooooo003oo`00ool002Cooooo
0`000?l8o`00oa3ooooo1@000?l1ooooo`4000000Oooool0000300000?oooooooooo00Kooooo1_oo
000>ooooo`?oo`001Oooool8ool000Cooooo0ooo0005ooooo`Goo`001oooool5ool000Cooooo0ooo
0004ooooo`?oo`000_ooool;ool000Sooooo1Ooo00000oooooooo`00ool00008ool001Sooooo1Ooo
000Booooo`Goo`000_ooool6ool000_ooooo1Ooo0007ooooo`Goo`003Oooool3ool001cooooo0ol0
0?lAooooo`?o003o1@000?l1ooooo`4000000Oooool0000300000?oooooooooo00Gooooo1_oo000G
ooooo`Woo`0000?oooooool00?oo00001?oo0004ooooo`Goo`001oooool5ool000[ooooo4Ooo0009
ooooo`?oo`000_ooool5ool00003oooooooo003oo`0000?oo`004?ooool3ool000Cooooo1Ooo000B
ooooo`Goo`000oooool4ool000cooooo1?oo00001?ooooooo`00ool00?oo0004ooooo`Goo`003?oo
ool5ool002kooooo1Ol00?l30000o`03o`00ooooool00000007ooooo00000`00003oooooooooo`05
ooooo`Goo`001_ooool3ool0013ooooo3ooo0004ooooo`Goo`001oooool5ool000Oooooo4ooo000?
ooooo`Goo`0000?oooooool00?oo00000ooo000?ooooo`Goo`001?ooool3ool001Cooooo0ooo000C
ooooo`[oo`000oooool5ool000cooooo1Ooo000^ooooo`So003o0_ooool10000007ooooo00000`00
003oooooooooo`05ooooo`Goo`001Oooool5ool001;ooooo3?oo0005ooooo`?oo`002Oooool5ool0
00Gooooo5?oo0008ooooo`?oo`001Oooool:ool000oooooo1Ooo000aooooo`[oo`001?ooool3ool0
00_ooooo1ooo000Yooooo`?o003o0_ooool7o`00o`?ooooo0@000001ooooo`0000<00000oooooooo
ool01_ooool3ool000Kooooo1Ooo000:ooooo`?oo`001_ooool3ool00003oooooooo003oo`0000Co
o`004_ooool5ool000Gooooo2?oo0002ooooo`?oo`000_ooool5ool000Oooooo1Ooo0005ooooo`So
o`004?ooool5ool0037ooooo2_oo000;ooooo`?oo`000oooool7ool000[ooooo0ol00?l01?oooooo
003oo`00ool00?l>ooooo`<0003o1oooool30000o`;o003o0_ooool5o`00o`Cooooo0@000001oooo
o`0000<00000ooooooooool03oooool5ool000Wooooo1Ooo000:ooooo`?oo`005?ooool5ool000Go
oooo1Ooo000:ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`07ool000Gooooo1Ooo000Doooo
o`?oo`00<oooool8ool000_ooooo1Ooo0002ooooo`Goo`002oooool8o`00o`<0003o2Oooool60000
o`Gooooo1@000?l00ol00?ooooooooooo`05ooooo`<0003o0Oooool10000007ooooo00000`00003o
ooooooooo`0?ooooo`Goo`002Oooool5ool001?ooooo0ooo000<ooooo`?oo`001oooool3ool000co
oooo0ooo00000oooooooo`00ool0000:ool000Gooooo1Ooo000Yooooo`?oo`002Oooool3ool001;o
oooo1Ooo000>ooooo`Goo`000_ooool5ool000Gooooo0ol00?l3ooooo`Oo003o20000?l4ooooo`L0
003o1Oooool50000o`03o`00oooooooooooo00Cooooo1@000?l10000007ooooo00000`00003ooooo
ooooo`0@ooooo`?oo`002_ooool5ool001;ooooo1Ooo000Tooooo`?oo`0000?oooooool00?oo0000
2Ooo0007ooooo`?oo`00:Oooool7ool000Cooooo1_oo000Booooo`?oo`003oooool5ool000?ooooo
0ooo0005ooooo`Go003o00?oooooo`00ool00?l00`000?l3o`00o`T0003o0oooool70000o`Gooooo
1@000?l7ooooo`D0003o0@000001ooooo`0000<00000ooooooooool00oooool3ool001Cooooo0ooo
00001?ooooooo`00ool00?oo000Cooooo`Goo`008oooool>ool003Gooooo2?oo0002ooooo`Ooo`00
9Oooool3ool000cooooo1ol00?l50000o`;o003o2@000?l3ooooo`T0003o1?ooool30000o`;ooooo
0ol00?l00ooooooo003oo`00o`050000o`4000000Oooool0000300000?oooooooooo00;ooooo1Ooo
000Booooo`Goo`005_ooool5ool002?ooooo1Ooo00001Oooooooo`00ool00?oo003ooooo00?oo`00
0_ooool3ool001[ooooo0ooo000Dooooo`Soo`000_ooool>ool002gooooo1ol00?l50000o`?ooooo
20000?l4ooooo`<0003o00?ooooo0000o`000?l00`000?l5ooooo`[o003o0`000?l1ooooo`400000
0Oooool0000300000?oooooooooo00Ooo`004_ooool5ool001Oooooo0ooo000Tooooo`Goo`001?oo
ool:ool001Gooooo2?oo000Dooooo`Ooo`000_ooool?ool000gooooo0ooo000Mooooo`?o003o00?o
ooooo`00ool00?l01@000?l7ooooo`<0003o2Oooool50000o`Cooooo3?l00?l3ooooo`4000000Ooo
ool0000300000?ooooooo`0000Soo`004Oooool5ool003oooooo0ooo0005ooooo`[oo`005?ooool9
ool001Oooooo0ooo0002oooooa3oo`003?ooool5ool0027ooooo0_l00?l30000oaCooooo1@000?l4
ooooo`co003o0oooool10000007ooooo00000`00003oooooool00008ool001;ooooo0ooo0017oooo
o`_oo`005?ooool9ool001_ooooo1Ooo00000oooooooo`00ool00009ool000cooooo1Ooo000koooo
o`<0003o1Oooool7o`00o`04ooooool00?oo003oo`00o`Cooooo0@000001ooooo`0000<00000oooo
oooo00002?oo001Looooo`Goo`000_ooool3ool001Gooooo2?oo000Looooo`Goo`000_ooool9ool0
00gooooo1Ooo0014ooooo`?o003o2oooool10000007ooooo00000`00003oooooooooo`03ool00004
oooooooo003oo`00ool005gooooo1Ooo000Kooooo`?oo`008?ooool5ool000Cooooo0ooo000Boooo
o`?oo`00Doooool10000007ooooo001X000000?oo`00@0000003ool0074000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #1: red class, scalar covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 9;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes scalar covariances", "Subsubsection"],

Cell[BoxData[
    \(\(initScalar\  = \ EMInitializationScalar[data1, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initScalar, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.37999999999999545`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PolygonalAllPlot[poly, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .80136 m
.0228 .78846 L
.02852 .76923 L
.03353 .75 L
.03665 .73077 L
.03699 .71154 L
.0347 .69231 L
.03118 .67308 L
.02786 .65385 L
.02555 .63462 L
.02454 .61538 L
.02484 .59615 L
.02641 .57692 L
.02915 .55769 L
.03296 .53846 L
.03773 .51923 L
.03846 .51655 L
.04332 .5 L
.04959 .48077 L
.05637 .46154 L
.05769 .45791 L
.06349 .44231 L
.07077 .42308 L
.07692 .40688 L
.07807 .40385 L
.08527 .38462 L
.09229 .36538 L
.09615 .35455 L
.0991 .34615 L
.10574 .32692 L
.11227 .30769 L
.11538 .29848 L
.1188 .28846 L
.12547 .26923 L
.13248 .25 L
.13462 .24441 L
.14005 .23077 L
.14846 .21154 L
.15385 .2004 L
.15805 .19231 L
.16926 .17308 L
.17308 .16724 L
.18272 .15385 L
.19231 .14225 L
.19939 .13462 L
.21154 .12313 L
.221 .11538 L
.23077 .10837 L
.25 .097 L
.25166 .09615 L
.26923 .0884 L
.28846 .0821 L
.30769 .07779 L
.31167 .07692 L
.32692 .07522 L
.34615 .0742 L
.36538 .07458 L
.38462 .07623 L
.39089 .07692 L
.40385 .07903 L
.42308 .08292 L
.44231 .08781 L
.46154 .09368 L
.46889 .09615 L
.48077 .10048 L
.5 .10822 L
.51605 .11538 L
.51923 .1169 L
.53846 .12655 L
.55317 .13462 L
.55769 .13723 L
.57692 .14901 L
.58432 .15385 L
.59615 .16199 L
.61122 .17308 L
.61538 .1763 L
.63462 .1921 L
.63486 .19231 L
.65385 .20961 L
.65585 .21154 L
.67308 .2291 L
.67463 .23077 L
.69151 .25 L
.69231 .25096 L
.70673 .26923 L
.71154 .27575 L
.72044 .28846 L
.73077 .30437 L
.73281 .30769 L
.74393 .32692 L
.75 .3384 L
.75387 .34615 L
.7627 .36538 L
.76923 .38135 L
.77047 .38462 L
.7772 .40385 L
.78291 .42308 L
.78761 .44231 L
.78846 .44619 L
.79129 .46154 L
.79394 .48077 L
.79554 .5 L
.79605 .51923 L
.79542 .53846 L
.79361 .55769 L
.79054 .57692 L
.78846 .58683 L
.7861 .59615 L
.78016 .61538 L
.77257 .63462 L
.76923 .64188 L
.76309 .65385 L
.75139 .67308 L
.75 .67513 L
.73702 .69231 L
.73077 .69956 L
.71924 .71154 L
.71154 .71868 L
.69678 .73077 L
.69231 .73407 L
.67308 .74661 L
.66714 .75 L
.65385 .75685 L
.63462 .76521 L
.62369 .76923 L
.61538 .77195 L
.59615 .7773 L
.57692 .78146 L
.55769 .78461 L
.53846 .78689 L
.51923 .78846 L
.51922 .78846 L
.5 .78948 L
.48077 .79012 L
.46154 .79062 L
.44231 .7913 L
.42308 .79281 L
.40385 .79668 L
.38471 .80769 L
.38462 .80782 L
.37271 .82692 L
.36794 .84615 L
.36538 .86241 L
.36484 .86538 L
.36109 .88462 L
.35673 .90385 L
.35158 .92308 L
.34615 .94142 L
.3458 .94231 L
.3375 .96154 L
.32822 .98077 L
.01923 .98077 L
F
0 g
.01923 .80136 m
.0228 .78846 L
.02852 .76923 L
.03353 .75 L
.03665 .73077 L
.03699 .71154 L
.0347 .69231 L
.03118 .67308 L
.02786 .65385 L
.02555 .63462 L
.02454 .61538 L
.02484 .59615 L
.02641 .57692 L
.02915 .55769 L
.03296 .53846 L
.03773 .51923 L
.03846 .51655 L
.04332 .5 L
.04959 .48077 L
.05637 .46154 L
.05769 .45791 L
.06349 .44231 L
.07077 .42308 L
.07692 .40688 L
.07807 .40385 L
.08527 .38462 L
.09229 .36538 L
.09615 .35455 L
.0991 .34615 L
.10574 .32692 L
.11227 .30769 L
.11538 .29848 L
.1188 .28846 L
.12547 .26923 L
.13248 .25 L
.13462 .24441 L
.14005 .23077 L
.14846 .21154 L
.15385 .2004 L
.15805 .19231 L
.16926 .17308 L
.17308 .16724 L
.18272 .15385 L
.19231 .14225 L
.19939 .13462 L
.21154 .12313 L
.221 .11538 L
.23077 .10837 L
.25 .097 L
.25166 .09615 L
Mistroke
.26923 .0884 L
.28846 .0821 L
.30769 .07779 L
.31167 .07692 L
.32692 .07522 L
.34615 .0742 L
.36538 .07458 L
.38462 .07623 L
.39089 .07692 L
.40385 .07903 L
.42308 .08292 L
.44231 .08781 L
.46154 .09368 L
.46889 .09615 L
.48077 .10048 L
.5 .10822 L
.51605 .11538 L
.51923 .1169 L
.53846 .12655 L
.55317 .13462 L
.55769 .13723 L
.57692 .14901 L
.58432 .15385 L
.59615 .16199 L
.61122 .17308 L
.61538 .1763 L
.63462 .1921 L
.63486 .19231 L
.65385 .20961 L
.65585 .21154 L
.67308 .2291 L
.67463 .23077 L
.69151 .25 L
.69231 .25096 L
.70673 .26923 L
.71154 .27575 L
.72044 .28846 L
.73077 .30437 L
.73281 .30769 L
.74393 .32692 L
.75 .3384 L
.75387 .34615 L
.7627 .36538 L
.76923 .38135 L
.77047 .38462 L
.7772 .40385 L
.78291 .42308 L
.78761 .44231 L
.78846 .44619 L
.79129 .46154 L
Mistroke
.79394 .48077 L
.79554 .5 L
.79605 .51923 L
.79542 .53846 L
.79361 .55769 L
.79054 .57692 L
.78846 .58683 L
.7861 .59615 L
.78016 .61538 L
.77257 .63462 L
.76923 .64188 L
.76309 .65385 L
.75139 .67308 L
.75 .67513 L
.73702 .69231 L
.73077 .69956 L
.71924 .71154 L
.71154 .71868 L
.69678 .73077 L
.69231 .73407 L
.67308 .74661 L
.66714 .75 L
.65385 .75685 L
.63462 .76521 L
.62369 .76923 L
.61538 .77195 L
.59615 .7773 L
.57692 .78146 L
.55769 .78461 L
.53846 .78689 L
.51923 .78846 L
.51922 .78846 L
.5 .78948 L
.48077 .79012 L
.46154 .79062 L
.44231 .7913 L
.42308 .79281 L
.40385 .79668 L
.38471 .80769 L
.38462 .80782 L
.37271 .82692 L
.36794 .84615 L
.36538 .86241 L
.36484 .86538 L
.36109 .88462 L
.35673 .90385 L
.35158 .92308 L
.34615 .94142 L
.3458 .94231 L
.3375 .96154 L
Mistroke
.32822 .98077 L
Mfstroke
.2 g
.29004 .98077 m
.30005 .96154 L
.30769 .94259 L
.30778 .94231 L
.31276 .92308 L
.31584 .90385 L
.31687 .88462 L
.31572 .86538 L
.31232 .84615 L
.30769 .83006 L
.30645 .82692 L
.29714 .80769 L
.28846 .79425 L
.28394 .78846 L
.26923 .77347 L
.26424 .76923 L
.25 .75999 L
.23077 .75068 L
.22948 .75 L
.21154 .74588 L
.19231 .74395 L
.17308 .74491 L
.15385 .7486 L
.14831 .75 L
.13462 .75581 L
.11538 .76643 L
.11097 .76923 L
.09615 .78136 L
.08861 .78846 L
.07692 .80183 L
.07245 .80769 L
.06011 .82692 L
.05769 .83132 L
.05086 .84615 L
.04383 .86538 L
.03888 .88462 L
.03846 .88677 L
.03607 .90385 L
.03543 .92308 L
.03707 .94231 L
.03846 .95221 L
.04122 .96154 L
.04817 .98077 L
F
0 g
.29004 .98077 m
.30005 .96154 L
.30769 .94259 L
.30778 .94231 L
.31276 .92308 L
.31584 .90385 L
.31687 .88462 L
.31572 .86538 L
.31232 .84615 L
.30769 .83006 L
.30645 .82692 L
.29714 .80769 L
.28846 .79425 L
.28394 .78846 L
.26923 .77347 L
.26424 .76923 L
.25 .75999 L
.23077 .75068 L
.22948 .75 L
.21154 .74588 L
.19231 .74395 L
.17308 .74491 L
.15385 .7486 L
.14831 .75 L
.13462 .75581 L
.11538 .76643 L
.11097 .76923 L
.09615 .78136 L
.08861 .78846 L
.07692 .80183 L
.07245 .80769 L
.06011 .82692 L
.05769 .83132 L
.05086 .84615 L
.04383 .86538 L
.03888 .88462 L
.03846 .88677 L
.03607 .90385 L
.03543 .92308 L
.03707 .94231 L
.03846 .95221 L
.04122 .96154 L
.04817 .98077 L
s
.3 g
.26739 .98077 m
.26923 .97789 L
.27871 .96154 L
.28694 .94231 L
.28846 .93845 L
.29219 .92308 L
.29493 .90385 L
.29518 .88462 L
.29279 .86538 L
.28846 .84857 L
.28744 .84615 L
.27821 .82692 L
.26923 .81382 L
.26396 .80769 L
.25 .79509 L
.24045 .78846 L
.23077 .78353 L
.21154 .77674 L
.19231 .77376 L
.17308 .77434 L
.15385 .7784 L
.13462 .78598 L
.12968 .78846 L
.11538 .79794 L
.10367 .80769 L
.09615 .81538 L
.08664 .82692 L
.07692 .84155 L
.07439 .84615 L
.06565 .86538 L
.0596 .88462 L
.05769 .89344 L
.05621 .90385 L
.05534 .92308 L
.05701 .94231 L
.05769 .94763 L
.0617 .96154 L
.06991 .98077 L
F
0 g
.26739 .98077 m
.26923 .97789 L
.27871 .96154 L
.28694 .94231 L
.28846 .93845 L
.29219 .92308 L
.29493 .90385 L
.29518 .88462 L
.29279 .86538 L
.28846 .84857 L
.28744 .84615 L
.27821 .82692 L
.26923 .81382 L
.26396 .80769 L
.25 .79509 L
.24045 .78846 L
.23077 .78353 L
.21154 .77674 L
.19231 .77376 L
.17308 .77434 L
.15385 .7784 L
.13462 .78598 L
.12968 .78846 L
.11538 .79794 L
.10367 .80769 L
.09615 .81538 L
.08664 .82692 L
.07692 .84155 L
.07439 .84615 L
.06565 .86538 L
.0596 .88462 L
.05769 .89344 L
.05621 .90385 L
.05534 .92308 L
.05701 .94231 L
.05769 .94763 L
.0617 .96154 L
.06991 .98077 L
s
.4 g
.24907 .98077 m
.25 .97949 L
.26214 .96154 L
.26923 .94728 L
.2711 .94231 L
.27669 .92308 L
.27937 .90385 L
.2791 .88462 L
.27566 .86538 L
.26923 .84747 L
.26852 .84615 L
.25619 .82692 L
.25 .82007 L
.23493 .80769 L
.23077 .80522 L
.21154 .79686 L
.19231 .79313 L
.17308 .79348 L
.15385 .7978 L
.13462 .80627 L
.13209 .80769 L
.11538 .82002 L
.1081 .82692 L
.09615 .84124 L
.0928 .84615 L
.0823 .86538 L
.07692 .87892 L
.07533 .88462 L
.07147 .90385 L
.07045 .92308 L
.07245 .94231 L
.07692 .96001 L
.07786 .96154 L
.08776 .98077 L
F
0 g
.24907 .98077 m
.25 .97949 L
.26214 .96154 L
.26923 .94728 L
.2711 .94231 L
.27669 .92308 L
.27937 .90385 L
.2791 .88462 L
.27566 .86538 L
.26923 .84747 L
.26852 .84615 L
.25619 .82692 L
.25 .82007 L
.23493 .80769 L
.23077 .80522 L
.21154 .79686 L
.19231 .79313 L
.17308 .79348 L
.15385 .7978 L
.13462 .80627 L
.13209 .80769 L
.11538 .82002 L
.1081 .82692 L
.09615 .84124 L
.0928 .84615 L
.0823 .86538 L
.07692 .87892 L
.07533 .88462 L
.07147 .90385 L
.07045 .92308 L
.07245 .94231 L
.07692 .96001 L
.07786 .96154 L
.08776 .98077 L
s
.5 g
.23207 .98077 m
.24754 .96154 L
.25 .9577 L
.25751 .94231 L
.26358 .92308 L
.26623 .90385 L
.26548 .88462 L
.26098 .86538 L
.25175 .84615 L
.25 .84348 L
.23499 .82692 L
.23077 .82369 L
.21154 .81332 L
.19231 .80873 L
.17308 .80887 L
.15385 .81353 L
.13462 .82314 L
.12903 .82692 L
.11538 .83918 L
.1093 .84615 L
.09678 .86538 L
.09615 .8665 L
.08882 .88462 L
.08441 .90385 L
.08334 .92308 L
.08576 .94231 L
.09227 .96154 L
.09615 .96608 L
.10442 .98077 L
F
0 g
.23207 .98077 m
.24754 .96154 L
.25 .9577 L
.25751 .94231 L
.26358 .92308 L
.26623 .90385 L
.26548 .88462 L
.26098 .86538 L
.25175 .84615 L
.25 .84348 L
.23499 .82692 L
.23077 .82369 L
.21154 .81332 L
.19231 .80873 L
.17308 .80887 L
.15385 .81353 L
.13462 .82314 L
.12903 .82692 L
.11538 .83918 L
.1093 .84615 L
.09678 .86538 L
.09615 .8665 L
.08882 .88462 L
.08441 .90385 L
.08334 .92308 L
.08576 .94231 L
.09227 .96154 L
.09615 .96608 L
.10442 .98077 L
s
.6 g
.21431 .98077 m
.23077 .96478 L
.23352 .96154 L
.24499 .94231 L
.25 .93072 L
.25159 .92308 L
.25422 .90385 L
.25296 .88462 L
.25 .87273 L
.24724 .86538 L
.23519 .84615 L
.23077 .84151 L
.21154 .82834 L
.2082 .82692 L
.19231 .82269 L
.17308 .82258 L
.1557 .82692 L
.15385 .82764 L
.13462 .8386 L
.12567 .84615 L
.11538 .858 L
.11044 .86538 L
.10116 .88462 L
.09624 .90385 L
.09615 .90442 L
.09517 .92308 L
.09615 .93285 L
.09813 .94231 L
.10605 .96154 L
.11538 .97133 L
.12171 .98077 L
F
0 g
.21431 .98077 m
.23077 .96478 L
.23352 .96154 L
.24499 .94231 L
.25 .93072 L
.25159 .92308 L
.25422 .90385 L
.25296 .88462 L
.25 .87273 L
.24724 .86538 L
.23519 .84615 L
.23077 .84151 L
.21154 .82834 L
.2082 .82692 L
.19231 .82269 L
.17308 .82258 L
.1557 .82692 L
.15385 .82764 L
.13462 .8386 L
.12567 .84615 L
.11538 .858 L
.11044 .86538 L
.10116 .88462 L
.09624 .90385 L
.09615 .90442 L
.09517 .92308 L
.09615 .93285 L
.09813 .94231 L
.10605 .96154 L
.11538 .97133 L
.12171 .98077 L
s
.7 g
.1903 .98077 m
.19231 .97978 L
.21154 .96787 L
.21912 .96154 L
.23077 .94582 L
.23262 .94231 L
.24007 .92308 L
.24275 .90385 L
.24085 .88462 L
.23331 .86538 L
.23077 .86119 L
.21647 .84615 L
.21154 .84319 L
.19231 .83596 L
.17308 .83551 L
.15385 .84117 L
.14374 .84615 L
.13462 .85395 L
.12414 .86538 L
.11538 .87955 L
.11327 .88462 L
.10765 .90385 L
.1066 .92308 L
.11035 .94231 L
.11538 .95505 L
.12026 .96154 L
.13462 .97261 L
.14599 .98077 L
F
0 g
.1903 .98077 m
.19231 .97978 L
.21154 .96787 L
.21912 .96154 L
.23077 .94582 L
.23262 .94231 L
.24007 .92308 L
.24275 .90385 L
.24085 .88462 L
.23331 .86538 L
.23077 .86119 L
.21647 .84615 L
.21154 .84319 L
.19231 .83596 L
.17308 .83551 L
.15385 .84117 L
.14374 .84615 L
.13462 .85395 L
.12414 .86538 L
.11538 .87955 L
.11327 .88462 L
.10765 .90385 L
.1066 .92308 L
.11035 .94231 L
.11538 .95505 L
.12026 .96154 L
.13462 .97261 L
.14599 .98077 L
s
.8 g
.15385 .85488 m
.17308 .8485 L
.19231 .84942 L
.21154 .85909 L
.21813 .86538 L
.22837 .88462 L
.23077 .89803 L
.23103 .90385 L
.23077 .90928 L
.22838 .92308 L
.21985 .94231 L
.21154 .95315 L
.20336 .96154 L
.19231 .96638 L
.17308 .97101 L
.15385 .96868 L
.13793 .96154 L
.13462 .9592 L
.12296 .94231 L
.11819 .92308 L
.11915 .90385 L
.12563 .88462 L
.13462 .87052 L
.13878 .86538 L
F
0 g
.15385 .85488 m
.17308 .8485 L
.19231 .84942 L
.21154 .85909 L
.21813 .86538 L
.22837 .88462 L
.23077 .89803 L
.23103 .90385 L
.23077 .90928 L
.22838 .92308 L
.21985 .94231 L
.21154 .95315 L
.20336 .96154 L
.19231 .96638 L
.17308 .97101 L
.15385 .96868 L
.13793 .96154 L
.13462 .9592 L
.12296 .94231 L
.11819 .92308 L
.11915 .90385 L
.12563 .88462 L
.13462 .87052 L
.13878 .86538 L
.15385 .85488 L
s
.9 g
.17308 .86253 m
.19231 .86449 L
.19438 .86538 L
.21154 .87906 L
.21399 .88462 L
.21867 .90385 L
.21556 .92308 L
.21154 .93181 L
.20661 .94231 L
.19231 .95291 L
.17308 .95906 L
.15385 .9561 L
.1386 .94231 L
.13462 .93516 L
.13098 .92308 L
.13183 .90385 L
.13462 .89525 L
.13869 .88462 L
.15385 .86977 L
.1632 .86538 L
F
0 g
.17308 .86253 m
.19231 .86449 L
.19438 .86538 L
.21154 .87906 L
.21399 .88462 L
.21867 .90385 L
.21556 .92308 L
.21154 .93181 L
.20661 .94231 L
.19231 .95291 L
.17308 .95906 L
.15385 .9561 L
.1386 .94231 L
.13462 .93516 L
.13098 .92308 L
.13183 .90385 L
.13462 .89525 L
.13869 .88462 L
.15385 .86977 L
.1632 .86538 L
.17308 .86253 L
s
1 g
.17308 .87905 m
.19231 .88453 L
.1924 .88462 L
.2025 .90385 L
.20194 .92308 L
.19231 .93257 L
.17308 .94183 L
.15385 .93431 L
.14475 .92308 L
.14577 .90385 L
.15385 .89195 L
.16166 .88462 L
F
0 g
.17308 .87905 m
.19231 .88453 L
.1924 .88462 L
.2025 .90385 L
.20194 .92308 L
.19231 .93257 L
.17308 .94183 L
.15385 .93431 L
.14475 .92308 L
.14577 .90385 L
.15385 .89195 L
.16166 .88462 L
.17308 .87905 L
s
.2 g
.46154 .33798 m
.48077 .33332 L
.5 .33188 L
.51923 .33344 L
.53846 .33792 L
.55769 .34545 L
.55919 .34615 L
.57692 .35634 L
.58933 .36538 L
.59615 .37125 L
.60951 .38462 L
.61538 .39154 L
.62449 .40385 L
.63462 .42077 L
.6358 .42308 L
.64423 .44231 L
.65009 .46154 L
.65355 .48077 L
.65385 .48341 L
.65467 .5 L
.65385 .51495 L
.65333 .51923 L
.64927 .53846 L
.642 .55769 L
.63462 .57107 L
.63056 .57692 L
.61538 .59387 L
.61284 .59615 L
.59615 .60814 L
.58199 .61538 L
.57692 .61733 L
.55769 .62287 L
.53846 .62544 L
.51923 .62541 L
.5 .62298 L
.48077 .61817 L
.47241 .61538 L
.46154 .61087 L
.44231 .60069 L
.43533 .59615 L
.42308 .58687 L
.41232 .57692 L
.40385 .56759 L
.39638 .55769 L
.38525 .53846 L
.38462 .5372 L
.37777 .51923 L
.37331 .5 L
.37144 .48077 L
.37197 .46154 L
.37484 .44231 L
.38015 .42308 L
.38462 .41139 L
.38823 .40385 L
.39979 .38462 L
.40385 .37919 L
.41638 .36538 L
.42308 .35944 L
.44231 .34638 L
.4427 .34615 L
F
0 g
.46154 .33798 m
.48077 .33332 L
.5 .33188 L
.51923 .33344 L
.53846 .33792 L
.55769 .34545 L
.55919 .34615 L
.57692 .35634 L
.58933 .36538 L
.59615 .37125 L
.60951 .38462 L
.61538 .39154 L
.62449 .40385 L
.63462 .42077 L
.6358 .42308 L
.64423 .44231 L
.65009 .46154 L
.65355 .48077 L
.65385 .48341 L
.65467 .5 L
.65385 .51495 L
.65333 .51923 L
.64927 .53846 L
.642 .55769 L
.63462 .57107 L
.63056 .57692 L
.61538 .59387 L
.61284 .59615 L
.59615 .60814 L
.58199 .61538 L
.57692 .61733 L
.55769 .62287 L
.53846 .62544 L
.51923 .62541 L
.5 .62298 L
.48077 .61817 L
.47241 .61538 L
.46154 .61087 L
.44231 .60069 L
.43533 .59615 L
.42308 .58687 L
.41232 .57692 L
.40385 .56759 L
.39638 .55769 L
.38525 .53846 L
.38462 .5372 L
.37777 .51923 L
.37331 .5 L
.37144 .48077 L
.37197 .46154 L
Mistroke
.37484 .44231 L
.38015 .42308 L
.38462 .41139 L
.38823 .40385 L
.39979 .38462 L
.40385 .37919 L
.41638 .36538 L
.42308 .35944 L
.44231 .34638 L
.4427 .34615 L
.46154 .33798 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.646 .09 0 r
.39834 .6165 .40457 .61946 .41455 .62621 .40827 .62498 Mtetra
.82 .36 .13 r
.40827 .62498 .41455 .62621 .4245 .63719 .41815 .63856 Mtetra
.846 .452 .301 r
.41815 .63856 .4245 .63719 .43446 .6524 .42803 .65735 Mtetra
.834 .478 .38 r
.42803 .65735 .43446 .6524 .44451 .67067 .43799 .68007 Mtetra
.806 .47 .421 r
.43799 .68007 .44451 .67067 .45471 .68945 .44811 .7038 Mtetra
.759 .437 .44 r
.44811 .7038 .45471 .68945 .46514 .70517 .45851 .7242 Mtetra
.684 .372 .44 r
.45851 .7242 .46514 .70517 .47583 .71407 .46922 .73665 Mtetra
.56 .26 .416 r
.46922 .73665 .47583 .71407 .48673 .71352 .48021 .73767 Mtetra
.354 .076 .347 r
.48021 .73767 .48673 .71352 .49777 .70294 .49139 .72633 Mtetra
.034 0 .203 r
.49139 .72633 .49777 .70294 .50884 .68408 .50263 .70457 Mtetra
0 0 0 r
.50263 .70457 .50884 .68408 .51986 .66029 .51382 .67642 Mtetra
.674 .75 .255 r
.51382 .67642 .51986 .66029 .5308 .63536 .52489 .64655 Mtetra
.861 .885 .453 r
.52489 .64655 .5308 .63536 .54165 .61238 .53584 .61886 Mtetra
.94 .944 .61 r
.53584 .61886 .54165 .61238 .55245 .59318 .54671 .59568 Mtetra
.947 .954 .734 r
.54671 .59568 .55245 .59318 .56324 .57828 .55754 .57777 Mtetra
.903 .928 .823 r
.55754 .57777 .56324 .57828 .57405 .56727 .56839 .56466 Mtetra
.835 .884 .877 r
.56839 .56466 .57405 .56727 .58491 .55925 .57928 .55531 Mtetra
.771 .839 .904 r
.57928 .55531 .58491 .55925 .59583 .55328 .59022 .54856 Mtetra
.723 .805 .915 r
.59022 .54856 .59583 .55328 .6068 .54856 .60121 .54339 Mtetra
.694 .783 .919 r
.60121 .54339 .6068 .54856 .61782 .54452 .61226 .53912 Mtetra
.679 .772 .921 r
.61226 .53912 .61782 .54452 .62889 .54082 .62337 .53529 Mtetra
.671 .766 .921 r
.62337 .53529 .62889 .54082 .64002 .53728 .63452 .53167 Mtetra
.668 .763 .921 r
.63452 .53167 .64002 .53728 .65118 .53381 .64572 .52814 Mtetra
.666 .761 .921 r
.64572 .52814 .65118 .53381 .66239 .53035 .65696 .52464 Mtetra
.666 .76 .921 r
.65696 .52464 .66239 .53035 .67365 .52691 .66825 .52115 Mtetra
.665 .759 .92 r
.66825 .52115 .67365 .52691 .68495 .52345 .67959 .51765 Mtetra
.67959 .51765 .68495 .52345 .6963 .51999 .69097 .51415 Mtetra
.665 .758 .92 r
.69097 .51415 .6963 .51999 .70769 .51652 .70239 .51064 Mtetra
.665 .758 .919 r
.70239 .51064 .70769 .51652 .71913 .51304 .71386 .50711 Mtetra
.665 .757 .919 r
.71386 .50711 .71913 .51304 .73062 .50955 .72538 .50357 Mtetra
.665 .756 .918 r
.72538 .50357 .73062 .50955 .74215 .50603 .73694 .50001 Mtetra
.666 .756 .917 r
.73694 .50001 .74215 .50603 .75372 .5025 .74855 .49643 Mtetra
.666 .755 .917 r
.74855 .49643 .75372 .5025 .76534 .49895 .7602 .49284 Mtetra
.666 .754 .916 r
.7602 .49284 .76534 .49895 .77701 .49539 .77191 .48922 Mtetra
.666 .753 .915 r
.77191 .48922 .77701 .49539 .78873 .4918 .78365 .48558 Mtetra
.78365 .48558 .78873 .4918 .80049 .48819 .79545 .48192 Mtetra
.667 .752 .914 r
.79545 .48192 .80049 .48819 .8123 .48456 .80729 .47824 Mtetra
.667 .751 .913 r
.80729 .47824 .8123 .48456 .82416 .48092 .81918 .47454 Mtetra
.667 .75 .913 r
.81918 .47454 .82416 .48092 .83606 .47725 .83112 .47082 Mtetra
.667 .75 .912 r
.83112 .47082 .83606 .47725 .84801 .47357 .84311 .46709 Mtetra
.667 .749 .911 r
.84311 .46709 .84801 .47357 .86001 .46987 .85514 .46334 Mtetra
.667 .748 .911 r
.85514 .46334 .86001 .46987 .87206 .46615 .86723 .45957 Mtetra
.667 .747 .91 r
.86723 .45957 .87206 .46615 .88416 .46241 .87936 .45579 Mtetra
.87936 .45579 .88416 .46241 .89631 .45866 .89154 .452 Mtetra
.667 .746 .91 r
.89154 .452 .89631 .45866 .90851 .45489 .90377 .44818 Mtetra
.667 .746 .909 r
.90377 .44818 .90851 .45489 .92075 .4511 .91606 .44436 Mtetra
.91606 .44436 .92075 .4511 .93305 .4473 .92839 .44052 Mtetra
.667 .745 .909 r
.92839 .44052 .93305 .4473 .9454 .44348 .94078 .43666 Mtetra
.667 .745 .908 r
.94078 .43666 .9454 .44348 .95779 .43964 .95321 .43278 Mtetra
.95321 .43278 .95779 .43964 .97024 .43578 .9657 .42889 Mtetra
.67 .127 0 r
.39208 .61274 .39834 .6165 .40827 .62498 .40198 .62237 Mtetra
.844 .387 .114 r
.40198 .62237 .40827 .62498 .41815 .63856 .41181 .63776 Mtetra
.876 .48 .28 r
.41181 .63776 .41815 .63856 .42803 .65735 .42161 .65915 Mtetra
.871 .509 .359 r
.42161 .65915 .42803 .65735 .43799 .68007 .43147 .68528 Mtetra
.85 .504 .398 r
.43147 .68528 .43799 .68007 .44811 .7038 .44152 .71297 Mtetra
.81 .472 .416 r
.44152 .71297 .44811 .7038 .45851 .7242 .45187 .73738 Mtetra
.735 .399 .413 r
.45187 .73738 .45851 .7242 .46922 .73665 .46258 .75314 Mtetra
.581 .25 .373 r
.46258 .75314 .46922 .73665 .48021 .73767 .47363 .75604 Mtetra
.253 0 .245 r
.47363 .75604 .48021 .73767 .49139 .72633 .48493 .74468 Mtetra
0 0 0 r
.48493 .74468 .49139 .72633 .50263 .70457 .49632 .72102 Mtetra
.722 .78 .29 r
.49632 .72102 .50263 .70457 .51382 .67642 .50766 .68958 Mtetra
.902 .879 .448 r
.50766 .68958 .51382 .67642 .52489 .64655 .51888 .65574 Mtetra
.965 .908 .549 r
.51888 .65574 .52489 .64655 .53584 .61886 .52994 .6241 Mtetra
.979 .918 .636 r
.52994 .6241 .53584 .61886 .54671 .59568 .54089 .59749 Mtetra
.961 .917 .719 r
.54089 .59749 .54671 .59568 .55754 .57777 .55179 .5769 Mtetra
.917 .903 .795 r
.55179 .5769 .55754 .57777 .56839 .56466 .56267 .5619 Mtetra
.853 .874 .854 r
.56267 .5619 .56839 .56466 .57928 .55531 .57359 .55133 Mtetra
.787 .838 .891 r
.57359 .55133 .57928 .55531 .59022 .54856 .58456 .54383 Mtetra
.735 .808 .909 r
.58456 .54383 .59022 .54856 .60121 .54339 .59559 .53825 Mtetra
.701 .787 .918 r
.59559 .53825 .60121 .54339 .61226 .53912 .60667 .53375 Mtetra
.682 .775 .921 r
.60667 .53375 .61226 .53912 .62337 .53529 .6178 .52979 Mtetra
.673 .769 .923 r
.6178 .52979 .62337 .53529 .63452 .53167 .62899 .5261 Mtetra
.669 .766 .923 r
.62899 .5261 .63452 .53167 .64572 .52814 .64022 .52251 Mtetra
.667 .764 .923 r
.64022 .52251 .64572 .52814 .65696 .52464 .65149 .51896 Mtetra
.666 .763 .923 r
.65149 .51896 .65696 .52464 .66825 .52115 .66281 .51543 Mtetra
.666 .762 .922 r
.66281 .51543 .66825 .52115 .67959 .51765 .67418 .51189 Mtetra
.665 .762 .922 r
.67418 .51189 .67959 .51765 .69097 .51415 .68559 .50835 Mtetra
.665 .761 .922 r
.68559 .50835 .69097 .51415 .70239 .51064 .69705 .50479 Mtetra
.666 .761 .921 r
.69705 .50479 .70239 .51064 .71386 .50711 .70855 .50122 Mtetra
.666 .76 .92 r
.70855 .50122 .71386 .50711 .72538 .50357 .7201 .49763 Mtetra
.666 .759 .92 r
.7201 .49763 .72538 .50357 .73694 .50001 .7317 .49402 Mtetra
.666 .758 .919 r
.7317 .49402 .73694 .50001 .74855 .49643 .74334 .49039 Mtetra
.667 .758 .918 r
.74334 .49039 .74855 .49643 .7602 .49284 .75503 .48674 Mtetra
.667 .757 .918 r
.75503 .48674 .7602 .49284 .77191 .48922 .76676 .48306 Mtetra
.667 .756 .917 r
.76676 .48306 .77191 .48922 .78365 .48558 .77855 .47936 Mtetra
.667 .755 .916 r
.77855 .47936 .78365 .48558 .79545 .48192 .79037 .47565 Mtetra
.668 .754 .915 r
.79037 .47565 .79545 .48192 .80729 .47824 .80225 .47191 Mtetra
.668 .753 .914 r
.80225 .47191 .80729 .47824 .81918 .47454 .81417 .46815 Mtetra
.668 .752 .913 r
.81417 .46815 .81918 .47454 .83112 .47082 .82615 .46438 Mtetra
.668 .751 .912 r
.82615 .46438 .83112 .47082 .84311 .46709 .83817 .46059 Mtetra
.668 .75 .912 r
.83817 .46059 .84311 .46709 .85514 .46334 .85023 .45678 Mtetra
.668 .749 .911 r
.85023 .45678 .85514 .46334 .86723 .45957 .86235 .45297 Mtetra
.668 .748 .911 r
.86235 .45297 .86723 .45957 .87936 .45579 .87452 .44913 Mtetra
.668 .748 .91 r
.87452 .44913 .87936 .45579 .89154 .452 .88674 .44529 Mtetra
.668 .747 .91 r
.88674 .44529 .89154 .452 .90377 .44818 .89901 .44143 Mtetra
.668 .746 .909 r
.89901 .44143 .90377 .44818 .91606 .44436 .91133 .43756 Mtetra
.91133 .43756 .91606 .44436 .92839 .44052 .9237 .43368 Mtetra
.668 .745 .909 r
.9237 .43368 .92839 .44052 .94078 .43666 .93612 .42978 Mtetra
.667 .745 .908 r
.93612 .42978 .94078 .43666 .95321 .43278 .94859 .42587 Mtetra
.94859 .42587 .95321 .43278 .9657 .42889 .96112 .42194 Mtetra
.631 .098 0 r
.38582 .60793 .39208 .61274 .40198 .62237 .3957 .61795 Mtetra
.845 .381 .04 r
.3957 .61795 .40198 .62237 .41181 .63776 .4055 .63406 Mtetra
.898 .491 .218 r
.4055 .63406 .41181 .63776 .42161 .65915 .41525 .65662 Mtetra
.907 .53 .301 r
.41525 .65662 .42161 .65915 .43147 .68528 .42505 .68449 Mtetra
.9 .535 .339 r
.42505 .68449 .43147 .68528 .44152 .71297 .43502 .71446 Mtetra
.875 .508 .347 r
.43502 .71446 .44152 .71297 .45187 .73738 .44531 .74149 Mtetra
.815 .428 .322 r
.44531 .74149 .45187 .73738 .46258 .75314 .45599 .75977 Mtetra
.613 .183 .202 r
.45599 .75977 .46258 .75314 .47363 .75604 .46707 .76456 Mtetra
0 0 0 r
.46707 .76456 .47363 .75604 .48493 .74468 .47845 .75398 Mtetra
.884 .928 .544 r
.47845 .75398 .48493 .74468 .49632 .72102 .48996 .72982 Mtetra
.979 .905 .576 r
.48996 .72982 .49632 .72102 .50766 .68958 .50144 .69676 Mtetra
.992 .881 .593 r
.50144 .69676 .50766 .68958 .51888 .65574 .51278 .6606 Mtetra
.989 .87 .62 r
.51278 .6606 .51888 .65574 .52994 .6241 .52396 .62643 Mtetra
.978 .868 .66 r
.52396 .62643 .52994 .6241 .54089 .59749 .535 .59749 Mtetra
.955 .869 .714 r
.535 .59749 .54089 .59749 .55179 .5769 .54596 .57499 Mtetra
.915 .865 .776 r
.54596 .57499 .55179 .5769 .56267 .5619 .5569 .5586 Mtetra
.859 .852 .834 r
.5569 .5586 .56267 .5619 .57359 .55133 .56786 .54708 Mtetra
.797 .83 .877 r
.56786 .54708 .57359 .55133 .58456 .54383 .57886 .539 Mtetra
.743 .807 .903 r
.57886 .539 .58456 .54383 .59559 .53825 .58992 .53308 Mtetra
.706 .789 .916 r
.58992 .53308 .59559 .53825 .60667 .53375 .60103 .52839 Mtetra
.685 .778 .921 r
.60103 .52839 .60667 .53375 .6178 .52979 .61219 .52433 Mtetra
.674 .772 .924 r
.61219 .52433 .6178 .52979 .62899 .5261 .62341 .52056 Mtetra
.669 .769 .925 r
.62341 .52056 .62899 .5261 .64022 .52251 .63467 .51692 Mtetra
.667 .768 .925 r
.63467 .51692 .64022 .52251 .65149 .51896 .64598 .51334 Mtetra
.666 .767 .925 r
.64598 .51334 .65149 .51896 .66281 .51543 .65733 .50976 Mtetra
.666 .766 .925 r
.65733 .50976 .66281 .51543 .67418 .51189 .66873 .50618 Mtetra
.666 .765 .924 r
.66873 .50618 .67418 .51189 .68559 .50835 .68018 .5026 Mtetra
.68018 .5026 .68559 .50835 .69705 .50479 .69167 .49899 Mtetra
.666 .764 .923 r
.69167 .49899 .69705 .50479 .70855 .50122 .70321 .49538 Mtetra
.70321 .49538 .70855 .50122 .7201 .49763 .71479 .49174 Mtetra
.667 .763 .922 r
.71479 .49174 .7201 .49763 .7317 .49402 .72642 .48807 Mtetra
.667 .762 .921 r
.72642 .48807 .7317 .49402 .74334 .49039 .7381 .48438 Mtetra
.668 .761 .92 r
.7381 .48438 .74334 .49039 .75503 .48674 .74982 .48067 Mtetra
.668 .76 .919 r
.74982 .48067 .75503 .48674 .76676 .48306 .76159 .47693 Mtetra
.668 .759 .918 r
.76159 .47693 .76676 .48306 .77855 .47936 .7734 .47317 Mtetra
.669 .758 .917 r
.7734 .47317 .77855 .47936 .79037 .47565 .78526 .46939 Mtetra
.669 .756 .916 r
.78526 .46939 .79037 .47565 .80225 .47191 .79717 .46558 Mtetra
.669 .755 .915 r
.79717 .46558 .80225 .47191 .81417 .46815 .80913 .46176 Mtetra
.669 .754 .914 r
.80913 .46176 .81417 .46815 .82615 .46438 .82113 .45792 Mtetra
.669 .753 .913 r
.82113 .45792 .82615 .46438 .83817 .46059 .83319 .45407 Mtetra
.669 .751 .912 r
.83319 .45407 .83817 .46059 .85023 .45678 .84529 .4502 Mtetra
.669 .75 .911 r
.84529 .4502 .85023 .45678 .86235 .45297 .85744 .44633 Mtetra
.669 .749 .911 r
.85744 .44633 .86235 .45297 .87452 .44913 .86965 .44244 Mtetra
.669 .748 .91 r
.86965 .44244 .87452 .44913 .88674 .44529 .8819 .43854 Mtetra
.668 .748 .91 r
.8819 .43854 .88674 .44529 .89901 .44143 .89421 .43464 Mtetra
.668 .747 .909 r
.89421 .43464 .89901 .44143 .91133 .43756 .90656 .43072 Mtetra
.668 .746 .909 r
.90656 .43072 .91133 .43756 .9237 .43368 .91897 .42679 Mtetra
.668 .746 .908 r
.91897 .42679 .9237 .43368 .93612 .42978 .93143 .42285 Mtetra
.668 .745 .908 r
.93143 .42285 .93612 .42978 .94859 .42587 .94394 .4189 Mtetra
.94394 .4189 .94859 .42587 .96112 .42194 .9565 .41493 Mtetra
.511 0 0 r
.37954 .60204 .38582 .60793 .3957 .61795 .38945 .61164 Mtetra
.796 .323 0 r
.38945 .61164 .3957 .61795 .4055 .63406 .39925 .62725 Mtetra
.891 .468 .093 r
.39925 .62725 .4055 .63406 .41525 .65662 .40899 .64936 Mtetra
.921 .527 .181 r
.40899 .64936 .41525 .65662 .42505 .68449 .41875 .67699 Mtetra
.928 .542 .202 r
.41875 .67699 .42505 .68449 .43502 .71446 .42868 .70713 Mtetra
.916 .516 .16 r
.42868 .70713 .43502 .71446 .44531 .74149 .43892 .73487 Mtetra
.84 .387 0 r
.43892 .73487 .44531 .74149 .45599 .75977 .44957 .75438 Mtetra
0 .33 .781 r
.44957 .75438 .45599 .75977 .46707 .76456 .46064 .76066 Mtetra
.813 .836 .868 r
.46064 .76066 .46707 .76456 .47845 .75398 .47204 .75151 Mtetra
.924 .815 .72 r
.47204 .75151 .47845 .75398 .48996 .72982 .48361 .72834 Mtetra
.947 .8 .665 r
.48361 .72834 .48996 .72982 .50144 .69676 .49519 .69565 Mtetra
.953 .795 .648 r
.49519 .69565 .50144 .69676 .51278 .6606 .50664 .65928 Mtetra
.952 .797 .652 r
.50664 .65928 .51278 .6606 .52396 .62643 .51792 .62448 Mtetra
.945 .804 .673 r
.51792 .62448 .52396 .62643 .535 .59749 .52904 .59473 Mtetra
.929 .814 .711 r
.52904 .59473 .535 .59749 .54596 .57499 .54007 .57144 Mtetra
.899 .822 .763 r
.54007 .57144 .54596 .57499 .5569 .5586 .55106 .55439 Mtetra
.854 .824 .818 r
.55106 .55439 .5569 .5586 .56786 .54708 .56207 .54238 Mtetra
.798 .816 .865 r
.56207 .54238 .56786 .54708 .57886 .539 .57311 .53398 Mtetra
.747 .802 .896 r
.57311 .53398 .57886 .539 .58992 .53308 .5842 .52785 Mtetra
.709 .789 .914 r
.5842 .52785 .58992 .53308 .60103 .52839 .59534 .52303 Mtetra
.687 .78 .922 r
.59534 .52303 .60103 .52839 .61219 .52433 .60654 .51889 Mtetra
.675 .775 .925 r
.60654 .51889 .61219 .52433 .62341 .52056 .61779 .51507 Mtetra
.67 .772 .927 r
.61779 .51507 .62341 .52056 .63467 .51692 .62909 .51139 Mtetra
.667 .771 .927 r
.62909 .51139 .63467 .51692 .64598 .51334 .64043 .50777 Mtetra
.666 .77 .927 r
.64043 .50777 .64598 .51334 .65733 .50976 .65182 .50416 Mtetra
.65182 .50416 .65733 .50976 .66873 .50618 .66325 .50054 Mtetra
.666 .769 .927 r
.66325 .50054 .66873 .50618 .68018 .5026 .67473 .49691 Mtetra
.67473 .49691 .68018 .5026 .69167 .49899 .68626 .49327 Mtetra
.667 .768 .926 r
.68626 .49327 .69167 .49899 .70321 .49538 .69783 .4896 Mtetra
.667 .768 .925 r
.69783 .4896 .70321 .49538 .71479 .49174 .70945 .48591 Mtetra
.668 .767 .924 r
.70945 .48591 .71479 .49174 .72642 .48807 .72111 .48218 Mtetra
.668 .766 .923 r
.72111 .48218 .72642 .48807 .7381 .48438 .73282 .47843 Mtetra
.669 .765 .922 r
.73282 .47843 .7381 .48438 .74982 .48067 .74457 .47465 Mtetra
.669 .764 .921 r
.74457 .47465 .74982 .48067 .76159 .47693 .75638 .47084 Mtetra
.67 .762 .92 r
.75638 .47084 .76159 .47693 .7734 .47317 .76822 .46701 Mtetra
.67 .761 .919 r
.76822 .46701 .7734 .47317 .78526 .46939 .78012 .46315 Mtetra
.67 .759 .917 r
.78012 .46315 .78526 .46939 .79717 .46558 .79206 .45927 Mtetra
.67 .758 .916 r
.79206 .45927 .79717 .46558 .80913 .46176 .80405 .45537 Mtetra
.67 .756 .915 r
.80405 .45537 .80913 .46176 .82113 .45792 .81609 .45146 Mtetra
.67 .755 .914 r
.81609 .45146 .82113 .45792 .83319 .45407 .82818 .44754 Mtetra
.67 .753 .913 r
.82818 .44754 .83319 .45407 .84529 .4502 .84031 .4436 Mtetra
.67 .752 .912 r
.84031 .4436 .84529 .4502 .85744 .44633 .8525 .43966 Mtetra
.67 .751 .911 r
.8525 .43966 .85744 .44633 .86965 .44244 .86474 .43571 Mtetra
.669 .749 .91 r
.86474 .43571 .86965 .44244 .8819 .43854 .87703 .43176 Mtetra
.669 .748 .91 r
.87703 .43176 .8819 .43854 .89421 .43464 .88937 .4278 Mtetra
.669 .747 .909 r
.88937 .4278 .89421 .43464 .90656 .43072 .90176 .42383 Mtetra
.90176 .42383 .90656 .43072 .91897 .42679 .9142 .41985 Mtetra
.668 .746 .908 r
.9142 .41985 .91897 .42679 .93143 .42285 .9267 .41587 Mtetra
.668 .745 .908 r
.9267 .41587 .93143 .42285 .94394 .4189 .93925 .41187 Mtetra
.93925 .41187 .94394 .4189 .9565 .41493 .95185 .40787 Mtetra
0 .157 .669 r
.37327 .59524 .37954 .60204 .38945 .61164 .38321 .60369 Mtetra
.648 .186 0 r
.38321 .60369 .38945 .61164 .39925 .62725 .39306 .61771 Mtetra
.799 .375 0 r
.39306 .61771 .39925 .62725 .40899 .64936 .40283 .63786 Mtetra
.844 .452 0 r
.40283 .63786 .40899 .64936 .41875 .67699 .41262 .66334 Mtetra
.82 .451 0 r
.41262 .66334 .41875 .67699 .42868 .70713 .42255 .69153 Mtetra
.673 .339 0 r
.42255 .69153 .42868 .70713 .43892 .73487 .43276 .71793 Mtetra
0 .003 .574 r
.43276 .71793 .43892 .73487 .44957 .75438 .44336 .73708 Mtetra
.396 .409 .756 r
.44336 .73708 .44957 .75438 .46064 .76066 .45439 .74414 Mtetra
.69 .586 .734 r
.45439 .74414 .46064 .76066 .47204 .75151 .46577 .7367 Mtetra
.805 .652 .694 r
.46577 .7367 .47204 .75151 .48361 .72834 .47736 .71578 Mtetra
.856 .685 .668 r
.47736 .71578 .48361 .72834 .49519 .69565 .48897 .68538 Mtetra
.883 .706 .658 r
.48897 .68538 .49519 .69565 .50664 .65928 .50048 .65094 Mtetra
.896 .724 .661 r
.50048 .65094 .50664 .65928 .51792 .62448 .51183 .61756 Mtetra
.899 .742 .678 r
.51183 .61756 .51792 .62448 .52904 .59473 .52303 .5887 Mtetra
.893 .762 .709 r
.52303 .5887 .52904 .59473 .54007 .57144 .53413 .56589 Mtetra
.874 .78 .755 r
.53413 .56589 .54007 .57144 .55106 .55439 .54517 .54904 Mtetra
.839 .793 .808 r
.54517 .54904 .55106 .55439 .56207 .54238 .55622 .5371 Mtetra
.792 .798 .856 r
.55622 .5371 .56207 .54238 .57311 .53398 .56731 .52868 Mtetra
.746 .794 .892 r
.56731 .52868 .57311 .53398 .5842 .52785 .57844 .52252 Mtetra
.709 .787 .912 r
.57844 .52252 .5842 .52785 .59534 .52303 .58962 .51766 Mtetra
.687 .781 .922 r
.58962 .51766 .59534 .52303 .60654 .51889 .60085 .51349 Mtetra
.675 .778 .927 r
.60085 .51349 .60654 .51889 .61779 .51507 .61213 .50964 Mtetra
.67 .776 .929 r
.61213 .50964 .61779 .51507 .62909 .51139 .62346 .50593 Mtetra
.667 .775 .93 r
.62346 .50593 .62909 .51139 .64043 .50777 .63484 .50227 Mtetra
.666 .775 .93 r
.63484 .50227 .64043 .50777 .65182 .50416 .64626 .49863 Mtetra
.666 .774 .93 r
.64626 .49863 .65182 .50416 .66325 .50054 .65773 .49498 Mtetra
.65773 .49498 .66325 .50054 .67473 .49691 .66925 .49131 Mtetra
.66925 .49131 .67473 .49691 .68626 .49327 .68081 .48763 Mtetra
.667 .773 .929 r
.68081 .48763 .68626 .49327 .69783 .4896 .69241 .48391 Mtetra
.668 .773 .928 r
.69241 .48391 .69783 .4896 .70945 .48591 .70406 .48016 Mtetra
.668 .772 .927 r
.70406 .48016 .70945 .48591 .72111 .48218 .71576 .47637 Mtetra
.669 .771 .926 r
.71576 .47637 .72111 .48218 .73282 .47843 .7275 .47255 Mtetra
.67 .77 .925 r
.7275 .47255 .73282 .47843 .74457 .47465 .73929 .4687 Mtetra
.671 .768 .923 r
.73929 .4687 .74457 .47465 .75638 .47084 .75113 .46481 Mtetra
.671 .766 .922 r
.75113 .46481 .75638 .47084 .76822 .46701 .76301 .46089 Mtetra
.672 .765 .92 r
.76301 .46089 .76822 .46701 .78012 .46315 .77494 .45695 Mtetra
.672 .763 .919 r
.77494 .45695 .78012 .46315 .79206 .45927 .78691 .45298 Mtetra
.672 .761 .917 r
.78691 .45298 .79206 .45927 .80405 .45537 .79894 .449 Mtetra
.672 .759 .916 r
.79894 .449 .80405 .45537 .81609 .45146 .81101 .44501 Mtetra
.672 .757 .915 r
.81101 .44501 .81609 .45146 .82818 .44754 .82313 .441 Mtetra
.672 .755 .913 r
.82313 .441 .82818 .44754 .84031 .4436 .8353 .43699 Mtetra
.671 .754 .912 r
.8353 .43699 .84031 .4436 .8525 .43966 .84752 .43298 Mtetra
.671 .752 .911 r
.84752 .43298 .8525 .43966 .86474 .43571 .85979 .42896 Mtetra
.67 .751 .911 r
.85979 .42896 .86474 .43571 .87703 .43176 .87211 .42494 Mtetra
.67 .749 .91 r
.87211 .42494 .87703 .43176 .88937 .4278 .88449 .42092 Mtetra
.67 .748 .909 r
.88449 .42092 .88937 .4278 .90176 .42383 .89692 .41689 Mtetra
.669 .747 .909 r
.89692 .41689 .90176 .42383 .9142 .41985 .9094 .41287 Mtetra
.669 .746 .908 r
.9094 .41287 .9142 .41985 .9267 .41587 .92193 .40883 Mtetra
.92193 .40883 .9267 .41587 .93925 .41187 .93452 .40479 Mtetra
.668 .745 .908 r
.93452 .40479 .93925 .41187 .95185 .40787 .94716 .40074 Mtetra
0 .326 .81 r
.36697 .58783 .37327 .59524 .38321 .60369 .37699 .59464 Mtetra
0 .03 .586 r
.37699 .59464 .38321 .60369 .39306 .61771 .38691 .60628 Mtetra
0 0 .403 r
.38691 .60628 .39306 .61771 .40283 .63786 .39677 .62331 Mtetra
0 0 .344 r
.39677 .62331 .40283 .63786 .41262 .66334 .40662 .64517 Mtetra
0 0 .405 r
.40662 .64517 .41262 .66334 .42255 .69153 .41659 .66965 Mtetra
0 0 .542 r
.41659 .66965 .42255 .69153 .43276 .71793 .42681 .69293 Mtetra
.197 .216 .654 r
.42681 .69293 .43276 .71793 .44336 .73708 .43739 .71021 Mtetra
.475 .396 .687 r
.43739 .71021 .44336 .73708 .45439 .74414 .44837 .71714 Mtetra
.639 .504 .682 r
.44837 .71714 .45439 .74414 .46577 .7367 .45969 .71137 Mtetra
.732 .568 .669 r
.45969 .71137 .46577 .7367 .47736 .71578 .47122 .69349 Mtetra
.787 .609 .659 r
.47122 .69349 .47736 .71578 .48897 .68538 .48282 .66682 Mtetra
.821 .64 .657 r
.48282 .66682 .48897 .68538 .50048 .65094 .49434 .6361 Mtetra
.843 .666 .663 r
.49434 .6361 .50048 .65094 .51183 .61756 .50573 .6059 Mtetra
.854 .691 .68 r
.50573 .6059 .51183 .61756 .52303 .5887 .51698 .57948 Mtetra
.855 .717 .709 r
.51698 .57948 .52303 .5887 .53413 .56589 .52813 .55835 Mtetra
.844 .743 .752 r
.52813 .55835 .53413 .56589 .54517 .54904 .53923 .54256 Mtetra
.819 .765 .803 r
.53923 .54256 .54517 .54904 .55622 .5371 .55033 .53122 Mtetra
.781 .78 .852 r
.55033 .53122 .55622 .5371 .56731 .52868 .56146 .52311 Mtetra
.74 .785 .889 r
.56146 .52311 .56731 .52868 .57844 .52252 .57262 .51709 Mtetra
.707 .784 .912 r
.57262 .51709 .57844 .52252 .58962 .51766 .58384 .51229 Mtetra
.686 .782 .924 r
.58384 .51229 .58962 .51766 .60085 .51349 .59511 .50812 Mtetra
.674 .78 .93 r
.59511 .50812 .60085 .51349 .61213 .50964 .60643 .50427 Mtetra
.669 .78 .932 r
.60643 .50427 .61213 .50964 .62346 .50593 .61779 .50054 Mtetra
.667 .779 .933 r
.61779 .50054 .62346 .50593 .63484 .50227 .62921 .49686 Mtetra
.666 .779 .934 r
.62921 .49686 .63484 .50227 .64626 .49863 .64067 .4932 Mtetra
.64067 .4932 .64626 .49863 .65773 .49498 .65217 .48952 Mtetra
.65217 .48952 .65773 .49498 .66925 .49131 .66372 .48582 Mtetra
.666 .779 .933 r
.66372 .48582 .66925 .49131 .68081 .48763 .67532 .48208 Mtetra
.667 .779 .933 r
.67532 .48208 .68081 .48763 .69241 .48391 .68696 .47831 Mtetra
.668 .778 .932 r
.68696 .47831 .69241 .48391 .70406 .48016 .69865 .47451 Mtetra
.669 .777 .93 r
.69865 .47451 .70406 .48016 .71576 .47637 .71038 .47065 Mtetra
.671 .776 .929 r
.71038 .47065 .71576 .47637 .7275 .47255 .72216 .46676 Mtetra
.672 .775 .927 r
.72216 .46676 .7275 .47255 .73929 .4687 .73398 .46282 Mtetra
.672 .773 .926 r
.73398 .46282 .73929 .4687 .75113 .46481 .74585 .45884 Mtetra
.673 .771 .924 r
.74585 .45884 .75113 .46481 .76301 .46089 .75776 .45483 Mtetra
.674 .769 .922 r
.75776 .45483 .76301 .46089 .77494 .45695 .76972 .45079 Mtetra
.674 .767 .92 r
.76972 .45079 .77494 .45695 .78691 .45298 .78173 .44673 Mtetra
.674 .765 .919 r
.78173 .44673 .78691 .45298 .79894 .449 .79379 .44265 Mtetra
.674 .762 .917 r
.79379 .44265 .79894 .449 .81101 .44501 .80589 .43856 Mtetra
.674 .76 .916 r
.80589 .43856 .81101 .44501 .82313 .441 .81804 .43447 Mtetra
.673 .758 .914 r
.81804 .43447 .82313 .441 .8353 .43699 .83025 .43037 Mtetra
.673 .756 .913 r
.83025 .43037 .8353 .43699 .84752 .43298 .8425 .42627 Mtetra
.672 .754 .912 r
.8425 .42627 .84752 .43298 .85979 .42896 .85481 .42218 Mtetra
.672 .752 .911 r
.85481 .42218 .85979 .42896 .87211 .42494 .86717 .41809 Mtetra
.671 .75 .91 r
.86717 .41809 .87211 .42494 .88449 .42092 .87958 .414 Mtetra
.671 .749 .909 r
.87958 .414 .88449 .42092 .89692 .41689 .89204 .40991 Mtetra
.67 .748 .909 r
.89204 .40991 .89692 .41689 .9094 .41287 .90456 .40583 Mtetra
.67 .747 .908 r
.90456 .40583 .9094 .41287 .92193 .40883 .91713 .40174 Mtetra
.669 .746 .908 r
.91713 .40174 .92193 .40883 .93452 .40479 .92976 .39766 Mtetra
.669 .745 .908 r
.92976 .39766 .93452 .40479 .94716 .40074 .94244 .39356 Mtetra
.177 .46 .884 r
.36065 .58016 .36697 .58783 .37699 .59464 .37075 .58509 Mtetra
0 .249 .762 r
.37075 .58509 .37699 .59464 .38691 .60628 .38078 .59396 Mtetra
0 .076 .637 r
.38078 .59396 .38691 .60628 .39677 .62331 .39074 .60727 Mtetra
0 .01 .581 r
.39074 .60727 .39677 .62331 .40662 .64517 .40071 .62463 Mtetra
0 .056 .594 r
.40071 .62463 .40662 .64517 .41659 .66965 .41076 .64433 Mtetra
.137 .17 .633 r
.41076 .64433 .41659 .66965 .42681 .69293 .42103 .66328 Mtetra
.347 .296 .658 r
.42103 .66328 .42681 .69293 .43739 .71021 .4316 .67757 Mtetra
.507 .397 .664 r
.4316 .67757 .43739 .71021 .44837 .71714 .44253 .68354 Mtetra
.616 .47 .661 r
.44253 .68354 .44837 .71714 .45969 .71137 .45376 .6791 Mtetra
.69 .523 .656 r
.45376 .6791 .45969 .71137 .47122 .69349 .46521 .66452 Mtetra
.74 .562 .653 r
.46521 .66452 .47122 .69349 .48282 .66682 .47674 .64235 Mtetra
.775 .595 .656 r
.47674 .64235 .48282 .66682 .49434 .6361 .48824 .61645 Mtetra
.798 .624 .665 r
.48824 .61645 .49434 .6361 .50573 .6059 .49963 .59065 Mtetra
.814 .652 .683 r
.49963 .59065 .50573 .6059 .51698 .57948 .51091 .56778 Mtetra
.82 .682 .712 r
.51091 .56778 .51698 .57948 .52813 .55835 .5221 .54923 Mtetra
.815 .714 .754 r
.5221 .54923 .52813 .55835 .53923 .54256 .53325 .53515 Mtetra
.796 .743 .804 r
.53325 .53515 .53923 .54256 .55033 .53122 .54439 .52484 Mtetra
.766 .765 .852 r
.54439 .52484 .55033 .53122 .56146 .52311 .55556 .51731 Mtetra
.731 .777 .89 r
.55556 .51731 .56146 .52311 .57262 .51709 .56677 .51158 Mtetra
.702 .782 .914 r
.56677 .51158 .57262 .51709 .58384 .51229 .57802 .50691 Mtetra
.683 .783 .926 r
.57802 .50691 .58384 .51229 .59511 .50812 .58933 .5028 Mtetra
.672 .783 .933 r
.58933 .5028 .59511 .50812 .60643 .50427 .60068 .49896 Mtetra
.668 .783 .935 r
.60068 .49896 .60643 .50427 .61779 .50054 .61208 .49524 Mtetra
.665 .784 .937 r
.61208 .49524 .61779 .50054 .62921 .49686 .62353 .49155 Mtetra
.665 .784 .938 r
.62353 .49155 .62921 .49686 .64067 .4932 .63503 .48787 Mtetra
.63503 .48787 .64067 .4932 .65217 .48952 .64657 .48416 Mtetra
.665 .785 .938 r
.64657 .48416 .65217 .48952 .66372 .48582 .65816 .48043 Mtetra
.666 .785 .937 r
.65816 .48043 .66372 .48582 .67532 .48208 .66979 .47666 Mtetra
.668 .785 .936 r
.66979 .47666 .67532 .48208 .68696 .47831 .68147 .47284 Mtetra
.669 .784 .935 r
.68147 .47284 .68696 .47831 .69865 .47451 .69319 .46896 Mtetra
.67 .783 .934 r
.69319 .46896 .69865 .47451 .71038 .47065 .70496 .46504 Mtetra
.672 .782 .932 r
.70496 .46504 .71038 .47065 .72216 .46676 .71677 .46106 Mtetra
.673 .781 .93 r
.71677 .46106 .72216 .46676 .73398 .46282 .72863 .45703 Mtetra
.675 .779 .928 r
.72863 .45703 .73398 .46282 .74585 .45884 .74053 .45296 Mtetra
.676 .776 .926 r
.74053 .45296 .74585 .45884 .75776 .45483 .75248 .44884 Mtetra
.676 .774 .924 r
.75248 .44884 .75776 .45483 .76972 .45079 .76447 .44469 Mtetra
.677 .771 .922 r
.76447 .44469 .76972 .45079 .78173 .44673 .77651 .44052 Mtetra
.677 .769 .92 r
.77651 .44052 .78173 .44673 .79379 .44265 .7886 .43633 Mtetra
.677 .766 .918 r
.7886 .43633 .79379 .44265 .80589 .43856 .80074 .43214 Mtetra
.676 .763 .916 r
.80074 .43214 .80589 .43856 .81804 .43447 .81293 .42794 Mtetra
.676 .761 .915 r
.81293 .42794 .81804 .43447 .83025 .43037 .82516 .42374 Mtetra
.675 .758 .913 r
.82516 .42374 .83025 .43037 .8425 .42627 .83745 .41955 Mtetra
.674 .756 .912 r
.83745 .41955 .8425 .42627 .85481 .42218 .84979 .41537 Mtetra
.673 .754 .911 r
.84979 .41537 .85481 .42218 .86717 .41809 .86218 .4112 Mtetra
.672 .752 .91 r
.86218 .4112 .86717 .41809 .87958 .414 .87463 .40704 Mtetra
.672 .75 .909 r
.87463 .40704 .87958 .414 .89204 .40991 .88713 .40289 Mtetra
.671 .749 .909 r
.88713 .40289 .89204 .40991 .90456 .40583 .89968 .39875 Mtetra
.67 .747 .908 r
.89968 .39875 .90456 .40583 .91713 .40174 .91229 .3946 Mtetra
.67 .746 .908 r
.91229 .3946 .91713 .40174 .92976 .39766 .92495 .39047 Mtetra
.669 .746 .908 r
.92495 .39047 .92976 .39766 .94244 .39356 .93767 .38633 Mtetra
.337 .554 .914 r
.35429 .57255 .36065 .58016 .37075 .58509 .36448 .57563 Mtetra
.189 .413 .848 r
.36448 .57563 .37075 .58509 .38078 .59396 .37461 .5817 Mtetra
.085 .28 .764 r
.37461 .5817 .38078 .59396 .39074 .60727 .38471 .5912 Mtetra
.081 .213 .702 r
.38471 .5912 .39074 .60727 .40071 .62463 .39481 .60387 Mtetra
.167 .221 .675 r
.39481 .60387 .40071 .62463 .41076 .64433 .40498 .61845 Mtetra
.296 .276 .667 r
.40498 .61845 .41076 .64433 .42103 .66328 .41532 .63261 Mtetra
.423 .344 .663 r
.41532 .63261 .42103 .66328 .4316 .67757 .42591 .64334 Mtetra
.527 .406 .659 r
.42591 .64334 .4316 .67757 .44253 .68354 .43679 .64778 Mtetra
.606 .458 .655 r
.43679 .64778 .44253 .68354 .45376 .6791 .44795 .64422 Mtetra
.664 .5 .652 r
.44795 .64422 .45376 .6791 .46521 .66452 .4593 .63273 Mtetra
.708 .535 .653 r
.4593 .63273 .46521 .66452 .47674 .64235 .47073 .61515 Mtetra
.74 .566 .658 r
.47073 .61515 .47674 .64235 .48824 .61645 .48217 .5944 Mtetra
.764 .596 .669 r
.48217 .5944 .48824 .61645 .49963 .59065 .49353 .57348 Mtetra
.78 .626 .689 r
.49353 .57348 .49963 .59065 .51091 .56778 .50481 .55469 Mtetra
.789 .659 .72 r
.50481 .55469 .51091 .56778 .5221 .54923 .51603 .5392 Mtetra
.787 .694 .762 r
.51603 .5392 .5221 .54923 .53325 .53515 .52722 .52719 Mtetra
.773 .728 .811 r
.52722 .52719 .53325 .53515 .54439 .52484 .5384 .51818 Mtetra
.748 .756 .858 r
.5384 .51818 .54439 .52484 .55556 .51731 .54961 .51138 Mtetra
.719 .772 .894 r
.54961 .51138 .55556 .51731 .56677 .51158 .56086 .50605 Mtetra
.695 .781 .917 r
.56086 .50605 .56677 .51158 .57802 .50691 .57216 .50156 Mtetra
.679 .784 .93 r
.57216 .50156 .57802 .50691 .58933 .5028 .5835 .49754 Mtetra
.67 .786 .936 r
.5835 .49754 .58933 .5028 .60068 .49896 .59489 .49374 Mtetra
.665 .787 .939 r
.59489 .49374 .60068 .49896 .61208 .49524 .60633 .49003 Mtetra
.664 .788 .941 r
.60633 .49003 .61208 .49524 .62353 .49155 .61782 .48634 Mtetra
.663 .789 .942 r
.61782 .48634 .62353 .49155 .63503 .48787 .62935 .48265 Mtetra
.664 .79 .942 r
.62935 .48265 .63503 .48787 .64657 .48416 .64093 .47893 Mtetra
.665 .791 .942 r
.64093 .47893 .64657 .48416 .65816 .48043 .65255 .47517 Mtetra
.666 .791 .941 r
.65255 .47517 .65816 .48043 .66979 .47666 .66422 .47136 Mtetra
.668 .791 .94 r
.66422 .47136 .66979 .47666 .68147 .47284 .67594 .46748 Mtetra
.67 .791 .939 r
.67594 .46748 .68147 .47284 .69319 .46896 .6877 .46355 Mtetra
.672 .79 .937 r
.6877 .46355 .69319 .46896 .70496 .46504 .6995 .45954 Mtetra
.674 .789 .935 r
.6995 .45954 .70496 .46504 .71677 .46106 .71135 .45547 Mtetra
.675 .787 .933 r
.71135 .45547 .71677 .46106 .72863 .45703 .72324 .45134 Mtetra
.677 .785 .931 r
.72324 .45134 .72863 .45703 .74053 .45296 .73518 .44716 Mtetra
.678 .782 .928 r
.73518 .44716 .74053 .45296 .75248 .44884 .74716 .44292 Mtetra
.679 .779 .926 r
.74716 .44292 .75248 .44884 .76447 .44469 .75919 .43866 Mtetra
.68 .776 .924 r
.75919 .43866 .76447 .44469 .77651 .44052 .77126 .43436 Mtetra
.68 .773 .921 r
.77126 .43436 .77651 .44052 .7886 .43633 .78338 .43005 Mtetra
.679 .77 .919 r
.78338 .43005 .7886 .43633 .80074 .43214 .79555 .42574 Mtetra
.679 .767 .917 r
.79555 .42574 .80074 .43214 .81293 .42794 .80777 .42142 Mtetra
.678 .764 .916 r
.80777 .42142 .81293 .42794 .82516 .42374 .82004 .41712 Mtetra
.677 .761 .914 r
.82004 .41712 .82516 .42374 .83745 .41955 .83236 .41282 Mtetra
.676 .758 .913 r
.83236 .41282 .83745 .41955 .84979 .41537 .84473 .40855 Mtetra
.675 .755 .911 r
.84473 .40855 .84979 .41537 .86218 .4112 .85716 .40429 Mtetra
.674 .753 .91 r
.85716 .40429 .86218 .4112 .87463 .40704 .86964 .40005 Mtetra
.673 .751 .909 r
.86964 .40005 .87463 .40704 .88713 .40289 .88217 .39583 Mtetra
.672 .749 .909 r
.88217 .39583 .88713 .40289 .89968 .39875 .89476 .39161 Mtetra
.671 .748 .908 r
.89476 .39161 .89968 .39875 .91229 .3946 .90741 .38741 Mtetra
.67 .747 .908 r
.90741 .38741 .91229 .3946 .92495 .39047 .92011 .38322 Mtetra
.67 .746 .907 r
.92011 .38322 .92495 .39047 .93767 .38633 .93287 .37903 Mtetra
.445 .618 .924 r
.34786 .5652 .35429 .57255 .36448 .57563 .35814 .56664 Mtetra
.355 .523 .885 r
.35814 .56664 .36448 .57563 .37461 .5817 .36839 .57021 Mtetra
.285 .422 .825 r
.36839 .57021 .37461 .5817 .38471 .5912 .37862 .57624 Mtetra
.272 .354 .765 r
.37862 .57624 .38471 .5912 .39481 .60387 .38886 .58459 Mtetra
.316 .334 .72 r
.38886 .58459 .39481 .60387 .40498 .61845 .39915 .59436 Mtetra
.392 .35 .692 r
.39915 .59436 .40498 .61845 .41532 .63261 .40958 .60391 Mtetra
.473 .384 .675 r
.40958 .60391 .41532 .63261 .42591 .64334 .42021 .61106 Mtetra
.544 .422 .664 r
.42021 .61106 .42591 .64334 .43679 .64778 .43107 .61375 Mtetra
.603 .459 .658 r
.43107 .61375 .43679 .64778 .44795 .64422 .44216 .61067 Mtetra
.649 .492 .656 r
.44216 .61067 .44795 .64422 .4593 .63273 .45341 .60178 Mtetra
.686 .522 .659 r
.45341 .60178 .4593 .63273 .47073 .61515 .46475 .58833 Mtetra
.715 .551 .666 r
.46475 .58833 .47073 .61515 .48217 .5944 .47611 .5724 Mtetra
.738 .581 .679 r
.47611 .5724 .48217 .5944 .49353 .57348 .48743 .55619 Mtetra
.754 .612 .702 r
.48743 .55619 .49353 .57348 .50481 .55469 .4987 .54141 Mtetra
.763 .647 .734 r
.4987 .54141 .50481 .55469 .51603 .5392 .50993 .52899 Mtetra
.763 .685 .777 r
.50993 .52899 .51603 .5392 .52722 .52719 .52115 .51911 Mtetra
.752 .722 .824 r
.52115 .51911 .52722 .52719 .5384 .51818 .53237 .51145 Mtetra
.731 .751 .869 r
.53237 .51145 .5384 .51818 .54961 .51138 .54362 .50544 Mtetra
.707 .771 .902 r
.54362 .50544 .54961 .51138 .56086 .50605 .55491 .50053 Mtetra
.687 .781 .923 r
.55491 .50053 .56086 .50605 .57216 .50156 .56624 .49627 Mtetra
.674 .786 .934 r
.56624 .49627 .57216 .50156 .5835 .49754 .57762 .49235 Mtetra
.666 .789 .94 r
.57762 .49235 .5835 .49754 .59489 .49374 .58905 .4886 Mtetra
.663 .791 .943 r
.58905 .4886 .59489 .49374 .60633 .49003 .60053 .48492 Mtetra
.661 .793 .945 r
.60053 .48492 .60633 .49003 .61782 .48634 .61205 .48125 Mtetra
.661 .794 .946 r
.61205 .48125 .61782 .48634 .62935 .48265 .62362 .47756 Mtetra
.662 .796 .946 r
.62362 .47756 .62935 .48265 .64093 .47893 .63524 .47383 Mtetra
.663 .797 .946 r
.63524 .47383 .64093 .47893 .65255 .47517 .64691 .47004 Mtetra
.665 .797 .945 r
.64691 .47004 .65255 .47517 .66422 .47136 .65861 .46619 Mtetra
.668 .798 .944 r
.65861 .46619 .66422 .47136 .67594 .46748 .67037 .46226 Mtetra
.67 .797 .943 r
.67037 .46226 .67594 .46748 .6877 .46355 .68217 .45826 Mtetra
.673 .797 .941 r
.68217 .45826 .6877 .46355 .6995 .45954 .69401 .45417 Mtetra
.676 .795 .939 r
.69401 .45417 .6995 .45954 .71135 .45547 .70589 .45 Mtetra
.678 .793 .936 r
.70589 .45 .71135 .45547 .72324 .45134 .71782 .44576 Mtetra
.68 .791 .933 r
.71782 .44576 .72324 .45134 .73518 .44716 .72979 .44145 Mtetra
.681 .788 .931 r
.72979 .44145 .73518 .44716 .74716 .44292 .74181 .43709 Mtetra
.682 .785 .928 r
.74181 .43709 .74716 .44292 .75919 .43866 .75387 .43268 Mtetra
.683 .781 .925 r
.75387 .43268 .75919 .43866 .77126 .43436 .76597 .42825 Mtetra
.683 .778 .923 r
.76597 .42825 .77126 .43436 .78338 .43005 .77813 .42381 Mtetra
.683 .774 .92 r
.77813 .42381 .78338 .43005 .79555 .42574 .79033 .41936 Mtetra
.682 .77 .918 r
.79033 .41936 .79555 .42574 .80777 .42142 .80258 .41492 Mtetra
.681 .767 .916 r
.80258 .41492 .80777 .42142 .82004 .41712 .81488 .41049 Mtetra
.68 .763 .914 r
.81488 .41049 .82004 .41712 .83236 .41282 .82723 .40608 Mtetra
.678 .76 .913 r
.82723 .40608 .83236 .41282 .84473 .40855 .83964 .4017 Mtetra
.677 .757 .912 r
.83964 .4017 .84473 .40855 .85716 .40429 .8521 .39735 Mtetra
.676 .755 .91 r
.8521 .39735 .85716 .40429 .86964 .40005 .86461 .39302 Mtetra
.674 .752 .91 r
.86461 .39302 .86964 .40005 .88217 .39583 .87718 .38872 Mtetra
.673 .75 .909 r
.87718 .38872 .88217 .39583 .89476 .39161 .88981 .38444 Mtetra
.672 .749 .908 r
.88981 .38444 .89476 .39161 .90741 .38741 .90249 .38017 Mtetra
.671 .747 .908 r
.90249 .38017 .90741 .38741 .92011 .38322 .91523 .37592 Mtetra
.67 .746 .907 r
.91523 .37592 .92011 .38322 .93287 .37903 .92803 .37167 Mtetra
.516 .663 .927 r
.34138 .55822 .34786 .5652 .35814 .56664 .35173 .55833 Mtetra
.462 .598 .902 r
.35173 .55833 .35814 .56664 .36839 .57021 .36209 .55986 Mtetra
.416 .523 .859 r
.36209 .55986 .36839 .57021 .37862 .57624 .37244 .56304 Mtetra
.399 .459 .806 r
.37244 .56304 .37862 .57624 .38886 .58459 .3828 .56777 Mtetra
.417 .422 .757 r
.3828 .56777 .38886 .58459 .39915 .59436 .39323 .57349 Mtetra
.46 .415 .72 r
.39323 .57349 .39915 .59436 .40958 .60391 .40375 .57907 Mtetra
.511 .426 .696 r
.40375 .57907 .40958 .60391 .42021 .61106 .41443 .58308 Mtetra
.561 .446 .68 r
.41443 .58308 .42021 .61106 .43107 .61375 .42529 .58409 Mtetra
.605 .471 .672 r
.42529 .58409 .43107 .61375 .44216 .61067 .43632 .58118 Mtetra
.642 .496 .669 r
.43632 .58118 .44216 .61067 .45341 .60178 .44749 .57429 Mtetra
.673 .522 .672 r
.44749 .57429 .45341 .60178 .46475 .58833 .45874 .56422 Mtetra
.698 .549 .681 r
.45874 .56422 .46475 .58833 .47611 .5724 .47002 .55235 Mtetra
.718 .578 .697 r
.47002 .55235 .47611 .5724 .48743 .55619 .4813 .54019 Mtetra
.733 .611 .722 r
.4813 .54019 .48743 .55619 .4987 .54141 .49256 .52892 Mtetra
.741 .648 .756 r
.49256 .52892 .4987 .54141 .50993 .52899 .5038 .51924 Mtetra
.741 .687 .798 r
.5038 .51924 .50993 .52899 .52115 .51911 .51504 .51128 Mtetra
.731 .724 .843 r
.51504 .51128 .52115 .51911 .53237 .51145 .5263 .50485 Mtetra
.714 .753 .883 r
.5263 .50485 .53237 .51145 .54362 .50544 .53758 .49958 Mtetra
.694 .772 .911 r
.53758 .49958 .54362 .50544 .55491 .50053 .54891 .49508 Mtetra
.678 .783 .929 r
.54891 .49508 .55491 .50053 .56624 .49627 .56028 .49103 Mtetra
.668 .789 .939 r
.56028 .49103 .56624 .49627 .57762 .49235 .5717 .48723 Mtetra
.662 .793 .944 r
.5717 .48723 .57762 .49235 .58905 .4886 .58317 .48355 Mtetra
.659 .795 .947 r
.58317 .48355 .58905 .4886 .60053 .48492 .59468 .47991 Mtetra
.658 .797 .949 r
.59468 .47991 .60053 .48492 .61205 .48125 .60625 .47626 Mtetra
.659 .8 .95 r
.60625 .47626 .61205 .48125 .62362 .47756 .61786 .47259 Mtetra
.66 .801 .951 r
.61786 .47259 .62362 .47756 .63524 .47383 .62951 .46885 Mtetra
.662 .803 .95 r
.62951 .46885 .63524 .47383 .64691 .47004 .64122 .46505 Mtetra
.665 .804 .95 r
.64122 .46505 .64691 .47004 .65861 .46619 .65297 .46116 Mtetra
.668 .804 .948 r
.65297 .46116 .65861 .46619 .67037 .46226 .66476 .45718 Mtetra
.671 .804 .946 r
.66476 .45718 .67037 .46226 .68217 .45826 .6766 .4531 Mtetra
.674 .804 .944 r
.6766 .4531 .68217 .45826 .69401 .45417 .68848 .44892 Mtetra
.678 .802 .942 r
.68848 .44892 .69401 .45417 .70589 .45 .7004 .44464 Mtetra
.681 .8 .939 r
.7004 .44464 .70589 .45 .71782 .44576 .71236 .44028 Mtetra
.683 .798 .936 r
.71236 .44028 .71782 .44576 .72979 .44145 .72437 .43584 Mtetra
.685 .794 .933 r
.72437 .43584 .72979 .44145 .74181 .43709 .73642 .43133 Mtetra
.686 .791 .929 r
.73642 .43133 .74181 .43709 .75387 .43268 .74851 .42678 Mtetra
.687 .787 .926 r
.74851 .42678 .75387 .43268 .76597 .42825 .76065 .4222 Mtetra
.687 .783 .924 r
.76065 .4222 .76597 .42825 .77813 .42381 .77283 .4176 Mtetra
.686 .778 .921 r
.77283 .4176 .77813 .42381 .79033 .41936 .78507 .41301 Mtetra
.685 .774 .919 r
.78507 .41301 .79033 .41936 .80258 .41492 .79735 .40842 Mtetra
.684 .77 .916 r
.79735 .40842 .80258 .41492 .81488 .41049 .80968 .40386 Mtetra
.683 .766 .915 r
.80968 .40386 .81488 .41049 .82723 .40608 .82207 .39933 Mtetra
.681 .762 .913 r
.82207 .39933 .82723 .40608 .83964 .4017 .83451 .39484 Mtetra
.679 .759 .912 r
.83451 .39484 .83964 .4017 .8521 .39735 .847 .39038 Mtetra
.678 .756 .91 r
.847 .39038 .8521 .39735 .86461 .39302 .85955 .38596 Mtetra
.676 .754 .909 r
.85955 .38596 .86461 .39302 .87718 .38872 .87215 .38157 Mtetra
.675 .751 .909 r
.87215 .38157 .87718 .38872 .88981 .38444 .88481 .37721 Mtetra
.673 .749 .908 r
.88481 .37721 .88981 .38444 .90249 .38017 .89753 .37287 Mtetra
.672 .748 .908 r
.89753 .37287 .90249 .38017 .91523 .37592 .91031 .36856 Mtetra
.671 .747 .907 r
.91031 .36856 .91523 .37592 .92803 .37167 .92315 .36426 Mtetra
.561 .694 .929 r
.33482 .5516 .34138 .55822 .35173 .55833 .34525 .55073 Mtetra
.53 .651 .912 r
.34525 .55073 .35173 .55833 .36209 .55986 .35569 .55074 Mtetra
.501 .597 .881 r
.35569 .55074 .36209 .55986 .37244 .56304 .36614 .55176 Mtetra
.486 .542 .839 r
.36614 .55176 .37244 .56304 .3828 .56777 .37662 .55374 Mtetra
.491 .5 .794 r
.37662 .55374 .3828 .56777 .39323 .57349 .38715 .55633 Mtetra
.513 .478 .755 r
.38715 .55633 .39323 .57349 .40375 .57907 .39777 .55884 Mtetra
.545 .473 .725 r
.39777 .55884 .40375 .57907 .41443 .58308 .4085 .56035 Mtetra
.579 .48 .706 r
.4085 .56035 .41443 .58308 .42529 .58409 .41937 .55994 Mtetra
.611 .494 .695 r
.41937 .55994 .42529 .58409 .43632 .58118 .43037 .55704 Mtetra
.64 .513 .692 r
.43037 .55704 .43632 .58118 .44749 .57429 .44148 .55158 Mtetra
.665 .534 .695 r
.44148 .55158 .44749 .57429 .45874 .56422 .45267 .54403 Mtetra
.687 .56 .705 r
.45267 .54403 .45874 .56422 .47002 .55235 .46389 .53528 Mtetra
.704 .589 .723 r
.46389 .53528 .47002 .55235 .4813 .54019 .47513 .52628 Mtetra
.717 .622 .75 r
.47513 .52628 .4813 .54019 .49256 .52892 .48638 .5178 Mtetra
.723 .659 .785 r
.48638 .5178 .49256 .52892 .5038 .51924 .49762 .51031 Mtetra
.722 .697 .826 r
.49762 .51031 .5038 .51924 .51504 .51128 .50889 .50392 Mtetra
.712 .732 .866 r
.50889 .50392 .51504 .51128 .5263 .50485 .52017 .49852 Mtetra
.697 .758 .899 r
.52017 .49852 .5263 .50485 .53758 .49958 .5315 .49386 Mtetra
.682 .775 .922 r
.5315 .49386 .53758 .49958 .54891 .49508 .54286 .48972 Mtetra
.669 .785 .936 r
.54286 .48972 .54891 .49508 .56028 .49103 .55427 .48587 Mtetra
.661 .791 .944 r
.55427 .48587 .56028 .49103 .5717 .48723 .56573 .4822 Mtetra
.657 .796 .949 r
.56573 .4822 .5717 .48723 .58317 .48355 .57724 .47859 Mtetra
.655 .799 .952 r
.57724 .47859 .58317 .48355 .59468 .47991 .58879 .475 Mtetra
.654 .802 .954 r
.58879 .475 .59468 .47991 .60625 .47626 .60039 .47139 Mtetra
.655 .804 .955 r
.60039 .47139 .60625 .47626 .61786 .47259 .61204 .46773 Mtetra
.657 .807 .955 r
.61204 .46773 .61786 .47259 .62951 .46885 .62374 .464 Mtetra
.66 .809 .955 r
.62374 .464 .62951 .46885 .64122 .46505 .63549 .46019 Mtetra
.663 .81 .954 r
.63549 .46019 .64122 .46505 .65297 .46116 .64727 .45626 Mtetra
.668 .811 .952 r
.64727 .45626 .65297 .46116 .66476 .45718 .65911 .45223 Mtetra
.672 .811 .95 r
.65911 .45223 .66476 .45718 .6766 .4531 .67098 .44807 Mtetra
.676 .811 .947 r
.67098 .44807 .6766 .4531 .68848 .44892 .6829 .44379 Mtetra
.68 .809 .944 r
.6829 .44379 .68848 .44892 .7004 .44464 .69486 .4394 Mtetra
.684 .807 .941 r
.69486 .4394 .7004 .44464 .71236 .44028 .70686 .4349 Mtetra
.687 .804 .938 r
.70686 .4349 .71236 .44028 .72437 .43584 .7189 .43031 Mtetra
.689 .8 .934 r
.7189 .43031 .72437 .43584 .73642 .43133 .73099 .42565 Mtetra
.69 .796 .931 r
.73099 .42565 .73642 .43133 .74851 .42678 .74312 .42094 Mtetra
.691 .792 .927 r
.74312 .42094 .74851 .42678 .76065 .4222 .75529 .41619 Mtetra
.691 .787 .924 r
.75529 .41619 .76065 .4222 .77283 .4176 .7675 .41143 Mtetra
.69 .783 .921 r
.7675 .41143 .77283 .4176 .78507 .41301 .77977 .40667 Mtetra
.689 .778 .919 r
.77977 .40667 .78507 .41301 .79735 .40842 .79208 .40194 Mtetra
.688 .773 .917 r
.79208 .40194 .79735 .40842 .80968 .40386 .80445 .39723 Mtetra
.686 .769 .915 r
.80445 .39723 .80968 .40386 .82207 .39933 .81686 .39257 Mtetra
.684 .765 .913 r
.81686 .39257 .82207 .39933 .83451 .39484 .82933 .38795 Mtetra
.682 .761 .911 r
.82933 .38795 .83451 .39484 .847 .39038 .84186 .38338 Mtetra
.68 .758 .91 r
.84186 .38338 .847 .39038 .85955 .38596 .85444 .37885 Mtetra
.678 .755 .909 r
.85444 .37885 .85955 .38596 .87215 .38157 .86708 .37437 Mtetra
.676 .752 .909 r
.86708 .37437 .87215 .38157 .88481 .37721 .87978 .36993 Mtetra
.674 .75 .908 r
.87978 .36993 .88481 .37721 .89753 .37287 .89254 .36553 Mtetra
.673 .748 .907 r
.89254 .36553 .89753 .37287 .91031 .36856 .90535 .36115 Mtetra
.672 .747 .907 r
.90535 .36115 .91031 .36856 .92315 .36426 .91823 .35679 Mtetra
.589 .715 .93 r
.3282 .54527 .33482 .5516 .34525 .55073 .33868 .54374 Mtetra
.572 .688 .919 r
.33868 .54374 .34525 .55073 .35569 .55074 .34919 .54269 Mtetra
.556 .651 .898 r
.34919 .54269 .35569 .55074 .36614 .55176 .35973 .54222 Mtetra
.546 .609 .867 r
.35973 .54222 .36614 .55176 .37662 .55374 .3703 .54228 Mtetra
.546 .57 .83 r
.3703 .54228 .37662 .55374 .38715 .55633 .38093 .54267 Mtetra
.557 .542 .794 r
.38093 .54267 .38715 .55633 .39777 .55884 .39162 .54299 Mtetra
.575 .527 .764 r
.39162 .54299 .39777 .55884 .4085 .56035 .40241 .54269 Mtetra
.598 .524 .743 r
.40241 .54269 .4085 .56035 .41937 .55994 .41329 .54124 Mtetra
.621 .53 .73 r
.41329 .54124 .41937 .55994 .43037 .55704 .42428 .53827 Mtetra
.643 .543 .726 r
.42428 .53827 .43037 .55704 .44148 .55158 .43535 .53375 Mtetra
.663 .561 .729 r
.43535 .53375 .44148 .55158 .45267 .54403 .4465 .52796 Mtetra
.681 .584 .74 r
.4465 .52796 .45267 .54403 .46389 .53528 .45769 .5214 Mtetra
.695 .612 .76 r
.45769 .5214 .46389 .53528 .47513 .52628 .46891 .51466 Mtetra
.704 .645 .787 r
.46891 .51466 .47513 .52628 .48638 .5178 .48014 .5082 Mtetra
.708 .68 .821 r
.48014 .5082 .48638 .5178 .49762 .51031 .4914 .50232 Mtetra
.704 .714 .856 r
.4914 .50232 .49762 .51031 .50889 .50392 .50269 .4971 Mtetra
.695 .743 .889 r
.50269 .4971 .50889 .50392 .52017 .49852 .514 .49247 Mtetra
.682 .765 .914 r
.514 .49247 .52017 .49852 .5315 .49386 .52536 .4883 Mtetra
.67 .779 .931 r
.52536 .4883 .5315 .49386 .54286 .48972 .53676 .48445 Mtetra
.661 .788 .942 r
.53676 .48445 .54286 .48972 .55427 .48587 .54821 .48079 Mtetra
.655 .794 .949 r
.54821 .48079 .55427 .48587 .56573 .4822 .55971 .47723 Mtetra
.651 .798 .953 r
.55971 .47723 .56573 .4822 .57724 .47859 .57125 .47371 Mtetra
.65 .802 .956 r
.57125 .47371 .57724 .47859 .58879 .475 .58285 .47018 Mtetra
.65 .806 .958 r
.58285 .47018 .58879 .475 .60039 .47139 .59449 .46662 Mtetra
.652 .809 .959 r
.59449 .46662 .60039 .47139 .61204 .46773 .60618 .46299 Mtetra
.654 .812 .959 r
.60618 .46299 .61204 .46773 .62374 .464 .61792 .45927 Mtetra
.658 .814 .959 r
.61792 .45927 .62374 .464 .63549 .46019 .62971 .45544 Mtetra
.662 .816 .957 r
.62971 .45544 .63549 .46019 .64727 .45626 .64154 .45149 Mtetra
.667 .817 .955 r
.64154 .45149 .64727 .45626 .65911 .45223 .65341 .44739 Mtetra
.673 .818 .953 r
.65341 .44739 .65911 .45223 .67098 .44807 .66533 .44315 Mtetra
.678 .817 .95 r
.66533 .44315 .67098 .44807 .6829 .44379 .67729 .43877 Mtetra
.683 .816 .946 r
.67729 .43877 .6829 .44379 .69486 .4394 .68928 .43425 Mtetra
.687 .813 .943 r
.68928 .43425 .69486 .4394 .70686 .4349 .70132 .42961 Mtetra
.691 .81 .939 r
.70132 .42961 .70686 .4349 .7189 .43031 .7134 .42486 Mtetra
.693 .806 .935 r
.7134 .42486 .7189 .43031 .73099 .42565 .72552 .42003 Mtetra
.695 .802 .931 r
.72552 .42003 .73099 .42565 .74312 .42094 .73768 .41514 Mtetra
.696 .797 .928 r
.73768 .41514 .74312 .42094 .75529 .41619 .74988 .41022 Mtetra
.696 .792 .924 r
.74988 .41022 .75529 .41619 .7675 .41143 .76213 .40528 Mtetra
.695 .787 .921 r
.76213 .40528 .7675 .41143 .77977 .40667 .77443 .40035 Mtetra
.693 .781 .919 r
.77443 .40035 .77977 .40667 .79208 .40194 .78677 .39545 Mtetra
.691 .776 .916 r
.78677 .39545 .79208 .40194 .80445 .39723 .79917 .39059 Mtetra
.689 .772 .914 r
.79917 .39059 .80445 .39723 .81686 .39257 .81162 .38578 Mtetra
.687 .767 .913 r
.81162 .38578 .81686 .39257 .82933 .38795 .82412 .38103 Mtetra
.684 .763 .911 r
.82412 .38103 .82933 .38795 .84186 .38338 .83668 .37634 Mtetra
.682 .759 .91 r
.83668 .37634 .84186 .38338 .85444 .37885 .8493 .37171 Mtetra
.68 .756 .909 r
.8493 .37171 .85444 .37885 .86708 .37437 .86197 .36713 Mtetra
.678 .753 .908 r
.86197 .36713 .86708 .37437 .87978 .36993 .87471 .3626 Mtetra
.676 .751 .908 r
.87471 .3626 .87978 .36993 .89254 .36553 .8875 .35812 Mtetra
.674 .749 .907 r
.8875 .35812 .89254 .36553 .90535 .36115 .90035 .35368 Mtetra
.673 .747 .907 r
.90035 .35368 .90535 .36115 .91823 .35679 .91326 .34926 Mtetra
.606 .728 .931 r
.32152 .53914 .3282 .54527 .33868 .54374 .33205 .53719 Mtetra
.598 .712 .924 r
.33205 .53719 .33868 .54374 .34919 .54269 .34261 .53547 Mtetra
.59 .689 .911 r
.34261 .53547 .34919 .54269 .35973 .54222 .35321 .53404 Mtetra
.585 .661 .89 r
.35321 .53404 .35973 .54222 .3703 .54228 .36386 .53286 Mtetra
.585 .631 .864 r
.36386 .53286 .3703 .54228 .38093 .54267 .37455 .53184 Mtetra
.59 .605 .835 r
.37455 .53184 .38093 .54267 .39162 .54299 .38531 .53073 Mtetra
.602 .586 .808 r
.38531 .53073 .39162 .54299 .40241 .54269 .39614 .52924 Mtetra
.616 .577 .788 r
.39614 .52924 .40241 .54269 .41329 .54124 .40705 .52707 Mtetra
.632 .577 .775 r
.40705 .52707 .41329 .54124 .42428 .53827 .41804 .52404 Mtetra
.649 .585 .77 r
.41804 .52404 .42428 .53827 .43535 .53375 .42911 .52011 Mtetra
.664 .6 .773 r
.42911 .52011 .43535 .53375 .4465 .52796 .44023 .51544 Mtetra
.677 .62 .785 r
.44023 .51544 .4465 .52796 .45769 .5214 .4514 .51032 Mtetra
.687 .646 .804 r
.4514 .51032 .45769 .5214 .46891 .51466 .46261 .50507 Mtetra
.692 .675 .829 r
.46261 .50507 .46891 .51466 .48014 .5082 .47385 .49996 Mtetra
.692 .705 .857 r
.47385 .49996 .48014 .5082 .4914 .50232 .48513 .49517 Mtetra
.687 .733 .885 r
.48513 .49517 .4914 .50232 .50269 .4971 .49644 .49075 Mtetra
.678 .755 .909 r
.49644 .49075 .50269 .4971 .514 .49247 .50778 .48668 Mtetra
.668 .771 .927 r
.50778 .48668 .514 .49247 .52536 .4883 .51917 .48287 Mtetra
.659 .783 .94 r
.51917 .48287 .52536 .4883 .53676 .48445 .53061 .47925 Mtetra
.653 .79 .948 r
.53061 .47925 .53676 .48445 .54821 .48079 .5421 .47575 Mtetra
.648 .796 .953 r
.5421 .47575 .54821 .48079 .55971 .47723 .55363 .47231 Mtetra
.645 .8 .957 r
.55363 .47231 .55971 .47723 .57125 .47371 .56522 .46889 Mtetra
.645 .805 .96 r
.56522 .46889 .57125 .47371 .58285 .47018 .57685 .46544 Mtetra
.645 .809 .962 r
.57685 .46544 .58285 .47018 .59449 .46662 .58854 .46193 Mtetra
.647 .812 .963 r
.58854 .46193 .59449 .46662 .60618 .46299 .60027 .45834 Mtetra
.651 .816 .963 r
.60027 .45834 .60618 .46299 .61792 .45927 .61205 .45464 Mtetra
.656 .819 .962 r
.61205 .45464 .61792 .45927 .62971 .45544 .62388 .4508 Mtetra
.661 .821 .96 r
.62388 .4508 .62971 .45544 .64154 .45149 .63575 .44681 Mtetra
.667 .823 .958 r
.63575 .44681 .64154 .45149 .65341 .44739 .64767 .44266 Mtetra
.674 .824 .955 r
.64767 .44266 .65341 .44739 .66533 .44315 .65963 .43833 Mtetra
.68 .823 .952 r
.65963 .43833 .66533 .44315 .67729 .43877 .67162 .43384 Mtetra
.686 .822 .948 r
.67162 .43384 .67729 .43877 .68928 .43425 .68366 .42918 Mtetra
.691 .819 .944 r
.68366 .42918 .68928 .43425 .70132 .42961 .69574 .42439 Mtetra
.695 .816 .94 r
.69574 .42439 .70132 .42961 .7134 .42486 .70785 .41947 Mtetra
.698 .812 .935 r
.70785 .41947 .7134 .42486 .72552 .42003 .72001 .41446 Mtetra
.7 .807 .931 r
.72001 .41446 .72552 .42003 .73768 .41514 .7322 .40938 Mtetra
.701 .801 .928 r
.7322 .40938 .73768 .41514 .74988 .41022 .74444 .40427 Mtetra
.7 .796 .924 r
.74444 .40427 .74988 .41022 .76213 .40528 .75672 .39914 Mtetra
.699 .79 .921 r
.75672 .39914 .76213 .40528 .77443 .40035 .76905 .39403 Mtetra
.698 .785 .918 r
.76905 .39403 .77443 .40035 .78677 .39545 .78142 .38895 Mtetra
.695 .779 .916 r
.78142 .38895 .78677 .39545 .79917 .39059 .79385 .38393 Mtetra
.693 .774 .914 r
.79385 .38393 .79917 .39059 .81162 .38578 .80633 .37897 Mtetra
.69 .769 .912 r
.80633 .37897 .81162 .38578 .82412 .38103 .81887 .37408 Mtetra
.687 .765 .911 r
.81887 .37408 .82412 .38103 .83668 .37634 .83146 .36926 Mtetra
.684 .761 .91 r
.83146 .36926 .83668 .37634 .8493 .37171 .84411 .36452 Mtetra
.682 .757 .909 r
.84411 .36452 .8493 .37171 .86197 .36713 .85682 .35984 Mtetra
.679 .754 .908 r
.85682 .35984 .86197 .36713 .87471 .3626 .86959 .35522 Mtetra
.677 .752 .907 r
.86959 .35522 .87471 .3626 .8875 .35812 .88242 .35066 Mtetra
.675 .75 .907 r
.88242 .35066 .8875 .35812 .90035 .35368 .89531 .34614 Mtetra
.673 .748 .907 r
.89531 .34614 .90035 .35368 .91326 .34926 .90826 .34166 Mtetra
.615 .735 .932 r
.31478 .5331 .32152 .53914 .33205 .53719 .32534 .5309 Mtetra
.612 .727 .927 r
.32534 .5309 .33205 .53719 .34261 .53547 .33595 .52879 Mtetra
.609 .714 .919 r
.33595 .52879 .34261 .53547 .35321 .53404 .3466 .52679 Mtetra
.608 .697 .907 r
.3466 .52679 .35321 .53404 .36386 .53286 .3573 .52489 Mtetra
.609 .678 .89 r
.3573 .52489 .36386 .53286 .37455 .53184 .36805 .52301 Mtetra
.614 .658 .87 r
.36805 .52301 .37455 .53184 .38531 .53073 .37886 .52104 Mtetra
.621 .643 .851 r
.37886 .52104 .38531 .53073 .39614 .52924 .38973 .51884 Mtetra
.631 .633 .834 r
.38973 .51884 .39614 .52924 .40705 .52707 .40067 .51625 Mtetra
.642 .631 .823 r
.40067 .51625 .40705 .52707 .41804 .52404 .41167 .51316 Mtetra
.653 .635 .819 r
.41167 .51316 .41804 .52404 .42911 .52011 .42274 .50958 Mtetra
.664 .646 .822 r
.42274 .50958 .42911 .52011 .44023 .51544 .43386 .50559 Mtetra
.672 .663 .832 r
.43386 .50559 .44023 .51544 .4514 .51032 .44504 .50134 Mtetra
.678 .683 .848 r
.44504 .50134 .4514 .51032 .46261 .50507 .45625 .49701 Mtetra
.68 .706 .868 r
.45625 .49701 .46261 .50507 .47385 .49996 .4675 .49275 Mtetra
.678 .729 .889 r
.4675 .49275 .47385 .49996 .48513 .49517 .4788 .48866 Mtetra
.672 .749 .908 r
.4788 .48866 .48513 .49517 .49644 .49075 .49013 .48477 Mtetra
.664 .764 .924 r
.49013 .48477 .49644 .49075 .50778 .48668 .50151 .48107 Mtetra
.657 .776 .937 r
.50151 .48107 .50778 .48668 .51917 .48287 .51294 .47753 Mtetra
.65 .785 .946 r
.51294 .47753 .51917 .48287 .53061 .47925 .52441 .47411 Mtetra
.645 .791 .953 r
.52441 .47411 .53061 .47925 .5421 .47575 .53593 .47076 Mtetra
.641 .797 .957 r
.53593 .47076 .5421 .47575 .55363 .47231 .5475 .46743 Mtetra
.639 .801 .961 r
.5475 .46743 .55363 .47231 .56522 .46889 .55913 .46411 Mtetra
.639 .806 .963 r
.55913 .46411 .56522 .46889 .57685 .46544 .5708 .46074 Mtetra
.64 .811 .965 r
.5708 .46074 .57685 .46544 .58854 .46193 .58253 .4573 Mtetra
.643 .815 .966 r
.58253 .4573 .58854 .46193 .60027 .45834 .59431 .45376 Mtetra
.647 .819 .966 r
.59431 .45376 .60027 .45834 .61205 .45464 .60613 .45008 Mtetra
.653 .823 .965 r
.60613 .45008 .61205 .45464 .62388 .4508 .618 .44624 Mtetra
.66 .826 .963 r
.618 .44624 .62388 .4508 .63575 .44681 .62992 .44221 Mtetra
.668 .827 .96 r
.62992 .44221 .63575 .44681 .64767 .44266 .64188 .438 Mtetra
.675 .828 .957 r
.64188 .438 .64767 .44266 .65963 .43833 .65388 .43358 Mtetra
.683 .828 .953 r
.65388 .43358 .65963 .43833 .67162 .43384 .66592 .42897 Mtetra
.69 .826 .949 r
.66592 .42897 .67162 .43384 .68366 .42918 .67799 .42417 Mtetra
.695 .824 .944 r
.67799 .42417 .68366 .42918 .69574 .42439 .69011 .41921 Mtetra
.7 .82 .939 r
.69011 .41921 .69574 .42439 .70785 .41947 .70226 .41411 Mtetra
.703 .816 .935 r
.70226 .41411 .70785 .41947 .72001 .41446 .71445 .40891 Mtetra
.705 .811 .931 r
.71445 .40891 .72001 .41446 .7322 .40938 .72668 .40364 Mtetra
.706 .805 .927 r
.72668 .40364 .7322 .40938 .74444 .40427 .73895 .39832 Mtetra
.706 .799 .923 r
.73895 .39832 .74444 .40427 .75672 .39914 .75126 .393 Mtetra
.704 .793 .92 r
.75126 .393 .75672 .39914 .76905 .39403 .76362 .38769 Mtetra
.702 .787 .917 r
.76362 .38769 .76905 .39403 .78142 .38895 .77603 .38243 Mtetra
.699 .782 .915 r
.77603 .38243 .78142 .38895 .79385 .38393 .78849 .37724 Mtetra
.696 .776 .913 r
.78849 .37724 .79385 .38393 .80633 .37897 .80101 .37212 Mtetra
.693 .771 .911 r
.80101 .37212 .80633 .37897 .81887 .37408 .81357 .36708 Mtetra
.69 .766 .91 r
.81357 .36708 .81887 .37408 .83146 .36926 .8262 .36213 Mtetra
.687 .762 .909 r
.8262 .36213 .83146 .36926 .84411 .36452 .83889 .35727 Mtetra
.684 .758 .908 r
.83889 .35727 .84411 .36452 .85682 .35984 .85163 .35249 Mtetra
.681 .755 .907 r
.85163 .35249 .85682 .35984 .86959 .35522 .86444 .34778 Mtetra
.678 .752 .907 r
.86444 .34778 .86959 .35522 .88242 .35066 .8773 .34314 Mtetra
.676 .75 .907 r
.8773 .34314 .88242 .35066 .89531 .34614 .89023 .33855 Mtetra
.674 .748 .906 r
.89023 .33855 .89531 .34614 .90826 .34166 .90322 .33401 Mtetra
.619 .739 .932 r
.30798 .52707 .31478 .5331 .32534 .5309 .31858 .52473 Mtetra
.619 .735 .929 r
.31858 .52473 .32534 .5309 .33595 .52879 .32922 .52241 Mtetra
.619 .728 .924 r
.32922 .52241 .33595 .52879 .3466 .52679 .33991 .52009 Mtetra
.62 .72 .917 r
.33991 .52009 .3466 .52679 .3573 .52489 .35065 .51779 Mtetra
.623 .709 .907 r
.35065 .51779 .3573 .52489 .36805 .52301 .36145 .51544 Mtetra
.627 .697 .896 r
.36145 .51544 .36805 .52301 .37886 .52104 .3723 .51301 Mtetra
.633 .687 .883 r
.3723 .51301 .37886 .52104 .38973 .51884 .3832 .51041 Mtetra
.64 .681 .873 r
.3832 .51041 .38973 .51884 .40067 .51625 .39417 .50758 Mtetra
.647 .678 .865 r
.39417 .50758 .40067 .51625 .41167 .51316 .40519 .50448 Mtetra
.655 .681 .863 r
.40519 .50448 .41167 .51316 .42274 .50958 .41627 .5011 Mtetra
.661 .689 .865 r
.41627 .5011 .42274 .50958 .43386 .50559 .42741 .4975 Mtetra
.666 .701 .873 r
.42741 .4975 .43386 .50559 .44504 .50134 .43859 .49375 Mtetra
.668 .715 .884 r
.43859 .49375 .44504 .50134 .45625 .49701 .44982 .48996 Mtetra
.667 .731 .897 r
.44982 .48996 .45625 .49701 .4675 .49275 .46109 .48621 Mtetra
.664 .746 .911 r
.46109 .48621 .4675 .49275 .4788 .48866 .47241 .48254 Mtetra
.659 .759 .924 r
.47241 .48254 .4788 .48866 .49013 .48477 .48377 .479 Mtetra
.653 .77 .935 r
.48377 .479 .49013 .48477 .50151 .48107 .49518 .47557 Mtetra
.647 .779 .944 r
.49518 .47557 .50151 .48107 .51294 .47753 .50664 .47223 Mtetra
.641 .785 .951 r
.50664 .47223 .51294 .47753 .52441 .47411 .51815 .46898 Mtetra
.637 .791 .956 r
.51815 .46898 .52441 .47411 .53593 .47076 .52971 .46576 Mtetra
.634 .796 .961 r
.52971 .46576 .53593 .47076 .5475 .46743 .54132 .46256 Mtetra
.632 .801 .964 r
.54132 .46256 .5475 .46743 .55913 .46411 .55299 .45935 Mtetra
.632 .807 .966 r
.55299 .45935 .55913 .46411 .5708 .46074 .5647 .45607 Mtetra
.635 .812 .968 r
.5647 .45607 .5708 .46074 .58253 .4573 .57647 .4527 Mtetra
.638 .817 .968 r
.57647 .4527 .58253 .4573 .59431 .45376 .58829 .44921 Mtetra
.644 .821 .968 r
.58829 .44921 .59431 .45376 .60613 .45008 .60016 .44555 Mtetra
.651 .825 .967 r
.60016 .44555 .60613 .45008 .618 .44624 .61207 .44171 Mtetra
.66 .828 .964 r
.61207 .44171 .618 .44624 .62992 .44221 .62403 .43765 Mtetra
.669 .831 .961 r
.62403 .43765 .62992 .44221 .64188 .438 .63603 .43337 Mtetra
.677 .832 .958 r
.63603 .43337 .64188 .438 .65388 .43358 .64808 .42885 Mtetra
.686 .832 .953 r
.64808 .42885 .65388 .43358 .66592 .42897 .66016 .42411 Mtetra
.694 .83 .948 r
.66016 .42411 .66592 .42897 .67799 .42417 .67227 .41917 Mtetra
.7 .827 .943 r
.67227 .41917 .67799 .42417 .69011 .41921 .68443 .41404 Mtetra
.705 .824 .938 r
.68443 .41404 .69011 .41921 .70226 .41411 .69662 .40875 Mtetra
.709 .819 .934 r
.69662 .40875 .70226 .41411 .71445 .40891 .70884 .40335 Mtetra
.711 .814 .929 r
.70884 .40335 .71445 .40891 .72668 .40364 .72111 .39787 Mtetra
.711 .808 .925 r
.72111 .39787 .72668 .40364 .73895 .39832 .73341 .39235 Mtetra
.711 .802 .921 r
.73341 .39235 .73895 .39832 .75126 .393 .74576 .38682 Mtetra
.709 .796 .918 r
.74576 .38682 .75126 .393 .76362 .38769 .75815 .38132 Mtetra
.707 .789 .916 r
.75815 .38132 .76362 .38769 .77603 .38243 .7706 .37587 Mtetra
.704 .783 .913 r
.7706 .37587 .77603 .38243 .78849 .37724 .78309 .3705 Mtetra
.7 .778 .912 r
.78309 .3705 .78849 .37724 .80101 .37212 .79563 .36521 Mtetra
.697 .772 .91 r
.79563 .36521 .80101 .37212 .81357 .36708 .80823 .36003 Mtetra
.693 .767 .909 r
.80823 .36003 .81357 .36708 .8262 .36213 .82089 .35495 Mtetra
.689 .763 .908 r
.82089 .35495 .8262 .36213 .83889 .35727 .83361 .34997 Mtetra
.686 .759 .907 r
.83361 .34997 .83889 .35727 .85163 .35249 .84639 .34508 Mtetra
.683 .756 .907 r
.84639 .34508 .85163 .35249 .86444 .34778 .85924 .34028 Mtetra
.68 .753 .906 r
.85924 .34028 .86444 .34778 .8773 .34314 .87214 .33555 Mtetra
.677 .75 .906 r
.87214 .33555 .8773 .34314 .89023 .33855 .88511 .33089 Mtetra
.675 .748 .906 r
.88511 .33089 .89023 .33855 .90322 .33401 .89814 .32628 Mtetra
.622 .739 .931 r
.30114 .52098 .30798 .52707 .31858 .52473 .31176 .51857 Mtetra
.623 .738 .929 r
.31176 .51857 .31858 .52473 .32922 .52241 .32243 .51613 Mtetra
.624 .735 .926 r
.32243 .51613 .32922 .52241 .33991 .52009 .33316 .51366 Mtetra
.626 .731 .923 r
.33316 .51366 .33991 .52009 .35065 .51779 .34393 .51114 Mtetra
.629 .726 .917 r
.34393 .51114 .35065 .51779 .36145 .51544 .35476 .50856 Mtetra
.633 .721 .911 r
.35476 .50856 .36145 .51544 .3723 .51301 .36564 .50589 Mtetra
.637 .716 .904 r
.36564 .50589 .3723 .51301 .3832 .51041 .37658 .5031 Mtetra
.642 .713 .898 r
.37658 .5031 .3832 .51041 .39417 .50758 .38757 .50016 Mtetra
.647 .712 .894 r
.38757 .50016 .39417 .50758 .40519 .50448 .39862 .49705 Mtetra
.652 .714 .893 r
.39862 .49705 .40519 .50448 .41627 .5011 .40972 .49379 Mtetra
.656 .719 .895 r
.40972 .49379 .41627 .5011 .42741 .4975 .42088 .49041 Mtetra
.658 .727 .9 r
.42088 .49041 .42741 .4975 .43859 .49375 .43208 .48695 Mtetra
.658 .736 .908 r
.43208 .48695 .43859 .49375 .44982 .48996 .44333 .48347 Mtetra
.656 .746 .916 r
.44333 .48347 .44982 .48996 .46109 .48621 .45463 .48002 Mtetra
.653 .756 .925 r
.45463 .48002 .46109 .48621 .47241 .48254 .46597 .47663 Mtetra
.648 .765 .934 r
.46597 .47663 .47241 .48254 .48377 .479 .47736 .47332 Mtetra
.643 .772 .942 r
.47736 .47332 .48377 .479 .49518 .47557 .4888 .47008 Mtetra
.638 .778 .948 r
.4888 .47008 .49518 .47557 .50664 .47223 .50029 .46692 Mtetra
.633 .784 .954 r
.50029 .46692 .50664 .47223 .51815 .46898 .51184 .46382 Mtetra
.629 .79 .959 r
.51184 .46382 .51815 .46898 .52971 .46576 .52343 .46075 Mtetra
.627 .795 .963 r
.52343 .46075 .52971 .46576 .54132 .46256 .53508 .45767 Mtetra
.626 .8 .966 r
.53508 .45767 .54132 .46256 .55299 .45935 .54679 .45457 Mtetra
.626 .806 .969 r
.54679 .45457 .55299 .45935 .5647 .45607 .55854 .45139 Mtetra
.629 .811 .97 r
.55854 .45139 .5647 .45607 .57647 .4527 .57036 .4481 Mtetra
.634 .817 .97 r
.57036 .4481 .57647 .4527 .58829 .44921 .58222 .44466 Mtetra
.641 .822 .97 r
.58222 .44466 .58829 .44921 .60016 .44555 .59413 .44103 Mtetra
.65 .826 .968 r
.59413 .44103 .60016 .44555 .61207 .44171 .60609 .43717 Mtetra
.66 .83 .965 r
.60609 .43717 .61207 .44171 .62403 .43765 .61809 .43308 Mtetra
.67 .832 .961 r
.61809 .43308 .62403 .43765 .63603 .43337 .63014 .42872 Mtetra
.68 .834 .957 r
.63014 .42872 .63603 .43337 .64808 .42885 .64222 .42411 Mtetra
.69 .833 .952 r
.64222 .42411 .64808 .42885 .66016 .42411 .65435 .41924 Mtetra
.698 .832 .947 r
.65435 .41924 .66016 .42411 .67227 .41917 .6665 .41414 Mtetra
.705 .829 .942 r
.6665 .41414 .67227 .41917 .68443 .41404 .6787 .40883 Mtetra
.71 .825 .936 r
.6787 .40883 .68443 .41404 .69662 .40875 .69092 .40335 Mtetra
.714 .821 .931 r
.69092 .40335 .69662 .40875 .70884 .40335 .70319 .39775 Mtetra
.716 .815 .927 r
.70319 .39775 .70884 .40335 .72111 .39787 .71549 .39205 Mtetra
.717 .809 .923 r
.71549 .39205 .72111 .39787 .73341 .39235 .72783 .38632 Mtetra
.716 .803 .919 r
.72783 .38632 .73341 .39235 .74576 .38682 .74021 .38058 Mtetra
.714 .797 .916 r
.74021 .38058 .74576 .38682 .75815 .38132 .75264 .37488 Mtetra
.711 .791 .913 r
.75264 .37488 .75815 .38132 .7706 .37587 .76511 .36924 Mtetra
.708 .784 .911 r
.76511 .36924 .7706 .37587 .78309 .3705 .77763 .36369 Mtetra
.704 .779 .91 r
.77763 .36369 .78309 .3705 .79563 .36521 .79021 .35825 Mtetra
.7 .773 .909 r
.79021 .35825 .79563 .36521 .80823 .36003 .80285 .35291 Mtetra
.696 .768 .908 r
.80285 .35291 .80823 .36003 .82089 .35495 .81554 .3477 Mtetra
.692 .764 .907 r
.81554 .3477 .82089 .35495 .83361 .34997 .8283 .3426 Mtetra
.688 .76 .906 r
.8283 .3426 .83361 .34997 .84639 .34508 .84111 .3376 Mtetra
.684 .756 .906 r
.84111 .3376 .84639 .34508 .85924 .34028 .85399 .33271 Mtetra
.681 .753 .906 r
.85399 .33271 .85924 .34028 .87214 .33555 .86694 .3279 Mtetra
.678 .751 .906 r
.86694 .3279 .87214 .33555 .88511 .33089 .87994 .32316 Mtetra
.676 .749 .906 r
.87994 .32316 .88511 .33089 .89814 .32628 .89301 .31849 Mtetra
.623 .738 .929 r
.29424 .51481 .30114 .52098 .31176 .51857 .30489 .51235 Mtetra
.625 .738 .928 r
.30489 .51235 .31176 .51857 .32243 .51613 .31559 .50985 Mtetra
.627 .737 .927 r
.31559 .50985 .32243 .51613 .33316 .51366 .32634 .50729 Mtetra
.629 .736 .924 r
.32634 .50729 .33316 .51366 .34393 .51114 .33715 .50467 Mtetra
.632 .734 .922 r
.33715 .50467 .34393 .51114 .35476 .50856 .34801 .50198 Mtetra
.635 .732 .918 r
.34801 .50198 .35476 .50856 .36564 .50589 .35892 .4992 Mtetra
.639 .731 .915 r
.35892 .4992 .36564 .50589 .37658 .5031 .36988 .49632 Mtetra
.642 .73 .912 r
.36988 .49632 .37658 .5031 .38757 .50016 .3809 .49333 Mtetra
.646 .73 .911 r
.3809 .49333 .38757 .50016 .39862 .49705 .39198 .49024 Mtetra
.648 .732 .911 r
.39198 .49024 .39862 .49705 .40972 .49379 .4031 .48706 Mtetra
.65 .736 .912 r
.4031 .48706 .40972 .49379 .42088 .49041 .41428 .48381 Mtetra
.651 .741 .916 r
.41428 .48381 .42088 .49041 .43208 .48695 .4255 .48052 Mtetra
.65 .747 .921 r
.4255 .48052 .43208 .48695 .44333 .48347 .43678 .47724 Mtetra
.647 .753 .927 r
.43678 .47724 .44333 .48347 .45463 .48002 .4481 .47398 Mtetra
.644 .76 .933 r
.4481 .47398 .45463 .48002 .46597 .47663 .45947 .47077 Mtetra
.64 .766 .939 r
.45947 .47077 .46597 .47663 .47736 .47332 .47089 .46763 Mtetra
.635 .771 .945 r
.47089 .46763 .47736 .47332 .4888 .47008 .48237 .46457 Mtetra
.63 .776 .951 r
.48237 .46457 .4888 .47008 .50029 .46692 .49389 .46156 Mtetra
.625 .782 .956 r
.49389 .46156 .50029 .46692 .51184 .46382 .50547 .4586 Mtetra
.622 .787 .961 r
.50547 .4586 .51184 .46382 .52343 .46075 .5171 .45567 Mtetra
.619 .792 .965 r
.5171 .45567 .52343 .46075 .53508 .45767 .52879 .45272 Mtetra
.619 .798 .968 r
.52879 .45272 .53508 .45767 .54679 .45457 .54053 .44973 Mtetra
.62 .803 .97 r
.54053 .44973 .54679 .45457 .55854 .45139 .55233 .44666 Mtetra
.624 .809 .971 r
.55233 .44666 .55854 .45139 .57036 .4481 .56418 .44344 Mtetra
.631 .815 .971 r
.56418 .44344 .57036 .4481 .58222 .44466 .57609 .44005 Mtetra
.639 .821 .97 r
.57609 .44005 .58222 .44466 .59413 .44103 .58804 .43645 Mtetra
.649 .826 .968 r
.58804 .43645 .59413 .44103 .60609 .43717 .60005 .43258 Mtetra
.66 .83 .965 r
.60005 .43258 .60609 .43717 .61809 .43308 .61209 .42845 Mtetra
.672 .832 .961 r
.61209 .42845 .61809 .43308 .63014 .42872 .62418 .42402 Mtetra
.683 .834 .956 r
.62418 .42402 .63014 .42872 .64222 .42411 .63631 .4193 Mtetra
.694 .834 .95 r
.63631 .4193 .64222 .42411 .65435 .41924 .64848 .41429 Mtetra
.703 .832 .944 r
.64848 .41429 .65435 .41924 .6665 .41414 .66068 .40903 Mtetra
.71 .829 .939 r
.66068 .40903 .6665 .41414 .6787 .40883 .67291 .40354 Mtetra
.716 .826 .933 r
.67291 .40354 .6787 .40883 .69092 .40335 .68518 .39787 Mtetra
.719 .821 .928 r
.68518 .39787 .69092 .40335 .70319 .39775 .69748 .39205 Mtetra
.721 .815 .923 r
.69748 .39205 .70319 .39775 .71549 .39205 .70982 .38615 Mtetra
.722 .81 .919 r
.70982 .38615 .71549 .39205 .72783 .38632 .72219 .3802 Mtetra
.721 .803 .916 r
.72219 .3802 .72783 .38632 .74021 .38058 .73461 .37426 Mtetra
.719 .797 .913 r
.73461 .37426 .74021 .38058 .75264 .37488 .74707 .36836 Mtetra
.715 .791 .911 r
.74707 .36836 .75264 .37488 .76511 .36924 .75958 .36253 Mtetra
.712 .785 .909 r
.75958 .36253 .76511 .36924 .77763 .36369 .77213 .3568 Mtetra
.707 .779 .908 r
.77213 .3568 .77763 .36369 .79021 .35825 .78475 .3512 Mtetra
.703 .774 .907 r
.78475 .3512 .79021 .35825 .80285 .35291 .79742 .34572 Mtetra
.698 .769 .906 r
.79742 .34572 .80285 .35291 .81554 .3477 .81015 .34037 Mtetra
.694 .764 .906 r
.81015 .34037 .81554 .3477 .8283 .3426 .82294 .33515 Mtetra
.69 .76 .905 r
.82294 .33515 .8283 .3426 .84111 .3376 .83579 .33005 Mtetra
.686 .757 .905 r
.83579 .33005 .84111 .3376 .85399 .33271 .84871 .32506 Mtetra
.682 .753 .905 r
.84871 .32506 .85399 .33271 .86694 .3279 .86169 .32017 Mtetra
.679 .751 .905 r
.86169 .32017 .86694 .3279 .87994 .32316 .87473 .31536 Mtetra
.677 .749 .905 r
.87473 .31536 .87994 .32316 .89301 .31849 .88784 .31063 Mtetra
.624 .736 .928 r
.2873 .50853 .29424 .51481 .30489 .51235 .29797 .50604 Mtetra
.626 .736 .927 r
.29797 .50604 .30489 .51235 .31559 .50985 .3087 .50349 Mtetra
.628 .736 .926 r
.3087 .50349 .31559 .50985 .32634 .50729 .31947 .50089 Mtetra
.63 .736 .924 r
.31947 .50089 .32634 .50729 .33715 .50467 .33031 .49822 Mtetra
.633 .736 .923 r
.33031 .49822 .33715 .50467 .34801 .50198 .34119 .49547 Mtetra
.636 .736 .921 r
.34119 .49547 .34801 .50198 .35892 .4992 .35213 .49264 Mtetra
.638 .736 .919 r
.35213 .49264 .35892 .4992 .36988 .49632 .36313 .48972 Mtetra
.641 .737 .918 r
.36313 .48972 .36988 .49632 .3809 .49333 .37417 .48673 Mtetra
.643 .738 .918 r
.37417 .48673 .3809 .49333 .39198 .49024 .38527 .48366 Mtetra
.645 .74 .918 r
.38527 .48366 .39198 .49024 .4031 .48706 .39642 .48054 Mtetra
.645 .743 .92 r
.39642 .48054 .4031 .48706 .41428 .48381 .40762 .47738 Mtetra
.645 .746 .923 r
.40762 .47738 .41428 .48381 .4255 .48052 .41887 .47421 Mtetra
.643 .75 .927 r
.41887 .47421 .4255 .48052 .43678 .47724 .43017 .47105 Mtetra
.64 .755 .932 r
.43017 .47105 .43678 .47724 .4481 .47398 .44152 .46793 Mtetra
.637 .759 .937 r
.44152 .46793 .4481 .47398 .45947 .47077 .45292 .46487 Mtetra
.632 .764 .942 r
.45292 .46487 .45947 .47077 .47089 .46763 .46437 .46188 Mtetra
.627 .768 .947 r
.46437 .46188 .47089 .46763 .48237 .46457 .47588 .45896 Mtetra
.623 .773 .953 r
.47588 .45896 .48237 .46457 .49389 .46156 .48743 .4561 Mtetra
.618 .778 .957 r
.48743 .4561 .49389 .46156 .50547 .4586 .49904 .45329 Mtetra
.615 .783 .962 r
.49904 .45329 .50547 .4586 .5171 .45567 .51071 .45049 Mtetra
.613 .788 .965 r
.51071 .45049 .5171 .45567 .52879 .45272 .52244 .44768 Mtetra
.613 .794 .968 r
.52244 .44768 .52879 .45272 .54053 .44973 .53422 .44481 Mtetra
.615 .8 .97 r
.53422 .44481 .54053 .44973 .55233 .44666 .54606 .44183 Mtetra
.62 .806 .971 r
.54606 .44183 .55233 .44666 .56418 .44344 .55795 .43869 Mtetra
.628 .812 .971 r
.55795 .43869 .56418 .44344 .57609 .44005 .5699 .43535 Mtetra
.638 .818 .969 r
.5699 .43535 .57609 .44005 .58804 .43645 .5819 .43176 Mtetra
.649 .823 .967 r
.5819 .43176 .58804 .43645 .60005 .43258 .59394 .42788 Mtetra
.662 .827 .963 r
.59394 .42788 .60005 .43258 .61209 .42845 .60604 .4237 Mtetra
.674 .83 .958 r
.60604 .4237 .61209 .42845 .62418 .42402 .61817 .41919 Mtetra
.687 .832 .953 r
.61817 .41919 .62418 .42402 .63631 .4193 .63034 .41436 Mtetra
.698 .832 .947 r
.63034 .41436 .63631 .4193 .64848 .41429 .64255 .40922 Mtetra
.707 .83 .941 r
.64255 .40922 .64848 .41429 .66068 .40903 .65479 .40379 Mtetra
.715 .828 .935 r
.65479 .40379 .66068 .40903 .67291 .40354 .66707 .39812 Mtetra
.721 .824 .929 r
.66707 .39812 .67291 .40354 .68518 .39787 .67937 .39225 Mtetra
.724 .819 .924 r
.67937 .39225 .68518 .39787 .69748 .39205 .69171 .38623 Mtetra
.726 .814 .919 r
.69171 .38623 .69748 .39205 .70982 .38615 .70409 .38012 Mtetra
.727 .808 .915 r
.70409 .38012 .70982 .38615 .72219 .3802 .7165 .37397 Mtetra
.725 .802 .912 r
.7165 .37397 .72219 .3802 .73461 .37426 .72895 .36782 Mtetra
.723 .796 .91 r
.72895 .36782 .73461 .37426 .74707 .36836 .74145 .36172 Mtetra
.719 .79 .908 r
.74145 .36172 .74707 .36836 .75958 .36253 .75399 .35571 Mtetra
.715 .784 .906 r
.75399 .35571 .75958 .36253 .77213 .3568 .76658 .34981 Mtetra
.711 .779 .905 r
.76658 .34981 .77213 .3568 .78475 .3512 .77923 .34405 Mtetra
.706 .773 .905 r
.77923 .34405 .78475 .3512 .79742 .34572 .79194 .33842 Mtetra
.701 .769 .904 r
.79194 .33842 .79742 .34572 .81015 .34037 .8047 .33295 Mtetra
.696 .764 .904 r
.8047 .33295 .81015 .34037 .82294 .33515 .81753 .32762 Mtetra
.692 .76 .904 r
.81753 .32762 .82294 .33515 .83579 .33005 .83042 .32242 Mtetra
.687 .757 .904 r
.83042 .32242 .83579 .33005 .84871 .32506 .84337 .31734 Mtetra
.684 .754 .904 r
.84337 .31734 .84871 .32506 .86169 .32017 .85639 .31237 Mtetra
.68 .751 .904 r
.85639 .31237 .86169 .32017 .87473 .31536 .86948 .30749 Mtetra
.678 .749 .905 r
.86948 .30749 .87473 .31536 .88784 .31063 .88263 .30269 Mtetra
.625 .734 .926 r
.28031 .50214 .2873 .50853 .29797 .50604 .291 .49961 Mtetra
.626 .734 .925 r
.291 .49961 .29797 .50604 .3087 .50349 .30175 .49703 Mtetra
.628 .735 .924 r
.30175 .49703 .3087 .50349 .31947 .50089 .31256 .49439 Mtetra
.631 .735 .923 r
.31256 .49439 .31947 .50089 .33031 .49822 .32342 .49168 Mtetra
.633 .736 .922 r
.32342 .49168 .33031 .49822 .34119 .49547 .33433 .48891 Mtetra
.635 .736 .921 r
.33433 .48891 .34119 .49547 .35213 .49264 .34529 .48605 Mtetra
.638 .737 .92 r
.34529 .48605 .35213 .49264 .36313 .48972 .35631 .48313 Mtetra
.64 .738 .92 r
.35631 .48313 .36313 .48972 .37417 .48673 .36738 .48014 Mtetra
.641 .739 .92 r
.36738 .48014 .37417 .48673 .38527 .48366 .37851 .4771 Mtetra
.642 .741 .921 r
.37851 .4771 .38527 .48366 .39642 .48054 .38968 .47403 Mtetra
.641 .744 .923 r
.38968 .47403 .39642 .48054 .40762 .47738 .40091 .47094 Mtetra
.64 .746 .926 r
.40091 .47094 .40762 .47738 .41887 .47421 .41219 .46786 Mtetra
.638 .75 .929 r
.41219 .46786 .41887 .47421 .43017 .47105 .42351 .46481 Mtetra
.635 .753 .933 r
.42351 .46481 .43017 .47105 .44152 .46793 .43489 .46181 Mtetra
.631 .756 .938 r
.43489 .46181 .44152 .46793 .45292 .46487 .44632 .45888 Mtetra
.626 .76 .943 r
.44632 .45888 .45292 .46487 .46437 .46188 .4578 .45602 Mtetra
.621 .764 .948 r
.4578 .45602 .46437 .46188 .47588 .45896 .46933 .45324 Mtetra
.616 .768 .953 r
.46933 .45324 .47588 .45896 .48743 .4561 .48092 .45052 Mtetra
.611 .773 .958 r
.48092 .45052 .48743 .4561 .49904 .45329 .49256 .44785 Mtetra
.608 .778 .962 r
.49256 .44785 .49904 .45329 .51071 .45049 .50427 .44519 Mtetra
.607 .783 .965 r
.50427 .44519 .51071 .45049 .52244 .44768 .51603 .4425 Mtetra
.607 .789 .968 r
.51603 .4425 .52244 .44768 .53422 .44481 .52785 .43974 Mtetra
.611 .795 .97 r
.52785 .43974 .53422 .44481 .54606 .44183 .53973 .43685 Mtetra
.617 .801 .97 r
.53973 .43685 .54606 .44183 .55795 .43869 .55166 .43378 Mtetra
.626 .808 .97 r
.55166 .43378 .55795 .43869 .5699 .43535 .56365 .43048 Mtetra
.637 .814 .968 r
.56365 .43048 .5699 .43535 .5819 .43176 .57569 .42691 Mtetra
.65 .819 .965 r
.57569 .42691 .5819 .43176 .59394 .42788 .58778 .42301 Mtetra
.664 .823 .96 r
.58778 .42301 .59394 .42788 .60604 .4237 .59992 .41877 Mtetra
.677 .826 .955 r
.59992 .41877 .60604 .4237 .61817 .41919 .6121 .41418 Mtetra
.69 .828 .949 r
.6121 .41418 .61817 .41919 .63034 .41436 .62431 .40924 Mtetra
.702 .828 .943 r
.62431 .40924 .63034 .41436 .64255 .40922 .63656 .40396 Mtetra
.712 .827 .936 r
.63656 .40396 .64255 .40922 .65479 .40379 .64885 .39837 Mtetra
.719 .824 .93 r
.64885 .39837 .65479 .40379 .66707 .39812 .66116 .39252 Mtetra
.725 .82 .924 r
.66116 .39252 .66707 .39812 .67937 .39225 .67351 .38646 Mtetra
.729 .816 .919 r
.67351 .38646 .67937 .39225 .69171 .38623 .68589 .38024 Mtetra
.731 .811 .914 r
.68589 .38024 .69171 .38623 .70409 .38012 .6983 .37392 Mtetra
.731 .806 .911 r
.6983 .37392 .70409 .38012 .7165 .37397 .71075 .36757 Mtetra
.729 .8 .908 r
.71075 .36757 .7165 .37397 .72895 .36782 .72324 .36122 Mtetra
.726 .794 .906 r
.72324 .36122 .72895 .36782 .74145 .36172 .73577 .35494 Mtetra
.723 .789 .904 r
.73577 .35494 .74145 .36172 .75399 .35571 .74835 .34875 Mtetra
.718 .783 .903 r
.74835 .34875 .75399 .35571 .76658 .34981 .76098 .3427 Mtetra
.713 .778 .903 r
.76098 .3427 .76658 .34981 .77923 .34405 .77366 .33678 Mtetra
.708 .773 .902 r
.77366 .33678 .77923 .34405 .79194 .33842 .7864 .33103 Mtetra
.703 .768 .902 r
.7864 .33103 .79194 .33842 .8047 .33295 .7992 .32543 Mtetra
.698 .764 .903 r
.7992 .32543 .8047 .33295 .81753 .32762 .81207 .31999 Mtetra
.693 .76 .903 r
.81207 .31999 .81753 .32762 .83042 .32242 .825 .31469 Mtetra
.689 .756 .903 r
.825 .31469 .83042 .32242 .84337 .31734 .83799 .30953 Mtetra
.685 .753 .904 r
.83799 .30953 .84337 .31734 .85639 .31237 .85105 .30449 Mtetra
.681 .751 .904 r
.85105 .30449 .85639 .31237 .86948 .30749 .86417 .29954 Mtetra
.678 .749 .904 r
.86417 .29954 .86948 .30749 .88263 .30269 .87737 .29468 Mtetra
.626 .732 .924 r
.27327 .49563 .28031 .50214 .291 .49961 .28399 .49306 Mtetra
.627 .732 .923 r
.28399 .49306 .291 .49961 .30175 .49703 .29476 .49044 Mtetra
.629 .733 .922 r
.29476 .49044 .30175 .49703 .31256 .49439 .30559 .48777 Mtetra
.631 .733 .921 r
.30559 .48777 .31256 .49439 .32342 .49168 .31648 .48504 Mtetra
.633 .734 .921 r
.31648 .48504 .32342 .49168 .33433 .48891 .32741 .48224 Mtetra
.635 .734 .92 r
.32741 .48224 .33433 .48891 .34529 .48605 .3384 .47938 Mtetra
.637 .735 .92 r
.3384 .47938 .34529 .48605 .35631 .48313 .34945 .47645 Mtetra
.638 .737 .92 r
.34945 .47645 .35631 .48313 .36738 .48014 .36055 .47348 Mtetra
.639 .738 .92 r
.36055 .47348 .36738 .48014 .37851 .4771 .37169 .47047 Mtetra
.639 .74 .922 r
.37169 .47047 .37851 .4771 .38968 .47403 .38289 .46744 Mtetra
.638 .742 .924 r
.38289 .46744 .38968 .47403 .40091 .47094 .39415 .46441 Mtetra
.636 .744 .926 r
.39415 .46441 .40091 .47094 .41219 .46786 .40545 .46141 Mtetra
.633 .747 .93 r
.40545 .46141 .41219 .46786 .42351 .46481 .4168 .45845 Mtetra
.63 .749 .934 r
.4168 .45845 .42351 .46481 .43489 .46181 .4282 .45556 Mtetra
.625 .752 .938 r
.4282 .45556 .43489 .46181 .44632 .45888 .43966 .45275 Mtetra
.62 .756 .943 r
.43966 .45275 .44632 .45888 .4578 .45602 .45117 .45002 Mtetra
.615 .759 .948 r
.45117 .45002 .4578 .45602 .46933 .45324 .46273 .44737 Mtetra
.609 .763 .953 r
.46273 .44737 .46933 .45324 .48092 .45052 .47435 .44479 Mtetra
.605 .767 .957 r
.47435 .44479 .48092 .45052 .49256 .44785 .48603 .44225 Mtetra
.602 .772 .961 r
.48603 .44225 .49256 .44785 .50427 .44519 .49776 .43972 Mtetra
.601 .777 .964 r
.49776 .43972 .50427 .44519 .51603 .4425 .50956 .43715 Mtetra
.603 .783 .967 r
.50956 .43715 .51603 .4425 .52785 .43974 .52142 .43449 Mtetra
.608 .789 .968 r
.52142 .43449 .52785 .43974 .53973 .43685 .53333 .43168 Mtetra
.615 .795 .968 r
.53333 .43168 .53973 .43685 .55166 .43378 .54531 .42867 Mtetra
.625 .802 .967 r
.54531 .42867 .55166 .43378 .56365 .43048 .55734 .42541 Mtetra
.638 .808 .965 r
.55734 .42541 .56365 .43048 .57569 .42691 .56942 .42183 Mtetra
.652 .813 .961 r
.56942 .42183 .57569 .42691 .58778 .42301 .58156 .41791 Mtetra
.666 .817 .956 r
.58156 .41791 .58778 .42301 .59992 .41877 .59374 .41361 Mtetra
.681 .82 .95 r
.59374 .41361 .59992 .41877 .6121 .41418 .60596 .40893 Mtetra
.694 .822 .944 r
.60596 .40893 .6121 .41418 .62431 .40924 .61822 .40387 Mtetra
.706 .822 .937 r
.61822 .40387 .62431 .40924 .63656 .40396 .63051 .39845 Mtetra
.716 .821 .93 r
.63051 .39845 .63656 .40396 .64885 .39837 .64284 .39271 Mtetra
.723 .818 .924 r
.64284 .39271 .64885 .39837 .66116 .39252 .6552 .38668 Mtetra
.729 .815 .918 r
.6552 .38668 .66116 .39252 .67351 .38646 .66758 .38044 Mtetra
.733 .811 .913 r
.66758 .38044 .67351 .38646 .68589 .38024 .68 .37403 Mtetra
.734 .807 .909 r
.68 .37403 .68589 .38024 .6983 .37392 .69245 .36752 Mtetra
.734 .802 .906 r
.69245 .36752 .6983 .37392 .71075 .36757 .70494 .36098 Mtetra
.732 .797 .903 r
.70494 .36098 .71075 .36757 .72324 .36122 .71747 .35445 Mtetra
.73 .791 .902 r
.71747 .35445 .72324 .36122 .73577 .35494 .73004 .34799 Mtetra
.726 .786 .9 r
.73004 .34799 .73577 .35494 .74835 .34875 .74265 .34165 Mtetra
.721 .781 .9 r
.74265 .34165 .74835 .34875 .76098 .3427 .75532 .33544 Mtetra
.716 .776 .9 r
.75532 .33544 .76098 .3427 .77366 .33678 .76804 .32939 Mtetra
.71 .771 .9 r
.76804 .32939 .77366 .33678 .7864 .33103 .78082 .32351 Mtetra
.705 .767 .9 r
.78082 .32351 .7864 .33103 .7992 .32543 .79366 .3178 Mtetra
.7 .763 .901 r
.79366 .3178 .7992 .32543 .81207 .31999 .80656 .31226 Mtetra
.694 .759 .901 r
.80656 .31226 .81207 .31999 .825 .31469 .81953 .30688 Mtetra
.69 .756 .902 r
.81953 .30688 .825 .31469 .83799 .30953 .83256 .30163 Mtetra
.686 .753 .903 r
.83256 .30163 .83799 .30953 .85105 .30449 .84566 .29652 Mtetra
.682 .751 .903 r
.84566 .29652 .85105 .30449 .86417 .29954 .85883 .29151 Mtetra
.679 .749 .904 r
.85883 .29151 .86417 .29954 .87737 .29468 .87206 .28658 Mtetra
.626 .731 .922 r
.26618 .489 .27327 .49563 .28399 .49306 .27693 .48639 Mtetra
.628 .731 .921 r
.27693 .48639 .28399 .49306 .29476 .49044 .28773 .48374 Mtetra
.629 .731 .92 r
.28773 .48374 .29476 .49044 .30559 .48777 .29858 .48104 Mtetra
.631 .731 .92 r
.29858 .48104 .30559 .48777 .31648 .48504 .30949 .47828 Mtetra
.633 .732 .919 r
.30949 .47828 .31648 .48504 .32741 .48224 .32045 .47546 Mtetra
.635 .732 .919 r
.32045 .47546 .32741 .48224 .3384 .47938 .33147 .47259 Mtetra
.636 .733 .918 r
.33147 .47259 .3384 .47938 .34945 .47645 .34254 .46966 Mtetra
.637 .734 .919 r
.34254 .46966 .34945 .47645 .36055 .47348 .35366 .4667 Mtetra
.637 .735 .92 r
.35366 .4667 .36055 .47348 .37169 .47047 .36483 .46372 Mtetra
.636 .737 .921 r
.36483 .46372 .37169 .47047 .38289 .46744 .37606 .46073 Mtetra
.635 .739 .923 r
.37606 .46073 .38289 .46744 .39415 .46441 .38733 .45776 Mtetra
.633 .741 .926 r
.38733 .45776 .39415 .46441 .40545 .46141 .39866 .45483 Mtetra
.629 .743 .929 r
.39866 .45483 .40545 .46141 .4168 .45845 .41004 .45196 Mtetra
.625 .745 .933 r
.41004 .45196 .4168 .45845 .4282 .45556 .42147 .44917 Mtetra
.62 .748 .938 r
.42147 .44917 .4282 .45556 .43966 .45275 .43295 .44646 Mtetra
.614 .75 .942 r
.43295 .44646 .43966 .45275 .45117 .45002 .44448 .44385 Mtetra
.609 .753 .947 r
.44448 .44385 .45117 .45002 .46273 .44737 .45608 .44133 Mtetra
.604 .757 .952 r
.45608 .44133 .46273 .44737 .47435 .44479 .46773 .43887 Mtetra
.6 .76 .956 r
.46773 .43887 .47435 .44479 .48603 .44225 .47944 .43645 Mtetra
.597 .765 .959 r
.47944 .43645 .48603 .44225 .49776 .43972 .4912 .43404 Mtetra
.597 .77 .962 r
.4912 .43404 .49776 .43972 .50956 .43715 .50304 .43157 Mtetra
.6 .775 .964 r
.50304 .43157 .50956 .43715 .52142 .43449 .51493 .429 Mtetra
.605 .782 .965 r
.51493 .429 .52142 .43449 .53333 .43168 .52688 .42627 Mtetra
.614 .788 .965 r
.52688 .42627 .53333 .43168 .54531 .42867 .5389 .42331 Mtetra
.626 .794 .963 r
.5389 .42331 .54531 .42867 .55734 .42541 .55097 .42006 Mtetra
.639 .8 .96 r
.55097 .42006 .55734 .42541 .56942 .42183 .5631 .41648 Mtetra
.654 .806 .956 r
.5631 .41648 .56942 .42183 .58156 .41791 .57527 .41252 Mtetra
.669 .81 .95 r
.57527 .41252 .58156 .41791 .59374 .41361 .58749 .40816 Mtetra
.684 .813 .944 r
.58749 .40816 .59374 .41361 .60596 .40893 .59976 .40338 Mtetra
.698 .814 .937 r
.59976 .40338 .60596 .40893 .61822 .40387 .61206 .39821 Mtetra
.709 .814 .93 r
.61206 .39821 .61822 .40387 .63051 .39845 .6244 .39265 Mtetra
.719 .813 .924 r
.6244 .39265 .63051 .39845 .64284 .39271 .63677 .38675 Mtetra
.727 .811 .917 r
.63677 .38675 .64284 .39271 .6552 .38668 .64917 .38056 Mtetra
.732 .809 .912 r
.64917 .38056 .6552 .38668 .66758 .38044 .6616 .37414 Mtetra
.736 .805 .907 r
.6616 .37414 .66758 .38044 .68 .37403 .67405 .36756 Mtetra
.737 .801 .903 r
.67405 .36756 .68 .37403 .69245 .36752 .68655 .36088 Mtetra
.737 .797 .9 r
.68655 .36088 .69245 .36752 .70494 .36098 .69907 .35416 Mtetra
.735 .792 .898 r
.69907 .35416 .70494 .36098 .71747 .35445 .71164 .34747 Mtetra
.732 .788 .897 r
.71164 .34747 .71747 .35445 .73004 .34799 .72425 .34086 Mtetra
.728 .783 .897 r
.72425 .34086 .73004 .34799 .74265 .34165 .7369 .33436 Mtetra
.723 .778 .896 r
.7369 .33436 .74265 .34165 .75532 .33544 .7496 .32802 Mtetra
.718 .774 .897 r
.7496 .32802 .75532 .33544 .76804 .32939 .76236 .32185 Mtetra
.712 .77 .897 r
.76236 .32185 .76804 .32939 .78082 .32351 .77518 .31586 Mtetra
.706 .765 .898 r
.77518 .31586 .78082 .32351 .79366 .3178 .78806 .31005 Mtetra
.701 .762 .899 r
.78806 .31005 .79366 .3178 .80656 .31226 .801 .30442 Mtetra
.696 .758 .9 r
.801 .30442 .80656 .31226 .81953 .30688 .81401 .29896 Mtetra
.691 .755 .901 r
.81401 .29896 .81953 .30688 .83256 .30163 .82709 .29364 Mtetra
.686 .753 .902 r
.82709 .29364 .83256 .30163 .84566 .29652 .84023 .28846 Mtetra
.683 .75 .903 r
.84023 .28846 .84566 .29652 .85883 .29151 .85343 .28339 Mtetra
.679 .748 .903 r
.85343 .28339 .85883 .29151 .87206 .28658 .86671 .27841 Mtetra
.627 .729 .921 r
.25904 .48228 .26618 .489 .27693 .48639 .26981 .47962 Mtetra
.629 .729 .92 r
.26981 .47962 .27693 .48639 .28773 .48374 .28064 .47693 Mtetra
.63 .729 .919 r
.28064 .47693 .28773 .48374 .29858 .48104 .29152 .47419 Mtetra
.631 .729 .918 r
.29152 .47419 .29858 .48104 .30949 .47828 .30245 .4714 Mtetra
.633 .73 .917 r
.30245 .4714 .30949 .47828 .32045 .47546 .31344 .46856 Mtetra
.634 .73 .917 r
.31344 .46856 .32045 .47546 .33147 .47259 .32448 .46567 Mtetra
.635 .731 .917 r
.32448 .46567 .33147 .47259 .34254 .46966 .33557 .46275 Mtetra
.636 .732 .918 r
.33557 .46275 .34254 .46966 .35366 .4667 .34672 .4598 Mtetra
.635 .733 .919 r
.34672 .4598 .35366 .4667 .36483 .46372 .35792 .45683 Mtetra
.634 .734 .92 r
.35792 .45683 .36483 .46372 .37606 .46073 .36917 .45388 Mtetra
.632 .735 .922 r
.36917 .45388 .37606 .46073 .38733 .45776 .38047 .45097 Mtetra
.629 .737 .925 r
.38047 .45097 .38733 .45776 .39866 .45483 .39182 .4481 Mtetra
.625 .739 .928 r
.39182 .4481 .39866 .45483 .41004 .45196 .40322 .44531 Mtetra
.621 .74 .932 r
.40322 .44531 .41004 .45196 .42147 .44917 .41468 .44261 Mtetra
.615 .742 .937 r
.41468 .44261 .42147 .44917 .43295 .44646 .42619 .44001 Mtetra
.61 .745 .941 r
.42619 .44001 .43295 .44646 .44448 .44385 .43775 .4375 Mtetra
.604 .747 .945 r
.43775 .4375 .44448 .44385 .45608 .44133 .44937 .43509 Mtetra
.599 .75 .95 r
.44937 .43509 .45608 .44133 .46773 .43887 .46105 .43274 Mtetra
.595 .753 .954 r
.46105 .43274 .46773 .43887 .47944 .43645 .47279 .43044 Mtetra
.593 .757 .957 r
.47279 .43044 .47944 .43645 .4912 .43404 .48459 .42812 Mtetra
.594 .762 .959 r
.48459 .42812 .4912 .43404 .50304 .43157 .49645 .42574 Mtetra
.598 .767 .961 r
.49645 .42574 .50304 .43157 .51493 .429 .50838 .42324 Mtetra
.605 .773 .961 r
.50838 .42324 .51493 .429 .52688 .42627 .52037 .42056 Mtetra
.614 .779 .96 r
.52037 .42056 .52688 .42627 .5389 .42331 .53243 .41763 Mtetra
.627 .786 .958 r
.53243 .41763 .5389 .42331 .55097 .42006 .54454 .41439 Mtetra
.641 .791 .954 r
.54454 .41439 .55097 .42006 .5631 .41648 .5567 .41079 Mtetra
.657 .796 .949 r
.5567 .41079 .5631 .41648 .57527 .41252 .56892 .40678 Mtetra
.672 .8 .944 r
.56892 .40678 .57527 .41252 .58749 .40816 .58119 .40235 Mtetra
.687 .803 .937 r
.58119 .40235 .58749 .40816 .59976 .40338 .59349 .39749 Mtetra
.7 .805 .93 r
.59349 .39749 .59976 .40338 .61206 .39821 .60584 .3922 Mtetra
.712 .805 .923 r
.60584 .3922 .61206 .39821 .6244 .39265 .61822 .38651 Mtetra
.722 .805 .916 r
.61822 .38651 .6244 .39265 .63677 .38675 .63063 .38047 Mtetra
.729 .803 .91 r
.63063 .38047 .63677 .38675 .64917 .38056 .64307 .37412 Mtetra
.734 .801 .905 r
.64307 .37412 .64917 .38056 .6616 .37414 .65554 .36755 Mtetra
.737 .798 .9 r
.65554 .36755 .6616 .37414 .67405 .36756 .66804 .3608 Mtetra
.739 .794 .897 r
.66804 .3608 .67405 .36756 .68655 .36088 .68057 .35396 Mtetra
.738 .791 .895 r
.68057 .35396 .68655 .36088 .69907 .35416 .69314 .34709 Mtetra
.736 .787 .893 r
.69314 .34709 .69907 .35416 .71164 .34747 .70575 .34026 Mtetra
.733 .783 .893 r
.70575 .34026 .71164 .34747 .72425 .34086 .71839 .33351 Mtetra
.729 .779 .893 r
.71839 .33351 .72425 .34086 .7369 .33436 .73109 .32689 Mtetra
.724 .775 .893 r
.73109 .32689 .7369 .33436 .7496 .32802 .74383 .32043 Mtetra
.719 .771 .894 r
.74383 .32043 .7496 .32802 .76236 .32185 .75663 .31416 Mtetra
.713 .767 .895 r
.75663 .31416 .76236 .32185 .77518 .31586 .76949 .30807 Mtetra
.707 .764 .896 r
.76949 .30807 .77518 .31586 .78806 .31005 .78241 .30218 Mtetra
.702 .76 .897 r
.78241 .30218 .78806 .31005 .801 .30442 .79539 .29647 Mtetra
.696 .757 .899 r
.79539 .29647 .801 .30442 .81401 .29896 .80844 .29093 Mtetra
.691 .754 .9 r
.80844 .29093 .81401 .29896 .82709 .29364 .82156 .28555 Mtetra
.687 .752 .901 r
.82156 .28555 .82709 .29364 .84023 .28846 .83474 .28031 Mtetra
.683 .75 .902 r
.83474 .28031 .84023 .28846 .85343 .28339 .84799 .27519 Mtetra
.68 .748 .903 r
.84799 .27519 .85343 .28339 .86671 .27841 .86131 .27016 Mtetra
.628 .728 .919 r
.25185 .47545 .25904 .48228 .26981 .47962 .26265 .47275 Mtetra
.629 .728 .918 r
.26265 .47275 .26981 .47962 .28064 .47693 .2735 .47001 Mtetra
.631 .728 .917 r
.2735 .47001 .28064 .47693 .29152 .47419 .28441 .46724 Mtetra
.632 .728 .917 r
.28441 .46724 .29152 .47419 .30245 .4714 .29536 .46441 Mtetra
.633 .728 .916 r
.29536 .46441 .30245 .4714 .31344 .46856 .30638 .46155 Mtetra
.634 .728 .916 r
.30638 .46155 .31344 .46856 .32448 .46567 .31744 .45865 Mtetra
.634 .729 .916 r
.31744 .45865 .32448 .46567 .33557 .46275 .32856 .45571 Mtetra
.634 .729 .917 r
.32856 .45571 .33557 .46275 .34672 .4598 .33973 .45277 Mtetra
.634 .73 .918 r
.33973 .45277 .34672 .4598 .35792 .45683 .35095 .44983 Mtetra
.632 .731 .919 r
.35095 .44983 .35792 .45683 .36917 .45388 .36223 .44691 Mtetra
.63 .732 .921 r
.36223 .44691 .36917 .45388 .38047 .45097 .37355 .44404 Mtetra
.626 .733 .924 r
.37355 .44404 .38047 .45097 .39182 .4481 .38493 .44123 Mtetra
.622 .735 .927 r
.38493 .44123 .39182 .4481 .40322 .44531 .39636 .43851 Mtetra
.617 .736 .931 r
.39636 .43851 .40322 .44531 .41468 .44261 .40784 .43589 Mtetra
.611 .737 .935 r
.40784 .43589 .41468 .44261 .42619 .44001 .41937 .43337 Mtetra
.605 .739 .939 r
.41937 .43337 .42619 .44001 .43775 .4375 .43096 .43096 Mtetra
.6 .741 .943 r
.43096 .43096 .43775 .4375 .44937 .43509 .44261 .42864 Mtetra
.595 .743 .947 r
.44261 .42864 .44937 .43509 .46105 .43274 .45432 .42639 Mtetra
.592 .746 .951 r
.45432 .42639 .46105 .43274 .47279 .43044 .46609 .42417 Mtetra
.591 .75 .953 r
.46609 .42417 .47279 .43044 .48459 .42812 .47792 .42193 Mtetra
.592 .754 .955 r
.47792 .42193 .48459 .42812 .49645 .42574 .48982 .41962 Mtetra
.597 .759 .956 r
.48982 .41962 .49645 .42574 .50838 .42324 .50178 .41717 Mtetra
.605 .764 .956 r
.50178 .41717 .50838 .42324 .52037 .42056 .51381 .41452 Mtetra
.616 .77 .954 r
.51381 .41452 .52037 .42056 .53243 .41763 .5259 .4116 Mtetra
.629 .776 .951 r
.5259 .4116 .53243 .41763 .54454 .41439 .53805 .40835 Mtetra
.644 .781 .947 r
.53805 .40835 .54454 .41439 .5567 .41079 .55025 .40472 Mtetra
.659 .786 .942 r
.55025 .40472 .5567 .41079 .56892 .40678 .56251 .40066 Mtetra
.675 .79 .936 r
.56251 .40066 .56892 .40678 .58119 .40235 .57482 .39615 Mtetra
.689 .793 .929 r
.57482 .39615 .58119 .40235 .59349 .39749 .58717 .39119 Mtetra
.703 .794 .922 r
.58717 .39119 .59349 .39749 .60584 .3922 .59955 .38579 Mtetra
.714 .795 .915 r
.59955 .38579 .60584 .3922 .61822 .38651 .61197 .37998 Mtetra
.723 .795 .908 r
.61197 .37998 .61822 .38651 .63063 .38047 .62443 .3738 Mtetra
.73 .794 .902 r
.62443 .3738 .63063 .38047 .64307 .37412 .63691 .36733 Mtetra
.735 .792 .898 r
.63691 .36733 .64307 .37412 .65554 .36755 .64942 .36061 Mtetra
.738 .79 .894 r
.64942 .36061 .65554 .36755 .66804 .3608 .66197 .35373 Mtetra
.74 .787 .891 r
.66197 .35373 .66804 .3608 .68057 .35396 .67454 .34675 Mtetra
.739 .784 .889 r
.67454 .34675 .68057 .35396 .69314 .34709 .68715 .33976 Mtetra
.737 .781 .888 r
.68715 .33976 .69314 .34709 .70575 .34026 .69979 .3328 Mtetra
.734 .778 .888 r
.69979 .3328 .70575 .34026 .71839 .33351 .71248 .32594 Mtetra
.73 .775 .889 r
.71248 .32594 .71839 .33351 .73109 .32689 .72522 .31922 Mtetra
.725 .771 .89 r
.72522 .31922 .73109 .32689 .74383 .32043 .73801 .31266 Mtetra
.719 .768 .891 r
.73801 .31266 .74383 .32043 .75663 .31416 .75085 .3063 Mtetra
.714 .765 .893 r
.75085 .3063 .75663 .31416 .76949 .30807 .76375 .30013 Mtetra
.708 .762 .894 r
.76375 .30013 .76949 .30807 .78241 .30218 .77671 .29417 Mtetra
.702 .759 .896 r
.77671 .29417 .78241 .30218 .79539 .29647 .78973 .28839 Mtetra
.697 .756 .897 r
.78973 .28839 .79539 .29647 .80844 .29093 .80282 .2828 Mtetra
.692 .753 .899 r
.80282 .2828 .80844 .29093 .82156 .28555 .81598 .27736 Mtetra
.687 .751 .9 r
.81598 .27736 .82156 .28555 .83474 .28031 .82921 .27207 Mtetra
.683 .749 .901 r
.82921 .27207 .83474 .28031 .84799 .27519 .8425 .2669 Mtetra
.68 .747 .902 r
.8425 .2669 .84799 .27519 .86131 .27016 .85587 .26182 Mtetra
.63 .728 .918 r
.24461 .46855 .25185 .47545 .26265 .47275 .25543 .4658 Mtetra
.63 .727 .917 r
.25543 .4658 .26265 .47275 .2735 .47001 .26631 .46301 Mtetra
.631 .727 .916 r
.26631 .46301 .2735 .47001 .28441 .46724 .27724 .46019 Mtetra
.632 .727 .916 r
.27724 .46019 .28441 .46724 .29536 .46441 .28823 .45733 Mtetra
.633 .727 .915 r
.28823 .45733 .29536 .46441 .30638 .46155 .29926 .45444 Mtetra
.634 .727 .915 r
.29926 .45444 .30638 .46155 .31744 .45865 .31035 .45152 Mtetra
.31035 .45152 .31744 .45865 .32856 .45571 .3215 .44857 Mtetra
.633 .728 .916 r
.3215 .44857 .32856 .45571 .33973 .45277 .33269 .44563 Mtetra
.632 .728 .917 r
.33269 .44563 .33973 .45277 .35095 .44983 .34394 .4427 Mtetra
.63 .729 .918 r
.34394 .4427 .35095 .44983 .36223 .44691 .35524 .43981 Mtetra
.627 .729 .92 r
.35524 .43981 .36223 .44691 .37355 .44404 .36659 .43697 Mtetra
.624 .73 .923 r
.36659 .43697 .37355 .44404 .38493 .44123 .37799 .43421 Mtetra
.619 .731 .926 r
.37799 .43421 .38493 .44123 .39636 .43851 .38944 .43155 Mtetra
.614 .732 .93 r
.38944 .43155 .39636 .43851 .40784 .43589 .40094 .42899 Mtetra
.608 .733 .934 r
.40094 .42899 .40784 .43589 .41937 .43337 .4125 .42654 Mtetra
.602 .734 .937 r
.4125 .42654 .41937 .43337 .43096 .43096 .42412 .42421 Mtetra
.597 .735 .941 r
.42412 .42421 .43096 .43096 .44261 .42864 .4358 .42196 Mtetra
.592 .737 .944 r
.4358 .42196 .44261 .42864 .45432 .42639 .44753 .41978 Mtetra
.59 .739 .947 r
.44753 .41978 .45432 .42639 .46609 .42417 .45933 .41762 Mtetra
.589 .742 .949 r
.45933 .41762 .46609 .42417 .47792 .42193 .4712 .41544 Mtetra
.592 .745 .95 r
.4712 .41544 .47792 .42193 .48982 .41962 .48312 .41318 Mtetra
.597 .75 .95 r
.48312 .41318 .48982 .41962 .50178 .41717 .49512 .41076 Mtetra
.606 .755 .949 r
.49512 .41076 .50178 .41717 .51381 .41452 .50718 .40812 Mtetra
.617 .76 .947 r
.50718 .40812 .51381 .41452 .5259 .4116 .51931 .40519 Mtetra
.631 .765 .944 r
.51931 .40519 .5259 .4116 .53805 .40835 .5315 .40191 Mtetra
.646 .77 .939 r
.5315 .40191 .53805 .40835 .55025 .40472 .54374 .39823 Mtetra
.662 .775 .933 r
.54374 .39823 .55025 .40472 .56251 .40066 .55604 .39411 Mtetra
.677 .779 .927 r
.55604 .39411 .56251 .40066 .57482 .39615 .56838 .38952 Mtetra
.691 .781 .92 r
.56838 .38952 .57482 .39615 .58717 .39119 .58077 .38446 Mtetra
.704 .783 .913 r
.58077 .38446 .58717 .39119 .59955 .38579 .5932 .37896 Mtetra
.715 .784 .906 r
.5932 .37896 .59955 .38579 .61197 .37998 .60567 .37304 Mtetra
.724 .784 .9 r
.60567 .37304 .61197 .37998 .62443 .3738 .61816 .36674 Mtetra
.731 .784 .895 r
.61816 .36674 .62443 .3738 .63691 .36733 .63069 .36015 Mtetra
.736 .782 .89 r
.63069 .36015 .63691 .36733 .64942 .36061 .64324 .35331 Mtetra
.738 .781 .887 r
.64324 .35331 .64942 .36061 .66197 .35373 .65582 .34632 Mtetra
.74 .779 .885 r
.65582 .34632 .66197 .35373 .67454 .34675 .66844 .33923 Mtetra
.739 .777 .884 r
.66844 .33923 .67454 .34675 .68715 .33976 .68109 .33214 Mtetra
.737 .775 .883 r
.68109 .33214 .68715 .33976 .69979 .3328 .69378 .32509 Mtetra
.734 .773 .884 r
.69378 .32509 .69979 .3328 .71248 .32594 .70651 .31814 Mtetra
.73 .77 .885 r
.70651 .31814 .71248 .32594 .72522 .31922 .71929 .31133 Mtetra
.725 .767 .886 r
.71929 .31133 .72522 .31922 .73801 .31266 .73212 .30471 Mtetra
.719 .765 .888 r
.73212 .30471 .73801 .31266 .75085 .3063 .745 .29828 Mtetra
.714 .762 .89 r
.745 .29828 .75085 .3063 .76375 .30013 .75795 .29205 Mtetra
.708 .759 .892 r
.75795 .29205 .76375 .30013 .77671 .29417 .77095 .28603 Mtetra
.702 .757 .894 r
.77095 .28603 .77671 .29417 .78973 .28839 .78402 .2802 Mtetra
.697 .754 .896 r
.78402 .2802 .78973 .28839 .80282 .2828 .79715 .27455 Mtetra
.692 .752 .898 r
.79715 .27455 .80282 .2828 .81598 .27736 .81036 .26907 Mtetra
.687 .75 .899 r
.81036 .26907 .81598 .27736 .82921 .27207 .82363 .26373 Mtetra
.683 .748 .901 r
.82363 .26373 .82921 .27207 .8425 .2669 .83697 .25852 Mtetra
.68 .747 .902 r
.83697 .25852 .8425 .2669 .85587 .26182 .85038 .2534 Mtetra
.631 .727 .917 r
.23732 .46157 .24461 .46855 .25543 .4658 .24817 .45876 Mtetra
.631 .727 .916 r
.24817 .45876 .25543 .4658 .26631 .46301 .25907 .45593 Mtetra
.632 .726 .915 r
.25907 .45593 .26631 .46301 .27724 .46019 .27003 .45306 Mtetra
.633 .726 .915 r
.27003 .45306 .27724 .46019 .28823 .45733 .28104 .45016 Mtetra
.633 .726 .914 r
.28104 .45016 .28823 .45733 .29926 .45444 .2921 .44724 Mtetra
.634 .726 .914 r
.2921 .44724 .29926 .45444 .31035 .45152 .30321 .44429 Mtetra
.633 .726 .914 r
.30321 .44429 .31035 .45152 .3215 .44857 .31438 .44134 Mtetra
.633 .726 .915 r
.31438 .44134 .3215 .44857 .33269 .44563 .3256 .43839 Mtetra
.631 .726 .916 r
.3256 .43839 .33269 .44563 .34394 .4427 .33687 .43547 Mtetra
.629 .727 .918 r
.33687 .43547 .34394 .4427 .35524 .43981 .3482 .43259 Mtetra
.626 .727 .92 r
.3482 .43259 .35524 .43981 .36659 .43697 .35957 .42978 Mtetra
.621 .727 .922 r
.35957 .42978 .36659 .43697 .37799 .43421 .37099 .42705 Mtetra
.617 .727 .925 r
.37099 .42705 .37799 .43421 .38944 .43155 .38247 .42443 Mtetra
.611 .728 .928 r
.38247 .42443 .38944 .43155 .40094 .42899 .394 .42192 Mtetra
.605 .728 .932 r
.394 .42192 .40094 .42899 .4125 .42654 .40559 .41952 Mtetra
.6 .728 .935 r
.40559 .41952 .4125 .42654 .42412 .42421 .41723 .41724 Mtetra
.595 .729 .938 r
.41723 .41724 .42412 .42421 .4358 .42196 .42893 .41504 Mtetra
.591 .73 .941 r
.42893 .41504 .4358 .42196 .44753 .41978 .4407 .4129 Mtetra
.589 .732 .943 r
.4407 .4129 .44753 .41978 .45933 .41762 .45252 .41079 Mtetra
.589 .734 .944 r
.45252 .41079 .45933 .41762 .4712 .41544 .46442 .40863 Mtetra
.592 .737 .944 r
.46442 .40863 .4712 .41544 .48312 .41318 .47638 .40638 Mtetra
.599 .741 .944 r
.47638 .40638 .48312 .41318 .49512 .41076 .48841 .40397 Mtetra
.608 .745 .942 r
.48841 .40397 .49512 .41076 .50718 .40812 .5005 .40132 Mtetra
.62 .75 .939 r
.5005 .40132 .50718 .40812 .51931 .40519 .51266 .39836 Mtetra
.634 .755 .935 r
.51266 .39836 .51931 .40519 .5315 .40191 .52489 .39504 Mtetra
.648 .759 .93 r
.52489 .39504 .5315 .40191 .54374 .39823 .53717 .39129 Mtetra
.664 .763 .924 r
.53717 .39129 .54374 .39823 .55604 .39411 .5495 .3871 Mtetra
.679 .767 .918 r
.5495 .3871 .55604 .39411 .56838 .38952 .56189 .38243 Mtetra
.692 .77 .911 r
.56189 .38243 .56838 .38952 .58077 .38446 .57432 .37728 Mtetra
.705 .771 .904 r
.57432 .37728 .58077 .38446 .5932 .37896 .58679 .37168 Mtetra
.715 .773 .898 r
.58679 .37168 .5932 .37896 .60567 .37304 .59929 .36566 Mtetra
.724 .773 .892 r
.59929 .36566 .60567 .37304 .61816 .36674 .61183 .35927 Mtetra
.73 .773 .887 r
.61183 .35927 .61816 .36674 .63069 .36015 .6244 .35257 Mtetra
.735 .773 .884 r
.6244 .35257 .63069 .36015 .64324 .35331 .63699 .34564 Mtetra
.738 .772 .881 r
.63699 .34564 .64324 .35331 .65582 .34632 .64962 .33856 Mtetra
.739 .771 .879 r
.64962 .33856 .65582 .34632 .66844 .33923 .66228 .3314 Mtetra
.738 .77 .879 r
.66228 .3314 .66844 .33923 .68109 .33214 .67497 .32422 Mtetra
.736 .769 .879 r
.67497 .32422 .68109 .33214 .69378 .32509 .68771 .31711 Mtetra
.733 .767 .88 r
.68771 .31711 .69378 .32509 .70651 .31814 .70048 .3101 Mtetra
.729 .765 .882 r
.70048 .3101 .70651 .31814 .71929 .31133 .7133 .30324 Mtetra
.724 .763 .884 r
.7133 .30324 .71929 .31133 .73212 .30471 .72618 .29656 Mtetra
.719 .761 .886 r
.72618 .29656 .73212 .30471 .745 .29828 .7391 .29008 Mtetra
.713 .759 .888 r
.7391 .29008 .745 .29828 .75795 .29205 .75209 .28381 Mtetra
.708 .757 .891 r
.75209 .28381 .75795 .29205 .77095 .28603 .76514 .27775 Mtetra
.702 .755 .893 r
.76514 .27775 .77095 .28603 .78402 .2802 .77825 .27188 Mtetra
.697 .753 .895 r
.77825 .27188 .78402 .2802 .79715 .27455 .79143 .2662 Mtetra
.692 .751 .897 r
.79143 .2662 .79715 .27455 .81036 .26907 .80468 .26068 Mtetra
.687 .749 .899 r
.80468 .26068 .81036 .26907 .82363 .26373 .818 .2553 Mtetra
.683 .748 .9 r
.818 .2553 .82363 .26373 .83697 .25852 .83138 .25005 Mtetra
.68 .746 .901 r
.83138 .25005 .83697 .25852 .85038 .2534 .84483 .2449 Mtetra
.632 .727 .916 r
.22997 .45452 .23732 .46157 .24817 .45876 .24085 .45166 Mtetra
.24085 .45166 .24817 .45876 .25907 .45593 .25177 .44877 Mtetra
.633 .726 .915 r
.25177 .44877 .25907 .45593 .27003 .45306 .26276 .44586 Mtetra
.633 .726 .914 r
.26276 .44586 .27003 .45306 .28104 .45016 .27379 .44292 Mtetra
.634 .725 .914 r
.27379 .44292 .28104 .45016 .2921 .44724 .28488 .43996 Mtetra
.28488 .43996 .2921 .44724 .30321 .44429 .29602 .43699 Mtetra
.633 .725 .914 r
.29602 .43699 .30321 .44429 .31438 .44134 .30721 .43401 Mtetra
.632 .725 .914 r
.30721 .43401 .31438 .44134 .3256 .43839 .31846 .43105 Mtetra
.63 .725 .916 r
.31846 .43105 .3256 .43839 .33687 .43547 .32976 .42813 Mtetra
.628 .725 .917 r
.32976 .42813 .33687 .43547 .3482 .43259 .3411 .42525 Mtetra
.624 .725 .919 r
.3411 .42525 .3482 .43259 .35957 .42978 .3525 .42246 Mtetra
.62 .724 .921 r
.3525 .42246 .35957 .42978 .37099 .42705 .36395 .41975 Mtetra
.615 .724 .924 r
.36395 .41975 .37099 .42705 .38247 .42443 .37545 .41715 Mtetra
.609 .724 .927 r
.37545 .41715 .38247 .42443 .394 .42192 .38701 .41467 Mtetra
.604 .724 .929 r
.38701 .41467 .394 .42192 .40559 .41952 .39862 .4123 Mtetra
.598 .724 .932 r
.39862 .4123 .40559 .41952 .41723 .41724 .41029 .41004 Mtetra
.594 .724 .935 r
.41029 .41004 .41723 .41724 .42893 .41504 .42202 .40787 Mtetra
.59 .724 .936 r
.42202 .40787 .42893 .41504 .4407 .4129 .43381 .40575 Mtetra
.589 .725 .938 r
.43381 .40575 .4407 .4129 .45252 .41079 .44567 .40365 Mtetra
.59 .727 .938 r
.44567 .40365 .45252 .41079 .46442 .40863 .45759 .40149 Mtetra
.594 .729 .938 r
.45759 .40149 .46442 .40863 .47638 .40638 .46958 .39923 Mtetra
.601 .732 .937 r
.46958 .39923 .47638 .40638 .48841 .40397 .48164 .39679 Mtetra
.611 .736 .934 r
.48164 .39679 .48841 .40397 .5005 .40132 .49377 .3941 Mtetra
.622 .74 .931 r
.49377 .3941 .5005 .40132 .51266 .39836 .50596 .3911 Mtetra
.636 .744 .926 r
.50596 .3911 .51266 .39836 .52489 .39504 .51822 .38771 Mtetra
.651 .748 .921 r
.51822 .38771 .52489 .39504 .53717 .39129 .53054 .3839 Mtetra
.665 .752 .915 r
.53054 .3839 .53717 .39129 .5495 .3871 .54291 .37962 Mtetra
.68 .755 .908 r
.54291 .37962 .5495 .3871 .56189 .38243 .55534 .37487 Mtetra
.693 .758 .902 r
.55534 .37487 .56189 .38243 .57432 .37728 .5678 .36964 Mtetra
.704 .76 .895 r
.5678 .36964 .57432 .37728 .58679 .37168 .58031 .36395 Mtetra
.714 .762 .889 r
.58031 .36395 .58679 .37168 .59929 .36566 .59286 .35784 Mtetra
.723 .763 .884 r
.59286 .35784 .59929 .36566 .61183 .35927 .60543 .35137 Mtetra
.729 .763 .88 r
.60543 .35137 .61183 .35927 .6244 .35257 .61804 .3446 Mtetra
.733 .764 .877 r
.61804 .3446 .6244 .35257 .63699 .34564 .63068 .3376 Mtetra
.736 .764 .875 r
.63068 .3376 .63699 .34564 .64962 .33856 .64335 .33046 Mtetra
.737 .763 .874 r
.64335 .33046 .64962 .33856 .66228 .3314 .65605 .32324 Mtetra
.65605 .32324 .66228 .3314 .67497 .32422 .66879 .31603 Mtetra
.735 .762 .875 r
.66879 .31603 .67497 .32422 .68771 .31711 .68157 .30887 Mtetra
.732 .761 .876 r
.68157 .30887 .68771 .31711 .70048 .3101 .69439 .30182 Mtetra
.728 .76 .879 r
.69439 .30182 .70048 .3101 .7133 .30324 .70726 .29493 Mtetra
.723 .759 .881 r
.70726 .29493 .7133 .30324 .72618 .29656 .72017 .28823 Mtetra
.718 .758 .884 r
.72017 .28823 .72618 .29656 .7391 .29008 .73315 .28173 Mtetra
.712 .756 .887 r
.73315 .28173 .7391 .29008 .75209 .28381 .74618 .27543 Mtetra
.707 .755 .889 r
.74618 .27543 .75209 .28381 .76514 .27775 .75927 .26934 Mtetra
.701 .753 .892 r
.75927 .26934 .76514 .27775 .77825 .27188 .77243 .26345 Mtetra
.696 .751 .894 r
.77243 .26345 .77825 .27188 .79143 .2662 .78566 .25774 Mtetra
.691 .75 .896 r
.78566 .25774 .79143 .2662 .80468 .26068 .79895 .25219 Mtetra
.687 .748 .898 r
.79895 .25219 .80468 .26068 .818 .2553 .81231 .24678 Mtetra
.683 .747 .9 r
.81231 .24678 .818 .2553 .83138 .25005 .82574 .24149 Mtetra
.68 .746 .901 r
.82574 .24149 .83138 .25005 .84483 .2449 .83924 .23631 Mtetra
.633 .727 .916 r
.22256 .44742 .22997 .45452 .24085 .45166 .23347 .4445 Mtetra
.633 .727 .915 r
.23347 .4445 .24085 .45166 .25177 .44877 .24442 .44156 Mtetra
.634 .726 .914 r
.24442 .44156 .25177 .44877 .26276 .44586 .25543 .4386 Mtetra
.25543 .4386 .26276 .44586 .27379 .44292 .26649 .43562 Mtetra
.634 .725 .914 r
.26649 .43562 .27379 .44292 .28488 .43996 .27761 .43262 Mtetra
.634 .725 .913 r
.27761 .43262 .28488 .43996 .29602 .43699 .28877 .42961 Mtetra
.633 .725 .914 r
.28877 .42961 .29602 .43699 .30721 .43401 .29999 .42661 Mtetra
.632 .724 .914 r
.29999 .42661 .30721 .43401 .31846 .43105 .31126 .42363 Mtetra
.63 .724 .915 r
.31126 .42363 .31846 .43105 .32976 .42813 .32258 .4207 Mtetra
.627 .723 .916 r
.32258 .4207 .32976 .42813 .3411 .42525 .33396 .41782 Mtetra
.623 .723 .918 r
.33396 .41782 .3411 .42525 .3525 .42246 .34538 .41502 Mtetra
.619 .722 .92 r
.34538 .41502 .3525 .42246 .36395 .41975 .35685 .41231 Mtetra
.614 .722 .922 r
.35685 .41231 .36395 .41975 .37545 .41715 .36838 .40972 Mtetra
.608 .721 .925 r
.36838 .40972 .37545 .41715 .38701 .41467 .37996 .40724 Mtetra
.603 .72 .927 r
.37996 .40724 .38701 .41467 .39862 .4123 .3916 .40488 Mtetra
.598 .719 .929 r
.3916 .40488 .39862 .4123 .41029 .41004 .4033 .40262 Mtetra
.594 .719 .931 r
.4033 .40262 .41029 .41004 .42202 .40787 .41505 .40045 Mtetra
.591 .718 .932 r
.41505 .40045 .42202 .40787 .43381 .40575 .42687 .39832 Mtetra
.59 .719 .933 r
.42687 .39832 .43381 .40575 .44567 .40365 .43876 .39619 Mtetra
.592 .72 .932 r
.43876 .39619 .44567 .40365 .45759 .40149 .45071 .39401 Mtetra
.597 .721 .931 r
.45071 .39401 .45759 .40149 .46958 .39923 .46273 .39171 Mtetra
.604 .724 .929 r
.46273 .39171 .46958 .39923 .48164 .39679 .47482 .38922 Mtetra
.614 .727 .926 r
.47482 .38922 .48164 .39679 .49377 .3941 .48698 .38647 Mtetra
.625 .73 .922 r
.48698 .38647 .49377 .3941 .50596 .3911 .49921 .38339 Mtetra
.639 .734 .917 r
.49921 .38339 .50596 .3911 .51822 .38771 .5115 .37993 Mtetra
.653 .737 .912 r
.5115 .37993 .51822 .38771 .53054 .3839 .52385 .37604 Mtetra
.667 .741 .906 r
.52385 .37604 .53054 .3839 .54291 .37962 .53626 .37168 Mtetra
.68 .744 .899 r
.53626 .37168 .54291 .37962 .55534 .37487 .54872 .36684 Mtetra
.693 .747 .893 r
.54872 .36684 .55534 .37487 .5678 .36964 .56123 .36153 Mtetra
.704 .749 .887 r
.56123 .36153 .5678 .36964 .58031 .36395 .57378 .35576 Mtetra
.713 .751 .882 r
.57378 .35576 .58031 .36395 .59286 .35784 .58636 .34959 Mtetra
.721 .752 .877 r
.58636 .34959 .59286 .35784 .60543 .35137 .59898 .34306 Mtetra
.727 .754 .874 r
.59898 .34306 .60543 .35137 .61804 .3446 .61163 .33624 Mtetra
.731 .755 .871 r
.61163 .33624 .61804 .3446 .63068 .3376 .62431 .3292 Mtetra
.734 .755 .87 r
.62431 .3292 .63068 .3376 .64335 .33046 .63702 .32202 Mtetra
.735 .756 .869 r
.63702 .32202 .64335 .33046 .65605 .32324 .64977 .31478 Mtetra
.734 .756 .87 r
.64977 .31478 .65605 .32324 .66879 .31603 .66255 .30755 Mtetra
.733 .756 .871 r
.66255 .30755 .66879 .31603 .68157 .30887 .67537 .30038 Mtetra
.73 .756 .873 r
.67537 .30038 .68157 .30887 .69439 .30182 .68824 .29333 Mtetra
.726 .756 .876 r
.68824 .29333 .69439 .30182 .70726 .29493 .70115 .28643 Mtetra
.722 .755 .879 r
.70115 .28643 .70726 .29493 .72017 .28823 .71412 .27972 Mtetra
.717 .754 .882 r
.71412 .27972 .72017 .28823 .73315 .28173 .72714 .27321 Mtetra
.711 .753 .885 r
.72714 .27321 .73315 .28173 .74618 .27543 .74021 .2669 Mtetra
.706 .752 .888 r
.74021 .2669 .74618 .27543 .75927 .26934 .75336 .2608 Mtetra
.7 .751 .891 r
.75336 .2608 .75927 .26934 .77243 .26345 .76656 .2549 Mtetra
.695 .75 .894 r
.76656 .2549 .77243 .26345 .78566 .25774 .77983 .24917 Mtetra
.691 .749 .896 r
.77983 .24917 .78566 .25774 .79895 .25219 .79317 .2436 Mtetra
.686 .747 .898 r
.79317 .2436 .79895 .25219 .81231 .24678 .80658 .23817 Mtetra
.682 .746 .9 r
.80658 .23817 .81231 .24678 .82574 .24149 .82006 .23285 Mtetra
.679 .745 .901 r
.82006 .23285 .82574 .24149 .83924 .23631 .83361 .22763 Mtetra
.634 .728 .916 r
.2151 .44026 .22256 .44742 .23347 .4445 .22603 .43729 Mtetra
.634 .727 .915 r
.22603 .43729 .23347 .4445 .24442 .44156 .23702 .4343 Mtetra
.634 .726 .914 r
.23702 .4343 .24442 .44156 .25543 .4386 .24805 .43129 Mtetra
.635 .726 .914 r
.24805 .43129 .25543 .4386 .26649 .43562 .25914 .42826 Mtetra
.635 .725 .913 r
.25914 .42826 .26649 .43562 .27761 .43262 .27028 .42522 Mtetra
.634 .725 .913 r
.27028 .42522 .27761 .43262 .28877 .42961 .28147 .42218 Mtetra
.633 .724 .913 r
.28147 .42218 .28877 .42961 .29999 .42661 .29272 .41914 Mtetra
.632 .724 .914 r
.29272 .41914 .29999 .42661 .31126 .42363 .30401 .41614 Mtetra
.629 .723 .915 r
.30401 .41614 .31126 .42363 .32258 .4207 .31536 .41318 Mtetra
.626 .723 .916 r
.31536 .41318 .32258 .4207 .33396 .41782 .32676 .41028 Mtetra
.623 .722 .917 r
.32676 .41028 .33396 .41782 .34538 .41502 .33821 .40747 Mtetra
.618 .721 .919 r
.33821 .40747 .34538 .41502 .35685 .41231 .34971 .40475 Mtetra
.613 .719 .921 r
.34971 .40475 .35685 .41231 .36838 .40972 .36126 .40214 Mtetra
.608 .718 .923 r
.36126 .40214 .36838 .40972 .37996 .40724 .37287 .39965 Mtetra
.603 .717 .925 r
.37287 .39965 .37996 .40724 .3916 .40488 .38453 .39727 Mtetra
.599 .715 .926 r
.38453 .39727 .3916 .40488 .4033 .40262 .39625 .39499 Mtetra
.595 .714 .927 r
.39625 .39499 .4033 .40262 .41505 .40045 .40804 .39278 Mtetra
.593 .713 .928 r
.40804 .39278 .41505 .40045 .42687 .39832 .41989 .39061 Mtetra
.593 .713 .927 r
.41989 .39061 .42687 .39832 .43876 .39619 .4318 .38843 Mtetra
.595 .713 .926 r
.4318 .38843 .43876 .39619 .45071 .39401 .44378 .38619 Mtetra
.6 .714 .925 r
.44378 .38619 .45071 .39401 .46273 .39171 .45583 .38382 Mtetra
.607 .716 .922 r
.45583 .38382 .46273 .39171 .47482 .38922 .46795 .38126 Mtetra
.617 .718 .918 r
.46795 .38126 .47482 .38922 .48698 .38647 .48015 .37842 Mtetra
.628 .721 .914 r
.48015 .37842 .48698 .38647 .49921 .38339 .49241 .37526 Mtetra
.641 .724 .909 r
.49241 .37526 .49921 .38339 .5115 .37993 .50473 .37171 Mtetra
.654 .727 .903 r
.50473 .37171 .5115 .37993 .52385 .37604 .51712 .36773 Mtetra
.668 .731 .897 r
.51712 .36773 .52385 .37604 .53626 .37168 .52956 .36328 Mtetra
.68 .734 .891 r
.52956 .36328 .53626 .37168 .54872 .36684 .54205 .35836 Mtetra
.692 .736 .885 r
.54205 .35836 .54872 .36684 .56123 .36153 .5546 .35298 Mtetra
.703 .739 .879 r
.5546 .35298 .56123 .36153 .57378 .35576 .56718 .34715 Mtetra
.712 .741 .875 r
.56718 .34715 .57378 .35576 .58636 .34959 .5798 .34092 Mtetra
.719 .743 .871 r
.5798 .34092 .58636 .34959 .59898 .34306 .59246 .33435 Mtetra
.725 .745 .868 r
.59246 .33435 .59898 .34306 .61163 .33624 .60515 .3275 Mtetra
.729 .746 .866 r
.60515 .3275 .61163 .33624 .62431 .3292 .61788 .32045 Mtetra
.731 .748 .865 r
.61788 .32045 .62431 .3292 .63702 .32202 .63063 .31327 Mtetra
.732 .749 .866 r
.63063 .31327 .63702 .32202 .64977 .31478 .64342 .30603 Mtetra
.732 .75 .867 r
.64342 .30603 .64977 .31478 .66255 .30755 .65625 .29881 Mtetra
.73 .751 .869 r
.65625 .29881 .66255 .30755 .67537 .30038 .66912 .29165 Mtetra
.728 .751 .871 r
.66912 .29165 .67537 .30038 .68824 .29333 .68203 .28462 Mtetra
.724 .751 .874 r
.68203 .28462 .68824 .29333 .70115 .28643 .69499 .27774 Mtetra
.72 .751 .877 r
.69499 .27774 .70115 .28643 .71412 .27972 .708 .27104 Mtetra
.715 .751 .881 r
.708 .27104 .71412 .27972 .72714 .27321 .72107 .26454 Mtetra
.71 .751 .884 r
.72107 .26454 .72714 .27321 .74021 .2669 .73419 .25824 Mtetra
.704 .75 .887 r
.73419 .25824 .74021 .2669 .75336 .2608 .74738 .25214 Mtetra
.699 .749 .89 r
.74738 .25214 .75336 .2608 .76656 .2549 .76064 .24623 Mtetra
.694 .748 .893 r
.76064 .24623 .76656 .2549 .77983 .24917 .77396 .2405 Mtetra
.69 .748 .896 r
.77396 .2405 .77983 .24917 .79317 .2436 .78734 .23491 Mtetra
.686 .747 .898 r
.78734 .23491 .79317 .2436 .80658 .23817 .8008 .22946 Mtetra
.682 .746 .899 r
.8008 .22946 .80658 .23817 .82006 .23285 .81432 .22412 Mtetra
.679 .745 .901 r
.81432 .22412 .82006 .23285 .83361 .22763 .82792 .21888 Mtetra
.635 .728 .915 r
.20759 .43306 .2151 .44026 .22603 .43729 .21854 .43003 Mtetra
.21854 .43003 .22603 .43729 .23702 .4343 .22955 .42699 Mtetra
.635 .727 .914 r
.22955 .42699 .23702 .4343 .24805 .43129 .24061 .42393 Mtetra
.635 .726 .914 r
.24061 .42393 .24805 .43129 .25914 .42826 .25173 .42085 Mtetra
.635 .726 .913 r
.25173 .42085 .25914 .42826 .27028 .42522 .26289 .41777 Mtetra
.634 .725 .913 r
.26289 .41777 .27028 .42522 .28147 .42218 .27411 .41468 Mtetra
.633 .725 .913 r
.27411 .41468 .28147 .42218 .29272 .41914 .28538 .41161 Mtetra
.632 .724 .914 r
.28538 .41161 .29272 .41914 .30401 .41614 .29671 .40858 Mtetra
.629 .723 .915 r
.29671 .40858 .30401 .41614 .31536 .41318 .30808 .40558 Mtetra
.626 .722 .915 r
.30808 .40558 .31536 .41318 .32676 .41028 .3195 .40266 Mtetra
.623 .721 .917 r
.3195 .40266 .32676 .41028 .33821 .40747 .33098 .39981 Mtetra
.619 .719 .918 r
.33098 .39981 .33821 .40747 .34971 .40475 .34251 .39706 Mtetra
.614 .718 .919 r
.34251 .39706 .34971 .40475 .36126 .40214 .35409 .39442 Mtetra
.609 .716 .921 r
.35409 .39442 .36126 .40214 .37287 .39965 .36572 .39189 Mtetra
.604 .714 .922 r
.36572 .39189 .37287 .39965 .38453 .39727 .37741 .38947 Mtetra
.6 .712 .923 r
.37741 .38947 .38453 .39727 .39625 .39499 .38916 .38713 Mtetra
.597 .71 .923 r
.38916 .38713 .39625 .39499 .40804 .39278 .40097 .38487 Mtetra
.595 .709 .923 r
.40097 .38487 .40804 .39278 .41989 .39061 .41285 .38263 Mtetra
.596 .708 .922 r
.41285 .38263 .41989 .39061 .4318 .38843 .42479 .38038 Mtetra
.598 .708 .92 r
.42479 .38038 .4318 .38843 .44378 .38619 .4368 .37805 Mtetra
.603 .708 .918 r
.4368 .37805 .44378 .38619 .45583 .38382 .44889 .37559 Mtetra
.611 .709 .915 r
.44889 .37559 .45583 .38382 .46795 .38126 .46104 .37292 Mtetra
.62 .711 .911 r
.46104 .37292 .46795 .38126 .48015 .37842 .47326 .36998 Mtetra
.631 .713 .906 r
.47326 .36998 .48015 .37842 .49241 .37526 .48555 .36671 Mtetra
.643 .716 .9 r
.48555 .36671 .49241 .37526 .50473 .37171 .49791 .36306 Mtetra
.656 .719 .895 r
.49791 .36306 .50473 .37171 .51712 .36773 .51033 .35898 Mtetra
.668 .721 .889 r
.51033 .35898 .51712 .36773 .52956 .36328 .5228 .35445 Mtetra
.68 .724 .883 r
.5228 .35445 .52956 .36328 .54205 .35836 .53533 .34945 Mtetra
.691 .727 .878 r
.53533 .34945 .54205 .35836 .5546 .35298 .54791 .344 Mtetra
.701 .73 .873 r
.54791 .344 .5546 .35298 .56718 .34715 .56053 .33813 Mtetra
.709 .732 .869 r
.56053 .33813 .56718 .34715 .5798 .34092 .57319 .33187 Mtetra
.716 .735 .865 r
.57319 .33187 .5798 .34092 .59246 .33435 .58589 .32528 Mtetra
.722 .737 .863 r
.58589 .32528 .59246 .33435 .60515 .3275 .59862 .31843 Mtetra
.726 .739 .862 r
.59862 .31843 .60515 .3275 .61788 .32045 .61139 .31139 Mtetra
.728 .741 .862 r
.61139 .31139 .61788 .32045 .63063 .31327 .62418 .30423 Mtetra
.729 .743 .863 r
.62418 .30423 .63063 .31327 .64342 .30603 .63702 .29702 Mtetra
.729 .744 .864 r
.63702 .29702 .64342 .30603 .65625 .29881 .64989 .28983 Mtetra
.727 .746 .867 r
.64989 .28983 .65625 .29881 .66912 .29165 .66281 .28271 Mtetra
.725 .747 .869 r
.66281 .28271 .66912 .29165 .68203 .28462 .67576 .27571 Mtetra
.721 .748 .873 r
.67576 .27571 .68203 .28462 .69499 .27774 .68877 .26887 Mtetra
.717 .748 .876 r
.68877 .26887 .69499 .27774 .708 .27104 .70183 .2622 Mtetra
.713 .748 .88 r
.70183 .2622 .708 .27104 .72107 .26454 .71495 .25573 Mtetra
.708 .748 .884 r
.71495 .25573 .72107 .26454 .73419 .25824 .72812 .24945 Mtetra
.703 .748 .887 r
.72812 .24945 .73419 .25824 .74738 .25214 .74136 .24337 Mtetra
.698 .748 .89 r
.74136 .24337 .74738 .25214 .76064 .24623 .75466 .23746 Mtetra
.693 .747 .893 r
.75466 .23746 .76064 .24623 .77396 .2405 .76803 .23173 Mtetra
.689 .747 .895 r
.76803 .23173 .77396 .2405 .78734 .23491 .78146 .22613 Mtetra
.685 .746 .898 r
.78146 .22613 .78734 .23491 .8008 .22946 .79496 .22067 Mtetra
.681 .745 .899 r
.79496 .22067 .8008 .22946 .81432 .22412 .80854 .21531 Mtetra
.678 .745 .901 r
.80854 .21531 .81432 .22412 .82792 .21888 .82218 .21004 Mtetra
.636 .729 .915 r
.20001 .42581 .20759 .43306 .21854 .43003 .21099 .42273 Mtetra
.636 .728 .915 r
.21099 .42273 .21854 .43003 .22955 .42699 .22203 .41964 Mtetra
.636 .728 .914 r
.22203 .41964 .22955 .42699 .24061 .42393 .23311 .41653 Mtetra
.636 .727 .914 r
.23311 .41653 .24061 .42393 .25173 .42085 .24426 .4134 Mtetra
.636 .726 .913 r
.24426 .4134 .25173 .42085 .26289 .41777 .25545 .41027 Mtetra
.635 .726 .913 r
.25545 .41027 .26289 .41777 .27411 .41468 .2667 .40714 Mtetra
.634 .725 .913 r
.2667 .40714 .27411 .41468 .28538 .41161 .27799 .40403 Mtetra
.632 .724 .914 r
.27799 .40403 .28538 .41161 .29671 .40858 .28934 .40095 Mtetra
.63 .723 .914 r
.28934 .40095 .29671 .40858 .30808 .40558 .30074 .39792 Mtetra
.627 .722 .915 r
.30074 .39792 .30808 .40558 .3195 .40266 .31219 .39495 Mtetra
.623 .72 .916 r
.31219 .39495 .3195 .40266 .33098 .39981 .3237 .39206 Mtetra
.619 .719 .917 r
.3237 .39206 .33098 .39981 .34251 .39706 .33525 .38926 Mtetra
.615 .717 .918 r
.33525 .38926 .34251 .39706 .35409 .39442 .34686 .38657 Mtetra
.61 .714 .919 r
.34686 .38657 .35409 .39442 .36572 .39189 .35852 .38398 Mtetra
.606 .712 .919 r
.35852 .38398 .36572 .39189 .37741 .38947 .37024 .38149 Mtetra
.602 .71 .92 r
.37024 .38149 .37741 .38947 .38916 .38713 .38202 .37908 Mtetra
.6 .707 .919 r
.38202 .37908 .38916 .38713 .40097 .38487 .39386 .37673 Mtetra
.599 .706 .918 r
.39386 .37673 .40097 .38487 .41285 .38263 .40577 .3744 Mtetra
.6 .704 .917 r
.40577 .3744 .41285 .38263 .42479 .38038 .41774 .37204 Mtetra
.603 .703 .915 r
.41774 .37204 .42479 .38038 .4368 .37805 .42978 .3696 Mtetra
.608 .703 .912 r
.42978 .3696 .4368 .37805 .44889 .37559 .44189 .36702 Mtetra
.615 .703 .908 r
.44189 .36702 .44889 .37559 .46104 .37292 .45407 .36423 Mtetra
.624 .705 .903 r
.45407 .36423 .46104 .37292 .47326 .36998 .46632 .36117 Mtetra
.634 .706 .898 r
.46632 .36117 .47326 .36998 .48555 .36671 .47865 .35779 Mtetra
.645 .708 .893 r
.47865 .35779 .48555 .36671 .49791 .36306 .49103 .35402 Mtetra
.657 .711 .887 r
.49103 .35402 .49791 .36306 .51033 .35898 .50348 .34984 Mtetra
.669 .713 .882 r
.50348 .34984 .51033 .35898 .5228 .35445 .51599 .34522 Mtetra
.68 .716 .876 r
.51599 .34522 .5228 .35445 .53533 .34945 .52856 .34015 Mtetra
.69 .719 .871 r
.52856 .34015 .53533 .34945 .54791 .344 .54117 .33465 Mtetra
.699 .722 .867 r
.54117 .33465 .54791 .344 .56053 .33813 .55383 .32874 Mtetra
.707 .725 .864 r
.55383 .32874 .56053 .33813 .57319 .33187 .56652 .32246 Mtetra
.714 .727 .861 r
.56652 .32246 .57319 .33187 .58589 .32528 .57926 .31588 Mtetra
.719 .73 .859 r
.57926 .31588 .58589 .32528 .59862 .31843 .59203 .30905 Mtetra
.723 .733 .859 r
.59203 .30905 .59862 .31843 .61139 .31139 .60484 .30204 Mtetra
.725 .735 .859 r
.60484 .30204 .61139 .31139 .62418 .30423 .61768 .29492 Mtetra
.726 .737 .86 r
.61768 .29492 .62418 .30423 .63702 .29702 .63056 .28777 Mtetra
.726 .739 .862 r
.63056 .28777 .63702 .29702 .64989 .28983 .64348 .28063 Mtetra
.724 .741 .865 r
.64348 .28063 .64989 .28983 .66281 .28271 .65644 .27358 Mtetra
.722 .743 .868 r
.65644 .27358 .66281 .28271 .67576 .27571 .66944 .26664 Mtetra
.719 .744 .872 r
.66944 .26664 .67576 .27571 .68877 .26887 .6825 .25985 Mtetra
.715 .745 .876 r
.6825 .25985 .68877 .26887 .70183 .2622 .6956 .25323 Mtetra
.71 .746 .88 r
.6956 .25323 .70183 .2622 .71495 .25573 .70877 .2468 Mtetra
.706 .746 .883 r
.70877 .2468 .71495 .25573 .72812 .24945 .72199 .24055 Mtetra
.701 .746 .887 r
.72199 .24055 .72812 .24945 .74136 .24337 .73528 .23449 Mtetra
.696 .746 .89 r
.73528 .23449 .74136 .24337 .75466 .23746 .74863 .2286 Mtetra
.692 .746 .893 r
.74863 .2286 .75466 .23746 .76803 .23173 .76204 .22286 Mtetra
.688 .746 .895 r
.76204 .22286 .76803 .23173 .78146 .22613 .77553 .21727 Mtetra
.684 .745 .898 r
.77553 .21727 .78146 .22613 .79496 .22067 .78908 .21179 Mtetra
.681 .745 .899 r
.78908 .21179 .79496 .22067 .80854 .21531 .8027 .20641 Mtetra
.678 .744 .901 r
.8027 .20641 .80854 .21531 .82218 .21004 .81639 .20112 Mtetra
.637 .73 .915 r
.19237 .41853 .20001 .42581 .21099 .42273 .20338 .4154 Mtetra
.637 .729 .915 r
.20338 .4154 .21099 .42273 .22203 .41964 .21444 .41225 Mtetra
.637 .728 .914 r
.21444 .41225 .22203 .41964 .23311 .41653 .22556 .40909 Mtetra
.22556 .40909 .23311 .41653 .24426 .4134 .23673 .40591 Mtetra
.636 .727 .914 r
.23673 .40591 .24426 .4134 .25545 .41027 .24795 .40273 Mtetra
.636 .726 .914 r
.24795 .40273 .25545 .41027 .2667 .40714 .25922 .39956 Mtetra
.634 .726 .914 r
.25922 .39956 .2667 .40714 .27799 .40403 .27054 .3964 Mtetra
.633 .725 .914 r
.27054 .3964 .27799 .40403 .28934 .40095 .28192 .39327 Mtetra
.631 .723 .914 r
.28192 .39327 .28934 .40095 .30074 .39792 .29335 .39018 Mtetra
.628 .722 .915 r
.29335 .39018 .30074 .39792 .31219 .39495 .30483 .38716 Mtetra
.624 .72 .915 r
.30483 .38716 .31219 .39495 .3237 .39206 .31636 .38422 Mtetra
.621 .718 .916 r
.31636 .38422 .3237 .39206 .33525 .38926 .32794 .38136 Mtetra
.617 .716 .917 r
.32794 .38136 .33525 .38926 .34686 .38657 .33958 .37859 Mtetra
.612 .713 .917 r
.33958 .37859 .34686 .38657 .35852 .38398 .35127 .37592 Mtetra
.609 .711 .917 r
.35127 .37592 .35852 .38398 .37024 .38149 .36302 .37334 Mtetra
.605 .708 .917 r
.36302 .37334 .37024 .38149 .38202 .37908 .37483 .37084 Mtetra
.603 .705 .916 r
.37483 .37084 .38202 .37908 .39386 .37673 .3867 .36837 Mtetra
.603 .703 .914 r
.3867 .36837 .39386 .37673 .40577 .3744 .39863 .36592 Mtetra
.604 .701 .912 r
.39863 .36592 .40577 .3744 .41774 .37204 .41063 .36344 Mtetra
.607 .7 .909 r
.41063 .36344 .41774 .37204 .42978 .3696 .42271 .36086 Mtetra
.612 .699 .906 r
.42271 .36086 .42978 .3696 .44189 .36702 .43485 .35815 Mtetra
.619 .699 .902 r
.43485 .35815 .44189 .36702 .45407 .36423 .44706 .35522 Mtetra
.627 .699 .897 r
.44706 .35522 .45407 .36423 .46632 .36117 .45934 .35203 Mtetra
.637 .701 .892 r
.45934 .35203 .46632 .36117 .47865 .35779 .47169 .34851 Mtetra
.648 .702 .886 r
.47169 .34851 .47865 .35779 .49103 .35402 .48411 .34463 Mtetra
.658 .704 .881 r
.48411 .34463 .49103 .35402 .50348 .34984 .49659 .34034 Mtetra
.669 .707 .876 r
.49659 .34034 .50348 .34984 .51599 .34522 .50913 .33564 Mtetra
.679 .709 .871 r
.50913 .33564 .51599 .34522 .52856 .34015 .52173 .33051 Mtetra
.689 .712 .866 r
.52173 .33051 .52856 .34015 .54117 .33465 .53438 .32496 Mtetra
.697 .715 .863 r
.53438 .32496 .54117 .33465 .55383 .32874 .54707 .31903 Mtetra
.705 .718 .86 r
.54707 .31903 .55383 .32874 .56652 .32246 .5598 .31276 Mtetra
.711 .721 .858 r
.5598 .31276 .56652 .32246 .57926 .31588 .57258 .30619 Mtetra
.716 .724 .857 r
.57258 .30619 .57926 .31588 .59203 .30905 .58539 .2994 Mtetra
.719 .727 .856 r
.58539 .2994 .59203 .30905 .60484 .30204 .59823 .29245 Mtetra
.722 .73 .857 r
.59823 .29245 .60484 .30204 .61768 .29492 .61112 .2854 Mtetra
.722 .733 .859 r
.61112 .2854 .61768 .29492 .63056 .28777 .62404 .27831 Mtetra
.722 .735 .861 r
.62404 .27831 .63056 .28777 .64348 .28063 .63701 .27126 Mtetra
.721 .738 .864 r
.63701 .27126 .64348 .28063 .65644 .27358 .65001 .26427 Mtetra
.719 .74 .868 r
.65001 .26427 .65644 .27358 .66944 .26664 .66307 .25741 Mtetra
.716 .741 .872 r
.66307 .25741 .66944 .26664 .6825 .25985 .67617 .25068 Mtetra
.712 .743 .876 r
.67617 .25068 .6825 .25985 .6956 .25323 .68933 .24413 Mtetra
.708 .744 .88 r
.68933 .24413 .6956 .25323 .70877 .2468 .70254 .23774 Mtetra
.703 .744 .883 r
.70254 .23774 .70877 .2468 .72199 .24055 .71581 .23154 Mtetra
.699 .745 .887 r
.71581 .23154 .72199 .24055 .73528 .23449 .72914 .22551 Mtetra
.695 .745 .89 r
.72914 .22551 .73528 .23449 .74863 .2286 .74254 .21963 Mtetra
.69 .745 .893 r
.74254 .21963 .74863 .2286 .76204 .22286 .75601 .21391 Mtetra
.686 .745 .896 r
.75601 .21391 .76204 .22286 .77553 .21727 .76954 .20831 Mtetra
.683 .745 .898 r
.76954 .20831 .77553 .21727 .78908 .21179 .78314 .20283 Mtetra
.68 .744 .9 r
.78314 .20283 .78908 .21179 .8027 .20641 .79681 .19744 Mtetra
.677 .744 .901 r
.79681 .19744 .8027 .20641 .81639 .20112 .81055 .19212 Mtetra
.637 .73 .916 r
.18467 .4112 .19237 .41853 .20338 .4154 .1957 .40802 Mtetra
.637 .73 .915 r
.1957 .40802 .20338 .4154 .21444 .41225 .2068 .40482 Mtetra
.638 .729 .915 r
.2068 .40482 .21444 .41225 .22556 .40909 .21794 .40161 Mtetra
.637 .729 .914 r
.21794 .40161 .22556 .40909 .23673 .40591 .22913 .39838 Mtetra
.637 .728 .914 r
.22913 .39838 .23673 .40591 .24795 .40273 .24038 .39515 Mtetra
.636 .727 .914 r
.24038 .39515 .24795 .40273 .25922 .39956 .25168 .39193 Mtetra
.635 .726 .914 r
.25168 .39193 .25922 .39956 .27054 .3964 .26304 .38871 Mtetra
.634 .725 .914 r
.26304 .38871 .27054 .3964 .28192 .39327 .27444 .38553 Mtetra
.632 .724 .914 r
.27444 .38553 .28192 .39327 .29335 .39018 .2859 .38239 Mtetra
.629 .722 .914 r
.2859 .38239 .29335 .39018 .30483 .38716 .29741 .3793 Mtetra
.626 .72 .915 r
.29741 .3793 .30483 .38716 .31636 .38422 .30897 .37629 Mtetra
.622 .718 .915 r
.30897 .37629 .31636 .38422 .32794 .38136 .32058 .37335 Mtetra
.619 .716 .915 r
.32058 .37335 .32794 .38136 .33958 .37859 .33225 .3705 Mtetra
.615 .713 .915 r
.33225 .3705 .33958 .37859 .35127 .37592 .34397 .36774 Mtetra
.612 .71 .915 r
.34397 .36774 .35127 .37592 .36302 .37334 .35575 .36505 Mtetra
.609 .707 .914 r
.35575 .36505 .36302 .37334 .37483 .37084 .36758 .36242 Mtetra
.608 .704 .912 r
.36758 .36242 .37483 .37084 .3867 .36837 .37949 .35983 Mtetra
.607 .701 .91 r
.37949 .35983 .3867 .36837 .39863 .36592 .39145 .35724 Mtetra
.609 .699 .908 r
.39145 .35724 .39863 .36592 .41063 .36344 .40348 .35461 Mtetra
.612 .697 .904 r
.40348 .35461 .41063 .36344 .42271 .36086 .41558 .35188 Mtetra
.617 .696 .901 r
.41558 .35188 .42271 .36086 .43485 .35815 .42776 .34901 Mtetra
.623 .695 .896 r
.42776 .34901 .43485 .35815 .44706 .35522 .44 .34593 Mtetra
.631 .695 .891 r
.44 .34593 .44706 .35522 .45934 .35203 .45231 .34259 Mtetra
.64 .696 .886 r
.45231 .34259 .45934 .35203 .47169 .34851 .46469 .33894 Mtetra
.65 .698 .881 r
.46469 .33894 .47169 .34851 .48411 .34463 .47714 .33493 Mtetra
.66 .699 .876 r
.47714 .33493 .48411 .34463 .49659 .34034 .48965 .33055 Mtetra
.669 .702 .871 r
.48965 .33055 .49659 .34034 .50913 .33564 .50223 .32576 Mtetra
.679 .704 .866 r
.50223 .32576 .50913 .33564 .52173 .33051 .51485 .32057 Mtetra
.688 .707 .862 r
.51485 .32057 .52173 .33051 .53438 .32496 .52753 .31499 Mtetra
.696 .71 .859 r
.52753 .31499 .53438 .32496 .54707 .31903 .54026 .30905 Mtetra
.702 .713 .857 r
.54026 .30905 .54707 .31903 .5598 .31276 .55303 .30279 Mtetra
.708 .716 .855 r
.55303 .30279 .5598 .31276 .57258 .30619 .56584 .29627 Mtetra
.713 .72 .855 r
.56584 .29627 .57258 .30619 .58539 .2994 .57869 .28953 Mtetra
.716 .723 .855 r
.57869 .28953 .58539 .2994 .59823 .29245 .59158 .28265 Mtetra
.718 .726 .856 r
.59158 .28265 .59823 .29245 .61112 .2854 .60451 .27568 Mtetra
.719 .729 .858 r
.60451 .27568 .61112 .2854 .62404 .27831 .61747 .26869 Mtetra
.719 .732 .861 r
.61747 .26869 .62404 .27831 .63701 .27126 .63048 .26172 Mtetra
.718 .735 .864 r
.63048 .26172 .63701 .27126 .65001 .26427 .64353 .25483 Mtetra
.715 .737 .868 r
.64353 .25483 .65001 .26427 .66307 .25741 .65664 .24805 Mtetra
.713 .739 .872 r
.65664 .24805 .66307 .25741 .67617 .25068 .66979 .2414 Mtetra
.709 .741 .876 r
.66979 .2414 .67617 .25068 .68933 .24413 .68299 .23492 Mtetra
.705 .742 .88 r
.68299 .23492 .68933 .24413 .70254 .23774 .69625 .22859 Mtetra
.701 .743 .884 r
.69625 .22859 .70254 .23774 .71581 .23154 .70957 .22243 Mtetra
.697 .744 .887 r
.70957 .22243 .71581 .23154 .72914 .22551 .72296 .21643 Mtetra
.693 .744 .891 r
.72296 .21643 .72914 .22551 .74254 .21963 .73641 .21059 Mtetra
.689 .744 .893 r
.73641 .21059 .74254 .21963 .75601 .21391 .74992 .20487 Mtetra
.685 .744 .896 r
.74992 .20487 .75601 .21391 .76954 .20831 .7635 .19928 Mtetra
.682 .744 .898 r
.7635 .19928 .76954 .20831 .78314 .20283 .77715 .19379 Mtetra
.679 .744 .9 r
.77715 .19379 .78314 .20283 .79681 .19744 .79087 .18838 Mtetra
.677 .743 .901 r
.79087 .18838 .79681 .19744 .81055 .19212 .80466 .18305 Mtetra
.638 .731 .916 r
.17691 .40384 .18467 .4112 .1957 .40802 .18797 .40061 Mtetra
.638 .731 .915 r
.18797 .40061 .1957 .40802 .2068 .40482 .19909 .39736 Mtetra
.638 .73 .915 r
.19909 .39736 .2068 .40482 .21794 .40161 .21026 .39409 Mtetra
.638 .729 .914 r
.21026 .39409 .21794 .40161 .22913 .39838 .22148 .39082 Mtetra
.22148 .39082 .22913 .39838 .24038 .39515 .23276 .38753 Mtetra
.637 .728 .914 r
.23276 .38753 .24038 .39515 .25168 .39193 .24409 .38425 Mtetra
.636 .727 .914 r
.24409 .38425 .25168 .39193 .26304 .38871 .25547 .38099 Mtetra
.635 .726 .914 r
.25547 .38099 .26304 .38871 .27444 .38553 .2669 .37774 Mtetra
.633 .725 .914 r
.2669 .37774 .27444 .38553 .2859 .38239 .27839 .37454 Mtetra
.63 .723 .914 r
.27839 .37454 .2859 .38239 .29741 .3793 .28993 .37138 Mtetra
.628 .721 .914 r
.28993 .37138 .29741 .3793 .30897 .37629 .30152 .36829 Mtetra
.625 .718 .914 r
.30152 .36829 .30897 .37629 .32058 .37335 .31316 .36526 Mtetra
.621 .716 .914 r
.31316 .36526 .32058 .37335 .33225 .3705 .32486 .36231 Mtetra
.618 .713 .913 r
.32486 .36231 .33225 .3705 .34397 .36774 .33661 .35943 Mtetra
.615 .71 .912 r
.33661 .35943 .34397 .36774 .35575 .36505 .34842 .35662 Mtetra
.613 .706 .911 r
.34842 .35662 .35575 .36505 .36758 .36242 .36029 .35386 Mtetra
.612 .703 .909 r
.36029 .35386 .36758 .36242 .37949 .35983 .37222 .35112 Mtetra
.612 .7 .907 r
.37222 .35112 .37949 .35983 .39145 .35724 .38422 .34838 Mtetra
.613 .698 .904 r
.38422 .34838 .39145 .35724 .40348 .35461 .39628 .34558 Mtetra
.617 .696 .9 r
.39628 .34558 .40348 .35461 .41558 .35188 .40841 .34269 Mtetra
.621 .694 .896 r
.40841 .34269 .41558 .35188 .42776 .34901 .42062 .33964 Mtetra
.627 .693 .892 r
.42062 .33964 .42776 .34901 .44 .34593 .43289 .3364 Mtetra
.635 .693 .887 r
.43289 .3364 .44 .34593 .45231 .34259 .44523 .33291 Mtetra
.643 .693 .882 r
.44523 .33291 .45231 .34259 .46469 .33894 .45764 .32912 Mtetra
.652 .694 .877 r
.45764 .32912 .46469 .33894 .47714 .33493 .47012 .32499 Mtetra
.661 .696 .872 r
.47012 .32499 .47714 .33493 .48965 .33055 .48267 .3205 Mtetra
.67 .698 .867 r
.48267 .3205 .48965 .33055 .50223 .32576 .49527 .31564 Mtetra
.678 .7 .863 r
.49527 .31564 .50223 .32576 .51485 .32057 .50793 .3104 Mtetra
.686 .703 .86 r
.50793 .3104 .51485 .32057 .52753 .31499 .52064 .30479 Mtetra
.694 .706 .857 r
.52064 .30479 .52753 .31499 .54026 .30905 .5334 .29886 Mtetra
.7 .709 .855 r
.5334 .29886 .54026 .30905 .55303 .30279 .5462 .29263 Mtetra
.705 .713 .854 r
.5462 .29263 .55303 .30279 .56584 .29627 .55905 .28615 Mtetra
.71 .716 .854 r
.55905 .28615 .56584 .29627 .57869 .28953 .57194 .27949 Mtetra
.713 .719 .855 r
.57194 .27949 .57869 .28953 .59158 .28265 .58487 .27269 Mtetra
.715 .723 .856 r
.58487 .27269 .59158 .28265 .60451 .27568 .59784 .26582 Mtetra
.715 .726 .859 r
.59784 .26582 .60451 .27568 .61747 .26869 .61085 .25893 Mtetra
.715 .729 .862 r
.61085 .25893 .61747 .26869 .63048 .26172 .6239 .25206 Mtetra
.714 .732 .865 r
.6239 .25206 .63048 .26172 .64353 .25483 .637 .24527 Mtetra
.712 .735 .869 r
.637 .24527 .64353 .25483 .65664 .24805 .65015 .23858 Mtetra
.709 .737 .873 r
.65015 .23858 .65664 .24805 .66979 .2414 .66335 .23203 Mtetra
.706 .739 .877 r
.66335 .23203 .66979 .2414 .68299 .23492 .6766 .22561 Mtetra
.703 .741 .881 r
.6766 .22561 .68299 .23492 .69625 .22859 .68991 .21935 Mtetra
.699 .742 .885 r
.68991 .21935 .69625 .22859 .70957 .22243 .70329 .21324 Mtetra
.695 .743 .888 r
.70329 .21324 .70957 .22243 .72296 .21643 .71672 .20728 Mtetra
.691 .743 .891 r
.71672 .20728 .72296 .21643 .73641 .21059 .73022 .20146 Mtetra
.687 .743 .894 r
.73022 .20146 .73641 .21059 .74992 .20487 .74378 .19576 Mtetra
.684 .744 .896 r
.74378 .19576 .74992 .20487 .7635 .19928 .75741 .19017 Mtetra
.681 .744 .898 r
.75741 .19017 .7635 .19928 .77715 .19379 .77111 .18467 Mtetra
.678 .743 .9 r
.77111 .18467 .77715 .19379 .79087 .18838 .78488 .17925 Mtetra
.676 .743 .901 r
.78488 .17925 .79087 .18838 .80466 .18305 .79872 .17389 Mtetra
.639 .732 .916 r
.16908 .39643 .17691 .40384 .18797 .40061 .18017 .39315 Mtetra
.639 .731 .915 r
.18017 .39315 .18797 .40061 .19909 .39736 .19132 .38985 Mtetra
.19132 .38985 .19909 .39736 .21026 .39409 .20251 .38654 Mtetra
.639 .73 .914 r
.20251 .38654 .21026 .39409 .22148 .39082 .21376 .38321 Mtetra
.21376 .38321 .22148 .39082 .23276 .38753 .22507 .37988 Mtetra
.638 .729 .914 r
.22507 .37988 .23276 .38753 .24409 .38425 .23643 .37654 Mtetra
.637 .728 .914 r
.23643 .37654 .24409 .38425 .25547 .38099 .24784 .37321 Mtetra
.636 .727 .914 r
.24784 .37321 .25547 .38099 .2669 .37774 .2593 .3699 Mtetra
.634 .725 .913 r
.2593 .3699 .2669 .37774 .27839 .37454 .27082 .36663 Mtetra
.632 .724 .913 r
.27082 .36663 .27839 .37454 .28993 .37138 .28239 .36339 Mtetra
.63 .721 .913 r
.28239 .36339 .28993 .37138 .30152 .36829 .29401 .36021 Mtetra
.627 .719 .913 r
.29401 .36021 .30152 .36829 .31316 .36526 .30568 .35709 Mtetra
.624 .716 .912 r
.30568 .35709 .31316 .36526 .32486 .36231 .31741 .35403 Mtetra
.622 .713 .912 r
.31741 .35403 .32486 .36231 .33661 .35943 .3292 .35103 Mtetra
.619 .71 .91 r
.3292 .35103 .33661 .35943 .34842 .35662 .34104 .34808 Mtetra
.617 .707 .909 r
.34104 .34808 .34842 .35662 .36029 .35386 .35294 .34517 Mtetra
.617 .703 .907 r
.35294 .34517 .36029 .35386 .37222 .35112 .36491 .34227 Mtetra
.617 .7 .904 r
.36491 .34227 .37222 .35112 .38422 .34838 .37693 .33936 Mtetra
.619 .697 .901 r
.37693 .33936 .38422 .34838 .39628 .34558 .38903 .33639 Mtetra
.621 .695 .897 r
.38903 .33639 .39628 .34558 .40841 .34269 .40119 .33332 Mtetra
.626 .693 .893 r
.40119 .33332 .40841 .34269 .42062 .33964 .41343 .3301 Mtetra
.631 .692 .888 r
.41343 .3301 .42062 .33964 .43289 .3364 .42573 .32669 Mtetra
.638 .691 .883 r
.42573 .32669 .43289 .3364 .44523 .33291 .43811 .32303 Mtetra
.646 .691 .878 r
.43811 .32303 .44523 .33291 .45764 .32912 .45055 .3191 Mtetra
.654 .692 .874 r
.45055 .3191 .45764 .32912 .47012 .32499 .46306 .31485 Mtetra
.662 .693 .869 r
.46306 .31485 .47012 .32499 .48267 .3205 .47563 .31026 Mtetra
.67 .695 .865 r
.47563 .31026 .48267 .3205 .49527 .31564 .48826 .30533 Mtetra
.678 .698 .861 r
.48826 .30533 .49527 .31564 .50793 .3104 .50095 .30004 Mtetra
.685 .7 .858 r
.50095 .30004 .50793 .3104 .52064 .30479 .5137 .29443 Mtetra
.692 .703 .856 r
.5137 .29443 .52064 .30479 .5334 .29886 .52649 .2885 Mtetra
.698 .706 .854 r
.52649 .2885 .5334 .29886 .5462 .29263 .53933 .28231 Mtetra
.703 .71 .854 r
.53933 .28231 .5462 .29263 .55905 .28615 .55221 .2759 Mtetra
.707 .713 .854 r
.55221 .2759 .55905 .28615 .57194 .27949 .56514 .26931 Mtetra
.709 .717 .855 r
.56514 .26931 .57194 .27949 .58487 .27269 .57811 .26261 Mtetra
.711 .721 .857 r
.57811 .26261 .58487 .27269 .59784 .26582 .59112 .25584 Mtetra
.712 .724 .86 r
.59112 .25584 .59784 .26582 .61085 .25893 .60417 .24906 Mtetra
.712 .727 .863 r
.60417 .24906 .61085 .25893 .6239 .25206 .61727 .24231 Mtetra
.711 .731 .866 r
.61727 .24231 .6239 .25206 .637 .24527 .63042 .23562 Mtetra
.709 .733 .87 r
.63042 .23562 .637 .24527 .65015 .23858 .64361 .22903 Mtetra
.706 .736 .874 r
.64361 .22903 .65015 .23858 .66335 .23203 .65686 .22256 Mtetra
.703 .738 .878 r
.65686 .22256 .66335 .23203 .6766 .22561 .67016 .21623 Mtetra
.7 .739 .882 r
.67016 .21623 .6766 .22561 .68991 .21935 .68352 .21003 Mtetra
.696 .741 .886 r
.68352 .21003 .68991 .21935 .70329 .21324 .69694 .20397 Mtetra
.693 .742 .889 r
.69694 .20397 .70329 .21324 .71672 .20728 .71043 .19805 Mtetra
.689 .743 .892 r
.71043 .19805 .71672 .20728 .73022 .20146 .72397 .19225 Mtetra
.686 .743 .895 r
.72397 .19225 .73022 .20146 .74378 .19576 .73759 .18656 Mtetra
.683 .743 .897 r
.73759 .18656 .74378 .19576 .75741 .19017 .75127 .18098 Mtetra
.68 .743 .899 r
.75127 .18098 .75741 .19017 .77111 .18467 .76502 .17547 Mtetra
.677 .743 .9 r
.76502 .17547 .77111 .18467 .78488 .17925 .77884 .17004 Mtetra
.675 .743 .902 r
.77884 .17004 .78488 .17925 .79872 .17389 .79272 .16466 Mtetra
.639 .732 .916 r
.16119 .38898 .16908 .39643 .18017 .39315 .17231 .38565 Mtetra
.639 .732 .915 r
.17231 .38565 .18017 .39315 .19132 .38985 .18348 .3823 Mtetra
.64 .731 .915 r
.18348 .3823 .19132 .38985 .20251 .38654 .19471 .37894 Mtetra
.19471 .37894 .20251 .38654 .21376 .38321 .20599 .37556 Mtetra
.639 .73 .914 r
.20599 .37556 .21376 .38321 .22507 .37988 .21732 .37217 Mtetra
.21732 .37217 .22507 .37988 .23643 .37654 .22871 .36878 Mtetra
.638 .729 .914 r
.22871 .36878 .23643 .37654 .24784 .37321 .24015 .36539 Mtetra
.637 .727 .913 r
.24015 .36539 .24784 .37321 .2593 .3699 .25164 .36202 Mtetra
.636 .726 .913 r
.25164 .36202 .2593 .3699 .27082 .36663 .26319 .35866 Mtetra
.634 .724 .913 r
.26319 .35866 .27082 .36663 .28239 .36339 .27478 .35535 Mtetra
.632 .722 .913 r
.27478 .35535 .28239 .36339 .29401 .36021 .28644 .35207 Mtetra
.63 .72 .912 r
.28644 .35207 .29401 .36021 .30568 .35709 .29814 .34884 Mtetra
.627 .717 .911 r
.29814 .34884 .30568 .35709 .31741 .35403 .30991 .34566 Mtetra
.625 .714 .91 r
.30991 .34566 .31741 .35403 .3292 .35103 .32172 .34253 Mtetra
.623 .711 .909 r
.32172 .34253 .3292 .35103 .34104 .34808 .3336 .33944 Mtetra
.622 .707 .907 r
.3336 .33944 .34104 .34808 .35294 .34517 .34554 .33637 Mtetra
.621 .704 .904 r
.34554 .33637 .35294 .34517 .36491 .34227 .35754 .33331 Mtetra
.622 .701 .901 r
.35754 .33331 .36491 .34227 .37693 .33936 .3696 .33021 Mtetra
.624 .698 .898 r
.3696 .33021 .37693 .33936 .38903 .33639 .38173 .32706 Mtetra
.626 .695 .894 r
.38173 .32706 .38903 .33639 .40119 .33332 .39392 .32381 Mtetra
.63 .693 .89 r
.39392 .32381 .40119 .33332 .41343 .3301 .40619 .32041 Mtetra
.636 .692 .885 r
.40619 .32041 .41343 .3301 .42573 .32669 .41852 .31683 Mtetra
.642 .691 .881 r
.41852 .31683 .42573 .32669 .43811 .32303 .43093 .31301 Mtetra
.648 .691 .876 r
.43093 .31301 .43811 .32303 .45055 .3191 .4434 .30894 Mtetra
.656 .691 .871 r
.4434 .30894 .45055 .3191 .46306 .31485 .45594 .30457 Mtetra
.663 .692 .867 r
.45594 .30457 .46306 .31485 .47563 .31026 .46854 .29989 Mtetra
.671 .694 .863 r
.46854 .29989 .47563 .31026 .48826 .30533 .48121 .29488 Mtetra
.678 .696 .86 r
.48121 .29488 .48826 .30533 .50095 .30004 .49393 .28956 Mtetra
.684 .699 .857 r
.49393 .28956 .50095 .30004 .5137 .29443 .5067 .28394 Mtetra
.69 .702 .856 r
.5067 .28394 .5137 .29443 .52649 .2885 .51953 .27804 Mtetra
.696 .705 .855 r
.51953 .27804 .52649 .2885 .53933 .28231 .5324 .27189 Mtetra
.7 .708 .854 r
.5324 .27189 .53933 .28231 .55221 .2759 .54532 .26555 Mtetra
.704 .712 .855 r
.54532 .26555 .55221 .2759 .56514 .26931 .55829 .25905 Mtetra
.706 .716 .856 r
.55829 .25905 .56514 .26931 .57811 .26261 .5713 .25245 Mtetra
.708 .719 .858 r
.5713 .25245 .57811 .26261 .59112 .25584 .58435 .24579 Mtetra
.708 .723 .861 r
.58435 .24579 .59112 .25584 .60417 .24906 .59745 .23912 Mtetra
.708 .726 .864 r
.59745 .23912 .60417 .24906 .61727 .24231 .61059 .23248 Mtetra
.707 .729 .868 r
.61059 .23248 .61727 .24231 .63042 .23562 .62378 .2259 Mtetra
.705 .732 .872 r
.62378 .2259 .63042 .23562 .64361 .22903 .63702 .21942 Mtetra
.703 .735 .876 r
.63702 .21942 .64361 .22903 .65686 .22256 .65032 .21304 Mtetra
.7 .737 .879 r
.65032 .21304 .65686 .22256 .67016 .21623 .66367 .20678 Mtetra
.697 .739 .883 r
.66367 .20678 .67016 .21623 .68352 .21003 .67708 .20064 Mtetra
.694 .74 .887 r
.67708 .20064 .68352 .21003 .69694 .20397 .69055 .19464 Mtetra
.691 .741 .89 r
.69055 .19464 .69694 .20397 .71043 .19805 .70408 .18875 Mtetra
.687 .742 .893 r
.70408 .18875 .71043 .19805 .72397 .19225 .71768 .18298 Mtetra
.684 .743 .895 r
.71768 .18298 .72397 .19225 .73759 .18656 .73134 .1773 Mtetra
.682 .743 .897 r
.73134 .1773 .73759 .18656 .75127 .18098 .74507 .17171 Mtetra
.679 .743 .899 r
.74507 .17171 .75127 .18098 .76502 .17547 .75887 .1662 Mtetra
.677 .743 .901 r
.75887 .1662 .76502 .17547 .77884 .17004 .77274 .16075 Mtetra
.675 .743 .902 r
.77274 .16075 .77884 .17004 .79272 .16466 .78667 .15534 Mtetra
.64 .733 .916 r
.15324 .38147 .16119 .38898 .17231 .38565 .16438 .3781 Mtetra
.64 .732 .915 r
.16438 .3781 .17231 .38565 .18348 .3823 .17558 .37471 Mtetra
.17558 .37471 .18348 .3823 .19471 .37894 .18684 .37129 Mtetra
.64 .731 .915 r
.18684 .37129 .19471 .37894 .20599 .37556 .19814 .36787 Mtetra
.64 .731 .914 r
.19814 .36787 .20599 .37556 .21732 .37217 .20951 .36442 Mtetra
.64 .73 .914 r
.20951 .36442 .21732 .37217 .22871 .36878 .22092 .36097 Mtetra
.639 .729 .914 r
.22092 .36097 .22871 .36878 .24015 .36539 .23239 .35752 Mtetra
.638 .728 .913 r
.23239 .35752 .24015 .36539 .25164 .36202 .24391 .35407 Mtetra
.637 .727 .913 r
.24391 .35407 .25164 .36202 .26319 .35866 .25549 .35065 Mtetra
.636 .725 .912 r
.25549 .35065 .26319 .35866 .27478 .35535 .26712 .34724 Mtetra
.634 .723 .912 r
.26712 .34724 .27478 .35535 .28644 .35207 .27881 .34386 Mtetra
.632 .721 .911 r
.27881 .34386 .28644 .35207 .29814 .34884 .29055 .34053 Mtetra
.63 .718 .91 r
.29055 .34053 .29814 .34884 .30991 .34566 .30234 .33722 Mtetra
.629 .715 .909 r
.30234 .33722 .30991 .34566 .32172 .34253 .3142 .33396 Mtetra
.627 .712 .907 r
.3142 .33396 .32172 .34253 .3336 .33944 .32611 .33071 Mtetra
.626 .709 .905 r
.32611 .33071 .3336 .33944 .34554 .33637 .33808 .32748 Mtetra
.626 .705 .902 r
.33808 .32748 .34554 .33637 .35754 .33331 .35011 .32425 Mtetra
.627 .702 .899 r
.35011 .32425 .35754 .33331 .3696 .33021 .36221 .32098 Mtetra
.628 .699 .896 r
.36221 .32098 .3696 .33021 .38173 .32706 .37437 .31764 Mtetra
.631 .696 .892 r
.37437 .31764 .38173 .32706 .39392 .32381 .3866 .3142 Mtetra
.635 .694 .888 r
.3866 .3142 .39392 .32381 .40619 .32041 .3989 .31062 Mtetra
.64 .693 .883 r
.3989 .31062 .40619 .32041 .41852 .31683 .41126 .30687 Mtetra
.645 .692 .879 r
.41126 .30687 .41852 .31683 .43093 .31301 .4237 .3029 Mtetra
.651 .691 .875 r
.4237 .3029 .43093 .31301 .4434 .30894 .4362 .29868 Mtetra
.658 .692 .87 r
.4362 .29868 .4434 .30894 .45594 .30457 .44877 .2942 Mtetra
.664 .693 .866 r
.44877 .2942 .45594 .30457 .46854 .29989 .46141 .28943 Mtetra
.671 .694 .863 r
.46141 .28943 .46854 .29989 .48121 .29488 .4741 .28436 Mtetra
.677 .696 .86 r
.4741 .28436 .48121 .29488 .49393 .28956 .48685 .27901 Mtetra
.683 .698 .858 r
.48685 .27901 .49393 .28956 .5067 .28394 .49966 .27339 Mtetra
.689 .701 .856 r
.49966 .27339 .5067 .28394 .51953 .27804 .51252 .26751 Mtetra
.694 .705 .856 r
.51252 .26751 .51953 .27804 .5324 .27189 .52543 .26142 Mtetra
.698 .708 .856 r
.52543 .26142 .5324 .27189 .54532 .26555 .53838 .25515 Mtetra
.701 .712 .857 r
.53838 .25515 .54532 .26555 .55829 .25905 .55138 .24874 Mtetra
.703 .715 .858 r
.55138 .24874 .55829 .25905 .5713 .25245 .56443 .24224 Mtetra
.705 .719 .86 r
.56443 .24224 .5713 .25245 .58435 .24579 .57752 .23569 Mtetra
.705 .722 .863 r
.57752 .23569 .58435 .24579 .59745 .23912 .59066 .22914 Mtetra
.705 .726 .866 r
.59066 .22914 .59745 .23912 .61059 .23248 .60385 .22261 Mtetra
.704 .729 .87 r
.60385 .22261 .61059 .23248 .62378 .2259 .61709 .21614 Mtetra
.702 .732 .874 r
.61709 .21614 .62378 .2259 .63702 .21942 .63038 .20975 Mtetra
.7 .734 .877 r
.63038 .20975 .63702 .21942 .65032 .21304 .64372 .20345 Mtetra
.698 .737 .881 r
.64372 .20345 .65032 .21304 .66367 .20678 .65712 .19727 Mtetra
.695 .738 .885 r
.65712 .19727 .66367 .20678 .67708 .20064 .67058 .1912 Mtetra
.692 .74 .888 r
.67058 .1912 .67708 .20064 .69055 .19464 .6841 .18524 Mtetra
.689 .741 .891 r
.6841 .18524 .69055 .19464 .70408 .18875 .69768 .17938 Mtetra
.686 .742 .894 r
.69768 .17938 .70408 .18875 .71768 .18298 .71133 .17363 Mtetra
.683 .742 .896 r
.71133 .17363 .71768 .18298 .73134 .1773 .72504 .16796 Mtetra
.68 .743 .898 r
.72504 .16796 .73134 .1773 .74507 .17171 .73882 .16237 Mtetra
.678 .743 .9 r
.73882 .16237 .74507 .17171 .75887 .1662 .75267 .15685 Mtetra
.676 .743 .901 r
.75267 .15685 .75887 .1662 .77274 .16075 .76659 .15138 Mtetra
.674 .743 .902 r
.76659 .15138 .77274 .16075 .78667 .15534 .78057 .14595 Mtetra
.64 .733 .916 r
.14522 .37391 .15324 .38147 .16438 .3781 .15639 .37049 Mtetra
.641 .733 .915 r
.15639 .37049 .16438 .3781 .17558 .37471 .16762 .36706 Mtetra
.641 .732 .915 r
.16762 .36706 .17558 .37471 .18684 .37129 .1789 .3636 Mtetra
.1789 .3636 .18684 .37129 .19814 .36787 .19024 .36012 Mtetra
.641 .731 .914 r
.19024 .36012 .19814 .36787 .20951 .36442 .20163 .35662 Mtetra
.20163 .35662 .20951 .36442 .22092 .36097 .21307 .35311 Mtetra
.64 .73 .913 r
.21307 .35311 .22092 .36097 .23239 .35752 .22457 .3496 Mtetra
.64 .729 .913 r
.22457 .3496 .23239 .35752 .24391 .35407 .23613 .34608 Mtetra
.639 .728 .912 r
.23613 .34608 .24391 .35407 .25549 .35065 .24774 .34257 Mtetra
.638 .726 .912 r
.24774 .34257 .25549 .35065 .26712 .34724 .2594 .33908 Mtetra
.637 .724 .911 r
.2594 .33908 .26712 .34724 .27881 .34386 .27112 .3356 Mtetra
.635 .722 .91 r
.27112 .3356 .27881 .34386 .29055 .34053 .28289 .33215 Mtetra
.634 .719 .909 r
.28289 .33215 .29055 .34053 .30234 .33722 .29472 .32872 Mtetra
.632 .717 .908 r
.29472 .32872 .30234 .33722 .3142 .33396 .30661 .32531 Mtetra
.631 .713 .906 r
.30661 .32531 .3142 .33396 .32611 .33071 .31855 .32192 Mtetra
.631 .71 .904 r
.31855 .32192 .32611 .33071 .33808 .32748 .33056 .31853 Mtetra
.631 .707 .901 r
.33056 .31853 .33808 .32748 .35011 .32425 .34263 .31512 Mtetra
.632 .704 .898 r
.34263 .31512 .35011 .32425 .36221 .32098 .35476 .31167 Mtetra
.633 .701 .894 r
.35476 .31167 .36221 .32098 .37437 .31764 .36696 .30815 Mtetra
.636 .698 .891 r
.36696 .30815 .37437 .31764 .3866 .3142 .37922 .30452 Mtetra
.639 .696 .887 r
.37922 .30452 .3866 .3142 .3989 .31062 .39155 .30077 Mtetra
.643 .694 .882 r
.39155 .30077 .3989 .31062 .41126 .30687 .40395 .29685 Mtetra
.648 .693 .878 r
.40395 .29685 .41126 .30687 .4237 .3029 .41642 .29272 Mtetra
.654 .693 .874 r
.41642 .29272 .4237 .3029 .4362 .29868 .42895 .28838 Mtetra
.66 .693 .87 r
.42895 .28838 .4362 .29868 .44877 .2942 .44155 .28378 Mtetra
.666 .694 .867 r
.44155 .28378 .44877 .2942 .46141 .28943 .45422 .27893 Mtetra
.671 .695 .863 r
.45422 .27893 .46141 .28943 .4741 .28436 .46694 .27381 Mtetra
.677 .697 .861 r
.46694 .27381 .4741 .28436 .48685 .27901 .47972 .26843 Mtetra
.683 .699 .859 r
.47972 .26843 .48685 .27901 .49966 .27339 .49256 .26281 Mtetra
.688 .702 .858 r
.49256 .26281 .49966 .27339 .51252 .26751 .50545 .25696 Mtetra
.692 .705 .858 r
.50545 .25696 .51252 .26751 .52543 .26142 .5184 .25092 Mtetra
.695 .708 .858 r
.5184 .25092 .52543 .26142 .53838 .25515 .53139 .24472 Mtetra
.698 .712 .859 r
.53139 .24472 .53838 .25515 .55138 .24874 .54443 .23841 Mtetra
.7 .715 .861 r
.54443 .23841 .55138 .24874 .56443 .24224 .55751 .23201 Mtetra
.702 .719 .863 r
.55751 .23201 .56443 .24224 .57752 .23569 .57065 .22557 Mtetra
.702 .723 .866 r
.57065 .22557 .57752 .23569 .59066 .22914 .58383 .21912 Mtetra
.702 .726 .869 r
.58383 .21912 .59066 .22914 .60385 .22261 .59706 .2127 Mtetra
.701 .729 .872 r
.59706 .2127 .60385 .22261 .61709 .21614 .61035 .20633 Mtetra
.699 .732 .876 r
.61035 .20633 .61709 .21614 .63038 .20975 .62368 .20004 Mtetra
.697 .734 .879 r
.62368 .20004 .63038 .20975 .64372 .20345 .63707 .19383 Mtetra
.695 .736 .883 r
.63707 .19383 .64372 .20345 .65712 .19727 .65052 .18771 Mtetra
.692 .738 .886 r
.65052 .18771 .65712 .19727 .67058 .1912 .66403 .1817 Mtetra
.69 .74 .889 r
.66403 .1817 .67058 .1912 .6841 .18524 .67759 .17578 Mtetra
.687 .741 .892 r
.67759 .17578 .6841 .18524 .69768 .17938 .69123 .16996 Mtetra
.684 .742 .895 r
.69123 .16996 .69768 .17938 .71133 .17363 .70492 .16422 Mtetra
.682 .742 .897 r
.70492 .16422 .71133 .17363 .72504 .16796 .71869 .15856 Mtetra
.679 .743 .899 r
.71869 .15856 .72504 .16796 .73882 .16237 .73251 .15296 Mtetra
.677 .743 .9 r
.73251 .15296 .73882 .16237 .75267 .15685 .74641 .14743 Mtetra
.675 .743 .902 r
.74641 .14743 .75267 .15685 .76659 .15138 .76038 .14194 Mtetra
.674 .743 .903 r
.76038 .14194 .76659 .15138 .78057 .14595 .77442 .13648 Mtetra
.641 .733 .915 r
.13714 .36629 .14522 .37391 .15639 .37049 .14834 .36283 Mtetra
.14834 .36283 .15639 .37049 .16762 .36706 .15959 .35935 Mtetra
.641 .732 .915 r
.15959 .35935 .16762 .36706 .1789 .3636 .1709 .35584 Mtetra
.641 .732 .914 r
.1709 .35584 .1789 .3636 .19024 .36012 .18227 .35231 Mtetra
.642 .732 .914 r
.18227 .35231 .19024 .36012 .20163 .35662 .19369 .34876 Mtetra
.642 .731 .914 r
.19369 .34876 .20163 .35662 .21307 .35311 .20516 .34519 Mtetra
.641 .73 .913 r
.20516 .34519 .21307 .35311 .22457 .3496 .21669 .34161 Mtetra
.641 .729 .913 r
.21669 .34161 .22457 .3496 .23613 .34608 .22828 .33803 Mtetra
.641 .728 .912 r
.22828 .33803 .23613 .34608 .24774 .34257 .23992 .33444 Mtetra
.64 .727 .911 r
.23992 .33444 .24774 .34257 .2594 .33908 .25161 .33085 Mtetra
.639 .725 .911 r
.25161 .33085 .2594 .33908 .27112 .3356 .26336 .32728 Mtetra
.638 .723 .91 r
.26336 .32728 .27112 .3356 .28289 .33215 .27517 .32371 Mtetra
.637 .721 .908 r
.27517 .32371 .28289 .33215 .29472 .32872 .28704 .32016 Mtetra
.636 .718 .907 r
.28704 .32016 .29472 .32872 .30661 .32531 .29896 .31662 Mtetra
.635 .715 .905 r
.29896 .31662 .30661 .32531 .31855 .32192 .31094 .31307 Mtetra
.635 .712 .903 r
.31094 .31307 .31855 .32192 .33056 .31853 .32298 .30952 Mtetra
.635 .709 .9 r
.32298 .30952 .33056 .31853 .34263 .31512 .33509 .30594 Mtetra
.636 .706 .897 r
.33509 .30594 .34263 .31512 .35476 .31167 .34725 .30231 Mtetra
.638 .703 .893 r
.34725 .30231 .35476 .31167 .36696 .30815 .35949 .29861 Mtetra
.64 .7 .89 r
.35949 .29861 .36696 .30815 .37922 .30452 .37178 .29481 Mtetra
.643 .698 .886 r
.37178 .29481 .37922 .30452 .39155 .30077 .38415 .29089 Mtetra
.647 .697 .882 r
.38415 .29089 .39155 .30077 .40395 .29685 .39658 .2868 Mtetra
.651 .695 .878 r
.39658 .2868 .40395 .29685 .41642 .29272 .40908 .28253 Mtetra
.656 .695 .874 r
.40908 .28253 .41642 .29272 .42895 .28838 .42165 .27806 Mtetra
.661 .695 .871 r
.42165 .27806 .42895 .28838 .44155 .28378 .43428 .27336 Mtetra
.667 .696 .867 r
.43428 .27336 .44155 .28378 .45422 .27893 .44697 .26843 Mtetra
.672 .697 .865 r
.44697 .26843 .45422 .27893 .46694 .27381 .45973 .26326 Mtetra
.677 .699 .863 r
.45973 .26326 .46694 .27381 .47972 .26843 .47254 .25786 Mtetra
.682 .701 .861 r
.47254 .25786 .47972 .26843 .49256 .26281 .48541 .25224 Mtetra
.686 .703 .86 r
.48541 .25224 .49256 .26281 .50545 .25696 .49834 .24642 Mtetra
.69 .706 .86 r
.49834 .24642 .50545 .25696 .5184 .25092 .51132 .24044 Mtetra
.693 .709 .861 r
.51132 .24044 .5184 .25092 .53139 .24472 .52434 .23431 Mtetra
.696 .713 .862 r
.52434 .23431 .53139 .24472 .54443 .23841 .53742 .22808 Mtetra
.698 .716 .864 r
.53742 .22808 .54443 .23841 .55751 .23201 .55055 .22178 Mtetra
.699 .72 .866 r
.55055 .22178 .55751 .23201 .57065 .22557 .56372 .21544 Mtetra
.699 .723 .869 r
.56372 .21544 .57065 .22557 .58383 .21912 .57694 .2091 Mtetra
.699 .726 .872 r
.57694 .2091 .58383 .21912 .59706 .2127 .59022 .20278 Mtetra
.698 .729 .875 r
.59022 .20278 .59706 .2127 .61035 .20633 .60355 .19651 Mtetra
.696 .732 .878 r
.60355 .19651 .61035 .20633 .62368 .20004 .61693 .1903 Mtetra
.695 .735 .882 r
.61693 .1903 .62368 .20004 .63707 .19383 .63037 .18416 Mtetra
.692 .737 .885 r
.63037 .18416 .63707 .19383 .65052 .18771 .64386 .17811 Mtetra
.69 .738 .888 r
.64386 .17811 .65052 .18771 .66403 .1817 .65742 .17214 Mtetra
.688 .74 .891 r
.65742 .17214 .66403 .1817 .67759 .17578 .67104 .16626 Mtetra
.685 .741 .893 r
.67104 .16626 .67759 .17578 .69123 .16996 .68472 .16046 Mtetra
.683 .742 .896 r
.68472 .16046 .69123 .16996 .70492 .16422 .69846 .15474 Mtetra
.68 .742 .898 r
.69846 .15474 .70492 .16422 .71869 .15856 .71227 .14908 Mtetra
.678 .743 .899 r
.71227 .14908 .71869 .15856 .73251 .15296 .72615 .14348 Mtetra
.676 .743 .901 r
.72615 .14348 .73251 .15296 .74641 .14743 .7401 .13793 Mtetra
.675 .743 .902 r
.7401 .13793 .74641 .14743 .76038 .14194 .75412 .13241 Mtetra
.673 .743 .903 r
.75412 .13241 .76038 .14194 .77442 .13648 .76821 .12693 Mtetra
.641 .733 .915 r
.12899 .3586 .13714 .36629 .14834 .36283 .14022 .3551 Mtetra
.14022 .3551 .14834 .36283 .15959 .35935 .1515 .35157 Mtetra
.642 .733 .915 r
.1515 .35157 .15959 .35935 .1709 .35584 .16284 .34802 Mtetra
.642 .732 .914 r
.16284 .34802 .1709 .35584 .18227 .35231 .17423 .34444 Mtetra
.17423 .34444 .18227 .35231 .19369 .34876 .18568 .34084 Mtetra
.642 .731 .913 r
.18568 .34084 .19369 .34876 .20516 .34519 .19718 .33721 Mtetra
.19718 .33721 .20516 .34519 .21669 .34161 .20874 .33357 Mtetra
.642 .73 .912 r
.20874 .33357 .21669 .34161 .22828 .33803 .22036 .32991 Mtetra
.642 .729 .912 r
.22036 .32991 .22828 .33803 .23992 .33444 .23203 .32625 Mtetra
.642 .728 .911 r
.23203 .32625 .23992 .33444 .25161 .33085 .24376 .32257 Mtetra
.641 .726 .91 r
.24376 .32257 .25161 .33085 .26336 .32728 .25555 .3189 Mtetra
.64 .724 .909 r
.25555 .3189 .26336 .32728 .27517 .32371 .26739 .31522 Mtetra
.64 .722 .907 r
.26739 .31522 .27517 .32371 .28704 .32016 .27929 .31155 Mtetra
.639 .719 .906 r
.27929 .31155 .28704 .32016 .29896 .31662 .29125 .30787 Mtetra
.639 .717 .904 r
.29125 .30787 .29896 .31662 .31094 .31307 .30326 .30418 Mtetra
.639 .714 .902 r
.30326 .30418 .31094 .31307 .32298 .30952 .31534 .30047 Mtetra
.639 .711 .899 r
.31534 .30047 .32298 .30952 .33509 .30594 .32748 .29673 Mtetra
.64 .708 .896 r
.32748 .29673 .33509 .30594 .34725 .30231 .33969 .29293 Mtetra
.642 .706 .893 r
.33969 .29293 .34725 .30231 .35949 .29861 .35195 .28906 Mtetra
.644 .703 .889 r
.35195 .28906 .35949 .29861 .37178 .29481 .36429 .28509 Mtetra
.647 .701 .886 r
.36429 .28509 .37178 .29481 .38415 .29089 .37669 .281 Mtetra
.65 .699 .882 r
.37669 .281 .38415 .29089 .39658 .2868 .38915 .27676 Mtetra
.654 .698 .879 r
.38915 .27676 .39658 .2868 .40908 .28253 .40169 .27235 Mtetra
.659 .698 .875 r
.40169 .27235 .40908 .28253 .42165 .27806 .41428 .26776 Mtetra
.663 .698 .872 r
.41428 .26776 .42165 .27806 .43428 .27336 .42695 .26297 Mtetra
.668 .698 .869 r
.42695 .26297 .43428 .27336 .44697 .26843 .43967 .25796 Mtetra
.673 .699 .867 r
.43967 .25796 .44697 .26843 .45973 .26326 .45246 .25275 Mtetra
.677 .701 .865 r
.45246 .25275 .45973 .26326 .47254 .25786 .46531 .24733 Mtetra
.681 .703 .864 r
.46531 .24733 .47254 .25786 .48541 .25224 .47821 .24171 Mtetra
.685 .705 .863 r
.47821 .24171 .48541 .25224 .49834 .24642 .49117 .23593 Mtetra
.689 .708 .863 r
.49117 .23593 .49834 .24642 .51132 .24044 .50418 .22999 Mtetra
.691 .711 .864 r
.50418 .22999 .51132 .24044 .52434 .23431 .51724 .22393 Mtetra
.693 .714 .865 r
.51724 .22393 .52434 .23431 .53742 .22808 .53036 .21778 Mtetra
.695 .718 .867 r
.53036 .21778 .53742 .22808 .55055 .22178 .54352 .21157 Mtetra
.696 .721 .869 r
.54352 .21157 .55055 .22178 .56372 .21544 .55674 .20533 Mtetra
.696 .724 .871 r
.55674 .20533 .56372 .21544 .57694 .2091 .57 .19908 Mtetra
.696 .727 .874 r
.57 .19908 .57694 .2091 .59022 .20278 .58332 .19286 Mtetra
.695 .73 .877 r
.58332 .19286 .59022 .20278 .60355 .19651 .59669 .18667 Mtetra
.694 .733 .881 r
.59669 .18667 .60355 .19651 .61693 .1903 .61012 .18053 Mtetra
.692 .735 .884 r
.61012 .18053 .61693 .1903 .63037 .18416 .62361 .17447 Mtetra
.69 .737 .887 r
.62361 .17447 .63037 .18416 .64386 .17811 .63715 .16847 Mtetra
.688 .739 .89 r
.63715 .16847 .64386 .17811 .65742 .17214 .65075 .16254 Mtetra
.686 .74 .892 r
.65075 .16254 .65742 .17214 .67104 .16626 .66442 .15669 Mtetra
.683 .741 .895 r
.66442 .15669 .67104 .16626 .68472 .16046 .67815 .15091 Mtetra
.681 .742 .897 r
.67815 .15091 .68472 .16046 .69846 .15474 .69194 .1452 Mtetra
.679 .742 .898 r
.69194 .1452 .69846 .15474 .71227 .14908 .70581 .13953 Mtetra
.677 .742 .9 r
.70581 .13953 .71227 .14908 .72615 .14348 .71974 .13392 Mtetra
.676 .743 .901 r
.71974 .13392 .72615 .14348 .7401 .13793 .73373 .12835 Mtetra
.674 .743 .902 r
.73373 .12835 .7401 .13793 .75412 .13241 .7478 .12281 Mtetra
.673 .743 .903 r
.7478 .12281 .75412 .13241 .76821 .12693 .76194 .1173 Mtetra
.642 .733 .915 r
.12078 .35084 .12899 .3586 .14022 .3551 .13204 .3473 Mtetra
.13204 .3473 .14022 .3551 .1515 .35157 .14334 .34373 Mtetra
.642 .732 .914 r
.14334 .34373 .1515 .35157 .16284 .34802 .15471 .34013 Mtetra
.643 .732 .914 r
.15471 .34013 .16284 .34802 .17423 .34444 .16613 .3365 Mtetra
.643 .732 .913 r
.16613 .3365 .17423 .34444 .18568 .34084 .17761 .33284 Mtetra
.17761 .33284 .18568 .34084 .19718 .33721 .18914 .32916 Mtetra
.643 .731 .912 r
.18914 .32916 .19718 .33721 .20874 .33357 .20073 .32546 Mtetra
.644 .73 .912 r
.20073 .32546 .20874 .33357 .22036 .32991 .21238 .32173 Mtetra
.644 .729 .911 r
.21238 .32173 .22036 .32991 .23203 .32625 .22409 .31799 Mtetra
.643 .728 .91 r
.22409 .31799 .23203 .32625 .24376 .32257 .23585 .31423 Mtetra
.643 .727 .909 r
.23585 .31423 .24376 .32257 .25555 .3189 .24767 .31046 Mtetra
.643 .725 .908 r
.24767 .31046 .25555 .3189 .26739 .31522 .25954 .30668 Mtetra
.643 .723 .907 r
.25954 .30668 .26739 .31522 .27929 .31155 .27148 .30288 Mtetra
.642 .721 .905 r
.27148 .30288 .27929 .31155 .29125 .30787 .28347 .29907 Mtetra
.642 .719 .903 r
.28347 .29907 .29125 .30787 .30326 .30418 .29553 .29525 Mtetra
.643 .716 .901 r
.29553 .29525 .30326 .30418 .31534 .30047 .30764 .29139 Mtetra
.643 .713 .898 r
.30764 .29139 .31534 .30047 .32748 .29673 .31982 .28749 Mtetra
.644 .711 .896 r
.31982 .28749 .32748 .29673 .33969 .29293 .33206 .28353 Mtetra
.646 .708 .893 r
.33206 .28353 .33969 .29293 .35195 .28906 .34436 .27949 Mtetra
.648 .706 .889 r
.34436 .27949 .35195 .28906 .36429 .28509 .35673 .27537 Mtetra
.651 .704 .886 r
.35673 .27537 .36429 .28509 .37669 .281 .36916 .27112 Mtetra
.654 .703 .883 r
.36916 .27112 .37669 .281 .38915 .27676 .38166 .26674 Mtetra
.657 .702 .879 r
.38166 .26674 .38915 .27676 .40169 .27235 .39423 .26221 Mtetra
.661 .701 .876 r
.39423 .26221 .40169 .27235 .41428 .26776 .40686 .2575 Mtetra
.665 .701 .873 r
.40686 .2575 .41428 .26776 .42695 .26297 .41956 .25262 Mtetra
.669 .701 .871 r
.41956 .25262 .42695 .26297 .43967 .25796 .43232 .24755 Mtetra
.673 .702 .869 r
.43232 .24755 .43967 .25796 .45246 .25275 .44514 .24229 Mtetra
.677 .704 .867 r
.44514 .24229 .45246 .25275 .46531 .24733 .45801 .23685 Mtetra
.681 .706 .866 r
.45801 .23685 .46531 .24733 .47821 .24171 .47095 .23124 Mtetra
.684 .708 .866 r
.47095 .23124 .47821 .24171 .49117 .23593 .48394 .22549 Mtetra
.687 .711 .866 r
.48394 .22549 .49117 .23593 .50418 .22999 .49699 .2196 Mtetra
.689 .713 .867 r
.49699 .2196 .50418 .22999 .51724 .22393 .51009 .2136 Mtetra
.691 .716 .868 r
.51009 .2136 .51724 .22393 .53036 .21778 .52324 .20752 Mtetra
.693 .72 .87 r
.52324 .20752 .53036 .21778 .54352 .21157 .53644 .20139 Mtetra
.693 .723 .872 r
.53644 .20139 .54352 .21157 .55674 .20533 .5497 .19524 Mtetra
.694 .726 .875 r
.5497 .19524 .55674 .20533 .57 .19908 .56301 .18907 Mtetra
.693 .728 .877 r
.56301 .18907 .57 .19908 .58332 .19286 .57637 .18293 Mtetra
.692 .731 .88 r
.57637 .18293 .58332 .19286 .59669 .18667 .58979 .17681 Mtetra
.691 .733 .883 r
.58979 .17681 .59669 .18667 .61012 .18053 .60326 .17075 Mtetra
.69 .736 .886 r
.60326 .17075 .61012 .18053 .62361 .17447 .61679 .16474 Mtetra
.688 .737 .889 r
.61679 .16474 .62361 .17447 .63715 .16847 .63038 .15878 Mtetra
.686 .739 .891 r
.63038 .15878 .63715 .16847 .65075 .16254 .64403 .1529 Mtetra
.684 .74 .893 r
.64403 .1529 .65075 .16254 .66442 .15669 .65775 .14707 Mtetra
.682 .741 .896 r
.65775 .14707 .66442 .15669 .67815 .15091 .67153 .1413 Mtetra
.68 .742 .897 r
.67153 .1413 .67815 .15091 .69194 .1452 .68537 .13558 Mtetra
.678 .742 .899 r
.68537 .13558 .69194 .1452 .70581 .13953 .69928 .12992 Mtetra
.676 .742 .9 r
.69928 .12992 .70581 .13953 .71974 .13392 .71326 .12429 Mtetra
.675 .743 .902 r
.71326 .12429 .71974 .13392 .73373 .12835 .72731 .11869 Mtetra
.673 .743 .903 r
.72731 .11869 .73373 .12835 .7478 .12281 .74143 .11313 Mtetra
.672 .743 .903 r
.74143 .11313 .7478 .12281 .76194 .1173 .75561 .10758 Mtetra
.642 .733 .915 r
.11251 .34301 .12078 .35084 .13204 .3473 .12379 .33942 Mtetra
.642 .732 .914 r
.12379 .33942 .13204 .3473 .14334 .34373 .13512 .33581 Mtetra
.643 .732 .914 r
.13512 .33581 .14334 .34373 .15471 .34013 .14651 .33216 Mtetra
.643 .732 .913 r
.14651 .33216 .15471 .34013 .16613 .3365 .15796 .32849 Mtetra
.644 .732 .913 r
.15796 .32849 .16613 .3365 .17761 .33284 .16947 .32478 Mtetra
.644 .731 .912 r
.16947 .32478 .17761 .33284 .18914 .32916 .18104 .32104 Mtetra
.18104 .32104 .18914 .32916 .20073 .32546 .19266 .31727 Mtetra
.645 .73 .911 r
.19266 .31727 .20073 .32546 .21238 .32173 .20434 .31348 Mtetra
.645 .73 .91 r
.20434 .31348 .21238 .32173 .22409 .31799 .21607 .30966 Mtetra
.645 .729 .91 r
.21607 .30966 .22409 .31799 .23585 .31423 .22787 .30582 Mtetra
.645 .727 .909 r
.22787 .30582 .23585 .31423 .24767 .31046 .23972 .30196 Mtetra
.645 .726 .907 r
.23972 .30196 .24767 .31046 .25954 .30668 .25163 .29807 Mtetra
.645 .724 .906 r
.25163 .29807 .25954 .30668 .27148 .30288 .2636 .29417 Mtetra
.645 .722 .904 r
.2636 .29417 .27148 .30288 .28347 .29907 .27563 .29024 Mtetra
.646 .72 .903 r
.27563 .29024 .28347 .29907 .29553 .29525 .28772 .28627 Mtetra
.646 .718 .9 r
.28772 .28627 .29553 .29525 .30764 .29139 .29987 .28228 Mtetra
.647 .716 .898 r
.29987 .28228 .30764 .29139 .31982 .28749 .31209 .27823 Mtetra
.648 .713 .896 r
.31209 .27823 .31982 .28749 .33206 .28353 .32436 .27412 Mtetra
.649 .711 .893 r
.32436 .27412 .33206 .28353 .34436 .27949 .3367 .26993 Mtetra
.651 .709 .89 r
.3367 .26993 .34436 .27949 .35673 .27537 .34911 .26566 Mtetra
.654 .707 .887 r
.34911 .26566 .35673 .27537 .36916 .27112 .36158 .26127 Mtetra
.657 .706 .884 r
.36158 .26127 .36916 .27112 .38166 .26674 .37411 .25676 Mtetra
.66 .705 .881 r
.37411 .25676 .38166 .26674 .39423 .26221 .38671 .25211 Mtetra
.663 .705 .878 r
.38671 .25211 .39423 .26221 .40686 .2575 .39938 .2473 Mtetra
.666 .704 .876 r
.39938 .2473 .40686 .2575 .41956 .25262 .41211 .24233 Mtetra
.67 .705 .873 r
.41211 .24233 .41956 .25262 .43232 .24755 .4249 .2372 Mtetra
.674 .706 .872 r
.4249 .2372 .43232 .24755 .44514 .24229 .43775 .2319 Mtetra
.677 .707 .87 r
.43775 .2319 .44514 .24229 .45801 .23685 .45066 .22645 Mtetra
.68 .709 .87 r
.45066 .22645 .45801 .23685 .47095 .23124 .46363 .22085 Mtetra
.683 .711 .869 r
.46363 .22085 .47095 .23124 .48394 .22549 .47666 .21511 Mtetra
.686 .713 .87 r
.47666 .21511 .48394 .22549 .49699 .2196 .48974 .20926 Mtetra
.688 .716 .87 r
.48974 .20926 .49699 .2196 .51009 .2136 .50288 .20332 Mtetra
.689 .719 .872 r
.50288 .20332 .51009 .2136 .52324 .20752 .51606 .19731 Mtetra
.691 .722 .873 r
.51606 .19731 .52324 .20752 .53644 .20139 .52931 .19125 Mtetra
.691 .724 .875 r
.52931 .19125 .53644 .20139 .5497 .19524 .5426 .18516 Mtetra
.691 .727 .878 r
.5426 .18516 .5497 .19524 .56301 .18907 .55595 .17908 Mtetra
.691 .73 .88 r
.55595 .17908 .56301 .18907 .57637 .18293 .56936 .173 Mtetra
.69 .732 .883 r
.56936 .173 .57637 .18293 .58979 .17681 .58282 .16695 Mtetra
.689 .734 .885 r
.58282 .16695 .58979 .17681 .60326 .17075 .59634 .16094 Mtetra
.688 .736 .888 r
.59634 .16094 .60326 .17075 .61679 .16474 .60992 .15497 Mtetra
.686 .738 .89 r
.60992 .15497 .61679 .16474 .63038 .15878 .62355 .14906 Mtetra
.684 .739 .893 r
.62355 .14906 .63038 .15878 .64403 .1529 .63725 .1432 Mtetra
.682 .74 .895 r
.63725 .1432 .64403 .1529 .65775 .14707 .65102 .13738 Mtetra
.681 .741 .897 r
.65102 .13738 .65775 .14707 .67153 .1413 .66484 .13162 Mtetra
.679 .742 .898 r
.66484 .13162 .67153 .1413 .68537 .13558 .67874 .1259 Mtetra
.677 .742 .9 r
.67874 .1259 .68537 .13558 .69928 .12992 .6927 .12022 Mtetra
.676 .742 .901 r
.6927 .12022 .69928 .12992 .71326 .12429 .70673 .11458 Mtetra
.674 .743 .902 r
.70673 .11458 .71326 .12429 .72731 .11869 .72083 .10896 Mtetra
.673 .743 .903 r
.72083 .10896 .72731 .11869 .74143 .11313 .73499 .10336 Mtetra
.672 .743 .904 r
.73499 .10336 .74143 .11313 .75561 .10758 .74923 .09778 Mtetra
.642 .732 .914 r
.10416 .3351 .11251 .34301 .12379 .33942 .11547 .33147 Mtetra
.643 .732 .914 r
.11547 .33147 .12379 .33942 .13512 .33581 .12683 .32781 Mtetra
.643 .732 .913 r
.12683 .32781 .13512 .33581 .14651 .33216 .13826 .32411 Mtetra
.644 .732 .913 r
.13826 .32411 .14651 .33216 .15796 .32849 .14973 .32039 Mtetra
.644 .732 .912 r
.14973 .32039 .15796 .32849 .16947 .32478 .16127 .31663 Mtetra
.645 .731 .912 r
.16127 .31663 .16947 .32478 .18104 .32104 .17286 .31284 Mtetra
.645 .731 .911 r
.17286 .31284 .18104 .32104 .19266 .31727 .18452 .30901 Mtetra
.646 .73 .911 r
.18452 .30901 .19266 .31727 .20434 .31348 .19623 .30515 Mtetra
.646 .73 .91 r
.19623 .30515 .20434 .31348 .21607 .30966 .208 .30126 Mtetra
.647 .729 .909 r
.208 .30126 .21607 .30966 .22787 .30582 .21982 .29734 Mtetra
.647 .728 .908 r
.21982 .29734 .22787 .30582 .23972 .30196 .23171 .29339 Mtetra
.647 .727 .907 r
.23171 .29339 .23972 .30196 .25163 .29807 .24366 .28941 Mtetra
.647 .725 .905 r
.24366 .28941 .25163 .29807 .2636 .29417 .25566 .2854 Mtetra
.648 .724 .904 r
.25566 .2854 .2636 .29417 .27563 .29024 .26773 .28135 Mtetra
.648 .722 .902 r
.26773 .28135 .27563 .29024 .28772 .28627 .27985 .27727 Mtetra
.649 .72 .9 r
.27985 .27727 .28772 .28627 .29987 .28228 .29204 .27314 Mtetra
.65 .718 .898 r
.29204 .27314 .29987 .28228 .31209 .27823 .30429 .26895 Mtetra
.651 .716 .896 r
.30429 .26895 .31209 .27823 .32436 .27412 .3166 .26471 Mtetra
.653 .714 .893 r
.3166 .26471 .32436 .27412 .3367 .26993 .32898 .26038 Mtetra
.654 .712 .89 r
.32898 .26038 .3367 .26993 .34911 .26566 .34142 .25597 Mtetra
.657 .711 .888 r
.34142 .25597 .34911 .26566 .36158 .26127 .35393 .25145 Mtetra
.659 .71 .885 r
.35393 .25145 .36158 .26127 .37411 .25676 .3665 .24682 Mtetra
.662 .709 .882 r
.3665 .24682 .37411 .25676 .38671 .25211 .37913 .24206 Mtetra
.665 .708 .88 r
.37913 .24206 .38671 .25211 .39938 .2473 .39183 .23716 Mtetra
.668 .708 .878 r
.39183 .23716 .39938 .2473 .41211 .24233 .40459 .23212 Mtetra
.671 .709 .876 r
.40459 .23212 .41211 .24233 .4249 .2372 .41742 .22693 Mtetra
.674 .709 .874 r
.41742 .22693 .4249 .2372 .43775 .2319 .4303 .22159 Mtetra
.677 .711 .873 r
.4303 .22159 .43775 .2319 .45066 .22645 .44325 .21612 Mtetra
.68 .712 .873 r
.44325 .21612 .45066 .22645 .46363 .22085 .45625 .21052 Mtetra
.682 .714 .873 r
.45625 .21052 .46363 .22085 .47666 .21511 .46931 .2048 Mtetra
.685 .716 .873 r
.46931 .2048 .47666 .21511 .48974 .20926 .48243 .19899 Mtetra
.686 .719 .874 r
.48243 .19899 .48974 .20926 .50288 .20332 .4956 .19309 Mtetra
.688 .721 .875 r
.4956 .19309 .50288 .20332 .51606 .19731 .50883 .18713 Mtetra
.689 .724 .877 r
.50883 .18713 .51606 .19731 .52931 .19125 .52211 .18114 Mtetra
.689 .726 .878 r
.52211 .18114 .52931 .19125 .5426 .18516 .53545 .17511 Mtetra
.689 .729 .881 r
.53545 .17511 .5426 .18516 .55595 .17908 .54884 .16909 Mtetra
.689 .731 .883 r
.54884 .16909 .55595 .17908 .56936 .173 .56229 .16307 Mtetra
.688 .733 .885 r
.56229 .16307 .56936 .173 .58282 .16695 .5758 .15707 Mtetra
.687 .735 .887 r
.5758 .15707 .58282 .16695 .59634 .16094 .58936 .1511 Mtetra
.686 .737 .89 r
.58936 .1511 .59634 .16094 .60992 .15497 .60298 .14517 Mtetra
.684 .738 .892 r
.60298 .14517 .60992 .15497 .62355 .14906 .61667 .13929 Mtetra
.683 .74 .894 r
.61667 .13929 .62355 .14906 .63725 .1432 .63042 .13344 Mtetra
.681 .741 .896 r
.63042 .13344 .63725 .1432 .65102 .13738 .64423 .12764 Mtetra
.679 .741 .898 r
.64423 .12764 .65102 .13738 .66484 .13162 .6581 .12188 Mtetra
.678 .742 .899 r
.6581 .12188 .66484 .13162 .67874 .1259 .67205 .11615 Mtetra
.676 .742 .9 r
.67205 .11615 .67874 .1259 .6927 .12022 .68606 .11045 Mtetra
.675 .742 .901 r
.68606 .11045 .6927 .12022 .70673 .11458 .70014 .10478 Mtetra
.674 .743 .902 r
.70014 .10478 .70673 .11458 .72083 .10896 .71428 .09914 Mtetra
.673 .743 .903 r
.71428 .09914 .72083 .10896 .73499 .10336 .7285 .09351 Mtetra
.671 .743 .904 r
.7285 .09351 .73499 .10336 .74923 .09778 .74279 .08789 Mtetra
.643 .732 .914 r
.09576 .3271 .10416 .3351 .11547 .33147 .10709 .32342 Mtetra
.643 .732 .913 r
.10709 .32342 .11547 .33147 .12683 .32781 .11848 .31972 Mtetra
.11848 .31972 .12683 .32781 .13826 .32411 .12993 .31598 Mtetra
.644 .731 .912 r
.12993 .31598 .13826 .32411 .14973 .32039 .14144 .31221 Mtetra
.645 .731 .912 r
.14144 .31221 .14973 .32039 .16127 .31663 .153 .3084 Mtetra
.645 .731 .911 r
.153 .3084 .16127 .31663 .17286 .31284 .16463 .30455 Mtetra
.646 .731 .911 r
.16463 .30455 .17286 .31284 .18452 .30901 .17631 .30067 Mtetra
.647 .73 .91 r
.17631 .30067 .18452 .30901 .19623 .30515 .18805 .29675 Mtetra
.647 .73 .909 r
.18805 .29675 .19623 .30515 .208 .30126 .19985 .29278 Mtetra
.648 .729 .908 r
.19985 .29278 .208 .30126 .21982 .29734 .21171 .28879 Mtetra
.648 .728 .907 r
.21171 .28879 .21982 .29734 .23171 .29339 .22363 .28475 Mtetra
.649 .727 .906 r
.22363 .28475 .23171 .29339 .24366 .28941 .23561 .28068 Mtetra
.649 .726 .905 r
.23561 .28068 .24366 .28941 .25566 .2854 .24765 .27657 Mtetra
.65 .725 .903 r
.24765 .27657 .25566 .2854 .26773 .28135 .25976 .27242 Mtetra
.651 .723 .902 r
.25976 .27242 .26773 .28135 .27985 .27727 .27192 .26822 Mtetra
.652 .722 .9 r
.27192 .26822 .27985 .27727 .29204 .27314 .28414 .26397 Mtetra
.653 .72 .898 r
.28414 .26397 .29204 .27314 .30429 .26895 .29643 .25966 Mtetra
.654 .718 .896 r
.29643 .25966 .30429 .26895 .3166 .26471 .30878 .25529 Mtetra
.655 .717 .893 r
.30878 .25529 .3166 .26471 .32898 .26038 .32119 .25084 Mtetra
.657 .715 .891 r
.32119 .25084 .32898 .26038 .34142 .25597 .33367 .2463 Mtetra
.659 .714 .889 r
.33367 .2463 .34142 .25597 .35393 .25145 .34621 .24167 Mtetra
.661 .713 .886 r
.34621 .24167 .35393 .25145 .3665 .24682 .35882 .23692 Mtetra
.664 .712 .884 r
.35882 .23692 .3665 .24682 .37913 .24206 .37149 .23206 Mtetra
.666 .712 .882 r
.37149 .23206 .37913 .24206 .39183 .23716 .38422 .22708 Mtetra
.669 .712 .88 r
.38422 .22708 .39183 .23716 .40459 .23212 .39702 .22197 Mtetra
.672 .712 .878 r
.39702 .22197 .40459 .23212 .41742 .22693 .40987 .21672 Mtetra
.675 .713 .877 r
.40987 .21672 .41742 .22693 .4303 .22159 .42279 .21136 Mtetra
.677 .714 .876 r
.42279 .21136 .4303 .22159 .44325 .21612 .43577 .20587 Mtetra
.679 .715 .876 r
.43577 .20587 .44325 .21612 .45625 .21052 .44881 .20026 Mtetra
.682 .717 .876 r
.44881 .20026 .45625 .21052 .46931 .2048 .46191 .19456 Mtetra
.683 .719 .876 r
.46191 .19456 .46931 .2048 .48243 .19899 .47506 .18877 Mtetra
.685 .721 .877 r
.47506 .18877 .48243 .19899 .4956 .19309 .48827 .18291 Mtetra
.686 .723 .878 r
.48827 .18291 .4956 .19309 .50883 .18713 .50154 .177 Mtetra
.687 .726 .88 r
.50154 .177 .50883 .18713 .52211 .18114 .51486 .17105 Mtetra
.687 .728 .881 r
.51486 .17105 .52211 .18114 .53545 .17511 .52824 .16508 Mtetra
.687 .73 .883 r
.52824 .16508 .53545 .17511 .54884 .16909 .54167 .1591 Mtetra
.687 .732 .885 r
.54167 .1591 .54884 .16909 .56229 .16307 .55516 .15313 Mtetra
.686 .734 .887 r
.55516 .15313 .56229 .16307 .5758 .15707 .56871 .14717 Mtetra
.685 .736 .89 r
.56871 .14717 .5758 .15707 .58936 .1511 .58232 .14124 Mtetra
.684 .738 .892 r
.58232 .14124 .58936 .1511 .60298 .14517 .59599 .13534 Mtetra
.683 .739 .893 r
.59599 .13534 .60298 .14517 .61667 .13929 .60972 .12947 Mtetra
.681 .74 .895 r
.60972 .12947 .61667 .13929 .63042 .13344 .62352 .12363 Mtetra
.68 .741 .897 r
.62352 .12363 .63042 .13344 .64423 .12764 .63738 .11783 Mtetra
.678 .741 .898 r
.63738 .11783 .64423 .12764 .6581 .12188 .6513 .11206 Mtetra
.677 .742 .9 r
.6513 .11206 .6581 .12188 .67205 .11615 .66529 .10632 Mtetra
.676 .742 .901 r
.66529 .10632 .67205 .11615 .68606 .11045 .67935 .1006 Mtetra
.674 .742 .902 r
.67935 .1006 .68606 .11045 .70014 .10478 .69348 .09491 Mtetra
.673 .743 .903 r
.69348 .09491 .70014 .10478 .71428 .09914 .70768 .08923 Mtetra
.672 .743 .903 r
.70768 .08923 .71428 .09914 .7285 .09351 .72195 .08357 Mtetra
.671 .743 .904 r
.72195 .08357 .7285 .09351 .74279 .08789 .73629 .07791 Mtetra
.643 .731 .913 r
.08728 .31901 .09576 .3271 .10709 .32342 .09864 .31529 Mtetra
.09864 .31529 .10709 .32342 .11848 .31972 .11006 .31154 Mtetra
.644 .731 .912 r
.11006 .31154 .11848 .31972 .12993 .31598 .12154 .30776 Mtetra
.645 .731 .912 r
.12154 .30776 .12993 .31598 .14144 .31221 .13308 .30394 Mtetra
.645 .731 .911 r
.13308 .30394 .14144 .31221 .153 .3084 .14467 .30008 Mtetra
.646 .731 .911 r
.14467 .30008 .153 .3084 .16463 .30455 .15632 .29618 Mtetra
.647 .73 .91 r
.15632 .29618 .16463 .30455 .17631 .30067 .16804 .29223 Mtetra
.647 .73 .909 r
.16804 .29223 .17631 .30067 .18805 .29675 .17981 .28825 Mtetra
.648 .73 .908 r
.17981 .28825 .18805 .29675 .19985 .29278 .19164 .28422 Mtetra
.649 .729 .908 r
.19164 .28422 .19985 .29278 .21171 .28879 .20354 .28015 Mtetra
.65 .728 .907 r
.20354 .28015 .21171 .28879 .22363 .28475 .21549 .27604 Mtetra
.65 .728 .905 r
.21549 .27604 .22363 .28475 .23561 .28068 .2275 .27188 Mtetra
.651 .727 .904 r
.2275 .27188 .23561 .28068 .24765 .27657 .23958 .26768 Mtetra
.652 .726 .903 r
.23958 .26768 .24765 .27657 .25976 .27242 .25172 .26343 Mtetra
.653 .724 .901 r
.25172 .26343 .25976 .27242 .27192 .26822 .26391 .25913 Mtetra
.654 .723 .9 r
.26391 .25913 .27192 .26822 .28414 .26397 .27618 .25477 Mtetra
.655 .722 .898 r
.27618 .25477 .28414 .26397 .29643 .25966 .2885 .25035 Mtetra
.656 .72 .896 r
.2885 .25035 .29643 .25966 .30878 .25529 .30088 .24586 Mtetra
.658 .719 .894 r
.30088 .24586 .30878 .25529 .32119 .25084 .31333 .2413 Mtetra
.659 .718 .892 r
.31333 .2413 .32119 .25084 .33367 .2463 .32585 .23665 Mtetra
.661 .717 .89 r
.32585 .23665 .33367 .2463 .34621 .24167 .33843 .2319 Mtetra
.663 .716 .888 r
.33843 .2319 .34621 .24167 .35882 .23692 .35107 .22706 Mtetra
.666 .715 .886 r
.35107 .22706 .35882 .23692 .37149 .23206 .36377 .22211 Mtetra
.668 .715 .884 r
.36377 .22211 .37149 .23206 .38422 .22708 .37654 .21705 Mtetra
.67 .715 .882 r
.37654 .21705 .38422 .22708 .39702 .22197 .38937 .21188 Mtetra
.673 .716 .881 r
.38937 .21188 .39702 .22197 .40987 .21672 .40226 .20659 Mtetra
.675 .716 .88 r
.40226 .20659 .40987 .21672 .42279 .21136 .41522 .20118 Mtetra
.677 .717 .879 r
.41522 .20118 .42279 .21136 .43577 .20587 .42823 .19568 Mtetra
.679 .719 .879 r
.42823 .19568 .43577 .20587 .44881 .20026 .44131 .19007 Mtetra
.681 .72 .879 r
.44131 .19007 .44881 .20026 .46191 .19456 .45444 .18438 Mtetra
.682 .722 .879 r
.45444 .18438 .46191 .19456 .47506 .18877 .46763 .17861 Mtetra
.684 .724 .88 r
.46763 .17861 .47506 .18877 .48827 .18291 .48088 .17277 Mtetra
.685 .726 .881 r
.48088 .17277 .48827 .18291 .50154 .177 .49418 .1669 Mtetra
.685 .728 .883 r
.49418 .1669 .50154 .177 .51486 .17105 .50754 .16098 Mtetra
.685 .73 .884 r
.50754 .16098 .51486 .17105 .52824 .16508 .52096 .15505 Mtetra
.685 .732 .886 r
.52096 .15505 .52824 .16508 .54167 .1591 .53444 .14911 Mtetra
.685 .734 .888 r
.53444 .14911 .54167 .1591 .55516 .15313 .54797 .14317 Mtetra
.684 .735 .889 r
.54797 .14317 .55516 .15313 .56871 .14717 .56157 .13724 Mtetra
.683 .737 .891 r
.56157 .13724 .56871 .14717 .58232 .14124 .57522 .13134 Mtetra
.682 .738 .893 r
.57522 .13134 .58232 .14124 .59599 .13534 .58894 .12545 Mtetra
.681 .739 .895 r
.58894 .12545 .59599 .13534 .60972 .12947 .60272 .11959 Mtetra
.68 .74 .896 r
.60272 .11959 .60972 .12947 .62352 .12363 .61656 .11376 Mtetra
.679 .741 .898 r
.61656 .11376 .62352 .12363 .63738 .11783 .63047 .10795 Mtetra
.677 .742 .899 r
.63047 .10795 .63738 .11783 .6513 .11206 .64444 .10217 Mtetra
.676 .742 .9 r
.64444 .10217 .6513 .11206 .66529 .10632 .65848 .09641 Mtetra
.675 .742 .901 r
.65848 .09641 .66529 .10632 .67935 .1006 .67259 .09067 Mtetra
.674 .742 .902 r
.67259 .09067 .67935 .1006 .69348 .09491 .68677 .08495 Mtetra
.673 .743 .903 r
.68677 .08495 .69348 .09491 .70768 .08923 .70102 .07924 Mtetra
.672 .743 .904 r
.70102 .07924 .70768 .08923 .72195 .08357 .71534 .07354 Mtetra
.671 .743 .904 r
.71534 .07354 .72195 .08357 .73629 .07791 .72973 .06784 Mtetra
.643 .731 .912 r
.07874 .31084 .08728 .31901 .09864 .31529 .09013 .30707 Mtetra
.644 .731 .912 r
.09013 .30707 .09864 .31529 .11006 .31154 .10158 .30327 Mtetra
.644 .73 .911 r
.10158 .30327 .11006 .31154 .12154 .30776 .11308 .29944 Mtetra
.645 .73 .911 r
.11308 .29944 .12154 .30776 .13308 .30394 .12465 .29557 Mtetra
.646 .73 .91 r
.12465 .29557 .13308 .30394 .14467 .30008 .13627 .29166 Mtetra
.13627 .29166 .14467 .30008 .15632 .29618 .14795 .28771 Mtetra
.647 .73 .909 r
.14795 .28771 .15632 .29618 .16804 .29223 .1597 .28371 Mtetra
.648 .73 .908 r
.1597 .28371 .16804 .29223 .17981 .28825 .1715 .27967 Mtetra
.649 .729 .908 r
.1715 .27967 .17981 .28825 .19164 .28422 .18337 .27558 Mtetra
.65 .729 .907 r
.18337 .27558 .19164 .28422 .20354 .28015 .19529 .27144 Mtetra
.651 .728 .906 r
.19529 .27144 .20354 .28015 .21549 .27604 .20728 .26725 Mtetra
.652 .728 .905 r
.20728 .26725 .21549 .27604 .2275 .27188 .21933 .26301 Mtetra
.653 .727 .904 r
.21933 .26301 .2275 .27188 .23958 .26768 .23144 .25872 Mtetra
.654 .726 .902 r
.23144 .25872 .23958 .26768 .25172 .26343 .24361 .25438 Mtetra
.655 .725 .901 r
.24361 .25438 .25172 .26343 .26391 .25913 .25584 .24999 Mtetra
.656 .724 .899 r
.25584 .24999 .26391 .25913 .27618 .25477 .26814 .24553 Mtetra
.657 .723 .898 r
.26814 .24553 .27618 .25477 .2885 .25035 .2805 .24101 Mtetra
.658 .722 .896 r
.2805 .24101 .2885 .25035 .30088 .24586 .29292 .23641 Mtetra
.66 .721 .894 r
.29292 .23641 .30088 .24586 .31333 .2413 .30541 .23175 Mtetra
.661 .72 .892 r
.30541 .23175 .31333 .2413 .32585 .23665 .31796 .227 Mtetra
.663 .719 .891 r
.31796 .227 .32585 .23665 .33843 .2319 .33057 .22216 Mtetra
.665 .719 .889 r
.33057 .22216 .33843 .2319 .35107 .22706 .34325 .21723 Mtetra
.667 .718 .887 r
.34325 .21723 .35107 .22706 .36377 .22211 .35599 .2122 Mtetra
.669 .718 .886 r
.35599 .2122 .36377 .22211 .37654 .21705 .36879 .20707 Mtetra
.671 .718 .884 r
.36879 .20707 .37654 .21705 .38937 .21188 .38166 .20183 Mtetra
.673 .719 .883 r
.38166 .20183 .38937 .21188 .40226 .20659 .39459 .1965 Mtetra
.675 .719 .882 r
.39459 .1965 .40226 .20659 .41522 .20118 .40758 .19107 Mtetra
.677 .72 .882 r
.40758 .19107 .41522 .20118 .42823 .19568 .42063 .18554 Mtetra
.679 .721 .882 r
.42063 .18554 .42823 .19568 .44131 .19007 .43374 .17992 Mtetra
.68 .723 .882 r
.43374 .17992 .44131 .19007 .45444 .18438 .44691 .17423 Mtetra
.681 .724 .882 r
.44691 .17423 .45444 .18438 .46763 .17861 .46013 .16848 Mtetra
.682 .726 .883 r
.46013 .16848 .46763 .17861 .48088 .17277 .47342 .16266 Mtetra
.683 .728 .884 r
.47342 .16266 .48088 .17277 .49418 .1669 .48676 .15681 Mtetra
.684 .73 .885 r
.48676 .15681 .49418 .1669 .50754 .16098 .50017 .15092 Mtetra
.684 .731 .887 r
.50017 .15092 .50754 .16098 .52096 .15505 .51363 .14502 Mtetra
.684 .733 .888 r
.51363 .14502 .52096 .15505 .53444 .14911 .52714 .13911 Mtetra
.683 .735 .89 r
.52714 .13911 .53444 .14911 .54797 .14317 .54072 .13319 Mtetra
.683 .736 .891 r
.54072 .13319 .54797 .14317 .56157 .13724 .55436 .12728 Mtetra
.682 .738 .893 r
.55436 .12728 .56157 .13724 .57522 .13134 .56806 .12139 Mtetra
.681 .739 .894 r
.56806 .12139 .57522 .13134 .58894 .12545 .58182 .11551 Mtetra
.68 .74 .896 r
.58182 .11551 .58894 .12545 .60272 .11959 .59565 .10965 Mtetra
.679 .741 .897 r
.59565 .10965 .60272 .11959 .61656 .11376 .60954 .10382 Mtetra
.678 .741 .899 r
.60954 .10382 .61656 .11376 .63047 .10795 .62349 .098 Mtetra
.677 .742 .9 r
.62349 .098 .63047 .10795 .64444 .10217 .63752 .0922 Mtetra
.675 .742 .901 r
.63752 .0922 .64444 .10217 .65848 .09641 .65161 .08642 Mtetra
.674 .742 .902 r
.65161 .08642 .65848 .09641 .67259 .09067 .66577 .08065 Mtetra
.673 .742 .902 r
.66577 .08065 .67259 .09067 .68677 .08495 .68 .0749 Mtetra
.672 .742 .903 r
.68 .0749 .68677 .08495 .70102 .07924 .69429 .06915 Mtetra
.671 .742 .904 r
.69429 .06915 .70102 .07924 .71534 .07354 .70867 .06341 Mtetra
.70867 .06341 .71534 .07354 .72973 .06784 .72311 .05768 Mtetra
.644 .73 .912 r
.07014 .30257 .07874 .31084 .09013 .30707 .08155 .29875 Mtetra
.644 .73 .911 r
.08155 .29875 .09013 .30707 .10158 .30327 .09303 .29491 Mtetra
.645 .73 .911 r
.09303 .29491 .10158 .30327 .11308 .29944 .10456 .29103 Mtetra
.645 .73 .91 r
.10456 .29103 .11308 .29944 .12465 .29557 .11615 .28711 Mtetra
.646 .73 .91 r
.11615 .28711 .12465 .29557 .13627 .29166 .12781 .28315 Mtetra
.647 .73 .909 r
.12781 .28315 .13627 .29166 .14795 .28771 .13952 .27914 Mtetra
.648 .729 .908 r
.13952 .27914 .14795 .28771 .1597 .28371 .15129 .27509 Mtetra
.649 .729 .908 r
.15129 .27509 .1597 .28371 .1715 .27967 .16313 .27099 Mtetra
.65 .729 .907 r
.16313 .27099 .1715 .27967 .18337 .27558 .17502 .26683 Mtetra
.651 .729 .906 r
.17502 .26683 .18337 .27558 .19529 .27144 .18698 .26263 Mtetra
.652 .728 .905 r
.18698 .26263 .19529 .27144 .20728 .26725 .199 .25837 Mtetra
.653 .728 .904 r
.199 .25837 .20728 .26725 .21933 .26301 .21108 .25406 Mtetra
.654 .727 .903 r
.21108 .25406 .21933 .26301 .23144 .25872 .22323 .2497 Mtetra
.655 .727 .902 r
.22323 .2497 .23144 .25872 .24361 .25438 .23543 .24527 Mtetra
.656 .726 .901 r
.23543 .24527 .24361 .25438 .25584 .24999 .2477 .24079 Mtetra
.657 .725 .899 r
.2477 .24079 .25584 .24999 .26814 .24553 .26004 .23624 Mtetra
.659 .724 .898 r
.26004 .23624 .26814 .24553 .2805 .24101 .27243 .23163 Mtetra
.66 .724 .896 r
.27243 .23163 .2805 .24101 .29292 .23641 .28489 .22694 Mtetra
.661 .723 .895 r
.28489 .22694 .29292 .23641 .30541 .23175 .29741 .22218 Mtetra
.663 .722 .893 r
.29741 .22218 .30541 .23175 .31796 .227 .31 .21734 Mtetra
.665 .722 .891 r
.31 .21734 .31796 .227 .33057 .22216 .32265 .21242 Mtetra
.666 .721 .89 r
.32265 .21242 .33057 .22216 .34325 .21723 .33536 .20741 Mtetra
.668 .721 .889 r
.33536 .20741 .34325 .21723 .35599 .2122 .34814 .20231 Mtetra
.67 .721 .887 r
.34814 .20231 .35599 .2122 .36879 .20707 .36098 .19711 Mtetra
.672 .721 .886 r
.36098 .19711 .36879 .20707 .38166 .20183 .37388 .19183 Mtetra
.673 .721 .885 r
.37388 .19183 .38166 .20183 .39459 .1965 .38684 .18645 Mtetra
.675 .722 .885 r
.38684 .18645 .39459 .1965 .40758 .19107 .39987 .18099 Mtetra
.677 .723 .884 r
.39987 .18099 .40758 .19107 .42063 .18554 .41295 .17544 Mtetra
.678 .724 .884 r
.41295 .17544 .42063 .18554 .43374 .17992 .4261 .16981 Mtetra
.68 .725 .884 r
.4261 .16981 .43374 .17992 .44691 .17423 .43931 .16412 Mtetra
.681 .727 .885 r
.43931 .16412 .44691 .17423 .46013 .16848 .45257 .15837 Mtetra
.681 .728 .886 r
.45257 .15837 .46013 .16848 .47342 .16266 .4659 .15257 Mtetra
.682 .73 .886 r
.4659 .15257 .47342 .16266 .48676 .15681 .47928 .14673 Mtetra
.682 .731 .887 r
.47928 .14673 .48676 .15681 .50017 .15092 .49272 .14086 Mtetra
.682 .733 .889 r
.49272 .14086 .50017 .15092 .51363 .14502 .50622 .13497 Mtetra
.682 .734 .89 r
.50622 .13497 .51363 .14502 .52714 .13911 .51979 .12908 Mtetra
.682 .736 .891 r
.51979 .12908 .52714 .13911 .54072 .13319 .53341 .12318 Mtetra
.681 .737 .893 r
.53341 .12318 .54072 .13319 .55436 .12728 .54709 .11728 Mtetra
.681 .738 .894 r
.54709 .11728 .55436 .12728 .56806 .12139 .56084 .11139 Mtetra
.68 .739 .896 r
.56084 .11139 .56806 .12139 .58182 .11551 .57464 .10552 Mtetra
.679 .74 .897 r
.57464 .10552 .58182 .11551 .59565 .10965 .58852 .09965 Mtetra
.678 .741 .898 r
.58852 .09965 .59565 .10965 .60954 .10382 .60245 .0938 Mtetra
.677 .741 .899 r
.60245 .0938 .60954 .10382 .62349 .098 .61646 .08797 Mtetra
.676 .742 .9 r
.61646 .08797 .62349 .098 .63752 .0922 .63053 .08215 Mtetra
.675 .742 .901 r
.63053 .08215 .63752 .0922 .65161 .08642 .64467 .07634 Mtetra
.674 .742 .902 r
.64467 .07634 .65161 .08642 .66577 .08065 .65888 .07055 Mtetra
.673 .742 .903 r
.65888 .07055 .66577 .08065 .68 .0749 .67316 .06476 Mtetra
.672 .742 .903 r
.67316 .06476 .68 .0749 .69429 .06915 .68751 .05898 Mtetra
.671 .742 .904 r
.68751 .05898 .69429 .06915 .70867 .06341 .70193 .0532 Mtetra
.67 .742 .904 r
.70193 .0532 .70867 .06341 .72311 .05768 .71643 .04742 Mtetra
.644 .73 .911 r
.06147 .2942 .07014 .30257 .08155 .29875 .07291 .29034 Mtetra
.644 .729 .911 r
.07291 .29034 .08155 .29875 .09303 .29491 .08441 .28645 Mtetra
.645 .729 .91 r
.08441 .28645 .09303 .29491 .10456 .29103 .09597 .28252 Mtetra
.646 .729 .91 r
.09597 .28252 .10456 .29103 .11615 .28711 .10759 .27855 Mtetra
.647 .729 .909 r
.10759 .27855 .11615 .28711 .12781 .28315 .11927 .27454 Mtetra
.647 .729 .908 r
.11927 .27454 .12781 .28315 .13952 .27914 .13102 .27048 Mtetra
.648 .729 .908 r
.13102 .27048 .13952 .27914 .15129 .27509 .14282 .26637 Mtetra
.649 .729 .907 r
.14282 .26637 .15129 .27509 .16313 .27099 .15469 .26221 Mtetra
.65 .729 .906 r
.15469 .26221 .16313 .27099 .17502 .26683 .16661 .258 Mtetra
.652 .728 .905 r
.16661 .258 .17502 .26683 .18698 .26263 .1786 .25373 Mtetra
.653 .728 .904 r
.1786 .25373 .18698 .26263 .199 .25837 .19066 .24941 Mtetra
.654 .728 .903 r
.19066 .24941 .199 .25837 .21108 .25406 .20277 .24503 Mtetra
.655 .727 .902 r
.20277 .24503 .21108 .25406 .22323 .2497 .21495 .24059 Mtetra
.656 .727 .901 r
.21495 .24059 .22323 .2497 .23543 .24527 .22719 .23609 Mtetra
.657 .727 .9 r
.22719 .23609 .23543 .24527 .2477 .24079 .23949 .23153 Mtetra
.659 .726 .899 r
.23949 .23153 .2477 .24079 .26004 .23624 .25186 .2269 Mtetra
.66 .725 .898 r
.25186 .2269 .26004 .23624 .27243 .23163 .26429 .2222 Mtetra
.661 .725 .896 r
.26429 .2222 .27243 .23163 .28489 .22694 .27679 .21743 Mtetra
.663 .724 .895 r
.27679 .21743 .28489 .22694 .29741 .22218 .28935 .21259 Mtetra
.664 .724 .894 r
.28935 .21259 .29741 .22218 .31 .21734 .30197 .20767 Mtetra
.666 .723 .892 r
.30197 .20767 .31 .21734 .32265 .21242 .31465 .20267 Mtetra
.667 .723 .891 r
.31465 .20267 .32265 .21242 .33536 .20741 .3274 .19759 Mtetra
.669 .723 .89 r
.3274 .19759 .33536 .20741 .34814 .20231 .34022 .19243 Mtetra
.67 .723 .889 r
.34022 .19243 .34814 .20231 .36098 .19711 .35309 .18717 Mtetra
.672 .723 .888 r
.35309 .18717 .36098 .19711 .37388 .19183 .36603 .18184 Mtetra
.674 .724 .887 r
.36603 .18184 .37388 .19183 .38684 .18645 .37903 .17642 Mtetra
.675 .725 .887 r
.37903 .17642 .38684 .18645 .39987 .18099 .39209 .17093 Mtetra
.677 .725 .886 r
.39209 .17093 .39987 .18099 .41295 .17544 .40521 .16536 Mtetra
.678 .726 .886 r
.40521 .16536 .41295 .17544 .4261 .16981 .4184 .15972 Mtetra
.679 .727 .887 r
.4184 .15972 .4261 .16981 .43931 .16412 .43164 .15402 Mtetra
.68 .729 .887 r
.43164 .15402 .43931 .16412 .45257 .15837 .44494 .14827 Mtetra
.68 .73 .888 r
.44494 .14827 .45257 .15837 .4659 .15257 .45831 .14247 Mtetra
.681 .731 .888 r
.45831 .14247 .4659 .15257 .47928 .14673 .47173 .13664 Mtetra
.681 .733 .889 r
.47173 .13664 .47928 .14673 .49272 .14086 .48521 .13078 Mtetra
.681 .734 .891 r
.48521 .13078 .49272 .14086 .50622 .13497 .49876 .1249 Mtetra
.681 .735 .892 r
.49876 .1249 .50622 .13497 .51979 .12908 .51236 .11901 Mtetra
.681 .737 .893 r
.51236 .11901 .51979 .12908 .53341 .12318 .52603 .11312 Mtetra
.68 .738 .894 r
.52603 .11312 .53341 .12318 .54709 .11728 .53976 .10722 Mtetra
.679 .739 .895 r
.53976 .10722 .54709 .11728 .56084 .11139 .55355 .10133 Mtetra
.679 .739 .897 r
.55355 .10133 .56084 .11139 .57464 .10552 .5674 .09545 Mtetra
.678 .74 .898 r
.5674 .09545 .57464 .10552 .58852 .09965 .58132 .08958 Mtetra
.677 .741 .899 r
.58132 .08958 .58852 .09965 .60245 .0938 .59531 .08371 Mtetra
.676 .741 .9 r
.59531 .08371 .60245 .0938 .61646 .08797 .60936 .07786 Mtetra
.675 .742 .901 r
.60936 .07786 .61646 .08797 .63053 .08215 .62348 .07202 Mtetra
.674 .742 .902 r
.62348 .07202 .63053 .08215 .64467 .07634 .63767 .06618 Mtetra
.673 .742 .902 r
.63767 .06618 .64467 .07634 .65888 .07055 .65193 .06035 Mtetra
.672 .742 .903 r
.65193 .06035 .65888 .07055 .67316 .06476 .66626 .05453 Mtetra
.672 .742 .904 r
.66626 .05453 .67316 .06476 .68751 .05898 .68066 .0487 Mtetra
.671 .742 .904 r
.68066 .0487 .68751 .05898 .70193 .0532 .69513 .04288 Mtetra
.67 .742 .904 r
.69513 .04288 .70193 .0532 .71643 .04742 .70968 .03706 Mtetra
.644 .729 .91 r
.05272 .28575 .06147 .2942 .07291 .29034 .06419 .28184 Mtetra
.645 .729 .91 r
.06419 .28184 .07291 .29034 .08441 .28645 .07572 .27789 Mtetra
.646 .729 .909 r
.07572 .27789 .08441 .28645 .09597 .28252 .08731 .27391 Mtetra
.08731 .27391 .09597 .28252 .10759 .27855 .09896 .26989 Mtetra
.647 .728 .908 r
.09896 .26989 .10759 .27855 .11927 .27454 .11067 .26583 Mtetra
.648 .728 .908 r
.11067 .26583 .11927 .27454 .13102 .27048 .12245 .26171 Mtetra
.649 .728 .907 r
.12245 .26171 .13102 .27048 .14282 .26637 .13428 .25755 Mtetra
.65 .728 .906 r
.13428 .25755 .14282 .26637 .15469 .26221 .14618 .25334 Mtetra
.651 .728 .905 r
.14618 .25334 .15469 .26221 .16661 .258 .15814 .24907 Mtetra
.652 .728 .905 r
.15814 .24907 .16661 .258 .1786 .25373 .17016 .24474 Mtetra
.653 .728 .904 r
.17016 .24474 .1786 .25373 .19066 .24941 .18224 .24035 Mtetra
.655 .728 .903 r
.18224 .24035 .19066 .24941 .20277 .24503 .19439 .23591 Mtetra
.656 .727 .902 r
.19439 .23591 .20277 .24503 .21495 .24059 .2066 .2314 Mtetra
.657 .727 .901 r
.2066 .2314 .21495 .24059 .22719 .23609 .21888 .22683 Mtetra
.658 .727 .9 r
.21888 .22683 .22719 .23609 .23949 .23153 .23122 .22219 Mtetra
.66 .726 .899 r
.23122 .22219 .23949 .23153 .25186 .2269 .24362 .21749 Mtetra
.661 .726 .898 r
.24362 .21749 .25186 .2269 .26429 .2222 .25609 .21272 Mtetra
.662 .726 .896 r
.25609 .21272 .26429 .2222 .27679 .21743 .26862 .20788 Mtetra
.664 .725 .895 r
.26862 .20788 .27679 .21743 .28935 .21259 .28121 .20296 Mtetra
.665 .725 .894 r
.28121 .20296 .28935 .21259 .30197 .20767 .29387 .19797 Mtetra
.667 .725 .893 r
.29387 .19797 .30197 .20767 .31465 .20267 .30659 .1929 Mtetra
.668 .725 .892 r
.30659 .1929 .31465 .20267 .3274 .19759 .31937 .18776 Mtetra
.669 .725 .891 r
.31937 .18776 .3274 .19759 .34022 .19243 .33222 .18253 Mtetra
.671 .725 .89 r
.33222 .18253 .34022 .19243 .35309 .18717 .34513 .17723 Mtetra
.672 .725 .889 r
.34513 .17723 .35309 .18717 .36603 .18184 .35811 .17185 Mtetra
.674 .726 .889 r
.35811 .17185 .36603 .18184 .37903 .17642 .37114 .1664 Mtetra
.675 .727 .888 r
.37114 .1664 .37903 .17642 .39209 .17093 .38424 .16087 Mtetra
.676 .727 .888 r
.38424 .16087 .39209 .17093 .40521 .16536 .3974 .15528 Mtetra
.677 .728 .888 r
.3974 .15528 .40521 .16536 .4184 .15972 .41062 .14962 Mtetra
.678 .729 .889 r
.41062 .14962 .4184 .15972 .43164 .15402 .42391 .14391 Mtetra
.679 .73 .889 r
.42391 .14391 .43164 .15402 .44494 .14827 .43725 .13816 Mtetra
.68 .731 .89 r
.43725 .13816 .44494 .14827 .45831 .14247 .45065 .13236 Mtetra
.68 .733 .89 r
.45065 .13236 .45831 .14247 .47173 .13664 .46412 .12653 Mtetra
.68 .734 .891 r
.46412 .12653 .47173 .13664 .48521 .13078 .47764 .12067 Mtetra
.68 .735 .892 r
.47764 .12067 .48521 .13078 .49876 .1249 .49123 .11479 Mtetra
.68 .736 .893 r
.49123 .11479 .49876 .1249 .51236 .11901 .50487 .1089 Mtetra
.68 .737 .894 r
.50487 .1089 .51236 .11901 .52603 .11312 .51858 .10301 Mtetra
.679 .738 .895 r
.51858 .10301 .52603 .11312 .53976 .10722 .53235 .09711 Mtetra
.678 .739 .896 r
.53235 .09711 .53976 .10722 .55355 .10133 .54619 .09121 Mtetra
.678 .74 .897 r
.54619 .09121 .55355 .10133 .5674 .09545 .56009 .08532 Mtetra
.677 .74 .898 r
.56009 .08532 .5674 .09545 .58132 .08958 .57406 .07943 Mtetra
.676 .741 .899 r
.57406 .07943 .58132 .08958 .59531 .08371 .58809 .07354 Mtetra
.675 .741 .9 r
.58809 .07354 .59531 .08371 .60936 .07786 .60219 .06766 Mtetra
.674 .742 .901 r
.60219 .06766 .60936 .07786 .62348 .07202 .61636 .06179 Mtetra
.674 .742 .902 r
.61636 .06179 .62348 .07202 .63767 .06618 .6306 .05592 Mtetra
.673 .742 .902 r
.6306 .05592 .63767 .06618 .65193 .06035 .64491 .05006 Mtetra
.672 .742 .903 r
.64491 .05006 .65193 .06035 .66626 .05453 .65929 .0442 Mtetra
.671 .742 .904 r
.65929 .0442 .66626 .05453 .68066 .0487 .67374 .03834 Mtetra
.67374 .03834 .68066 .0487 .69513 .04288 .68827 .03247 Mtetra
.67 .742 .905 r
.68827 .03247 .69513 .04288 .70968 .03706 .70287 .0266 Mtetra
.645 .729 .91 r
.04391 .2772 .05272 .28575 .06419 .28184 .05541 .27323 Mtetra
.645 .728 .909 r
.05541 .27323 .06419 .28184 .07572 .27789 .06697 .26924 Mtetra
.646 .728 .909 r
.06697 .26924 .07572 .27789 .08731 .27391 .07859 .26521 Mtetra
.647 .728 .908 r
.07859 .26521 .08731 .27391 .09896 .26989 .09027 .26113 Mtetra
.648 .728 .907 r
.09027 .26113 .09896 .26989 .11067 .26583 .10201 .25701 Mtetra
.10201 .25701 .11067 .26583 .12245 .26171 .11381 .25285 Mtetra
.649 .728 .906 r
.11381 .25285 .12245 .26171 .13428 .25755 .12567 .24863 Mtetra
.65 .728 .905 r
.12567 .24863 .13428 .25755 .14618 .25334 .1376 .24436 Mtetra
.652 .728 .905 r
.1376 .24436 .14618 .25334 .15814 .24907 .14959 .24003 Mtetra
.653 .728 .904 r
.14959 .24003 .15814 .24907 .17016 .24474 .16164 .23565 Mtetra
.654 .727 .903 r
.16164 .23565 .17016 .24474 .18224 .24035 .17376 .2312 Mtetra
.655 .727 .902 r
.17376 .2312 .18224 .24035 .19439 .23591 .18594 .22669 Mtetra
.656 .727 .901 r
.18594 .22669 .19439 .23591 .2066 .2314 .19819 .22212 Mtetra
.658 .727 .9 r
.19819 .22212 .2066 .2314 .21888 .22683 .2105 .21749 Mtetra
.659 .727 .899 r
.2105 .21749 .21888 .22683 .23122 .22219 .22287 .21279 Mtetra
.66 .727 .898 r
.22287 .21279 .23122 .22219 .24362 .21749 .23531 .20802 Mtetra
.662 .727 .897 r
.23531 .20802 .24362 .21749 .25609 .21272 .24781 .20318 Mtetra
.663 .726 .896 r
.24781 .20318 .25609 .21272 .26862 .20788 .26037 .19827 Mtetra
.664 .726 .895 r
.26037 .19827 .26862 .20788 .28121 .20296 .273 .19329 Mtetra
.666 .726 .894 r
.273 .19329 .28121 .20296 .29387 .19797 .28569 .18823 Mtetra
.667 .726 .893 r
.28569 .18823 .29387 .19797 .30659 .1929 .29845 .1831 Mtetra
.669 .726 .893 r
.29845 .1831 .30659 .1929 .31937 .18776 .31127 .1779 Mtetra
.67 .726 .892 r
.31127 .1779 .31937 .18776 .33222 .18253 .32416 .17262 Mtetra
.671 .727 .891 r
.32416 .17262 .33222 .18253 .34513 .17723 .33711 .16727 Mtetra
.673 .727 .891 r
.33711 .16727 .34513 .17723 .35811 .17185 .35012 .16185 Mtetra
.674 .727 .89 r
.35012 .16185 .35811 .17185 .37114 .1664 .36319 .15636 Mtetra
.675 .728 .89 r
.36319 .15636 .37114 .1664 .38424 .16087 .37632 .1508 Mtetra
.676 .729 .89 r
.37632 .1508 .38424 .16087 .3974 .15528 .38952 .14518 Mtetra
.677 .73 .89 r
.38952 .14518 .3974 .15528 .41062 .14962 .40278 .13951 Mtetra
.678 .731 .89 r
.40278 .13951 .41062 .14962 .42391 .14391 .4161 .13379 Mtetra
.678 .732 .891 r
.4161 .13379 .42391 .14391 .43725 .13816 .42948 .12802 Mtetra
.679 .733 .891 r
.42948 .12802 .43725 .13816 .45065 .13236 .44293 .12221 Mtetra
.679 .734 .892 r
.44293 .12221 .45065 .13236 .46412 .12653 .45643 .11638 Mtetra
.679 .735 .893 r
.45643 .11638 .46412 .12653 .47764 .12067 .47 .11052 Mtetra
.679 .736 .893 r
.47 .11052 .47764 .12067 .49123 .11479 .48363 .10463 Mtetra
.679 .737 .894 r
.48363 .10463 .49123 .11479 .50487 .1089 .49732 .09874 Mtetra
.678 .738 .895 r
.49732 .09874 .50487 .1089 .51858 .10301 .51107 .09283 Mtetra
.678 .738 .896 r
.51107 .09283 .51858 .10301 .53235 .09711 .52489 .08693 Mtetra
.677 .739 .897 r
.52489 .08693 .53235 .09711 .54619 .09121 .53877 .08101 Mtetra
.677 .74 .898 r
.53877 .08101 .54619 .09121 .56009 .08532 .55272 .0751 Mtetra
.676 .74 .899 r
.55272 .0751 .56009 .08532 .57406 .07943 .56673 .06919 Mtetra
.675 .741 .9 r
.56673 .06919 .57406 .07943 .58809 .07354 .58081 .06328 Mtetra
.675 .741 .901 r
.58081 .06328 .58809 .07354 .60219 .06766 .59496 .05738 Mtetra
.674 .741 .901 r
.59496 .05738 .60219 .06766 .61636 .06179 .60918 .05147 Mtetra
.673 .742 .902 r
.60918 .05147 .61636 .06179 .6306 .05592 .62347 .04557 Mtetra
.672 .742 .903 r
.62347 .04557 .6306 .05592 .64491 .05006 .63783 .03967 Mtetra
.63783 .03967 .64491 .05006 .65929 .0442 .65226 .03377 Mtetra
.671 .742 .904 r
.65226 .03377 .65929 .0442 .67374 .03834 .66676 .02787 Mtetra
.67 .742 .904 r
.66676 .02787 .67374 .03834 .68827 .03247 .68134 .02196 Mtetra
.67 .742 .905 r
.68134 .02196 .68827 .03247 .70287 .0266 .69599 .01605 Mtetra
.645 .728 .909 r
.03503 .26855 .04391 .2772 .05541 .27323 .04656 .26454 Mtetra
.646 .728 .908 r
.04656 .26454 .05541 .27323 .06697 .26924 .05815 .26049 Mtetra
.05815 .26049 .06697 .26924 .07859 .26521 .06979 .2564 Mtetra
.647 .728 .907 r
.06979 .2564 .07859 .26521 .09027 .26113 .0815 .25227 Mtetra
.648 .727 .907 r
.0815 .25227 .09027 .26113 .10201 .25701 .09327 .2481 Mtetra
.649 .727 .906 r
.09327 .2481 .10201 .25701 .11381 .25285 .1051 .24388 Mtetra
.65 .727 .905 r
.1051 .24388 .11381 .25285 .12567 .24863 .117 .23961 Mtetra
.651 .727 .905 r
.117 .23961 .12567 .24863 .1376 .24436 .12895 .23528 Mtetra
.652 .727 .904 r
.12895 .23528 .1376 .24436 .14959 .24003 .14098 .2309 Mtetra
.653 .727 .903 r
.14098 .2309 .14959 .24003 .16164 .23565 .15306 .22645 Mtetra
.654 .727 .902 r
.15306 .22645 .16164 .23565 .17376 .2312 .16521 .22195 Mtetra
.656 .727 .902 r
.16521 .22195 .17376 .2312 .18594 .22669 .17742 .21738 Mtetra
.657 .727 .901 r
.17742 .21738 .18594 .22669 .19819 .22212 .1897 .21275 Mtetra
.658 .727 .9 r
.1897 .21275 .19819 .22212 .2105 .21749 .20204 .20806 Mtetra
.66 .727 .899 r
.20204 .20806 .2105 .21749 .22287 .21279 .21445 .20329 Mtetra
.661 .727 .898 r
.21445 .20329 .22287 .21279 .23531 .20802 .22692 .19846 Mtetra
.662 .727 .897 r
.22692 .19846 .23531 .20802 .24781 .20318 .23946 .19356 Mtetra
.664 .727 .896 r
.23946 .19356 .24781 .20318 .26037 .19827 .25206 .18859 Mtetra
.665 .727 .895 r
.25206 .18859 .26037 .19827 .273 .19329 .26472 .18355 Mtetra
.666 .727 .895 r
.26472 .18355 .273 .19329 .28569 .18823 .27745 .17844 Mtetra
.668 .727 .894 r
.27745 .17844 .28569 .18823 .29845 .1831 .29024 .17325 Mtetra
.669 .727 .893 r
.29024 .17325 .29845 .1831 .31127 .1779 .3031 .16799 Mtetra
.67 .727 .893 r
.3031 .16799 .31127 .1779 .32416 .17262 .31602 .16267 Mtetra
.671 .728 .892 r
.31602 .16267 .32416 .17262 .33711 .16727 .32901 .15727 Mtetra
.672 .728 .892 r
.32901 .15727 .33711 .16727 .35012 .16185 .34205 .15181 Mtetra
.674 .729 .891 r
.34205 .15181 .35012 .16185 .36319 .15636 .35516 .14629 Mtetra
.675 .729 .891 r
.35516 .14629 .36319 .15636 .37632 .1508 .36834 .1407 Mtetra
.675 .73 .891 r
.36834 .1407 .37632 .1508 .38952 .14518 .38157 .13506 Mtetra
.676 .731 .891 r
.38157 .13506 .38952 .14518 .40278 .13951 .39487 .12937 Mtetra
.677 .732 .891 r
.39487 .12937 .40278 .13951 .4161 .13379 .40823 .12363 Mtetra
.677 .733 .892 r
.40823 .12363 .4161 .13379 .42948 .12802 .42165 .11784 Mtetra
.678 .734 .892 r
.42165 .11784 .42948 .12802 .44293 .12221 .43513 .11203 Mtetra
.678 .734 .893 r
.43513 .11203 .44293 .12221 .45643 .11638 .44868 .10618 Mtetra
.678 .735 .894 r
.44868 .10618 .45643 .11638 .47 .11052 .46229 .10031 Mtetra
.678 .736 .894 r
.46229 .10031 .47 .11052 .48363 .10463 .47596 .09442 Mtetra
.678 .737 .895 r
.47596 .09442 .48363 .10463 .49732 .09874 .48969 .08851 Mtetra
.678 .738 .896 r
.48969 .08851 .49732 .09874 .51107 .09283 .50349 .08259 Mtetra
.677 .739 .897 r
.50349 .08259 .51107 .09283 .52489 .08693 .51735 .07667 Mtetra
.677 .739 .898 r
.51735 .07667 .52489 .08693 .53877 .08101 .53128 .07074 Mtetra
.676 .74 .899 r
.53128 .07074 .53877 .08101 .55272 .0751 .54527 .0648 Mtetra
.675 .74 .899 r
.54527 .0648 .55272 .0751 .56673 .06919 .55933 .05887 Mtetra
.675 .741 .9 r
.55933 .05887 .56673 .06919 .58081 .06328 .57346 .05293 Mtetra
.674 .741 .901 r
.57346 .05293 .58081 .06328 .59496 .05738 .58766 .047 Mtetra
.673 .741 .902 r
.58766 .047 .59496 .05738 .60918 .05147 .60193 .04106 Mtetra
.673 .742 .902 r
.60193 .04106 .60918 .05147 .62347 .04557 .61627 .03513 Mtetra
.672 .742 .903 r
.61627 .03513 .62347 .04557 .63783 .03967 .63068 .02919 Mtetra
.671 .742 .903 r
.63068 .02919 .63783 .03967 .65226 .03377 .64516 .02324 Mtetra
.671 .742 .904 r
.64516 .02324 .65226 .03377 .66676 .02787 .65971 .0173 Mtetra
.67 .742 .904 r
.65971 .0173 .66676 .02787 .68134 .02196 .67434 .01135 Mtetra
.669 .742 .905 r
.67434 .01135 .68134 .02196 .69599 .01605 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.1388 .83364 m
.1646 .82032 L
.1904 .81862 L
.2162 .82711 L
.22956 .8354 L
.242 .84909 L
.24666 .8612 L
.25246 .887 L
.24806 .9128 L
.242 .92481 L
.23334 .9386 L
.2162 .9505 L
.1904 .95872 L
.1646 .95708 L
.1388 .94404 L
.13241 .9386 L
.1159 .9128 L
.113 .89946 L
.11216 .887 L
.113 .87791 L
.11707 .8612 L
.13654 .8354 L
.1388 .83364 L
s
.0098 .80764 m
.01133 .8096 L
.03433 .8354 L
.0356 .8366 L
.0614 .85675 L
.0684 .8612 L
.0872 .87102 L
.113 .88076 L
.1388 .88662 L
.14126 .887 L
.1646 .889 L
.1904 .888 L
.19836 .887 L
.2162 .88356 L
.242 .87545 L
.2678 .86311 L
.27111 .8612 L
.2936 .8456 L
.30537 .8354 L
.3194 .82078 L
.32838 .8096 L
.34468 .7838 L
.3452 .78285 L
.35609 .758 L
.3634 .7322 L
.36711 .7064 L
.36741 .6806 L
.36432 .6548 L
.35767 .629 L
.34704 .6032 L
.3452 .59953 L
.33172 .5774 L
.3194 .5616 L
.3101 .5516 L
.2936 .53679 L
.27853 .5258 L
.2678 .51928 L
.242 .50695 L
.22124 .5 L
.2162 .49884 L
.1904 .49439 L
.1646 .49338 L
.1388 .49576 L
.11666 .5 L
.113 .50165 L
.0872 .51137 L
.0614 .52567 L
.0612 .5258 L
.0356 .54577 L
.02967 .5516 L
Mistroke
.0098 .57477 L
Mfstroke
.9902 .63573 m
.98269 .629 L
.9644 .61392 L
.94979 .6032 L
.9386 .5957 L
.9128 .58049 L
.90694 .5774 L
.887 .56788 L
.8612 .55759 L
.84299 .5516 L
.8354 .54944 L
.8096 .54327 L
.7838 .53898 L
.758 .53652 L
.7322 .53584 L
.7064 .53694 L
.6806 .53983 L
.6548 .54456 L
.629 .5512 L
.62763 .5516 L
.6032 .55984 L
.5774 .57066 L
.56359 .5774 L
.5516 .58386 L
.5258 .59975 L
.52076 .6032 L
.5 .61876 L
.48782 .629 L
.4742 .64156 L
.46119 .6548 L
.4484 .66921 L
.43918 .6806 L
.4226 .70365 L
.4208 .7064 L
.40544 .7322 L
.3968 .74913 L
.39271 .758 L
.38232 .7838 L
.37406 .8096 L
.371 .82095 L
.36779 .8354 L
.36341 .8612 L
.36086 .887 L
.36009 .9128 L
.36111 .9386 L
.36391 .9644 L
.36854 .9902 L
s
.4742 .26046 m
.5 .25686 L
.5258 .25736 L
.5516 .26201 L
.57046 .2678 L
.5774 .27116 L
.6032 .28572 L
.61377 .2936 L
.629 .30774 L
.63905 .3194 L
.6548 .34356 L
.65564 .3452 L
.66642 .371 L
.67243 .3968 L
.67422 .4226 L
.67195 .4484 L
.66543 .4742 L
.6548 .49873 L
.65405 .5 L
.63663 .5258 L
.629 .53445 L
.60995 .5516 L
.6032 .55647 L
.5774 .57106 L
.5621 .5774 L
.5516 .58019 L
.5258 .58484 L
.5 .58534 L
.4742 .58174 L
.45646 .5774 L
.4484 .57378 L
.4226 .5607 L
.40938 .5516 L
.3968 .54084 L
.38274 .5258 L
.371 .50974 L
.36533 .5 L
.35397 .4742 L
.34747 .4484 L
.34521 .4226 L
.347 .3968 L
.35298 .371 L
.36373 .3452 L
.371 .33242 L
.38033 .3194 L
.3968 .30137 L
.40561 .2936 L
.4226 .2815 L
.4484 .26845 L
.44955 .2678 L
Mistroke
.4742 .26046 L
Mfstroke
.0098 .68607 m
.0356 .69282 L
.0614 .6972 L
.0872 .69933 L
.113 .69925 L
.1388 .69696 L
.1646 .69241 L
.1904 .68548 L
.20474 .6806 L
.2162 .67601 L
.242 .66373 L
.25758 .6548 L
.2678 .64821 L
.29338 .629 L
.2936 .62881 L
.3194 .60445 L
.32058 .6032 L
.34206 .5774 L
.3452 .5731 L
.35925 .5516 L
.371 .52986 L
.37293 .5258 L
.38365 .5 L
.3917 .4742 L
.3968 .45154 L
.39732 .4484 L
.40063 .4226 L
.40171 .3968 L
.40059 .371 L
.39724 .3452 L
.3968 .34252 L
.39159 .3194 L
.3835 .2936 L
.37273 .2678 L
.371 .26418 L
.35899 .242 L
.3452 .22092 L
.34174 .2162 L
.32018 .1904 L
.3194 .18958 L
.2936 .16522 L
.29287 .1646 L
.2678 .14582 L
.25688 .1388 L
.242 .1303 L
.2162 .11802 L
.20358 .113 L
.1904 .10855 L
.1646 .10162 L
.1388 .09707 L
Mistroke
.113 .09478 L
.0872 .0947 L
.0614 .09683 L
.0356 .10121 L
.0098 .10796 L
Mfstroke
.72412 .0098 m
.7322 .02768 L
.73553 .0356 L
.74402 .0614 L
.74986 .0872 L
.75321 .113 L
.75416 .1388 L
.75274 .1646 L
.74891 .1904 L
.74256 .2162 L
.73352 .242 L
.7322 .24522 L
.72149 .2678 L
.7064 .29301 L
.70599 .2936 L
.68631 .3194 L
.6806 .32585 L
.6611 .3452 L
.6548 .3507 L
.629 .37012 L
.62767 .371 L
.6032 .3854 L
.57852 .3968 L
.5774 .39724 L
.5516 .40613 L
.5258 .41233 L
.5 .41602 L
.4742 .41731 L
.4484 .41622 L
.4226 .41274 L
.3968 .40675 L
.371 .3981 L
.36769 .3968 L
.3452 .38652 L
.3194 .37155 L
.31857 .371 L
.2936 .35252 L
.28513 .3452 L
.2678 .3282 L
.25992 .3194 L
.242 .29619 L
.24024 .2936 L
.22474 .2678 L
.2162 .25028 L
.21272 .242 L
.20367 .2162 L
.19733 .1904 L
.1935 .1646 L
.19208 .1388 L
.19303 .113 L
Mistroke
.19638 .0872 L
.20221 .0614 L
.21071 .0356 L
.2162 .02283 L
.22212 .0098 L
Mfstroke
.5258 .41367 m
.5516 .40584 L
.5774 .40239 L
.6032 .40302 L
.629 .40778 L
.6548 .41709 L
.666 .4226 L
.6806 .43182 L
.70072 .4484 L
.7064 .45417 L
.72241 .4742 L
.7322 .49038 L
.7367 .5 L
.74568 .5258 L
.75014 .5516 L
.75048 .5774 L
.74673 .6032 L
.73856 .629 L
.7322 .64308 L
.72526 .6548 L
.7064 .67912 L
.70499 .6806 L
.6806 .70151 L
.67339 .7064 L
.6548 .71627 L
.629 .72557 L
.6032 .73031 L
.5774 .73094 L
.5516 .7275 L
.5258 .71969 L
.5 .70672 L
.49948 .7064 L
.4742 .68712 L
.46758 .6806 L
.4484 .65639 L
.4474 .6548 L
.43402 .629 L
.42589 .6032 L
.4226 .58283 L
.42215 .5774 L
.4225 .5516 L
.4226 .55052 L
.42694 .5258 L
.43588 .5 L
.4484 .47686 L
.45024 .4742 L
.47195 .4484 L
.4742 .44627 L
.5 .4266 L
.50655 .4226 L
Mistroke
.5258 .41367 L
Mfstroke
.21316 .9902 m
.2162 .98304 L
.2225 .9644 L
.22214 .9386 L
.2162 .92181 L
.21215 .9128 L
.1904 .89201 L
.17803 .887 L
.1646 .88325 L
.1388 .88388 L
.1286 .887 L
.113 .89395 L
.09441 .9128 L
.0872 .92961 L
.08465 .9386 L
.08429 .9644 L
.0872 .97524 L
.09328 .9902 L
s
.0098 .28709 m
.01739 .2936 L
.0356 .30775 L
.05342 .3194 L
.0614 .324 L
.0872 .33668 L
.1096 .3452 L
.113 .34628 L
.1388 .35315 L
.1646 .35747 L
.1904 .35937 L
.2162 .35889 L
.242 .35602 L
.2678 .35069 L
.28675 .3452 L
.2936 .34274 L
.3194 .33195 L
.34273 .3194 L
.3452 .31789 L
.371 .29999 L
.3789 .2936 L
.3968 .27718 L
.40576 .2678 L
.4226 .2475 L
.42663 .242 L
.44305 .2162 L
.4484 .20629 L
.45587 .1904 L
.4656 .1646 L
.47257 .1388 L
.4742 .13277 L
.477 .113 L
.479 .0872 L
.47862 .0614 L
.47585 .0356 L
.4742 .02599 L
.47063 .0098 L
s
0 g
.03 w
.18211 .88868 Mdot
.16981 .6912 Mdot
.73527 .91101 Mdot
.5097 .4211 Mdot
.09916 .39701 Mdot
.47312 .13626 Mdot
.5863 .56668 Mdot
.15332 .95243 Mdot
.19808 .07842 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.16667 .88649 m
.18627 .89207 L
.18637 .89216 L
.19666 .91176 L
.1961 .93137 L
.18627 .94105 L
.16667 .95049 L
.14706 .94283 L
.13779 .93137 L
.13882 .91176 L
.14706 .89963 L
.15502 .89216 L
.16667 .88649 L
s
.16667 .86963 m
.18627 .87164 L
.18839 .87255 L
.20588 .88649 L
.20838 .89216 L
.21315 .91176 L
.20998 .93137 L
.20588 .94027 L
.20085 .95098 L
.18627 .96179 L
.16667 .96806 L
.14706 .96505 L
.13151 .95098 L
.12745 .94369 L
.12375 .93137 L
.12461 .91176 L
.12745 .903 L
.13161 .89216 L
.14706 .87702 L
.1566 .87255 L
.16667 .86963 L
s
.14706 .86184 m
.16667 .85533 L
.18627 .85628 L
.20588 .86613 L
.2126 .87255 L
.22304 .89216 L
.22549 .90583 L
.22575 .91176 L
.22549 .91731 L
.22305 .93137 L
.21435 .95098 L
.20588 .96204 L
.19755 .97059 L
.18627 .97552 L
.16667 .98024 L
.14706 .97787 L
.13083 .97059 L
.12745 .9682 L
.11557 .95098 L
.1107 .93137 L
.11168 .91176 L
.11829 .89216 L
.12745 .87778 L
.13169 .87255 L
.14706 .86184 L
s
.18422 .9902 m
.18627 .98919 L
.20588 .97705 L
.21361 .97059 L
.22549 .95456 L
.22738 .95098 L
.23497 .93137 L
.23771 .91176 L
.23577 .89216 L
.22808 .87255 L
.22549 .86827 L
.21091 .85294 L
.20588 .84992 L
.18627 .84255 L
.16667 .84209 L
.14706 .84786 L
.13675 .85294 L
.12745 .86089 L
.11677 .87255 L
.10784 .88699 L
.10568 .89216 L
.09996 .91176 L
.09888 .93137 L
.10271 .95098 L
.10784 .96397 L
.11281 .97059 L
.12745 .98188 L
.13905 .9902 L
s
.2087 .9902 m
.22549 .97389 L
.2283 .97059 L
.23999 .95098 L
.2451 .93917 L
.24672 .93137 L
.2494 .91176 L
.24812 .89216 L
.2451 .88004 L
.24229 .87255 L
.23 .85294 L
.22549 .84821 L
.20588 .83477 L
.20248 .83333 L
.18627 .82902 L
.16667 .82891 L
.14894 .83333 L
.14706 .83406 L
.12745 .84524 L
.11833 .85294 L
.10784 .86502 L
.1028 .87255 L
.09334 .89216 L
.08832 .91176 L
.08824 .91235 L
.08724 .93137 L
.08824 .94134 L
.09025 .95098 L
.09833 .97059 L
.10784 .98057 L
.11429 .9902 L
s
.22682 .9902 m
.24259 .97059 L
.2451 .96667 L
.25275 .95098 L
.25895 .93137 L
.26165 .91176 L
.26088 .89216 L
.2563 .87255 L
.24688 .85294 L
.2451 .85021 L
.22979 .83333 L
.22549 .83003 L
.20588 .81946 L
.18627 .81478 L
.16667 .81492 L
.14706 .81968 L
.12745 .82947 L
.12175 .83333 L
.10784 .84583 L
.10164 .85294 L
.08887 .87255 L
.08824 .87369 L
.08075 .89216 L
.07626 .91176 L
.07517 .93137 L
.07764 .95098 L
.08428 .97059 L
.08824 .97522 L
.09666 .9902 L
s
.24415 .9902 m
.2451 .98889 L
.25748 .97059 L
.26471 .95605 L
.26661 .95098 L
.27231 .93137 L
.27504 .91176 L
.27477 .89216 L
.27127 .87255 L
.26471 .85429 L
.26398 .85294 L
.25141 .83333 L
.2451 .82634 L
.22973 .81373 L
.22549 .8112 L
.20588 .80268 L
.18627 .79888 L
.16667 .79924 L
.14706 .80364 L
.12745 .81228 L
.12487 .81373 L
.10784 .8263 L
.10042 .83333 L
.08824 .84793 L
.08482 .85294 L
.07411 .87255 L
.06863 .88635 L
.06701 .89216 L
.06306 .91176 L
.06203 .93137 L
.06407 .95098 L
.06863 .96903 L
.06959 .97059 L
.07968 .9902 L
s
.26283 .9902 m
.26471 .98726 L
.27437 .97059 L
.28276 .95098 L
.28431 .94705 L
.28811 .93137 L
.29091 .91176 L
.29117 .89216 L
.28873 .87255 L
.28431 .85541 L
.28327 .85294 L
.27386 .83333 L
.26471 .81998 L
.25933 .81373 L
.2451 .80088 L
.23536 .79412 L
.22549 .78909 L
.20588 .78217 L
.18627 .77913 L
.16667 .77972 L
.14706 .78386 L
.12745 .79159 L
.12242 .79412 L
.10784 .80378 L
.0959 .81373 L
.08824 .82156 L
.07853 .83333 L
.06863 .84825 L
.06605 .85294 L
.05713 .87255 L
.05096 .89216 L
.04902 .90115 L
.04751 .91176 L
.04662 .93137 L
.04832 .95098 L
.04902 .95641 L
.0531 .97059 L
.06148 .9902 L
s
.46078 .33481 m
.48039 .33005 L
.5 .32859 L
.51961 .33017 L
.53922 .33474 L
.55882 .34242 L
.56035 .34314 L
.57843 .35352 L
.59109 .36275 L
.59804 .36872 L
.61166 .38235 L
.61765 .38941 L
.62693 .40196 L
.63725 .41922 L
.63846 .42157 L
.64706 .44118 L
.65303 .46078 L
.65656 .48039 L
.65686 .48308 L
.6577 .5 L
.65686 .51525 L
.65633 .51961 L
.6522 .53922 L
.64478 .55882 L
.63725 .57246 L
.63312 .57843 L
.61765 .59571 L
.61506 .59804 L
.59804 .61026 L
.5836 .61765 L
.57843 .61963 L
.55882 .62528 L
.53922 .6279 L
.51961 .62787 L
.5 .6254 L
.48039 .62049 L
.47187 .61765 L
.46078 .61304 L
.44118 .60266 L
.43406 .59804 L
.42157 .58857 L
.4106 .57843 L
.40196 .56891 L
.39435 .55882 L
.383 .53922 L
.38235 .53793 L
.37538 .51961 L
.37082 .5 L
.36892 .48039 L
.36946 .46078 L
Mistroke
.37239 .44118 L
.3778 .42157 L
.38235 .40965 L
.38604 .40196 L
.39782 .38235 L
.40196 .37682 L
.41474 .36275 L
.42157 .35668 L
.44118 .34337 L
.44158 .34314 L
.46078 .33481 L
Mfstroke
.28593 .9902 m
.29613 .97059 L
.30392 .95127 L
.30401 .95098 L
.30909 .93137 L
.31223 .91176 L
.31327 .89216 L
.31211 .87255 L
.30864 .85294 L
.30392 .83653 L
.30265 .83333 L
.29317 .81373 L
.28431 .80002 L
.27971 .79412 L
.26471 .77883 L
.25962 .77451 L
.2451 .76509 L
.22549 .7556 L
.22418 .7549 L
.20588 .7507 L
.18627 .74873 L
.16667 .74971 L
.14706 .75348 L
.14142 .7549 L
.12745 .76082 L
.10784 .77166 L
.10334 .77451 L
.08824 .78688 L
.08054 .79412 L
.06863 .80775 L
.06407 .81373 L
.05149 .83333 L
.04902 .83782 L
.04205 .85294 L
.03488 .87255 L
.02984 .89216 L
.02941 .89436 L
.02697 .91176 L
.02632 .93137 L
.02799 .95098 L
.02941 .96108 L
.03222 .97059 L
.03931 .9902 L
s
.0098 .80727 m
.01344 .79412 L
.01928 .77451 L
.02439 .7549 L
.02757 .73529 L
.02791 .71569 L
.02558 .69608 L
.02198 .67647 L
.0186 .65686 L
.01625 .63725 L
.01522 .61765 L
.01553 .59804 L
.01712 .57843 L
.01992 .55882 L
.02381 .53922 L
.02867 .51961 L
.02941 .51688 L
.03437 .5 L
.04076 .48039 L
.04767 .46078 L
.04902 .45708 L
.05493 .44118 L
.06235 .42157 L
.06863 .40505 L
.0698 .40196 L
.07714 .38235 L
.08429 .36275 L
.08824 .35169 L
.09124 .34314 L
.09801 .32353 L
.10467 .30392 L
.10784 .29453 L
.11132 .28431 L
.11813 .26471 L
.12528 .2451 L
.12745 .23939 L
.133 .22549 L
.14157 .20588 L
.14706 .19453 L
.15134 .18627 L
.16278 .16667 L
.16667 .16071 L
.1765 .14706 L
.18627 .13523 L
.19349 .12745 L
.20588 .11574 L
.21553 .10784 L
.22549 .10069 L
.2451 .0891 L
.24679 .08824 L
Mistroke
.26471 .08033 L
.28431 .07391 L
.30392 .06951 L
.30797 .06863 L
.32353 .06689 L
.34314 .06586 L
.36275 .06624 L
.38235 .06792 L
.38875 .06863 L
.40196 .07078 L
.42157 .07474 L
.44118 .07973 L
.46078 .08571 L
.46828 .08824 L
.48039 .09265 L
.5 .10054 L
.51636 .10784 L
.51961 .10938 L
.53922 .11923 L
.55422 .12745 L
.55882 .13012 L
.57843 .14213 L
.58597 .14706 L
.59804 .15537 L
.6134 .16667 L
.61765 .16996 L
.63725 .18606 L
.6375 .18627 L
.65686 .20391 L
.65891 .20588 L
.67647 .22378 L
.67806 .22549 L
.69527 .2451 L
.69608 .24607 L
.71078 .26471 L
.71569 .27136 L
.72477 .28431 L
.73529 .30054 L
.73738 .30392 L
.74871 .32353 L
.7549 .33523 L
.75885 .34314 L
.76786 .36275 L
.77451 .37902 L
.77578 .38235 L
.78264 .40196 L
.78846 .42157 L
.79325 .44118 L
.79412 .44514 L
.797 .46078 L
Mistroke
.7997 .48039 L
.80133 .5 L
.80185 .51961 L
.80122 .53922 L
.79937 .55882 L
.79624 .57843 L
.79412 .58854 L
.79171 .59804 L
.78565 .61765 L
.77791 .63725 L
.77451 .64466 L
.76824 .65686 L
.75632 .67647 L
.7549 .67856 L
.74167 .69608 L
.73529 .70347 L
.72354 .71569 L
.71569 .72297 L
.70064 .73529 L
.69608 .73865 L
.67647 .75144 L
.67042 .7549 L
.65686 .76189 L
.63725 .77041 L
.62611 .77451 L
.61765 .77728 L
.59804 .78274 L
.57843 .78698 L
.55882 .79019 L
.53922 .79251 L
.51961 .79412 L
.5196 .79412 L
.5 .79516 L
.48039 .79581 L
.46078 .79631 L
.44118 .79701 L
.42157 .79855 L
.40196 .80249 L
.38245 .81373 L
.38235 .81386 L
.37021 .83333 L
.36535 .85294 L
.36275 .86952 L
.36219 .87255 L
.35836 .89216 L
.35392 .91176 L
.34867 .93137 L
.34314 .95008 L
.34278 .95098 L
.33431 .97059 L
Mistroke
.32485 .9902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo@P00
00000ol0000000000000001X000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo<P00000F01TI6FD000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool_000001d06ATIH@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooob`000008`0I6AT00`00003o00000000001K000000Cooooo00<0
0000ooooooooool0Roooool2o`0004;ooooo0009ooooo`0400000?ooooooooooooooobT0000000?o
00000000000I6AT09@0I6AUL000000Cooooo00<00000ooooooooool0R?ooool3o`000003ooooool0
003ooooo047ooooo0009ooooo`0400000?ooooooooooooooobP00000;@0I6AUH000000Cooooo00<0
0000ooooooooool0Q_ooool2o`0000?ooooo00?oZkgWo`000?l00000@Oooool000Wooooo00@00000
oooooooooooooooo9`00000_01TI6EL000001?ooool00`00003oooooooooo`23ooooo`?o00000_oo
ool4oj^mi`03o`000?oooooo0000043ooooo0009ooooo`0400000?ooooooooooooooobD00000=00I
6AT00ol0000000000000001A000000Cooooo00<00000ooooooooool0P?ooool3o`0000;ooooo1on[
_NL00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooooooooolS000003T06ATID@00
0004ooooo`0300000?oooooooooo07kooooo0_l00003ooooo`WoZkgW00Co0000oj^miooooooo0000
?oooool000Wooooo00@00000oooooooooooooooo8P00000k01TI6E0000001?ooool00`00003ooooo
ooooo`1kooooo`?o00000_ooool00on/_NOoZkgWoj^mi`09oj^mi`05o`000?n[_NOoooooooooool0
0000?_ooool000Wooooo00@00000oooooooooooooooo8@00000o01TI6@03o`0000000000000004X0
00001?ooool00`00003oooooooooo`1iooooo`;o00000oooool01?n/_NKo[;gWojbmion/_NL2oj^m
i`03ojbmion[_NOoZkgW00GoZkgW00Go0000oj^mion[_NOoooooo`00000nooooo`002Oooool01000
003ooooooooooooooolQ000004006ATIC0000004ooooo`0300000?oooooooooo07Kooooo0ol00004
ooooo`?o[;gV1_n/_NL6oj^mi`06o`000?n[_NOoZkgWoj^miooooooo0000?Oooool000Wooooo00@0
0000oooooooooooooooo8000001301TI6DX000001?ooool00`00003oooooooooo`1dooooo`;o0000
1Oooool5ojbmiPOo[;gW1On[_NL00ol0003oZkgWoj^mi`02oj^mi`03o`000?oooooooooo03_ooooo
0009ooooo`0400000?oooooooooooooooal00000A@0I6AU9000000Cooooo00<00000ooooooooool0
LOooool3o`0000Cooooo2On/_NH2ojbmi`03ojbmi_n/_NOo[;gW00;o[;gW00GoZkgWojbmion[_NOo
ZkgWo`000004oj^mi`03ooooool0003ooooo03_ooooo0009ooooo`0400000?oooooooooooooooah0
0000B00I6AU7000000Cooooo00<00000ooooooooool0K_ooool3o`0000Gooooo3on/_NH6ojbmi`03
oj^miol0003oZkgW00CoZkgW00?oooooo`000?ooool0>_ooool000Wooooo00@00000oooooooooooo
oooo7@00001;01TI6DD000001?ooool00`00003oooooooooo`1/ooooo`;o00001OoooolBojbmiPOo
[;gW00?oZkgWo`000?n[_NL01?n[_NL00ol0003oooooooooo`0iooooo`002Oooool01000003ooooo
oooooooooolL000004h06ATI@`000004ooooo`0300000?oooooooooo06Wooooo0ol00005ooooo`03
ojfmi_n/_NKo[;gV01;o[;gV1on/_NL00ol0003oZkgWoj^mi`02oj^mi`03oj^niooooooo000003[o
oooo0009ooooo`0400000?oooooooooooooooa/0000000?o000001TI6@0I6AT0C@0I6AT00ol00000
00000000000o000000Cooooo00<00000ooooooooool0Ioooool2o`0000Gooooo00?o[KgUojfmi_n]
_NH00_n]_NH2ojbmiP;o[KgV00?o[;gVojfmi_n]_NH03?n/_NH7ojbmi`04o`000?n[_NOo[;kWojbn
i`?oZkkW00?oooooo`000?ooool0>?ooool000Wooooo00@00000oooooooooooooooo7000001?01TI
6D8000001?ooool00`00003oooooooooo`1Tooooo`?o00001Oooool4ojfmi@;o[KgV00Go[KgUojfm
i_n]_NKo[KgVojfmi@04ojfmiP03ojbmi_n]_NKo[KgV00Wo[;gV0_n/_NL2ojbmiP;o[;gW00?o0000
ojbnion/_^L00_n/_^L2oj^ni`03ooooool0003ooooo03Sooooo0009ooooo`0400000?oooooooooo
oooooa/00000DP0I6AU0000000Cooooo00<00000ooooooooool0H_ooool2o`0000Gooooo00?o[KcU
ojfmiOn]_ND02?n]_ND01?n]_NKo[KgUojfmiOn]_ND7ojfmiP03ojbmi_n]_NKo[;gV00Wo[;gV0_n/
_^L00ol0003o[;kWojbni`02ojbni`?oZkkW00?oooooo`000?ooool0=oooool000Wooooo00@00000
oooooooooooooooo6`00001C01TI6Cl000001?ooool00`00003oooooooooo`1Oooooo`?o00001Ooo
ool4ojfli@;o[KgU00?o[KcUojfmiOn]_ND02?n]_ND:ojfmiP[o[;gV00?o[;kWo`000?n/_^L01?n/
_^L3oj^ni`03ooooool0003ooooo03Kooooo0009ooooo`0400000?oooooooooooooooaX00000E@0I
6ATn000000Cooooo00<00000ooooooooool0GOooool2o`0000Gooooo0_n]_>@9ojfli@[o[KgU0_n]
_NH00on]_NGo[KgVojfmiP05ojfmiP[o[;gV00?o0000ojbnion/_^L00on/_^L4oj^ni`03o`000?oo
oooooooo03Gooooo0009ooooo`0400000?oooooooooooooooaP0000000?o000001TI6@0I6AT0E@0I
6ATm000000Cooooo00<00000ooooooooool0F_ooool3o`0000Gooooo1On]_>@00on]_>Go[KcTojfl
i@06ojfli@go[KgU1on]_NH00on/_NKo[KgVojfmiP02ojbmiP07ojfmi_n/_NKo[;gVojbmi_l0003o
[;kWojbniP04ojbni`;oZkkW00?o[;kWooooool00000=_ooool000Wooooo00@00000oooooooooooo
oooo6@00001H01TI6C`000001?ooool00`00003oooooooooo`1Gooooo`?o00001Oooool2ojfki0Wo
[KcT0_n]_>D00on^_>Co[KcUojfli@02ojfli@Go[KgU00?o[[gUojfmiOn]_ND01On]_ND=ojfmiP;o
[;gV00Co0000ojbni_n/_^Ko[;kV1on/_^L00ooooooo0000ooooo`0dooooo`002Oooool01000003o
oooooooooooooolH000005X06ATI00?o0000000000000000>0000004ooooo`0300000?oooooooooo
05Gooooo0_l00006ooooo`Go[K_T1on]_>@5ojjli0;o[KcU0_n^_>@00on]_NGo[[cTojjli003ojjm
i@;o[KgU00?o[[gUojfmiOn]_ND00_n]_ND00on]_NKo[KgUojfmi@02ojfmiP03ojfmiOn]_NKo[KgV
00Co[KgV0_n/_NH00ol0003o[;gVojbniP02ojbniPOo[;kW00?o0000ooooooooool0<oooool000Wo
oooo00@00000oooooooooooooooo6000001K01TI6CX000001?ooool00`00003oooooooooo`1Boooo
o`?o00001Oooool8ojfki0Go[KcT3on^_>@00on^_NGo[[gTojjmi003ojjmi@;o[KgU0_n^_ND00on]
_NGo[[gUojjmi@03ojfmi@Ko[KgV00?o[;gVo`000?n]_NH01?n/_^H6ojbni`03ooooool0003ooooo
03?ooooo0009ooooo`0400000?oooooooooooooooaL00000G@0I6ATi000000Cooooo00<00000oooo
ooooool0D?ooool2o`0000Kooooo2on]^n@00on]_>Co[[_Tojjki00@ojjli0Co[[gT2_n^_ND2ojfm
i@Oo[KgV00?o0000ojfmi_n]_NH01?n/_^H00on/_^Oo[;kVojbni`03ojbni`03o`000?oooooooooo
03;ooooo0009ooooo`0400000?oooooooooooooooaL00000GP0I6ATh000000Cooooo00<00000oooo
ooooool0COooool3o`0000Oooooo2on]^n@00on^^n?o[[_Tojjki002ojjki003ojjli?n^^nCo[[_T
00go[[cT0_n^_N@00on^_>Co[[gUojjmi@08ojjmi@?o[KgU0_n]_NH01On]_NGo[KgVojfmi_n]_NKo
000000?o[KgV0_n/_^H01?n]_^Ko[;kVojbni_n/_^H3ojbni`03ooooool0003ooooo03;ooooo0009
ooooo`0400000?oooooooooooooooaH00000H00I6ATg000000Cooooo00<00000ooooooooool0Booo
ool2o`0000Sooooo1?n]^n@2ojfkh`Go[K_T1?n^^n<2ojjki003ojjkhon^^nCo[[_T00;o[[_T00?o
[[cTojjkhon^^n<00_n^_>@00on^_>?o[[cTojjli008ojjli006ojjmiOn^_NCo[[gTojjmi?n^_NGo
[[gT1?n^_ND00on]_NGo[[gUojjmi@03ojfmi@;o[KgV00Co0000ojfmi_n]_NKo[KgV1?n]_^H3ojbn
iP?o[;kW00?oooooo`000?ooool0<Oooool000Wooooo00@00000oooooooooooooooo5P00001Q01TI
6CH000001?ooool00`00003oooooooooo`18ooooo`?o00002?ooool2ojbji0;o[K_T00?o[K[Sojfk
hon]^n<00_n]^n<00on]^nCo[K[Sojfjh`09ojjkh`;o[[_T0on^^n<2ojnkh`?o[[cS0_n^_>@00on_
_>?o[[cTojjli003ojjli0;o[kcT0_n^_N@01?n__>Co[[gTojjmi?n^_N@7ojjmi@06ojfmiOn^_NGo
[[gUojfmi_l0003o[KgU0on]_NH3ojfniPCo[;kV0_n/_^L00ooooooo0000ooooo`0aooooo`002Ooo
ool01000003ooooooooooooooolE000006<06ATI=@000004ooooo`0300000?oooooooooo04Gooooo
0ol00009ooooo`?o[;[T1On]^^<2ojfkh`Go[K[S00?o[[_Sojjjhon^^n<02?n^^n<5ojnkh`03ojjl
hon_^n?o[kcS00?o[kcS00Ko[[cTojnlhon__>?o[kcSojnli?n__><4ojnli003ojjmi?n__NCo[kgT
00Wo[[gU00Go[KgUo`000?n]_NGo[KgUojfmiP05ojfniP?o[;kV0on/_^L00ooooooo0000ooooo`0`
ooooo`002Oooool01000003ooooooooooooooolD00000003o`00000I6AT06ATI06806ATI00?o0000
000000000000<@000004ooooo`0300000?oooooooooo04?ooooo0_l00009ooooo`Co[;[T0_n/^^<;
ojfjh`Co[[[S0_n^^n<2ojjjhP;o[[_S00?o[k[Rojnkhon_^n<00on_^n<01?n_^n;o[k_Sojnkhon_
^n<2ojnlh`03ojnkhon__>?o[kcS00Go[kcS0_n__>@00on__>?o[kgTojnmi002ojnmi003ojjmiOn_
_NCo[kgT00Ko[[gU00?o0000ojfmiOn^_ND01on]_^H3ojbniP05ojbnion/_^Ko[;kVooooool00000
<?ooool000Wooooo00@00000oooooooooooooooo5@00001T01TI6C@000001?ooool00`00003ooooo
ooooo`10ooooo`?o00002Oooool4ojbji0Go[;[S2?n]^^<5ojjjh`Go[[[R1?n_^^800on_^n?o[k[R
ojnjhP03ojnkhP03ojnkhon_^n;o[k_R00?o[k_S1On__><2ok2lh`?o[kcS1_n__N@6ojjmi@04o`00
0?n^_NGo[[gUojjmi@[o[KkV0_n/_^H00ooooooo0000ooooo`0_ooooo`002Oooool01000003ooooo
oooooooooolE000006D06ATI<`000004ooooo`0300000?oooooooooo03kooooo0_l0000:ooooo`;o
Zk[T0on/^^@6ojbjh`Go[K[S00Co[KWRojfjhon]^^?o[K[S0_n^^^<8ojjjhPOo[k[R00?o[k_Rojnj
h_n_^n800on_^n800on_^n?o/;_Rok2khP02ojnlh`03ok2kh_n`_>?o/;cS00;o/;cS00?o[kcSok2l
hon__N@01_n__N@2ojjmi@04ojnmi?n^_NGo[[gUo`0000?o[[gU0on]_^H00on^_^Go[KkVojfniP04
ojfniP?o[;kV00?oooooo`000?ooool0;_ooool000Wooooo00@00000oooooooooooooooo5000001W
01TI6C8000001?ooool00`00003oooooooooo`0kooooo`?o00002Oooool5oj^ji0Co[;[T00?o[;[S
ojbihon/^N<00on/^^<00on]^^?o[KWRojfihP03ojfihP03ojfjhon^^N;o[[WR00Go[[[R0_n^^N80
0on^^^;o[kWQojnih@05ojnjhP04ojnjhOn_^^;o[k[RojnjhP;o[k_R2?n`^n82ok2lh`04ok2lh_n`
_>?o/;cSok2lh`;o[kgT0_n`_N<00on__NCo/;gTok2mi003ojnmi003ojjmiOl0003o[kgU00?o[[gU
00Co[KkVojjniOn^_^Go[[kU1_n]_^H3ojbniP03ooooool0003ooooo02gooooo0009ooooo`040000
0?oooooooooooooooa@00000J00I6AT00ol0000000000000000^000000Cooooo00<00000oooooooo
ool0>Oooool2o`0000Sooooo1_n[^^@01?n[^NCoZk[Toj^ji?n[^^@2ojbji0Go[;WS00?o[;[Sojbi
hon]^N801On]^N84ojjihP05ojjjh_n^^N7o[[WQojjihOn^^N801On_^N400on_^^;o[kWQojnjh@03
ojnjh@03ojnjh_n`^^7o/;[Q00Wo/;_R1?n`_>84ok2lh`03ok2mhon`_>?o/;gT00?o/;gT0_n__N@0
1?n__NGo0000ojnmiOn__ND3ojjmi@?o[[kU1_n]_^H4ojbniP03o`000?oooooooooo02cooooo0009
ooooo`0400000?oooooooooooooooa@00000J@0I6AT`000000Cooooo00<00000ooooooooool0=_oo
ool3o`0000Oooooo0_nZ^^D4oj^ji0GoZkWT00?oZk[Toj^ihon[^N<02On/^N<6ojfihP;o[[WR1?n^
^N400on^^>7o[kWQojnih@03ojnih@04ojnih?n_^N7o[kWQojnih@;o[k[Q00?o/;WPok2jhOn`^^40
0_n`^^400on`^n;o/;[Qok2jh@02ok2khP04ok6khOn`^n;o/;_Rok2khP;o/;cR0_na_>82ok2lh`04
ok6lh_n`_>?o/;cSok2lh`;o/;gT00Ko/;gSojnmi?n__NCo[kgTo`000?n__ND2ojnmi003ojjmiOn_
_^Go[[kU00?o[[kU00?o[KkVojjni_n^_^H00on]_^H2ojbniP;o[KkV00?o0000ooooooooool0:ooo
ool000Wooooo00@00000oooooooooooooooo4`00001Z01TI6C0000001?ooool00`00003ooooooooo
o`0cooooo`?o00002?ooool5ojZji@03oj^ji?nZ^NCoZkWT00KoZkWT0on[^N<7ojbih`;o[;SR1?n]
^N82ojfhh@?o[[WQ1?n^^>400on_^N7o[kSPojnhh003ojnih003ojnihOn`^N3o/;WP00?o/;WP0_n`
^^42ok2jh003ok2jhOna^^3o/K[P00?o/K_Q00?o/;_Rok6khOna^n401ona_>800on`_>?o/KcRok2m
h`03ok2mh`03ojnmi?n`_NCo000000?o[kgT0on__^D3ojjni@Co[[kV1_n]_^H00ol0003ooooooooo
o`0[ooooo`002Oooool01000003ooooooooooooooolC000006/06ATI;`000004ooooo`0300000?oo
oooooooo037ooooo0_l00009ooooo`03ojVjiOnZ^^GoZ[[U00?oZ[[U1?nZ^N@7oj^ii0;oZkWS1On/
^N<5ojbhhP03ojfih_n]^>7o[KSQ00?o[KSQ00?o[[WQojjhhOn^^>400_n^^>400on^^>3o[kSPojnh
h002ojnhh003ojnih?n`^=oo/;WP00Co/;WP0_n`^Ml2ok2jh003ok6igona^^3o/K[P00;o/K[P00?o
/K_Qok6jh?na^n400ona^n400ona_>;o/KcQok6lh@06ok6lhP;o/;gS0_na_N<00on`_NCo/;gSo`00
0003ojnmi0?o[kkU0on^_^D2ojjniP;o[[kU1_n]_^H00ol0003oooooooooo`0Zooooo`002Oooool0
1000003ooooooooooooooolC000006/06ATI;`000004ooooo`0300000?oooooooooo02kooooo0ol0
0008ooooo`GoZK[U00?oZ[[UojViiOnY^ND01_nZ^N@5oj^ii0CoZkWS0_n/^N<6ojbhhP03ojbhhOn]
^>7o[KSQ00Go[KSQ0_n^^>401?n^]n3o[[SPojjhh?n^^>02ojnhh004ojnhgon`^=oo/;SOok2hg`;o
/;WP00Co/;SOok2igon`^Moo/;WO1?na^Ml2ok6jh004ok:jgona^^3o/K[Pok6jh0;o/K_Q0_nb^n00
0ona_>7o/[_Qok6lhP07ok6lhP;o/KgS0_n`_N<01?l0003o/;gSojnmi?n`_^@4ojnni@03ojjniOn_
_^Go[kkU00?o[[kU1_n]_^H00ooooooo0000ooooo`0Zooooo`002Oooool01000003ooooooooooooo
oolB000006d06ATI;P000004ooooo`0300000?oooooooooo02cooooo0_l00009ooooo`KoZK[U1OnY
^ND6ojZii003oj^ii?nZ^NCoZ[WT00CoZkWS0_n[^><7ojbhhP;o[;SQ00Go[KSQojfghOn]]n7o[KOQ
ojfhh@02ojfgh0?o[[OP00?o[[SPojnggon_]ml00on_^=l6ok2hg`03ok2igona^Moo/KWO00;o/KWO
00?o/[WNok:jgonb^]l00_nb^]l00ona^^3o/[[Ook:jg`03ok:kh0?o/[_Q0_na_>801Onb_>7o/KcR
ok6lh_na_>;o/[gR00?o/KgS00?o/;gSo`000?na_N<00on`_^@2ojnni@;o[kkT0_n__^D4ojjni@03
ojfni_n^_^Ko[[kV00?o[KkV00?o0000ooooooooool0:Oooool000Wooooo00@00000oooooooooooo
oooo4P00001^01TI6@03o`0000000000000002X000001?ooool00`00003oooooooooo`0Yooooo`?o
00002Oooool00onX^^KoZK[UojVji@04ojVji@KoZKWU2_nZ^N@00on[^N?oZkSSoj^hh`03oj^hh`03
ojbhh_n[]n;oZkOR00;o[;SR1On/]n400on]]n7o[KKPojfgh003ojfgh003ojjgh?n^]]oo[kOO00?o
[kOO00?o[kSOok2gg_n`^=l01?n`^=l2ok6hgP;o/KWO00Co/[SNok:ig_nb^Mko/[WN0_nb^]l01Onb
^Moo/[[Ook:jgonb^]oo/k[O00?o/[_P00?o/[_Qok>kh?nc^n000onb_>402?na_>;o/[gRok:mh_nb
_N;o/KgSok:mh_na_N?o00000_na_N<3ok2ni0;o[kkT00Co/;kTojnniOn__^Go[kkU1?n^_^D2ojjn
iPCo[KkV00?o0000ooooooooool0:?ooool000Wooooo00@00000oooooooooooooooo4@00001`01TI
6B`000001?ooool00`00003oooooooooo`0Wooooo`;o00002_ooool4ojRjiP;oZK[U0_nX^^D2ojVj
i@KoZKWU0_nZ^N@2ojVii0CoZ[WT0_nZ^><4oj^hh`?oZkOR0_n[]n45ojbgh@04ojbfh?n]]^3o[KKP
ojffh0;o[KOP1?n^]]l2ojngg`04ojnfg_n`]mko/;ONok2ggP;o/;SO00Go/;ONok6hg_na^=ko/KSN
ok6gg@03ok:hgP?o/[WN0onb^Ml01_nb^]oo/k[Ook>jgonc^]oo/[_Pok>kg`Co/k_P00?o/[cQok>l
hOnc_>400_nb_N801_nc_N7o/[gRok:mh_nb_N;o0000ok6mh`;o/KkS00?o/;kTok6ni?n`_^@00on`
_^@3ojnni@;o[[kU00Co[kkUojjni_n^_^Ko[[kV0on]_^H00ooooooo0000ooooo`0Xooooo`002Ooo
ool01000003ooooooooooooooolA000007006ATI;0000004ooooo`0300000?oooooooooo02Cooooo
0ol00007ooooo`;oYk[V2OnX^^H00onX^^GoZ;WVojRiiP09ojVii@03ojVii?nY^>CoZKST00?oZ[ST
0onZ^><3ojZgh`?oZkOR0on[]n400on/]n7o[;KPojbfh003ojbfh003ojffh?n]]]oo[KKO00Co[[KO
0_n^]]h3ojnfgP03ok2gg_n`]]go/;KM00?o/;ON00Ko/KSNok6ggOna]mgo/KOMok:hg_nb^=d4ok:i
gP03ok:igonc^Mko/kWN00;o/k[O00Co];[Nok>kgonc^moo/k_O0_nc^n02ok>lh003ok>lhOnc_>3o
/kgQ00?o/kgQ0_nb_N801?l0003o/KkSok6nhonb_^<3ok6ni0Co/;kT00?o[kkUok2niOn__^D00on_
_^D2ojjniPCo[KkV00?o0000ooooooooool09oooool000Wooooo00@00000oooooooooooooooo4000
001b01TI6B/000001?ooool00`00003oooooooooo`0Rooooo`;o00002?ooool5ojNjiP03ojRji_nW
^^KoZ;[V00GoZ;[V1?nX^NH00onY^NGoZ;WUojVii@05ojVii@CoZKST00?oZ[STojVhi?nZ^><00onZ
^><00onZ]n?oZ[ORoj^ghP03oj^ghP03oj^ghOn[]^7o[;KP00Co[;KP00?o[;GOojffgon]]]l00_n]
]]l00on^]]oo[[GNojjfgP03ojjfgP03ojnfg_n_]]go/;KM00?o/;KM00?o/;ONok6fgOna]]d00_na
]md01?nb]mgo/[SMok:hgOnb^=d2ok:igP04ok>igOnc^Mko/kWNok>igPCo];[N00?o/k_OokBkgonc
_>000_nc_>001?nd_=oo/kcPok>lh?nc_>04ok>mh@03ok:mh_l0003o/kkR00?o/[kS00?o/KkTok6n
hona_^<00_n`_^@01?na_^Co/;kUok2niOn`_^D3ojnni@?o[[kV1?n]_^H00ol0003oooooooooo`0V
ooooo`002Oooool01000003oooooooooooooool@000007<06ATI:P000004ooooo`0300000?oooooo
oooo01oooooo0ol00008ooooo`03ojNjionW^^KoYk[V00OoYk[V1_nX^^H3ojRiiP?oZ;WU0_nY^ND0
1?nX^NGoZKWUojViiOnY^ND6ojVhi0;oZ[SS00CoZKOSojZgh_nZ]n;oZ[OR0_n[]n801?nZ]^7oZkKQ
oj^fhOn[]^42ojbfh004oj^eh?n/]Moo[;GOojbeg`;o[KKO00Co[KCNojjeg_n^]Mko[[GN0_n^]]h0
1?n_]Mgo[kKMojnfgOn_]]d3ok2fg@?o/KKM00Ko/[KLok:ggOnb]mgo/[OMok:hgOnc^=`4ok>ig@03
ok>ig_nd^Mgo];WM00?o];[N0ond^ml01Onc_>3o];cOokBlgond_=oo/kcP00;o];gP0onc_N401?nc
_^;o0000ok>nh_nc_^82ok:nh`?o/KkS00Ko/[kSok6ni?na_^Co/KkTok2niOn`_nD4ojnni@?o[[kV
0on]_^H00ooooooo0000ooooo`0Vooooo`002Oooool01000003oooooooooooooool@000004806ATI
2`00000V01TI6BX000001?ooool00`00003oooooooooo`0Looooo`?o00002Oooool01OnV^^OoYk[W
ojNjionW^^OoYk[V00;oYk[W1_nW^^H6ojRjiP?oZ;WV1_nX^ND00onY^NGoZ;STojRhi004ojVhi0Go
ZKOS00?oZ[ORojVfh_nY]^800onZ]^400on[]^7oZkGPoj^eh003oj^eh003ojbegon/]=oo[;CO00?o
[KCN00?o[[GNojjdgOn^]=d00on_]Md00on_]]go/;GLok2eg003ok2fg@06ok6fgOnb]]co/[KLok:f
g?nb]mgo/kOL0onc^=`2ok>ig@;o];SL00?o];WMokFigOne^Md00ond^]h01_nd^moo]K_NokFkg_ne
^mko];cOokFlg`Co];gP00Co/kgQokBmhOnd_N7o00000_nc_^83ok:nh`06ok6nhonb_^?o/[kSok:n
hona_^Co/KoT0on`_nD2ojnni@;o[koU0_n^_^H4ojfniP03o`000?oooooooooo02Gooooo0009oooo
o`0400000?oooooooooooooooa000000?`0I6AT3000000/0<c<c0P00000U01TI6BT000001?ooool0
0`00003oooooooooo`0Jooooo`;o00001oooool7ojJji`KoYk[W00CoYk[VojNjionW^^OoYk[W0_nW
^^H01?nX^^KoYk[VojNji_nW^^H2ojRjiP?oZ;WV1?nX^ND00onX^>GoZ;STojRhi002ojRhi003ojVh
i?nX]nCoZKOS00CoZKOS1OnY]^800onZ]^7oZ[GQoj^eh004oj^eh003oj^dgon/]=oo[;CO00;o[;CO
00?o[KCNojfdgOn^]=d00on^]=d00on_]Mgo[kCLok2eg003ok2eg003ok2fgOna]Mco/KGL00;o/[KL
00Go/[KKok>gg?nc]mco/kOLok>hg005okBhg0Co]KWM00?o];[NokJkgOnf^md00_ne^mh01?nf_=ko
]KcOokFlgone_=l2okBmh0;o]KgP00?o];gQokFnhOl000000onc_^800onb_^?o/kkSok>nh`02ok:n
h`04ok:ohona_nCo/KoTok6oi0Co/;oU0_n__nD3ojjniP;o[KkV0_n^_^H00ol0003oooooooooo`0T
ooooo`002Oooool01000003oooooooooooooool?000003h06ATI0P00000@03<c<`8000008`0I6ATY
000000Cooooo00<00000ooooooooool05oooool3o`0000Oooooo2onV^^L00onW^^OoY[[WojNji`05
ojNji`KoYk[V0onW^NH3ojRiiP?oZ;WU0_nX^>D3ojRhi0?oZ;OT0_nY]n<00onX]^?oZKKRojVfhP03
ojVfhP04ojVehOnZ]N7oZ[GQojZeh@;oZkGP00CoZ[CPoj^dgon[]=ooZkCO0_n/]=l01?n//mko[KCM
ojfdgOn]]=d2ojjdg@04ojjcgOn_]=co[kCLojndg0;o/;GL00Co/;CLok6eg?na]Mco/KGL1?nb]]/0
0onc]mco/kOKokBhg004okBhg0;o]KWL0_ne^Md01?nf^]co][_MokJkgOnf^md4okJlgP03okFlgonf
_Moo][gO00;o]KgP00Co][kPokFnhOl0003o00000_nc_^82okBnhP03ok>nhonc_n?o/[oS00?o/[oS
0ona_n@3ok2oi@?o[koU00?o[[kVojjoi_n^_nH00on^_^H00ooooooo0000ooooo`0Tooooo`002Ooo
ool01000003oooooooooooooool?000003`06ATI0P00000D03<c<`8000008@0I6ATY000000Cooooo
00<00000ooooooooool05_ooool2o`0000Oooooo00?oYK[XojJjionV^^L03OnV^^L6ojNji`03ojNj
i_nW^^OoYk[W00?oYk[V1_nW^NH00onX^NGoYkSUojNhi@03ojNhi@;oZ;ST1?nX]n@2ojRfh`03ojVf
h_nX]N;oZ;GR00?oZKGQ00?oZ[GQojVdh?nY]>000onZ]>000on[]=ooZk?Noj^cgP03ojbcgP03ojfd
gOn]/mgo[K?M00?o[[?M00?o[kCLojncg?n`]=`00on`]=`00ona]Mco/KGKok6ef`02ok:ff`04ok>f
fonc]m_o/kOKok>gf`;o];SL0_ne^=/00one^Mco][WLokJig003okJjg0?o][_M0_nf_=h01Ong_=ko
][gOokJmgonf_Moo][kP00?o000000?o]KkQo`000?ne_^400_nd_^801?ne_n;o/koSok>ohonc_n<4
ok:oh`;o/KoT1?n`_nD3ojnoi@;o[[oV1?n^_^H00ol0003oooooooooo`0Sooooo`002Oooool01000
003oooooooooooooool>00000003o`00000I6AT06ATI03T06ATI00<0000003<c<`0c<c<05P0c<c<0
0`0000006ATI01TI6@0N01TI6BT000001?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooo
000000Cooooo1?nU^^P2ojJji`;oYK[X2onV^^L9ojNji`03ojNji_nW^NKoYkWV00GoYkWV1OnW^>D0
0onW]nGoYkOTojNgi002ojNgi003ojRgi?nW]^?oZ;KS00;oZ;KS0onX]N800onY]N7oZ;CQojVdh003
ojVdh003ojZdh?nZ/mooZk?N00?oZk?N00?o[;?NojbbgOn]/md00on]/md00on^/mgo[[?Lojncg002
ojncg0;o/;CL0_na]=/00ona]M_o/[GKok:ef`03ok>ff`03ok>gfond]m_o];OK00?o]KSK1?nf^M`0
1?nf^]co]k[LokNjg?nf^md2okNlg@?o]kcN0ol00002okJnh004okNnh?ne_^7o]KkQo`0000Co]KoR
00?o/koSokBohond_n<00_nb_n<01?nc`>Co/KoTok6oi?na_n@4ok2oi@03ojnoiOn__nKo[[oV00;o
[[oV0_n^_^H2ojjoiP03o`000?oooooooooo02;ooooo0009ooooo`0400000?ooooooooooooooo`l0
0000>@0I6AT2000001X0<c<c0`00000N01TI6BP000001?ooool00`00003oooooooooo`0Fooooo`03
o`000?oooooooooo00goYK[X0onV^^P8ojJji`04ojNjionV^^OoY[[WojJji`CoYk[W2OnW^NH3ojNh
i@?oYkOU0_nW]n@01OnW]^CoYkKSojNfhonW]^?oZ;KS00;oYkCS0onX]>82ojRdh@;oZKCP00CoZK?P
ojZcgonZ/mooZ[?O0_n[/mh01?n[/]ko[;;MojbbgOn//]d2ojfcg@05ojfbg?n^/mco[[?Lojjcg?n_
/m`00_n`/m/3ok6df`Co/[GK00?o/kKKokBff_nd]m/00ond]m/00one^=_o][SKokJhf`02okJig004
okNifong^]co]k[LokNjg0?o]kcM0ol000001?nh_Mko]kgOokRngonh_]l3okNnh003okFnhOnf_n7o
000000;o]KoR0_ne`>800ond_n?o]<3Sok?0i003ok?0i003ok6oi?nb`>Co//3T00;o/;oU00Co/L3U
ojnoi_n__nKo[koV1_n^_nH00ol0003oooooooooo`0Rooooo`002Oooool01000003ooooooooooooo
ool>000003T06ATI00<0000003<c<`0c<c<07@0c<c<00ol000006ATI01TI6@0L01TI6BL000001?oo
ool00`00003oooooooooo`0Fooooo`03o`000?nU^^SoYK[X00koYK[X00?oY[[XojFjj?nV^^P00onV
^^P00onV^^OoY[[XojJji`08ojJji`;oYk[W0_nW^NH2ojJii`?oYkWV0_nV^>H3ojNhi@03ojNgiOnV
]nGoY[OU00?oYkKT00?oYkKSojJehonV]N<00onW]><00onX]>;oYk?RojRch@03ojRch@;oZK?P00?o
Z[?OojVbgonY/]l00on[/]h2ojbbg@Co[K;L00?o[[?Lojjbfon`/m/00on`/m/3ok6df`;o/[GK00Co
/kGJokBff_nd]][o];KJ0_nd]m/2okFgfP03okJhfong^M_o]kWK00?o]kWK00?o]k[LokRkg?l00000
0_l000001?nh_=go^;gNokRmg_nh_Mh4okRng`06okNnh?ng_n3o]koPokJohOng`>7o00000one`>83
okC0h`Co/l3T00?o//3Tok;0iOna`>D00ona`>D3ojnoiPKo[[oV00?o0000ooooooooool08Oooool0
00Wooooo00@00000oooooooooooooooo3P00000i01TI6@030000000c<c<0<c<c01h0<c<c00<00000
01TI6@0I6AT06`0I6ATW000000Cooooo00<00000ooooooooool05Oooool00ol0003oooooojFjj00B
ojFjj0KoY[[X00?oY[[WojJjj?nV^^P02OnV^^L2ojJii`CoY[WV0_nV^>H00onW^>GoY[OUojJgi@03
ojJgi@03ojNfi?nV]^CoY[GS00?oY[GS00?oYkCSojJdh_nW/n800_nW/n82ojRch@04ojNbhOnX/]oo
Z;;OojRbg`?oZK;O00?oZk;NojZbgOn//]d00_n//]d3ojfbg0?o[[;K1?n`/m/00ona]=_o/[CJok:d
fP03ok>efP;o];KJ0one]mX00onf^=[o]kWKokNif`03okNif`?o000000?o^;cLokRlgOnh_=d00_nh
_=d00onh_Mko^;kNokRngP02okRng`;o^;oO00Oo]koPokS0h?ng`>7o]l3Qo`000?ng`>7o]L3R00;o
]/3R00?o]<3SokC1hond`N<00_nc`>@01?nc`NCo//3Uok;0iOnb`>D4ok70i@03ojnoi_n_`>Ko[[oV
00Co[[oV0_n^_nL00ol0003oooooooooo`0Pooooo`002Oooool01000003oooooooooooooool>0000
03P06ATI00<0000003<c<`0c<c<07`0c<c<00`0000006ATI01TI6@0L01TI6BH000001?ooool00`00
003oooooooooo`0Eooooo`03o`000?oooooooooo01CoYK[X2?nV^^P00onV^^OoY[[XojJji`04ojJj
i`CoY[WW0_nV^NH01OnU^>KoY[SVojJhi_nV^>KoY[OU00;oYKOU0onU]^D2ojJfi0;oY[GS00GoYKCS
ojJdh_nV]>;oY[CRojNchP02ojJbh@?oYk;Q00?oZ;;OojNagonW/Ml00onY/Mh2ojZbg@03ojbbgOn[
/McoZk7L00?o[K;L1?n^/]/2ok2cf`Co/[CJ0_nc]MX3okBffP05okFgf_nf^=[o][SJokJhf_ng^M/0
0ol00002okRjf`?o^;cL0_nh_=d2okVmg@03okRng_ni_mko^;oO00;o^;oO00Co^L3OokS0h?nh`>3o
^<3P0_ng`>400ol0003o]l7QokK0hP02okK1h`03okC1hone`NCo/l7T00?o/l7T00?o//3Uok;1iOnb
`ND00_na`>D01?na`>Ko[l3Vojo0i_n_`>H3ojjoiP;o[[oW00?o[KoWo`000?ooool08Oooool000Wo
oooo00@00000oooooooooooooooo3@00000h01TI6@030000000c<c<0<c<c0240<c<c00<0000001TI
6@0I6AT06`0I6AT00ol0000000000000000S000000Cooooo00<00000ooooooooool05Oooool01_l0
003oooooooooooooooooYK[XojBjj1GoYK[X1onV^^P4ojJji`?oY[WW0_nU^NL3ojFhiP03ojJhi_nU
]nKoYKOV00?oYKOU00?oYKKUojBfiOnU]N@00onU]N@2ojFdh`03ojJdh_nU/n;oYK?R00?oY[;Q00?o
Yk;QojJah?nW/Ml00onW/Ml00onY/MkoZ;7NojZag@02ojZag@?oZk7L0_n]/]`3ojjbf`04ojnbfon`
/m_o/;?Kok2cf`?o/[CJ0onc]MX01?nd]][o]KOJokFgf_nf^=X3o`0000?o]kWK00Co^;[KokRkfonh
^m_o^;cL0_ni_M`3okVmg@?o^KoN00Go^;oOokW0goni`=oo^L3OokS0h002okS1h@;o]l7Q00Co0000
okK1honf`N?o]/7S0one`N@4ok?1i0;o//7U1?na`>H3ojo0iP03ojjoi_n^_nOo[KoW00?o[KoW00?o
0000ooooooooool07oooool000Wooooo00@00000oooooooooooooooo3@00000g01TI6@03o`00000c
<c<0<c<c02<0<c<c00?o000001TI6@0I6AT06P0I6ATV000000Cooooo00<00000ooooooooool05Ooo
ool00ol0003oooooooooo`02ooooo`;oY;[X00CoYK[XojBjjOnT^^WoY;[Y4onU^^P00onV^^SoYK[X
ojFjj003ojFjj003ojJjionU^^SoYK[X00GoYKWW00?oYKSVojFhionU]nH00onU]nH00onU]nGoY;KU
ojBfi@02ojBfi@;oYKGT00CoY;CTojBchonT/n?oY;?S0onU/n800onV/^7oYK;QojJah002ojJah0?o
Yk7O0onX/Mh00onZ/MgoZK7MojVag@03oj^ag0;o[K;L00Go[[;Kojnbfon_/]_o[k;Kok2cf`02ok6c
f`?o/[CJ00?o/kGJokBff_ne]mX00ol000000onf^=[o]kWJokNifP02okNif`;o^;[K00?o^;_KokVl
g?ni_M`00oni_M`01?ni_Mgo^[kMokZngOni_mh3ok[0gP05okW0goni`N3o^L7PokS1hOni`^400ong
`^801Ol0003o]/7SokK2honf`^?o]L7T00?o]L;T00?o/l7Tok?2iOnb`ND00_nb`ND2ok70iP;o/<7V
0_n_`>H3ojjoi`Co[KoW00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooooooo
3@00000g01TI6@030000000c<c<0<c<c02@0<c<c00<0000001TI6@0I6AT06@0I6ATV000000Cooooo
00<00000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`GoY;[Y0onU^^TJojFjj0;oYKWW
1OnU^>L2ojFgiP;oY;OV0onT]^D2oj>ei@?oY;CT00?oY;?Soj>chonS/n<00_nT/^83ojFbh@03ojJa
h?nU/N3oYK7P00?oYk7O0_nX/Mh4ojVag@;oZk7L1?n]/]`00on_/]_o[k?Kok6cf`03ok6cf`03ok:d
f_nc]M[o];KJ00;o00000_ne]mX2okJhfP03okNif_nh^]_o^;[K00;o^;[K00Co^KcKokVlg?ni_=co
^KcL0_ni_M`3okZng@Co^/3N00Co^/7OokW1h?ni`N3o^L7P0oni`^42okO2hP03o`000?nh`^;o]/;S
00;o]/?S0_ne`^@01One`nCo/l;Uok?2iOnc`^Go//7U00;o//7V0on``NH3ojo0iP03ojjoion^`>Oo
[/3W00?o[KoW00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooooooo3000000g
01TI6@030000000c<c<0<c<c02H0<c<c00<0000001TI6@0I6AT06@0I6ATU000000Cooooo00<00000
ooooooooool05Oooool00ol0003oooooooooo`04ooooo`GoY;[Y00?oYK[YojBjjOnT^^T00onU^^T0
0onU^^SoYK_YojFkj@03ojFkj@ooYK[X00GoYKWXojFiionU^NOoYKWWojFhi`05ojBhi`03ojBgi_nS
]^KoXkKV00?oXkKV0_nS]ND00onT]>CoXk?Toj>ch`03oj>ch`;oY;;R00?oYK;QojBahOnU/N000onU
/N000onW/MooY[3OojRagP02ojRagP?oZK7M0on[/M`3ojfbg0?o[k?K0_na/m/01Ona]=_o0000o`00
0?l0003o];KJ00;o]KOJ0onf^=X4okRjf`?o^KcK00?o^KcLokZng?nj_]`00_nj_]d01?nk_mgo^/3N
ok[0g_nj`=h4ok[1g`04okW1h?nj`^7o^/;QokW2h@;o^L?R0_nh`^801?l0003o]/?SokK3honf`n<4
okG3i0?o/l;U00?o//7Vok;2i_n``NH00on``NH00on_`>Ko[l3Wojo0i`02ojk0i`Co[KoW00?o0000
ooooooooool07Oooool000Wooooo00@00000oooooooooooooooo2`00000g01TI6@030000000c<c<0
<c<c02P0<c<c00<0000001TI6@0I6AT06@0I6ATT000000Cooooo00<00000ooooooooool05?ooool0
0ol0003oooooooooo`06ooooo`?oY;[Y0onT^nT2ojBjj@03ojFjjOnU^nWoYK_Y00SoYK_Y0_nU^^P0
0onU^^WoYK[XojFjj007ojFjj0;oYKWX00CoYKWWojBij?nT^NSoY;WX0onT^>L00onS]nOoXkKVoj>f
iP03oj>fiP03oj:ei_nR]>GoX[CU00?oXk?T0_nS/n<01?nR/^CoXk;Soj>bhonS/^<2ojBah@;oYK7P
00GoYK7QojJ`gonV/=ooY[3OojRagP02ojN`gP?oZK7M00?oZk7Loj^agOn[/Md00on]/]`00on_/m_o
[k?Lo`000002o`000003ok6dfonc]M[o/kKK00Co]KOJ00Co][SJokNifong^M_o^;[K0oni^m/00oni
_=_o^[gLokZng002okZng0Co^koM00?o^/3Nok_1g_nk`Mh00_nj`Ml2ok_2h004ok[2hOnj`n7o^/?Q
okW3hP;o^LCR0_nh`n<01?l0003o]/?SokK3i?nf`n@2okG3i0;o]<?U00?o/l;Uok?3i_nb`^H00_nb
`^H4ok31iP;o[l3W0on^`>L4ojfoi`03o`000?oooooooooo01cooooo0009ooooo`0400000?oooooo
ooooooooo`X0000000?o000001TI6@0I6AT0=@0I6AT00ol00000<c<c03<c<`0X03<c<`030000000I
6AT06ATI01T06ATI90000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool01ooo
ool9ojBkj@[oYK_Y0onU^^T7ojFjj003ojBjj?nT^NSoY;WX00?oY;WX00CoXkSXoj>hionS^>OoXkSW
0_nS]nL00onS]^KoX[KWoj:fi`03oj:eiP;oX[CU00?oXk?Toj:ci?nR/n@00onR/^@00onS/^?oX[7S
oj>ahP03oj>ahP;oYK7Q00?oY[3OojF`h?nU/>000onW/=h00onY/MgoZK7Noj^ag@03oj^ag@05ojfb
g?l0003o0000o`000?n_/m`00_na]=/01?nb]M_o/kKKok>ffonc]]/2okFgfP;o][SK00?o]kWKokRj
foni^m/00_ni^m/01Oni_Mco^[gLokZmg?nj_Mco^[kL00Co^koM0onk`Mh2okc3g`;o^l;P00Co^lCQ
ok[3hOnj`n7o^/?Q1?nia>801?nh`n?o^<CTo`000?nf`n@2okK4i@?o]<?U0onc`nH00onb`^Ko/L;V
ok72iP02ok31iP04ok31ion_`>Oo[l3Wojo0i`?o[/3W0on]_nL00ol0003oooooooooo`0Looooo`00
2Oooool01000003oooooooooooooool;000003L06ATI00<0000003<c<`0c<c<0:@0c<c<00`000000
6ATI01TI6@0H01TI6B@000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo2onT^nT00onU^nWoY;_YojBkj@05ojFkj@?oYK[Y1?nU^^P4ojBjj003ojBij?nS^NSoXkWX00?o
XkSX00?oXkSWoj:gj?nR]nL00onR]nL2oj:fi`03oj:ei_nQ]>KoXKCU00?oXKCU0_nR/n@00onR/^Co
XK;Toj:ah`02oj:ah`;oXk7R00?oX[7RojB`hOnT/>401?nU/>000onW/=koYk7OojVagP02ojVagP04
oj^agOl0003o0000o`0000;o[K?L00?o[k?Lok2dg?n`]=`00onb]M/01_nc]]_o];OLokBgg?nd]mco
][SKokJjg0?o^;[K00Go^K_KokVmg?ni_Mco^KgLokZmg004ok^og@04okc1g_nk`Mko^l7Nok_1gP?o
_<?O00Go_<CQok_4hOnka>7o^lCQok[3h@02ok[5hP;o^LCR0_niaN<01Onha>Co0000okS5i?nfa>Go
]/GU00Co]<?U0onc`nH00ona`^Ko/L;Wok72i`03ok31i`05ojo0ion_`NOo[l7Wojk0ion]`>L01?n]
_nL00ol0003oooooooooo`0Kooooo`002Oooool01000003oooooooooooooool:000003L06ATI00<0
000003<c<`0c<c<0:`0c<c<00ol000006ATI01TI6@0H01TI6B<000001?ooool00`00003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Wooooo3_nT^nT00onU^nWoY;_YojBkj@02ojBkj@03ojFjjOnT
^^WoY;[Y00?oY;[Y00?oY;[XojBjjOnT^^T00onT^NP2oj>ij0;oXkSX0onR]nP2oj:gi`04oj6fionQ
]NOoXKGWoj6ei`;oXKCV0_nQ]>D01?nP/nKoX;;Uoj2biOnP/^D2oj6bi003oj:ahonQ/N?oXK7S00?o
X[7R0_nT/>43ojF`h0?oYk7O0ol00003oj^bg@03ojfcg?n]]=go/;CL00?o/;CL00?o/[GKok:gg?nd
]m`00_nd]m`01Ond^Mgo][[LokJjg?nf^]co^;[K00;o^;cL0_ni_M`01?nj_]go^koMok^ogOnk_md4
okc1gP04ok_1g_nl`moo_<?Ookc3g`?o_<CQ00Co^lCQok_5h_nkaN;o^/GR0_nja^<2okW5h`;o^LKT
00?o^<GTo`000?nfaND00_nfaND2okC3i@;o]<CV00?o/l?Vok;3ionb`nL00_na`^L5ojo1i`;o[/3W
0_n]`>L4ojfoi`03o`000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooo`X00000
=`0I6AT00`000000<c<c03<c<`0[03<c<`030000000I6AT06ATI01P06ATI8`000004ooooo`030000
0?oooooooooo01Cooooo00?o0000ooooooooool02_oooolDojBkj@SoY;[Y00?oY;WXoj>ijOnS^NP0
0_nS^NP2oj>hj003oj:gj?nQ]nSoXKOX00?oXKKW00?oXKGWoj2eionP]NL00onP]>H2oj2ciP03oj2b
iOnO/^GoX;7T00?oX;7T0_nQ/N<00onR/N;oXK7Soj>`hP03oj>`hP04ojF`h?l0003o0000o`0000Co
ZK;O00?oZk;Moj^cg_n]]=d00_n]]=d2ok2dg005ok2fgOnb]mco/[OLok:gg?nd]m`00ond^Md00onf
^]co]kcMokRlg002okRlg005okVng_nj_]go^[kMokZngOnk_md00_nk`Mh2okc1gP?o_<?O0_nlaN42
okc4h@;o_<KR00Go^lGRok_7honkan?o^/KSok[7i003okW6i005okW7iOnga^Go]lKUo`000?nfaND0
0_neaNH2okC4iP;o/lCV0_nb`nL3ok72i`Co[l7W0_n^`>L3ojg0i`;o[KoW00?o[;oWo`000?ooool0
6oooool000Wooooo00@00000oooooooooooooooo2P00000g01TI6@030000000c<c<0<c<c02/0<c<c
00<0000001TI6@0I6AT0600I6ATS000000Cooooo00<00000ooooooooool05?ooool00ol0003ooooo
ooooo`0;oooooa?oY;_Y1onT^^T2oj>jj@;oXkWY00?oXkWXoj:hj?nR^>P00onR^>P2oj6gj003oj6f
ionP]^SoX;GW00?oX;GW00CoX;CVoijdionO/nKoWk?V0onO/^D2oj2ai003oijaiOnP/NCoX;7T00?o
XK7S00CoXk3Ro`000?l0003o00000_nT/N42ojJah0;oZK;O00GoZ;;Poj^cg_n[/mkoZk?Nojfdg@02
ojfegP?o/;KM00?o/[OLok:hgOnb^=d00_nd^Md01One^mko]kcMokNlgOng_=go^;cL00?o^KkN00Co
^[kMok_1g_nk`Mko^l7N1?nl`ml2okg5h@03okc5hOnma^;o_<KR00;o_<KR00Co_<OSok_7honkan?o
^lOS0onjan@01onia^Co^LOUokW7iOnianGo]lKUo`000?nga^H00oneaNH2ok?4iP05ok?4ionb`nOo
//?Wok;3iona`^L00_n``^L3ojo1i`?o[/3W00?o[L3Wojfoion]_nL00_n/_nL00ooooooo0000oooo
o`0Jooooo`002Oooool01000003oooooooooooooool9000003L06ATI00<0000003<c<`0c<c<0;@0c
<c<00`0000006ATI01TI6@0G01TI6B<000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oo
oooooooo00gooooo4onT^nT6ojBjj@03oj>jjOnS^NWoXkWY00;oXkWY1?nR^>P4oj6gj0;oX;KX0_nP
]NL01?nO]>SoW[CWoijdionN]>L2oinciP03oinbiOnN/^KoW[;V00?oW[7U0_nP/N@3o`0000?oX[7S
00?oY;7Qoj>bh_nV/^400onV/^42ojRbh003oj^cg_n[]>3o[KGN00?o[KGN00Co/;KMok2hg_n`^=ko
/[SM0_nc^]l3okFkgP03okNlgOnh_]ko^;kN00;o^KkN0_nj`Ml00onk`Mko^l?Pokc3g`02okc3g`04
okc5hOnmaN7o_LGQokg5h@?o_LKR00Go_<KRokc7honlan?o_<OSok_7h`02ok_8i003ok[7i?njb>Go
^/SU00;o^LOU0_nhanH01Onga^Ko0000okK7ioneaNKo]<GW00Co/lCW00?o//?Wok73iona`nL00_n`
`^L3ojo1i`Co[/3W00?o[KoWojfoj?n/_nL00_n/_nL00ol0003oooooooooo`0Iooooo`002Oooool0
1000003oooooooooooooool9000003L06ATI00<0000003<c<`0c<c<0;P0c<c<00`0000006ATI01TI
6@0F01TI6@03o`00000000000000020000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oo
oooooooo00kooooo0onT^nX00onT^nWoY;_ZojBkj@0;ojBkj@KoY;[Y00?oXk[Yoj>ijOnS^NT00_nS
^NT2oj:ij@?oXKSY0onQ]nP5oinfj0;oWkCX00?oW[CWoifcj?nM/nL00onM/nL2oijbiP05oijaiOnM
/^Ko0000o`000?nN/ND00onP/N@00onR/N?oXK7Toj>bhP02oj>bhP;oY[;Q00CoYK?RojRdhOnX]>7o
Z;CQ0_n[]>02ojfegP;o[[OP00?o/;SNok2jh?nc^]l00onc^]l01?ne^mko][gOokJmgonh_]h2okS0
h0?o^/7O0onk`n001Onl`moo_<GQokc5hOnlaN7o_LGQ00;o_LOR00?o_LKRokg8honmb><00_nlan<2
okc9i004ok_8i?nkbNGo^lWUok[8i@;o^LWV0_nhanH2okO8i`03okK7iol0003o]<GW00;o]<GW0_nc
a>L2ok;4i`03ok73iona`nSo/L?X00;o/<;W00?o[l7Wojk1j?n^`NP00_n^`>L01On]`>So[KoXojfo
j?n]_nSo[;oW00;o[;oX00?o0000ooooooooool06?ooool000Wooooo00@00000oooooooooooooooo
2@00000g01TI6@030000000c<c<0<c<c02h0<c<c00<0000001TI6@0I6AT05`0I6ATR000000Cooooo
00<00000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`GoY;_Z00?oY;_YojBkj_nT^nX0
2OnT^nT00onT^^WoXk[Yoj>jj@04oj>jj@03oj>ijOnR^NWoX[WY00?oX[WY0_nQ^>T3oj2gj@CoWkKX
00CoW[GXoifdj?nM]>SoWKCX0_nM/nP2oifci`03oibcj?nL/^Oo000000;o000000CoWK;VoijaiOnM
/^KoWK;V0onO/ND2oj6ai003oj>bh_nS/nCoXk?T00?oYK?R00?oZ;CQojRfhon[]^400on[]^400on^
]n3o[[WRok2jh002ok2jh0;o/k[O0_nc_N400onf_Moo]/3QokS0h003okS0h004ok[1gonj`n7o^/?Q
ok_3h0;o_<GR0_nlaN42okc7h`04okg7h_nmbNCo_LWTokg8h`;o_<[U0_nlbN@2okc:i@04ok_9iOnj
b^Ko^/[VokW9iP;o^LWW0ongb>L2okK7i`04o`000?ndaNOo/lKXok?6j0;o//CW0_nba>P00ona`nSo
/<?Xojo2j002ojo2j0?o[/7X0on]`>P00on]_nSo[;oXojboj002ojboj003ooooool0003ooooo01So
oooo0009ooooo`0400000?ooooooooooooooo`P00000>00I6AT00`000000<c<c03<c<`0^03<c<`03
0000000I6AT06ATI01L06ATI8P000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooooooo
ool04?ooool8ojBkjPWoY;_Y2?nS^^T2oj:ij@GoXKSY00?oX;OYoingjOnO]nT00onO]^T2oijej003
oifdj?nL]>WoW;CY00;oW;?X0ol000000onL/^OoVk;Xoibbi`02oibbi`?oWK;V00?oWk7Uoijbi_nP
/^D00_nP/^D3oj>ci003ojFch_nU]NCoZ;KS00;oZ;KS0_n[]^401On[^>?o[[WRojjih_n^^N;o/;[P
00;o/KcR0onc_N43okK0h@;o^<3P0_ni`n801?nj`n7o^/GSok[5honlaN83okc8h`04okc7honlb^Co
_<[Tokg9i0;o_L_U00Go_<[Uokc<i_nlc>Ko_<cVokc:i@02ok_<i`03ok[:i_nibnOo^LWW00;o^LWW
1?ngb>L01?nfanOo0000okC7j?nca^P2ok?5j0;o//CX00Co/LCXok33j?n``nSo/<?X0on_`^P00on^
`NSo[L7Xojg0j003ojg0j0Go[;oX00?o0000ooooooooool05oooool000Wooooo00@00000oooooooo
oooooooo2000000g01TI6@030000000c<c<0<c<c0300<c<c00<0000001TI6@0I6AT05P0I6ATR0000
00Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Booooo`OoY;_Z00?oY;_YojBk
j_nT^nX01?nT^nT8oj>jj@CoX[WY0onQ^>T3oj2hj@;oWkOY00?oWkKYoijfjOnM]NT00_nM]NT01OnL
]>Wo0000o`000?l0003oVkCY00?oVk?X0_nK/^P00onL/^OoVk?Xoi^cj002oibbi`?oW[;V00?oX;;U
oindionO]>L00onR]>D2ojFei003ojRfhonW^>GoYkSU00?oZkSS00?o[[WRojjki?n^^n@00ona_>80
1?nc_N7o];oSokBohonf`>42okK3h`;o^L?R0_niaN@00onjaN?o^lSUokc8h`02okc8h`04okc:iOnl
b^Co_<[Tokc:i0?o_L_U0onlc>H01?nkcNOo^lcWok_<ionkc>L3okW;i`03okW9ionhb^So^<[X00;o
]lSW0_nfb>P01OndanSo0000okC7j?ncaNSo//GX00?o/LCX0_n``nP2ojo3j003ojo2j?n^`NSo[L7X
00;o[L7X0on]`>P6ojboj003o`000?oooooooooo01Kooooo0009ooooo`0400000?oooooooooooooo
o`H0000000?o000001TI6@0I6AT0=P0I6AT00`000000<c<c03<c<`0`03<c<`030000000I6AT06ATI
01H06ATI8P000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool;ojBk
jP03ojBkjOnS^nWoXk_Y00SoXk[Y0_nR^NT3oj6ij@?oXKSY00?oX;SYoingjOnN]nT00_nN]nT2oijf
j@?o00001OnK]>T00onK/nSoV[?YoiZcj@03oiZcj@;oVk?X0_nL/^L00onN/^KoWK?Xoindi`03oind
i`03oj:diOnQ]^OoY;OV00;oY;OV0onW^>D01On[^>?oZk_Uoj^kiOn^^nCo[[kV00Co/KoT00Co];oS
okC2iOnd`^Go]/?S0_ngaND3okW5i0?o^lSU00Go_<SSokc:iOnlb^Go_<[Uokc:i002okc<iP04okg;
iOnlcNOo_<gWokc<iP?o^lgW00Co^lcWok[<j?njc>So^L_W0_nibnP00onhb^So]l[YokO:j@02okK8
j0;o]LSY00?o]<OXo`000?ncanT00_nbaNP00onaa>So/<CXok34j002ojo3j0;o[l;X0_n^`NP01?n]
`NSo[L3Xojg0j?n]`>P6ojboj0;oZkoX00?o0000ooooooooool05Oooool000Wooooo00@00000oooo
oooooooooooo1`00000h01TI6@030000000c<c<0<c<c0300<c<c00<0000001TI6@0I6AT05P0I6ATR
000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03ojBkj_nS^n[o
Xk_Z00CoY;_Z1?nS^nX00onS^nWoXk[Yoj>jj@06oj>jj@;oX[[Y0_nR^NT3oj6ij@?oX;SY0_nO]nT0
1?nN]nWo0000o`000?l00002oiffjP;oW;GZ00?oVkCYoiZej_nJ]>X00_nJ]>X4oiZcj@03oiVdj_nJ
/n[oV[?Z00?oVk?Y0_nM/nP2oindi`05oijfjOnQ]^OoXKKWoj6fionT]nH00_nT^NP3ojNji`03oj^k
iOnZ_NOo[[kV00;o[[kV0_na_n@2ok72iP03okC2iOndaNOo]lGU00?o]lGU00Co^LGTokW8i_nib>Ko
^lSU0_njbnH2okc:i@;o^lgW00Co_<cVokc>j?nlc^So_<gW0_nkc^P2ok_=i`;o^lkY00Co^/cXokW=
jOnicNWo^L_X0_nhc>T00ongb^Wo]/[YokK:j@02okG8j@;o]<SY00?o/lOYo`000?naaNT00_naaNT0
0on`a>So[l?Yojo3j@02ojo2j004ojk2j?n^`NSo[/7Xojk1j0?o[L3X1_n/_nP00on[_nSoZkkXo`00
000Gooooo`002Oooool01000003oooooooooooooool6000003T06ATI00<0000003<c<`0c<c<0<00c
<c<00`0000006ATI01TI6@0G01TI6B4000001?ooool00`00003oooooooooo`0Booooo`03o`000?oo
oooooooo01Kooooo0_nS^nX00onT^n[oXk_Zoj>kjP06oj>kjPOoXk[Y00?oX[[Yoj:ijOnR^NT00onR
^NT2oj6ij@03oj2hjOnP^>[o000000;o00000_nN]nX2oiffjP04oibfj_nK]^[oVkKZoi^fjP;oV[GZ
00?oV[CZoiVdjonI]>/00onI]>/2oiVdjP;oV[?Z00?oVk?YoiZejonL]NX00onL]NX2oijfj@03oj6f
ionP^>WoX;SY00?oY;WX00?oYk[WojNljOnZ_NL00_nZ_NL01_n^_^Ko[/7Xojk1j?n^`NSo/L;Vok75
j@?o]<GW0_ngaND2okO8i`04okW8i_nibnSo^L_Xok[;iP;o^/gX0_nkcNL2ok_?j@04okc>j?nkcnWo
^loYok_>j0;o^loY0_nkc^T2ok[>jP04okW=jOnhcN[o^<gZokS<j@;o]/cZ00?o]/[YokC9j_ndbNX0
0_ndb>T01Onbb>[o//KYo`000?nba^Wo/LGY00;o/<CY0on_`nT3ojk2j005ojk1j?n]`NSo[L7Xojg0
j?n/`>P01On/_nP01On[_nSoZkkXoj^nj?n[_^So000001Kooooo0009ooooo`0400000?oooooooooo
ooooo`H00000>@0I6AT00`000000<c<c03<c<`0`03<c<`03o`00000I6AT06ATI01L06ATI8@000004
ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool05oooool9oj>kjPOoXk[Y0onR^^T3
oj:ij@03oj6ijOnQ^>Wo000000;o000000CoX;SZoingj_nN]n[oW[OZ0onM]nX2oibfjP03oi^fj_nK
]^_oV[G[00;oV[G[1?nI]>/4oiRek0;oVKG[0_nJ]N/2oibejP05oi^gk?nM]n_oWKO[oifgjonP^>T0
0_nO^^`3oj>kjP;oYkcY00?oZ[gWoj[0j_nZ`>X00_n^`NP01On]a>_o/LGYok75jOnaaNWo]<GW00;o
]<SY0_ngb>L2okK;jP04okW;j?nhc^[o^<kZok[=j0?o^/oZ00Co^loYok[@jonjd>_o^loY0_njd>/0
0onkcnWo^M3[okW@j`02ok[>jP;o^<o[00Co^<gZokO=jongcN_o]/cZ0_nebn/00ondbN[o/lWZok?9
jP03ok;8jP04ok;6jOl0003o/LKYok34j@;o[lCY00?o[l?Yojk2jOn^`^P00on^`^P3ojg1j0;o[<3X
0on/_nP2oj^oj0CoZkkX00?o0000ooooooooool04oooool000Wooooo00@00000oooooooooooooooo
1P00000i01TI6@030000000c<c<0<c<c0300<c<c00<0000001TI6@0I6AT05`0I6ATQ000000Cooooo
00<00000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`SoXk_Z2?nS^^T00onR^^WoX[WY
oj:ij@02oj:ij@;o000000?oXKSYoj2hj_nO^>X00onO^>X2oijgjP03oifgj_nM]n_oWKO[00;oW;K[
0_nK]^/00onJ]N_oVKK/oiVfk006oiRek003oiNfkOnH]^goV;K]00;oV;K]0_nI]^`2oi^gk003oifg
jonM^^goWK[]00?oWk[/00?oXk_Zoj:nkOnV_n/00_nV_n/01?nZ`>[oZL?/ojW3k?nY`n`2ojg4j`04
ok75jOn`an_o/<O[okC8j@?o/l_/00Co]/_ZokK>k?nfc^co^<kZ0_nhd>`2ok[?jP;o^M7/00Co^]3[
okWAk?nidNco^]3[0_nidN`00onid>_o^=3/okS@k002okS?j`;o]lo/00Co]lg[okK=jonfcN_o]L_[
0_ndbn/00oncbN[o//S[ok77jP03ok77jP05ok76jOl0003o/<GYojo4jOn_`nT00on^`^T2ojk2j0?o
[L7X00?o[<3Xojboj?n/_nP00_n/_nP4oj^oj0?oZkkX00?o0000ooooooooool04oooool000Wooooo
00@00000oooooooooooooooo1@00000k01TI6@030000000c<c<0<c<c02l0<c<c00<0000001TI6@0I
6AT05`0I6ATQ000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`Ko
Xk_Z00?oXk[Zoj>jjOnS^^T01OnS^^T2oj:jj@04oj:ijOl0003o0000o`0000?oXKWY0_nP^>X4oinh
jP;oW[SZ0_nM]n/3oi^gj`?oV[K/0_nI]^`00onH]NcoV;K]oiNfk@04oiNfk@;oV;K]00CoUkS^oiRh
k_nH^>koV;S^0_nJ^Nd00onM^^goW;c_oiblk`03oinmkP;oX[k]00?oY[o[ojG2k_nU`^h00_nY`n`0
1OnYa^ko[LO]ojg7kOn]ango/<O[00;o/<_]0_ncbn`2ok?>kP04okK>k?ned>ko]M3^okS@k0;o]m;^
0_nidN`2okSBkP04okWAk?nhd^go^=;]okWAk0;o^=;]00?o^=3/okO@kOngd>d00_ngcn`2okK>k005
okK=jondc>co]<c/okC;jonbb^/00onbb>/2ok77jP;o/<KZ00?o/<GYo`000?n_a>X00_n_`nT00on^
`^Wo[L;Yojg2j@03ojg1j0?o[<3X0on/_nP3oj^oj0GoZkkX00?o0000ooooooooool04_ooool000Wo
oooo00@00000oooooooooooooooo1@00000k01TI6@030000000c<c<0<c<c02l0<c<c00<0000001TI
6@0I6AT05`0I6ATQ000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Joooo
o`GoXk_Z0_nS^^X6oj>jj@?o00001?nR^NT4oj6ij@;oX;SZ0_nO^>X3oijhj`;oWKO[00?oVkO[oi^g
k?nK]n`00onJ]n`2oiVgk@;oV;K]00?oUkK]oiNgk_nG^>h01OnG^>h00onH^>koV;[`oiVkk`02oiVk
k`?oW;c_00?oWkg^oijol?nN_o000_nR`Nl01?nU`^koYLG`ojG5l?nUaO02ojW6kP04ojg7kOn/b^oo
[<[_ok3;k@?o[lg_00Co/lk^ok;@konbd>oo]M3^0_ndd^l00ongd^ko]]?_okKCk`02okSBkP;o]m?_
00Co^=;]okOCk_ngdnko^=;]0_nfd^h00ongd>go]]3]okK@k@02okK>k0;o]<k]00?o]<c/ok?;k?nc
bn`00_nbb^/00onbb>_o/LO[ok77j`02ok36jP;o/<GZ00?o0000ojk4j_n^`nT00_n^`nT01?n]`^Wo
[L7Yojg1jOn]`NP5ojc0j003ojboj?n[_nSoZkoX00;oZkoX1On[_^P00ol0003oooooooooo`0Boooo
o`002Oooool01000003oooooooooooooool5000003/06ATI00<0000003<c<`0c<c<0;`0c<c<00`00
00006ATI01TI6@0G01TI6B4000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo
01[ooooo1?nS^nX5oj>jjP05oj>jjOl0003o0000o`000?nR^^T01OnR^NT4oj6ij@04oj6ij_nP^>[o
X;SZoj2hjP;oWkSZ0onN^>/3oibhj`;oVkO/00?oV[O/oiZhkOnI^>d00_nI^>d2oiRhkP;oUkO^0_nG
^>h2oiJil0;oUk[`0_nH^_001?nI^nooVKgaoiVmlOnI_O42oi^nl@03oijol?nM`_;oXL?a00;oXL?a
0_nUaO02ojC7lP;oZ<Wa00?o[<[_ojc<lOn/c?400_n_cNl2ojo@l@04ok;@konad_7o/M;aokCBk`;o
/m?a00Go]]?_okCDl?nde?3o]=C`okOCk`02okGDl004okOCk_nednoo]M?_okKBkP;o]M7_00?o]]3]
okC?k_ndcnh00_ndc^d2ok?=k@03ok?;k?nbb^co/LW[00;o/LW[00?o/LO[ok37jon`an/00_n`aNX0
1On_aN[o[/CZo`000?n^a>[o[/?Y00;o[L;Y00?o[L7Yojc1jOn/`>P01?n/`>P00on/_nSoZkoXoj^o
j004oj^oj0GoZkkX00?o0000ooooooooool04Oooool000Wooooo00@00000oooooooooooooooo1000
000l01TI6@030000000c<c<0<c<c02l0<c<c00<0000001TI6@0I6AT05`0I6ATQ000000Cooooo00<0
0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03oj>kj_nS^^[oXk[Z00?oXk[Z0ol0
0002oj>jj@03oj:jjOnR^NWoX[WY00GoX[WY0onQ^NT2oj6ijP03oj2hj_nP^N[oWkSZ00;oWkSZ0onN
^>/00onL^>_oWKS/oi^hk002oi^hk0;oV[S]00?oVKS]oiVik_nH^Nl00onH^Nl2oiNik`03oiJil?nF
^o7oU[_a00;oU[_a0_nG_?42oiVml@04oiRolonK`O;oVl7boi_1lP;oWL;b00GoXL?aoj76lonQa_?o
XLKcojC7lP02ojC:m0;oZ<_b00?o[<caoj_?lon[co<00_n_d?42ojkAl`04ok7BlOn`do;o/=?bok?C
l@;o/]Cb0_nde?02ok?Dl@04okGDl?nde?7o]=CaokGCk`;o]=;`00Co]M7_ok?@koncd>oo]<o^0_nc
c^h2ok?=k@;o//c]0_nbb^`01?nabN_o/<S[ok38jon`an/2ojo6j`06ojo5j_n^a>[o[/?Yojk3jOl0
003o[/?Y0on]`^T2ojc1j@?o[<3X00?o[;oXoj^oj?n[_nP01?n[_nP5oj^nj080ZkkX00?o0000oooo
ooooool04?ooool000Wooooo00@00000oooooooooooooooo1000000l01TI6@030000000c<c<0<c<c
02l0<c<c00?o000001TI6@0I6AT05`0I6ATQ000000Cooooo00<00000ooooooooool04Oooool00ol0
003oooooooooo`0Nooooo`06oj>jj_l0003o0000o`000?nS^^[oXk[Y1OnR^^T7oj:ij@;oXKWY0onQ
^NX2oj2ijP03oinhj_nO^N_oWkW[00?oW[S[0_nM^>`00onK^>coVkW]oi^ik@02oiZik@;oVKW^0_nH
^Nl2oiRjl0;oUk[`0onF^o42oiJmlP?oUkkc0_nH_o<00onK`O;oV/?doi[3m002oig5m0;oXLKc0_nP
bOD00onTb_CoXlceoj?<m@02ojO>m005oj_?lonZdOCoZ]7doj[Am?n^dO<00_n]do@01?n`do;o[mCc
ojoDlonbe?82ok7El`;o/mCa0_nbe?801?nde?7o/m?aok?ClOndd_02ok?Al004ok?@konbcnoo//o_
ok?>kP;o/Lg^0_nbc>d01On`b^go/<W/ok39k?n`bNco/<S[00;o[lO[00?o[lK[ojk5jon^aN/00_n^
a>X2ojk3j@03o`000?n]`^Wo[L;Y00Co[<7Y00?o[<3Xoj^oj?n[_nP01On[_nP2oj^nj0H0ZkkX00?o
0000ooooooooool04?ooool000Wooooo00@00000oooooooooooooooo0`0000000ol000006ATI01TI
6@0j01TI6@030000000c<c<0<c<c02l0<c<c00<0000001TI6@0I6AT05`0I6ATQ000000Cooooo00<0
0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`?o00000onS^^X3oj:jjP?oX[[Y2OnR
^NT2oj6ij@?oXKWZ0onP^NX2oinij`03oijhjonN^N_oW[W[00;oWKW/00?oVkW]oibjkOnL^^d00onJ
^^h2oiVjk`03oiRjl?nH_?3oUkca00;oUkca0_nG_O800onF_O;oUkocoiNol`03oiO1m0;oV<;d00?o
V/?doi[5m_nJaOH00onMaoD01?nPbOGoX<_foj3;m_nSc?D2oj?>m`;oY]3f0_nZdO@2ojWBm@04ojgC
m?n/e?Go[=CeojoDl`;o[]Gd00?o/MGcok3Elon`eO<00_nbe?82ok7DlP04ok?ClOnad_7o/M;aok?A
l0;o/M3`00Co//o_ok7>konac^oo/Lg^0_n`bnh3ok3:k@04ok39k?n_b>co[lS/ojo7j`;o[/K[00?o
[/G[ojg4j_n]`nX00_n]`nX00on]`^Wo0000ojc2j@04ojc1j@;o[<3Y1_n[_nP20:^oj0L0ZkkX00<0
Z[kXo`000?ooool04?ooool000Wooooo00@00000oooooooooooooooo1000000l01TI6@030000000c
<c<0<c<c02l0<c<c00<0000001TI6@0I6AT05`0I6ATQ000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Iooooo`?o00001Oooool4oj:jjP?oX[[Y2_nR^NT3oj6ij@;oXKWZ0onP
^NX2oinij`03oijijonN^^coWK[/00;oWK[/0onL^^d00onJ^^koVk__oiZkk`02oiZkk`;oV;c`00?o
UkcaoiRnl_nH__800onG__<2oiNol`03oiO1m?nH`oGoV<?e00;oVLCf00CoV/Gfoi[8monJb?OoV/Sg
0_nMbOL01?nPboKoWlggoio=monSc_L2oj?@m`;oY]7g0_nYd_D2ojWCmP03ojcDmOn/e?Ko[=Cf00?o
[]Gd00?o/=GcojoDlon_e?<00_nae?82ok3ClP04ok7BlOn`dO7o/=7aok7@l0;o/<o`00Co/Lk_ok3<
kon`c>oo/<_^0_n_b^d3ojo9k@04ojo8k?n^anco[/O/ojk6j`;o[LG[0_n]a>X01On]`n[o[L;Zojg2
j_n/`^Wo000000Co[<7Y00?o[<3Yoj_0jOn[`>T00on[_nP30:^oj0H0ZkkX102Z_^P00ol0003ooooo
ooooo`0>ooooo`002Oooool01000003oooooooooooooool3000003h06ATI00<0000003<c<`0c<c<0
;@0c<c<00`0000006ATI01TI6@0H01TI6B4000001?ooool00`00003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Kooooo0ol00008ooooo`GoX[[Z00?oX[[Yoj:ijOnR^NT02_nR^NT3oj6ij@;oXKWZ
00?oX;WZoj6jjonP^^/00_nP^^/2oijjk004oifjk?nN^ngoW[_]oijkk@;oWK_^0_nK^nl00onJ^noo
V[g`oiZml002oiVml@03oiRnl_nI_o?oVKoc00?oV<3d0_nG`O@00onH`oGoV<GfoiS5mP02oiW6mP;o
V/Sg0_nKbOL2oig;m`04oio=monPc_SoX<khoj?@m`;oXm7h0_nVd_L2ojKCm`?oZ=Cg0_n[e?H01?n^
eOCo[MCeojgDmOn_e?<3ojkCl`04ok3Cl_n_d_;o[m;bok3Al@;o[m3a00Co/<o`ojo=l?n_cO3o/<c_
0_n_bnh00on_b^go[/S]ojk8k@04ojk7k0;o[/G[00?o[LG[ojg4jon]a>/00_n]`nX01On]`^[o[<;Y
ojc2jOn/`NWo000000GoZl3Y1`2[_nP50:^nj0D0Z[kX00?o0000ooooooooool03_ooool000Wooooo
00@00000oooooooooooooooo0`00000o01TI6@030000000c<c<0<c<c02`0<c<c00<0000001TI6@0I
6AT0600I6ATQ000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o
00003?ooool5oj:jjPgoX[WY00?oXKWYoj:ij_nQ^NX00_nQ^NX2oj6jj`CoX;[[0_nO^^`00onN^ngo
Wkc]oiflkP02oiflkP;oW;c_00?oV[g`oibnl?nL__000onJ_o42oiVol`03oiS0m?nI`_CoVL;d00;o
V<?e00?oV<GfoiW6m_nIa_H00onJb?L01?nKbOOoW<_hoic;n?nMcOP2oik>n0;oX<oh00CoXm7hoj?B
n?nSd_SoXm;h0onVdoL01?nXe?OoZ=?fojSCm_n[e?H2oj_Cm@03ojcCm?n/d_Co[=;d00?o[];c00Co
[m;bojk@l_n^d?;o[m3a0_n_c_001?n_cO3o[/c_ojk<kon_bnh2ojk9kP03ojk8kOn]ango[/K/00?o
[/K/00Go[/G[ojg4jon]a>_o[LC[ojc3jP03ojc2jP06ojc2jOn/`NWo[<7Yoj_1jOl0003oZl3Y0P2[
`>T70:^oj0D0ZkkX1P2Z_^P00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooooooo
ool3000003l06ATI00<0000003<c<`0c<c<0;00c<c<00`0000006ATI01TI6@0H01TI6B4000001?oo
ool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol0000?ooooo`KoX[[Z3?nR
^NT2oj:ijP03oj6ij_nQ^^[oXK[Z00?oXK[[00?oX;[[oj6kjonP^n`00_nP^n`2oinlk@03oiflk_nN
_NkoW[g^00;oWKg_00?oW;k`oifolOnM_o400onK`?82oi[1l`03oiW2m?nJa?CoV/Cd00;oV/Gf00Co
VLKfoi_8monKb?OoVlSg0_nKbOL01?nLboSoWLchoig<n?nNc_P2oio?n0;oXM3h0_nSd_P2ojCBn0?o
Y]?g0onXdoH01?n[doGoZ];eoj[BmOn/d_@2ojcAl`;o[M7c0_n]co82ojk?l@04ojo>l?n^c?3o[/c`
ojk<k`;o[/[^00?o[/W^ojg8kOn]b>d00_n]and2ojk6k003ojg5k?n]a>_o[LC[00;o[<?[0_n/`nX0
1?n/`^[o[<7Zojc1j_n/`NT20:_0j@03o`00002[`>T0Zl3Y0080ZkoY1P2[_nP30:^nj0<0Z[kX1Ooo
ool00ol0003oooooooooo`0>ooooo`002Oooool01000003oooooooooooooool3000004006ATI00<0
000003<c<`0c<c<0:`0c<c<00`0000006ATI01TI6@0H01TI6B4000001?ooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo0ol0000Dooooo`?oX[[Z00CoXK[Zoj:ij_nR^N[oX[WZ
2?nR^NT4oj:jjP?oXK[Z00?oXK[[oj6kjonQ^n/00_nQ^n/00onP^ncoXKc/oj6lk002oinmk@03oijm
k_nO_^koW[o`00?oW[o`0_nM_o400onK`?;oWL;boig2lP02oi_3l`03oi[4m?nLaOGoW<Ge00;oVlOf
0_nKb?L2oic9m`03oic;monNc?OoW/cg00;oW/gh00CoWlohoj7?n?nQcoSoX]7h0onSdOL2ojCBm`04
ojKCmonWd_OoYm;gojSCmP;oZM;e00CoZ];eoj[Am?nZdOCo[=7c0_n/co<2ojg?lP;o[<ga0_n]cO40
1?n^c?3o[L__ojg;kon^b^h2ojg8kP03ojg8kOn]a^go[LK]00;o[LK/00?o[LG/ojc4jon/a>/00_n/
`n/4ojc2jP03ojc1jP2[`NT0Zl7Y00<0Zl3Y00Co00000:^oj@2[_nT0ZkoY1@2[_nP50:Znj0Sooooo
00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo0P00001101TI6@030000
000c<c<0<c<c02X0<c<c00<0000001TI6@0I6AT06@0I6ATQ000000Cooooo00<00000ooooooooool0
4?ooool00ol0003oooooooooo`0<ooooo`?o00005oooool5oj6jjP03oj:ij_nQ^N[oXKWZ00;oX[WZ
00?oX[WYoj:jj_nR^^X02?nR^^X2oj:jj`03oj6kjonR^n_oX[_[00?oXKc/00CoX[g]oj6nkOnQ_^go
XKk]0_nO_^h2oijol0;oWl3`0_nN`O400onM`_;oW/?boik3lP02oig4l`03oic5mOnNaoCoW/Od00?o
WLSf00CoW<Wgoik:monNb_OoW/cg0_nPc?L2oj3>n003oj7?n?nRcoOoX/og00;oXm7g0_nTd?L00onU
dOOoY]3fojK@mP02ojOAmP04ojWBmOnYd?CoZM3doj[Am0;oZloc00?o[<ocoj_=l_n[cO800_n/cO42
ojc<l0;o[L_`00Co[L__ojc9k_n/bNko[LS^0_n/and00on]a^go[<G/ojc4k002ojc4k003ojc4jon/
`n_o[<?[00Co[<;Z0P2[`NX00`2[`NT0Zl3Y0:_0j@020:_0j@030:^ojOl00000ZkoY0080ZkoY00@0
ZkoX0:Zoj02Z_nP0Z[kX3Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooo
ooooool2000004806ATI00<0000003<c<`0c<c<0:@0c<c<00`0000006ATI01TI6@0I01TI6B400000
1?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0ol0000Kooooo`GoXK[Z
00?oXKWZoj6jj_nQ^^X00_nQ^^X9oj:jjPGoX[_[00CoX[c[oj:mk?nR_NcoX[g/0_nR_Nd01?nQ_^go
X[o^oj:ok_nR_nh2oj6ok`03oio0l?nQ`O3oXL7`00;oX<;a00?oW/?boj34l_nPa?800_nOaO<01OnN
aoCoWlSdoio8m?nOb?CoWlWf00;oXL[e0_nPboH01?nPc?OoXLgfoj7=m_nQc_L2oj?>mP;oXlog0_nT
d?L2ojG?mP04ojK@m_nWcoGoYloeojS@m@;oZ<od0_nYco@01?n[co?oZlgboj_=l_n[cO82oj_<l@;o
[<c`0_n/b^l2ojc9k`04ojc9k_n/anko[<O^ojc7k@;o[<G]0_n/aN`01?n/a>co[<?[ojc3jon/`n/4
0:_2jP80Zl7Z00@0Zl7Y0:_0j@2[`>T0Zl3Y0`2[_nT00ol00000Z[oY0:Zoj@030:Zoj0oooooo00?o
0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo0P00001201TI6@030000000c
<c<0<c<c02T0<c<c00<0000001TI6@0I6AT06@0I6ATQ000000Cooooo00<00000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`?o00007oooool00onQ^^[oXK[[oj6jj`08oj6jjPCoX[[Z0onR
^nX3oj:kj`;oXkc[0_nR_>/01?nR_NcoXkg/oj>mk?nS_N`2oj:nk@03oj:ok_nS_ngoXko]00;oX/3^
00?oXL7`oj?2konS`^l00_nQ`o400onPa?;oX/Gaoj;5l@03oj76l`04oio8m?nRb?CoX/Sdoj7:m@;o
Xl[d0_nRboH01?nQcOKoXlgfoj?=m_nSc_H2ojG>m@CoYLof0_nVcoD01?nWcoGoZ<kdojS>m?nXco@2
ojW=l`03oj[=lonZc?7oZ/ca00?oZlca0_n[b_02ojc:k`;oZlS_0_n/b>h01?n/anko[<K]ojc6kOn/
aNd4oj_4k004ojc3j`2[`^/0Zl;[0:_2jP@0Zl7Z00<0Zl7Y0:_0j@2[`>T00`2[`>T0102[_nT0Z[oY
0:ZojOl0000Cooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooo`80
0000@`0I6AT2000002P0<c<c00?o000001TI6@0I6AT06@0I6ATR000000Cooooo00<00000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`?o00009?ooool2oj6jj`03oj6jj_nQ^^_oXK[[00?o
XK[Z00?oXK[[oj:jj_nR^^X00onR^^X00onR^n[oX[_[oj:kj`02oj>kj`?oXkc[1?nS_N`2ojBnk0;o
Xkk]00?oXko]ojBokOnT_nd00_nS`Nh00onS`^ooY<;^ojC2kP02oj?4l004oj;5lOnTaO7oY<GaojC5
l@;oXlOb00CoX/SdojC8lonTb??oXl[d0_nUb_<2ojC<m004oj?=m_nUc?CoYLcdojG>m@?oY/gd00?o
Y/keojO=m?nWcO@00_nWcO@01?nXc_CoZ<gcojS=lonYcO<2ojW<lP03oj[<lOnZb_3oZ/[`00?oZl[`
1?n[b>l2oj_6kP;oZlK]00Co[<K]oj_5k?n[aNcoZlC/102[`n/00`2[`^/0Zl;Z0:_2jP030:_1jP<0
Zl3Y1P2Z_nT2ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool000Wooooo
00@00000oooooooooooooooo0P00001501TI6@030000000c<c<0<c<c02@0<c<c00<0000001TI6@0I
6AT06P0I6ATR000000Cooooo00<00000ooooooooool03oooool01?l0003oooooooooooooool3o`00
02Sooooo0_nP^^/7oj6jj`03oj:jj_nR^n_oX[_[00?oX[_[1OnS_>/5ojBmj`03ojBnk?nU_^_oYKk/
00;oYKk/00?oY;o]ojJojonU`>d00_nU`>d00onT`^koYl7/ojO1k003ojG3k`03ojC5lOnWaNooYlG_
00;oYLOa00CoY<ScojK8l_nVb?;oYL[c0_nWb_800onUbo?oYl_bojO;lP02ojK<l`;oY/gd0_nWc?<0
0onWcOCoZ<cbojS<lP02ojS<l`04ojS=lonYbo;oZL_bojW<lP;oZ/[a00?oZ/[`oj[8konZb>l00on[
b>l2oj_7kP;oZlK^1?n[aNd01?n[aN`0Zl?/0:_3k02[`n/40:_2j`030:_2jP2Z`NX0Z/7Z0080Zl7Z
00@0Zl3Y0:[0j@2Z`>T0Z[oY2?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00go
oooo0009ooooo`0400000?ooooooooooooooo`800000AP0I6AT00`000000<c<c03<c<`0R03<c<`03
0000000I6AT06ATI01/06ATI8P000004ooooo`0300000?oooooooooo00oooooo1?l0000[ooooo`?o
X;[[0onQ^^/4oj6kj`GoX[_[1_nS_>/3ojBmj`;oYKg[0_nU_^/00onU_^coY[gZojJmjP02ojJoj`04
ojG0kOnW_^[oYkkZojO1k0;oZKkY0onX`^`01?nWaNooZL?/ojW3k?nXa^l2oj_5k@;oZ<S`00CoYl[b
ojW9lOnYbO7oYl_b0_nYb_43ojS;lP04ojO<lonXbo;oZ<_bojS<lP;oZL_a00?oZL_bojW9lOnYbO40
0_nYb_401?nZb_7oZ/S`oj[8l?nZb>l4oj[7kP04oj_7k_n[aNgoZlG]oj_5k@D0ZlC/00<0Zl?/0:_2
j`2[`^/00`2[`^/30:[1jP80Z/3Z0`2Z`>T:ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03Oooool000Wooooo00@00000oooooooooooooooo0P00001701TI6@030000000c<c<0<c<c
0200<c<c00<0000001TI6@0I6AT0700I6ATR000000Cooooo00<00000ooooooooool03oooool2o`00
02kooooo00?oX;[[oj2kk?nP^n`00_nP^n/00onQ^n_oXK_/oj6kk003oj6kj`;oX[_[0onR_>/3oj>l
j`CoY;c[00?oYKg[ojFkjOnU^nT00_nV_>T00onV_N[oZ;[VojRjiP02ojRlj004ojNnj_nZ^nGoZ[_U
ojZki@;oZKkY00CoZ<;/ojboj?n/_nSoZL?/0_n]`NP00on[aNgo[/?Yojk3j@02oj_7kP04ojW9lOn[
b>ooZlS_ojW:l@?oZlW`0_nYbo401?nXbo;oZL[aojW:lOnYbo42ojW9l003ojW9lOnZb?3oZ/S`00?o
Z/S`0_nZanl00onZankoZ/K^oj[6kP02oj[5k@05oj_5k@2Za>`0Z/C/0:_4k02Z`n`00`2Z`n/20:_2
j`80Z/;[0P2Z`N/0102Z`NX0Z/3Z0:[0jP2Z`>X?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo0P00001801TI6@030000000c<c<0
<c<c01h0<c<c00?o000001TI6@0I6AT07@0I6ATR000000Cooooo00<00000ooooooooool04Oooool0
0ol0003oooooooooo`0/ooooo`KoX;_/0_nQ^n`00onQ^n_oXKc/oj6lk002oj:lk0?oX[c[0_nS_>/0
0onT_>_oY;[YojFjj@02ojFjj@03ojFkjOnV]^CoYkSU00;oYkSU00?oZ;[VojZcgonZ/ml00on[]n80
0onZ^nGo[[CNojfjh`02ojfjh`04ojboj?n_^n;o[k_Rojg1j0;o/KkS00?o[/?Yok;2i_n^a^`00_n^
a^`00on[b>oo[LS]ojg8k@02oj_9l0;o[<W_00?oZ/W`oj_9kon[bNl00_nZbO001?nYbO3oZ/S_oj[8
konZb?05oj[7k`?oZ/K^102Za>d00`2Za>`0Z/?/0:[3k0020:[3k0030:[3j`2Z`^/0Z/;[0080Z/;[
102Z`NX00`2Z`>[oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3?ooool000Wooooo00@00000oooooooooooooooo0P00001901TI6@030000000c<c<0<c<c01`0<c<c
0P00000N01TI6B<000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo
1OnP^n`2oj2lk0?oXKc/0_nR_>`00onR_>_oX[_[oj>kjP02oj>kjP;oY;[Y00?oYK[YojFfi?nU]^@0
0_nV]^@00onW^>GoZK3MojV`g@03ojZcg`03oj^gh_n][]Wo[[CN00;o[[CN00Co[K[Sok6dfona]=_o
[k_R0_nd]]/00ona_^?o][_MokJkg@02ok;2iP04ojk6k?naaNWo/LGYojg8k@?o[lO/00Co[<W_ojg8
k_n]b>koZlW_0_n/b>h2oj_8k`04oj[8konZankoZ/O^oj[7k`GoZ/K^0`2Za>d50:[3k0D0Z/;[0`2Z
`NXHooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00@00000
oooooooooooooooo0P00001:01TI6@03o`0000000000<c<c01X0<c<c00<0000001TI6@0I6AT07P0I
6ATS000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0]ooooo`;oWk_]00?o
X;_/oj2lkOnP_>d00_nP_>d2oj6lk0?oXK_/0_nR^n/00onS^n[oXkOWoj>gi`02ojBfi@03ojFfi?nU
[MgoYjkL00;oYjkL0onY/=d00onZ/moo[:WDojbYe002ojf^f@04ojjdg_na[=Co/JcDok6df`;o]JkB
00?o];KKokRbdonf^md00_nf^md3okK0hP03ok75jOndaNKo]<GV00;o[lO/0_naanX01?n]b>ko[/S]
ojk8kOn/b>h2ojc7kP;oZlO^00CoZ/O^oj[6k_nZa^koZ/K^102ZaNd01@2Za>d0Z/?/0:[3k02Z`n`0
Z/;/00@0Z/;[102Z`N/00`2Z`N[oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo0P00001<01TI6@8000005`0c<c<2
000002006ATI90000004ooooo`0300000?oooooooooo01Cooooo0_l0000^ooooo`;oWkc]00?oX;c]
oinlkOnP_>d00_nP_>d2oj6lk003oj6kk?nQ^N[oXKWZ00;oX[SY00CoXkOWoj:_h_nR[n;oXjkO0onU
[Md00onW[]coYj;AojNRd@03ojVUdP03ojbYe?n]W/So[jG=00;o[jG=00?o/JcDokBUbOne[]800_ne
[]83okRbd`04okJkgOnk^MOo^kWGokK0hP;o^l3N00Go]<GVokS5i?nhaNCo^<GTok77jP02ok?8j@04
ojk8kOn_b>co[lS/ojc7kP;o[<O]0_n[a^d01?nZa^h0Z/G]0:[5k@2ZaNd40:[4k0<0Z/?/0P2Z`^`3
0:[2j`030:[1jooooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`002Oooool01000003oooooooooooooool2000004h06ATI00<00000o`00000000004P0c<c<0
0ol00000000001TI6@0Q01TI6B@000001?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooo
oooo02cooooo1?nO_>d01_nP_>goWkc]oinlkOnO_>goX;_/oj6ijP;oWkGX0onP/^D2oj:_hP04oj>^
gonU[MgoY:7BojBQdP?oYj;A00?oZJGBojVIaOn]W/P00_n]W/P00on_YLgo/Ic2okBUb@02okBUb@04
okF^d_niZ<So^JS8okRbd`;o_Jo<00Co^kWGol2hd_o0^=;o^l3N0ono`M/01?nhaNCo^lKSok_6honc
b>T2okC8j@04ojo8k?n_anco[lO/ojc7k@80[<K/0P2[aNd0102ZaNd0Z/C/0:[4k02Za>`50:[3k0D0
Z/;[8_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo0009ooooo`040000
0?ooooooooooooooo`800000D@0I6AT3000000d0<c<c0P00000T01TI6B@000001?ooool00`00003o
ooooooooo`0Gooooo`03o`000?oooooooooo02gooooo0_nO_Nh3oinlk@;oW[[/0_nN^>X2oinej004
oj2biOnMZ=koWZCIoijTf@?oXJ;E0_nTXM800onWX]7oYYG5ojVIa@02ojVIa@;o[Ik80onaW<800ond
YLWo]inookVXb002okVXb0?o_Jo<0oo0^=82olFjc`04oko1foo4`m[oa<?Jok_6h`;o_LSS00Co]<SY
okG9jOnebNWo[lO/0P2_an`00`2/a^`0[<G/0:c5k0020:_4k0040:[4k02Z`n`0Z/?/0:[3k0D0Z/;[
9oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oo
ooooooooooooo`800000E00I6AT=000002H06ATI90000004ooooo`0300000?oooooooooo01Sooooo
00?o0000ooooooooool0;?ooool3oijmkP;oW[c]00CoW[[/oi^fjonK/^SoVk;X0onK[N<2oifXgP;o
WZCI00CoXJ;EoifCbOnQTlKoXI?60onVULD2ojVIa@03ojfNb?n^UKgo[YFm00;o/Ic20ongWkl01?ni
Z<So_JG1okfU`Onm[l`2ol>_aP03ol2hd_o5^/ooaK[?00;obkk=00Coa<?JolO7f_o7am[o_LSS0_nn
bn@01?nebNT0]LWY0;G9j@2_an`20:o7j`030:c5k02/a>`0[<C/0080ZlC/00@0Z/?/0:[2j`2Z`^/0
Z/;[:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0009ooooo`040000
0?ooooooooooooooo`800000QP0I6ATU000000Cooooo00<00000ooooooooool06Oooool2o`0002go
oooo00?oW[g^oiflk_nM_>h00_nL^^d2oi^fj`;oVk;X00CoVjgSoiFQgOnGV]GoUi[E0_nJU/h3oifC
b@;oXI?60_nVULD00onYVLGoZHnjojjE_@02ojjE_@03ok6L`_ndU[Wo]9Ji00;o]ino0onmYL43ol>_
aP03olVa`oo5^/oobkk=00;obkk=00GodL?=olO7f_o:c=_ob/cKokk;i0020;o=i@040;G9j@2dbNX0
]<WZ0:o7j`80[/K[00<0[<C/0:_4j`2[a>/00P2[`n/00`2Z`^_oooooooooo`0/ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo0P00
002601TI6@03o`00000000000000028000001?ooool00`00003oooooooooo`0Kooooo`03o`000?oo
oooooooo02_ooooo00?oWKc^oi^jk_nK^^h00_nI]^`2oiN`j@;oUJWS0_nEXMd2oiNJe@;oVYK>0_nM
TlT2oj6CaP03ojJEaOnTRkWoZHnj00;oZHnj0_n^UKd3okBF^@04okNO_onkW;So^ibhokfU`@;o`jFk
00?o`jo6olVa`oo9/L<00_o@]/401Oo;_/godL?=om73cOoFblkob/cK0080c=3M00@0_lgU0;k>i`2n
c^L0]<WZ0P2cbN/0102^a^/0[LG[0:g5j`2[a>/cooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool000Wooooo00@00000oooooooooooooooo0P00002501TI6BH000001?ooool0
0`00003oooooooooo`0Looooo`03o`000?oooooooooo02_ooooo00CoVk[^oiJgk_nB/>_oT[3[0_n>
Y^D2oh^Kg@;oRi7D0_n>R//2oi>6``;oVHJn0_nNQkX3ojB;^@;oZHnj00?o[YFmojn?]?n_Sk@00_nd
U[T3ok^L^0?o`jFk00?obJRholVa`oo@]/400_o@]/401_oH_/3odL?=omK;c_oFblh0f];A0<c@g@80
c=CP00@0_/kW0;c>j02ic^X0^LkZ0P2ab>/00`2]aN_oooooooooo`0dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo0P00002501TI
6BH000001?ooool00`00003oooooooooo`0Mooooo`03o`000?oooooooooo02cooooo00?oU[O^oi:`
jonB/>/00_n>Y^D2oh^Kg@;oRi7D0_n>R//01?nCQ/?oVHJnoiV6__nIQ[h2oij7^P;oY8^i00?oZHnj
ojZ8/On_Sk@00_n_Sk@00ondU[Wo]i>bokNC/P02ok^L^005ol6L/oo3YK_obJRholVX^?oA[[H00oo@
]/400ooH_/3oglO1omK;cP020=[Bd@060=_Je@3<e>00bMKT0<WFi035e^L0^LkZ>_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooo`80
0000Q00I6ATW000000Cooooo00<00000ooooooooool07_ooool2o`0002gooooo0_n?/Nd2ohNVj@;o
O8[F0_mmOl/2ohj:b`;oThK30_nIQ[h2oij7^P03ojB;^OnSPk7oZXRa00;oZXRa0_n_Sk@3okNC/P03
ok^L^?o1W;?o`Ibc00?obJRh0_oA[[H01_o@]/7of;k0omRn`?oOal40i];30=[Bd@80fm[E00<0f]oJ
0<WFi035e^L0?Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0009oooo
o`0400000?ooooooooooooooo`800000Q00I6ATW000000Cooooo00<00000ooooooooool08?ooool0
0ol0003oooooooooo`0[ooooo`04ohBYkOmfVNKoMYWVofZ5f`;oO8[F00?oOGo;oh=j`On3N/400_n;
NKT01?nIQ[koU7Zdoian/OnLO[42oj>3/@?oZXRa00?o[hndok:<[_ngTk800_ngTk83ol6L/`03olNP
/?o9Z;SodJjf00;odJjf0_oH_/02omo7`@040>KB``3ZgLH0fm[E0=[OfP80eN;P?oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooo`80
0000P`0I6ATX000000Cooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0Zooooo`;o
LIk/0_mfVNH01OmZQM_oIWG>ogeobommOl_oPg[100;oRgVi0_nDN[@2oian/@?oXh>a0_nZR;43ok:<
[P;o]i>b00Go_9B]ol6L/oo7X;3oaj2`olVX^003om6^]P03omZg]OoH_/3oglO10080i];300@0j]g6
0>[Wb`3WkM80eN;P@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009
ooooo`0400000?ooooooooooooooo`<00000PP0I6ATX000000Cooooo00<00000ooooooooool08_oo
ool00ol0003oooooooooo`0Zooooo`;oLIk/00?oFXGRodQ/dom8K=<00_mZK<42oh=j`@04oh]i^OnD
N[CoU7ZdoiAj]0;oW7ja0_nSPk400onZR;7o[8F/ok:<[P02ok:<[P04okNC/_nlU:go_9B]ol6L/`;o
aj2`00?od:J^om6^]_oA[[H00_oJ]kD01?oT`kGoglO10>KB``3ZgLH20>[Wb`030>O]d_oooooooooo
043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003o
ooooooooooooool3000008406ATI:@000004ooooo`0300000?oooooooooo02?ooooo00?o0000oooo
ooooool0:_ooool01_mFSNWo<6WIoc1YfOm8K=?oIWG>ofY/`@;oMFZh0_n;NKT2oiAj]0;oW7ja00?o
Xh>aojAnZon/QJ`00_n/QJ`2ok:<[P?o_9B]0oo7X;02om2V[P09om6^]_oJ]kGof[NeonC3]@3]d;H0
m=jf0?KZ^03Zil/0ingB04Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`002Oooool01000003oooooooooooooool3000008006ATI:P000004ooooo`0300000?oooooooooo
02Cooooo0_l0000[ooooo`05obeeh_l`JMWo5DO3odQ/domZK<400_meJ[P2oh9]/P;oU7Zd00CoW7ja
oiYh[?nTOZ_oY7j[0on/QJ`2ok:<[P?o_9B]00?o`iR[olNP/?o@YZh00_o@YZh2omZg]@;oi<>e00@0
kM2f0?CN]P3fj[P0l_BkA_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
0009ooooo`0400000?ooooooooooooooo`<00000O`0I6AT[000000Cooooo00<00000ooooooooool0
9_ooool00ol0003oooooooooo`0Yooooo`06o`0o`ol`JMWo5DO3oe1E^?mZK<7oMFZh0_n2KK82ohmb
[P;oVWR/0onTOZ/2ojb5[004ok:<[_ngSJ[o]hfZokbD[@;o`iR[00Woaj2`om2V[_o@YZkod:J^omZ`
[_oJ]kGoi<>e0>g@]P3dg[H00P3fj[Q7ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool000Wooooo00@00000oooooooooooooooo0`00001n01TI6B`000001?ooool00`00003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Wooooo00Co03o3oaE7`om5F/?oD5Fh0_meJ[P00on2
KK;oSg:^ohmb[P02oiYh[0?oY7j[0_n/QJ`3okN=ZP03okbD[Oo3V:_o`iR[00?od:J^0_oJ/:h01OoV
_Jgoi<>e0>g@]P3dg[H0m^Zh04Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`002Oooool01000003oooooooooooooool3000007h06ATI;0000004ooooo`0300000?oooooo
oooo02Sooooo00?o0000ooooooooool0:Oooool00ol04j?o5DO3oe1E^002ofAI/@;oPVfb0_n?LZh2
oiYh[0;oY7j[00?o[8F/ojn5Z?ngSJX00_ngSJX3ol>HZ`03olbOZ_o@YZkod:J^00;of[2^00Goi[f]
0?7=[03jgZP0n^^R0?3aW01:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool000Wooooo00@00000oooooooooooooooo0`00001m01TI6Bd000001?ooool00`00003ooooooooo
o`0Yooooo`;o0000:Oooool00ol01iKo01>Soe1E^002ofAI/@04ogUR[?n2KK;oSg:^ohmb[P;oVWR/
0_nTOZ/3ojn5Z0;o]hfZ0_o3V:/3olbOZP07om2V[_oJ/:koi[f]onJm[@3acJ`0n]jX0?[[XP1<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooo
oooooooo1000001k01TI6Bh000001?ooool00`00003oooooooooo`0[ooooo`03o`000?oooooooooo
02Oooooo00Co01>Soa@f/om@EKSoI5Va0_miHZ`2ohmb[P;oVWR/00?oY7j[ojImYon_QJP00_n_QJP0
1?ngSJ[o_I2Xokf@Z?o3V:/3olbOZP;of[2^00Goi[f]0?7=[03jgZP0n^^R0?3aW01<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo
1000001j01TI6@03o`0000000000000002`000001?ooool00`00003oooooooooo`0/ooooo`03o`00
0?oooooooooo02Kooooo00@0YBl0o`0CXolZ>:coI5Va0_miHZ`2oh]/Z@;oVWFX0_nVOJL3ojn5Z0?o
_I2X00[o`iR[olbOZ_o<Wj[oc9nZomNZZOoJ/:koi[f]0?7=[03jgZP0n^^RC_ooool01Ol0003ooooo
oooooooooooo000000_ooooo0009ooooo`0400000?ooooooooooooooo`@00000N00I6ATa000000Co
oooo00<00000ooooooooool0;Oooool00ol0003oooooooooo`0Vooooo`05o`00Iol00YCoI5VaofAI
/OmiHZ`00_n;K:T2oiYeZ0?oYWfW0_n_QJP3okf@Z0?oc9nZ0_oGZZT01OoU^JWoi[f]0?7=[03jgZP0
g>9c04oooooo00Co0000oooooooooooo00002oooool000Wooooo00@00000oooooooooooooooo1000
001g01TI6C8000001?ooool00`00003oooooooooo`0^ooooo`;o00009oooool01?l00YCoBdJZofAI
/OmiHZ`2oh]/Z@;oVWFX0onVOJL00on_QJSo]HRWokF8Y`02okf@Z003olJHYoo<Wj[oejZY00;oejZY
00CoiKVY0??<YP3mgYh0mnR<DOooool00ol0003oooooo`00000;ooooo`002Oooool01000003ooooo
ooooooooool4000007H06ATI00?o0000000000000000<0000004ooooo`0300000?oooooooooo033o
oooo00?o0000ooooooooool09?ooool00ol006Oo:SR/od]6ZP02ogUR[0;oRfbY0_nJMJP2ojImY`04
ojn5Z?neR:Oo]HRWokf@Z0;oaYRW00?oc9nZomNZZOoGZZT00_oU^JT00`3cc:H0oMjN0=cRL`1Aoooo
o`03o`000?oooooo000000_ooooo0009ooooo`0400000?ooooooooooooooo`@00000M00I6ATe0000
00Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Tooooo`04o`02U?m;AZ[oK5RY
ogUR[0;oRfbY0_nJMJP2ojImY`?o]HRW00?o_I2XolJHYoo6V:L00ooGZZT01?oU^JT0llbV0??<YP3g
j8aCooooo`03o`000?oooooo000000[ooooo0009ooooo`0400000?ooooooooooooooo`@00000L`0I
6ATf000000Cooooo00<00000ooooooooool0<_ooool00ol0003oooooooooo`0Sooooo`04o`00F?m;
AZ[oK5RYofaHZ@;oRfbY0_nJMJP00onVOJOoZGnVokF8Y`02okF8Y`?oaYRW00OodZ>XomNZZOoGZZWo
iKVY0??<YP3mgYh0mnR<05Cooooo0_l0000:ooooo`002Oooool01000003oooooooooooooool30000
01D06ATI3Ol0001A01TI6@03o`0000000000000003@000001?ooool00`00003oooooooooo`0coooo
o`;o00008oooool01?l0003oBdJZod]6Z_m/F:T2ohIWZ0;oVgFW0onYOjH2okF8Y`;oaYRW0ooBXjP2
onFiZ@030??<YP3mgYkooooo05?ooooo0ol0000:ooooo`002Oooool01000003oooooooooooooool3
000001<06ATI0_l0000=03<c<`Co0000B`0I6ATi000000Cooooo00<00000ooooooooool0=Oooool0
0ol0003oooooooooo`0Pooooo`04o`000?lS:j;oBdJZofaHZ@;oQVNX0_nKMJL3ojUoYP04okF8Yonm
SjOo_HnWolJHY`?odZ>X00Coh[BX0??<YP3cc:H0mnR<D?ooool4o`0000gooooo0009ooooo`040000
0?ooooooooooooooo`<00000400I6AT3o`0001<0<c<c0_l0001601TI6C`000001?ooool00`00003o
ooooooooo`0fooooo`03o`000?oooooooooo01oooooo00Co0000oooooolS:j;oK5RY0_n6IjP2oi]e
Y`?oZGnV00Co]HRWokf?YonmSjOoaYRW0ooBXjP01?oR]:P0ll^U0?gNWP2/_d5=ooooo`?o00004Ooo
ool000Wooooo00@00000oooooooooooooooo0P00000@01TI6@03o`00000c<c<0<c<c01H0<c<c00?o
000001TI6@0I6AT0@00I6ATo000000Cooooo00<00000ooooooooool0=oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooo8b^R00;oK5RY0_n6IjP2oi]eY`;oZGnV0onmSjL3om:SZ0;oh[BX00<0
ll^U0?gQUoooool0BOooool4o`0001Cooooo0009ooooo`0400000?ooooooooooooooo`8000003P0I
6AT2o`0001X0<c<c00?o000001TI6@0I6AT0?@0I6AU1000000Cooooo00<00000ooooooooool0>?oo
ool2o`0001kooooo00Go0000oooooolS:j;oF4^XofaHZ@02ohIWZ0;oVgFW0_nYOjH3okf?Y`?odZ>X
0_oR]:P00`3cbjD0i^5booooo`15ooooo`Co00006?ooool000Wooooo00@00000oooooooooooooooo
0P00000=01TI6@03o`00000c<c<0<c<c00P0<c<c2?l0000;03<c<`03o`00000I6AT06ATI03X06ATI
@`000004ooooo`0300000?oooooooooo03[ooooo00?o0000ooooooooool06oooool01Ol0003ooooo
o`00R_lS:j;oF4^X00;oQVNX0_nKMJL00onYOjKo/8FWokf?Y`02okf?Y`06olVKZ?oBXjSoh[BXon:d
Z03cbjD0oN6G@oooool4o`0001cooooo0009ooooo`0400000?ooooooooooooooo`800000300I6AT0
0ol00000<c<c03<c<`0503<c<`Co0000201<C4`3o`0000P0<c<c00?o000001TI6@0I6AT0<`0I6AU:
000000Cooooo00<00000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooo
ooooob<[X_mHBjP00_n1IJT00onKMJOoWGRYok25Y`02ok25Y`04okf?Yoo9VjSobI^Xom:SZ0;oh[BX
00<0ll^U0?gQUoooool0?oooool3o`00023ooooo0009ooooo`0500000?ooooooooooooooo`000000
300I6AT00ol00000<c<c03<c<`0403<c<`;o00003`1<C4`3o`0000H0<c<c00?o000001TI6@0I6AT0
:@0I6AT00ol000006ATI0000001@000000Cooooo00<00000ooooooooool0??ooool00ol0003ooooo
ooooo`0Iooooo`05o`000?ooooooooooo`00R_mHBjP00_n1IJT2oiehZ@?o/8FW00Co_HnWolVKZ?o9
VjSofjn[0_oR]:P00`3cbjD0i^5booooo`0kooooo`Co00008oooool000Wooooo00D00000oooooooo
oooooooo0000000;01TI6@03o`00000c<c<0<c<c00@0<c<c0_l0000804a<C0Go00001P1<C4`00ol0
0000<c<c03<c<`0403<c<`03o`00000I6AT06ATI01D06ATIIP000004ooooo`0300000?oooooooooo
03gooooo0_l0000Iooooo`05o`000?ooooooooooo`00R_mHBjP00_n1IJT2oiehZ@?o/8FW00?o_HnW
olVKZ?o9VjP00_oK[j/00`3cbjD0oN6Gooooo`0hooooo`Co00009oooool000Wooooo00D00000oooo
oooooooooooo0000000:01TI6@03o`00000c<c<0<c<c00<0<c<c0_l0000404a<C0Ko00001@1VIVH2
o`0000D0C4a<0_l0000503<c<`03o`00000I6AT06ATI01406ATIJ@000004ooooo`0300000?oooooo
oooo03oooooo00?o0000ooooooooool05_ooool01ol0003ooooooooooooooooo<SNWoeQ;Z?n1IJT0
0onMN:T2ok25Y`;obI^X0ooK[j/00`3bc:X0n^NCooooo`0dooooo`Co0000:oooool000Wooooo00D0
0000oooooooooooooooo0000000901TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`0
0P1<C4`2o`0000d0IVIV0_l0000504a<C003o`00000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT0
3`0I6AUZ000000Cooooo00<00000ooooooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00;ooooo00Co002:oeQ;Z?n1IJWoPFFY0_nMN:T2ok25Y`;obI^X0ooK[j/00`3bc:X0
^<M:ooooo`0aooooo`?o0000;oooool000Wooooo00@00000oooooooooooooooo2@0I6AT00ol00000
<c<c03<c<`0303<c<`04o`00001<C4`0C4a<04a<C0;o00001@1VIVH8o`0000@0IVIV0_l0000404a<
C003o`00000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT03@0I6AU[000000Cooooo00<00000oooo
ooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co002:oc8g
Yon1IJWoPFFY0_nMN:T01?n`QJOo^i6[ok^AZoo9VjP2om^_Z`030?;<ZP3jii?ooooo02kooooo1?l0
000booooo`002Oooool01000003oooooooooooooool901TI6@03o`00000c<c<0<c<c0080<c<c00Go
000004a<C01<C4`0C4a<o`00000406IVIP?o0000201oOgl2o`0000@0IVIV00?o000004a<C01<C4`0
0P1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00d06ATIJ`000004ooooo`030000
0?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo00Go<SNWogUU[omiIJoo
WGRYoj>1[P03ok^AZ`?ofjn[00<0l/bZ0?[WToooool0:_ooool4o`0003Kooooo0009ooooo`040000
0?ooooooooooooooo`P06ATI00?o000003<c<`0c<c<00`0c<c<01?l00000C4a<04a<C?l0000306IV
IP;o00003@1oOgl2o`0000<0IVIV00Go000004a<C01<C4`0C4a<o`00000403<c<`03o`00000I6AT0
6ATI00`06ATIK0000004ooooo`0300000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`03ooooo`03oc8gYomiIJooNFF_00;oXh6^0onkTJ/01?o>Y[7ofjn[om^_Z`3b
c:XXooooo`Co0000>_ooool000Wooooo00@00000oooooooooooooooo200I6AT00ol00000<c<c03<c
<`0203<c<`05o`00001<C4`0C4a<04a<C?l000000P1VIVH00ol00000Ogmo07moO`0307moO`So0000
101oOgl01?l00000IVIV06IVI_l0000404a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I
6AT02P0I6AU]000000Cooooo00<00000ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Cooooo00?o<SNWogUU[onSPJh00_nSPJh2ok^AZ`;ocZJa00<0l/bZ0?[WTooo
ool08oooool4o`0003kooooo0009ooooo`0400000?ooooooooooooooo`L06ATI00?o000003<c<`0c
<c<00P0c<c<01Ol00000C4a<04a<C01<C4co00000080IVIV00Co000007moO`1oOgl0Ogmo0ol00008
09VIV@;o00000`1oOgl01?l00000IVIV06IVI_l0000304a<C003o`00000c<c<0<c<c0080<c<c0_l0
000:01TI6Fh000001?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?ooool00ol009;oNFF_ogUU[`02oj>1[P06ok^AZoo>Y[7ocZJaoljV/@3/d;P0
h^f;8Oooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooo`L06ATI00Go000003<c<`0c
<c<0<c<co`00000304a<C004o`00001VIVH0IVIVo`000080Ogmo0_l0000309VIV@Oo00000`2IVIT2
o`00000307moOol00000IVIV0080IVIV00Co000004a<C01<C4co00001@0c<c<00ol000006ATI01TI
6@0801TI6Fh000001?ooool00`00003oooooooooo`17ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01?ooool00ol009;oIFS1ogUU[`02oj>1[PCocZJa00<0k=2hooooooooool07?oo
ool4o`0004Gooooo0009ooooo`0400000?ooooooooooooooo`H06ATI00Go000003<c<`0c<c<0<c<c
o`00000304a<C004o`00001VIVH0IVIVo`000080Ogmo00?o000009VIV@2IVIT00ol000070;>c/`03
o`00002IVIT0VIVI0080VIVI00?o000007moOol000000`1VIVH01?l00000C4a<04a<C?l0000503<c
<`03o`00000I6AT06ATI00L06ATIKP000004ooooo`0300000?oooooooooo04Sooooo0_l0000=oooo
o`03o`000?oooooooooo00Gooooo0_mUJ<400onSPJko/9Jkok2F^`02oljV/@030>c@^03RkH_ooooo
01Wooooo1?l00019ooooo`002Oooool01000003oooooooooooooool501TI6@03o`00000c<c<0<c<c
0080<c<c00Co000004a<C01<C4co00000P1VIVH01Ol00000Ogmo07moOol00000VIVI00;o00000`2c
/k<4o`0000@0/k>c0_l0000309VIV@04o`00001oOgoo0000o`000080IVIV00Co000004a<C01<C4co
0000100c<c<00ol000006ATI01TI6@0701TI6Fh000001?ooool00`00003oooooooooo`1:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol009;oIFS1ok2F^`02ok2F^`03
oljV/@3/d;P0k=2h01Oooooo1?l0001=ooooo`002Oooool01000003oooooooooooooool501TI6@03
o`00000c<c<0<c<c0080<c<c00Co000004a<C01<C4co00000P1VIVH01Ol00000Ogmoo`00002IVIWo
000000@0/k>c00?o00000<c<c03<c<`00P3<c<`4o`000080/k>c00Co000009VIV@2IVIWo00000P1o
Ogl01?l00000IVIV06IVI_l0000204a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0
1`0I6AU^000000Cooooo00<00000ooooooooool0Boooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Kooooo0_mUJ<42ok2F^`80d=KN00<0k=2hooooooooool04_ooool3o`00057ooooo
0009ooooo`0400000?ooooooooooooooo`D06ATI00Go000003<c<`0c<c<0<c<co`00000204a<C006
o`00001VIVH0IVIVo`00001oOgoo00000P2IVIT00ol00000/k>c0;>c/`02o`0000T0c<c<00Co0000
0;>c/`2c/k?o00000P2IVIT00ol00000Ogmoo`00000206IVIP04o`00001<C4`0C4a<o`0000@0<c<c
00?o000001TI6@0I6AT01P0I6AU_000000Cooooo00<00000ooooooooool0C?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o/9Jk0=3FgP3@e]h04_ooool4o`0005Cooooo
0009ooooo`0400000?ooooooooooooooo`@06ATI00?o000003<c<`0c<c<00P0c<c<01?l00000C4a<
04a<C?l0000206IVIP05o`00001oOgoo000009VIVOl000000P2c/k<00ol00000c<c<0<c<c0020<c<
c0Go00000`3<c<`01_l00000/k>c0;>c/ol00000VIVIo`000080Ogmo00Co000006IVIP1VIVKo0000
0P1<C4`01Ol00000<c<c03<c<`0c<c?o000000P06ATI00?o0000000000000000K0000004ooooo`03
00000?oooooooooo04gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001Hooooo`00
2Oooool01000003oooooooooooooool401TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`01_l0
0000IVIV06IVI_l00000Ogmoo`000080VIVI0ol000020<c<c0?o0000103Vi^H2o`0000<0c<c<00?o
00000;>c/ol000000P2IVIT00ol00000Ogmoo`00000206IVIP04o`00001<C4`0C4a<o`0000<0<c<c
00?o000001TI6@0I6AT01P0I6AU_000000Cooooo00<00000ooooooooool0Coooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0001Looooo`002Oooool01000003ooooooooo
ooooool401TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`02_l00000IVIV06IVI_l00000Ogmo
o`00002IVIWo00000;>c/ol000020<c<c003o`00003Vi^H0i^KV00L0i^KV00Ko00000<c<c03<c<co
00000;>c/ol0000209VIV@03o`00001oOgoo00000080IVIV00Co000004a<C01<C4co00000`0c<c<0
0ol000006ATI01TI6@0601TI6Fl000001?ooool00`00003oooooooooo`1@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009ooooo`0400000?oooooooooo
ooooo`<06ATI00Go000003<c<`0c<c<0<c<co`00000204a<C00:o`00001VIVH0IVIVo`00001oOgoo
000009VIVOl00000/k>co`000080c<c<00Co00000>KViP3Vi^H0i^KV100000040>KViP08o`00003<
c<`0c<c<o`00002c/k?o000009VIVOl0000207moO`06o`00001VIVH0IVIVo`00001<C4co00000`0c
<c<00ol000006ATI01TI6@0501TI6G0000001?ooool00`00003oooooooooo`1Aooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?oooooo
ooooooooo`<06ATI00Go000003<c<`0c<c<0<c<co`00000204a<C005o`00001VIVKo000007moOol0
00000P2IVIT01Ol00000/k>co`00003<c<co000000<0i^KV00<000000?ooo`3oool00P3oool20000
00<0i^KV00?o00000<c<c?l000000P2c/k<01Ol00000VIVIo`00001oOgoo00000080IVIV00?o0000
04a<C?l000000`0c<c<00ol000006ATI01TI6@0501TI6G0000001?ooool00`00003oooooooooo`1B
ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000Ioooool000Wooooo00@00000oooo
oooooooooooo0`0I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00Go000006IVI_l00000Ogmo
o`00000209VIV@05o`00002c/k?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`040?ooo`07
0000003Vi^H0i^KV0>KVi_l00000c<c<o`0000020;>c/`05o`00002IVIWo000007moOol000000P1V
IVH00ol00000C4a<o`00000303<c<`03o`00000I6AT06ATI00D06ATIL0000004ooooo`0300000?oo
oooooooo05Cooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`0400000?oo
ooooooooooooo`<06ATI00Wo000003<c<`0c<c<0<c<co`00001<C4co000006IVI_l000000P1oOgl0
1ol00000VIVIo`00002c/k?o00000<c<c?l000000P3Vi^H00`000000oooo0?ooo`060?ooo`0=0000
003Vi^H0i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIVOl00000Ogmoo`00000206IVIP03o`00
001<C4co000000<0<c<c00?o000001TI6@0I6AT01@0I6AU`000000Cooooo00<00000ooooooooool0
EOooool00ol0003oooooo`000005ooooo`?o0000Koooool000Wooooo00@00000oooooooooooooooo
0`0I6AT01?l00000<c<c03<c<ol0000204a<C003o`00001VIVKo00000080Ogmo00Wo000009VIVOl0
0000/k>co`00003<c<co00000>KViP0000002P3oool030000000i^KV0>KVi_l00000c<c<o`00002c
/k?o000009VIVOl00000Ogmoo`000080IVIV00?o000004a<C?l000000`0c<c<00ol000006ATI01TI
6@0501TI6G0000001?ooool00`00003oooooooooo`1Fooooo`;o000000?oooooo`000?l000000_l0
001booooo`002Oooool01000003oooooooooooooool301TI6@04o`00000c<c<0<c<co`000080C4a<
00?o000006IVI_l000000P1oOgl02Ol00000VIVIo`00002c/k?o00000<c<c?l00000i^KV0000000:
0?ooo`0<0000003Vi^H0i^KVo`00003<c<co00000;>c/ol00000VIVIo`00001oOgoo00000P1VIVH0
0ol00000C4a<o`00000303<c<`03o`00000I6AT06ATI00D06ATIL0000004ooooo`0300000?oooooo
oooo05Oooooo0_l0001fooooo`002Oooool01000003oooooooooooooool301TI6@04o`00000c<c<0
<c<co`000080C4a<00?o000006IVI_l000000P1oOgl02Ol00000VIVIo`00002c/k?o00000<c<c?l0
0000i^KV0000000:0?ooo`0<0000003Vi^H0i^KVo`00003<c<co00000;>c/ol00000VIVIo`00001o
Ogoo00000P1VIVH00ol00000C4a<o`00000303<c<`03o`00000I6AT06ATI00D06ATIL0000004oooo
o`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00Co000003<c
<`0c<c?o00000P1<C4`02Ol00000IVIVo`00001oOgoo000009VIVOl00000/k>co`0000020<c<c003
o`00003Vi^H0000000X0oooo00D000000>KVi_l00000c<c<o`0000020;>c/`07o`00002IVIWo0000
07moOol00000IVIVo`00000204a<C005o`00000c<c<0<c<c03<c<ol000001P0I6AUa000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0`0I6AT01?l00000<c<c
03<c<ol0000204a<C009o`00001VIVKo000007moOol00000VIVIo`00002c/k?o00000080c<c<00?o
00000>KViP0000002P3oool01@000000i^KVo`00003<c<co00000080/k>c00Oo000009VIVOl00000
Ogmoo`00001VIVKo00000080C4a<00Go000003<c<`0c<c<0<c<co`00000601TI6G4000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool301TI6@04o`00000c<c<0
<c<co`000080C4a<00Wo000006IVI_l00000Ogmoo`00002IVIWo00000;>c/ol000000P3<c<`01?l0
0000i^KV0>KViP0000080?ooo`060000003Vi^H0i^KVo`00003<c<co00000P2c/k<2o`000080Ogmo
00?o000006IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000H06ATIL@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00Co000003<c<`0c
<c?o00000P1<C4`03?l00000IVIV06IVI_l00000Ogmoo`00002IVIWo00000;>c/ol00000c<c<o`00
00<0i^KV0`0000020?ooo`<000000P3Vi^H00ol00000c<c<o`0000020;>c/`07o`00002IVIWo0000
07moOol00000IVIVo`00000204a<C005o`00000c<c<0<c<c03<c<ol000001P0I6AUb000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0`0I6AT01?l00000<c<c
03<c<ol0000204a<C00:o`00001VIVH0IVIVo`00001oOgoo000009VIVOl00000/k>co`000080c<c<
00?o00000>KViP3Vi^H00`3Vi^H2000000@0i^KV00So00000<c<c03<c<co00000;>c/ol00000VIVI
o`000080Ogmo00?o000006IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000H06ATILP00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00Oo
000003<c<`0c<c<0<c<co`00001<C4co00000080IVIV00Oo000007moOol00000VIVIo`00002c/k?o
000000<0c<c<00?o00000>KViP3Vi^H01`3Vi^H01?l00000c<c<0<c<c?l000020;>c/`03o`00002I
VIWo00000080Ogmo00?o000006IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000H06ATI
LP000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<06ATI
00Oo000003<c<`0c<c<0<c<co`00001<C4co00000080IVIV00?o000007moOol000000P2IVIT00ol0
0000/k>co`0000030<c<c003o`00003Vi^H0i^KV00<0i^KV0ol000020<c<c004o`00002c/k<0/k>c
0;>c/`;o00000P1oOgl01_l00000IVIV06IVI_l00000C4a<o`0000<0<c<c00?o000001TI6@0I6AT0
100I6AUc000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
0`0I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00So000006IVIP1VIVKo000007moOol00000
VIVIo`000080/k>c00Co00000<c<c03<c<`0c<c<1Ol000050<c<c008o`00002c/k<0/k>co`00002I
VIWo000007moOol0000206IVIP04o`00001<C4`0C4a<o`0000<0<c<c00?o000001TI6@0I6AT0100I
6AUc000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo100I
6AT01?l00000<c<c03<c<ol0000204a<C006o`00001VIVH0IVIVo`00001oOgoo00000P2IVIT00ol0
0000/k>c0;>c/`03o`0000P0c<c<0_l000001@2c/k?o0000o`00002IVIWo00000080Ogmo00?o0000
06IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000H06ATIM0000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`@06ATI00Co000003<c<`0c<c?o0000
0P1<C4`01ol00000IVIV06IVIP1VIVKo000007moOol000000P2IVIT00ol00000/k>c0;>c/`020;>c
/`?o00000P3<c<`3o`0000030;>c/ol0003o00000080VIVI00Co000007moO`1oOgoo00000P1VIVH0
1?l00000C4a<04a<C?l0000303<c<`03o`00000I6AT06ATI00@06ATIM0000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00Co000003<c<`0c<c?o0000
0P1<C4`01?l00000IVIV06IVI_l0000207moO`03o`00002IVIT0VIVI00?o0000102c/k<2o`0000<0
/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIVo`000080C4a<00Go0000
03<c<`0c<c<0<c<co`00000601TI6GD000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool501TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`01?l00000IVIV
06IVI_l0000207moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<01@2c/k<01Ol00000
VIVI09VIV@2IVIWo00000080Ogmo00Co000006IVIP1VIVKo00000P1<C4`2o`0000<0<c<c00?o0000
01TI6@0I6AT00`0I6AUf000000Cooooo00<00000ooooooooool0coooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
coooool000Wooooo]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00017o
oooo]_l0000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Uooooo`030000oooooooooooo02[ooooo00?o003oooooooooool0:oooool00ol00?oooooooooo
o`0_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@0U0?nf`@030000o`3o]/40okK102X0okK100?o003o
0?nf`@3o]/40:`3o]/400ol00?l0okK10?nf`@0:0?nf`BGooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/40903o]/400`000?l0okK10?nf`@0/0?nf`@03o`00o`3o]/40okK102/0okK100?o003o0?nf
`@3o]/402@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uoooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK102@0okK100<0003o0?nf`@3o
]/40;03o]/400ol00?l0okK10?nf`@0[0?nf`@03o`00o`3o]/40okK100T0okK19Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0S0?nf`@030000o`3o]/40okK102d0okK100?o003o0?nf`@3o]/40
:`3o]/400ol00?l0okK10?nf`@090?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408`3o
]/400`000?l0okK10?nf`@0]0?nf`@03o`00o`3o]/40okK102`0okK100?o003o0?nf`@3o]/40203o
]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK102<0okK100<0003o0?nf`@3o]/40;@3o]/40
0ol00?l0okK10?nf`@0/0?nf`@03o`00o`3o]/40okK100P0okK19Oooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0S0?nf`@030000o`3o]/40okK102d0okK100?o003o0?nf`@3o]/40;@3o]/400ol0
0?l0okK10?nf`@070?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf
`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/400`000?l0
okK10?nf`@0_0?nf`@03o`00o`3o]/40okK102`0okK100?o003o0?nf`@3o]/401`3o]/4Uooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK10280okK100<0003o0?nf`@3o]/40;`3o]/400ol00?l0okK1
0?nf`@0]0?nf`@03o`00o`3o]/40okK100H0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@0R0?nf`@030000o`3o]/40okK102l0okK100?o003o0?nf`@3o]/40;@3o]/400ol00?l0okK10?nf
`@060?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0g0?nf`@/0000000?o
00000?nf`@3o]/40B03o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK10200okK10ol0000a0?nf`@03o`00o`3o]/40okK102d0okK100?o003o0?nf`@3o]/401P3o]/4U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40<P3o]/4200000003o`0000000000
000000`0okK11P0000140?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/407`3o]/45o`000300okK100?o003o0?nf`@3o]/40;P3o]/400ol00?l0okK10?nf`@050?nf
`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0_0?nf`@<000005`3o]/430000
0440okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0O0?nf`@Go
0000<03o]/400ol00?l0okK10?nf`@0^0?nf`@03o`00o`3o]/40okK100D0okK19Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK102`0okK10`00000M0?nf`@@00000?@3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101l0okK11Ol0000`0?nf`@03o`00
o`3o]/40okK102h0okK100?o003o0?nf`@3o]/401@3o]/4Uooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3o]/40:03o]/401000003o000000000000000T0?nf`@@00000>@3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100/0okK12P000?l;0?nf`@?o0000
<@3o]/400ol00?l0okK10?nf`@0^0?nf`@03o`00o`3o]/40okK100D0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK102L0okK100<000000?nf`@3o]/40:P3o]/43000003H0okK1
9Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@030?nf`@P0003o2P3o
]/420000o`?o003o1`3o]/400`000?l0okK10?nf`@0`0?nf`@03o`00o`3o]/40okK102h0okK100?o
003o0?nf`@3o]/401@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/409P3o
]/400`000000okK10?nf`@0^0?nf`@800000=03o]/4Uooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK100<0003o5`3o]/45o`00o`030?nf`@000?l0okK10340okK100?o003o
0?nf`@3o]/40;`3o]/400ol00?l0okK10?nf`@050?nf`BGooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?nf`@0U0?nf`@030000003o]/40okK10340okK100<000000?nf`@3o]/40<@3o]/4U
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0003o01l0okK100?o003o0000
ool00?l0<@3o]/400ol00?l0okK10?nf`@0_0?nf`@03o`00o`3o]/40okK100D0okK19Oooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0okK102<0okK10P00000e0?nf`@03o`00000000000000
0300okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0P0?nf`@04
0000o`3o]/7o003oo`00obl0okK100?o003o0?nf`@3o]/40;`3o]/400ol00?l0okK10?nf`@050?nf
`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0R0?nf`@030000003o]/40okK1
03P0okK10P00000^0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/40803o]/401?l00?l0okK10?nf`@3o]/42o`00obd0okK100?o003o0?nf`@3o]/40;`3o]/400ol0
0?l0okK10?nf`@050?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0Q0?nf
`@030000003o]/40okK103/0okK10P00000/0?nf`BGooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/40803o]/400ol00?l0okK10?nf`@030?nf`@?o003o:03o]/43o`000340
okK100?o003o0?nf`@3o]/401@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
]/40803o]/400`000000okK10?nf`@0n0?nf`@03o`00003o]/40okK102T0okK19Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0P0?nf`@03o`00o`3o]/40okK100H0okK1
0ol00?lT0?nf`@Go0000<03o]/400ol00?l0okK10?nf`@050?nf`BGooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?nf`@0P0?nf`@030000003o]/40okK103l0okK10P00000Y0?nf`BGooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40803o]/400ol00?l0okK10?nf
`@090?nf`@03o`00o`3o]/40okK10240okK11Ol0000`0?nf`@03o`00o`3o]/40okK100D0okK19Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK101l0okK100<000000?nf`@3o]/40@P3o
]/42000002L0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0P
0?nf`@03o`00o`3o]/40okK100X0okK100?o003o0?nf`@3o]/40803o]/45o`000300okK100?o003o
0?nf`@3o]/401@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/407P3o]/40
0`000000okK10?nf`@150?nf`@03o`00003o]/40okK102@0okK19Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0P0?nf`@03o`00o`3o]/40okK100/0okK10_l00?lQ0?nf
`@?o0000<@3o]/400ol00?l0okK10?nf`@050?nf`BGooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?nf`@0M0?nf`@030000003o]/40okK104L0okK10P00000T0?nf`BGooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/40803o]/400ol00?l0okK10?nf`@0=0?nf`@03
o`00o`3o]/40okK101l0okK100?o003o0?nf`@3o]/40<03o]/400ol00?l0okK10?nf`@050?nf`BGo
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0L0?nf`@030000003o]/40okK104X0
okK10P00000R0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
803o]/400ol00?l0okK10?nf`@0>0?nf`@03o`00o`3o]/40okK101h0okK100?o003o0?nf`@3o]/40
<03o]/400ol00?l0okK10?nf`@050?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@0K0?nf`@030000003o]/40okK104d0okK100<000000?nf`@3o]/407`3o]/4Uooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10200okK100?o003o0?nf`@3o]/403`3o
]/42o`00oad0okK100?o003o0?nf`@3o]/40<@3o]/400ol00?l0okK10?nf`@050?nf`BGooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@0K0?nf`@03o`00003o]/40okK104h0okK100?o
00000?nf`@3o]/407P3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK10200okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@0J0?nf`@03o`00o`3o]/40
okK10340okK100?o003o0?nf`@3o]/401@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3o]/406`3o]/400`000000okK10?nf`@1?0?nf`@030000003o]/40okK101d0okK19Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0P0?nf`@03o`00o`3o]/40okK1
0180okK100?o003o0?nf`@3o]/40603o]/400ol00?l0okK10?nf`@0b0?nf`@03o`00o`3o]/40okK1
00D0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK101X0okK100<000000?nf
`@3o]/40D@3o]/400`000000okK10?nf`@0L0?nf`BGooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/408@3o]/400ol00?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK101L0
okK100?o003o0?nf`@3o]/40<@3o]/400ol00?l0okK10?nf`@060?nf`BGooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@0I0?nf`@030000003o]/40okK105<0okK100<000000?nf`@3o
]/406`3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10240okK1
00?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK10340okK1
00?o003o0?nf`@3o]/401P3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40
603o]/400`000000okK10?nf`@1E0?nf`@8000006`3o]/4Uooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK10240okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf
`@0E0?nf`@03o`00o`3o]/40okK10380okK100?o003o0?nf`@3o]/401P3o]/4Uooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/40603o]/400ol00000okK10?nf`@1G0?nf`@030000003o
]/40okK101P0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0Q
0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0b
0?nf`@03o`00o`3o]/40okK100H0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK101P0okK100<000000?nf`@3o]/40F03o]/400`000000okK10?nf`@0G0?nf`BGooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408@3o]/400ol00?l0okK10?nf`@0E0?nf
`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/40<`3o]/400ol00?l0okK10?nf`@060?nf
`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0G0?nf`@030000003o]/40okK1
05X0okK100<000000?nf`@3o]/405P3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK10280okK100?o003oooooooooool05Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo03;ooooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0okK101L0okK100<000000?nf`@3o]/40203o]/5Booooo`0300000?oooooooooo03_o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/400ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0<oooool00ol00?oooooo
ooooo`0/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/405P3o]/400`000000okK1
0?nf`@090?nf`E?ooooo00<00000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0R0?nf`@03o`00oooooooooooo01Oooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo02cooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?nf`@0F0?nf`@030000003o]/40okK100T0okK1E?ooool00`00003ooooooooo
o`0iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK100?ooooo
o`00ooooool05oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo03Cooooo00?o003o
ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK101D0okK100<00000
0?nf`@3o]/402P3o]/5Eooooo`03o`000000003ooooo03Sooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/408P3o]/400ooooooo003oooooo`0Hooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3o]/405@3o]/400`000000okK10?nf`@0:0?nf`EOooooo00<00000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`@03
ooooool00?oooooo01Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0dooooo`03
o`00oooooooooooo02gooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0D0?nf`@03
0000003o]/40okK100/0okK1F?ooool00`00003oooooooooo`0eooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK10280okK10_ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0=?ooool2o`00oboooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?nf`@0D0?nf`@03o`00003o]/40okK100/0okK1FOooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK10_oo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0=Ooo
ool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40503o
]/400`000000okK10?nf`@0;0?nf`EWooooo00<00000ooooooooool0=?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`@;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool0;oooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0okK101<0okK100<000000?nf`@3o]/40303o]/5J
ooooo`0300000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/408P3o]/43ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`80003o3?l00?lPooooo`03o`00oooooooooooo02oooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@0C0?nf`@030000003o]/40okK100`0okK1Foooool00`00
003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280
okK10oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool30000o`kooooo1?l00?lLooooo`03o`00oooooooooooo02oooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@0B0?nf`@030000003o]/40okK100d0okK1G?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1
1?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1?ooool00ol00?l0003oooooo`0Dooooo`?o003o6?ooool00ol00?ooooooooooo`0`ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/404P3o]/400`000000okK10?nf`@0=0?nf`Ecooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@0R0?nf`@Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo0ol00?lJooooo`;o003o5_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/404P3o]/400`000000okK10?nf`@0=0?nf`Ecooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R
0?nf`@Gooooo00?o003oooooooooool05oooool01?l00?ooooooooooool00?l3ooooo`;o003o7ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?nf`@0A0?nf`@030000003o]/40okK100h0okK1GOooool00`00003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo003o0280okK11_ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool08?ooool2
o`00oa;ooooo00?o003oooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK10140okK100<000000?nf`@3o]/403P3o]/5Nooooo`0300000?oooooooooo02oooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/400_l00?lP0?nf`@Oooooo00?o003ooooo
ooooool05Oooool2o`00o`?ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo03;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0A0?nf
`@03o`00003o]/40okK100h0okK1Goooool00`00003oooooooooo`0^ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK10080okK100?o003o0?nf`@3o]/407@3o]/47ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`0Tooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0okK10140okK100<000000?nf`@3o]/403P3o]/5Pooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/400`3o]/400ol00?l0okK1
0?nf`@0L0?nf`@Oooooo00?o003oooooooooool04oooool01ol00?oooooooooooooooooo003ooooo
ool00?l0:?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo03?ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@0@0?nf`@030000003o]/40okK100l0okK1H?ooool00`00
003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100@0
okK10_l00?lL0?nf`@Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`;o
003o:_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo03Cooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@0@0?nf`@030000003o]/40okK100l0okK1H?ooool00`00003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100H0okK1
00?o003o0?nf`@3o]/406@3o]/49ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
=Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10100okK100<000000?nf`@3o]/40
3`3o]/5Qooooo`0300000?oooooooooo02cooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/401`3o]/400ol00?l0okK10?nf`@0H0?nf`@[ooooo0_l00?l<ooooo`?o003o1Ooo
ool00ol00?ooooooo`00o`0/ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0=_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100l0okK100<000000?nf`@3o]/40403o
]/5Qooooo`0300000?oooooooooo02cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/40203o]/42o`00oaP0okK13?ooool00ol00?ooooooooooo`07ooooo`;o003o1oooool0
1?l00?ooooooooooool00?l/ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0=ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100l0okK100<000000?nf`@3o]/40403o
]/5Rooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/402P3o]/43o`00oaD0okK13?ooool00ol00?ooooooooooo`05ooooo`;o003o2?ooool0
1Ol00?oooooooooooooooooo003o02gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0gooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/403`3o]/400`000000okK10?nf
`@0@0?nf`C3ooooo3000000Wooooo`0300000?oooooooooo02[ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/403@3o]/42o`00oa<0okK13Oooool01?l00?oooooooooooooo
ool3o`00o`[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0okK100h0okK100<000000?nf`@3o]/404@3o]/4]ooooo`<000003?ooool4000002Cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0?
0?nf`@;o003o4@3o]/4>ooooo`03o`00oooooooo003o00cooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0[ooooo`04o`00ooooooooooooo`00oc_ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?nf`@0>0?nf`@030000003o]/40okK10140okK1:_ooool3000001?ooooo0P00
000Rooooo`0300000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/404@3o]/44o`00o`d0okK13_ooool2o`00o`gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0/ooooo`;o003o??ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK100h0okK100<000000?nf`@3o]/404@3o]/4Yooooo`0300000?oooooooooo01Kooooo0P00000P
ooooo`0300000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/405@3o]/45o`00o`P0okK12_ooool4o`00o`;ooooo0_l00?l;ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0:_ooool3o`00ocgooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?nf`@0=0?nf`@030000003o]/40okK10180okK1:?ooool00`00003oooooooooo`0Ioooo
o`0300000?oooooooooo01kooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@0J0?nf`A;o003o2?ooool2o`00o`Sooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Yooooo`05o`00ooooooooooooooooool00?l0??ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0okK100d0okK100<000000?nf`@3o]/404P3o]/4Woooo
o`0300000?oooooooooo01_ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK15?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?nf`@0<0?nf`@030000003o]/40okK101<0okK19_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01gooooo00<00000ooooooooool09oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0R0?nf`AGooooo0_l00?l4ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool09Oooool2o`00o`Kooooo00?o003oooooooooool0>Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK100`0okK100<000000?nf`@3o]/404`3o]/4Uooooo`030000
0?oooooooooo01oooooo0P00000Mooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/4Gooooo`;o003o0_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo02?ooooo0_l00?l8ooooo`03o`00oooooooooooo03Wooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@0;0?nf`@030000003o]/40okK101@0okK19?oo
ool00`00003oooooooooo`0Rooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool09_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`AWooooo00?o003o
ooooool00?l02?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100/0okK100<00000
0?nf`@3o]/40503o]/4Sooooo`03o`000?oooooooooo02Cooooo00<00000ooooooooool06_ooool0
0`00003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
00h0okK10ol0000A0?nf`A[ooooo0_l00?l8ooooo`03o`00oooooooooooo023ooooo0_l00?l<oooo
o`03o`00oooooooooooo03Sooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0;0?nf
`@030000003o]/40okK101@0okK18oooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo
01[ooooo00<00000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0=0?nf`@Go0000403o]/4Jooooo`04o`00oooooooo003oo`00o`Kooooo00?o003ooooo
ooooool07_ooool2o`00o`kooooo00?o003oooooooooool0>?ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0okK100/0okK100<000000?nf`@3o]/40503o]/4Rooooo`0300000?oooooooooo
02Kooooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Uooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100d0okK11Ol0000@0?nf`A[ooooo00Co003ooooooooo
oooooooo0_l00?l4ooooo`03o`00oooooooooooo01_ooooo0ol00?l@ooooo`03o`00oooooooooooo
03Sooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0:0?nf`@030000003o]/40okK1
01D0okK18_ooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo01[ooooo00<00000oooo
ooooool09Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@Go
0000403o]/4Jooooo`03o`00oooooooooooo00?ooooo0ol00?l00ooooooo003oooooo`0Jooooo`co
003o2Oooool00ol00?ooooooooooo`0hooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
]/402P3o]/400`000000okK10?nf`@0E0?nf`B7ooooo00<00000ooooooooool0:?ooool00`00003o
ooooooooo`0Jooooo`0300000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/403P3o]/43o`0002/0okK100?o003o0?nf`@3o]/401P3o]/43o`00oa00okK1
0ol000040?nf`@Co003o2`3o]/43o`00o`H0okK100?o003o0?nf`@3o]/404`3o]/4Uooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/402P3o]/400`000000okK10?nf`@0e0?nf`@03o`00
003o]/40okK102T0okK100<000000?nf`@3o]/406P3o]/400`000000okK1ooooo`0Tooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103`0okK100?o003o0?nf`@3o]/401`3o
]/400ol00?l0okK1o`00o`09o`00o`<0okK10_l00?l5o`0000030000ool00?oo003o0180okK10_l0
0?l40?nf`@03o`00o`3o]/40okK101<0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0okK100T0okK100<000000?nf`@3o]/40=P3o]/400`000000okK10?nf`@0Z0?nf`@030000003o
]/40okK101X0okK100<00000ooooooooool08oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?nf`@0l0?nf`@03o`00o`3o]/40okK100L0okK100?o003o0?nf`@3o]/402@3o]/43
o`00o`80okK11Ol0000G0?nf`@;o003o0P3o]/400ol00?l0okK10?nf`@0C0?nf`BGooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?nf`@080?nf`@030000003o]/40okK103H0okK100<00000
0?nf`@3o]/40;03o]/400`000000okK10?nf`@0I0?nf`@0300000?oooooooooo02?ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40?03o]/400ol00?l0okK10?nf`@070?nf
`@03o`00o`3o]/40okK100h0okK11Ol0000I0?nf`@?o003o5@3o]/4Uooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3o]/40203o]/400`000000okK10?nf`@0f0?nf`@030000003o]/40okK1
02`0okK100<000000?nf`@3o]/406@3o]/400`00003oooooooooo`0Sooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK103`0okK100?o003o0?nf`@3o]/401`3o]/400ol00?l0
okK10?nf`@0=0?nf`@03o`00o`3o]/7o000000;o0000703o]/43o`00oa<0okK19Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK100P0okK100<000000?nf`@3o]/40=P3o]/400`000000
okK10?nf`@0]0?nf`@030000003o]/40okK101P0okK100<00000ooooooooool08oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0l0?nf`@03o`00o`3o]/40okK100L0okK1
00?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0O0?nf`@04o`00o`3o]/40okK1o`00oa80
okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100L0okK100<000000?nf`@3o
]/40=P3o]/400`000000okK10?nf`@0^0?nf`@030000003o]/40okK101P0okK100<00000oooooooo
ool08oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0l0?nf`@03o`00
o`3o]/40okK100H0okK100?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0P0?nf`@05o`00
o`3o]/40okK10?nf`Ol00?l04@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
]/401`3o]/400`000000okK10?nf`@0f0?nf`@030000003o]/40okK102l0okK100<000000?nf`@3o
]/405`3o]/400ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK103`0okK100?o003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0:0?nf`@;o003o
8`3o]/400ol00?l0okK10?nf`@020?nf`@03o`00o`3o]/40okK100h0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK100L0okK100<000000?nf`@3o]/40=P3o]/400`000000okK1
0?nf`@0_0?nf`@030000003o]/40okK101P0okK100<00000ooooooooool08_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0l0?nf`@03o`00o`3o]/40okK100H0okK100?o
003o0?nf`@3o]/402P3o]/400ol00?l0okK10?nf`@0R0?nf`@03o`00o`3o]/40okK100<0okK100?o
003o0?nf`@3o]/403@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/401P3o
]/400`000000okK10?nf`@0g0?nf`@030000003o]/40okK10300okK100<000000?nf`@3o]/405`3o
]/400`00003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK103`0okK100?o003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40
okK10280okK100?o003o0?nf`@3o]/40103o]/400ol00?l0okK10?nf`@0=0?nf`BGooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?nf`@060?nf`@030000003o]/40okK103L0okK100<00000
0?nf`@3o]/40<03o]/400`000000okK10?nf`@0G0?nf`@0300000?oooooooooo02;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40?@3o]/400ol00?l0okK10?nf`@050?nf
`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/408`3o]/400ol00?l0okK10?nf`@050?nf
`@03o`00o`3o]/40okK100`0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK1
00H0okK100<000000?nf`@3o]/40=`3o]/400`000000okK10?nf`@0`0?nf`@030000003o]/40okK1
01L0okK100<00000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0m0?nf`@03o`00o`3o]/40okK100@0okK100?o003o0?nf`@3o]/40203o]/400ol00?l0
okK10?nf`@0T0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/402`3o]/4Uooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3o]/401@3o]/400`000000okK10?nf`@0h0?nf`@03
0000003o]/40okK10300okK100<000000?nf`@3o]/405`3o]/400`00003oooooooooo`0Rooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103d0okK100?o003o0?nf`@3o]/40
103o]/400ol00?l0okK10?nf`@070?nf`@03o`00o`3o]/40okK102@0okK100?o003o0?nf`@3o]/40
203o]/400ol00?l0okK10?nf`@0:0?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@050?nf`@030000003o]/40okK103P0okK100<000000?nf`@3o]/40<@3o]/400`000000okK1
0?nf`@0F0?nf`@03ooooo`00003ooooo02;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/40?@3o]/400ol00?l0okK10?nf`@040?nf`@03o`00o`3o]/40okK100L0okK100?o
003o0?nf`@3o]/40903o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100X0okK19Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100@0okK100<000000?nf`@3o]/40>@3o
]/400`000000okK10?nf`@0a0?nf`@030000003o]/40okK101H0okK100?ooooo00000?ooool08_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0n0?nf`@03o`00o`3o]/40
okK10080okK100?o003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@0T0?nf`@03o`00o`3o]/40
okK100X0okK100?o003o0?nf`@3o]/402@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3o]/40103o]/400`000000okK10?nf`@0i0?nf`@030000003o]/40okK10340okK100<00000
0?nf`@3o]/405P3o]/400oooool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK101T0okK11P000?lO0?nf`@03o`00o`3o]/40okK10080okK100?o003o0?nf
`@3o]/401`3o]/400ol00?l0okK10?nf`@0T0?nf`@03o`00o`3o]/40okK100X0okK100?o003o0?nf
`@3o]/402@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40103o]/400`00
0000okK10?nf`@0i0?nf`@030000003o]/40okK10340okK100<000000?nf`@3o]/405P3o]/400ooo
ool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101@0
okK11@000?l60?nf`@H0003o6@3o]/400ol00?l0okK10?nf`@020?nf`@03o`00o`3o]/40okK100L0
okK100?o003o0?nf`@3o]/408`3o]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK100T0
okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100<0okK100<000000?nf`@3o
]/40>P3o]/400`000000okK10?nf`@0a0?nf`@030000003o]/40okK101H0okK100?ooooo00000?oo
ool08_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0A0?nf`@<0003o
4@3o]/400ol00?l0003o0000o`0G0?nf`@04o`00o`3o]/40okK1o`00o`T0okK100?o003o0?nf`@3o
]/40903o]/400ol00?l0okK10?nf`@0<0?nf`@03o`00o`3o]/40okK100P0okK19Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK100<0okK100<000000?nf`@3o]/40>P3o]/400`000000
okK10?nf`@0a0?nf`@030000003o]/40okK101H0okK100?ooooo00000?ooool08_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0>0?nf`@<0003o5`3o]/430000oaD0okK1
00?o003o0?nf`Ol00?l02@3o]/400ol00?l0okK10?nf`@0T0?nf`@03o`00o`3o]/40okK100`0okK1
00?o003o0?nf`@3o]/40203o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40
0`3o]/400`000000okK10?nf`@0j0?nf`@030000003o]/40okK10340okK100<000000?nf`@3o]/40
5P3o]/400oooool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK100`0okK10P000?lM0?nf`@<0003o4P3o]/400ol00?l0okK1o`00o`080?nf`@03o`00o`3o
]/40okK102@0okK100?o003o0?nf`@3o]/403P3o]/400ol00?l0okK10?nf`@070?nf`BGooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@030000003o]/40okK103`0okK100<0
00000?nf`@3o]/40<03o]/400ol00000okK10?nf`@0F0?nf`@03ooooo`00003ooooo02;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402@3o]/430000ob80okK100<0003o
0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@070?nf`@03o`00o`3o]/40okK102<0okK100?o003o
0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@070?nf`BGooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?nf`@020?nf`@030000003o]/40okK103`0okK100<000000?nf`@3o]/40<03o]/40
0`000000okK10?nf`@0F0?nf`@03ooooo`00003ooooo02;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf`@0T0?nf`@03o`00o`000?l0okK1
00l0okK10_l00?l70?nf`@03o`00o`3o]/40okK102<0okK100?o003o0?nf`@3o]/404@3o]/400ol0
0?l0okK10?nf`@060?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf
`@030000003o]/40okK103`0okK100<000000?nf`@3o]/40<03o]/400`000000okK10?nf`@0F0?nf
`@03ooooo`00003ooooo02;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/401`3o]/400`000?l0okK10?nf`@0W0?nf`@030000o`3o]/40okK100`0okK100Co003o0?nf`@3o
]/7o003o1P3o]/400ol00?l0okK10?nf`@0S0?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf
`@3o]/401P3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400`00
0000okK10?nf`@0m0?nf`@030000003o]/40okK102l0okK100<000000?nf`@3o]/405P3o]/400ooo
ool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100H0
okK100<0003o0?nf`@3o]/40:@3o]/400`000?l0okK10?nf`@0;0?nf`@05o`00o`3o]/40okK10?nf
`Ol00?l01@3o]/400ol00?l0okK10?nf`@0Q0?nf`@;o003o2`3o]/4?o`00o`<0okK19Oooool00ol0
003oooooooooo`0?ooooo`05o`000?ooool0okK10?nf`@000000@03o]/400`000000okK10?nf`@0^
0?nf`@030000003o]/40okK101L0okK100?ooooo00000?ooool08_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK102/0okK100<0003o0?nf
`@3o]/402@3o]/400ol00?l0okK10?nf`@030?nf`@05o`00o`3o]/40okK10?nf`Ol00?l08`3o]/40
0ol00?l0okK10?nf`@060?nf`@Go003o2P3o]/400ol00?l0okK10?nf`@020?nf`@Wo003o7oooool0
0ol0003oooooooooo`0?ooooo`05o`000?ooool0okK10?nf`@000000@03o]/400ol00000okK10?nf
`@0^0?nf`@030000003o]/40okK101L0okK100?ooooo00000?ooool08_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@030?nf`@80003o;`3o]/400`000?l0okK10?nf`@08
0?nf`@03o`00o`3o]/40okK100@0okK100Co003o0?nf`@3o]/7o003o8P3o]/400ol00?l0okK10?nf
`@020?nf`@Go003o3`3o]/400ol00?l0okK10?nf`@050?nf`@Kooooo0_l00?lMooooo`03o`000?oo
oooooooo00oooooo00Go0000ooooo`3o]/40okK1000000100?nf`@030000003o]/40okK102h0okK1
00<000000?nf`@3o]/405`3o]/400oooool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK10080okK100<0003o0?nf`@3o]/40<03o]/400`000?l0okK10?nf
`@060?nf`@03o`00o`3o]/40okK100H0okK10ol00?lQ0?nf`@03o`00o`3o]/7o003o00?o003o503o
]/400ol00?l0okK10?nf`@050?nf`@Sooooo0ol00?lJooooo`03o`000?oooooooooo00oooooo00Go
0000ooooo`3o]/40okK1000000110?nf`@030000003o]/40okK102`0okK100<000000?nf`@3o]/40
603o]/400oooool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK10080okK100<0003o0?nf`@3o]/40<@3o]/400`000?l0okK10?nf`@050?nf`@03o`00o`3o
]/40okK100P0okK10_l00?lK0?nf`@?o00001?l00?lH0?nf`@03o`00o`3o]/40okK100D0okK12ooo
ool3o`00oaOooooo00?o0000ooooooooool03oooool01Ol0003ooooo0?nf`@3o]/4000000480okK1
00<000000?nf`@3o]/40:`3o]/400`000000okK10?nf`@0H0?nf`@03ooooo`00003ooooo02;ooooo
00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooo`3o]/40okK10000o`0e0?nf`@030000
o`3o]/40okK100<0okK100?o003o0?nf`@3o]/402@3o]/401?l00?l0okK1o`00ool00?lH0?nf`@Go
00006`3o]/400ol00?l0okK10?nf`@050?nf`@kooooo0_l00?lEooooo`03o`000?oooooooooo00oo
oooo00Go0000ooooo`3o]/40okK1000000130?nf`@030000003o]/40okK102X0okK100<000000?nf
`@3o]/40603o]/400oooool00000ooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`04
o`000?ooool0okK10000ocH0okK100<0003o0?nf`@3o]/400`3o]/400ol00?l0okK10?nf`@090?nf
`@05o`00o`3o]/40okK10?nf`Ol00?l05`3o]/45o`0001/0okK100?o003o0?nf`@3o]/401@3o]/4@
ooooo`;o003o4oooool00ol0003oooooooooo`0?ooooo`05o`000?ooool0okK10?nf`@000000A03o
]/400`000000okK10?nf`@0X0?nf`@030000003o]/40okK101T0okK100?ooooo00000?ooool08_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0000o`0h0?nf`@050000o`3o]/40
okK10?nf`Ol00?l0303o]/400ol00?l0okK10?nf`@020?nf`@;o003o503o]/400ol00?oo0000o`00
0003o`0001/0okK100?o003o0?nf`@3o]/401@3o]/4Booooo`;o003o4Oooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooool0okK1000004D0okK100<000000?nf`@3o]/409`3o]/400ol00000okK1
0?nf`@0J0?nf`@0300000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/40>@3o]/400`000?l0okK1o`00o`0=0?nf`@03o`00o`3o]/40okK100@0okK11_l0
0?l90?nf`@Go003o0P3o]/43o`0001`0okK100?o003o0?nf`@3o]/401@3o]/4Dooooo`?o003o3_oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooool0okK1000004H0okK100<000000?nf`@3o]/40
9P3o]/400`000000okK10?nf`@0J0?nf`@0300000?oooooooooo02;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/40>@3o]/400`000?oo003o0?nf`@0=0?nf`@03o`00o`3o
]/40okK100X0okK12Ol00?l00`3o]/7o003oo`00o`0S0?nf`@03o`00o`3o]/40okK100D0okK15ooo
ool2o`00o`cooooo00?o0000ooooooooool03oooool01?l0003ooooo0?nf`@0000170?nf`@030000
003o]/40okK102@0okK100<000000?nf`@3o]/406`3o]/400`00003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103T0okK100?o003o0000o`3o]/403@3o
]/400ol00?l0okK10?nf`@0B0?nf`@;o003o9@3o]/400ol00?l0okK10?nf`@050?nf`AWooooo00?o
003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooool0okK1000004P0okK1
0`00000R0?nf`@030000003o]/40okK101`0okK100?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0h0?nf`@04o`00o`3o]/40okK10000o`h0okK1
00?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0T0?nf`@03o`00o`3o]/40okK100H0okK1
6_ooool2o`00o`Wooooo00?o0000ooooooooool03oooool01?l0003ooooo0?nf`@00001;0?nf`@03
0000003o]/40okK101`0okK10P0000000ol00000okK10?nf`@0L0?nf`@0300000?oooooooooo02?o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/4Eooooo`03o`00
oooooooooooo00;ooooo00<0003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`?o003o
9oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
3oooool01?l0003ooooo0?nf`@00000Q0?nf`B_ooooo00?o000000000?ooool06_ooool00`00003o
ooooooooo`0Oooooo`0300000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/408P3o]/4Dooooo`03o`00oooooooooooo00?ooooo00<0003oooooooooool0
2oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/40
00008@3o]/4]ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool08?ooool00`00003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1
4oooool00ol00?ooooooooooo`05ooooo`030000oooooooooooo00_ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo02Cooooo0_l00?l5ooooo`03o`00
0?oooooooooo00oooooo00Co0000ooooo`3o]/4000008@3o]/4^ooooo`8000005_ooool00`00003o
ooooooooo`0Pooooo`0300000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/408P3o]/4Booooo`03o`00oooooooooooo00Kooooo00<0003oooooooooool0
2oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0
9oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/40
00008@3o]/4`ooooo`D000003Oooool300000003o`000?oooooooooo027ooooo00<00000oooooooo
ool09?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`A7ooooo
00?o003oooooooooool01oooool00`000?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0Xooooo`05o`00ooooooooooooooooool0
00004Oooool01?l0003ooooo0?nf`@00000Q0?nf`CGooooo0`000007ooooo`<000009oooool00`00
003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280
okK13oooool2o`00o`_ooooo00<0003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo02_ooooo00?o003oooooooooool0:Oooool01?l00?ooooooooooool0000Aoooo
o`04o`000?ooool0okK100000240okK1>?ooool7000002Wooooo00<00000ooooooooool09Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`@kooooo00?o003ooooo
ooooool02oooool00`000?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooo0000017ooooo00Co0000oooo
o`3o]/4000008@3o]/5Xooooo`0300000?oooooooooo02Gooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/408P3o]/4=ooooo`03o`00oooooooooooo00cooooo00<0003ooooo
ooooool03?ooool00ol00?ooooooooooo`02ooooo`;o003o;Oooool00ol00?ooooooooooo`0^oooo
o`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/4000008@3o]/5Xooooo`0300000?oooooo
oooo02Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/4;oooo
o`;o003o4?ooool00`000?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l0;oooool0
0ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/4000008@3o
]/5Wooooo`0300000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/408P3o]/49ooooo`;o003o4_ooool00`000?ooooooooooo`0<ooooo`03o`00oooooooo
003o02oooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0?ooooo`04o`000?ooool0
okK100000240okK1Ioooool00`00003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK10280okK12?ooool00ol00?ooooooooooo`0Booooo`030000oooooooo
oooo00cooooo00?o003oooooool00?l0;oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooo`3o]/4000008@3o]/5Vooooo`0300000?oooooooooo02Oooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/46ooooo`;o003o5Oooool0
0`000?ooooooooooo`0=ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0<?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooool0okK100000240okK1I_ooool00`00003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK10oooool3
o`00oaSooooo00<0003oooooooooool02oooool00ol00?ooooooo`00o`0]ooooo`03o`00oooooooo
oooo037ooooo00?o0000ooooooooool03oooool01Ol0003ooooo0?nf`@3o]/4000000200okK1IOoo
ool00`00003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK10280okK100?oooooo`00ool00?l06oooool00`000?ooooooooooo`0:ooooo`05o`00oooooooo
ooooooooool00?l0;?ooool00ol00?ooooooooooo`0aooooo`03o`000?oooooooooo00oooooo00Go
0000ooooo`3o]/40okK10000000P0?nf`FCooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0K0?nf`@?o00000`3o]/42o`00oagooooo00<0
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Oooooo0_l0
0?ldooooo`03o`000?oooooooooo00oooooo00Go0000ooooo`3o]/40okK10000000P0?nf`FCooooo
00<00000ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooo`00
o`03o`00oaL0okK11Ol00002o`00o`030?nf`Ooooooooooo01cooooo00<0003oooooooooool02Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0=?oo
ool00ol0003oooooooooo`0?ooooo`05o`000?ooool0okK10?nf`@000000803o]/5Sooooo`030000
0?oooooooooo02[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/400`3o
]/44o`00oa80okK100?o003oo`000?l000000ol000030?nf`Akooooo00<0003oooooooooool02?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0=Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10080okK100<000000?nf`@3o]/407@3o
]/5Rooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/401`3o]/45o`00o`P0okK11Ol00?l00`3o]/7o0000o`000003o`0000<0okK17Oooool0
0`000?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/40
0`000000okK10?nf`@0M0?nf`F7ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0<0?nf`@So003o1`3o]/43o`0000@0okK17Oooool00`00
0?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0gooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400`00
0000okK10?nf`@0M0?nf`F3ooooo00<00000ooooooooool0;Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@0R0?nf`Agooooo00<0003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`;o003o7Oooool2o`00oc[ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?nf`@020?nf`@030000003o]/40okK101d0okK1H?ooool00`00003oooooooooo`0]ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK17Oooool00`000?oooooo
ooooo`07ooooo`03o`00oooooooooooo00gooooo0ol00?lHooooo`;o003o??ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK10080okK100<000000?nf`@3o]/407@3o]/5Oooooo`030000
0?oooooooooo02kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o
]/4Mooooo`030000oooooooooooo00Kooooo00?o003oooooooooool04Oooool2o`00oa?ooooo0ol0
0?lnooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400`000000okK10?nf
`@0M0?nf`Egooooo0P00000aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK10280okK17Oooool00`000?ooooooooooo`05ooooo`03o`00oooooooooooo01Cooooo0ol00?l<
ooooo`Co003o@Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10080okK100<00000
0?nf`@3o]/407@3o]/5Looooo`0300000?oooooooooo037ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/408P3o]/4Mooooo`030000oooooooooooo00Cooooo00?o003ooooo
ooooool06?ooool<o`00odGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf
`@030000003o]/40okK101d0okK1Foooool00`00003oooooooooo`0booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK10280okK17Oooool00`000?ooooooooooo`04ooooo`03
o`00oooooooooooo06Wooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@03
0000003o]/40okK101d0okK1F_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK10280okK17?ooool00`000?ooooooooooo`05ooooo`03o`00
oooooooooooo06Wooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@030000
003o]/40okK101d0okK1F?ooool2000003Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/408P3o]/4Looooo`030000oooooooooooo00Cooooo00?o003oooooooooool0J_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10080okK100<000000?nf`@3o]/40603o
]/45o`0005Kooooo0P00000hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK10280okK17?ooool00`000?ooooooooooo`04ooooo`03o`00oooooooooooo06[ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@030000003o]/40okK101<0okK11Ol00005
0?nf`@?o0000D_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK10280okK16oooool00`000?ooooooooooo`04ooooo`03o`00oooooooooooo
06_ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@030000003o]/40okK1
0140okK10_l0000:0?nf`@?ooooo1?l0001<ooooo`800000>oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@0R0?nf`A_ooooo00<0003oooooooooool01?ooool00ol00?oo
ooooooooo`1[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400`000000
okK10?nf`@0>0?nf`@?o0000303o]/47ooooo`;o0000Aoooool3000003gooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/4Kooooo`030000oooooooooooo00?ooooo
00?o003oooooooooool0K?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooool0okK10?nf`@00
0000403o]/400ol00000okK10?nf`@0=0?nf`@Wooooo00?o0000ooooooooool0@Oooool30000043o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/4Jooooo`030000
oooooooooooo00Cooooo00?o003oooooooooool0K?ooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooool0okK10?nf`@0000003@3o]/43o`000100okK12_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
8P3o]/4Jooooo`030000oooooooooooo00Cooooo00?o003oooooooooool0K?ooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooool0okK10?nf`@000000303o]/400ol00000okK10?nf`@090?nf`@So
00002oooool00ol0003oooooooooo`0kooooo`<00000A?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0R0?nf`AWooooo00?o003o0000ooooool01?ooool00ol00?oooooo
ooooo`1]ooooo`03o`000?oooooooooo00oooooo00Go0000ooooo`3o]/40okK10000000;0?nf`@03
o`00003o]/40okK100H0okK11?l000080?nf`@?o00002Oooool00ol0003oooooooooo`0cooooo`L0
0000Aoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`AWooooo
00<0003oooooooooool01?ooool00ol00?ooooooooooo`1]ooooo`03o`000?oooooooooo00oooooo
00Co0000ooooo`3o]/400000303o]/400ol00000okK10?nf`@040?nf`@;o0000303o]/43ooooo`?o
00001oooool00ol0003oooooooooo`0Yooooo`0300000?ooool0000000H00000C_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`ASooooo00<0003oooooooooool0
1Oooool00ol00?ooooooooooo`1]ooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/40
00002`3o]/400ol00000okK10?nf`@030?nf`@;o00003P3o]/46ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05OoooolE000005Gooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/40>@3o]/400`000?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK104T0okK1
9Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooool0okK1000000X0okK100?o00000?nf`@3o
]/400P3o]/42o`0000D0okK13Ol000050?nf`@;o00001@3o]/400ol00000okK10?nf`@0B0?nf`@<0
0000A@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0003o03P0okK1
00<0003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@190?nf`BGooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0000000:0?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/40
0`3o]/42o`0000d0okK10_l000050?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/40
3`3o]/42000004P0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0000
o`0h0?nf`@030000o`3o]/40okK100H0okK100?o003o0?nf`@3o]/40B@3o]/4Uooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/402@3o]/400ol00000okK10?nf`@020?nf`@03o`00003o
]/40okK10080okK10_l000050?nf`@So0000103o]/42o`0000@0okK100?o00000?nf`@3o]/400`3o
]/400ol00000okK10?nf`@0=0?nf`@030000003o]/40okK104P0okK19Oooool00ol0003ooooooooo
o`08ooooo`002Oooool01?l0003ooooo0?nf`@000?lI0?nf`@So003o5@3o]/400`000?l0okK10?nf
`@060?nf`@03o`00o`3o]/40okK104X0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0okK100T0okK100?o00000?nf`@3o]/400P3o]/401Ol00000okK10?nf`@3o]/7o000000@0okK1
0ol000080?nf`@;o0000103o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK1
00?o00000?nf`@3o]/403@3o]/400`000000okK10?nf`@180?nf`BGooooo00?o0000ooooooooool0
2?ooool000Wooooo00Go0000ooooo`3o]/40okK10000o`0F0?nf`@;o003o203o]/42o`00oa80okK1
00<0003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@1:0?nf`BGooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?nf`@080?nf`@03o`00003o]/40okK10080okK100Go00000?nf`@3o]/40
okK1o`0000030?nf`@;o00003@3o]/42o`0000<0okK100Go00000?nf`@3o]/40okK1o`0000050?nf
`@03o`00003o]/40okK100/0okK100<000000?nf`@3o]/40B@3o]/4Uooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK10080okK100<0003o0?nf`@3o]/404P3o]/400ol00?l0
okK10?nf`@0:0?nf`@?o003o3P3o]/400`000?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK104X0
okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100L0okK100?o00000?nf`@3o
]/400P3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`@3o]/400`3o]/48o`00
00@0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK10080okK100?o0000
0?nf`@3o]/402`3o]/400`000000okK10?nf`@190?nf`BGooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/400`3o]/400ol00?l0003o0?nf`@0@0?nf`@03o`00o`3o]/40okK1
00h0okK100?o003o0?nf`@3o]/402P3o]/400`000?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK1
04X0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100H0okK100?o00000?nf
`@3o]/400P3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100Co00000?nf`@3o]/40okK10ol0
00080?nf`@;o00000`3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`@3o]/40
0P3o]/400ol00000okK10?nf`@090?nf`@030000003o]/40okK104X0okK19Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK100h0okK100?o
003o0?nf`@3o]/403P3o]/400ol00?l0okK10?nf`@090?nf`@030000o`3o]/40okK100X0okK100?o
003o0?nf`@3o]/40BP3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/401P3o
]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/40
0_l000030?nf`@Oo00000`3o]/42o`0000030?nf`Ol00000okK10080okK100Go00000?nf`@3o]/40
okK1o`0000040?nf`@03o`00003o]/40okK100T0okK100<000000?nf`@3o]/40BP3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o]/40
303o]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100H0okK10P000?l=0?nf`@03o`00
o`3o]/40okK104X0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100H0okK1
00Go00000?nf`@3o]/40okK1o`0000020?nf`@03o`00003o]/40okK100;o00000P3o]/400ol00000
okK10?nf`@03o`0000L0okK100?o00000?nf`@3o]/400P3o]/400ol00000okK1o`0000030?nf`@05
o`00003o]/40okK10?nf`Ol00000103o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK1
04/0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@070?nf`@03
0000o`3o]/40okK100X0okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@040?nf`@03
0000o`3o]/40okK100`0okK100?o003o0?nf`@3o]/40B`3o]/4Uooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3o]/401@3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Co00000?nf
`@3o]/7o00000`3o]/401?l00000okK10?nf`Ol0000;0?nf`@;o00000`3o]/401?l00000okK1o`00
0?l000020?nf`@04o`00003o]/40okK1o`0000@0okK100?o00000?nf`@3o]/401`3o]/400`000000
okK10?nf`@1;0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
203o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40
0`3o]/400`000?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK104/0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK100D0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04
o`00003o]/40okK1o`000080okK100Co00000?nf`@3o]/7o0000103o]/47o`0000<0okK100Co0000
0?nf`@3o]/7o00000P3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/40okK10080okK1
00?o00000?nf`@3o]/401`3o]/400`000000okK10?nf`@1;0?nf`BGooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/402@3o]/420000o`L0okK100?o003o0?nf`@3o]/405@3o
]/400ol00?l0okK10?nf`@020000oa00okK100?o003o0?nf`@3o]/40B`3o]/4Uooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/40103o]/401Ol00000okK10?nf`@3o]/7o000000<0okK1
00?o00000?nf`Ol000000P3o]/401?l00000okK10?nf`Ol000020?nf`@?o00001`3o]/401Ol00000
okK10?nf`@3o]/7o00000080okK100?o00000?nf`Ol000000P3o]/401?l00000okK10?nf`Ol00004
0?nf`@03o`00003o]/40okK100L0okK100<000000?nf`@3o]/40B`3o]/4Uooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100/0okK10P000?l50?nf`@03o`00o`3o]/40okK1
01D0okK10`000?lB0?nf`@03o`00o`3o]/40okK104/0okK19Oooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0okK100@0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04o`00003o]/40
okK1o`000080okK100?o00000?nf`Ol000000P3o]/401?l00000okK10?nf`@3o]/44o`0000@0okK1
0_l000020?nf`@03o`00003o]/7o00000080okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000
okK10?nf`@020?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/40B`3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100d0okK110000?l00`3o]/7o003o
0?nf`@0D0?nf`@80003o00?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@1;0?nf`BGooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@030?nf`@05o`00003o]/40okK10?nf`Ol0
00000`3o]/400ol00000okK1o`0000020?nf`@03o`00003o]/7o00000080okK100Go00000?nf`@3o
]/40okK1o`0000040?nf`@?o00000`3o]/400ol00000okK1o`0000020?nf`@03o`00003o]/7o0000
0080okK100Co00000?nf`@3o]/7o0000103o]/400ol00000okK10?nf`@060?nf`@030000003o]/40
okK104/0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0A0?nf
`@@0003o203o]/43o`0000D0okK10`000?l30?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf
`@3o]/40C03o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400`3o]/401Ol0
0000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`Ol000000P3o]/401Ol00000okK1o`00003o
]/7o00000080okK10_l000080?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o]/400ol00000
okK1o`0000020?nf`@04o`00003o]/40okK1o`0000@0okK100?o00000?nf`@3o]/401P3o]/400`00
0000okK10?nf`@1;0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/404@3o]/400ol00?l0okK10?nf`@08o`00o`Go000010000?l60?nf`@03o`00o`3o]/40okK10100
okK100?o003o0?nf`@3o]/40C03o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
]/400`3o]/401?l00000okK10?nf`Ol000030?nf`@03o`00003o]/7o00000080okK100?o00000?nf
`Ol000000P3o]/400ol00000okK1o`0000030?nf`@Co0000103o]/402?l00000okK10?nf`Ol00000
okK1o`00003o]/7o00000P3o]/401?l00000okK10?nf`Ol000020?nf`@05o`00003o]/40okK10?nf
`Ol000001`3o]/400`000000okK10?nf`@1<0?nf`BGooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/404@3o]/400ol00?l0okK1o`00o`060?nf`@80003o1Ol0000:0?nf`@03
o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/40C03o]/4Uooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3o]/400`3o]/401?l00000okK10?nf`Ol000020?nf`@08o`00003o]/40okK1
o`00003o]/7o00000?nf`Ol000020?nf`@03o`00003o]/7o000000<0okK100?o00000?nf`@3o]/40
0P3o]/42o`0000<0okK100?o00000?nf`Ol000000P3o]/401Ol00000okK1o`00003o]/7o00000080
okK100Co00000?nf`@3o]/7o00000`3o]/400ol00000okK10?nf`@050?nf`@030000003o]/40okK1
04`0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0A0?nf`@;o
003o2@3o]/45o`0000X0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@1<0?nf`BGo
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@05o`00003o]/40okK10?nf
`Ol000000P3o]/402?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000P3o]/400ol00000okK1
o`0000030?nf`@03o`00003o]/40okK100<0okK100Oo00000?nf`@3o]/40okK1o`00003o]/7o0000
0080okK100Go00000?nf`Ol00000okK1o`0000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o
00000?nf`@3o]/401@3o]/400`000000okK10?nf`@1<0?nf`BGooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/40403o]/400ol00?l0okK1o`00o`0:0?nf`@?o000000<0okK1
o`00o`3o]/401`3o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK10400okK10ol00009
0?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@05o`00003o]/40
okK10?nf`Ol000000P3o]/403?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000?nf`Ol00000
okK1o`0000<0okK100?o00000?nf`@3o]/401@3o]/401?l00000okK10?nf`Ol000020?nf`@07o`00
003o]/7o00000?nf`Ol00000okK1o`0000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o0000
0?nf`@3o]/401@3o]/400`000000okK10?nf`@1<0?nf`BGooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/403`3o]/401?l00?l0okK10?nf`Ol00?l?0?nf`@03o`00o`3o]/40
okK100D0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@0o0?nf`@Go0000203o]/4U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/401Ol00000okK10?nf`@3o
]/7o00000080okK100Oo00000?nf`Ol00000okK1o`00003o]/7o00000080okK100?o00000?nf`Ol0
00000P3o]/400ol00000okK10?nf`@060?nf`@0=o`00003o]/40okK10?nf`Ol00000okK1o`00003o
]/7o00000?nf`Ol00000okK1o`0000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf
`@3o]/40103o]/400`000000okK10?nf`@1=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/403P3o]/401Ol00?l0okK10?nf`@3o]/7o003o0100okK100?o003o0?nf
`@3o]/40103o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK103l0okK11Ol000080?nf
`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@05o`00003o]/40okK1
0?nf`Ol000000P3o]/402Ol00000okK1o`00003o]/7o00000?nf`Ol00000okK1o`0000020?nf`@03
o`00003o]/7o000000X0okK100co00000?nf`@3o]/7o00000?nf`Ol00000okK1o`00003o]/7o0000
0?nf`Ol000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/40103o]/400`00
0000okK10?nf`@1=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/403P3o]/401Ol00?l0okK10?nf`@3o]/7o003o0100okK100?o003o0?nf`@3o]/40103o]/400ol0
0?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK103l0okK11Ol000080?nf`BGooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@020?nf`@05o`00003o]/40okK10?nf`Ol000000P3o]/40
2Ol00000okK1o`00003o]/7o00000?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/7o000000X0
okK100co00000?nf`@3o]/7o00000?nf`Ol00000okK1o`00003o]/7o00000?nf`Ol000020?nf`@04
o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@1=0?nf
`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/400ol00?l0
okK10?nf`@030?nf`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o]/400P3o]/400ol00?l0
okK10?nf`@0B0?nf`@03o`00o`3o]/40okK10400okK10ol000090?nf`BGooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@020?nf`@07o`00003o]/40okK10?nf`Ol00000okK1o`000002
0?nf`@09o`00003o]/7o00000?nf`Ol00000okK1o`00003o]/7o00000080okK100?o00000?nf`@3o
]/40203o]/400ol00000okK1o`0000020?nf`@09o`00003o]/7o00000?nf`Ol00000okK1o`00003o
]/7o00000080okK100Go00000?nf`@3o]/40okK1o`0000060?nf`@030000003o]/40okK104h0okK1
9Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@03o`00o`3o
]/40okK100@0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@020?nf`@03o`00o`3o
]/40okK10180okK100?o003o0?nf`@3o]/40C03o]/4Uooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3o]/400P3o]/401ol00000okK10?nf`@3o]/7o00000?nf`Ol000000P3o]/402Ol00000
okK1o`00003o]/7o00000?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/40okK100P0okK100Go
00000?nf`Ol00000okK1o`0000020?nf`@07o`00003o]/7o00000?nf`Ol00000okK1o`0000020?nf
`@05o`00003o]/40okK10?nf`Ol000001P3o]/400`000000okK10?nf`@1>0?nf`BGooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/400ol00?l0okK10?nf`@040?nf
`@03o`00o`3o]/40okK100h0okK100Co003o0?nf`@3o]/7o003o5@3o]/400ol00?l0okK10?nf`@1<
0?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@07o`00003o]/40
okK10?nf`Ol00000okK1o`0000020?nf`@09o`00003o]/7o00000?nf`Ol00000okK1o`00003o]/7o
00000080okK100?o00000?nf`@3o]/401`3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK1
00Oo00000?nf`Ol00000okK1o`00003o]/7o00000080okK100Go00000?nf`@3o]/40okK1o`000006
0?nf`@030000003o]/40okK104h0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0<0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/400ol0000:0?nf
`@?o003o5P3o]/400ol00?l0okK10?nf`@1<0?nf`BGooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?nf`@020?nf`@07o`00003o]/40okK10?nf`Ol00000okK1o`0000020?nf`@07o`00003o
]/7o00000?nf`Ol00000okK1o`0000020?nf`@04o`00003o]/40okK1o`0000H0okK10_l000020?nf
`@08o`00003o]/40okK1o`00003o]/7o00000?nf`Ol000020?nf`@05o`00003o]/7o00000?nf`Ol0
0000103o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK104h0okK19Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0<0?nf`@03o`00o`3o]/40okK100L0okK1
00?o003oo`000?l000000ol000090?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/40
C03o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/401Ol00000okK1
0?nf`@3o]/7o00000080okK100Go00000?nf`Ol00000okK1o`0000020?nf`@05o`00003o]/7o0000
0?nf`Ol000000`3o]/43o`0000030?nf`Ol0003o000000@0okK100?o00000?nf`Ol000000P3o]/40
1ol00000okK1o`00003o]/7o00000?nf`Ol000000P3o]/401Ol00000okK10?nf`@3o]/7o000000H0
okK100<000000?nf`@3o]/40C`3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK100`0okK100?o003o0?nf`@3o]/40203o]/45o`0000H0okK11?l00?lH0?nf`@03o`00
o`3o]/40okK104`0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10080okK1
00Go00000?nf`@3o]/40okK1o`0000020?nf`@05o`00003o]/7o00000?nf`Ol000000P3o]/400ol0
0000okK1o`0000020?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400`3o]/402?l0
0000okK10?nf`Ol00000okK1o`00003o]/7o00000P3o]/400ol00000okK1o`0000020?nf`@05o`00
003o]/40okK10?nf`Ol000001P3o]/400`000000okK10?nf`@1?0?nf`BGooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/40303o]/400ol00?l0okK10?nf`@080?nf`@Go0000
1_l00?l30?nf`@03o`00o`3o]/40okK101L0okK100?o003o0?nf`@3o]/40B`3o]/4Uooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/401Ol00000okK10?nf`@3o]/7o00000080
okK100Go00000?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/7o000000<0okK100?o00000?nf
`@3o]/401`3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/7o00000080okK100?o0000
0?nf`Ol000000P3o]/401Ol00000okK10?nf`@3o]/7o000000H0okK100<000000?nf`@3o]/40C`3o
]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100`0okK100?o003o
0?nf`@3o]/402@3o]/43o`0000X0okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf`@1;
0?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@020?nf`@05o`00003o]/40
okK10?nf`Ol000000`3o]/42o`000080okK100Ko00000?nf`@3o]/7o00000?nf`Ol000030?nf`@03
o`00003o]/40okK100<0okK10ol000020?nf`@04o`00003o]/40okK10?nf`@;o00000P3o]/401?l0
0000okK10?nf`Ol000020?nf`@05o`00003o]/40okK10?nf`Ol000001P3o]/400`000000okK10?nf
`@1?0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40303o]/40
0ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK101L0okK100?o003o0?nf`@3o]/40B`3o]/4U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400ol00000okK10?nf`@02
0?nf`@08o`00003o]/40okK1o`00003o]/7o00000?nf`Ol000020?nf`@04o`00003o]/40okK1o`00
00<0okK11Ol000050?nf`@08o`00003o]/40okK1o`00003o]/7o00000?nf`Ol000020?nf`@04o`00
003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@1@0?nf`BGo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/400ol00?l0okK1
0?nf`@0E0?nf`@03o`00o`3o]/40okK101L0okK100?o003o0?nf`@3o]/40B`3o]/4Uooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/400`3o]/401Ol00000okK10?nf`@3o]/7o00000080
okK100Go00000?nf`Ol0003o00000?nf`@02o`0000040?nf`Ol00000okK10?nf`@?o00001@3o]/45
o`0000050?nf`Ol0003o00000?nf`Ol000000P3o]/401?l00000okK10?nf`Ol000020?nf`@05o`00
003o]/40okK10?nf`Ol000001P3o]/400`000000okK10?nf`@1@0?nf`BGooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00
o`3o]/40okK101T0okK100?o003o0?nf`@3o]/40BP3o]/4Uooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3o]/400`3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Co00000?nf`@3o
]/7o00000`3o]/400ol00000okK1o`0000040?nf`@Go0000103o]/42o`000080okK100Co00000?nf
`@3o]/7o00000P3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`@3o]/40103o
]/400`000000okK10?nf`@1@0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/403P3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK101T0okK100?o003o
0?nf`@3o]/40BP3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40103o]/40
1Ol00000okK10?nf`@3o]/7o00000080okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK1
0?nf`@02o`0000X0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04o`00003o]/40okK1o`00
00<0okK100Go00000?nf`@3o]/40okK1o`0000060?nf`@030000003o]/40okK10540okK19Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0>0?nf`@03o`00o`3o]/40okK1
01<0okK100?o003o0?nf`@3o]/406@3o]/400ol00?l0okK10?nf`@1:0?nf`BGooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@040?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/40
1?l00000okK10?nf`Ol000020?nf`@05o`00003o]/40okK10?nf`Ol000001`3o]/42o`0000<0okK1
00Co00000?nf`@3o]/7o00000P3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100?o00000?nf
`@3o]/40103o]/400`000000okK10?nf`@1B0?nf`BGooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo]_l0000AoooookKo00002_ooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PolygonalAllPlot[poly, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.3 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.2 g
.01923 .58635 m
.02133 .59615 L
.02774 .61538 L
.03744 .63462 L
.03846 .6363 L
.05051 .65385 L
.05769 .66242 L
.06631 .67308 L
.07692 .68575 L
.08161 .69231 L
.08797 .71154 L
.07973 .73077 L
.07692 .7361 L
.06445 .75 L
.05769 .7587 L
.04979 .76923 L
.03846 .78805 L
.03825 .78846 L
.03022 .80769 L
.02556 .82692 L
.02408 .84615 L
.02571 .86538 L
.03067 .88462 L
.03846 .90216 L
.03946 .90385 L
.05316 .92308 L
.05769 .92798 L
.07474 .94231 L
.07692 .94376 L
.09615 .95392 L
.11538 .96008 L
.12295 .96154 L
.13462 .96283 L
.15385 .96242 L
.16064 .96154 L
.17308 .95899 L
.19231 .95266 L
.21154 .94395 L
.21404 .94231 L
.23077 .93441 L
.25 .92826 L
.26923 .93157 L
.28584 .94231 L
.28846 .94433 L
.30769 .95941 L
.31066 .96154 L
.32692 .97205 L
.34537 .98077 L
.01923 .98077 L
F
0 g
.01923 .58635 m
.02133 .59615 L
.02774 .61538 L
.03744 .63462 L
.03846 .6363 L
.05051 .65385 L
.05769 .66242 L
.06631 .67308 L
.07692 .68575 L
.08161 .69231 L
.08797 .71154 L
.07973 .73077 L
.07692 .7361 L
.06445 .75 L
.05769 .7587 L
.04979 .76923 L
.03846 .78805 L
.03825 .78846 L
.03022 .80769 L
.02556 .82692 L
.02408 .84615 L
.02571 .86538 L
.03067 .88462 L
.03846 .90216 L
.03946 .90385 L
.05316 .92308 L
.05769 .92798 L
.07474 .94231 L
.07692 .94376 L
.09615 .95392 L
.11538 .96008 L
.12295 .96154 L
.13462 .96283 L
.15385 .96242 L
.16064 .96154 L
.17308 .95899 L
.19231 .95266 L
.21154 .94395 L
.21404 .94231 L
.23077 .93441 L
.25 .92826 L
.26923 .93157 L
.28584 .94231 L
.28846 .94433 L
.30769 .95941 L
.31066 .96154 L
.32692 .97205 L
.34537 .98077 L
s
.2 g
.01923 .5258 m
.02048 .51923 L
.02363 .5 L
.02618 .48077 L
.02717 .46154 L
.02655 .44231 L
.0252 .42308 L
.02439 .40385 L
.02513 .38462 L
.02813 .36538 L
.03384 .34615 L
.03846 .33498 L
.04248 .32692 L
.05387 .30769 L
.05769 .30224 L
.06681 .28846 L
.07692 .27248 L
.07805 .26923 L
.08317 .25 L
.08152 .23077 L
.07692 .2141 L
.07611 .21154 L
.07001 .19231 L
.06507 .17308 L
.06218 .15385 L
.06174 .13462 L
.06396 .11538 L
.06911 .09615 L
.07692 .07815 L
.07761 .07692 L
.09036 .05769 L
.09615 .0509 L
.10924 .03846 L
.11538 .03371 L
.13462 .02204 L
.14032 .01923 L
.01923 .01923 L
F
0 g
.01923 .5258 m
.02048 .51923 L
.02363 .5 L
.02618 .48077 L
.02717 .46154 L
.02655 .44231 L
.0252 .42308 L
.02439 .40385 L
.02513 .38462 L
.02813 .36538 L
.03384 .34615 L
.03846 .33498 L
.04248 .32692 L
.05387 .30769 L
.05769 .30224 L
.06681 .28846 L
.07692 .27248 L
.07805 .26923 L
.08317 .25 L
.08152 .23077 L
.07692 .2141 L
.07611 .21154 L
.07001 .19231 L
.06507 .17308 L
.06218 .15385 L
.06174 .13462 L
.06396 .11538 L
.06911 .09615 L
.07692 .07815 L
.07761 .07692 L
.09036 .05769 L
.09615 .0509 L
.10924 .03846 L
.11538 .03371 L
.13462 .02204 L
.14032 .01923 L
s
.1 g
.01923 .91192 m
.02595 .92308 L
.03846 .93903 L
.04154 .94231 L
.05769 .95657 L
.06465 .96154 L
.07692 .96883 L
.09615 .9771 L
.10799 .98077 L
.01923 .98077 L
F
0 g
.01923 .91192 m
.02595 .92308 L
.03846 .93903 L
.04154 .94231 L
.05769 .95657 L
.06465 .96154 L
.07692 .96883 L
.09615 .9771 L
.10799 .98077 L
s
.1 g
.01923 .32519 m
.02697 .30769 L
.03617 .28846 L
.03846 .28538 L
.04386 .26923 L
.04756 .25 L
.04661 .23077 L
.04265 .21154 L
.03846 .19464 L
.03789 .19231 L
.03392 .17308 L
.03157 .15385 L
.0312 .13462 L
.033 .11538 L
.03714 .09615 L
.03846 .09151 L
.04385 .07692 L
.05346 .05769 L
.05769 .05081 L
.06668 .03846 L
.07692 .02686 L
.08484 .01923 L
.01923 .01923 L
F
0 g
.01923 .32519 m
.02697 .30769 L
.03617 .28846 L
.03846 .28538 L
.04386 .26923 L
.04756 .25 L
.04661 .23077 L
.04265 .21154 L
.03846 .19464 L
.03789 .19231 L
.03392 .17308 L
.03157 .15385 L
.0312 .13462 L
.033 .11538 L
.03714 .09615 L
.03846 .09151 L
.04385 .07692 L
.05346 .05769 L
.05769 .05081 L
.06668 .03846 L
.07692 .02686 L
.08484 .01923 L
s
.1 g
.01923 .77747 m
.02343 .76923 L
.03457 .75 L
.03846 .74537 L
.04529 .73077 L
.05075 .71154 L
.04726 .69231 L
.03846 .67534 L
.0371 .67308 L
.02529 .65385 L
.01923 .64293 L
F
0 g
.01923 .77747 m
.02343 .76923 L
.03457 .75 L
.03846 .74537 L
.04529 .73077 L
.05075 .71154 L
.04726 .69231 L
.03846 .67534 L
.0371 .67308 L
.02529 .65385 L
.01923 .64293 L
s
.01923 .96741 m
.03424 .98077 L
.01923 .98077 L
F
.01923 .96741 m
.03424 .98077 L
s
.01923 .02633 m
.02401 .01923 L
.01923 .01923 L
F
.01923 .02633 m
.02401 .01923 L
s
.4 g
.17308 .03623 m
.19231 .03441 L
.21154 .03614 L
.22518 .03846 L
.23077 .04159 L
.25 .05147 L
.25865 .05769 L
.26923 .06748 L
.27712 .07692 L
.28846 .09607 L
.2885 .09615 L
.2951 .11538 L
.29777 .13462 L
.29682 .15385 L
.29218 .17308 L
.28846 .1831 L
.28347 .19231 L
.26972 .21154 L
.26923 .2121 L
.25 .23026 L
.24938 .23077 L
.23077 .24403 L
.22203 .25 L
.21154 .25608 L
.19742 .26923 L
.19231 .27782 L
.19122 .28846 L
.19231 .29631 L
.19549 .30769 L
.20193 .32692 L
.20768 .34615 L
.21154 .36279 L
.21202 .36538 L
.21481 .38462 L
.21652 .40385 L
.218 .42308 L
.22061 .44231 L
.22593 .46154 L
.23077 .47315 L
.23236 .48077 L
.24269 .5 L
.25 .51195 L
.2525 .51923 L
.2563 .53846 L
.25391 .55769 L
.25153 .57692 L
.25 .58448 L
.24549 .59615 L
.23653 .61538 L
.23077 .62528 L
.22422 .63462 L
.21154 .64947 L
.20731 .65385 L
.19231 .66642 L
.18429 .67308 L
.17308 .67981 L
.15385 .68836 L
.13462 .69005 L
.11538 .68404 L
.0964 .67308 L
.09615 .67282 L
.07692 .65734 L
.07291 .65385 L
.05769 .63653 L
.05627 .63462 L
.0447 .61538 L
.03846 .60054 L
.03716 .59615 L
.03305 .57692 L
.03188 .55769 L
.03315 .53846 L
.03616 .51923 L
.03846 .5075 L
.03988 .5 L
.04293 .48077 L
.04415 .46154 L
.04345 .44231 L
.04187 .42308 L
.04092 .40385 L
.04185 .38462 L
.04551 .36538 L
.05257 .34615 L
.05769 .33624 L
.06362 .32692 L
.07692 .3105 L
.07935 .30769 L
.09615 .2919 L
.09905 .28846 L
.11538 .2731 L
.11696 .26923 L
.1226 .25 L
.11659 .23077 L
.11538 .22734 L
.10713 .21154 L
.0984 .19231 L
.09615 .18687 L
.09188 .17308 L
.08819 .15385 L
.08762 .13462 L
.0904 .11538 L
.09615 .09744 L
.09696 .09615 L
.10822 .07692 L
.11538 .0682 L
.12657 .05769 L
.13462 .05185 L
.15385 .0418 L
.16028 .03846 L
F
0 g
.17308 .03623 m
.19231 .03441 L
.21154 .03614 L
.22518 .03846 L
.23077 .04159 L
.25 .05147 L
.25865 .05769 L
.26923 .06748 L
.27712 .07692 L
.28846 .09607 L
.2885 .09615 L
.2951 .11538 L
.29777 .13462 L
.29682 .15385 L
.29218 .17308 L
.28846 .1831 L
.28347 .19231 L
.26972 .21154 L
.26923 .2121 L
.25 .23026 L
.24938 .23077 L
.23077 .24403 L
.22203 .25 L
.21154 .25608 L
.19742 .26923 L
.19231 .27782 L
.19122 .28846 L
.19231 .29631 L
.19549 .30769 L
.20193 .32692 L
.20768 .34615 L
.21154 .36279 L
.21202 .36538 L
.21481 .38462 L
.21652 .40385 L
.218 .42308 L
.22061 .44231 L
.22593 .46154 L
.23077 .47315 L
.23236 .48077 L
.24269 .5 L
.25 .51195 L
.2525 .51923 L
.2563 .53846 L
.25391 .55769 L
.25153 .57692 L
.25 .58448 L
.24549 .59615 L
.23653 .61538 L
.23077 .62528 L
Mistroke
.22422 .63462 L
.21154 .64947 L
.20731 .65385 L
.19231 .66642 L
.18429 .67308 L
.17308 .67981 L
.15385 .68836 L
.13462 .69005 L
.11538 .68404 L
.0964 .67308 L
.09615 .67282 L
.07692 .65734 L
.07291 .65385 L
.05769 .63653 L
.05627 .63462 L
.0447 .61538 L
.03846 .60054 L
.03716 .59615 L
.03305 .57692 L
.03188 .55769 L
.03315 .53846 L
.03616 .51923 L
.03846 .5075 L
.03988 .5 L
.04293 .48077 L
.04415 .46154 L
.04345 .44231 L
.04187 .42308 L
.04092 .40385 L
.04185 .38462 L
.04551 .36538 L
.05257 .34615 L
.05769 .33624 L
.06362 .32692 L
.07692 .3105 L
.07935 .30769 L
.09615 .2919 L
.09905 .28846 L
.11538 .2731 L
.11696 .26923 L
.1226 .25 L
.11659 .23077 L
.11538 .22734 L
.10713 .21154 L
.0984 .19231 L
.09615 .18687 L
.09188 .17308 L
.08819 .15385 L
.08762 .13462 L
.0904 .11538 L
Mistroke
.09615 .09744 L
.09696 .09615 L
.10822 .07692 L
.11538 .0682 L
.12657 .05769 L
.13462 .05185 L
.15385 .0418 L
.16028 .03846 L
.17308 .03623 L
Mfstroke
.4 g
.09615 .7496 m
.11538 .73971 L
.13462 .7312 L
.15385 .73325 L
.17308 .74334 L
.18774 .75 L
.19231 .75387 L
.21016 .76923 L
.21154 .77061 L
.22748 .78846 L
.23077 .79243 L
.24127 .80769 L
.25 .81773 L
.25739 .82692 L
.26923 .83141 L
.28846 .8279 L
.29038 .82692 L
.30769 .81554 L
.32121 .80769 L
.32692 .80417 L
.34615 .79558 L
.36538 .79024 L
.3807 .78846 L
.38462 .78835 L
.38972 .78846 L
.40385 .79007 L
.42308 .79577 L
.44231 .80615 L
.4445 .80769 L
.46154 .82317 L
.46455 .82692 L
.47696 .84615 L
.48077 .85446 L
.483 .86538 L
.48443 .88462 L
.4819 .90385 L
.48077 .91049 L
.47375 .92308 L
.46154 .94033 L
.45967 .94231 L
.44231 .95731 L
.43594 .96154 L
.42308 .9677 L
.40385 .97326 L
.38462 .97475 L
.36538 .97238 L
.34615 .96601 L
.33697 .96154 L
.32692 .95519 L
.311 .94231 L
.30769 .9393 L
.29318 .92308 L
.28846 .91857 L
.27615 .90385 L
.26923 .90104 L
.25 .8968 L
.23669 .90385 L
.23077 .90821 L
.21154 .92196 L
.20981 .92308 L
.19231 .93315 L
.17308 .94082 L
.16767 .94231 L
.15385 .94485 L
.13462 .94532 L
.11604 .94231 L
.11538 .94213 L
.09615 .93477 L
.07813 .92308 L
.07692 .92205 L
.06013 .90385 L
.05769 .90045 L
.04941 .88462 L
.04351 .86538 L
.04157 .84615 L
.04332 .82692 L
.04886 .80769 L
.05769 .78985 L
.0586 .78846 L
.07344 .76923 L
.07692 .76577 L
.09502 .75 L
F
0 g
.09615 .7496 m
.11538 .73971 L
.13462 .7312 L
.15385 .73325 L
.17308 .74334 L
.18774 .75 L
.19231 .75387 L
.21016 .76923 L
.21154 .77061 L
.22748 .78846 L
.23077 .79243 L
.24127 .80769 L
.25 .81773 L
.25739 .82692 L
.26923 .83141 L
.28846 .8279 L
.29038 .82692 L
.30769 .81554 L
.32121 .80769 L
.32692 .80417 L
.34615 .79558 L
.36538 .79024 L
.3807 .78846 L
.38462 .78835 L
.38972 .78846 L
.40385 .79007 L
.42308 .79577 L
.44231 .80615 L
.4445 .80769 L
.46154 .82317 L
.46455 .82692 L
.47696 .84615 L
.48077 .85446 L
.483 .86538 L
.48443 .88462 L
.4819 .90385 L
.48077 .91049 L
.47375 .92308 L
.46154 .94033 L
.45967 .94231 L
.44231 .95731 L
.43594 .96154 L
.42308 .9677 L
.40385 .97326 L
.38462 .97475 L
.36538 .97238 L
.34615 .96601 L
.33697 .96154 L
.32692 .95519 L
.311 .94231 L
Mistroke
.30769 .9393 L
.29318 .92308 L
.28846 .91857 L
.27615 .90385 L
.26923 .90104 L
.25 .8968 L
.23669 .90385 L
.23077 .90821 L
.21154 .92196 L
.20981 .92308 L
.19231 .93315 L
.17308 .94082 L
.16767 .94231 L
.15385 .94485 L
.13462 .94532 L
.11604 .94231 L
.11538 .94213 L
.09615 .93477 L
.07813 .92308 L
.07692 .92205 L
.06013 .90385 L
.05769 .90045 L
.04941 .88462 L
.04351 .86538 L
.04157 .84615 L
.04332 .82692 L
.04886 .80769 L
.05769 .78985 L
.0586 .78846 L
.07344 .76923 L
.07692 .76577 L
.09502 .75 L
.09615 .7496 L
Mfstroke
.5 g
.13462 .30391 m
.15385 .30708 L
.15722 .30769 L
.17308 .32211 L
.17732 .32692 L
.18816 .34615 L
.19231 .357 L
.19472 .36538 L
.19848 .38462 L
.20029 .40385 L
.2013 .42308 L
.20311 .44231 L
.2074 .46154 L
.21154 .47364 L
.21455 .48077 L
.22337 .5 L
.23077 .51686 L
.23143 .51923 L
.2362 .53846 L
.23776 .55769 L
.23572 .57692 L
.23077 .59572 L
.23021 .59615 L
.22066 .61538 L
.21154 .62836 L
.20611 .63462 L
.19231 .64709 L
.18327 .65385 L
.17308 .65877 L
.15385 .66526 L
.13462 .66648 L
.11538 .66219 L
.097 .65385 L
.09615 .6531 L
.07692 .63753 L
.07409 .63462 L
.05986 .61538 L
.05769 .61175 L
.05109 .59615 L
.04641 .57692 L
.04508 .55769 L
.04653 .53846 L
.05 .51923 L
.05435 .5 L
.05769 .48389 L
.05803 .48077 L
.05962 .46154 L
.05889 .44231 L
.05769 .42833 L
.05708 .42308 L
.056 .40385 L
.05716 .38462 L
.05769 .38127 L
.06165 .36538 L
.07069 .34615 L
.07692 .33722 L
.08583 .32692 L
.09615 .31871 L
.11538 .30777 L
.11558 .30769 L
F
0 g
.13462 .30391 m
.15385 .30708 L
.15722 .30769 L
.17308 .32211 L
.17732 .32692 L
.18816 .34615 L
.19231 .357 L
.19472 .36538 L
.19848 .38462 L
.20029 .40385 L
.2013 .42308 L
.20311 .44231 L
.2074 .46154 L
.21154 .47364 L
.21455 .48077 L
.22337 .5 L
.23077 .51686 L
.23143 .51923 L
.2362 .53846 L
.23776 .55769 L
.23572 .57692 L
.23077 .59572 L
.23021 .59615 L
.22066 .61538 L
.21154 .62836 L
.20611 .63462 L
.19231 .64709 L
.18327 .65385 L
.17308 .65877 L
.15385 .66526 L
.13462 .66648 L
.11538 .66219 L
.097 .65385 L
.09615 .6531 L
.07692 .63753 L
.07409 .63462 L
.05986 .61538 L
.05769 .61175 L
.05109 .59615 L
.04641 .57692 L
.04508 .55769 L
.04653 .53846 L
.05 .51923 L
.05435 .5 L
.05769 .48389 L
.05803 .48077 L
.05962 .46154 L
.05889 .44231 L
.05769 .42833 L
.05708 .42308 L
Mistroke
.056 .40385 L
.05716 .38462 L
.05769 .38127 L
.06165 .36538 L
.07069 .34615 L
.07692 .33722 L
.08583 .32692 L
.09615 .31871 L
.11538 .30777 L
.11558 .30769 L
.13462 .30391 L
Mfstroke
.6 g
.09615 .34177 m
.11538 .33048 L
.13462 .32795 L
.15385 .33467 L
.16746 .34615 L
.17308 .35622 L
.17722 .36538 L
.18257 .38462 L
.1847 .40385 L
.18536 .42308 L
.18659 .44231 L
.19048 .46154 L
.19231 .46794 L
.1979 .48077 L
.20733 .5 L
.21154 .50868 L
.21589 .51923 L
.22178 .53846 L
.224 .55769 L
.22228 .57692 L
.2164 .59615 L
.21154 .60649 L
.20556 .61538 L
.19231 .63002 L
.18716 .63462 L
.17308 .64312 L
.15385 .6499 L
.13462 .65111 L
.11538 .64682 L
.09615 .63672 L
.09316 .63462 L
.07692 .61841 L
.07468 .61538 L
.06412 .59615 L
.05869 .57692 L
.05769 .56932 L
.05719 .55769 L
.05769 .54806 L
.05887 .53846 L
.06294 .51923 L
.0682 .5 L
.0729 .48077 L
.07517 .46154 L
.07445 .44231 L
.07227 .42308 L
.07097 .40385 L
.07253 .38462 L
.07692 .36939 L
.07841 .36538 L
.09122 .34615 L
F
0 g
.09615 .34177 m
.11538 .33048 L
.13462 .32795 L
.15385 .33467 L
.16746 .34615 L
.17308 .35622 L
.17722 .36538 L
.18257 .38462 L
.1847 .40385 L
.18536 .42308 L
.18659 .44231 L
.19048 .46154 L
.19231 .46794 L
.1979 .48077 L
.20733 .5 L
.21154 .50868 L
.21589 .51923 L
.22178 .53846 L
.224 .55769 L
.22228 .57692 L
.2164 .59615 L
.21154 .60649 L
.20556 .61538 L
.19231 .63002 L
.18716 .63462 L
.17308 .64312 L
.15385 .6499 L
.13462 .65111 L
.11538 .64682 L
.09615 .63672 L
.09316 .63462 L
.07692 .61841 L
.07468 .61538 L
.06412 .59615 L
.05869 .57692 L
.05769 .56932 L
.05719 .55769 L
.05769 .54806 L
.05887 .53846 L
.06294 .51923 L
.0682 .5 L
.0729 .48077 L
.07517 .46154 L
.07445 .44231 L
.07227 .42308 L
.07097 .40385 L
.07253 .38462 L
.07692 .36939 L
.07841 .36538 L
.09122 .34615 L
Mistroke
.09615 .34177 L
Mfstroke
.5 g
.11538 .76127 m
.13462 .75645 L
.15385 .7574 L
.17308 .76394 L
.18344 .76923 L
.19231 .77607 L
.20551 .78846 L
.21154 .79544 L
.21976 .80769 L
.22935 .82692 L
.23077 .83082 L
.23212 .84615 L
.23283 .86538 L
.23077 .87137 L
.22304 .88462 L
.21154 .89939 L
.20647 .90385 L
.19231 .91463 L
.17615 .92308 L
.17308 .92417 L
.15385 .92905 L
.13462 .92962 L
.11538 .92579 L
.10701 .92308 L
.09615 .9168 L
.08034 .90385 L
.07692 .90012 L
.06668 .88462 L
.05953 .86538 L
.05769 .85437 L
.05724 .84615 L
.05769 .83705 L
.05931 .82692 L
.06599 .80769 L
.07692 .79018 L
.07834 .78846 L
.09615 .77176 L
.09899 .76923 L
F
0 g
.11538 .76127 m
.13462 .75645 L
.15385 .7574 L
.17308 .76394 L
.18344 .76923 L
.19231 .77607 L
.20551 .78846 L
.21154 .79544 L
.21976 .80769 L
.22935 .82692 L
.23077 .83082 L
.23212 .84615 L
.23283 .86538 L
.23077 .87137 L
.22304 .88462 L
.21154 .89939 L
.20647 .90385 L
.19231 .91463 L
.17615 .92308 L
.17308 .92417 L
.15385 .92905 L
.13462 .92962 L
.11538 .92579 L
.10701 .92308 L
.09615 .9168 L
.08034 .90385 L
.07692 .90012 L
.06668 .88462 L
.05953 .86538 L
.05769 .85437 L
.05724 .84615 L
.05769 .83705 L
.05931 .82692 L
.06599 .80769 L
.07692 .79018 L
.07834 .78846 L
.09615 .77176 L
.09899 .76923 L
.11538 .76127 L
s
.7 g
.11538 .35306 m
.13462 .35113 L
.15385 .36341 L
.15558 .36538 L
.16541 .38462 L
.16821 .40385 L
.16855 .42308 L
.16922 .44231 L
.17246 .46154 L
.17308 .46513 L
.18101 .48077 L
.19177 .5 L
.19231 .50099 L
.20175 .51923 L
.20856 .53846 L
.2113 .55769 L
.20965 .57692 L
.20305 .59615 L
.19231 .61257 L
.18979 .61538 L
.17308 .6285 L
.15913 .63462 L
.15385 .63604 L
.13462 .63735 L
.12077 .63462 L
.11538 .6327 L
.09615 .62089 L
.09027 .61538 L
.07717 .59615 L
.07692 .59561 L
.07068 .57692 L
.06893 .55769 L
.07094 .53846 L
.07592 .51923 L
.07692 .51617 L
.0824 .5 L
.08879 .48077 L
.09255 .46154 L
.09198 .44231 L
.08901 .42308 L
.08729 .40385 L
.08973 .38462 L
.09615 .37084 L
.09997 .36538 L
F
0 g
.11538 .35306 m
.13462 .35113 L
.15385 .36341 L
.15558 .36538 L
.16541 .38462 L
.16821 .40385 L
.16855 .42308 L
.16922 .44231 L
.17246 .46154 L
.17308 .46513 L
.18101 .48077 L
.19177 .5 L
.19231 .50099 L
.20175 .51923 L
.20856 .53846 L
.2113 .55769 L
.20965 .57692 L
.20305 .59615 L
.19231 .61257 L
.18979 .61538 L
.17308 .6285 L
.15913 .63462 L
.15385 .63604 L
.13462 .63735 L
.12077 .63462 L
.11538 .6327 L
.09615 .62089 L
.09027 .61538 L
.07717 .59615 L
.07692 .59561 L
.07068 .57692 L
.06893 .55769 L
.07094 .53846 L
.07592 .51923 L
.07692 .51617 L
.0824 .5 L
.08879 .48077 L
.09255 .46154 L
.09198 .44231 L
.08901 .42308 L
.08729 .40385 L
.08973 .38462 L
.09615 .37084 L
.09997 .36538 L
.11538 .35306 L
s
.6 g
.11538 .77978 m
.13462 .77455 L
.15385 .77551 L
.17308 .78274 L
.18251 .78846 L
.19231 .79744 L
.20049 .80769 L
.21031 .82692 L
.21154 .83086 L
.21392 .84615 L
.21154 .86498 L
.21142 .86538 L
.20131 .88462 L
.19231 .89485 L
.18035 .90385 L
.17308 .90752 L
.15385 .91368 L
.13462 .9144 L
.11538 .90964 L
.10303 .90385 L
.09615 .89807 L
.08425 .88462 L
.07692 .87232 L
.0753 .86538 L
.07244 .84615 L
.07501 .82692 L
.07692 .81826 L
.08335 .80769 L
.09615 .79232 L
.09998 .78846 L
F
0 g
.11538 .77978 m
.13462 .77455 L
.15385 .77551 L
.17308 .78274 L
.18251 .78846 L
.19231 .79744 L
.20049 .80769 L
.21031 .82692 L
.21154 .83086 L
.21392 .84615 L
.21154 .86498 L
.21142 .86538 L
.20131 .88462 L
.19231 .89485 L
.18035 .90385 L
.17308 .90752 L
.15385 .91368 L
.13462 .9144 L
.11538 .90964 L
.10303 .90385 L
.09615 .89807 L
.08425 .88462 L
.07692 .87232 L
.0753 .86538 L
.07244 .84615 L
.07501 .82692 L
.07692 .81826 L
.08335 .80769 L
.09615 .79232 L
.09998 .78846 L
.11538 .77978 L
s
.8 g
.13462 .45431 m
.14123 .46154 L
.15385 .47818 L
.1607 .48077 L
.17308 .49836 L
.17449 .5 L
.18737 .51923 L
.19231 .52859 L
.19534 .53846 L
.19876 .55769 L
.19692 .57692 L
.19231 .58968 L
.18908 .59615 L
.17308 .61333 L
.16977 .61538 L
.15385 .6225 L
.13462 .62406 L
.11538 .61845 L
.10893 .61538 L
.09615 .60352 L
.09098 .59615 L
.08289 .57692 L
.08084 .55769 L
.08328 .53846 L
.08962 .51923 L
.09615 .50585 L
.09793 .5 L
.1084 .48077 L
.11538 .47308 L
.1231 .46154 L
F
0 g
.13462 .45431 m
.14123 .46154 L
.15385 .47818 L
.1607 .48077 L
.17308 .49836 L
.17449 .5 L
.18737 .51923 L
.19231 .52859 L
.19534 .53846 L
.19876 .55769 L
.19692 .57692 L
.19231 .58968 L
.18908 .59615 L
.17308 .61333 L
.16977 .61538 L
.15385 .6225 L
.13462 .62406 L
.11538 .61845 L
.10893 .61538 L
.09615 .60352 L
.09098 .59615 L
.08289 .57692 L
.08084 .55769 L
.08328 .53846 L
.08962 .51923 L
.09615 .50585 L
.09793 .5 L
.1084 .48077 L
.11538 .47308 L
.1231 .46154 L
.13462 .45431 L
s
.7 g
.11538 .79855 m
.13462 .79201 L
.15385 .79313 L
.17308 .80246 L
.17937 .80769 L
.19189 .82692 L
.19231 .82811 L
.19587 .84615 L
.19231 .86492 L
.19214 .86538 L
.17871 .88462 L
.17308 .8889 L
.15385 .8975 L
.13462 .89842 L
.11538 .89207 L
.1043 .88462 L
.09615 .87603 L
.0922 .86538 L
.08836 .84615 L
.09181 .82692 L
.09615 .81462 L
.10287 .80769 L
F
0 g
.11538 .79855 m
.13462 .79201 L
.15385 .79313 L
.17308 .80246 L
.17937 .80769 L
.19189 .82692 L
.19231 .82811 L
.19587 .84615 L
.19231 .86492 L
.19214 .86538 L
.17871 .88462 L
.17308 .8889 L
.15385 .8975 L
.13462 .89842 L
.11538 .89207 L
.1043 .88462 L
.09615 .87603 L
.0922 .86538 L
.08836 .84615 L
.09181 .82692 L
.09615 .81462 L
.10287 .80769 L
.11538 .79855 L
s
.9 g
.13462 .49903 m
.14386 .5 L
.15385 .50466 L
.16957 .51923 L
.17308 .52284 L
.18132 .53846 L
.18569 .55769 L
.18344 .57692 L
.17308 .59457 L
.17163 .59615 L
.15385 .60814 L
.13462 .61009 L
.11538 .60274 L
.10674 .59615 L
.09658 .57692 L
.09615 .57488 L
.094 .55769 L
.09615 .54313 L
.09705 .53846 L
.10492 .51923 L
.11538 .50885 L
.12929 .5 L
F
0 g
.13462 .49903 m
.14386 .5 L
.15385 .50466 L
.16957 .51923 L
.17308 .52284 L
.18132 .53846 L
.18569 .55769 L
.18344 .57692 L
.17308 .59457 L
.17163 .59615 L
.15385 .60814 L
.13462 .61009 L
.11538 .60274 L
.10674 .59615 L
.09658 .57692 L
.09615 .57488 L
.094 .55769 L
.09615 .54313 L
.09705 .53846 L
.10492 .51923 L
.11538 .50885 L
.12929 .5 L
.13462 .49903 L
s
.8 g
.11538 .8238 m
.13462 .81003 L
.15385 .81139 L
.169 .82692 L
.17308 .83482 L
.17532 .84615 L
.17308 .85719 L
.16864 .86538 L
.15385 .87982 L
.13462 .88115 L
.11538 .86691 L
.11444 .86538 L
.10703 .84615 L
.11361 .82692 L
F
0 g
.11538 .8238 m
.13462 .81003 L
.15385 .81139 L
.169 .82692 L
.17308 .83482 L
.17532 .84615 L
.17308 .85719 L
.16864 .86538 L
.15385 .87982 L
.13462 .88115 L
.11538 .86691 L
.11444 .86538 L
.10703 .84615 L
.11361 .82692 L
.11538 .8238 L
s
1 g
.13462 .52353 m
.15385 .52866 L
.16158 .53846 L
.16862 .55769 L
.1648 .57692 L
.15385 .58849 L
.13462 .5919 L
.11538 .57817 L
.11446 .57692 L
.10927 .55769 L
.11538 .54023 L
.11641 .53846 L
F
0 g
.13462 .52353 m
.15385 .52866 L
.16158 .53846 L
.16862 .55769 L
.1648 .57692 L
.15385 .58849 L
.13462 .5919 L
.11538 .57817 L
.11446 .57692 L
.10927 .55769 L
.11538 .54023 L
.11641 .53846 L
.13462 .52353 L
s
.5 g
.15385 .06957 m
.17308 .06197 L
.19231 .05958 L
.21154 .06184 L
.23077 .06928 L
.2426 .07692 L
.25 .08374 L
.25974 .09615 L
.2687 .11538 L
.26923 .11718 L
.27225 .13462 L
.27105 .15385 L
.26923 .16151 L
.26502 .17308 L
.2529 .19231 L
.25 .19566 L
.23123 .21154 L
.23077 .21182 L
.21154 .22163 L
.19231 .22673 L
.17308 .22644 L
.15385 .21842 L
.14395 .21154 L
.13462 .20088 L
.12836 .19231 L
.11866 .17308 L
.11538 .16247 L
.11361 .15385 L
.1128 .13462 L
.11538 .1192 L
.11647 .11538 L
.12545 .09615 L
.13462 .08433 L
.14256 .07692 L
F
0 g
.15385 .06957 m
.17308 .06197 L
.19231 .05958 L
.21154 .06184 L
.23077 .06928 L
.2426 .07692 L
.25 .08374 L
.25974 .09615 L
.2687 .11538 L
.26923 .11718 L
.27225 .13462 L
.27105 .15385 L
.26923 .16151 L
.26502 .17308 L
.2529 .19231 L
.25 .19566 L
.23123 .21154 L
.23077 .21182 L
.21154 .22163 L
.19231 .22673 L
.17308 .22644 L
.15385 .21842 L
.14395 .21154 L
.13462 .20088 L
.12836 .19231 L
.11866 .17308 L
.11538 .16247 L
.11361 .15385 L
.1128 .13462 L
.11538 .1192 L
.11647 .11538 L
.12545 .09615 L
.13462 .08433 L
.14256 .07692 L
.15385 .06957 L
s
.8 g
.11538 .3988 m
.13462 .39011 L
.14019 .40385 L
.13815 .42308 L
.13462 .43283 L
.11859 .42308 L
.11538 .41261 L
.11464 .40385 L
F
0 g
.11538 .3988 m
.13462 .39011 L
.14019 .40385 L
.13815 .42308 L
.13462 .43283 L
.11859 .42308 L
.11538 .41261 L
.11464 .40385 L
.11538 .3988 L
s
.6 g
.17308 .09206 m
.19231 .0881 L
.21154 .09186 L
.22311 .09615 L
.23077 .10388 L
.23791 .11538 L
.24368 .13462 L
.24191 .15385 L
.23141 .17308 L
.23077 .17387 L
.21154 .18873 L
.19888 .19231 L
.19231 .19305 L
.18206 .19231 L
.17308 .18994 L
.15385 .17553 L
.15196 .17308 L
.14259 .15385 L
.14122 .13462 L
.14717 .11538 L
.15385 .10454 L
.16234 .09615 L
F
0 g
.17308 .09206 m
.19231 .0881 L
.21154 .09186 L
.22311 .09615 L
.23077 .10388 L
.23791 .11538 L
.24368 .13462 L
.24191 .15385 L
.23141 .17308 L
.23077 .17387 L
.21154 .18873 L
.19888 .19231 L
.19231 .19305 L
.18206 .19231 L
.17308 .18994 L
.15385 .17553 L
.15196 .17308 L
.14259 .15385 L
.14122 .13462 L
.14717 .11538 L
.15385 .10454 L
.16234 .09615 L
.17308 .09206 L
s
.1 g
.30577 .98077 m
.28846 .97056 L
.27056 .96154 L
.26923 .96104 L
.25 .95799 L
.23195 .96154 L
.23077 .96191 L
.21154 .96911 L
.19231 .97609 L
.17535 .98077 L
F
0 g
.30577 .98077 m
.28846 .97056 L
.27056 .96154 L
.26923 .96104 L
.25 .95799 L
.23195 .96154 L
.23077 .96191 L
.21154 .96911 L
.19231 .97609 L
.17535 .98077 L
s
.2 g
.428 .98077 m
.44231 .97384 L
.46023 .96154 L
.46154 .96046 L
.47975 .94231 L
.48077 .94121 L
.49265 .92308 L
.5 .91567 L
.50524 .90385 L
.51127 .88462 L
.50787 .86538 L
.5 .84967 L
.49729 .84615 L
.48318 .82692 L
.48077 .82222 L
.46666 .80769 L
.46154 .80303 L
.44231 .78964 L
.44031 .78846 L
.42308 .78103 L
.40385 .77612 L
.38462 .77456 L
.36538 .77608 L
.34615 .78038 L
.32692 .78688 L
.32416 .78846 L
.30769 .79453 L
.28846 .80016 L
.26923 .79769 L
.2556 .78846 L
.25 .78329 L
.23644 .76923 L
.23077 .763 L
.21896 .75 L
.21154 .74382 L
.20235 .73077 L
.19312 .71154 L
.19903 .69231 L
.21154 .67606 L
.21407 .67308 L
.23006 .65385 L
.23077 .65292 L
.24379 .63462 L
.25 .62474 L
.25503 .61538 L
.26492 .59615 L
.26923 .58841 L
.27558 .57692 L
.28846 .56384 L
.30769 .56448 L
.32692 .57241 L
.33838 .57692 L
.34615 .5802 L
.36538 .58582 L
.38462 .5886 L
.40385 .5882 L
.42308 .58435 L
.44203 .57692 L
.44231 .57676 L
.46154 .56476 L
.46999 .55769 L
.48077 .5481 L
.48614 .53846 L
.5 .52814 L
.5077 .51923 L
.51923 .51233 L
.53091 .51923 L
.53846 .52887 L
.55011 .53846 L
.55769 .55101 L
.56432 .55769 L
.57692 .56971 L
.58627 .57692 L
.59615 .58322 L
.61538 .59217 L
.62928 .59615 L
.63462 .59714 L
.65385 .59846 L
.67308 .59632 L
.67417 .59615 L
.69231 .59028 L
.71154 .5797 L
.7154 .57692 L
.73077 .56245 L
.73462 .55769 L
.74636 .53846 L
.75 .53111 L
.75319 .51923 L
.7561 .5 L
.75546 .48077 L
.75122 .46154 L
.75 .45759 L
.74277 .44231 L
.73077 .42517 L
.7289 .42308 L
.71154 .40775 L
.70585 .40385 L
.69231 .39701 L
.67308 .39077 L
.65385 .38836 L
.63462 .38965 L
.61538 .3947 L
.59615 .40365 L
.59581 .40385 L
.57692 .41731 L
.57065 .42308 L
.55769 .43583 L
.55528 .44231 L
.53846 .4579 L
.5355 .46154 L
.51923 .47226 L
.50489 .46154 L
.5 .45547 L
.48529 .44231 L
.48077 .4343 L
.46853 .42308 L
.46154 .4172 L
.44231 .40499 L
.44031 .40385 L
.42308 .39732 L
.40385 .39349 L
.38462 .39326 L
.36538 .39666 L
.34615 .4038 L
.34606 .40385 L
.32692 .41549 L
.31794 .42308 L
.30769 .4322 L
.29828 .44231 L
.28846 .45338 L
.28031 .46154 L
.26923 .46672 L
.25737 .46154 L
.25 .4525 L
.24314 .44231 L
.23788 .42308 L
.23554 .40385 L
.2336 .38462 L
.23141 .36538 L
.23077 .36078 L
.2288 .34615 L
.22654 .32692 L
.22646 .30769 L
.23077 .29129 L
.23213 .28846 L
.24727 .26923 L
.25 .26654 L
.26837 .25 L
.26923 .24921 L
.28758 .23077 L
.28846 .22977 L
.30228 .21154 L
.30769 .20271 L
.31285 .19231 L
.31991 .17308 L
.32383 .15385 L
.32472 .13462 L
.32254 .11538 L
.31718 .09615 L
.30838 .07692 L
.30769 .07569 L
.29528 .05769 L
.28846 .04992 L
.27612 .03846 L
.26923 .03322 L
.25 .02176 L
.24485 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.428 .98077 m
.44231 .97384 L
.46023 .96154 L
.46154 .96046 L
.47975 .94231 L
.48077 .94121 L
.49265 .92308 L
.5 .91567 L
.50524 .90385 L
.51127 .88462 L
.50787 .86538 L
.5 .84967 L
.49729 .84615 L
.48318 .82692 L
.48077 .82222 L
.46666 .80769 L
.46154 .80303 L
.44231 .78964 L
.44031 .78846 L
.42308 .78103 L
.40385 .77612 L
.38462 .77456 L
.36538 .77608 L
.34615 .78038 L
.32692 .78688 L
.32416 .78846 L
.30769 .79453 L
.28846 .80016 L
.26923 .79769 L
.2556 .78846 L
.25 .78329 L
.23644 .76923 L
.23077 .763 L
.21896 .75 L
.21154 .74382 L
.20235 .73077 L
.19312 .71154 L
.19903 .69231 L
.21154 .67606 L
.21407 .67308 L
.23006 .65385 L
.23077 .65292 L
.24379 .63462 L
.25 .62474 L
.25503 .61538 L
.26492 .59615 L
.26923 .58841 L
.27558 .57692 L
.28846 .56384 L
.30769 .56448 L
Mistroke
.32692 .57241 L
.33838 .57692 L
.34615 .5802 L
.36538 .58582 L
.38462 .5886 L
.40385 .5882 L
.42308 .58435 L
.44203 .57692 L
.44231 .57676 L
.46154 .56476 L
.46999 .55769 L
.48077 .5481 L
.48614 .53846 L
.5 .52814 L
.5077 .51923 L
.51923 .51233 L
.53091 .51923 L
.53846 .52887 L
.55011 .53846 L
.55769 .55101 L
.56432 .55769 L
.57692 .56971 L
.58627 .57692 L
.59615 .58322 L
.61538 .59217 L
.62928 .59615 L
.63462 .59714 L
.65385 .59846 L
.67308 .59632 L
.67417 .59615 L
.69231 .59028 L
.71154 .5797 L
.7154 .57692 L
.73077 .56245 L
.73462 .55769 L
.74636 .53846 L
.75 .53111 L
.75319 .51923 L
.7561 .5 L
.75546 .48077 L
.75122 .46154 L
.75 .45759 L
.74277 .44231 L
.73077 .42517 L
.7289 .42308 L
.71154 .40775 L
.70585 .40385 L
.69231 .39701 L
.67308 .39077 L
.65385 .38836 L
Mistroke
.63462 .38965 L
.61538 .3947 L
.59615 .40365 L
.59581 .40385 L
.57692 .41731 L
.57065 .42308 L
.55769 .43583 L
.55528 .44231 L
.53846 .4579 L
.5355 .46154 L
.51923 .47226 L
.50489 .46154 L
.5 .45547 L
.48529 .44231 L
.48077 .4343 L
.46853 .42308 L
.46154 .4172 L
.44231 .40499 L
.44031 .40385 L
.42308 .39732 L
.40385 .39349 L
.38462 .39326 L
.36538 .39666 L
.34615 .4038 L
.34606 .40385 L
.32692 .41549 L
.31794 .42308 L
.30769 .4322 L
.29828 .44231 L
.28846 .45338 L
.28031 .46154 L
.26923 .46672 L
.25737 .46154 L
.25 .4525 L
.24314 .44231 L
.23788 .42308 L
.23554 .40385 L
.2336 .38462 L
.23141 .36538 L
.23077 .36078 L
.2288 .34615 L
.22654 .32692 L
.22646 .30769 L
.23077 .29129 L
.23213 .28846 L
.24727 .26923 L
.25 .26654 L
.26837 .25 L
.26923 .24921 L
.28758 .23077 L
Mistroke
.28846 .22977 L
.30228 .21154 L
.30769 .20271 L
.31285 .19231 L
.31991 .17308 L
.32383 .15385 L
.32472 .13462 L
.32254 .11538 L
.31718 .09615 L
.30838 .07692 L
.30769 .07569 L
.29528 .05769 L
.28846 .04992 L
.27612 .03846 L
.26923 .03322 L
.25 .02176 L
.24485 .01923 L
Mfstroke
.1 g
.73052 .98077 m
.73077 .98058 L
.75 .96264 L
.75093 .96154 L
.76425 .94231 L
.76923 .93286 L
.77297 .92308 L
.77808 .90385 L
.7801 .88462 L
.7791 .86538 L
.77506 .84615 L
.76923 .82985 L
.76773 .82692 L
.75602 .80769 L
.75 .80008 L
.73853 .78846 L
.73077 .78217 L
.71154 .77017 L
.70978 .76923 L
.69231 .76265 L
.67308 .75838 L
.65385 .75721 L
.63462 .75909 L
.61538 .76402 L
.60181 .76923 L
.59615 .77216 L
.57692 .78408 L
.57123 .78846 L
.55769 .79919 L
.54732 .80769 L
.53846 .81409 L
.51923 .81933 L
.5 .80983 L
.49617 .80769 L
.48077 .79452 L
.47268 .78846 L
.46154 .78062 L
.44231 .7698 L
.44116 .76923 L
.42308 .76275 L
.40385 .75853 L
.38462 .75709 L
.36538 .75822 L
.34615 .76147 L
.32692 .76599 L
.31263 .76923 L
.30769 .7702 L
.28846 .77097 L
.28105 .76923 L
.26923 .76375 L
.25303 .75 L
.25 .74715 L
.23843 .73077 L
.2313 .71154 L
.23392 .69231 L
.24383 .67308 L
.25 .66281 L
.25618 .65385 L
.26899 .63462 L
.26923 .63427 L
.282 .61538 L
.28846 .60915 L
.30769 .59868 L
.32692 .59913 L
.34615 .60294 L
.36538 .60658 L
.38462 .60851 L
.40385 .608 L
.42308 .60473 L
.44231 .59862 L
.44832 .59615 L
.46154 .58941 L
.48077 .57788 L
.48231 .57692 L
.5 .56663 L
.51923 .56212 L
.53846 .56908 L
.55216 .57692 L
.55769 .58257 L
.57692 .596 L
.57717 .59615 L
.59615 .60642 L
.61538 .6138 L
.62112 .61538 L
.63462 .61784 L
.65385 .61894 L
.67308 .61718 L
.68424 .61538 L
.69231 .61224 L
.71154 .60368 L
.72383 .59615 L
.73077 .59082 L
.74526 .57692 L
.75 .5713 L
.75923 .55769 L
.7686 .53846 L
.76923 .53721 L
.77409 .51923 L
.7765 .5 L
.77597 .48077 L
.77247 .46154 L
.76923 .45033 L
.76568 .44231 L
.75489 .42308 L
.75 .41629 L
.73891 .40385 L
.73077 .39651 L
.71424 .38462 L
.71154 .38312 L
.69231 .37424 L
.67308 .36851 L
.65385 .36603 L
.63462 .36695 L
.61538 .37142 L
.59615 .3792 L
.58532 .38462 L
.57692 .38994 L
.55769 .4034 L
.55745 .40385 L
.53846 .41645 L
.51923 .42217 L
.5 .41634 L
.48077 .40416 L
.48027 .40385 L
.46154 .3922 L
.44694 .38462 L
.44231 .38273 L
.42308 .37653 L
.40385 .37316 L
.38462 .3727 L
.36538 .37513 L
.34615 .38033 L
.33463 .38462 L
.32692 .3881 L
.30769 .39798 L
.29465 .40385 L
.28846 .40585 L
.27413 .40385 L
.26923 .39947 L
.26046 .38462 L
.25736 .36538 L
.25622 .34615 L
.25756 .32692 L
.26355 .30769 L
.26923 .29717 L
.27631 .28846 L
.28846 .27501 L
.29418 .26923 L
.30769 .25479 L
.31191 .25 L
.32689 .23077 L
.32692 .23072 L
.33873 .21154 L
.34615 .19683 L
.34794 .19231 L
.35442 .17308 L
.35861 .15385 L
.35994 .13462 L
.35797 .11538 L
.35285 .09615 L
.34615 .07839 L
.34537 .07692 L
.3342 .05769 L
.32692 .04712 L
.31991 .03846 L
.30769 .02543 L
.30096 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.73052 .98077 m
.73077 .98058 L
.75 .96264 L
.75093 .96154 L
.76425 .94231 L
.76923 .93286 L
.77297 .92308 L
.77808 .90385 L
.7801 .88462 L
.7791 .86538 L
.77506 .84615 L
.76923 .82985 L
.76773 .82692 L
.75602 .80769 L
.75 .80008 L
.73853 .78846 L
.73077 .78217 L
.71154 .77017 L
.70978 .76923 L
.69231 .76265 L
.67308 .75838 L
.65385 .75721 L
.63462 .75909 L
.61538 .76402 L
.60181 .76923 L
.59615 .77216 L
.57692 .78408 L
.57123 .78846 L
.55769 .79919 L
.54732 .80769 L
.53846 .81409 L
.51923 .81933 L
.5 .80983 L
.49617 .80769 L
.48077 .79452 L
.47268 .78846 L
.46154 .78062 L
.44231 .7698 L
.44116 .76923 L
.42308 .76275 L
.40385 .75853 L
.38462 .75709 L
.36538 .75822 L
.34615 .76147 L
.32692 .76599 L
.31263 .76923 L
.30769 .7702 L
.28846 .77097 L
.28105 .76923 L
.26923 .76375 L
Mistroke
.25303 .75 L
.25 .74715 L
.23843 .73077 L
.2313 .71154 L
.23392 .69231 L
.24383 .67308 L
.25 .66281 L
.25618 .65385 L
.26899 .63462 L
.26923 .63427 L
.282 .61538 L
.28846 .60915 L
.30769 .59868 L
.32692 .59913 L
.34615 .60294 L
.36538 .60658 L
.38462 .60851 L
.40385 .608 L
.42308 .60473 L
.44231 .59862 L
.44832 .59615 L
.46154 .58941 L
.48077 .57788 L
.48231 .57692 L
.5 .56663 L
.51923 .56212 L
.53846 .56908 L
.55216 .57692 L
.55769 .58257 L
.57692 .596 L
.57717 .59615 L
.59615 .60642 L
.61538 .6138 L
.62112 .61538 L
.63462 .61784 L
.65385 .61894 L
.67308 .61718 L
.68424 .61538 L
.69231 .61224 L
.71154 .60368 L
.72383 .59615 L
.73077 .59082 L
.74526 .57692 L
.75 .5713 L
.75923 .55769 L
.7686 .53846 L
.76923 .53721 L
.77409 .51923 L
.7765 .5 L
.77597 .48077 L
Mistroke
.77247 .46154 L
.76923 .45033 L
.76568 .44231 L
.75489 .42308 L
.75 .41629 L
.73891 .40385 L
.73077 .39651 L
.71424 .38462 L
.71154 .38312 L
.69231 .37424 L
.67308 .36851 L
.65385 .36603 L
.63462 .36695 L
.61538 .37142 L
.59615 .3792 L
.58532 .38462 L
.57692 .38994 L
.55769 .4034 L
.55745 .40385 L
.53846 .41645 L
.51923 .42217 L
.5 .41634 L
.48077 .40416 L
.48027 .40385 L
.46154 .3922 L
.44694 .38462 L
.44231 .38273 L
.42308 .37653 L
.40385 .37316 L
.38462 .3727 L
.36538 .37513 L
.34615 .38033 L
.33463 .38462 L
.32692 .3881 L
.30769 .39798 L
.29465 .40385 L
.28846 .40585 L
.27413 .40385 L
.26923 .39947 L
.26046 .38462 L
.25736 .36538 L
.25622 .34615 L
.25756 .32692 L
.26355 .30769 L
.26923 .29717 L
.27631 .28846 L
.28846 .27501 L
.29418 .26923 L
.30769 .25479 L
.31191 .25 L
Mistroke
.32689 .23077 L
.32692 .23072 L
.33873 .21154 L
.34615 .19683 L
.34794 .19231 L
.35442 .17308 L
.35861 .15385 L
.35994 .13462 L
.35797 .11538 L
.35285 .09615 L
.34615 .07839 L
.34537 .07692 L
.3342 .05769 L
.32692 .04712 L
.31991 .03846 L
.30769 .02543 L
.30096 .01923 L
Mfstroke
.77427 .98077 m
.78821 .96154 L
.78846 .96114 L
.79781 .94231 L
.80479 .92308 L
.80769 .91331 L
.80887 .90385 L
.81034 .88462 L
.80961 .86538 L
.80769 .85124 L
.80655 .84615 L
.80049 .82692 L
.79177 .80769 L
.78846 .80157 L
.77945 .78846 L
.76923 .7761 L
.76247 .76923 L
.75 .75865 L
.73802 .75 L
.73077 .74602 L
.71154 .73665 L
.69617 .73077 L
.69231 .73033 L
.67308 .72808 L
.65385 .7273 L
.63462 .7286 L
.61557 .73077 L
.61538 .73087 L
.59615 .73831 L
.57692 .74745 L
.57197 .75 L
.55769 .75842 L
.53846 .76846 L
.53644 .76923 L
.51923 .77263 L
.50365 .76923 L
.5 .76786 L
.48077 .75822 L
.46567 .75 L
.46154 .74809 L
.44231 .74006 L
.42308 .73368 L
.41219 .73077 L
.40385 .73025 L
.38462 .72937 L
.36538 .72965 L
.34615 .73062 L
.34305 .73077 L
.32692 .73217 L
.30769 .73087 L
.3073 .73077 L
.28846 .72049 L
.2822 .71154 L
.28035 .69231 L
.28761 .67308 L
.28846 .67119 L
.30072 .65385 L
.30769 .64793 L
.32692 .6389 L
.34615 .63752 L
.36538 .63828 L
.38462 .63886 L
.40385 .63816 L
.42308 .63585 L
.43081 .63462 L
.44231 .63107 L
.46154 .6239 L
.48077 .61615 L
.4828 .61538 L
.5 .60926 L
.51923 .60761 L
.53846 .61319 L
.54417 .61538 L
.55769 .62269 L
.57692 .63294 L
.58026 .63462 L
.59615 .64064 L
.61538 .64686 L
.63462 .65087 L
.65385 .65205 L
.67308 .65024 L
.69231 .64555 L
.71154 .63865 L
.72145 .63462 L
.73077 .62918 L
.75 .61586 L
.75061 .61538 L
.76923 .59734 L
.77025 .59615 L
.78434 .57692 L
.78846 .57015 L
.79441 .55769 L
.80157 .53846 L
.80616 .51923 L
.80769 .50741 L
.80812 .5 L
.80773 .48077 L
.80769 .48023 L
.8048 .46154 L
.79929 .44231 L
.79127 .42308 L
.78846 .41744 L
.77989 .40385 L
.76923 .3898 L
.76464 .38462 L
.75 .37046 L
.74421 .36538 L
.73077 .35592 L
.71765 .34615 L
.71154 .34221 L
.69231 .32949 L
.68921 .32692 L
.68156 .30769 L
.69231 .29403 L
.69838 .28846 L
.71154 .27509 L
.72036 .26923 L
.73077 .25923 L
.74009 .25 L
.75 .23869 L
.7562 .23077 L
.76906 .21154 L
.76923 .21125 L
.77879 .19231 L
.78626 .17308 L
.78846 .16626 L
.79134 .15385 L
.79435 .13462 L
.79547 .11538 L
.79469 .09615 L
.79201 .07692 L
.78846 .06112 L
.78736 .05769 L
.78027 .03846 L
.77092 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.77427 .98077 m
.78821 .96154 L
.78846 .96114 L
.79781 .94231 L
.80479 .92308 L
.80769 .91331 L
.80887 .90385 L
.81034 .88462 L
.80961 .86538 L
.80769 .85124 L
.80655 .84615 L
.80049 .82692 L
.79177 .80769 L
.78846 .80157 L
.77945 .78846 L
.76923 .7761 L
.76247 .76923 L
.75 .75865 L
.73802 .75 L
.73077 .74602 L
.71154 .73665 L
.69617 .73077 L
.69231 .73033 L
.67308 .72808 L
.65385 .7273 L
.63462 .7286 L
.61557 .73077 L
.61538 .73087 L
.59615 .73831 L
.57692 .74745 L
.57197 .75 L
.55769 .75842 L
.53846 .76846 L
.53644 .76923 L
.51923 .77263 L
.50365 .76923 L
.5 .76786 L
.48077 .75822 L
.46567 .75 L
.46154 .74809 L
.44231 .74006 L
.42308 .73368 L
.41219 .73077 L
.40385 .73025 L
.38462 .72937 L
.36538 .72965 L
.34615 .73062 L
.34305 .73077 L
.32692 .73217 L
.30769 .73087 L
Mistroke
.3073 .73077 L
.28846 .72049 L
.2822 .71154 L
.28035 .69231 L
.28761 .67308 L
.28846 .67119 L
.30072 .65385 L
.30769 .64793 L
.32692 .6389 L
.34615 .63752 L
.36538 .63828 L
.38462 .63886 L
.40385 .63816 L
.42308 .63585 L
.43081 .63462 L
.44231 .63107 L
.46154 .6239 L
.48077 .61615 L
.4828 .61538 L
.5 .60926 L
.51923 .60761 L
.53846 .61319 L
.54417 .61538 L
.55769 .62269 L
.57692 .63294 L
.58026 .63462 L
.59615 .64064 L
.61538 .64686 L
.63462 .65087 L
.65385 .65205 L
.67308 .65024 L
.69231 .64555 L
.71154 .63865 L
.72145 .63462 L
.73077 .62918 L
.75 .61586 L
.75061 .61538 L
.76923 .59734 L
.77025 .59615 L
.78434 .57692 L
.78846 .57015 L
.79441 .55769 L
.80157 .53846 L
.80616 .51923 L
.80769 .50741 L
.80812 .5 L
.80773 .48077 L
.80769 .48023 L
.8048 .46154 L
.79929 .44231 L
Mistroke
.79127 .42308 L
.78846 .41744 L
.77989 .40385 L
.76923 .3898 L
.76464 .38462 L
.75 .37046 L
.74421 .36538 L
.73077 .35592 L
.71765 .34615 L
.71154 .34221 L
.69231 .32949 L
.68921 .32692 L
.68156 .30769 L
.69231 .29403 L
.69838 .28846 L
.71154 .27509 L
.72036 .26923 L
.73077 .25923 L
.74009 .25 L
.75 .23869 L
.7562 .23077 L
.76906 .21154 L
.76923 .21125 L
.77879 .19231 L
.78626 .17308 L
.78846 .16626 L
.79134 .15385 L
.79435 .13462 L
.79547 .11538 L
.79469 .09615 L
.79201 .07692 L
.78846 .06112 L
.78736 .05769 L
.78027 .03846 L
.77092 .01923 L
Mfstroke
.5 g
.36538 .8028 m
.38462 .80053 L
.40385 .80245 L
.42233 .80769 L
.42308 .80899 L
.44231 .82164 L
.44784 .82692 L
.46154 .84544 L
.46188 .84615 L
.46896 .86538 L
.47079 .88462 L
.46739 .90385 L
.46154 .91955 L
.4585 .92308 L
.44231 .9418 L
.44173 .94231 L
.42308 .95442 L
.40385 .96092 L
.40041 .96154 L
.38462 .96263 L
.3733 .96154 L
.36538 .9599 L
.34615 .95245 L
.33053 .94231 L
.32692 .93931 L
.31188 .92308 L
.30769 .91836 L
.30074 .90385 L
.29415 .88462 L
.29448 .86538 L
.3043 .84615 L
.30769 .83754 L
.31916 .82692 L
.32692 .82038 L
.34615 .80924 L
.3484 .80769 L
F
0 g
.36538 .8028 m
.38462 .80053 L
.40385 .80245 L
.42233 .80769 L
.42308 .80899 L
.44231 .82164 L
.44784 .82692 L
.46154 .84544 L
.46188 .84615 L
.46896 .86538 L
.47079 .88462 L
.46739 .90385 L
.46154 .91955 L
.4585 .92308 L
.44231 .9418 L
.44173 .94231 L
.42308 .95442 L
.40385 .96092 L
.40041 .96154 L
.38462 .96263 L
.3733 .96154 L
.36538 .9599 L
.34615 .95245 L
.33053 .94231 L
.32692 .93931 L
.31188 .92308 L
.30769 .91836 L
.30074 .90385 L
.29415 .88462 L
.29448 .86538 L
.3043 .84615 L
.30769 .83754 L
.31916 .82692 L
.32692 .82038 L
.34615 .80924 L
.3484 .80769 L
.36538 .8028 L
s
.4 g
.36538 .41412 m
.38462 .4098 L
.40385 .40994 L
.42308 .41452 L
.44083 .42308 L
.44231 .42415 L
.46154 .44078 L
.46279 .44231 L
.47549 .46154 L
.48077 .47447 L
.48143 .48077 L
.48153 .5 L
.48077 .50798 L
.47627 .51923 L
.46384 .53846 L
.46154 .54131 L
.44234 .55769 L
.44231 .55771 L
.42308 .56731 L
.40385 .57193 L
.38462 .57227 L
.36538 .56857 L
.34615 .56069 L
.34099 .55769 L
.32692 .54797 L
.31885 .53846 L
.30769 .52699 L
.30491 .51923 L
.30141 .5 L
.30634 .48077 L
.30769 .47078 L
.31211 .46154 L
.32494 .44231 L
.32692 .43987 L
.34615 .4235 L
.34673 .42308 L
F
0 g
.36538 .41412 m
.38462 .4098 L
.40385 .40994 L
.42308 .41452 L
.44083 .42308 L
.44231 .42415 L
.46154 .44078 L
.46279 .44231 L
.47549 .46154 L
.48077 .47447 L
.48143 .48077 L
.48153 .5 L
.48077 .50798 L
.47627 .51923 L
.46384 .53846 L
.46154 .54131 L
.44234 .55769 L
.44231 .55771 L
.42308 .56731 L
.40385 .57193 L
.38462 .57227 L
.36538 .56857 L
.34615 .56069 L
.34099 .55769 L
.32692 .54797 L
.31885 .53846 L
.30769 .52699 L
.30491 .51923 L
.30141 .5 L
.30634 .48077 L
.30769 .47078 L
.31211 .46154 L
.32494 .44231 L
.32692 .43987 L
.34615 .4235 L
.34673 .42308 L
.36538 .41412 L
s
.6 g
.34615 .82255 m
.36538 .81453 L
.38462 .81178 L
.40385 .81397 L
.42308 .8218 L
.43096 .82692 L
.44231 .83773 L
.44815 .84615 L
.45644 .86538 L
.45847 .88462 L
.45467 .90385 L
.44414 .92308 L
.44231 .92545 L
.42308 .94161 L
.4218 .94231 L
.40385 .94934 L
.38462 .95134 L
.36538 .94816 L
.34972 .94231 L
.34615 .93932 L
.32773 .92308 L
.32692 .92238 L
.31572 .90385 L
.31029 .88462 L
.31155 .86538 L
.32047 .84615 L
.32692 .83736 L
.33924 .82692 L
F
0 g
.34615 .82255 m
.36538 .81453 L
.38462 .81178 L
.40385 .81397 L
.42308 .8218 L
.43096 .82692 L
.44231 .83773 L
.44815 .84615 L
.45644 .86538 L
.45847 .88462 L
.45467 .90385 L
.44414 .92308 L
.44231 .92545 L
.42308 .94161 L
.4218 .94231 L
.40385 .94934 L
.38462 .95134 L
.36538 .94816 L
.34972 .94231 L
.34615 .93932 L
.32773 .92308 L
.32692 .92238 L
.31572 .90385 L
.31029 .88462 L
.31155 .86538 L
.32047 .84615 L
.32692 .83736 L
.33924 .82692 L
.34615 .82255 L
s
.5 g
.36538 .43041 m
.38462 .42497 L
.40385 .42506 L
.42308 .43067 L
.44105 .44231 L
.44231 .44344 L
.45639 .46154 L
.46154 .47378 L
.46319 .48077 L
.46341 .5 L
.46154 .50831 L
.45707 .51923 L
.44231 .53834 L
.44217 .53846 L
.42308 .55122 L
.40385 .55686 L
.38462 .55716 L
.36538 .55235 L
.34615 .54109 L
.34315 .53846 L
.32841 .51923 L
.32692 .51593 L
.32318 .5 L
.32429 .48077 L
.32692 .47156 L
.33153 .46154 L
.34615 .44304 L
.34696 .44231 L
F
0 g
.36538 .43041 m
.38462 .42497 L
.40385 .42506 L
.42308 .43067 L
.44105 .44231 L
.44231 .44344 L
.45639 .46154 L
.46154 .47378 L
.46319 .48077 L
.46341 .5 L
.46154 .50831 L
.45707 .51923 L
.44231 .53834 L
.44217 .53846 L
.42308 .55122 L
.40385 .55686 L
.38462 .55716 L
.36538 .55235 L
.34615 .54109 L
.34315 .53846 L
.32841 .51923 L
.32692 .51593 L
.32318 .5 L
.32429 .48077 L
.32692 .47156 L
.33153 .46154 L
.34615 .44304 L
.34696 .44231 L
.36538 .43041 L
s
.7 g
.36538 .82637 m
.38462 .82293 L
.40385 .82553 L
.41047 .82692 L
.42308 .83489 L
.43453 .84615 L
.44231 .85998 L
.44427 .86538 L
.44664 .88462 L
.44231 .90353 L
.44219 .90385 L
.4293 .92308 L
.42308 .92833 L
.40385 .93794 L
.38462 .94027 L
.36538 .93656 L
.34615 .92525 L
.3437 .92308 L
.32944 .90385 L
.32692 .89751 L
.32413 .88462 L
.32598 .86538 L
.32692 .86251 L
.33625 .84615 L
.34615 .83631 L
.36324 .82692 L
F
0 g
.36538 .82637 m
.38462 .82293 L
.40385 .82553 L
.41047 .82692 L
.42308 .83489 L
.43453 .84615 L
.44231 .85998 L
.44427 .86538 L
.44664 .88462 L
.44231 .90353 L
.44219 .90385 L
.4293 .92308 L
.42308 .92833 L
.40385 .93794 L
.38462 .94027 L
.36538 .93656 L
.34615 .92525 L
.3437 .92308 L
.32944 .90385 L
.32692 .89751 L
.32413 .88462 L
.32598 .86538 L
.32692 .86251 L
.33625 .84615 L
.34615 .83631 L
.36324 .82692 L
.36538 .82637 L
s
.40385 .22694 m
.42308 .22748 L
.43029 .23077 L
.44231 .23827 L
.45872 .25 L
.46154 .25278 L
.48077 .26723 L
.48358 .26923 L
.5 .27952 L
.51478 .28846 L
.51923 .29001 L
.53846 .29898 L
.55354 .30769 L
.55769 .30981 L
.57663 .32692 L
.56646 .34615 L
.55769 .35393 L
.54203 .36538 L
.53846 .36715 L
.51923 .37361 L
.5 .37093 L
.48629 .36538 L
.48077 .36374 L
.46154 .35541 L
.44231 .34757 L
.4383 .34615 L
.42308 .34338 L
.40385 .34018 L
.38462 .33839 L
.36538 .33524 L
.34615 .33319 L
.33367 .32692 L
.3346 .30769 L
.34608 .28846 L
.34615 .28833 L
.36013 .26923 L
.36538 .2624 L
.37497 .25 L
.38462 .24036 L
.39622 .23077 L
F
.40385 .22694 m
.42308 .22748 L
.43029 .23077 L
.44231 .23827 L
.45872 .25 L
.46154 .25278 L
.48077 .26723 L
.48358 .26923 L
.5 .27952 L
.51478 .28846 L
.51923 .29001 L
.53846 .29898 L
.55354 .30769 L
.55769 .30981 L
.57663 .32692 L
.56646 .34615 L
.55769 .35393 L
.54203 .36538 L
.53846 .36715 L
.51923 .37361 L
.5 .37093 L
.48629 .36538 L
.48077 .36374 L
.46154 .35541 L
.44231 .34757 L
.4383 .34615 L
.42308 .34338 L
.40385 .34018 L
.38462 .33839 L
.36538 .33524 L
.34615 .33319 L
.33367 .32692 L
.3346 .30769 L
.34608 .28846 L
.34615 .28833 L
.36013 .26923 L
.36538 .2624 L
.37497 .25 L
.38462 .24036 L
.39622 .23077 L
.40385 .22694 L
s
.8 g
.36538 .83872 m
.38462 .83426 L
.40385 .83747 L
.41786 .84615 L
.42308 .85129 L
.43191 .86538 L
.43483 .88462 L
.42919 .90385 L
.42308 .91411 L
.40919 .92308 L
.40385 .92559 L
.38462 .92872 L
.36538 .92373 L
.36367 .92308 L
.34615 .9087 L
.34357 .90385 L
.33718 .88462 L
.33984 .86538 L
.34615 .85436 L
.35185 .84615 L
F
0 g
.36538 .83872 m
.38462 .83426 L
.40385 .83747 L
.41786 .84615 L
.42308 .85129 L
.43191 .86538 L
.43483 .88462 L
.42919 .90385 L
.42308 .91411 L
.40919 .92308 L
.40385 .92559 L
.38462 .92872 L
.36538 .92373 L
.36367 .92308 L
.34615 .9087 L
.34357 .90385 L
.33718 .88462 L
.33984 .86538 L
.34615 .85436 L
.35185 .84615 L
.36538 .83872 L
s
.6 g
.38462 .44041 m
.40385 .44048 L
.41071 .44231 L
.42308 .4475 L
.43795 .46154 L
.44231 .46975 L
.4462 .48077 L
.44645 .5 L
.44231 .51222 L
.4387 .51923 L
.42308 .53442 L
.41391 .53846 L
.40385 .54153 L
.38462 .54183 L
.37283 .53846 L
.36538 .53541 L
.3482 .51923 L
.34615 .51536 L
.34078 .5 L
.34156 .48077 L
.34615 .46878 L
.35012 .46154 L
.36538 .44731 L
.37737 .44231 L
F
0 g
.38462 .44041 m
.40385 .44048 L
.41071 .44231 L
.42308 .4475 L
.43795 .46154 L
.44231 .46975 L
.4462 .48077 L
.44645 .5 L
.44231 .51222 L
.4387 .51923 L
.42308 .53442 L
.41391 .53846 L
.40385 .54153 L
.38462 .54183 L
.37283 .53846 L
.36538 .53541 L
.3482 .51923 L
.34615 .51536 L
.34078 .5 L
.34156 .48077 L
.34615 .46878 L
.35012 .46154 L
.36538 .44731 L
.37737 .44231 L
.38462 .44041 L
s
.9 g
.36538 .85491 m
.38462 .8481 L
.40385 .85274 L
.41645 .86538 L
.42069 .88462 L
.41225 .90385 L
.40385 .91242 L
.38462 .91703 L
.36538 .90914 L
.35939 .90385 L
.35011 .88462 L
.35376 .86538 L
F
0 g
.36538 .85491 m
.38462 .8481 L
.40385 .85274 L
.41645 .86538 L
.42069 .88462 L
.41225 .90385 L
.40385 .91242 L
.38462 .91703 L
.36538 .90914 L
.35939 .90385 L
.35011 .88462 L
.35376 .86538 L
.36538 .85491 L
s
.7 g
.38462 .45819 m
.40385 .45829 L
.41075 .46154 L
.42308 .47278 L
.42749 .48077 L
.42788 .5 L
.42308 .50916 L
.41277 .51923 L
.40385 .52392 L
.38462 .52426 L
.37461 .51923 L
.36538 .51058 L
.35966 .5 L
.3604 .48077 L
.36538 .47219 L
.37739 .46154 L
F
0 g
.38462 .45819 m
.40385 .45829 L
.41075 .46154 L
.42308 .47278 L
.42749 .48077 L
.42788 .5 L
.42308 .50916 L
.41277 .51923 L
.40385 .52392 L
.38462 .52426 L
.37461 .51923 L
.36538 .51058 L
.35966 .5 L
.3604 .48077 L
.36538 .47219 L
.37739 .46154 L
.38462 .45819 L
s
1 g
.38462 .86909 m
.39914 .88462 L
.38462 .89405 L
.37407 .88462 L
F
0 g
.38462 .86909 m
.39914 .88462 L
.38462 .89405 L
.37407 .88462 L
.38462 .86909 L
s
.41735 .01923 m
.40385 .02611 L
.38462 .02438 L
.37527 .01923 L
F
.41735 .01923 m
.40385 .02611 L
.38462 .02438 L
.37527 .01923 L
s
.2 g
.72423 .01923 m
.73077 .0284 L
.73697 .03846 L
.74608 .05769 L
.75 .06846 L
.75217 .07692 L
.75558 .09615 L
.75657 .11538 L
.75516 .13462 L
.7513 .15385 L
.75 .15869 L
.74469 .17308 L
.73502 .19231 L
.73077 .19914 L
.72156 .21154 L
.71154 .22266 L
.70291 .23077 L
.69231 .23916 L
.67557 .25 L
.67308 .25129 L
.65385 .25979 L
.63462 .26555 L
.61538 .26847 L
.59615 .26862 L
.57692 .26618 L
.55769 .26125 L
.53846 .25383 L
.5305 .25 L
.51923 .24343 L
.50157 .23077 L
.5 .22946 L
.48148 .21154 L
.48077 .21075 L
.46649 .19231 L
.46154 .18495 L
.45546 .17308 L
.44707 .15385 L
.44231 .13712 L
.44215 .13462 L
.44136 .11538 L
.44231 .09653 L
.44238 .09615 L
.44763 .07692 L
.45547 .05769 L
.46154 .04539 L
.46584 .03846 L
.47976 .01923 L
F
0 g
.72423 .01923 m
.73077 .0284 L
.73697 .03846 L
.74608 .05769 L
.75 .06846 L
.75217 .07692 L
.75558 .09615 L
.75657 .11538 L
.75516 .13462 L
.7513 .15385 L
.75 .15869 L
.74469 .17308 L
.73502 .19231 L
.73077 .19914 L
.72156 .21154 L
.71154 .22266 L
.70291 .23077 L
.69231 .23916 L
.67557 .25 L
.67308 .25129 L
.65385 .25979 L
.63462 .26555 L
.61538 .26847 L
.59615 .26862 L
.57692 .26618 L
.55769 .26125 L
.53846 .25383 L
.5305 .25 L
.51923 .24343 L
.50157 .23077 L
.5 .22946 L
.48148 .21154 L
.48077 .21075 L
.46649 .19231 L
.46154 .18495 L
.45546 .17308 L
.44707 .15385 L
.44231 .13712 L
.44215 .13462 L
.44136 .11538 L
.44231 .09653 L
.44238 .09615 L
.44763 .07692 L
.45547 .05769 L
.46154 .04539 L
.46584 .03846 L
.47976 .01923 L
s
.1 g
.57995 .98077 m
.57692 .97868 L
.55769 .96362 L
.55518 .96154 L
.53846 .9488 L
.51923 .94376 L
.5 .95348 L
.48753 .96154 L
.48077 .96895 L
.46468 .98077 L
F
0 g
.57995 .98077 m
.57692 .97868 L
.55769 .96362 L
.55518 .96154 L
.53846 .9488 L
.51923 .94376 L
.5 .95348 L
.48753 .96154 L
.48077 .96895 L
.46468 .98077 L
s
.3 g
.68982 .01923 m
.69231 .02168 L
.70689 .03846 L
.71154 .04526 L
.71836 .05769 L
.72584 .07692 L
.73003 .09615 L
.73077 .10288 L
.73122 .11538 L
.73077 .12446 L
.72951 .13462 L
.72476 .15385 L
.71664 .17308 L
.71154 .18208 L
.70434 .19231 L
.69231 .20582 L
.68606 .21154 L
.67308 .22125 L
.65603 .23077 L
.65385 .23171 L
.63462 .23829 L
.61538 .24169 L
.59615 .2421 L
.57692 .23957 L
.55769 .23401 L
.54955 .23077 L
.53846 .225 L
.51923 .2117 L
.51904 .21154 L
.50013 .19231 L
.5 .19215 L
.48727 .17308 L
.48077 .15986 L
.47865 .15385 L
.4737 .13462 L
.47197 .11538 L
.4734 .09615 L
.47797 .07692 L
.48077 .06861 L
.48596 .05769 L
.49795 .03846 L
.5 .03582 L
.51544 .01923 L
F
0 g
.68982 .01923 m
.69231 .02168 L
.70689 .03846 L
.71154 .04526 L
.71836 .05769 L
.72584 .07692 L
.73003 .09615 L
.73077 .10288 L
.73122 .11538 L
.73077 .12446 L
.72951 .13462 L
.72476 .15385 L
.71664 .17308 L
.71154 .18208 L
.70434 .19231 L
.69231 .20582 L
.68606 .21154 L
.67308 .22125 L
.65603 .23077 L
.65385 .23171 L
.63462 .23829 L
.61538 .24169 L
.59615 .2421 L
.57692 .23957 L
.55769 .23401 L
.54955 .23077 L
.53846 .225 L
.51923 .2117 L
.51904 .21154 L
.50013 .19231 L
.5 .19215 L
.48727 .17308 L
.48077 .15986 L
.47865 .15385 L
.4737 .13462 L
.47197 .11538 L
.4734 .09615 L
.47797 .07692 L
.48077 .06861 L
.48596 .05769 L
.49795 .03846 L
.5 .03582 L
.51544 .01923 L
s
.4 g
.65428 .01923 m
.67308 .03234 L
.67974 .03846 L
.69231 .05393 L
.69467 .05769 L
.70391 .07692 L
.70895 .09615 L
.71038 .11538 L
.70833 .13462 L
.7026 .15385 L
.6925 .17308 L
.69231 .17336 L
.67625 .19231 L
.67308 .19514 L
.65385 .20841 L
.64818 .21154 L
.63462 .21647 L
.61538 .22054 L
.59615 .22106 L
.57692 .2181 L
.55794 .21154 L
.55769 .21138 L
.53846 .20007 L
.529 .19231 L
.51923 .1821 L
.51248 .17308 L
.50212 .15385 L
.5 .15062 L
.49627 .13462 L
.49421 .11538 L
.49574 .09615 L
.5 .07959 L
.50096 .07692 L
.51047 .05769 L
.51923 .04547 L
.52563 .03846 L
.53846 .02754 L
.55112 .01923 L
F
0 g
.65428 .01923 m
.67308 .03234 L
.67974 .03846 L
.69231 .05393 L
.69467 .05769 L
.70391 .07692 L
.70895 .09615 L
.71038 .11538 L
.70833 .13462 L
.7026 .15385 L
.6925 .17308 L
.69231 .17336 L
.67625 .19231 L
.67308 .19514 L
.65385 .20841 L
.64818 .21154 L
.63462 .21647 L
.61538 .22054 L
.59615 .22106 L
.57692 .2181 L
.55794 .21154 L
.55769 .21138 L
.53846 .20007 L
.529 .19231 L
.51923 .1821 L
.51248 .17308 L
.50212 .15385 L
.5 .15062 L
.49627 .13462 L
.49421 .11538 L
.49574 .09615 L
.5 .07959 L
.50096 .07692 L
.51047 .05769 L
.51923 .04547 L
.52563 .03846 L
.53846 .02754 L
.55112 .01923 L
s
.5 g
.55769 .0376 m
.57692 .02926 L
.59615 .02564 L
.61538 .02629 L
.63462 .03127 L
.64986 .03846 L
.65385 .04139 L
.67135 .05769 L
.67308 .05976 L
.68332 .07692 L
.68955 .09615 L
.69127 .11538 L
.68879 .13462 L
.68166 .15385 L
.67308 .16769 L
.66846 .17308 L
.65385 .18599 L
.64403 .19231 L
.63462 .19623 L
.61538 .20124 L
.59615 .20189 L
.57692 .19827 L
.56126 .19231 L
.55769 .18984 L
.53846 .17462 L
.53702 .17308 L
.52358 .15385 L
.51923 .14655 L
.51639 .13462 L
.51387 .11538 L
.51567 .09615 L
.51923 .0837 L
.52201 .07692 L
.53412 .05769 L
.53846 .05277 L
.55618 .03846 L
F
0 g
.55769 .0376 m
.57692 .02926 L
.59615 .02564 L
.61538 .02629 L
.63462 .03127 L
.64986 .03846 L
.65385 .04139 L
.67135 .05769 L
.67308 .05976 L
.68332 .07692 L
.68955 .09615 L
.69127 .11538 L
.68879 .13462 L
.68166 .15385 L
.67308 .16769 L
.66846 .17308 L
.65385 .18599 L
.64403 .19231 L
.63462 .19623 L
.61538 .20124 L
.59615 .20189 L
.57692 .19827 L
.56126 .19231 L
.55769 .18984 L
.53846 .17462 L
.53702 .17308 L
.52358 .15385 L
.51923 .14655 L
.51639 .13462 L
.51387 .11538 L
.51567 .09615 L
.51923 .0837 L
.52201 .07692 L
.53412 .05769 L
.53846 .05277 L
.55618 .03846 L
.55769 .0376 L
s
.6 g
.57692 .04935 m
.59615 .04467 L
.61538 .04549 L
.63462 .05206 L
.64431 .05769 L
.65385 .06638 L
.66168 .07692 L
.66992 .09615 L
.67211 .11538 L
.66895 .13462 L
.65937 .15385 L
.65385 .16082 L
.63885 .17308 L
.63462 .17524 L
.61538 .18186 L
.59615 .18268 L
.57692 .17798 L
.56581 .17308 L
.55769 .1666 L
.54603 .15385 L
.53846 .14171 L
.53655 .13462 L
.5333 .11538 L
.53558 .09615 L
.53846 .08767 L
.54381 .07692 L
.55769 .06084 L
.56106 .05769 L
F
0 g
.57692 .04935 m
.59615 .04467 L
.61538 .04549 L
.63462 .05206 L
.64431 .05769 L
.65385 .06638 L
.66168 .07692 L
.66992 .09615 L
.67211 .11538 L
.66895 .13462 L
.65937 .15385 L
.65385 .16082 L
.63885 .17308 L
.63462 .17524 L
.61538 .18186 L
.59615 .18268 L
.57692 .17798 L
.56581 .17308 L
.55769 .1666 L
.54603 .15385 L
.53846 .14171 L
.53655 .13462 L
.5333 .11538 L
.53558 .09615 L
.53846 .08767 L
.54381 .07692 L
.55769 .06084 L
.56106 .05769 L
.57692 .04935 L
s
.3 g
.6884 .98077 m
.69231 .97943 L
.71154 .96999 L
.72327 .96154 L
.73077 .95458 L
.74105 .94231 L
.75 .92757 L
.75197 .92308 L
.75815 .90385 L
.76055 .88462 L
.75937 .86538 L
.75452 .84615 L
.75 .83487 L
.74539 .82692 L
.73077 .80812 L
.73034 .80769 L
.71154 .7927 L
.7045 .78846 L
.69231 .78332 L
.67308 .77825 L
.65385 .77688 L
.63462 .77908 L
.61538 .78497 L
.60742 .78846 L
.59615 .79514 L
.58007 .80769 L
.57692 .81061 L
.56268 .82692 L
.55769 .83281 L
.54913 .84615 L
.53948 .86538 L
.53846 .8683 L
.53617 .88462 L
.53846 .89457 L
.54219 .90385 L
.55316 .92308 L
.55769 .92983 L
.56813 .94231 L
.57692 .95211 L
.58778 .96154 L
.59615 .96757 L
.61538 .97776 L
.62142 .98077 L
F
0 g
.6884 .98077 m
.69231 .97943 L
.71154 .96999 L
.72327 .96154 L
.73077 .95458 L
.74105 .94231 L
.75 .92757 L
.75197 .92308 L
.75815 .90385 L
.76055 .88462 L
.75937 .86538 L
.75452 .84615 L
.75 .83487 L
.74539 .82692 L
.73077 .80812 L
.73034 .80769 L
.71154 .7927 L
.7045 .78846 L
.69231 .78332 L
.67308 .77825 L
.65385 .77688 L
.63462 .77908 L
.61538 .78497 L
.60742 .78846 L
.59615 .79514 L
.58007 .80769 L
.57692 .81061 L
.56268 .82692 L
.55769 .83281 L
.54913 .84615 L
.53948 .86538 L
.53846 .8683 L
.53617 .88462 L
.53846 .89457 L
.54219 .90385 L
.55316 .92308 L
.55769 .92983 L
.56813 .94231 L
.57692 .95211 L
.58778 .96154 L
.59615 .96757 L
.61538 .97776 L
.62142 .98077 L
s
.7 g
.57692 .07359 m
.59615 .06619 L
.61538 .0674 L
.63297 .07692 L
.63462 .07834 L
.64767 .09615 L
.65076 .11538 L
.6462 .13462 L
.63462 .15106 L
.62819 .15385 L
.61538 .15977 L
.59615 .16102 L
.5774 .15385 L
.57692 .15371 L
.55949 .13462 L
.55769 .1288 L
.55513 .11538 L
.55769 .09855 L
.55834 .09615 L
.57182 .07692 L
F
0 g
.57692 .07359 m
.59615 .06619 L
.61538 .0674 L
.63297 .07692 L
.63462 .07834 L
.64767 .09615 L
.65076 .11538 L
.6462 .13462 L
.63462 .15106 L
.62819 .15385 L
.61538 .15977 L
.59615 .16102 L
.5774 .15385 L
.57692 .15371 L
.55949 .13462 L
.55769 .1288 L
.55513 .11538 L
.55769 .09855 L
.55834 .09615 L
.57182 .07692 L
.57692 .07359 L
s
.4 g
.61538 .41316 m
.63462 .40714 L
.65385 .40557 L
.67308 .40829 L
.69231 .41571 L
.70425 .42308 L
.71154 .42929 L
.72298 .44231 L
.73077 .4549 L
.73346 .46154 L
.73861 .48077 L
.73938 .5 L
.73587 .51923 L
.73077 .53349 L
.7275 .53846 L
.71218 .55769 L
.71154 .55829 L
.69231 .57185 L
.68262 .57692 L
.67308 .57912 L
.65385 .58172 L
.63462 .58013 L
.62253 .57692 L
.61538 .57417 L
.59615 .56299 L
.58963 .55769 L
.57692 .54451 L
.57272 .53846 L
.56229 .51923 L
.55769 .50372 L
.55756 .5 L
.55769 .4832 L
.55816 .48077 L
.56523 .46154 L
.57692 .44287 L
.57744 .44231 L
.59615 .42435 L
.59782 .42308 L
F
0 g
.61538 .41316 m
.63462 .40714 L
.65385 .40557 L
.67308 .40829 L
.69231 .41571 L
.70425 .42308 L
.71154 .42929 L
.72298 .44231 L
.73077 .4549 L
.73346 .46154 L
.73861 .48077 L
.73938 .5 L
.73587 .51923 L
.73077 .53349 L
.7275 .53846 L
.71218 .55769 L
.71154 .55829 L
.69231 .57185 L
.68262 .57692 L
.67308 .57912 L
.65385 .58172 L
.63462 .58013 L
.62253 .57692 L
.61538 .57417 L
.59615 .56299 L
.58963 .55769 L
.57692 .54451 L
.57272 .53846 L
.56229 .51923 L
.55769 .50372 L
.55756 .5 L
.55769 .4832 L
.55816 .48077 L
.56523 .46154 L
.57692 .44287 L
.57744 .44231 L
.59615 .42435 L
.59782 .42308 L
.61538 .41316 L
s
.4 g
.61538 .80248 m
.63462 .79536 L
.65385 .79276 L
.67308 .79438 L
.69231 .80046 L
.70576 .80769 L
.71154 .81212 L
.72613 .82692 L
.73077 .83315 L
.73747 .84615 L
.74331 .86538 L
.7447 .88462 L
.74185 .90385 L
.73433 .92308 L
.73077 .92937 L
.72054 .94231 L
.71154 .95056 L
.69398 .96154 L
.69231 .96225 L
.67308 .96832 L
.65385 .96993 L
.63462 .96735 L
.61702 .96154 L
.61538 .96024 L
.59615 .94744 L
.59063 .94231 L
.57692 .92552 L
.57557 .92308 L
.56703 .90385 L
.56338 .88462 L
.56521 .86538 L
.57219 .84615 L
.57692 .83689 L
.58465 .82692 L
.59615 .81523 L
.60606 .80769 L
F
0 g
.61538 .80248 m
.63462 .79536 L
.65385 .79276 L
.67308 .79438 L
.69231 .80046 L
.70576 .80769 L
.71154 .81212 L
.72613 .82692 L
.73077 .83315 L
.73747 .84615 L
.74331 .86538 L
.7447 .88462 L
.74185 .90385 L
.73433 .92308 L
.73077 .92937 L
.72054 .94231 L
.71154 .95056 L
.69398 .96154 L
.69231 .96225 L
.67308 .96832 L
.65385 .96993 L
.63462 .96735 L
.61702 .96154 L
.61538 .96024 L
.59615 .94744 L
.59063 .94231 L
.57692 .92552 L
.57557 .92308 L
.56703 .90385 L
.56338 .88462 L
.56521 .86538 L
.57219 .84615 L
.57692 .83689 L
.58465 .82692 L
.59615 .81523 L
.60606 .80769 L
.61538 .80248 L
s
.5 g
.63462 .42299 m
.65385 .42107 L
.66853 .42308 L
.67308 .4243 L
.69231 .43348 L
.70316 .44231 L
.71154 .45209 L
.71679 .46154 L
.72319 .48077 L
.72412 .5 L
.71981 .51923 L
.71154 .53581 L
.70915 .53846 L
.69231 .55419 L
.68835 .55769 L
.67308 .56329 L
.65385 .56649 L
.63462 .56454 L
.61651 .55769 L
.61538 .55711 L
.59615 .54224 L
.5929 .53846 L
.5812 .51923 L
.57692 .50469 L
.5763 .5 L
.57692 .48268 L
.57728 .48077 L
.58442 .46154 L
.59615 .4451 L
.59905 .44231 L
.61538 .43035 L
.63425 .42308 L
F
0 g
.63462 .42299 m
.65385 .42107 L
.66853 .42308 L
.67308 .4243 L
.69231 .43348 L
.70316 .44231 L
.71154 .45209 L
.71679 .46154 L
.72319 .48077 L
.72412 .5 L
.71981 .51923 L
.71154 .53581 L
.70915 .53846 L
.69231 .55419 L
.68835 .55769 L
.67308 .56329 L
.65385 .56649 L
.63462 .56454 L
.61651 .55769 L
.61538 .55711 L
.59615 .54224 L
.5929 .53846 L
.5812 .51923 L
.57692 .50469 L
.5763 .5 L
.57692 .48268 L
.57728 .48077 L
.58442 .46154 L
.59615 .4451 L
.59905 .44231 L
.61538 .43035 L
.63425 .42308 L
.63462 .42299 L
s
.5 g
.65385 .80713 m
.66535 .80769 L
.67308 .80904 L
.69231 .81644 L
.70694 .82692 L
.71154 .83158 L
.72159 .84615 L
.72869 .86538 L
.73035 .88462 L
.72695 .90385 L
.71763 .92308 L
.71154 .93103 L
.69888 .94231 L
.69231 .94622 L
.67308 .95366 L
.65385 .95559 L
.63462 .95248 L
.61538 .94368 L
.61323 .94231 L
.59615 .92652 L
.59366 .92308 L
.58369 .90385 L
.57992 .88462 L
.58177 .86538 L
.58949 .84615 L
.59615 .8359 L
.60479 .82692 L
.61538 .81897 L
.63462 .81021 L
.6468 .80769 L
F
0 g
.65385 .80713 m
.66535 .80769 L
.67308 .80904 L
.69231 .81644 L
.70694 .82692 L
.71154 .83158 L
.72159 .84615 L
.72869 .86538 L
.73035 .88462 L
.72695 .90385 L
.71763 .92308 L
.71154 .93103 L
.69888 .94231 L
.69231 .94622 L
.67308 .95366 L
.65385 .95559 L
.63462 .95248 L
.61538 .94368 L
.61323 .94231 L
.59615 .92652 L
.59366 .92308 L
.58369 .90385 L
.57992 .88462 L
.58177 .86538 L
.58949 .84615 L
.59615 .8359 L
.60479 .82692 L
.61538 .81897 L
.63462 .81021 L
.6468 .80769 L
.65385 .80713 L
s
.6 g
.63462 .43883 m
.65385 .43634 L
.67308 .44052 L
.67832 .44231 L
.69231 .45272 L
.69937 .46154 L
.70774 .48077 L
.70889 .5 L
.70345 .51923 L
.69231 .53529 L
.68948 .53846 L
.67308 .5473 L
.65385 .55138 L
.63462 .54892 L
.61538 .53879 L
.61495 .53846 L
.59888 .51923 L
.59615 .51261 L
.59311 .5 L
.59435 .48077 L
.59615 .47498 L
.6029 .46154 L
.61538 .44833 L
.62594 .44231 L
F
0 g
.63462 .43883 m
.65385 .43634 L
.67308 .44052 L
.67832 .44231 L
.69231 .45272 L
.69937 .46154 L
.70774 .48077 L
.70889 .5 L
.70345 .51923 L
.69231 .53529 L
.68948 .53846 L
.67308 .5473 L
.65385 .55138 L
.63462 .54892 L
.61538 .53879 L
.61495 .53846 L
.59888 .51923 L
.59615 .51261 L
.59311 .5 L
.59435 .48077 L
.59615 .47498 L
.6029 .46154 L
.61538 .44833 L
.62594 .44231 L
.63462 .43883 L
s
.8 g
.59615 .10854 m
.61111 .11538 L
.59615 .11889 L
.59449 .11538 L
F
0 g
.59615 .10854 m
.61111 .11538 L
.59615 .11889 L
.59449 .11538 L
.59615 .10854 L
s
.6 g
.63462 .82505 m
.65385 .82114 L
.67308 .82355 L
.68179 .82692 L
.69231 .83286 L
.70532 .84615 L
.71154 .85783 L
.71422 .86538 L
.71631 .88462 L
.71199 .90385 L
.71154 .90527 L
.69989 .92308 L
.69231 .92967 L
.67308 .93922 L
.65385 .94153 L
.63462 .93778 L
.61538 .92612 L
.61218 .92308 L
.59936 .90385 L
.59615 .89306 L
.59502 .88462 L
.59615 .86961 L
.59714 .86538 L
.6065 .84615 L
.61538 .83627 L
.6288 .82692 L
F
0 g
.63462 .82505 m
.65385 .82114 L
.67308 .82355 L
.68179 .82692 L
.69231 .83286 L
.70532 .84615 L
.71154 .85783 L
.71422 .86538 L
.71631 .88462 L
.71199 .90385 L
.71154 .90527 L
.69989 .92308 L
.69231 .92967 L
.67308 .93922 L
.65385 .94153 L
.63462 .93778 L
.61538 .92612 L
.61218 .92308 L
.59936 .90385 L
.59615 .89306 L
.59502 .88462 L
.59615 .86961 L
.59714 .86538 L
.6065 .84615 L
.61538 .83627 L
.6288 .82692 L
.63462 .82505 L
s
.7 g
.63462 .84128 m
.65385 .83584 L
.67308 .83914 L
.68435 .84615 L
.69231 .85439 L
.6987 .86538 L
.70155 .88462 L
.69547 .90385 L
.69231 .90964 L
.67333 .92308 L
.67308 .92319 L
.65385 .92656 L
.63886 .92308 L
.63462 .92181 L
.61611 .90385 L
.61538 .90155 L
.61045 .88462 L
.6134 .86538 L
.61538 .86117 L
.62567 .84615 L
F
0 g
.63462 .84128 m
.65385 .83584 L
.67308 .83914 L
.68435 .84615 L
.69231 .85439 L
.6987 .86538 L
.70155 .88462 L
.69547 .90385 L
.69231 .90964 L
.67333 .92308 L
.67308 .92319 L
.65385 .92656 L
.63886 .92308 L
.63462 .92181 L
.61611 .90385 L
.61538 .90155 L
.61045 .88462 L
.6134 .86538 L
.61538 .86117 L
.62567 .84615 L
.63462 .84128 L
s
.7 g
.63462 .45668 m
.65385 .45293 L
.67308 .4594 L
.67691 .46154 L
.6909 .48077 L
.69193 .5 L
.68541 .51923 L
.67308 .52943 L
.65385 .53511 L
.63462 .53189 L
.61978 .51923 L
.61538 .51269 L
.61079 .5 L
.61263 .48077 L
.61538 .47498 L
.62709 .46154 L
F
0 g
.63462 .45668 m
.65385 .45293 L
.67308 .4594 L
.67691 .46154 L
.6909 .48077 L
.69193 .5 L
.68541 .51923 L
.67308 .52943 L
.65385 .53511 L
.63462 .53189 L
.61978 .51923 L
.61538 .51269 L
.61079 .5 L
.61263 .48077 L
.61538 .47498 L
.62709 .46154 L
.63462 .45668 L
s
.8 g
.65385 .85559 m
.67308 .8618 L
.6765 .86538 L
.68179 .88462 L
.67308 .9009 L
.66888 .90385 L
.65385 .90816 L
.6433 .90385 L
.63462 .89592 L
.6288 .88462 L
.63462 .8667 L
.63558 .86538 L
F
0 g
.65385 .85559 m
.67308 .8618 L
.6765 .86538 L
.68179 .88462 L
.67308 .9009 L
.66888 .90385 L
.65385 .90816 L
.6433 .90385 L
.63462 .89592 L
.6288 .88462 L
.63462 .8667 L
.63558 .86538 L
.65385 .85559 L
s
.8 g
.65385 .47989 m
.65685 .48077 L
.66427 .5 L
.65385 .50775 L
.63878 .5 L
.64642 .48077 L
F
0 g
.65385 .47989 m
.65685 .48077 L
.66427 .5 L
.65385 .50775 L
.63878 .5 L
.64642 .48077 L
.65385 .47989 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.39 0 0 r
.39846 .61319 .40477 .61387 .4149 .61517 .40855 .61663 Mtetra
.574 .038 0 r
.40855 .61663 .4149 .61517 .42508 .61712 .41869 .62106 Mtetra
.617 .148 .119 r
.41869 .62106 .42508 .61712 .43533 .61924 .42891 .62577 Mtetra
.603 .18 .212 r
.42891 .62577 .43533 .61924 .44565 .62089 .43923 .62978 Mtetra
.56 .165 .25 r
.43923 .62978 .44565 .62089 .45607 .62134 .44968 .63201 Mtetra
.493 .115 .25 r
.44968 .63201 .45607 .62134 .46659 .62002 .46025 .63158 Mtetra
.398 .029 .217 r
.46025 .63158 .46659 .62002 .47718 .61664 .47092 .62806 Mtetra
.269 0 .143 r
.47092 .62806 .47718 .61664 .48783 .61134 .48167 .62165 Mtetra
.103 0 .021 r
.48167 .62165 .48783 .61134 .49852 .60467 .49246 .61319 Mtetra
0 0 0 r
.49246 .61319 .49852 .60467 .50923 .59756 .50326 .60406 Mtetra
.50326 .60406 .50923 .59756 .51996 .5911 .51407 .59593 Mtetra
.51407 .59593 .51996 .5911 .53072 .58643 .52489 .59045 Mtetra
.255 0 0 r
.52489 .59045 .53072 .58643 .54151 .58445 .53574 .58899 Mtetra
.555 .077 .074 r
.53574 .58899 .54151 .58445 .55239 .58563 .54669 .59224 Mtetra
.676 .262 .252 r
.54669 .59224 .55239 .58563 .56337 .58973 .55776 .59987 Mtetra
.701 .332 .346 r
.55776 .59987 .56337 .58973 .57446 .59568 .56898 .61031 Mtetra
.681 .342 .394 r
.56898 .61031 .57446 .59568 .58566 .60166 .58033 .62084 Mtetra
.634 .317 .416 r
.58033 .62084 .58566 .60166 .59692 .60548 .59176 .62817 Mtetra
.563 .262 .416 r
.59176 .62817 .59692 .60548 .60817 .60526 .60316 .62947 Mtetra
.463 .178 .394 r
.60316 .62947 .60817 .60526 .61935 .6001 .61445 .62335 Mtetra
.327 .057 .342 r
.61445 .62335 .61935 .6001 .63043 .59041 .62557 .61044 Mtetra
.145 0 .245 r
.62557 .61044 .63043 .59041 .6414 .57777 .63653 .59313 Mtetra
0 0 .081 r
.63653 .59313 .6414 .57777 .65233 .56431 .6474 .57464 Mtetra
0 0 0 r
.6474 .57464 .65233 .56431 .66329 .55213 .65828 .55804 Mtetra
.65828 .55804 .66329 .55213 .67436 .54275 .6693 .54561 Mtetra
.419 .831 .644 r
.6693 .54561 .67436 .54275 .6856 .53704 .68055 .53853 Mtetra
.028 0 0 r
.68055 .53853 .6856 .53704 .69708 .53518 .69211 .5371 Mtetra
.489 0 0 r
.69211 .5371 .69708 .53518 .70881 .53683 .70399 .54076 Mtetra
.662 .181 .099 r
.70399 .54076 .70881 .53683 .72077 .54112 .7162 .54829 Mtetra
.693 .273 .244 r
.7162 .54829 .72077 .54112 .73291 .5467 .72864 .55773 Mtetra
.669 .29 .319 r
.72864 .55773 .73291 .5467 .74514 .55184 .74119 .56659 Mtetra
.617 .267 .355 r
.74119 .56659 .74514 .55184 .75732 .55474 .75366 .57227 Mtetra
.541 .214 .364 r
.75366 .57227 .75732 .55474 .76933 .55396 .76587 .57267 Mtetra
.439 .132 .347 r
.76587 .57267 .76933 .55396 .78108 .54885 .77769 .56681 Mtetra
.303 .015 .298 r
.77769 .56681 .78108 .54885 .79255 .53974 .7891 .55521 Mtetra
.12 0 .201 r
.7891 .55521 .79255 .53974 .80379 .52782 .80017 .53957 Mtetra
0 0 .026 r
.80017 .53957 .80379 .52782 .81492 .51468 .81106 .52223 Mtetra
0 0 0 r
.81106 .52223 .81492 .51468 .82605 .50184 .82193 .50535 Mtetra
.749 .935 .594 r
.82193 .50535 .82605 .50184 .8373 .49036 .83295 .49046 Mtetra
.86 .995 .815 r
.83295 .49046 .8373 .49036 .84872 .48075 .84419 .47825 Mtetra
.834 .935 .895 r
.84419 .47825 .84872 .48075 .86033 .47297 .85568 .46867 Mtetra
.777 .862 .913 r
.85568 .46867 .86033 .47297 .87212 .46672 .8674 .46128 Mtetra
.73 .809 .913 r
.8674 .46128 .87212 .46672 .88407 .46157 .87932 .45546 Mtetra
.699 .776 .911 r
.87932 .45546 .88407 .46157 .89613 .45712 .89139 .45064 Mtetra
.681 .758 .909 r
.89139 .45064 .89613 .45712 .90829 .45307 .90357 .44639 Mtetra
.671 .748 .909 r
.90357 .44639 .90829 .45307 .92052 .44921 .91583 .44244 Mtetra
.667 .744 .908 r
.91583 .44244 .92052 .44921 .93282 .44545 .92816 .43861 Mtetra
.665 .742 .908 r
.92816 .43861 .93282 .44545 .94517 .44171 .94054 .43484 Mtetra
.664 .742 .908 r
.94054 .43484 .94517 .44171 .95757 .43798 .95299 .43107 Mtetra
.664 .741 .908 r
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.635 .098 0 r
.39205 .61359 .39846 .61319 .40855 .61663 .40208 .61968 Mtetra
.696 .238 .16 r
.40208 .61968 .40855 .61663 .41869 .62106 .41215 .62718 Mtetra
.691 .285 .271 r
.41215 .62718 .41869 .62106 .42891 .62577 .42232 .6351 Mtetra
.661 .286 .324 r
.42232 .6351 .42891 .62577 .43923 .62978 .43262 .64205 Mtetra
.611 .256 .344 r
.43262 .64205 .43923 .62978 .44968 .63201 .44309 .6465 Mtetra
.541 .199 .338 r
.44309 .6465 .44968 .63201 .46025 .63158 .45372 .64719 Mtetra
.444 .111 .305 r
.45372 .64719 .46025 .63158 .47092 .62806 .46449 .6435 Mtetra
.313 0 .24 r
.46449 .6435 .47092 .62806 .48167 .62165 .47535 .63569 Mtetra
.147 0 .134 r
.47535 .63569 .48167 .62165 .49246 .61319 .48627 .62498 Mtetra
0 0 0 r
.48627 .62498 .49246 .61319 .50326 .60406 .49719 .6133 Mtetra
.49719 .6133 .50326 .60406 .51407 .59593 .50809 .60298 Mtetra
.022 0 0 r
.50809 .60298 .51407 .59593 .52489 .59045 .51898 .59633 Mtetra
.37 0 .002 r
.51898 .59633 .52489 .59045 .53574 .58899 .5299 .59523 Mtetra
.63 .198 .203 r
.5299 .59523 .53574 .58899 .54669 .59224 .54091 .60064 Mtetra
.723 .341 .326 r
.54091 .60064 .54669 .59224 .55776 .59987 .55207 .61213 Mtetra
.737 .389 .392 r
.55207 .61213 .55776 .59987 .56898 .61031 .56341 .62758 Mtetra
.713 .388 .426 r
.56341 .62758 .56898 .61031 .58033 .62084 .57492 .64326 Mtetra
.662 .354 .441 r
.57492 .64326 .58033 .62084 .59176 .62817 .58652 .65459 Mtetra
.582 .29 .438 r
.58652 .65459 .59176 .62817 .60316 .62947 .5981 .65762 Mtetra
.464 .189 .412 r
.5981 .65762 .60316 .62947 .61445 .62335 .60951 .65039 Mtetra
.295 .044 .352 r
.60951 .65039 .61445 .62335 .62557 .61044 .62068 .63379 Mtetra
.068 0 .24 r
.62068 .63379 .62557 .61044 .63653 .59313 .63163 .61113 Mtetra
0 0 .064 r
.63163 .61113 .63653 .59313 .6474 .57464 .64244 .5869 Mtetra
0 0 0 r
.64244 .5869 .6474 .57464 .65828 .55804 .65325 .56532 Mtetra
.585 .805 .404 r
.65325 .56532 .65828 .55804 .6693 .54561 .66422 .5494 Mtetra
.444 .821 .575 r
.66422 .5494 .6693 .54561 .68055 .53853 .67547 .54076 Mtetra
.149 0 0 r
.67547 .54076 .68055 .53853 .69211 .5371 .6871 .53971 Mtetra
.601 .077 0 r
.6871 .53971 .69211 .5371 .70399 .54076 .69916 .54554 Mtetra
.726 .279 .187 r
.69916 .54554 .70399 .54076 .7162 .54829 .71161 .55657 Mtetra
.739 .341 .296 r
.71161 .55657 .7162 .54829 .72864 .55773 .72437 .57024 Mtetra
.708 .343 .353 r
.72437 .57024 .72864 .55773 .74119 .56659 .73726 .5832 Mtetra
.649 .308 .381 r
.73726 .5832 .74119 .56659 .75366 .57227 .75004 .59196 Mtetra
.561 .242 .385 r
.75004 .59196 .75366 .57227 .76587 .57267 .76246 .59364 Mtetra
.439 .143 .364 r
.76246 .59364 .76587 .57267 .77769 .56681 .77437 .58697 Mtetra
.272 .001 .307 r
.77437 .58697 .77769 .56681 .7891 .55521 .78571 .57261 Mtetra
.047 0 .198 r
.78571 .57261 .7891 .55521 .80017 .53957 .79659 .55289 Mtetra
0 0 .015 r
.79659 .55289 .80017 .53957 .81106 .52223 .80722 .53093 Mtetra
0 0 0 r
.80722 .53093 .81106 .52223 .82193 .50535 .81782 .50964 Mtetra
.812 .926 .546 r
.81782 .50964 .82193 .50535 .83295 .49046 .82859 .49105 Mtetra
.903 .985 .758 r
.82859 .49105 .83295 .49046 .84419 .47825 .83964 .47602 Mtetra
.873 .941 .859 r
.83964 .47602 .84419 .47825 .85568 .46867 .851 .46451 Mtetra
.807 .873 .895 r
.851 .46451 .85568 .46867 .8674 .46128 .86265 .45589 Mtetra
.749 .817 .906 r
.86265 .45589 .8674 .46128 .87932 .45546 .87454 .44935 Mtetra
.709 .781 .908 r
.87454 .44935 .87932 .45546 .89139 .45064 .88661 .44413 Mtetra
.686 .76 .908 r
.88661 .44413 .89139 .45064 .90357 .44639 .89881 .43967 Mtetra
.674 .75 .908 r
.89881 .43967 .90357 .44639 .91583 .44244 .9111 .43561 Mtetra
.668 .745 .908 r
.9111 .43561 .91583 .44244 .92816 .43861 .92346 .43172 Mtetra
.665 .743 .908 r
.92346 .43172 .92816 .43861 .94054 .43484 .93588 .42791 Mtetra
.664 .742 .908 r
.93588 .42791 .94054 .43484 .95299 .43107 .94836 .42411 Mtetra
.664 .741 .908 r
.94836 .42411 .95299 .43107 .96548 .4273 .9609 .42031 Mtetra
.736 .259 .113 r
.38554 .61467 .39205 .61359 .40208 .61968 .39549 .62374 Mtetra
.752 .338 .265 r
.39549 .62374 .40208 .61968 .41215 .62718 .40548 .6347 Mtetra
.734 .358 .339 r
.40548 .6347 .41215 .62718 .42232 .6351 .41558 .64625 Mtetra
.697 .345 .375 r
.41558 .64625 .42232 .6351 .43262 .64205 .42584 .65654 Mtetra
.644 .306 .386 r
.42584 .65654 .43262 .64205 .44309 .6465 .43631 .66352 Mtetra
.567 .241 .375 r
.43631 .66352 .44309 .6465 .45372 .64719 .447 .66549 Mtetra
.459 .141 .339 r
.447 .66549 .45372 .64719 .46449 .6435 .45788 .66159 Mtetra
.307 0 .269 r
.45788 .66159 .46449 .6435 .47535 .63569 .46888 .65218 Mtetra
.112 0 .155 r
.46888 .65218 .47535 .63569 .48627 .62498 .47994 .63886 Mtetra
0 0 .008 r
.47994 .63886 .48627 .62498 .49719 .6133 .49099 .6242 Mtetra
0 0 0 r
.49099 .6242 .49719 .6133 .50809 .60298 .50201 .61123 Mtetra
.50201 .61123 .50809 .60298 .51898 .59633 .51298 .60295 Mtetra
.387 0 .044 r
.51298 .60295 .51898 .59633 .5299 .59523 .52397 .60177 Mtetra
.666 .246 .238 r
.52397 .60177 .5299 .59523 .54091 .60064 .53504 .60893 Mtetra
.758 .383 .345 r
.53504 .60893 .54091 .60064 .55207 .61213 .54627 .62391 Mtetra
.772 .426 .4 r
.54627 .62391 .55207 .61213 .56341 .62758 .55771 .64406 Mtetra
.748 .421 .43 r
.55771 .64406 .56341 .62758 .57492 .64326 .56935 .66464 Mtetra
.693 .38 .441 r
.56935 .66464 .57492 .64326 .58652 .65459 .58112 .67985 Mtetra
.597 .299 .433 r
.58112 .67985 .58652 .65459 .5981 .65762 .59285 .68454 Mtetra
.438 .161 .394 r
.59285 .68454 .5981 .65762 .60951 .65039 .60439 .6762 Mtetra
.187 0 .299 r
.60439 .6762 .60951 .65039 .62068 .63379 .61563 .65597 Mtetra
0 0 .126 r
.61563 .65597 .62068 .63379 .63163 .61113 .62658 .6281 Mtetra
0 0 0 r
.62658 .6281 .63163 .61113 .64244 .5869 .63735 .5983 Mtetra
.721 .8 .325 r
.63735 .5983 .64244 .5869 .65325 .56532 .64811 .57188 Mtetra
.797 .913 .521 r
.64811 .57188 .65325 .56532 .66422 .5494 .65904 .55261 Mtetra
.636 .934 .685 r
.65904 .55261 .66422 .5494 .67547 .54076 .6703 .54243 Mtetra
.121 0 0 r
.6703 .54243 .67547 .54076 .6871 .53971 .68201 .5417 Mtetra
.655 .133 0 r
.68201 .5417 .6871 .53971 .69916 .54554 .69421 .54952 Mtetra
.772 .328 .195 r
.69421 .54952 .69916 .54554 .71161 .55657 .70689 .56384 Mtetra
.782 .381 .295 r
.70689 .56384 .71161 .55657 .72437 .57024 .71993 .58148 Mtetra
.749 .376 .347 r
.71993 .58148 .72437 .57024 .73726 .5832 .73313 .59833 Mtetra
.683 .33 .371 r
.73313 .59833 .73726 .5832 .75004 .59196 .7462 .61 Mtetra
.575 .244 .37 r
.7462 .61 .75004 .59196 .76246 .59364 .75882 .61292 Mtetra
.407 .103 .334 r
.75882 .61292 .76246 .59364 .77437 .58697 .77081 .60547 Mtetra
.158 0 .245 r
.77081 .60547 .77437 .58697 .78571 .57261 .7821 .58847 Mtetra
0 0 .084 r
.7821 .58847 .78571 .57261 .79659 .55289 .79282 .56487 Mtetra
0 0 0 r
.79282 .56487 .79659 .55289 .80722 .53093 .80322 .53856 Mtetra
.779 .839 .379 r
.80322 .53856 .80722 .53093 .81782 .50964 .81358 .51313 Mtetra
.918 .941 .586 r
.81358 .51313 .81782 .50964 .82859 .49105 .82413 .49106 Mtetra
.943 .958 .735 r
.82413 .49106 .82859 .49105 .83964 .47602 .83501 .47342 Mtetra
.898 .921 .827 r
.83501 .47342 .83964 .47602 .851 .46451 .84626 .4601 Mtetra
.828 .866 .874 r
.84626 .4601 .851 .46451 .86265 .45589 .85785 .45034 Mtetra
.764 .817 .894 r
.85785 .45034 .86265 .45589 .87454 .44935 .86972 .44313 Mtetra
.719 .782 .902 r
.86972 .44313 .87454 .44935 .88661 .44413 .88179 .43754 Mtetra
.691 .761 .906 r
.88179 .43754 .88661 .44413 .89881 .43967 .89401 .43289 Mtetra
.676 .75 .907 r
.89401 .43289 .89881 .43967 .9111 .43561 .90633 .42873 Mtetra
.669 .745 .907 r
.90633 .42873 .9111 .43561 .92346 .43172 .91873 .42478 Mtetra
.666 .743 .908 r
.91873 .42478 .92346 .43172 .93588 .42791 .93119 .42092 Mtetra
.664 .742 .908 r
.93119 .42092 .93588 .42791 .94836 .42411 .94371 .41709 Mtetra
.664 .741 .908 r
.94371 .41709 .94836 .42411 .9609 .42031 .95628 .41326 Mtetra
.788 .344 .192 r
.37896 .6157 .38554 .61467 .39549 .62374 .38881 .62776 Mtetra
.79 .396 .308 r
.38881 .62776 .39549 .62374 .40548 .6347 .3987 .64222 Mtetra
.768 .404 .366 r
.3987 .64222 .40548 .6347 .41558 .64625 .40872 .65745 Mtetra
.73 .384 .393 r
.40872 .65745 .41558 .64625 .42584 .65654 .41893 .67115 Mtetra
.673 .338 .398 r
.41893 .67115 .42584 .65654 .43631 .66352 .4294 .68072 Mtetra
.586 .259 .382 r
.4294 .68072 .43631 .66352 .447 .66549 .44015 .68398 Mtetra
.453 .134 .335 r
.44015 .68398 .447 .66549 .45788 .66159 .45114 .67986 Mtetra
.249 0 .239 r
.45114 .67986 .45788 .66159 .46888 .65218 .46228 .66878 Mtetra
0 0 .083 r
.46228 .66878 .46888 .65218 .47994 .63886 .4735 .65275 Mtetra
0 0 0 r
.4735 .65275 .47994 .63886 .49099 .6242 .4847 .63491 Mtetra
.4847 .63491 .49099 .6242 .50201 .61123 .49583 .61901 Mtetra
.49583 .61901 .50201 .61123 .51298 .60295 .5069 .60864 Mtetra
.301 0 0 r
.5069 .60864 .51298 .60295 .52397 .60177 .51795 .6067 Mtetra
.684 .242 .195 r
.51795 .6067 .52397 .60177 .53504 .60893 .52907 .61464 Mtetra
.795 .405 .317 r
.52907 .61464 .53504 .60893 .54627 .62391 .54034 .6319 Mtetra
.815 .454 .374 r
.54034 .6319 .54627 .62391 .55771 .64406 .55185 .65537 Mtetra
.796 .45 .402 r
.55185 .65537 .55771 .64406 .56935 .66464 .56358 .67956 Mtetra
.739 .401 .409 r
.56358 .67956 .56935 .66464 .58112 .67985 .57546 .69764 Mtetra
.616 .286 .387 r
.57546 .69764 .58112 .67985 .59285 .68454 .58731 .70356 Mtetra
.343 .038 .295 r
.58731 .70356 .59285 .68454 .60439 .6762 .59895 .69433 Mtetra
0 0 .056 r
.59895 .69433 .60439 .6762 .61563 .65597 .61027 .67128 Mtetra
.681 .743 .241 r
.61027 .67128 .61563 .65597 .62658 .6281 .62125 .63939 Mtetra
.896 .868 .427 r
.62125 .63939 .62658 .6281 .63735 .5983 .63202 .60532 Mtetra
.96 .91 .545 r
.63202 .60532 .63735 .5983 .64811 .57188 .64277 .57522 Mtetra
.958 .947 .664 r
.64277 .57522 .64811 .57188 .65904 .55261 .6537 .55339 Mtetra
.847 .995 .836 r
.6537 .55339 .65904 .55261 .6703 .54243 .66498 .54202 Mtetra
.115 .665 .801 r
.66498 .54202 .6703 .54243 .68201 .5417 .67675 .54151 Mtetra
.66 .109 0 r
.67675 .54151 .68201 .5417 .69421 .54952 .68906 .5508 Mtetra
.808 .344 .125 r
.68906 .5508 .69421 .54952 .70689 .56384 .7019 .56757 Mtetra
.827 .403 .235 r
.7019 .56757 .70689 .56384 .71993 .58148 .71515 .58819 Mtetra
.8 .396 .287 r
.71515 .58819 .71993 .58148 .73313 .59833 .72858 .60796 Mtetra
.729 .336 .305 r
.72858 .60796 .73313 .59833 .7462 .61 .74185 .62184 Mtetra
.583 .201 .284 r
.74185 .62184 .7462 .61 .75882 .61292 .75464 .6257 Mtetra
.281 0 .187 r
.75464 .6257 .75882 .61292 .77081 .60547 .76669 .61764 Mtetra
0 0 0 r
.76669 .61764 .77081 .60547 .7821 .58847 .77796 .59865 Mtetra
.666 .757 .271 r
.77796 .59865 .7821 .58847 .79282 .56487 .78858 .5721 Mtetra
.883 .875 .437 r
.78858 .5721 .79282 .56487 .80322 .53856 .79884 .5425 Mtetra
.963 .91 .551 r
.79884 .5425 .80322 .53856 .81358 .51313 .80904 .51396 Mtetra
.979 .917 .647 r
.80904 .51396 .81358 .51313 .82413 .49106 .81945 .48929 Mtetra
.955 .907 .732 r
.81945 .48929 .82413 .49106 .83501 .47342 .83023 .46969 Mtetra
.903 .881 .803 r
.83023 .46969 .83501 .47342 .84626 .4601 .84142 .45502 Mtetra
.836 .844 .852 r
.84142 .45502 .84626 .4601 .85785 .45034 .85298 .44441 Mtetra
.773 .808 .881 r
.85298 .44441 .85785 .45034 .86972 .44313 .86484 .43669 Mtetra
.725 .779 .896 r
.86484 .43669 .86972 .44313 .88179 .43754 .87693 .43083 Mtetra
.694 .76 .902 r
.87693 .43083 .88179 .43754 .89401 .43289 .88917 .42603 Mtetra
.678 .75 .906 r
.88917 .42603 .89401 .43289 .90633 .42873 .90152 .42178 Mtetra
.669 .745 .907 r
.90152 .42178 .90633 .42873 .91873 .42478 .91395 .41778 Mtetra
.666 .743 .908 r
.91395 .41778 .91873 .42478 .93119 .42092 .92645 .41388 Mtetra
.664 .742 .908 r
.92645 .41388 .93119 .42092 .94371 .41709 .93901 .41002 Mtetra
.664 .741 .908 r
.93901 .41002 .94371 .41709 .95628 .41326 .95163 .40615 Mtetra
.824 .392 .211 r
.37236 .61578 .37896 .6157 .38881 .62776 .38211 .63044 Mtetra
.825 .434 .312 r
.38211 .63044 .38881 .62776 .3987 .64222 .3919 .64795 Mtetra
.805 .438 .362 r
.3919 .64795 .3987 .64222 .40872 .65745 .40183 .66641 Mtetra
.768 .414 .384 r
.40183 .66641 .40872 .65745 .41893 .67115 .41198 .68309 Mtetra
.708 .359 .384 r
.41198 .68309 .41893 .67115 .4294 .68072 .42245 .69494 Mtetra
.604 .257 .355 r
.42245 .69494 .4294 .68072 .44015 .68398 .43324 .69936 Mtetra
.414 .073 .275 r
.43324 .69936 .44015 .68398 .45114 .67986 .44433 .69502 Mtetra
.076 0 .101 r
.44433 .69502 .45114 .67986 .46228 .66878 .45561 .68243 Mtetra
0 0 0 r
.45561 .68243 .46228 .66878 .4735 .65275 .46698 .6639 Mtetra
.68 .828 .393 r
.46698 .6639 .4735 .65275 .4847 .63491 .47833 .64311 Mtetra
.791 .92 .537 r
.47833 .64311 .4847 .63491 .49583 .61901 .48959 .6243 Mtetra
.709 .942 .639 r
.48959 .6243 .49583 .61901 .5069 .60864 .50076 .61157 Mtetra
0 0 0 r
.50076 .61157 .5069 .60864 .51795 .6067 .51187 .60807 Mtetra
.66 .141 0 r
.51187 .60807 .51795 .6067 .52907 .61464 .52302 .61544 Mtetra
.833 .399 .204 r
.52302 .61544 .52907 .61464 .54034 .6319 .53431 .63304 Mtetra
.869 .472 .278 r
.53431 .63304 .54034 .6319 .55185 .65537 .54583 .65755 Mtetra
.865 .475 .298 r
.54583 .65755 .55185 .65537 .56358 .67956 .55759 .68308 Mtetra
.822 .413 .271 r
.55759 .68308 .56358 .67956 .57546 .69764 .5695 .70228 Mtetra
.636 .165 .118 r
.5695 .70228 .57546 .69764 .58731 .70356 .58141 .70865 Mtetra
0 0 0 r
.58141 .70865 .58731 .70356 .59895 .69433 .59313 .69897 Mtetra
.962 .94 .643 r
.59313 .69897 .59895 .69433 .61027 .67128 .60452 .6746 Mtetra
.99 .872 .617 r
.60452 .6746 .61027 .67128 .62125 .63939 .61557 .64088 Mtetra
.985 .843 .619 r
.61557 .64088 .62125 .63939 .63202 .60532 .62639 .60488 Mtetra
.973 .837 .648 r
.62639 .60488 .63202 .60532 .64277 .57522 .63718 .57311 Mtetra
.948 .849 .711 r
.63718 .57311 .64277 .57522 .6537 .55339 .64814 .55013 Mtetra
.867 .874 .841 r
.64814 .55013 .6537 .55339 .66498 .54202 .65946 .53823 Mtetra
.441 .76 .996 r
.65946 .53823 .66498 .54202 .67675 .54151 .67127 .53781 Mtetra
.507 0 0 r
.67127 .53781 .67675 .54151 .68906 .5508 .68364 .54776 Mtetra
.791 .297 0 r
.68364 .54776 .68906 .5508 .7019 .56757 .69655 .56562 Mtetra
.846 .384 .057 r
.69655 .56562 .7019 .56757 .71515 .58819 .70989 .58757 Mtetra
.841 .378 .09 r
.70989 .58757 .71515 .58819 .72858 .60796 .72342 .60866 Mtetra
.773 .278 .035 r
.72342 .60866 .72858 .60796 .74185 .62184 .73679 .62353 Mtetra
.48 0 0 r
.73679 .62353 .74185 .62184 .75464 .6257 .74966 .62779 Mtetra
.552 .915 .736 r
.74966 .62779 .75464 .6257 .76669 .61764 .76177 .61945 Mtetra
.943 .962 .691 r
.76177 .61945 .76669 .61764 .77796 .59865 .77306 .59953 Mtetra
.985 .897 .636 r
.77306 .59953 .77796 .59865 .78858 .5721 .78368 .57163 Mtetra
.987 .863 .626 r
.78368 .57163 .78858 .5721 .79884 .5425 .79392 .54052 Mtetra
.979 .849 .643 r
.79392 .54052 .79884 .5425 .80904 .51396 .80409 .51056 Mtetra
.962 .843 .679 r
.80409 .51056 .80904 .51396 .81945 .48929 .81448 .48471 Mtetra
.932 .839 .729 r
.81448 .48471 .81945 .48929 .83023 .46969 .82525 .4642 Mtetra
.887 .83 .785 r
.82525 .4642 .83023 .46969 .84142 .45502 .83643 .44892 Mtetra
.83 .813 .834 r
.83643 .44892 .84142 .45502 .85298 .44441 .84801 .43791 Mtetra
.772 .791 .868 r
.84801 .43791 .85298 .44441 .86484 .43669 .85989 .42995 Mtetra
.726 .771 .888 r
.85989 .42995 .86484 .43669 .87693 .43083 .87201 .42394 Mtetra
.695 .757 .899 r
.87201 .42394 .87693 .43083 .88917 .42603 .88428 .41906 Mtetra
.678 .749 .904 r
.88428 .41906 .88917 .42603 .90152 .42178 .89667 .41475 Mtetra
.67 .744 .906 r
.89667 .41475 .90152 .42178 .91395 .41778 .90914 .41071 Mtetra
.666 .742 .907 r
.90914 .41071 .91395 .41778 .92645 .41388 .92168 .40678 Mtetra
.664 .742 .908 r
.92168 .40678 .92645 .41388 .93901 .41002 .93428 .40288 Mtetra
.664 .741 .908 r
.93428 .40288 .93901 .41002 .95163 .40615 .94693 .39899 Mtetra
.852 .415 .181 r
.36576 .61397 .37236 .61578 .38211 .63044 .37544 .63043 Mtetra
.86 .459 .278 r
.37544 .63043 .38211 .63044 .3919 .64795 .38515 .65005 Mtetra
.847 .464 .324 r
.38515 .65005 .3919 .64795 .40183 .66641 .395 .67074 Mtetra
.817 .439 .339 r
.395 .67074 .40183 .66641 .41198 .68309 .40511 .68951 Mtetra
.757 .371 .322 r
.40511 .68951 .41198 .68309 .42245 .69494 .41556 .70294 Mtetra
.622 .214 .249 r
.41556 .70294 .42245 .69494 .43324 .69936 .42639 .70814 Mtetra
.252 0 .024 r
.42639 .70814 .43324 .69936 .44433 .69502 .43755 .70363 Mtetra
0 0 0 r
.43755 .70363 .44433 .69502 .45561 .68243 .44896 .68993 Mtetra
.883 .955 .611 r
.44896 .68993 .45561 .68243 .46698 .6639 .46046 .66955 Mtetra
.959 .945 .664 r
.46046 .66955 .46698 .6639 .47833 .64311 .47194 .64648 Mtetra
.962 .934 .71 r
.47194 .64648 .47833 .64311 .48959 .6243 .48332 .62525 Mtetra
.921 .946 .796 r
.48332 .62525 .48959 .6243 .50076 .61157 .49457 .61016 Mtetra
.709 .932 .963 r
.49457 .61016 .50076 .61157 .51187 .60807 .50574 .6045 Mtetra
0 .315 .709 r
.50574 .6045 .51187 .60807 .52302 .61544 .51691 .60989 Mtetra
.751 .259 0 r
.51691 .60989 .52302 .61544 .53431 .63304 .5282 .62569 Mtetra
.839 .398 0 r
.5282 .62569 .53431 .63304 .54583 .65755 .53968 .64859 Mtetra
.808 .381 0 r
.53968 .64859 .54583 .65755 .55759 .68308 .5514 .67274 Mtetra
0 0 .44 r
.5514 .67274 .55759 .68308 .5695 .70228 .56329 .69096 Mtetra
.329 .462 .843 r
.56329 .69096 .5695 .70228 .58141 .70865 .57519 .69685 Mtetra
.745 .664 .77 r
.57519 .69685 .58141 .70865 .59313 .69897 .58694 .68725 Mtetra
.849 .698 .694 r
.58694 .68725 .59313 .69897 .60452 .6746 .59839 .66344 Mtetra
.884 .709 .659 r
.59839 .66344 .60452 .6746 .61557 .64088 .60952 .63056 Mtetra
.897 .717 .651 r
.60952 .63056 .61557 .64088 .62639 .60488 .62045 .59548 Mtetra
.896 .727 .664 r
.62045 .59548 .62639 .60488 .63718 .57311 .63133 .56451 Mtetra
.876 .738 .706 r
.63133 .56451 .63718 .57311 .64814 .55013 .64237 .54207 Mtetra
.807 .741 .791 r
.64237 .54207 .64814 .55013 .65946 .53823 .65374 .53042 Mtetra
.555 .662 .908 r
.65374 .53042 .65946 .53823 .67127 .53781 .66557 .52995 Mtetra
0 .275 .778 r
.66557 .52995 .67127 .53781 .68364 .54776 .67793 .53959 Mtetra
0 0 .455 r
.67793 .53959 .68364 .54776 .69655 .56562 .69082 .55694 Mtetra
.635 .206 0 r
.69082 .55694 .69655 .56562 .70989 .58757 .70411 .57827 Mtetra
0 0 .423 r
.70411 .57827 .70989 .58757 .72342 .60866 .71759 .59873 Mtetra
0 .141 .686 r
.71759 .59873 .72342 .60866 .73679 .62353 .73093 .61312 Mtetra
.409 .529 .867 r
.73093 .61312 .73679 .62353 .74966 .62779 .7438 .61716 Mtetra
.737 .686 .801 r
.7438 .61716 .74966 .62779 .76177 .61945 .75595 .6089 Mtetra
.85 .723 .722 r
.75595 .6089 .76177 .61945 .77306 .59953 .76732 .58935 Mtetra
.893 .734 .678 r
.76732 .58935 .77306 .59953 .78368 .57163 .77804 .56202 Mtetra
.91 .742 .661 r
.77804 .56202 .78368 .57163 .79392 .54052 .78839 .53154 Mtetra
.914 .75 .665 r
.78839 .53154 .79392 .54052 .80409 .51056 .79869 .50217 Mtetra
.908 .761 .687 r
.79869 .50217 .80409 .51056 .81448 .48471 .80919 .47681 Mtetra
.89 .771 .725 r
.80919 .47681 .81448 .48471 .82525 .4642 .82004 .45666 Mtetra
.858 .778 .772 r
.82004 .45666 .82525 .4642 .83643 .44892 .8313 .44162 Mtetra
.813 .778 .82 r
.8313 .44162 .83643 .44892 .84801 .43791 .84294 .43074 Mtetra
.765 .771 .858 r
.84294 .43074 .84801 .43791 .85989 .42995 .85488 .42285 Mtetra
.723 .761 .883 r
.85488 .42285 .85989 .42995 .87201 .42394 .86704 .41686 Mtetra
.694 .752 .896 r
.86704 .41686 .87201 .42394 .88428 .41906 .87935 .41197 Mtetra
.678 .746 .903 r
.87935 .41197 .88428 .41906 .89667 .41475 .89178 .40765 Mtetra
.67 .744 .906 r
.89178 .40765 .89667 .41475 .90914 .41071 .90429 .40358 Mtetra
.666 .742 .907 r
.90429 .40358 .90914 .41071 .92168 .40678 .91687 .39962 Mtetra
.664 .742 .908 r
.91687 .39962 .92168 .40678 .93428 .40288 .92951 .3957 Mtetra
.664 .741 .908 r
.92951 .3957 .93428 .40288 .94693 .39899 .9422 .39177 Mtetra
.86 .408 .087 r
.35923 .60959 .36576 .61397 .37544 .63043 .36887 .62671 Mtetra
.886 .464 .186 r
.36887 .62671 .37544 .63043 .38515 .65005 .37853 .64712 Mtetra
.887 .476 .222 r
.37853 .64712 .38515 .65005 .395 .67074 .38834 .66866 Mtetra
.87 .447 .206 r
.38834 .66866 .395 .67074 .40511 .68951 .39842 .6882 Mtetra
.812 .343 .105 r
.39842 .6882 .40511 .68951 .41556 .70294 .40886 .70222 Mtetra
.528 0 0 r
.40886 .70222 .41556 .70294 .42639 .70814 .41971 .7077 Mtetra
.604 .932 .96 r
.41971 .7077 .42639 .70814 .43755 .70363 .43092 .70308 Mtetra
.903 .908 .816 r
.43092 .70308 .43755 .70363 .44896 .68993 .4424 .68887 Mtetra
.933 .849 .736 r
.4424 .68887 .44896 .68993 .46046 .66955 .454 .66763 Mtetra
.932 .82 .712 r
.454 .66763 .46046 .66955 .47194 .64648 .46558 .64336 Mtetra
.919 .806 .72 r
.46558 .64336 .47194 .64648 .48332 .62525 .47705 .62063 Mtetra
.882 .797 .761 r
.47705 .62063 .48332 .62525 .49457 .61016 .48837 .60365 Mtetra
.772 .76 .842 r
.48837 .60365 .49457 .61016 .50574 .6045 .49959 .5956 Mtetra
.437 .573 .892 r
.49959 .5956 .50574 .6045 .51691 .60989 .51078 .598 Mtetra
0 .195 .721 r
.51078 .598 .51691 .60989 .5282 .62569 .52205 .61023 Mtetra
0 .014 .586 r
.52205 .61023 .5282 .62569 .53968 .64859 .53348 .62922 Mtetra
0 .081 .617 r
.53348 .62922 .53968 .64859 .5514 .67274 .54512 .64963 Mtetra
.249 .268 .685 r
.54512 .64963 .5514 .67274 .56329 .69096 .55691 .665 Mtetra
.513 .428 .697 r
.55691 .665 .56329 .69096 .57519 .69685 .56875 .6696 Mtetra
.665 .521 .678 r
.56875 .6696 .57519 .69685 .58694 .68725 .58048 .66058 Mtetra
.747 .574 .66 r
.58048 .66058 .58694 .68725 .59839 .66344 .59197 .63903 Mtetra
.793 .606 .649 r
.59197 .63903 .59839 .66344 .60952 .63056 .6032 .60945 Mtetra
.817 .63 .649 r
.6032 .60945 .60952 .63056 .62045 .59548 .61426 .57787 Mtetra
.825 .648 .662 r
.61426 .57787 .62045 .59548 .63133 .56451 .62527 .54993 Mtetra
.812 .66 .695 r
.62527 .54993 .63133 .56451 .64237 .54207 .63642 .52959 Mtetra
.753 .657 .754 r
.63642 .52959 .64237 .54207 .65374 .53042 .64785 .5189 Mtetra
.582 .592 .828 r
.64785 .5189 .65374 .53042 .66557 .52995 .65968 .51825 Mtetra
.232 .388 .814 r
.65968 .51825 .66557 .52995 .67793 .53959 .67199 .52668 Mtetra
0 .165 .697 r
.67199 .52668 .67793 .53959 .69082 .55694 .68475 .54201 Mtetra
0 .102 .649 r
.68475 .54201 .69082 .55694 .70411 .57827 .69789 .56088 Mtetra
.048 .185 .686 r
.69789 .56088 .70411 .57827 .71759 .59873 .7112 .57893 Mtetra
.305 .334 .727 r
.7112 .57893 .71759 .59873 .73093 .61312 .72439 .59148 Mtetra
.526 .462 .727 r
.72439 .59148 .73093 .61312 .7438 .61716 .73718 .59472 Mtetra
.668 .543 .704 r
.73718 .59472 .7438 .61716 .75595 .6089 .74935 .5869 Mtetra
.752 .593 .68 r
.74935 .5869 .75595 .6089 .76732 .58935 .76083 .56892 Mtetra
.801 .627 .665 r
.76083 .56892 .76732 .58935 .77804 .56202 .77175 .54391 Mtetra
.831 .652 .66 r
.77175 .54391 .77804 .56202 .78839 .53154 .78234 .51604 Mtetra
.847 .674 .668 r
.78234 .51604 .78839 .53154 .79869 .50217 .79288 .48914 Mtetra
.852 .695 .688 r
.79288 .48914 .79869 .50217 .80919 .47681 .80359 .46582 Mtetra
.845 .716 .722 r
.80359 .46582 .80919 .47681 .82004 .45666 .81463 .44721 Mtetra
.824 .735 .766 r
.81463 .44721 .82004 .45666 .8313 .44162 .82604 .43319 Mtetra
.791 .747 .813 r
.82604 .43319 .8313 .44162 .84294 .43074 .83778 .42295 Mtetra
.752 .752 .852 r
.83778 .42295 .84294 .43074 .85488 .42285 .84979 .41541 Mtetra
.716 .75 .879 r
.84979 .41541 .85488 .42285 .86704 .41686 .86201 .4096 Mtetra
.691 .747 .894 r
.86201 .4096 .86704 .41686 .87935 .41197 .87438 .40478 Mtetra
.676 .744 .902 r
.87438 .40478 .87935 .41197 .89178 .40765 .88685 .40046 Mtetra
.669 .743 .905 r
.88685 .40046 .89178 .40765 .90429 .40358 .89941 .39639 Mtetra
.666 .742 .907 r
.89941 .39639 .90429 .40358 .91687 .39962 .91202 .39241 Mtetra
.664 .741 .908 r
.91202 .39241 .91687 .39962 .92951 .3957 .9247 .38845 Mtetra
.9247 .38845 .92951 .3957 .9422 .39177 .93744 .38449 Mtetra
.804 .341 0 r
.35279 .60238 .35923 .60959 .36887 .62671 .36243 .61892 Mtetra
.852 .413 0 r
.36243 .61892 .36887 .62671 .37853 .64712 .3721 .63866 Mtetra
.851 .419 0 r
.3721 .63866 .37853 .64712 .38834 .66866 .38191 .65949 Mtetra
.775 .337 0 r
.38191 .65949 .38834 .66866 .39842 .6882 .39198 .67838 Mtetra
0 0 .532 r
.39198 .67838 .39842 .6882 .40886 .70222 .40242 .69188 Mtetra
.304 .468 .858 r
.40242 .69188 .40886 .70222 .41971 .7077 .41327 .69708 Mtetra
.679 .648 .813 r
.41327 .69708 .41971 .7077 .43092 .70308 .42451 .69243 Mtetra
.795 .687 .745 r
.42451 .69243 .43092 .70308 .4424 .68887 .43601 .67841 Mtetra
.839 .699 .709 r
.43601 .67841 .4424 .68887 .454 .66763 .44765 .65744 Mtetra
.855 .705 .695 r
.44765 .65744 .454 .66763 .46558 .64336 .45929 .6333 Mtetra
.853 .706 .699 r
.45929 .6333 .46558 .64336 .47705 .62063 .47081 .61026 Mtetra
.827 .699 .722 r
.47081 .61026 .47705 .62063 .48837 .60365 .48219 .59224 Mtetra
.754 .665 .762 r
.48219 .59224 .48837 .60365 .49959 .5956 .49345 .58209 Mtetra
.591 .564 .792 r
.49345 .58209 .49959 .5956 .51078 .598 .50466 .58117 Mtetra
.366 .394 .757 r
.50466 .58117 .51078 .598 .52205 .61023 .5159 .5889 Mtetra
.252 .28 .696 r
.5159 .5889 .52205 .61023 .53348 .62922 .52727 .60263 Mtetra
.304 .283 .671 r
.52727 .60263 .53348 .62922 .54512 .64963 .53881 .61788 Mtetra
.429 .349 .665 r
.53881 .61788 .54512 .64963 .55691 .665 .55049 .62927 Mtetra
.548 .42 .658 r
.55049 .62927 .55691 .665 .56875 .6696 .56222 .63209 Mtetra
.636 .477 .65 r
.56222 .63209 .56875 .6696 .58048 .66058 .5739 .624 Mtetra
.697 .52 .644 r
.5739 .624 .58048 .66058 .59197 .63903 .58541 .6058 Mtetra
.738 .552 .642 r
.58541 .6058 .59197 .63903 .6032 .60945 .59673 .58108 Mtetra
.763 .578 .647 r
.59673 .58108 .6032 .60945 .61426 .57787 .60792 .55471 Mtetra
.774 .598 .661 r
.60792 .55471 .61426 .57787 .62527 .54993 .61908 .53126 Mtetra
.764 .612 .69 r
.61908 .53126 .62527 .54993 .63642 .52959 .63034 .51405 Mtetra
.716 .609 .737 r
.63034 .51405 .63642 .52959 .64785 .5189 .64184 .50478 Mtetra
.591 .559 .787 r
.64184 .50478 .64785 .5189 .65968 .51825 .65366 .50382 Mtetra
.384 .436 .792 r
.65366 .50382 .65968 .51825 .67199 .52668 .66587 .51036 Mtetra
.22 .31 .744 r
.66587 .51036 .67199 .52668 .68475 .54201 .67847 .52262 Mtetra
.208 .271 .709 r
.67847 .52262 .68475 .54201 .69789 .56088 .69137 .53776 Mtetra
.306 .309 .699 r
.69137 .53776 .69789 .56088 .7112 .57893 .70443 .55216 Mtetra
.438 .378 .693 r
.70443 .55216 .7112 .57893 .72439 .59148 .71741 .56195 Mtetra
.553 .443 .682 r
.71741 .56195 .72439 .59148 .73718 .59472 .73007 .56398 Mtetra
.64 .495 .67 r
.73007 .56398 .73718 .59472 .74935 .5869 .74223 .55684 Mtetra
.702 .536 .66 r
.74223 .55684 .74935 .5869 .76083 .56892 .75385 .54124 Mtetra
.745 .569 .656 r
.75385 .54124 .76083 .56892 .77175 .54391 .76502 .51979 Mtetra
.775 .597 .658 r
.76502 .51979 .77175 .54391 .78234 .51604 .77592 .4959 Mtetra
.795 .624 .669 r
.77592 .4959 .78234 .51604 .79288 .48914 .78678 .47277 Mtetra
.805 .65 .691 r
.78678 .47277 .79288 .48914 .80359 .46582 .79779 .4526 Mtetra
.804 .677 .724 r
.79779 .4526 .80359 .46582 .81463 .44721 .80907 .43635 Mtetra
.792 .703 .767 r
.80907 .43635 .81463 .44721 .82604 .43319 .82066 .42394 Mtetra
.768 .724 .812 r
.82066 .42394 .82604 .43319 .83778 .42295 .83254 .41469 Mtetra
.737 .736 .851 r
.83254 .41469 .83778 .42295 .84979 .41541 .84465 .40772 Mtetra
.708 .741 .878 r
.84465 .40772 .84979 .41541 .86201 .4096 .85694 .40219 Mtetra
.687 .743 .894 r
.85694 .40219 .86201 .4096 .87438 .40478 .86936 .39748 Mtetra
.674 .742 .902 r
.86936 .39748 .87438 .40478 .88685 .40046 .88188 .39321 Mtetra
.668 .742 .905 r
.88188 .39321 .88685 .40046 .89941 .39639 .89448 .38913 Mtetra
.665 .742 .907 r
.89448 .38913 .89941 .39639 .91202 .39241 .90714 .38513 Mtetra
.664 .741 .908 r
.90714 .38513 .91202 .39241 .9247 .38845 .91985 .38114 Mtetra
.91985 .38114 .9247 .38845 .93744 .38449 .93263 .37716 Mtetra
0 0 .387 r
.34643 .59262 .35279 .60238 .36243 .61892 .35613 .60749 Mtetra
.626 .233 0 r
.35613 .60749 .36243 .61892 .3721 .63866 .36585 .62526 Mtetra
0 0 .407 r
.36585 .62526 .3721 .63866 .38191 .65949 .3757 .64401 Mtetra
0 .003 .577 r
.3757 .64401 .38191 .65949 .39198 .67838 .38581 .66095 Mtetra
.17 .262 .716 r
.38581 .66095 .39198 .67838 .40242 .69188 .39626 .67296 Mtetra
.478 .444 .742 r
.39626 .67296 .40242 .69188 .41327 .69708 .40711 .67737 Mtetra
.643 .538 .721 r
.40711 .67737 .41327 .69708 .42451 .69243 .41833 .67278 Mtetra
.728 .587 .698 r
.41833 .67278 .42451 .69243 .43601 .67841 .42982 .65959 Mtetra
.774 .616 .683 r
.42982 .65959 .43601 .67841 .44765 .65744 .44145 .63994 Mtetra
.797 .633 .679 r
.44145 .63994 .44765 .65744 .45929 .6333 .45309 .61719 Mtetra
.803 .644 .684 r
.45309 .61719 .45929 .6333 .47081 .61026 .46463 .5951 Mtetra
.789 .643 .7 r
.46463 .5951 .47081 .61026 .48219 .59224 .47604 .57706 Mtetra
.741 .621 .726 r
.47604 .57706 .48219 .59224 .49345 .58209 .48732 .56553 Mtetra
.642 .559 .746 r
.48732 .56553 .49345 .58209 .50466 .58117 .49854 .56163 Mtetra
.512 .459 .735 r
.49854 .56163 .50466 .58117 .5159 .5889 .50977 .56488 Mtetra
.431 .38 .701 r
.50977 .56488 .5159 .5889 .52727 .60263 .52109 .57316 Mtetra
.439 .362 .673 r
.52109 .57316 .52727 .60263 .53881 .61788 .53253 .58294 Mtetra
.497 .386 .658 r
.53253 .58294 .53881 .61788 .55049 .62927 .5441 .5901 Mtetra
.565 .424 .648 r
.5441 .5901 .55049 .62927 .56222 .63209 .55573 .59106 Mtetra
.624 .462 .642 r
.55573 .59106 .56222 .63209 .5739 .624 .56734 .58401 Mtetra
.67 .495 .64 r
.56734 .58401 .5739 .624 .58541 .6058 .57885 .5695 Mtetra
.704 .523 .642 r
.57885 .5695 .58541 .6058 .59673 .58108 .59025 .55013 Mtetra
.727 .548 .65 r
.59025 .55013 .59673 .58108 .60792 .55471 .60155 .52949 Mtetra
.738 .57 .666 r
.60155 .52949 .60792 .55471 .61908 .53126 .61284 .51104 Mtetra
.731 .586 .694 r
.61284 .51104 .61908 .53126 .63034 .51405 .62422 .49728 Mtetra
.691 .586 .734 r
.62422 .49728 .63034 .51405 .64184 .50478 .63577 .48956 Mtetra
.599 .551 .772 r
.63577 .48956 .64184 .50478 .65366 .50382 .64758 .48818 Mtetra
.465 .47 .779 r
.64758 .48818 .65366 .50382 .66587 .51036 .65969 .49254 Mtetra
.369 .389 .75 r
.65969 .49254 .66587 .51036 .67847 .52262 .6721 .50124 Mtetra
.362 .356 .718 r
.6721 .50124 .67847 .52262 .69137 .53776 .68475 .51212 Mtetra
.419 .369 .696 r
.68475 .51212 .69137 .53776 .70443 .55216 .69753 .52237 Mtetra
.495 .403 .68 r
.69753 .52237 .70443 .55216 .71741 .56195 .71026 .52902 Mtetra
.568 .442 .668 r
.71026 .52902 .71741 .56195 .73007 .56398 .72278 .5297 Mtetra
.627 .478 .66 r
.72278 .5297 .73007 .56398 .74223 .55684 .73493 .52332 Mtetra
.674 .51 .655 r
.73493 .52332 .74223 .55684 .75385 .54124 .74669 .51044 Mtetra
.71 .539 .655 r
.74669 .51044 .75385 .54124 .76502 .51979 .75811 .49301 Mtetra
.738 .566 .661 r
.75811 .49301 .76502 .51979 .77592 .4959 .76934 .47367 Mtetra
.757 .594 .675 r
.76934 .47367 .77592 .4959 .78678 .47277 .78055 .45488 Mtetra
.769 .623 .698 r
.78055 .45488 .78678 .47277 .79779 .4526 .79188 .43834 Mtetra
.771 .653 .732 r
.79188 .43834 .79779 .4526 .80907 .43635 .80343 .42482 Mtetra
.763 .683 .774 r
.80343 .42482 .80907 .43635 .82066 .42394 .81522 .41428 Mtetra
.745 .709 .818 r
.81522 .41428 .82066 .42394 .83254 .41469 .82724 .4062 Mtetra
.721 .726 .854 r
.82724 .4062 .83254 .41469 .84465 .40772 .83946 .39987 Mtetra
.698 .735 .88 r
.83946 .39987 .84465 .40772 .85694 .40219 .85183 .39467 Mtetra
.682 .739 .894 r
.85183 .39467 .85694 .40219 .86936 .39748 .86431 .39012 Mtetra
.672 .741 .902 r
.86431 .39012 .86936 .39748 .88188 .39321 .87687 .38589 Mtetra
.667 .741 .906 r
.87687 .38589 .88188 .39321 .89448 .38913 .88951 .38181 Mtetra
.665 .741 .907 r
.88951 .38181 .89448 .38913 .90714 .38513 .90221 .37779 Mtetra
.664 .741 .908 r
.90221 .37779 .90714 .38513 .91985 .38114 .91497 .37378 Mtetra
.91497 .37378 .91985 .38114 .93263 .37716 .92778 .36976 Mtetra
0 .068 .631 r
.34013 .5811 .34643 .59262 .35613 .60749 .34993 .59354 Mtetra
0 .026 .597 r
.34993 .59354 .35613 .60749 .36585 .62526 .35975 .60847 Mtetra
0 .087 .63 r
.35975 .60847 .36585 .62526 .3757 .64401 .36968 .62421 Mtetra
.138 .213 .679 r
.36968 .62421 .3757 .64401 .38581 .66095 .37985 .63837 Mtetra
.361 .341 .702 r
.37985 .63837 .38581 .66095 .39626 .67296 .39033 .64824 Mtetra
.523 .436 .699 r
.39033 .64824 .39626 .67296 .40711 .67737 .40117 .65154 Mtetra
.627 .499 .687 r
.40117 .65154 .40711 .67737 .41833 .67278 .41236 .64706 Mtetra
.693 .541 .677 r
.41236 .64706 .41833 .67278 .42982 .65959 .42379 .63513 Mtetra
.734 .571 .671 r
.42379 .63513 .42982 .65959 .44145 .63994 .43537 .61753 Mtetra
.76 .593 .67 r
.43537 .61753 .44145 .63994 .45309 .61719 .44697 .59708 Mtetra
.77 .607 .677 r
.44697 .59708 .45309 .61719 .46463 .5951 .45849 .57691 Mtetra
.764 .613 .691 r
.45849 .57691 .46463 .5951 .47604 .57706 .4699 .55982 Mtetra
.732 .602 .712 r
.4699 .55982 .47604 .57706 .48732 .56553 .4812 .54779 Mtetra
.667 .564 .729 r
.4812 .54779 .48732 .56553 .49854 .56163 .49244 .54171 Mtetra
.581 .499 .727 r
.49244 .54171 .49854 .56163 .50977 .56488 .50366 .54123 Mtetra
.519 .439 .705 r
.50366 .54123 .50977 .56488 .52109 .57316 .51494 .54474 Mtetra
.509 .412 .681 r
.51494 .54474 .52109 .57316 .53253 .58294 .52631 .54967 Mtetra
.537 .416 .663 r
.52631 .54967 .53253 .58294 .5441 .5901 .53779 .55306 Mtetra
.579 .437 .652 r
.53779 .55306 .5441 .5901 .55573 .59106 .54932 .55237 Mtetra
.62 .462 .647 r
.54932 .55237 .55573 .59106 .56734 .58401 .56087 .5463 Mtetra
.655 .488 .646 r
.56087 .5463 .56734 .58401 .57885 .5695 .57238 .53517 Mtetra
.682 .512 .65 r
.57238 .53517 .57885 .5695 .59025 .55013 .58382 .52072 Mtetra
.702 .536 .66 r
.58382 .52072 .59025 .55013 .60155 .52949 .59522 .50538 Mtetra
.713 .559 .678 r
.59522 .50538 .60155 .52949 .61284 .51104 .60662 .49155 Mtetra
.707 .577 .706 r
.60662 .49155 .61284 .51104 .62422 .49728 .61809 .48098 Mtetra
.676 .582 .743 r
.61809 .48098 .62422 .49728 .63577 .48956 .6297 .47465 Mtetra
.608 .56 .775 r
.6297 .47465 .63577 .48956 .64758 .48818 .64149 .47279 Mtetra
.519 .505 .781 r
.64149 .47279 .64758 .48818 .65969 .49254 .65351 .47499 Mtetra
.457 .446 .758 r
.65351 .47499 .65969 .49254 .6721 .50124 .66574 .48025 Mtetra
.45 .415 .728 r
.66574 .48025 .6721 .50124 .68475 .51212 .67817 .48701 Mtetra
.482 .412 .702 r
.67817 .48701 .68475 .51212 .69753 .52237 .69069 .49328 Mtetra
.531 .428 .683 r
.69069 .49328 .69753 .52237 .71026 .52902 .70321 .49694 Mtetra
.579 .451 .67 r
.70321 .49694 .71026 .52902 .72278 .5297 .71558 .49633 Mtetra
.622 .476 .662 r
.71558 .49633 .72278 .5297 .73493 .52332 .72773 .49068 Mtetra
.659 .501 .659 r
.72773 .49068 .73493 .52332 .74669 .51044 .73961 .48037 Mtetra
.688 .526 .662 r
.73961 .48037 .74669 .51044 .75811 .49301 .75127 .4668 Mtetra
.712 .552 .671 r
.75127 .4668 .75811 .49301 .76934 .47367 .7628 .45183 Mtetra
.73 .58 .687 r
.7628 .45183 .76934 .47367 .78055 .45488 .77434 .43722 Mtetra
.741 .611 .713 r
.77434 .43722 .78055 .45488 .79188 .43834 .78597 .4242 Mtetra
.745 .643 .748 r
.78597 .4242 .79188 .43834 .80343 .42482 .79776 .41334 Mtetra
.739 .675 .788 r
.79776 .41334 .80343 .42482 .81522 .41428 .80975 .40462 Mtetra
.725 .702 .829 r
.80975 .40462 .81522 .41428 .82724 .4062 .82191 .39767 Mtetra
.706 .721 .861 r
.82191 .39767 .82724 .4062 .83946 .39987 .83423 .39198 Mtetra
.689 .732 .884 r
.83423 .39198 .83946 .39987 .85183 .39467 .84667 .38711 Mtetra
.677 .738 .896 r
.84667 .38711 .85183 .39467 .86431 .39012 .85921 .3827 Mtetra
.67 .74 .903 r
.85921 .3827 .86431 .39012 .87687 .38589 .87182 .37852 Mtetra
.666 .741 .906 r
.87182 .37852 .87687 .38589 .88951 .38181 .8845 .37444 Mtetra
.665 .741 .907 r
.8845 .37444 .88951 .38181 .90221 .37779 .89725 .3704 Mtetra
.664 .741 .908 r
.89725 .3704 .90221 .37779 .91497 .37378 .91004 .36636 Mtetra
.91004 .36636 .91497 .37378 .92778 .36976 .9229 .36231 Mtetra
.032 .25 .751 r
.33385 .56889 .34013 .5811 .34993 .59354 .34376 .57863 Mtetra
.045 .209 .71 r
.34376 .57863 .34993 .59354 .35975 .60847 .3537 .59042 Mtetra
.15 .238 .701 r
.3537 .59042 .35975 .60847 .36968 .62421 .36374 .60287 Mtetra
.297 .306 .7 r
.36374 .60287 .36968 .62421 .37985 .63837 .37398 .61397 Mtetra
.436 .379 .696 r
.37398 .61397 .37985 .63837 .39033 .64824 .3845 .62151 Mtetra
.544 .44 .687 r
.3845 .62151 .39033 .64824 .40117 .65154 .39534 .6236 Mtetra
.621 .487 .678 r
.39534 .6236 .40117 .65154 .41236 .64706 .40648 .61926 Mtetra
.675 .523 .671 r
.40648 .61926 .41236 .64706 .42379 .63513 .41785 .60872 Mtetra
.713 .551 .669 r
.41785 .60872 .42379 .63513 .43537 .61753 .42935 .59345 Mtetra
.737 .574 .671 r
.42935 .59345 .43537 .61753 .44697 .59708 .44088 .57567 Mtetra
.75 .591 .678 r
.44088 .57567 .44697 .59708 .45849 .57691 .45237 .55791 Mtetra
.749 .601 .692 r
.45237 .55791 .45849 .57691 .4699 .55982 .46376 .54236 Mtetra
.729 .599 .711 r
.46376 .54236 .4699 .55982 .4812 .54779 .47507 .53058 Mtetra
.685 .577 .729 r
.47507 .53058 .4812 .54779 .49244 .54171 .48631 .52324 Mtetra
.624 .534 .733 r
.48631 .52324 .49244 .54171 .50366 .54123 .49754 .52008 Mtetra
.574 .487 .719 r
.49754 .52008 .50366 .54123 .51494 .54474 .50881 .51999 Mtetra
.556 .457 .698 r
.50881 .51999 .51494 .54474 .52631 .54967 .52014 .52117 Mtetra
.567 .45 .68 r
.52014 .52117 .52631 .54967 .53779 .55306 .53155 .52163 Mtetra
.592 .458 .668 r
.53155 .52163 .53779 .55306 .54932 .55237 .54302 .51967 Mtetra
.621 .474 .662 r
.54302 .51967 .54932 .55237 .56087 .5463 .55452 .5144 Mtetra
.647 .494 .661 r
.55452 .5144 .56087 .5463 .57238 .53517 .56602 .50598 Mtetra
.67 .516 .667 r
.56602 .50598 .57238 .53517 .58382 .52072 .5775 .49547 Mtetra
.687 .539 .679 r
.5775 .49547 .58382 .52072 .59522 .50538 .58897 .4844 Mtetra
.696 .562 .7 r
.58897 .4844 .59522 .50538 .60662 .49155 .60046 .47429 Mtetra
.692 .583 .729 r
.60046 .47429 .60662 .49155 .61809 .48098 .61201 .46628 Mtetra
.667 .594 .763 r
.61201 .46628 .61809 .48098 .6297 .47465 .62365 .46103 Mtetra
.618 .581 .79 r
.62365 .46103 .6297 .47465 .64149 .47279 .63543 .45868 Mtetra
.559 .544 .794 r
.63543 .45868 .64149 .47279 .65351 .47499 .64738 .459 Mtetra
.517 .499 .775 r
.64738 .459 .65351 .47499 .66574 .48025 .65948 .46131 Mtetra
.509 .467 .745 r
.65948 .46131 .66574 .48025 .67817 .48701 .67172 .46458 Mtetra
.527 .455 .718 r
.67172 .46458 .67817 .48701 .69069 .49328 .68405 .46749 Mtetra
.558 .458 .697 r
.68405 .46749 .69069 .49328 .70321 .49694 .69639 .46864 Mtetra
.591 .47 .683 r
.69639 .46864 .70321 .49694 .71558 .49633 .70865 .46695 Mtetra
.623 .487 .675 r
.70865 .46695 .71558 .49633 .72773 .49068 .72079 .46189 Mtetra
.651 .506 .673 r
.72079 .46189 .72773 .49068 .73961 .48037 .73277 .45374 Mtetra
.675 .529 .678 r
.73277 .45374 .73961 .48037 .75127 .4668 .74463 .4434 Mtetra
.695 .553 .689 r
.74463 .4434 .75127 .4668 .7628 .45183 .75642 .43211 Mtetra
.711 .581 .708 r
.75642 .43211 .7628 .45183 .77434 .43722 .76822 .42104 Mtetra
.721 .612 .735 r
.76822 .42104 .77434 .43722 .78597 .4242 .78011 .41101 Mtetra
.724 .645 .77 r
.78011 .41101 .78597 .4242 .79776 .41334 .79212 .40242 Mtetra
.719 .677 .808 r
.79212 .40242 .79776 .41334 .80975 .40462 .80427 .39525 Mtetra
.707 .703 .844 r
.80427 .39525 .80975 .40462 .82191 .39767 .81656 .38927 Mtetra
.693 .721 .871 r
.81656 .38927 .82191 .39767 .83423 .39198 .82897 .38413 Mtetra
.681 .732 .889 r
.82897 .38413 .83423 .39198 .84667 .38711 .84148 .37953 Mtetra
.673 .737 .899 r
.84148 .37953 .84667 .38711 .85921 .3827 .85407 .37523 Mtetra
.668 .74 .904 r
.85407 .37523 .85921 .3827 .87182 .37852 .86673 .37109 Mtetra
.665 .741 .906 r
.86673 .37109 .87182 .37852 .8845 .37444 .87946 .36701 Mtetra
.664 .741 .907 r
.87946 .36701 .8845 .37444 .89725 .3704 .89224 .36294 Mtetra
.664 .741 .908 r
.89224 .36294 .89725 .3704 .91004 .36636 .90508 .35887 Mtetra
.90508 .35887 .91004 .36636 .9229 .36231 .91798 .35479 Mtetra
.189 .362 .806 r
.32751 .55713 .33385 .56889 .34376 .57863 .33754 .56444 Mtetra
.189 .316 .763 r
.33754 .56444 .34376 .57863 .3537 .59042 .34759 .57341 Mtetra
.258 .321 .738 r
.34759 .57341 .3537 .59042 .36374 .60287 .35773 .58289 Mtetra
.363 .36 .722 r
.35773 .58289 .36374 .60287 .37398 .61397 .36805 .59127 Mtetra
.469 .41 .709 r
.36805 .59127 .37398 .61397 .3845 .62151 .37862 .59673 Mtetra
.557 .457 .697 r
.37862 .59673 .3845 .62151 .39534 .6236 .38945 .59775 Mtetra
.623 .496 .686 r
.38945 .59775 .39534 .6236 .40648 .61926 .40056 .59351 Mtetra
.671 .527 .68 r
.40056 .59351 .40648 .61926 .41785 .60872 .41186 .58423 Mtetra
.706 .553 .678 r
.41186 .58423 .41785 .60872 .42935 .59345 .4233 .57103 Mtetra
.73 .575 .681 r
.4233 .57103 .42935 .59345 .44088 .57567 .43477 .55571 Mtetra
.743 .593 .689 r
.43477 .55571 .44088 .57567 .45237 .55791 .44621 .54024 Mtetra
.745 .606 .704 r
.44621 .54024 .45237 .55791 .46376 .54236 .45759 .52634 Mtetra
.732 .611 .723 r
.45759 .52634 .46376 .54236 .47507 .53058 .4689 .51519 Mtetra
.701 .601 .741 r
.4689 .51519 .47507 .53058 .48631 .52324 .48016 .5073 Mtetra
.656 .573 .749 r
.48016 .5073 .48631 .52324 .49754 .52008 .4914 .50248 Mtetra
.615 .536 .742 r
.4914 .50248 .49754 .52008 .50881 .51999 .50267 .49996 Mtetra
.594 .506 .725 r
.50267 .49996 .50881 .51999 .52014 .52117 .51398 .49856 Mtetra
.594 .492 .708 r
.51398 .49856 .52014 .52117 .53155 .52163 .52536 .497 Mtetra
.608 .491 .695 r
.52536 .497 .53155 .52163 .54302 .51967 .5368 .49416 Mtetra
.627 .5 .688 r
.5368 .49416 .54302 .51967 .55452 .5144 .54827 .48948 Mtetra
.647 .515 .688 r
.54827 .48948 .55452 .5144 .56602 .50598 .55977 .48299 Mtetra
.665 .534 .695 r
.55977 .48299 .56602 .50598 .5775 .49547 .57127 .47529 Mtetra
.679 .557 .71 r
.57127 .47529 .5775 .49547 .58897 .4844 .5828 .46727 Mtetra
.686 .581 .733 r
.5828 .46727 .58897 .4844 .60046 .47429 .59435 .45982 Mtetra
.682 .604 .762 r
.59435 .45982 .60046 .47429 .61201 .46628 .60595 .45363 Mtetra
.664 .617 .793 r
.60595 .45363 .61201 .46628 .62365 .46103 .61763 .4491 Mtetra
.63 .612 .814 r
.61763 .4491 .62365 .46103 .63543 .45868 .62942 .44633 Mtetra
.591 .587 .816 r
.62942 .44633 .63543 .45868 .64738 .459 .64131 .44517 Mtetra
.563 .551 .799 r
.64131 .44517 .64738 .459 .65948 .46131 .65333 .44522 Mtetra
.555 .52 .772 r
.65333 .44522 .65948 .46131 .67172 .46458 .66544 .44584 Mtetra
.563 .502 .744 r
.66544 .44584 .67172 .46458 .68405 .46749 .67763 .44621 Mtetra
.582 .496 .722 r
.67763 .44621 .68405 .46749 .69639 .46864 .68985 .44548 Mtetra
.605 .499 .707 r
.68985 .44548 .69639 .46864 .70865 .46695 .70205 .44295 Mtetra
.628 .51 .699 r
.70205 .44295 .70865 .46695 .72079 .46189 .71418 .43834 Mtetra
.65 .525 .698 r
.71418 .43834 .72079 .46189 .73277 .45374 .72625 .43179 Mtetra
.669 .545 .704 r
.72625 .43179 .73277 .45374 .74463 .4434 .73825 .42387 Mtetra
.686 .568 .717 r
.73825 .42387 .74463 .4434 .75642 .43211 .75024 .41535 Mtetra
.698 .596 .738 r
.75024 .41535 .75642 .43211 .76822 .42104 .76226 .40695 Mtetra
.706 .626 .766 r
.76226 .40695 .76822 .42104 .78011 .41101 .77434 .39919 Mtetra
.707 .658 .798 r
.77434 .39919 .78011 .41101 .79212 .40242 .78652 .39232 Mtetra
.703 .686 .831 r
.78652 .39232 .79212 .40242 .80427 .39525 .79881 .38633 Mtetra
.693 .709 .86 r
.79881 .38633 .80427 .39525 .81656 .38927 .8112 .38108 Mtetra
.683 .724 .881 r
.8112 .38108 .81656 .38927 .82897 .38413 .82369 .37635 Mtetra
.675 .733 .894 r
.82369 .37635 .82897 .38413 .84148 .37953 .83625 .37195 Mtetra
.669 .738 .901 r
.83625 .37195 .84148 .37953 .85407 .37523 .8489 .36774 Mtetra
.666 .74 .905 r
.8489 .36774 .85407 .37523 .86673 .37109 .8616 .36361 Mtetra
.665 .741 .907 r
.8616 .36361 .86673 .37109 .87946 .36701 .87437 .35952 Mtetra
.664 .741 .907 r
.87437 .35952 .87946 .36701 .89224 .36294 .88719 .35543 Mtetra
.664 .741 .908 r
.88719 .35543 .89224 .36294 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.242 .431 .848 r
.32105 .54687 .32751 .55713 .33754 .56444 .33117 .55244 Mtetra
.22 .378 .809 r
.33117 .55244 .33754 .56444 .34759 .57341 .34131 .55943 Mtetra
.269 .372 .784 r
.34131 .55943 .34759 .57341 .35773 .58289 .35153 .56686 Mtetra
.366 .403 .767 r
.35153 .56686 .35773 .58289 .36805 .59127 .36192 .57335 Mtetra
.473 .449 .75 r
.36192 .57335 .36805 .59127 .37862 .59673 .37251 .57737 Mtetra
.565 .493 .733 r
.37251 .57737 .37862 .59673 .38945 .59775 .38336 .57762 Mtetra
.634 .53 .718 r
.38336 .57762 .38945 .59775 .40056 .59351 .39444 .57344 Mtetra
.684 .56 .708 r
.39444 .57344 .40056 .59351 .41186 .58423 .40572 .56498 Mtetra
.719 .584 .703 r
.40572 .56498 .41186 .58423 .4233 .57103 .41711 .5532 Mtetra
.742 .604 .704 r
.41711 .5532 .4233 .57103 .43477 .55571 .42855 .53958 Mtetra
.754 .621 .712 r
.42855 .53958 .43477 .55571 .44621 .54024 .43997 .52573 Mtetra
.756 .635 .726 r
.43997 .52573 .44621 .54024 .45759 .52634 .45134 .51304 Mtetra
.745 .641 .745 r
.45134 .51304 .45759 .52634 .4689 .51519 .46266 .50244 Mtetra
.721 .637 .764 r
.46266 .50244 .4689 .51519 .48016 .5073 .47394 .49431 Mtetra
.685 .619 .776 r
.47394 .49431 .48016 .5073 .4914 .50248 .48521 .48851 Mtetra
.65 .591 .775 r
.48521 .48851 .4914 .50248 .50267 .49996 .49649 .48451 Mtetra
.627 .563 .763 r
.49649 .48451 .50267 .49996 .51398 .49856 .50781 .48151 Mtetra
.621 .545 .748 r
.50781 .48151 .51398 .49856 .52536 .497 .51918 .47867 Mtetra
.626 .538 .735 r
.51918 .47867 .52536 .497 .5368 .49416 .5306 .47529 Mtetra
.638 .541 .729 r
.5306 .47529 .5368 .49416 .54827 .48948 .54207 .47099 Mtetra
.652 .552 .729 r
.54207 .47099 .54827 .48948 .55977 .48299 .55357 .46573 Mtetra
.665 .569 .737 r
.55357 .46573 .55977 .48299 .57127 .47529 .56511 .45983 Mtetra
.676 .591 .753 r
.56511 .45983 .57127 .47529 .5828 .46727 .57667 .45375 Mtetra
.68 .614 .775 r
.57667 .45375 .5828 .46727 .59435 .45982 .58827 .448 Mtetra
.677 .636 .801 r
.58827 .448 .59435 .45982 .60595 .45363 .59992 .44296 Mtetra
.663 .65 .826 r
.59992 .44296 .60595 .45363 .61763 .4491 .61163 .43885 Mtetra
.64 .648 .842 r
.61163 .43885 .61763 .4491 .62942 .44633 .62342 .43574 Mtetra
.616 .631 .843 r
.62342 .43574 .62942 .44633 .64131 .44517 .6353 .43356 Mtetra
.598 .604 .829 r
.6353 .43356 .64131 .44517 .65333 .44522 .64727 .43206 Mtetra
.591 .577 .806 r
.64727 .43206 .65333 .44522 .66544 .44584 .65932 .43088 Mtetra
.594 .556 .781 r
.65932 .43088 .66544 .44584 .67763 .44621 .67143 .42953 Mtetra
.605 .544 .76 r
.67143 .42953 .67763 .44621 .68985 .44548 .68358 .42751 Mtetra
.621 .542 .745 r
.68358 .42751 .68985 .44548 .70205 .44295 .69574 .42442 Mtetra
.638 .548 .736 r
.69574 .42442 .70205 .44295 .71418 .43834 .70789 .42008 Mtetra
.654 .56 .736 r
.70789 .42008 .71418 .43834 .72625 .43179 .72001 .4146 Mtetra
.669 .577 .742 r
.72001 .4146 .72625 .43179 .73825 .42387 .73213 .40829 Mtetra
.682 .598 .756 r
.73213 .40829 .73825 .42387 .75024 .41535 .74426 .40162 Mtetra
.691 .624 .776 r
.74426 .40162 .75024 .41535 .76226 .40695 .75642 .39502 Mtetra
.696 .651 .802 r
.75642 .39502 .76226 .40695 .77434 .39919 .76865 .38879 Mtetra
.695 .678 .829 r
.76865 .38879 .77434 .39919 .78652 .39232 .78096 .38307 Mtetra
.69 .701 .855 r
.78096 .38307 .78652 .39232 .79881 .38633 .79334 .37788 Mtetra
.683 .718 .876 r
.79334 .37788 .79881 .38633 .8112 .38108 .80582 .37311 Mtetra
.676 .729 .89 r
.80582 .37311 .8112 .38108 .82369 .37635 .81837 .36865 Mtetra
.67 .735 .899 r
.81837 .36865 .82369 .37635 .83625 .37195 .83099 .36438 Mtetra
.667 .739 .904 r
.83099 .36438 .83625 .37195 .8489 .36774 .84368 .36021 Mtetra
.665 .74 .906 r
.84368 .36021 .8489 .36774 .8616 .36361 .85643 .35608 Mtetra
.664 .741 .907 r
.85643 .35608 .8616 .36361 .87437 .35952 .86924 .35197 Mtetra
.664 .741 .908 r
.86924 .35197 .87437 .35952 .88719 .35543 .88211 .34786 Mtetra
.88211 .34786 .88719 .35543 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.167 .456 .883 r
.31442 .53885 .32105 .54687 .33117 .55244 .32458 .54375 Mtetra
.085 .383 .844 r
.32458 .54375 .33117 .55244 .34131 .55943 .33476 .54998 Mtetra
.102 .372 .834 r
.33476 .54998 .34131 .55943 .35153 .56686 .34501 .55666 Mtetra
.224 .426 .849 r
.34501 .55666 .35153 .56686 .36192 .57335 .35542 .56246 Mtetra
.4 .511 .855 r
.35542 .56246 .36192 .57335 .37251 .57737 .36604 .56595 Mtetra
.557 .582 .835 r
.36604 .56595 .37251 .57737 .38336 .57762 .3769 .5659 Mtetra
.664 .626 .802 r
.3769 .5659 .38336 .57762 .39444 .57344 .388 .56167 Mtetra
.729 .653 .774 r
.388 .56167 .39444 .57344 .40572 .56498 .39929 .55343 Mtetra
.766 .669 .755 r
.39929 .55343 .40572 .56498 .41711 .5532 .41069 .54206 Mtetra
.786 .681 .748 r
.41069 .54206 .41711 .5532 .42855 .53958 .42215 .52896 Mtetra
.794 .69 .75 r
.42215 .52896 .42855 .53958 .43997 .52573 .43359 .51561 Mtetra
.79 .696 .761 r
.43359 .51561 .43997 .52573 .45134 .51304 .44499 .50326 Mtetra
.775 .698 .778 r
.44499 .50326 .45134 .51304 .46266 .50244 .45634 .4927 Mtetra
.749 .692 .797 r
.45634 .4927 .46266 .50244 .47394 .49431 .46765 .48426 Mtetra
.715 .676 .811 r
.46765 .48426 .47394 .49431 .48521 .48851 .47895 .4778 Mtetra
.681 .652 .814 r
.47895 .4778 .48521 .48851 .49649 .48451 .49026 .4729 Mtetra
.657 .627 .808 r
.49026 .4729 .49649 .48451 .50781 .48151 .5016 .46897 Mtetra
.646 .609 .798 r
.5016 .46897 .50781 .48151 .51918 .47867 .51298 .4654 Mtetra
.646 .599 .788 r
.51298 .4654 .51918 .47867 .5306 .47529 .52441 .46171 Mtetra
.652 .599 .782 r
.52441 .46171 .5306 .47529 .54207 .47099 .53589 .45762 Mtetra
.661 .606 .783 r
.53589 .45762 .54207 .47099 .55357 .46573 .5474 .45305 Mtetra
.67 .62 .79 r
.5474 .45305 .55357 .46573 .56511 .45983 .55896 .44815 Mtetra
.677 .638 .804 r
.55896 .44815 .56511 .45983 .57667 .45375 .57056 .44316 Mtetra
.678 .657 .822 r
.57056 .44316 .57667 .45375 .58827 .448 .5822 .43834 Mtetra
.674 .674 .842 r
.5822 .43834 .58827 .448 .59992 .44296 .59389 .43392 Mtetra
.663 .685 .86 r
.59389 .43392 .59992 .44296 .61163 .43885 .60563 .43003 Mtetra
.648 .684 .87 r
.60563 .43003 .61163 .43885 .62342 .43574 .61745 .42671 Mtetra
.632 .673 .871 r
.61745 .42671 .62342 .43574 .6353 .43356 .62933 .42391 Mtetra
.621 .655 .862 r
.62933 .42391 .6353 .43356 .64727 .43206 .64129 .4215 Mtetra
.616 .634 .846 r
.64129 .4215 .64727 .43206 .65932 .43088 .65331 .41926 Mtetra
.618 .616 .827 r
.65331 .41926 .65932 .43088 .67143 .42953 .66539 .4169 Mtetra
.626 .605 .809 r
.66539 .4169 .67143 .42953 .68358 .42751 .67752 .41411 Mtetra
.638 .6 .795 r
.67752 .41411 .68358 .42751 .69574 .42442 .68967 .41067 Mtetra
.651 .603 .787 r
.68967 .41067 .69574 .42442 .70789 .42008 .70184 .40648 Mtetra
.664 .611 .786 r
.70184 .40648 .70789 .42008 .72001 .4146 .71402 .40158 Mtetra
.675 .625 .791 r
.71402 .40158 .72001 .4146 .73213 .40829 .72621 .39619 Mtetra
.684 .643 .803 r
.72621 .39619 .73213 .40829 .74426 .40162 .73843 .39058 Mtetra
.689 .663 .82 r
.73843 .39058 .74426 .40162 .75642 .39502 .7507 .38499 Mtetra
.69 .684 .839 r
.7507 .38499 .75642 .39502 .76865 .38879 .76302 .37963 Mtetra
.687 .702 .859 r
.76302 .37963 .76865 .38879 .78096 .38307 .77542 .37458 Mtetra
.682 .717 .876 r
.77542 .37458 .78096 .38307 .79334 .37788 .78788 .36983 Mtetra
.676 .728 .889 r
.78788 .36983 .79334 .37788 .80582 .37311 .80042 .36533 Mtetra
.671 .734 .897 r
.80042 .36533 .80582 .37311 .81837 .36865 .81302 .36101 Mtetra
.668 .738 .903 r
.81302 .36101 .81837 .36865 .83099 .36438 .8257 .3568 Mtetra
.666 .74 .905 r
.8257 .3568 .83099 .36438 .84368 .36021 .83843 .35264 Mtetra
.665 .741 .907 r
.83843 .35264 .84368 .36021 .85643 .35608 .85122 .34851 Mtetra
.664 .741 .907 r
.85122 .34851 .85643 .35608 .86924 .35197 .86407 .34437 Mtetra
.664 .741 .908 r
.86407 .34437 .86924 .35197 .88211 .34786 .87698 .34022 Mtetra
.87698 .34022 .88211 .34786 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
0 .336 .778 r
.30757 .5335 .31442 .53885 .32458 .54375 .3177 .53894 Mtetra
0 .157 .594 r
.3177 .53894 .32458 .54375 .33476 .54998 .32785 .54588 Mtetra
.494 0 0 r
.32785 .54588 .33476 .54998 .34501 .55666 .33807 .55332 Mtetra
.464 0 0 r
.33807 .55332 .34501 .55666 .35542 .56246 .34846 .55984 Mtetra
.251 0 0 r
.34846 .55984 .35542 .56246 .36604 .56595 .35908 .56386 Mtetra
.22 .706 .927 r
.35908 .56386 .36604 .56595 .3769 .5659 .36996 .56402 Mtetra
.649 .905 .982 r
.36996 .56402 .3769 .5659 .388 .56167 .38111 .55964 Mtetra
.817 .905 .902 r
.38111 .55964 .388 .56167 .39929 .55343 .39247 .55088 Mtetra
.867 .87 .838 r
.39247 .55088 .39929 .55343 .41069 .54206 .40396 .53876 Mtetra
.877 .841 .806 r
.40396 .53876 .41069 .54206 .42215 .52896 .4155 .52477 Mtetra
.87 .819 .796 r
.4155 .52477 .42215 .52896 .43359 .51561 .42703 .51053 Mtetra
.852 .801 .801 r
.42703 .51053 .43359 .51561 .44499 .50326 .4385 .49735 Mtetra
.824 .785 .815 r
.4385 .49735 .44499 .50326 .45634 .4927 .44991 .48605 Mtetra
.788 .766 .833 r
.44991 .48605 .45634 .4927 .46765 .48426 .46127 .47691 Mtetra
.748 .744 .848 r
.46127 .47691 .46765 .48426 .47895 .4778 .47261 .4698 Mtetra
.71 .719 .857 r
.47261 .4698 .47895 .4778 .49026 .4729 .48396 .4643 Mtetra
.681 .696 .858 r
.48396 .4643 .49026 .4729 .5016 .46897 .49533 .45985 Mtetra
.666 .68 .854 r
.49533 .45985 .5016 .46897 .51298 .4654 .50673 .45592 Mtetra
.662 .671 .848 r
.50673 .45592 .51298 .4654 .52441 .46171 .51818 .45209 Mtetra
.665 .67 .844 r
.51818 .45209 .52441 .46171 .53589 .45762 .52968 .44807 Mtetra
.672 .675 .844 r
.52968 .44807 .53589 .45762 .5474 .45305 .54123 .4438 Mtetra
.678 .684 .849 r
.54123 .4438 .5474 .45305 .55896 .44815 .55281 .43931 Mtetra
.681 .695 .857 r
.55281 .43931 .55896 .44815 .57056 .44316 .56444 .43477 Mtetra
.679 .706 .868 r
.56444 .43477 .57056 .44316 .5822 .43834 .57612 .43034 Mtetra
.673 .715 .879 r
.57612 .43034 .5822 .43834 .59389 .43392 .58784 .42618 Mtetra
.663 .719 .89 r
.58784 .42618 .59389 .43392 .60563 .43003 .59962 .42237 Mtetra
.651 .717 .897 r
.59962 .42237 .60563 .43003 .61745 .42671 .61147 .41897 Mtetra
.638 .711 .9 r
.61147 .41897 .61745 .42671 .62933 .42391 .62337 .41593 Mtetra
.629 .702 .898 r
.62337 .41593 .62933 .42391 .64129 .4215 .63534 .41315 Mtetra
.626 .691 .891 r
.63534 .41315 .64129 .4215 .65331 .41926 .64738 .41048 Mtetra
.63 .683 .881 r
.64738 .41048 .65331 .41926 .66539 .4169 .65947 .4077 Mtetra
.639 .677 .87 r
.65947 .4077 .66539 .4169 .67752 .41411 .67161 .40458 Mtetra
.652 .675 .86 r
.67161 .40458 .67752 .41411 .68967 .41067 .68378 .40096 Mtetra
.665 .678 .852 r
.68378 .40096 .68967 .41067 .70184 .40648 .69598 .39677 Mtetra
.677 .684 .849 r
.69598 .39677 .70184 .40648 .71402 .40158 .7082 .39207 Mtetra
.686 .692 .85 r
.7082 .39207 .71402 .40158 .72621 .39619 .72045 .387 Mtetra
.691 .702 .856 r
.72045 .387 .72621 .39619 .73843 .39058 .73273 .38177 Mtetra
.692 .713 .864 r
.73273 .38177 .73843 .39058 .7507 .38499 .74506 .37657 Mtetra
.69 .722 .874 r
.74506 .37657 .7507 .38499 .76302 .37963 .75744 .37153 Mtetra
.685 .729 .884 r
.75744 .37153 .76302 .37963 .77542 .37458 .76989 .36671 Mtetra
.679 .735 .892 r
.76989 .36671 .77542 .37458 .78788 .36983 .78241 .36212 Mtetra
.674 .738 .899 r
.78241 .36212 .78788 .36983 .80042 .36533 .795 .35771 Mtetra
.67 .74 .903 r
.795 .35771 .80042 .36533 .81302 .36101 .80765 .35342 Mtetra
.667 .741 .905 r
.80765 .35342 .81302 .36101 .8257 .3568 .82036 .34921 Mtetra
.665 .741 .907 r
.82036 .34921 .8257 .3568 .83843 .35264 .83313 .34504 Mtetra
.664 .741 .907 r
.83313 .34504 .83843 .35264 .85122 .34851 .84597 .34088 Mtetra
.664 .741 .908 r
.84597 .34088 .85122 .34851 .86407 .34437 .85886 .33671 Mtetra
.85886 .33671 .86407 .34437 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.585 .011 0 r
.30048 .53081 .30757 .5335 .3177 .53894 .31052 .53805 Mtetra
.715 .193 0 r
.31052 .53805 .3177 .53894 .32785 .54588 .32055 .54714 Mtetra
.735 .256 .107 r
.32055 .54714 .32785 .54588 .33807 .55332 .33067 .55689 Mtetra
.703 .247 .165 r
.33067 .55689 .33807 .55332 .34846 .55984 .34098 .56556 Mtetra
.624 .174 .163 r
.34098 .56556 .34846 .55984 .35908 .56386 .35156 .57118 Mtetra
.469 .016 .091 r
.35156 .57118 .35908 .56386 .36996 .56402 .36248 .57209 Mtetra
.166 0 0 r
.36248 .57209 .36996 .56402 .38111 .55964 .37371 .56742 Mtetra
0 0 0 r
.37371 .56742 .38111 .55964 .39247 .55088 .38521 .55742 Mtetra
.734 .946 .633 r
.38521 .55742 .39247 .55088 .40396 .53876 .39686 .54332 Mtetra
.895 .986 .732 r
.39686 .54332 .40396 .53876 .4155 .52477 .40857 .52701 Mtetra
.93 .958 .774 r
.40857 .52701 .4155 .52477 .42703 .51053 .42025 .51044 Mtetra
.916 .921 .803 r
.42025 .51044 .42703 .51053 .4385 .49735 .43185 .49521 Mtetra
.882 .885 .831 r
.43185 .49521 .4385 .49735 .44991 .48605 .44336 .48228 Mtetra
.835 .851 .858 r
.44336 .48228 .44991 .48605 .46127 .47691 .4548 .47198 Mtetra
.783 .819 .881 r
.4548 .47198 .46127 .47691 .47261 .4698 .46619 .46411 Mtetra
.733 .791 .898 r
.46619 .46411 .47261 .4698 .48396 .4643 .47758 .45816 Mtetra
.695 .77 .909 r
.47758 .45816 .48396 .4643 .49533 .45985 .48898 .45348 Mtetra
.674 .758 .914 r
.48898 .45348 .49533 .45985 .50673 .45592 .50042 .44946 Mtetra
.668 .754 .915 r
.50042 .44946 .50673 .45592 .51818 .45209 .51191 .44561 Mtetra
.672 .756 .913 r
.51191 .44561 .51818 .45209 .52968 .44807 .52344 .4416 Mtetra
.681 .759 .91 r
.52344 .4416 .52968 .44807 .54123 .4438 .53502 .43732 Mtetra
.687 .762 .908 r
.53502 .43732 .54123 .4438 .55281 .43931 .54664 .43281 Mtetra
.689 .762 .907 r
.54664 .43281 .55281 .43931 .56444 .43477 .55831 .42822 Mtetra
.685 .761 .909 r
.55831 .42822 .56444 .43477 .57612 .43034 .57002 .42374 Mtetra
.676 .757 .912 r
.57002 .42374 .57612 .43034 .58784 .42618 .58178 .41955 Mtetra
.662 .753 .918 r
.58178 .41955 .58784 .42618 .59962 .42237 .59359 .41576 Mtetra
.646 .749 .924 r
.59359 .41576 .59962 .42237 .61147 .41897 .60547 .41241 Mtetra
.63 .746 .932 r
.60547 .41241 .61147 .41897 .62337 .41593 .61742 .40947 Mtetra
.617 .746 .938 r
.61742 .40947 .62337 .41593 .63534 .41315 .62943 .40683 Mtetra
.611 .749 .943 r
.62943 .40683 .63534 .41315 .64738 .41048 .64151 .40429 Mtetra
.615 .756 .946 r
.64151 .40429 .64738 .41048 .65947 .4077 .65364 .4016 Mtetra
.629 .766 .945 r
.65364 .4016 .65947 .4077 .67161 .40458 .66582 .39851 Mtetra
.651 .775 .94 r
.66582 .39851 .67161 .40458 .68378 .40096 .67803 .39485 Mtetra
.673 .782 .932 r
.67803 .39485 .68378 .40096 .69598 .39677 .69027 .39055 Mtetra
.692 .785 .923 r
.69027 .39055 .69598 .39677 .7082 .39207 .70252 .38568 Mtetra
.703 .784 .914 r
.70252 .38568 .7082 .39207 .72045 .387 .7148 .38041 Mtetra
.707 .78 .909 r
.7148 .38041 .72045 .387 .73273 .38177 .72711 .37496 Mtetra
.705 .774 .906 r
.72711 .37496 .73273 .38177 .74506 .37657 .73947 .36956 Mtetra
.699 .767 .905 r
.73947 .36956 .74506 .37657 .75744 .37153 .75189 .36436 Mtetra
.69 .76 .905 r
.75189 .36436 .75744 .37153 .76989 .36671 .76437 .3594 Mtetra
.682 .754 .906 r
.76437 .3594 .76989 .36671 .78241 .36212 .77692 .3547 Mtetra
.675 .749 .906 r
.77692 .3547 .78241 .36212 .795 .35771 .78954 .35021 Mtetra
.67 .746 .907 r
.78954 .35021 .795 .35771 .80765 .35342 .80223 .34586 Mtetra
.667 .744 .907 r
.80223 .34586 .80765 .35342 .82036 .34921 .81498 .3416 Mtetra
.665 .742 .908 r
.81498 .3416 .82036 .34921 .83313 .34504 .8278 .33739 Mtetra
.664 .742 .908 r
.8278 .33739 .83313 .34504 .84597 .34088 .84067 .33319 Mtetra
.84067 .33319 .84597 .34088 .85886 .33671 .85361 .32899 Mtetra
.664 .741 .908 r
.85361 .32899 .85886 .33671 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.747 .249 .044 r
.29317 .53034 .30048 .53081 .31052 .53805 .30304 .54042 Mtetra
.775 .34 .217 r
.30304 .54042 .31052 .53805 .32055 .54714 .31288 .55292 Mtetra
.759 .362 .299 r
.31288 .55292 .32055 .54714 .33067 .55689 .32282 .56631 Mtetra
.719 .343 .335 r
.32282 .56631 .33067 .55689 .34098 .56556 .33299 .57837 Mtetra
.653 .288 .34 r
.33299 .57837 .34098 .56556 .35156 .57118 .34351 .58654 Mtetra
.547 .189 .311 r
.34351 .58654 .35156 .57118 .36248 .57209 .35445 .58866 Mtetra
.371 .02 .234 r
.35445 .58866 .36248 .57209 .37371 .56742 .36581 .58361 Mtetra
.079 0 .077 r
.36581 .58361 .37371 .56742 .38521 .55742 .3775 .57169 Mtetra
0 0 0 r
.3775 .57169 .38521 .55742 .39686 .54332 .3894 .55457 Mtetra
.691 .855 .442 r
.3894 .55457 .39686 .54332 .40857 .52701 .40135 .53468 Mtetra
.877 .959 .621 r
.40135 .53468 .40857 .52701 .42025 .51044 .41325 .51456 Mtetra
.931 .971 .727 r
.41325 .51456 .42025 .51044 .43185 .49521 .42503 .49627 Mtetra
.919 .95 .799 r
.42503 .49627 .43185 .49521 .44336 .48228 .43668 .48101 Mtetra
.874 .921 .854 r
.43668 .48101 .44336 .48228 .4548 .47198 .44821 .46918 Mtetra
.812 .891 .9 r
.44821 .46918 .4548 .47198 .46619 .46411 .45968 .46051 Mtetra
.744 .866 .936 r
.45968 .46051 .46619 .46411 .47758 .45816 .47111 .45431 Mtetra
.685 .85 .962 r
.47111 .45431 .47758 .45816 .48898 .45348 .48256 .44973 Mtetra
.647 .846 .977 r
.48256 .44973 .48898 .45348 .50042 .44946 .49404 .44592 Mtetra
.637 .853 .982 r
.49404 .44592 .50042 .44946 .51191 .44561 .50557 .4422 Mtetra
.65 .862 .98 r
.50557 .4422 .51191 .44561 .52344 .4416 .51714 .43814 Mtetra
.674 .867 .972 r
.51714 .43814 .52344 .4416 .53502 .43732 .52877 .43359 Mtetra
.694 .862 .962 r
.52877 .43359 .53502 .43732 .54664 .43281 .54043 .42864 Mtetra
.702 .849 .953 r
.54043 .42864 .54664 .43281 .55831 .42822 .55214 .42354 Mtetra
.698 .83 .946 r
.55214 .42354 .55831 .42822 .57002 .42374 .56388 .41861 Mtetra
.683 .811 .944 r
.56388 .41861 .57002 .42374 .58178 .41955 .57568 .41411 Mtetra
.659 .794 .947 r
.57568 .41411 .58178 .41955 .59359 .41576 .58754 .41026 Mtetra
.629 .784 .956 r
.58754 .41026 .59359 .41576 .60547 .41241 .59946 .40713 Mtetra
.594 .781 .969 r
.59946 .40713 .60547 .41241 .61742 .40947 .61146 .40466 Mtetra
.559 .786 .984 r
.61146 .40466 .61742 .40947 .62943 .40683 .62353 .40265 Mtetra
.529 .8 .995 r
.62353 .40265 .62943 .40683 .64151 .40429 .63568 .40081 Mtetra
.514 .822 1 r
.63568 .40081 .64151 .40429 .65364 .4016 .64788 .39873 Mtetra
.527 .851 .997 r
.64788 .39873 .65364 .4016 .66582 .39851 .66013 .39605 Mtetra
.567 .882 .991 r
.66013 .39605 .66582 .39851 .67803 .39485 .6724 .39247 Mtetra
.623 .906 .984 r
.6724 .39247 .67803 .39485 .69027 .39055 .68468 .38791 Mtetra
.676 .914 .975 r
.68468 .38791 .69027 .39055 .70252 .38568 .69696 .38248 Mtetra
.713 .904 .963 r
.69696 .38248 .70252 .38568 .7148 .38041 .70926 .37646 Mtetra
.729 .881 .951 r
.70926 .37646 .7148 .38041 .72711 .37496 .72157 .37019 Mtetra
.729 .852 .939 r
.72157 .37019 .72711 .37496 .73947 .36956 .73393 .36401 Mtetra
.72 .823 .929 r
.73393 .36401 .73947 .36956 .75189 .36436 .74636 .35813 Mtetra
.706 .797 .921 r
.74636 .35813 .75189 .36436 .76437 .3594 .75885 .35266 Mtetra
.693 .777 .916 r
.75885 .35266 .76437 .3594 .77692 .3547 .77142 .34759 Mtetra
.682 .763 .912 r
.77142 .34759 .77692 .3547 .78954 .35021 .78406 .34285 Mtetra
.674 .753 .91 r
.78406 .34285 .78954 .35021 .80223 .34586 .79678 .33834 Mtetra
.669 .747 .909 r
.79678 .33834 .80223 .34586 .81498 .3416 .80957 .33398 Mtetra
.666 .744 .908 r
.80957 .33398 .81498 .3416 .8278 .33739 .82242 .3297 Mtetra
.665 .743 .908 r
.82242 .3297 .8278 .33739 .84067 .33319 .83534 .32545 Mtetra
.664 .742 .908 r
.83534 .32545 .84067 .33319 .85361 .32899 .84831 .3212 Mtetra
.84831 .3212 .85361 .32899 .8666 .32477 .86134 .31695 Mtetra
.664 .741 .908 r
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31269 Mtetra
.87443 .31269 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.8 .359 .199 r
.28568 .53122 .29317 .53034 .30304 .54042 .29533 .54481 Mtetra
.8 .409 .313 r
.29533 .54481 .30304 .54042 .31288 .55292 .30493 .5615 Mtetra
.777 .413 .369 r
.30493 .5615 .31288 .55292 .32282 .56631 .31462 .5794 Mtetra
.736 .389 .393 r
.31462 .5794 .32282 .56631 .33299 .57837 .3246 .59566 Mtetra
.673 .335 .394 r
.3246 .59566 .33299 .57837 .34351 .58654 .33502 .60701 Mtetra
.573 .243 .37 r
.33502 .60701 .34351 .58654 .35445 .58866 .34598 .61065 Mtetra
.41 .089 .307 r
.34598 .61065 .35445 .58866 .36581 .58361 .35749 .60514 Mtetra
.139 0 .175 r
.35749 .60514 .36581 .58361 .3775 .57169 .36943 .59088 Mtetra
0 0 0 r
.36943 .59088 .3775 .57169 .3894 .55457 .38162 .57003 Mtetra
.38162 .57003 .3894 .55457 .40135 .53468 .39388 .54577 Mtetra
.847 .916 .517 r
.39388 .54577 .40135 .53468 .41325 .51456 .40606 .52138 Mtetra
.929 .96 .65 r
.40606 .52138 .41325 .51456 .42503 .49627 .41806 .49946 Mtetra
.935 .965 .746 r
.41806 .49946 .42503 .49627 .43668 .48101 .42987 .48158 Mtetra
.896 .959 .829 r
.42987 .48158 .43668 .48101 .44821 .46918 .44151 .46821 Mtetra
.822 .95 .904 r
.44151 .46821 .44821 .46918 .45968 .46051 .45305 .45898 Mtetra
.712 .936 .961 r
.45305 .45898 .45968 .46051 .47111 .45431 .46454 .45296 Mtetra
.577 .908 .977 r
.46454 .45296 .47111 .45431 .48256 .44973 .47603 .44896 Mtetra
.461 .874 .946 r
.47603 .44896 .48256 .44973 .49404 .44592 .48755 .44578 Mtetra
.418 .861 .905 r
.48755 .44578 .49404 .44592 .50557 .4422 .49913 .44244 Mtetra
.459 .886 .894 r
.49913 .44244 .50557 .4422 .51714 .43814 .51077 .43831 Mtetra
.552 .928 .913 r
.51077 .43831 .51714 .43814 .52877 .43359 .52245 .43321 Mtetra
.643 .954 .94 r
.52245 .43321 .52877 .43359 .54043 .42864 .53417 .42734 Mtetra
.698 .947 .957 r
.53417 .42734 .54043 .42864 .55214 .42354 .54592 .42117 Mtetra
.711 .918 .964 r
.54592 .42117 .55214 .42354 .56388 .41861 .55771 .41527 Mtetra
.691 .881 .969 r
.55771 .41527 .56388 .41861 .57568 .41411 .56955 .41015 Mtetra
.648 .848 .977 r
.56955 .41015 .57568 .41411 .58754 .41026 .58145 .40614 Mtetra
.584 .822 .989 r
.58145 .40614 .58754 .41026 .59946 .40713 .59342 .40338 Mtetra
.495 .802 .999 r
.59342 .40338 .59946 .40713 .61146 .40466 .60549 .40177 Mtetra
.375 .776 .985 r
.60549 .40177 .61146 .40466 .62353 .40265 .61765 .40098 Mtetra
.238 .732 .915 r
.61765 .40098 .62353 .40265 .63568 .40081 .62989 .40048 Mtetra
.132 .679 .799 r
.62989 .40048 .63568 .40081 .64788 .39873 .6422 .39961 Mtetra
0 0 0 r
.6422 .39961 .64788 .39873 .66013 .39605 .65455 .39773 Mtetra
.65455 .39773 .66013 .39605 .6724 .39247 .6669 .39437 Mtetra
.302 .782 .696 r
.6669 .39437 .6724 .39247 .68468 .38791 .67924 .38938 Mtetra
.475 .889 .781 r
.67924 .38938 .68468 .38791 .69696 .38248 .69154 .38295 Mtetra
.631 .963 .869 r
.69154 .38295 .69696 .38248 .70926 .37646 .70383 .37553 Mtetra
.726 .975 .924 r
.70383 .37553 .70926 .37646 .72157 .37019 .71613 .36774 Mtetra
.759 .942 .942 r
.71613 .36774 .72157 .37019 .73393 .36401 .72846 .3601 Mtetra
.754 .892 .94 r
.72846 .3601 .73393 .36401 .74636 .35813 .74085 .35298 Mtetra
.734 .844 .932 r
.74085 .35298 .74636 .35813 .75885 .35266 .75333 .34656 Mtetra
.713 .807 .923 r
.75333 .34656 .75885 .35266 .77142 .34759 .7659 .34082 Mtetra
.695 .78 .917 r
.7659 .34082 .77142 .34759 .78406 .34285 .77856 .33565 Mtetra
.682 .763 .913 r
.77856 .33565 .78406 .34285 .79678 .33834 .7913 .33087 Mtetra
.673 .752 .91 r
.7913 .33087 .79678 .33834 .80957 .33398 .80411 .32635 Mtetra
.668 .747 .909 r
.80411 .32635 .80957 .33398 .82242 .3297 .817 .32197 Mtetra
.666 .744 .908 r
.817 .32197 .82242 .3297 .83534 .32545 .82995 .31765 Mtetra
.664 .742 .908 r
.82995 .31765 .83534 .32545 .84831 .3212 .84297 .31336 Mtetra
.84297 .31336 .84831 .3212 .86134 .31695 .85604 .30907 Mtetra
.664 .741 .908 r
.85604 .30907 .86134 .31695 .87443 .31269 .86918 .30476 Mtetra
.86918 .30476 .87443 .31269 .88758 .3084 .88237 .30044 Mtetra
.832 .42 .262 r
.27809 .53224 .28568 .53122 .29533 .54481 .2875 .54944 Mtetra
.825 .453 .35 r
.2875 .54944 .29533 .54481 .30493 .5615 .29682 .57046 Mtetra
.801 .45 .393 r
.29682 .57046 .30493 .5615 .31462 .5794 .30624 .59302 Mtetra
.762 .423 .411 r
.30624 .59302 .31462 .5794 .3246 .59566 .316 .61364 Mtetra
.699 .366 .409 r
.316 .61364 .3246 .59566 .33502 .60701 .32631 .62831 Mtetra
.592 .264 .382 r
.32631 .62831 .33502 .60701 .34598 .61065 .33729 .63354 Mtetra
.402 .083 .307 r
.33729 .63354 .34598 .61065 .35749 .60514 .34895 .62754 Mtetra
.062 0 .14 r
.34895 .62754 .35749 .60514 .36943 .59088 .36115 .61084 Mtetra
0 0 0 r
.36115 .61084 .36943 .59088 .38162 .57003 .37367 .58614 Mtetra
.756 .837 .38 r
.37367 .58614 .38162 .57003 .39388 .54577 .38626 .55742 Mtetra
.91 .921 .535 r
.38626 .55742 .39388 .54577 .40606 .52138 .39873 .52875 Mtetra
.955 .944 .635 r
.39873 .52875 .40606 .52138 .41806 .49946 .41097 .50334 Mtetra
.949 .954 .719 r
.41097 .50334 .41806 .49946 .42987 .48158 .42295 .48311 Mtetra
.905 .971 .806 r
.42295 .48311 .42987 .48158 .44151 .46821 .4347 .46867 Mtetra
.794 .985 .894 r
.4347 .46867 .44151 .46821 .45305 .45898 .4463 .45952 Mtetra
.539 .924 .9 r
.4463 .45952 .45305 .45898 .46454 .45296 .45783 .45443 Mtetra
.168 .7 .7 r
.45783 .45443 .46454 .45296 .47603 .44896 .46936 .45177 Mtetra
.061 0 0 r
.46936 .45177 .47603 .44896 .48755 .44578 .48093 .44985 Mtetra
.099 0 0 r
.48093 .44985 .48755 .44578 .49913 .44244 .49257 .44723 Mtetra
.01 0 0 r
.49257 .44723 .49913 .44244 .51077 .43831 .50428 .44304 Mtetra
0 0 0 r
.50428 .44304 .51077 .43831 .52245 .43321 .51604 .43703 Mtetra
.396 .813 .621 r
.51604 .43703 .52245 .43321 .53417 .42734 .52784 .42964 Mtetra
.59 .941 .786 r
.52784 .42964 .53417 .42734 .54592 .42117 .53966 .4217 Mtetra
.685 .977 .895 r
.53966 .4217 .54592 .42117 .55771 .41527 .5515 .41421 Mtetra
.684 .953 .953 r
.5515 .41421 .55771 .41527 .56955 .41015 .56338 .40801 Mtetra
.613 .904 .985 r
.56338 .40801 .56955 .41015 .58145 .40614 .57533 .40369 Mtetra
.472 .84 .991 r
.57533 .40369 .58145 .40614 .59342 .40338 .58736 .40146 Mtetra
.241 .728 .925 r
.58736 .40146 .59342 .40338 .60549 .40177 .59951 .40115 Mtetra
0 .532 .716 r
.59951 .40115 .60549 .40177 .61765 .40098 .61177 .40223 Mtetra
.266 0 0 r
.61177 .40223 .61765 .40098 .62989 .40048 .62415 .40381 Mtetra
.343 0 0 r
.62415 .40381 .62989 .40048 .6422 .39961 .63659 .40483 Mtetra
.323 0 0 r
.63659 .40483 .6422 .39961 .65455 .39773 .64907 .40422 Mtetra
.238 0 0 r
.64907 .40422 .65455 .39773 .6669 .39437 .66153 .40123 Mtetra
.093 0 0 r
.66153 .40123 .6669 .39437 .67924 .38938 .67393 .39559 Mtetra
0 0 0 r
.67393 .39559 .67924 .38938 .69154 .38295 .68626 .38762 Mtetra
.68626 .38762 .69154 .38295 .70383 .37553 .69853 .37808 Mtetra
.623 .938 .717 r
.69853 .37808 .70383 .37553 .71613 .36774 .71077 .36794 Mtetra
.763 .995 .861 r
.71077 .36794 .71613 .36774 .72846 .3601 .72304 .35807 Mtetra
.794 .96 .918 r
.72304 .35807 .72846 .3601 .74085 .35298 .73538 .34908 Mtetra
.775 .898 .93 r
.73538 .34908 .74085 .35298 .75333 .34656 .74782 .34121 Mtetra
.742 .842 .926 r
.74782 .34121 .75333 .34656 .7659 .34082 .76036 .33447 Mtetra
.714 .801 .919 r
.76036 .33447 .7659 .34082 .77856 .33565 .77302 .32863 Mtetra
.693 .774 .914 r
.77302 .32863 .77856 .33565 .7913 .33087 .78578 .32346 Mtetra
.679 .758 .911 r
.78578 .32346 .7913 .33087 .80411 .32635 .79862 .31871 Mtetra
.671 .749 .909 r
.79862 .31871 .80411 .32635 .817 .32197 .81154 .3142 Mtetra
.667 .745 .908 r
.81154 .3142 .817 .32197 .82995 .31765 .82453 .3098 Mtetra
.665 .743 .908 r
.82453 .3098 .82995 .31765 .84297 .31336 .83758 .30546 Mtetra
.664 .742 .908 r
.83758 .30546 .84297 .31336 .85604 .30907 .8507 .30112 Mtetra
.8507 .30112 .85604 .30907 .86918 .30476 .86387 .29678 Mtetra
.664 .741 .908 r
.86387 .29678 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.859 .458 .276 r
.2705 .53209 .27809 .53224 .2875 .54944 .27968 .55235 Mtetra
.854 .486 .353 r
.27968 .55235 .2875 .54944 .29682 .57046 .28875 .57706 Mtetra
.834 .483 .391 r
.28875 .57706 .29682 .57046 .30624 .59302 .29792 .60362 Mtetra
.799 .454 .405 r
.29792 .60362 .30624 .59302 .316 .61364 .30747 .62799 Mtetra
.736 .392 .397 r
.30747 .62799 .316 .61364 .32631 .62831 .31766 .6455 Mtetra
.615 .266 .355 r
.31766 .6455 .32631 .62831 .33729 .63354 .32865 .65208 Mtetra
.341 0 .229 r
.32865 .65208 .33729 .63354 .34895 .62754 .34045 .64562 Mtetra
0 0 0 r
.34045 .64562 .34895 .62754 .36115 .61084 .3529 .6268 Mtetra
.753 .843 .393 r
.3529 .6268 .36115 .61084 .37367 .58614 .36572 .59883 Mtetra
.936 .916 .537 r
.36572 .59883 .37367 .58614 .38626 .55742 .37862 .56638 Mtetra
.977 .916 .605 r
.37862 .56638 .38626 .55742 .39873 .52875 .39137 .53425 Mtetra
.978 .914 .658 r
.39137 .53425 .39873 .52875 .41097 .50334 .40382 .50623 Mtetra
.959 .93 .721 r
.40382 .50623 .41097 .50334 .42295 .48311 .41594 .48459 Mtetra
.906 .969 .807 r
.41594 .48459 .42295 .48311 .4347 .46867 .42778 .47006 Mtetra
.702 .984 .875 r
.42778 .47006 .4347 .46867 .4463 .45952 .43942 .46202 Mtetra
0 0 0 r
.43942 .46202 .4463 .45952 .45783 .45443 .45097 .45892 Mtetra
.309 0 0 r
.45097 .45892 .45783 .45443 .46936 .45177 .46252 .45859 Mtetra
.41 0 .01 r
.46252 .45859 .46936 .45177 .48093 .44985 .47413 .45871 Mtetra
.38 0 .067 r
.47413 .45871 .48093 .44985 .49257 .44723 .48585 .45728 Mtetra
.277 0 .045 r
.48585 .45728 .49257 .44723 .50428 .44304 .49765 .45303 Mtetra
.107 0 0 r
.49765 .45303 .50428 .44304 .51604 .43703 .50952 .44573 Mtetra
0 0 0 r
.50952 .44573 .51604 .43703 .52784 .42964 .52142 .43612 Mtetra
.52142 .43612 .52784 .42964 .53966 .4217 .53332 .42559 Mtetra
.582 .912 .677 r
.53332 .42559 .53966 .4217 .5515 .41421 .54523 .41574 Mtetra
.632 .962 .837 r
.54523 .41574 .5515 .41421 .56338 .40801 .55717 .40793 Mtetra
.526 .916 .915 r
.55717 .40793 .56338 .40801 .57533 .40369 .56917 .40308 Mtetra
.246 .755 .867 r
.56917 .40308 .57533 .40369 .58736 .40146 .58127 .4015 Mtetra
.156 0 0 r
.58127 .4015 .58736 .40146 .59951 .40115 .59351 .40293 Mtetra
.438 0 0 r
.59351 .40293 .59951 .40115 .61177 .40223 .6059 .40654 Mtetra
.538 .021 0 r
.6059 .40654 .61177 .40223 .62415 .40381 .61842 .41099 Mtetra
.538 .071 .093 r
.61842 .41099 .62415 .40381 .63659 .40483 .63104 .41461 Mtetra
.485 .054 .146 r
.63104 .41461 .63659 .40483 .64907 .40422 .64369 .41578 Mtetra
.392 0 .148 r
.64369 .41578 .64907 .40422 .66153 .40123 .65628 .41331 Mtetra
.257 0 .103 r
.65628 .41331 .66153 .40123 .67393 .39559 .66876 .40679 Mtetra
.069 0 0 r
.66876 .40679 .67393 .39559 .68626 .38762 .6811 .39671 Mtetra
0 0 0 r
.6811 .39671 .68626 .38762 .69853 .37808 .69333 .38426 Mtetra
.69333 .38426 .69853 .37808 .71077 .36794 .7055 .37091 Mtetra
.725 .962 .691 r
.7055 .37091 .71077 .36794 .72304 .35807 .71768 .358 Mtetra
.826 .997 .846 r
.71768 .358 .72304 .35807 .73538 .34908 .72994 .34645 Mtetra
.821 .945 .905 r
.72994 .34645 .73538 .34908 .74782 .34121 .74231 .33663 Mtetra
.78 .878 .918 r
.74231 .33663 .74782 .34121 .76036 .33447 .75481 .32852 Mtetra
.739 .824 .917 r
.75481 .32852 .76036 .33447 .77302 .32863 .76746 .32182 Mtetra
.707 .787 .914 r
.76746 .32182 .77302 .32863 .78578 .32346 .78022 .31612 Mtetra
.687 .765 .911 r
.78022 .31612 .78578 .32346 .79862 .31871 .79308 .31107 Mtetra
.675 .753 .909 r
.79308 .31107 .79862 .31871 .81154 .3142 .80603 .30639 Mtetra
.669 .746 .908 r
.80603 .30639 .81154 .3142 .82453 .3098 .81906 .3019 Mtetra
.666 .743 .908 r
.81906 .3019 .82453 .3098 .83758 .30546 .83215 .29749 Mtetra
.664 .742 .908 r
.83215 .29749 .83758 .30546 .8507 .30112 .84531 .29311 Mtetra
.84531 .29311 .8507 .30112 .86387 .29678 .85853 .28872 Mtetra
.664 .741 .908 r
.85853 .28872 .86387 .29678 .87711 .29242 .87181 .28433 Mtetra
.884 .482 .255 r
.263 .52965 .2705 .53209 .27968 .55235 .27202 .55189 Mtetra
.886 .513 .329 r
.27202 .55189 .27968 .55235 .28875 .57706 .28089 .579 Mtetra
.874 .513 .362 r
.28089 .579 .28875 .57706 .29792 .60362 .28987 .60814 Mtetra
.848 .487 .368 r
.28987 .60814 .29792 .60362 .30747 .62799 .29927 .63492 Mtetra
.794 .418 .344 r
.29927 .63492 .30747 .62799 .31766 .6455 .30937 .65423 Mtetra
.647 .234 .246 r
.30937 .65423 .31766 .6455 .32865 .65208 .32037 .66161 Mtetra
.055 0 0 r
.32037 .66161 .32865 .65208 .34045 .64562 .33228 .65479 Mtetra
.837 .951 .601 r
.33228 .65479 .34045 .64562 .3529 .6268 .34492 .63454 Mtetra
.977 .921 .639 r
.34492 .63454 .3529 .6268 .36572 .59883 .35798 .60446 Mtetra
.985 .877 .64 r
.35798 .60446 .36572 .59883 .37862 .56638 .37111 .56974 Mtetra
.978 .857 .653 r
.37111 .56974 .37862 .56638 .39137 .53425 .38406 .53571 Mtetra
.967 .859 .681 r
.38406 .53571 .39137 .53425 .40382 .50623 .39666 .5066 Mtetra
.949 .887 .736 r
.39666 .5066 .40382 .50623 .41594 .48459 .40888 .48497 Mtetra
.892 .957 .835 r
.40888 .48497 .41594 .48459 .42778 .47006 .42075 .47167 Mtetra
.498 .906 .833 r
.42075 .47167 .42778 .47006 .43942 .46202 .4324 .46601 Mtetra
.313 0 0 r
.4324 .46601 .43942 .46202 .45097 .45892 .44394 .46609 Mtetra
.532 .072 .107 r
.44394 .46609 .45097 .45892 .46252 .45859 .45549 .46916 Mtetra
.546 .133 .21 r
.45549 .46916 .46252 .45859 .47413 .45871 .46714 .47217 Mtetra
.487 .101 .234 r
.46714 .47217 .47413 .45871 .48585 .45728 .47893 .4724 Mtetra
.374 .007 .206 r
.47893 .4724 .48585 .45728 .49765 .45303 .49085 .46813 Mtetra
.204 0 .125 r
.49085 .46813 .49765 .45303 .50952 .44573 .50285 .45914 Mtetra
0 0 0 r
.50285 .45914 .50952 .44573 .52142 .43612 .51488 .44661 Mtetra
.51488 .44661 .52142 .43612 .53332 .42559 .52689 .43268 Mtetra
.52689 .43268 .53332 .42559 .54523 .41574 .53888 .41972 Mtetra
.575 .907 .668 r
.53888 .41972 .54523 .41574 .55717 .40793 .55089 .40976 Mtetra
.419 .859 .768 r
.55089 .40976 .55717 .40793 .56917 .40308 .56295 .40411 Mtetra
.01 0 0 r
.56295 .40411 .56917 .40308 .58127 .4015 .57513 .40323 Mtetra
.431 0 0 r
.57513 .40323 .58127 .4015 .59351 .40293 .58747 .40676 Mtetra
.608 .096 .005 r
.58747 .40676 .59351 .40293 .6059 .40654 .59999 .41347 Mtetra
.644 .188 .153 r
.59999 .41347 .6059 .40654 .61842 .41099 .61269 .42144 Mtetra
.617 .2 .228 r
.61269 .42144 .61842 .41099 .63104 .41461 .6255 .4283 Mtetra
.552 .163 .257 r
.6255 .4283 .63104 .41461 .64369 .41578 .63833 .43168 Mtetra
.452 .085 .251 r
.63833 .43168 .64369 .41578 .65628 .41331 .65108 .42986 Mtetra
.31 0 .208 r
.65108 .42986 .65628 .41331 .66876 .40679 .66365 .42225 Mtetra
.117 0 .115 r
.66365 .42225 .66876 .40679 .6811 .39671 .67602 .40956 Mtetra
0 0 0 r
.67602 .40956 .6811 .39671 .69333 .38426 .6882 .3935 Mtetra
.6882 .3935 .69333 .38426 .7055 .37091 .70028 .37619 Mtetra
.711 .907 .546 r
.70028 .37619 .7055 .37091 .71768 .358 .71235 .35956 Mtetra
.853 .995 .753 r
.71235 .35956 .71768 .358 .72994 .34645 .7245 .34487 Mtetra
.865 .969 .859 r
.7245 .34487 .72994 .34645 .74231 .33663 .73679 .33268 Mtetra
.82 .904 .899 r
.73679 .33268 .74231 .33663 .75481 .32852 .74924 .32292 Mtetra
.767 .843 .91 r
.74924 .32292 .75481 .32852 .76746 .32182 .76186 .31515 Mtetra
.725 .8 .911 r
.76186 .31515 .76746 .32182 .78022 .31612 .77462 .30882 Mtetra
.697 .772 .91 r
.77462 .30882 .78022 .31612 .79308 .31107 .7875 .30341 Mtetra
.68 .756 .909 r
.7875 .30341 .79308 .31107 .80603 .30639 .80048 .29853 Mtetra
.671 .748 .908 r
.80048 .29853 .80603 .30639 .81906 .3019 .81355 .29393 Mtetra
.667 .744 .908 r
.81355 .29393 .81906 .3019 .83215 .29749 .82668 .28946 Mtetra
.665 .742 .908 r
.82668 .28946 .83215 .29749 .84531 .29311 .83988 .28503 Mtetra
.664 .742 .908 r
.83988 .28503 .84531 .29311 .85853 .28872 .85314 .2806 Mtetra
.664 .741 .908 r
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.9 .49 .197 r
.25565 .52436 .263 .52965 .27202 .55189 .26459 .54724 Mtetra
.914 .53 .271 r
.26459 .54724 .27202 .55189 .28089 .579 .27337 .57509 Mtetra
.913 .537 .295 r
.27337 .57509 .28089 .579 .28987 .60814 .28226 .605 Mtetra
.902 .514 .277 r
.28226 .605 .28987 .60814 .29927 .63492 .29158 .63244 Mtetra
.863 .429 .18 r
.29158 .63244 .29927 .63492 .30937 .65423 .30164 .65216 Mtetra
.581 .005 0 r
.30164 .65216 .30937 .65423 .32037 .66161 .31266 .6596 Mtetra
.756 .918 .945 r
.31266 .6596 .32037 .66161 .33228 .65479 .32464 .65249 Mtetra
.917 .838 .751 r
.32464 .65249 .33228 .65479 .34492 .63454 .33739 .63169 Mtetra
.933 .795 .686 r
.33739 .63169 .34492 .63454 .35798 .60446 .35058 .60099 Mtetra
.934 .779 .665 r
.35058 .60099 .35798 .60446 .37111 .56974 .36385 .56584 Mtetra
.931 .777 .668 r
.36385 .56584 .37111 .56974 .38406 .53571 .3769 .53181 Mtetra
.926 .79 .691 r
.3769 .53181 .38406 .53571 .39666 .5066 .38957 .50338 Mtetra
.913 .829 .749 r
.38957 .50338 .39666 .5066 .40888 .48497 .40181 .48333 Mtetra
.85 .923 .878 r
.40181 .48333 .40888 .48497 .42075 .47167 .41366 .4726 Mtetra
.168 .705 .743 r
.41366 .4726 .42075 .47167 .4324 .46601 .42526 .47047 Mtetra
.551 .047 .011 r
.42526 .47047 .4324 .46601 .44394 .46609 .43675 .47475 Mtetra
.64 .218 .225 r
.43675 .47475 .44394 .46609 .45549 .46916 .44828 .48209 Mtetra
.616 .231 .29 r
.44828 .48209 .45549 .46916 .46714 .47217 .45995 .48864 Mtetra
.539 .175 .298 r
.45995 .48864 .46714 .47217 .47893 .4724 .47182 .49089 Mtetra
.407 .062 .263 r
.47182 .49089 .47893 .4724 .49085 .46813 .48386 .48665 Mtetra
.209 0 .176 r
.48386 .48665 .49085 .46813 .50285 .45914 .49602 .4757 Mtetra
0 0 .023 r
.49602 .4757 .50285 .45914 .51488 .44661 .5082 .45976 Mtetra
0 0 0 r
.5082 .45976 .51488 .44661 .52689 .43268 .52034 .44184 Mtetra
.52034 .44184 .52689 .43268 .53888 .41972 .53244 .42524 Mtetra
.609 .893 .589 r
.53244 .42524 .53888 .41972 .55089 .40976 .54453 .41272 Mtetra
.396 .829 .68 r
.54453 .41272 .55089 .40976 .56295 .40411 .55666 .40605 Mtetra
.158 0 0 r
.55666 .40605 .56295 .40411 .57513 .40323 .56891 .40585 Mtetra
.561 .017 0 r
.56891 .40585 .57513 .40323 .58747 .40676 .58135 .41159 Mtetra
.688 .212 .115 r
.58135 .41159 .58747 .40676 .59999 .41347 .59401 .42168 Mtetra
.703 .273 .224 r
.59401 .42168 .59999 .41347 .61269 .42144 .60688 .43353 Mtetra
.666 .267 .279 r
.60688 .43353 .61269 .42144 .6255 .4283 .61989 .44397 Mtetra
.592 .216 .298 r
.61989 .44397 .6255 .4283 .63833 .43168 .63292 .44982 Mtetra
.477 .122 .285 r
.63292 .44982 .63833 .43168 .65108 .42986 .64583 .44873 Mtetra
.309 0 .233 r
.64583 .44873 .65108 .42986 .66365 .42225 .65851 .43991 Mtetra
.076 0 .13 r
.65851 .43991 .66365 .42225 .67602 .40956 .6709 .42432 Mtetra
0 0 0 r
.6709 .42432 .67602 .40956 .6882 .3935 .68304 .40426 Mtetra
.68304 .40426 .6882 .3935 .70028 .37619 .69503 .38259 Mtetra
.775 .902 .503 r
.69503 .38259 .70028 .37619 .71235 .35956 .70698 .36186 Mtetra
.895 .979 .694 r
.70698 .36186 .71235 .35956 .7245 .34487 .71902 .34376 Mtetra
.904 .967 .812 r
.71902 .34376 .7245 .34487 .73679 .33268 .73123 .32898 Mtetra
.855 .913 .871 r
.73123 .32898 .73679 .33268 .74924 .32292 .74362 .31743 Mtetra
.793 .854 .895 r
.74362 .31743 .74924 .32292 .76186 .31515 .75622 .30851 Mtetra
.742 .807 .904 r
.75622 .30851 .76186 .31515 .77462 .30882 .76898 .3015 Mtetra
.706 .777 .907 r
.76898 .3015 .77462 .30882 .7875 .30341 .78188 .29571 Mtetra
.685 .759 .907 r
.78188 .29571 .7875 .30341 .80048 .29853 .79489 .29062 Mtetra
.673 .749 .908 r
.79489 .29062 .80048 .29853 .81355 .29393 .80799 .28591 Mtetra
.668 .745 .908 r
.80799 .28591 .81355 .29393 .82668 .28946 .82116 .28136 Mtetra
.665 .743 .908 r
.82116 .28136 .82668 .28946 .83988 .28503 .8344 .27688 Mtetra
.664 .742 .908 r
.8344 .27688 .83988 .28503 .85314 .2806 .8477 .27241 Mtetra
.664 .741 .908 r
.8477 .27241 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.894 .474 .104 r
.24846 .51645 .25565 .52436 .26459 .54724 .2574 .53868 Mtetra
.92 .525 .175 r
.2574 .53868 .26459 .54724 .27337 .57509 .26619 .56573 Mtetra
.924 .535 .176 r
.26619 .56573 .27337 .57509 .28226 .605 .27509 .59468 Mtetra
.9 .497 .087 r
.27509 .59468 .28226 .605 .29158 .63244 .28442 .62111 Mtetra
.716 .292 0 r
.28442 .62111 .29158 .63244 .30164 .65216 .29451 .63989 Mtetra
.202 .391 .827 r
.29451 .63989 .30164 .65216 .31266 .6596 .30556 .64664 Mtetra
.707 .644 .783 r
.30556 .64664 .31266 .6596 .32464 .65249 .31757 .63923 Mtetra
.82 .68 .709 r
.31757 .63923 .32464 .65249 .33739 .63169 .33035 .61865 Mtetra
.857 .69 .674 r
.33035 .61865 .33739 .63169 .35058 .60099 .34357 .58869 Mtetra
.873 .698 .663 r
.34357 .58869 .35058 .60099 .36385 .56584 .35686 .55479 Mtetra
.878 .709 .668 r
.35686 .55479 .36385 .56584 .3769 .53181 .36992 .52248 Mtetra
.876 .727 .693 r
.36992 .52248 .3769 .53181 .38957 .50338 .38257 .49627 Mtetra
.86 .765 .756 r
.38257 .49627 .38957 .50338 .40181 .48333 .39476 .47903 Mtetra
.766 .849 .914 r
.39476 .47903 .40181 .48333 .41366 .4726 .40655 .47181 Mtetra
.171 0 0 r
.40655 .47181 .41366 .4726 .42526 .47047 .41806 .47388 Mtetra
.684 .199 .092 r
.41806 .47388 .42526 .47047 .43675 .47475 .42946 .48279 Mtetra
.714 .3 .261 r
.42946 .48279 .43675 .47475 .44828 .48209 .44094 .49469 Mtetra
.67 .286 .311 r
.44094 .49469 .44828 .48209 .45995 .48864 .45261 .50498 Mtetra
.574 .208 .309 r
.45261 .50498 .45995 .48864 .47182 .49089 .46454 .50936 Mtetra
.405 .056 .257 r
.46454 .50936 .47182 .49089 .48386 .48665 .47671 .50518 Mtetra
.13 0 .134 r
.47671 .50518 .48386 .48665 .49602 .4757 .48903 .49224 Mtetra
0 0 0 r
.48903 .49224 .49602 .4757 .5082 .45976 .50138 .47283 Mtetra
.50138 .47283 .5082 .45976 .52034 .44184 .51368 .45087 Mtetra
.736 .886 .484 r
.51368 .45087 .52034 .44184 .53244 .42524 .5259 .43057 Mtetra
.757 .954 .64 r
.5259 .43057 .53244 .42524 .54453 .41272 .53808 .41543 Mtetra
.519 .902 .74 r
.53808 .41543 .54453 .41272 .55666 .40605 .55028 .40765 Mtetra
.177 0 0 r
.55028 .40765 .55666 .40605 .56891 .40585 .5626 .40798 Mtetra
.624 .088 0 r
.5626 .40798 .56891 .40585 .58135 .41159 .57512 .41577 Mtetra
.74 .272 .137 r
.57512 .41577 .58135 .41159 .59401 .42168 .5879 .42903 Mtetra
.75 .321 .234 r
.5879 .42903 .59401 .42168 .60688 .43353 .60092 .44459 Mtetra
.71 .306 .279 r
.60092 .44459 .60688 .43353 .61989 .44397 .61411 .45846 Mtetra
.627 .24 .291 r
.61411 .45846 .61989 .44397 .63292 .44982 .62732 .46669 Mtetra
.482 .115 .265 r
.62732 .46669 .63292 .44982 .64583 .44873 .64039 .46631 Mtetra
.249 0 .187 r
.64039 .46631 .64583 .44873 .65851 .43991 .65317 .45631 Mtetra
0 0 .038 r
.65317 .45631 .65851 .43991 .6709 .42432 .6656 .43791 Mtetra
0 0 0 r
.6656 .43791 .6709 .42432 .68304 .40426 .67772 .41401 Mtetra
.734 .831 .377 r
.67772 .41401 .68304 .40426 .69503 .38259 .68963 .38817 Mtetra
.891 .93 .55 r
.68963 .38817 .69503 .38259 .70698 .36186 .7015 .36354 Mtetra
.946 .958 .682 r
.7015 .36354 .70698 .36186 .71902 .34376 .71345 .34219 Mtetra
.932 .942 .779 r
.71345 .34219 .71902 .34376 .73123 .32898 .72559 .32497 Mtetra
.879 .9 .842 r
.72559 .32497 .73123 .32898 .74362 .31743 .73794 .31172 Mtetra
.813 .851 .877 r
.73794 .31172 .74362 .31743 .75622 .30851 .75052 .30173 Mtetra
.756 .809 .894 r
.75052 .30173 .75622 .30851 .76898 .3015 .76328 .29407 Mtetra
.715 .778 .902 r
.76328 .29407 .76898 .3015 .78188 .29571 .7762 .28792 Mtetra
.69 .76 .905 r
.7762 .28792 .78188 .29571 .79489 .29062 .78924 .28264 Mtetra
.676 .75 .907 r
.78924 .28264 .79489 .29062 .80799 .28591 .80238 .27781 Mtetra
.669 .745 .907 r
.80238 .27781 .80799 .28591 .82116 .28136 .81559 .27319 Mtetra
.666 .743 .908 r
.81559 .27319 .82116 .28136 .8344 .27688 .82887 .26866 Mtetra
.664 .742 .908 r
.82887 .26866 .8344 .27688 .8477 .27241 .84222 .26416 Mtetra
.664 .741 .908 r
.84222 .26416 .8477 .27241 .86107 .26794 .85563 .25964 Mtetra
.859 .432 0 r
.24135 .5068 .24846 .51645 .2574 .53868 .25037 .52758 Mtetra
.891 .491 .059 r
.25037 .52758 .2574 .53868 .26619 .56573 .25924 .55281 Mtetra
.878 .49 .024 r
.25924 .55281 .26619 .56573 .27509 .59468 .26823 .57967 Mtetra
.758 .389 0 r
.26823 .57967 .27509 .59468 .28442 .62111 .27765 .60394 Mtetra
0 0 .566 r
.27765 .60394 .28442 .62111 .29451 .63989 .28781 .62081 Mtetra
.41 .414 .753 r
.28781 .62081 .29451 .63989 .30556 .64664 .2989 .62625 Mtetra
.674 .561 .719 r
.2989 .62625 .30556 .64664 .31757 .63923 .31093 .61844 Mtetra
.769 .61 .683 r
.31093 .61844 .31757 .63923 .33035 .61865 .3237 .59847 Mtetra
.81 .634 .664 r
.3237 .59847 .33035 .61865 .34357 .58869 .33688 .57006 Mtetra
.83 .649 .658 r
.33688 .57006 .34357 .58869 .35686 .55479 .35011 .53843 Mtetra
.837 .663 .667 r
.35011 .53843 .35686 .55479 .36992 .52248 .36309 .50887 Mtetra
.832 .68 .694 r
.36309 .50887 .36992 .52248 .38257 .49627 .37566 .48574 Mtetra
.802 .706 .759 r
.37566 .48574 .38257 .49627 .39476 .47903 .38776 .47186 Mtetra
.65 .74 .915 r
.38776 .47186 .39476 .47903 .40655 .47181 .39944 .46833 Mtetra
.357 0 0 r
.39944 .46833 .40655 .47181 .41806 .47388 .41085 .47441 Mtetra
.767 .281 .076 r
.41085 .47441 .41806 .47388 .42946 .48279 .42216 .48751 Mtetra
.779 .352 .237 r
.42216 .48751 .42946 .48279 .44094 .49469 .43356 .50342 Mtetra
.727 .321 .279 r
.43356 .50342 .44094 .49469 .45261 .50498 .44521 .51693 Mtetra
.607 .207 .258 r
.44521 .51693 .45261 .50498 .46454 .50936 .4572 .52316 Mtetra
.347 0 .152 r
.4572 .52316 .46454 .50936 .47671 .50518 .46948 .51905 Mtetra
0 0 0 r
.46948 .51905 .47671 .50518 .48903 .49224 .48195 .50445 Mtetra
.641 .805 .368 r
.48195 .50445 .48903 .49224 .50138 .47283 .49446 .48216 Mtetra
.865 .922 .528 r
.49446 .48216 .50138 .47283 .51368 .45087 .50692 .45683 Mtetra
.928 .955 .63 r
.50692 .45683 .51368 .45087 .5259 .43057 .51926 .43345 Mtetra
.909 .983 .739 r
.51926 .43345 .5259 .43057 .53808 .41543 .53152 .41609 Mtetra
.728 .988 .882 r
.53152 .41609 .53808 .41543 .55028 .40765 .54379 .40731 Mtetra
.037 0 0 r
.54379 .40731 .55028 .40765 .5626 .40798 .55617 .40796 Mtetra
.64 .084 0 r
.55617 .40796 .5626 .40798 .57512 .41577 .56876 .41727 Mtetra
.778 .295 .08 r
.56876 .41727 .57512 .41577 .5879 .42903 .58162 .43296 Mtetra
.795 .347 .181 r
.58162 .43296 .5879 .42903 .60092 .44459 .59475 .45137 Mtetra
.76 .326 .22 r
.59475 .45137 .60092 .44459 .61411 .45846 .60806 .46793 Mtetra
.666 .235 .215 r
.60806 .46793 .61411 .45846 .62732 .46669 .62141 .478 Mtetra
.456 .033 .148 r
.62141 .478 .62732 .46669 .64039 .46631 .63461 .47817 Mtetra
.031 0 0 r
.63461 .47817 .64039 .46631 .65317 .45631 .64749 .46724 Mtetra
0 0 0 r
.64749 .46724 .65317 .45631 .6656 .43791 .65997 .44663 Mtetra
.82 .881 .45 r
.65997 .44663 .6656 .43791 .67772 .41401 .67209 .41971 Mtetra
.939 .92 .548 r
.67209 .41971 .67772 .41401 .68963 .38817 .68399 .39061 Mtetra
.974 .923 .623 r
.68399 .39061 .68963 .38817 .7015 .36354 .69581 .36295 Mtetra
.97 .915 .693 r
.69581 .36295 .7015 .36354 .71345 .34219 .70772 .33909 Mtetra
.939 .898 .76 r
.70772 .33909 .71345 .34219 .72559 .32497 .71983 .31998 Mtetra
.885 .87 .817 r
.71983 .31998 .72559 .32497 .73794 .31172 .73217 .30543 Mtetra
.823 .836 .858 r
.73217 .30543 .73794 .31172 .75052 .30173 .74474 .2946 Mtetra
.765 .802 .883 r
.74474 .2946 .75052 .30173 .76328 .29407 .75753 .28644 Mtetra
.721 .776 .896 r
.75753 .28644 .76328 .29407 .7762 .28792 .77047 .28 Mtetra
.693 .759 .903 r
.77047 .28 .7762 .28792 .78924 .28264 .78355 .27455 Mtetra
.677 .75 .906 r
.78355 .27455 .78924 .28264 .80238 .27781 .79672 .26963 Mtetra
.669 .745 .907 r
.79672 .26963 .80238 .27781 .81559 .27319 .80998 .26495 Mtetra
.666 .743 .908 r
.80998 .26495 .81559 .27319 .82887 .26866 .8233 .26038 Mtetra
.664 .742 .908 r
.8233 .26038 .82887 .26866 .84222 .26416 .83669 .25583 Mtetra
.664 .741 .908 r
.83669 .25583 .84222 .26416 .85563 .25964 .85015 .25127 Mtetra
.818 .385 0 r
.23424 .49675 .24135 .5068 .25037 .52758 .24335 .51589 Mtetra
.854 .449 0 r
.24335 .51589 .25037 .52758 .25924 .55281 .25233 .53905 Mtetra
.82 .434 0 r
.25233 .53905 .25924 .55281 .26823 .57967 .26143 .56351 Mtetra
0 0 .308 r
.26143 .56351 .26823 .57967 .27765 .60394 .27097 .58525 Mtetra
0 .122 .65 r
.27097 .58525 .27765 .60394 .28781 .62081 .28123 .59983 Mtetra
.47 .434 .736 r
.28123 .59983 .28781 .62081 .2989 .62625 .2924 .60363 Mtetra
.672 .547 .704 r
.2924 .60363 .2989 .62625 .31093 .61844 .30446 .59518 Mtetra
.753 .591 .676 r
.30446 .59518 .31093 .61844 .3237 .59847 .31721 .57572 Mtetra
.791 .614 .661 r
.31721 .57572 .3237 .59847 .33688 .57006 .33033 .54891 Mtetra
.809 .629 .659 r
.33033 .54891 .33688 .57006 .35011 .53843 .34347 .51968 Mtetra
.813 .641 .669 r
.34347 .51968 .35011 .53843 .36309 .50887 .35636 .49298 Mtetra
.801 .652 .697 r
.35636 .49298 .36309 .50887 .37566 .48574 .36882 .47288 Mtetra
.753 .662 .76 r
.36882 .47288 .37566 .48574 .38776 .47186 .38082 .46204 Mtetra
.547 .631 .886 r
.38082 .46204 .38776 .47186 .39944 .46833 .39241 .46148 Mtetra
0 .149 .643 r
.39241 .46148 .39944 .46833 .41085 .47441 .40371 .47048 Mtetra
.794 .298 0 r
.40371 .47048 .41085 .47441 .42216 .48751 .41493 .48639 Mtetra
.833 .374 .12 r
.41493 .48639 .42216 .48751 .43356 .50342 .42627 .50484 Mtetra
.791 .327 .139 r
.42627 .50484 .43356 .50342 .44521 .51693 .4379 .52034 Mtetra
.63 .122 .021 r
.4379 .52034 .44521 .51693 .4572 .52316 .44991 .52769 Mtetra
0 0 0 r
.44991 .52769 .4572 .52316 .46948 .51905 .46227 .52365 Mtetra
.826 .986 .713 r
.46227 .52365 .46948 .51905 .48195 .50445 .47485 .5081 Mtetra
.962 .942 .687 r
.47485 .5081 .48195 .50445 .49446 .48216 .4875 .48415 Mtetra
.976 .9 .678 r
.4875 .48415 .49446 .48216 .50692 .45683 .50008 .45687 Mtetra
.965 .887 .703 r
.50008 .45687 .50692 .45683 .51926 .43345 .51254 .43169 Mtetra
.932 .895 .77 r
.51254 .43169 .51926 .43345 .53152 .41609 .52489 .41302 Mtetra
.815 .91 .905 r
.52489 .41302 .53152 .41609 .54379 .40731 .53722 .40358 Mtetra
.271 .697 .967 r
.53722 .40358 .54379 .40731 .55617 .40796 .54964 .40428 Mtetra
.537 0 0 r
.54964 .40428 .55617 .40796 .56876 .41727 .56226 .41429 Mtetra
.77 .262 0 r
.56226 .41429 .56876 .41727 .58162 .43296 .57515 .43116 Mtetra
.816 .333 .016 r
.57515 .43116 .58162 .43296 .59475 .45137 .58832 .45099 Mtetra
.795 .304 .025 r
.58832 .45099 .59475 .45137 .60806 .46793 .6017 .46889 Mtetra
.679 .142 0 r
.6017 .46889 .60806 .46793 .62141 .478 .61512 .47989 Mtetra
.193 0 0 r
.61512 .47989 .62141 .478 .63461 .47817 .6284 .48032 Mtetra
.721 .982 .781 r
.6284 .48032 .63461 .47817 .64749 .46724 .64135 .46889 Mtetra
.95 .956 .702 r
.64135 .46889 .64749 .46724 .65997 .44663 .6539 .44713 Mtetra
.981 .9 .655 r
.6539 .44713 .65997 .44663 .67209 .41971 .66608 .41866 Mtetra
.982 .87 .647 r
.66608 .41866 .67209 .41971 .68399 .39061 .67801 .38788 Mtetra
.973 .856 .665 r
.67801 .38788 .68399 .39061 .69581 .36295 .68986 .35866 Mtetra
.953 .848 .7 r
.68986 .35866 .69581 .36295 .70772 .33909 .70179 .33351 Mtetra
.922 .841 .748 r
.70179 .33351 .70772 .33909 .71983 .31998 .71392 .31343 Mtetra
.876 .83 .798 r
.71392 .31343 .71983 .31998 .73217 .30543 .72628 .2982 Mtetra
.82 .811 .842 r
.72628 .2982 .73217 .30543 .74474 .2946 .73889 .28693 Mtetra
.766 .789 .872 r
.73889 .28693 .74474 .2946 .75753 .28644 .7517 .2785 Mtetra
.723 .77 .89 r
.7517 .2785 .75753 .28644 .77047 .28 .76469 .27189 Mtetra
.694 .756 .9 r
.76469 .27189 .77047 .28 .78355 .27455 .7778 .26635 Mtetra
.678 .748 .904 r
.7778 .26635 .78355 .27455 .79672 .26963 .79102 .26136 Mtetra
.67 .744 .906 r
.79102 .26136 .79672 .26963 .80998 .26495 .80431 .25664 Mtetra
.666 .743 .907 r
.80431 .25664 .80998 .26495 .8233 .26038 .81768 .25201 Mtetra
.664 .742 .908 r
.81768 .25201 .8233 .26038 .83669 .25583 .83112 .24742 Mtetra
.664 .741 .908 r
.83112 .24742 .83669 .25583 .85015 .25127 .84462 .24283 Mtetra
.812 .366 0 r
.227 .48751 .23424 .49675 .24335 .51589 .23618 .50544 Mtetra
.854 .434 0 r
.23618 .50544 .24335 .51589 .25233 .53905 .24524 .52701 Mtetra
.829 .422 0 r
.24524 .52701 .25233 .53905 .26143 .56351 .25444 .54953 Mtetra
.645 .269 0 r
.25444 .54953 .26143 .56351 .27097 .58525 .26409 .56912 Mtetra
0 .16 .687 r
.26409 .56912 .27097 .58525 .28123 .59983 .27446 .58159 Mtetra
.5 .477 .763 r
.27446 .58159 .28123 .59983 .2924 .60363 .28572 .58368 Mtetra
.693 .574 .717 r
.28572 .58368 .2924 .60363 .30446 .59518 .29784 .57427 Mtetra
.766 .608 .683 r
.29784 .57427 .30446 .59518 .31721 .57572 .31061 .55483 Mtetra
.797 .624 .667 r
.31061 .55483 .31721 .57572 .33033 .54891 .3237 .52901 Mtetra
.81 .634 .665 r
.3237 .52901 .33033 .54891 .34347 .51968 .33679 .5015 Mtetra
.808 .642 .676 r
.33679 .5015 .34347 .51968 .35636 .49298 .34961 .47694 Mtetra
.788 .646 .705 r
.34961 .47694 .35636 .49298 .36882 .47288 .362 .45903 Mtetra
.722 .638 .764 r
.362 .45903 .36882 .47288 .38082 .46204 .37393 .45014 Mtetra
.499 .564 .853 r
.37393 .45014 .38082 .46204 .39241 .46148 .38545 .45116 Mtetra
0 .194 .723 r
.38545 .45116 .39241 .46148 .40371 .47048 .39671 .4613 Mtetra
.655 .199 0 r
.39671 .4613 .40371 .47048 .41493 .48639 .40788 .47798 Mtetra
.753 .29 0 r
.40788 .47798 .41493 .48639 .42627 .50484 .41918 .49689 Mtetra
.657 .176 0 r
.41918 .49689 .42627 .50484 .4379 .52034 .43079 .51263 Mtetra
0 .318 .797 r
.43079 .51263 .4379 .52034 .44991 .52769 .44281 .5201 Mtetra
.657 .744 .914 r
.44281 .5201 .44991 .52769 .46227 .52365 .4552 .51609 Mtetra
.85 .777 .78 r
.4552 .51609 .46227 .52365 .47485 .5081 .46784 .50054 Mtetra
.896 .769 .714 r
.46784 .50054 .47485 .5081 .4875 .48415 .48057 .47656 Mtetra
.908 .766 .693 r
.48057 .47656 .4875 .48415 .50008 .45687 .49324 .44924 Mtetra
.902 .768 .704 r
.49324 .44924 .50008 .45687 .51254 .43169 .50577 .42399 Mtetra
.874 .775 .749 r
.50577 .42399 .51254 .43169 .52489 .41302 .51819 .40521 Mtetra
.784 .77 .841 r
.51819 .40521 .52489 .41302 .53722 .40358 .53056 .39562 Mtetra
.469 .654 .94 r
.53056 .39562 .53722 .40358 .54964 .40428 .54301 .3961 Mtetra
0 .228 .737 r
.54301 .3961 .54964 .40428 .56226 .41429 .55563 .40582 Mtetra
.561 .102 0 r
.55563 .40582 .56226 .41429 .57515 .43116 .56851 .42237 Mtetra
.64 .188 0 r
.56851 .42237 .57515 .43116 .58832 .45099 .58167 .44186 Mtetra
0 0 .448 r
.58167 .44186 .58832 .45099 .6017 .46889 .59503 .45943 Mtetra
0 .236 .751 r
.59503 .45943 .6017 .46889 .61512 .47989 .60845 .47021 Mtetra
.5 .631 .911 r
.60845 .47021 .61512 .47989 .6284 .48032 .62175 .47054 Mtetra
.79 .745 .812 r
.62175 .47054 .6284 .48032 .64135 .46889 .63475 .45917 Mtetra
.879 .76 .726 r
.63475 .45917 .64135 .46889 .6539 .44713 .64738 .43758 Mtetra
.911 .761 .683 r
.64738 .43758 .6539 .44713 .66608 .41866 .65965 .40935 Mtetra
.921 .763 .669 r
.65965 .40935 .66608 .41866 .67801 .38788 .67167 .37885 Mtetra
.921 .769 .676 r
.67167 .37885 .67801 .38788 .68986 .35866 .68362 .34989 Mtetra
.91 .776 .7 r
.68362 .34989 .68986 .35866 .70179 .33351 .69564 .32494 Mtetra
.889 .783 .739 r
.69564 .32494 .70179 .33351 .71392 .31343 .70784 .305 Mtetra
.853 .786 .785 r
.70784 .305 .71392 .31343 .72628 .2982 .72028 .28986 Mtetra
.808 .783 .829 r
.72028 .28986 .72628 .2982 .73889 .28693 .73294 .27863 Mtetra
.76 .773 .863 r
.73294 .27863 .73889 .28693 .7517 .2785 .74581 .27021 Mtetra
.721 .762 .885 r
.74581 .27021 .7517 .2785 .76469 .27189 .75884 .26359 Mtetra
.693 .752 .897 r
.75884 .26359 .76469 .27189 .7778 .26635 .772 .25802 Mtetra
.678 .747 .903 r
.772 .25802 .7778 .26635 .79102 .26136 .78526 .253 Mtetra
.67 .744 .906 r
.78526 .253 .79102 .26136 .80431 .25664 .7986 .24824 Mtetra
.666 .742 .907 r
.7986 .24824 .80431 .25664 .81768 .25201 .81201 .24358 Mtetra
.664 .742 .908 r
.81201 .24358 .81768 .25201 .83112 .24742 .82549 .23895 Mtetra
.664 .741 .908 r
.82549 .23895 .83112 .24742 .84462 .24283 .83904 .23432 Mtetra
.836 .379 0 r
.21957 .47978 .227 .48751 .23618 .50544 .22876 .49726 Mtetra
.877 .444 .054 r
.22876 .49726 .23618 .50544 .24524 .52701 .23784 .51813 Mtetra
.873 .443 .034 r
.23784 .51813 .24524 .52701 .25444 .54953 .24708 .53964 Mtetra
.781 .335 0 r
.24708 .53964 .25444 .54953 .26409 .56912 .2568 .5579 Mtetra
0 .116 .665 r
.2568 .5579 .26409 .56912 .27446 .58159 .26726 .5688 Mtetra
.52 .562 .839 r
.26726 .5688 .27446 .58159 .28572 .58368 .27863 .56933 Mtetra
.739 .642 .752 r
.27863 .56933 .28572 .58368 .29784 .57427 .29085 .55868 Mtetra
.802 .656 .701 r
.29085 .55868 .29784 .57427 .31061 .55483 .3037 .5386 Mtetra
.824 .66 .679 r
.3037 .5386 .31061 .55483 .3237 .52901 .31684 .51282 Mtetra
.829 .662 .675 r
.31684 .51282 .3237 .52901 .33679 .5015 .32994 .48596 Mtetra
.821 .663 .687 r
.32994 .48596 .33679 .5015 .34961 .47694 .34275 .46236 Mtetra
.793 .66 .716 r
.34275 .46236 .34961 .47694 .362 .45903 .35514 .44536 Mtetra
.717 .639 .77 r
.35514 .44536 .362 .45903 .37393 .45014 .36706 .437 Mtetra
.51 .548 .831 r
.36706 .437 .37393 .45014 .38545 .45116 .37859 .43791 Mtetra
.081 .29 .774 r
.37859 .43791 .38545 .45116 .39671 .4613 .38985 .44723 Mtetra
0 .031 .602 r
.38985 .44723 .39671 .4613 .40788 .47798 .40104 .46248 Mtetra
0 0 .572 r
.40104 .46248 .40788 .47798 .41918 .49689 .41235 .47968 Mtetra
0 .164 .684 r
.41235 .47968 .41918 .49689 .43079 .51263 .42396 .49388 Mtetra
.373 .399 .759 r
.42396 .49388 .43079 .51263 .44281 .5201 .43597 .50042 Mtetra
.623 .541 .741 r
.43597 .50042 .44281 .5201 .4552 .51609 .44835 .4964 Mtetra
.743 .606 .706 r
.44835 .4964 .4552 .51609 .46784 .50054 .46099 .48178 Mtetra
.8 .64 .683 r
.46099 .48178 .46784 .50054 .48057 .47656 .47373 .45941 Mtetra
.826 .661 .677 r
.47373 .45941 .48057 .47656 .49324 .44924 .48642 .43395 Mtetra
.832 .675 .689 r
.48642 .43395 .49324 .44924 .50577 .42399 .49899 .41037 Mtetra
.811 .683 .723 r
.49899 .41037 .50577 .42399 .51819 .40521 .51145 .39271 Mtetra
.737 .671 .785 r
.51145 .39271 .51819 .40521 .53056 .39562 .52385 .38349 Mtetra
.533 .584 .852 r
.52385 .38349 .53056 .39562 .54301 .3961 .53631 .38353 Mtetra
.156 .355 .81 r
.53631 .38353 .54301 .3961 .55563 .40582 .54891 .39206 Mtetra
0 .133 .679 r
.54891 .39206 .55563 .40582 .56851 .42237 .56175 .40683 Mtetra
0 .081 .638 r
.56175 .40683 .56851 .42237 .58167 .44186 .57483 .42428 Mtetra
.018 .184 .694 r
.57483 .42428 .58167 .44186 .59503 .45943 .58811 .43995 Mtetra
.31 .357 .749 r
.58811 .43995 .59503 .45943 .60845 .47021 .60147 .44939 Mtetra
.554 .496 .746 r
.60147 .44939 .60845 .47021 .62175 .47054 .61473 .44928 Mtetra
.7 .578 .715 r
.61473 .44928 .62175 .47054 .63475 .45917 .62776 .43847 Mtetra
.78 .624 .686 r
.62776 .43847 .63475 .45917 .64738 .43758 .64046 .41833 Mtetra
.825 .653 .669 r
.64046 .41833 .64738 .43758 .65965 .40935 .65285 .3921 Mtetra
.85 .676 .666 r
.65285 .3921 .65965 .40935 .67167 .37885 .66502 .36375 Mtetra
.861 .695 .675 r
.66502 .36375 .67167 .37885 .68362 .34989 .67713 .33679 Mtetra
.861 .715 .698 r
.67713 .33679 .68362 .34989 .69564 .32494 .6893 .31349 Mtetra
.85 .733 .734 r
.6893 .31349 .69564 .32494 .70784 .305 .70162 .29477 Mtetra
.825 .748 .778 r
.70162 .29477 .70784 .305 .72028 .28986 .71416 .28045 Mtetra
.789 .755 .822 r
.71416 .28045 .72028 .28986 .73294 .27863 .72691 .26972 Mtetra
.749 .756 .858 r
.72691 .26972 .73294 .27863 .74581 .27021 .73984 .26158 Mtetra
.715 .752 .882 r
.73984 .26158 .74581 .27021 .75884 .26359 .75293 .25509 Mtetra
.691 .748 .895 r
.75293 .25509 .75884 .26359 .772 .25802 .76614 .24957 Mtetra
.676 .745 .902 r
.76614 .24957 .772 .25802 .78526 .253 .77945 .24454 Mtetra
.669 .743 .906 r
.77945 .24454 .78526 .253 .7986 .24824 .79284 .23976 Mtetra
.666 .742 .907 r
.79284 .23976 .7986 .24824 .81201 .24358 .8063 .23507 Mtetra
.664 .742 .908 r
.8063 .23507 .81201 .24358 .82549 .23895 .81982 .2304 Mtetra
.664 .741 .908 r
.81982 .2304 .82549 .23895 .83904 .23432 .83341 .22573 Mtetra
.856 .402 .045 r
.21195 .47351 .21957 .47978 .22876 .49726 .22109 .49124 Mtetra
.887 .458 .136 r
.22109 .49124 .22876 .49726 .23784 .51813 .23012 .51228 Mtetra
.887 .458 .139 r
.23012 .51228 .23784 .51813 .24708 .53964 .23934 .53371 Mtetra
.845 .383 .027 r
.23934 .53371 .24708 .53964 .2568 .5579 .24907 .55148 Mtetra
.544 .014 0 r
.24907 .55148 .2568 .5579 .26726 .5688 .2596 .56145 Mtetra
.522 .696 .948 r
.2596 .56145 .26726 .5688 .27863 .56933 .27108 .56072 Mtetra
.801 .739 .795 r
.27108 .56072 .27863 .56933 .29085 .55868 .28344 .54871 Mtetra
.851 .721 .72 r
.28344 .54871 .29085 .55868 .3037 .5386 .29642 .52746 Mtetra
.862 .709 .691 r
.29642 .52746 .3037 .5386 .31684 .51282 .30968 .50091 Mtetra
.86 .702 .685 r
.30968 .50091 .31684 .51282 .32994 .48596 .32287 .47368 Mtetra
.845 .696 .697 r
.32287 .47368 .32994 .48596 .34275 .46236 .33575 .44991 Mtetra
.812 .687 .727 r
.33575 .44991 .34275 .46236 .35514 .44536 .34819 .43262 Mtetra
.734 .658 .775 r
.34819 .43262 .35514 .44536 .36706 .437 .36018 .42347 Mtetra
.561 .569 .819 r
.36018 .42347 .36706 .437 .37859 .43791 .37178 .4228 Mtetra
.285 .387 .792 r
.37178 .4228 .37859 .43791 .38985 .44723 .38312 .42965 Mtetra
.097 .23 .713 r
.38312 .42965 .38985 .44723 .40104 .46248 .39439 .44173 Mtetra
.124 .212 .685 r
.39439 .44173 .40104 .46248 .41235 .47968 .40576 .45553 Mtetra
.291 .297 .694 r
.40576 .45553 .41235 .47968 .42396 .49388 .4174 .4668 Mtetra
.471 .399 .694 r
.4174 .4668 .42396 .49388 .43597 .50042 .42939 .47161 Mtetra
.603 .478 .683 r
.42939 .47161 .43597 .50042 .44835 .4964 .44173 .46754 Mtetra
.687 .532 .67 r
.44173 .46754 .44835 .4964 .46099 .48178 .45431 .45454 Mtetra
.738 .569 .663 r
.45431 .45454 .46099 .48178 .47373 .45941 .467 .435 Mtetra
.767 .595 .665 r
.467 .435 .47373 .45941 .48642 .43395 .47967 .41282 Mtetra
.777 .615 .679 r
.47967 .41282 .48642 .43395 .49899 .41037 .49223 .39222 Mtetra
.762 .625 .708 r
.49223 .39222 .49899 .41037 .51145 .39271 .5047 .37663 Mtetra
.702 .613 .754 r
.5047 .37663 .51145 .39271 .52385 .38349 .51712 .3682 Mtetra
.558 .548 .799 r
.51712 .3682 .52385 .38349 .53631 .38353 .52957 .36764 Mtetra
.334 .41 .791 r
.52957 .36764 .53631 .38353 .54891 .39206 .54214 .37429 Mtetra
.168 .279 .735 r
.54214 .37429 .54891 .39206 .56175 .40683 .55491 .38622 Mtetra
.162 .245 .703 r
.55491 .38622 .56175 .40683 .57483 .42428 .56789 .40037 Mtetra
.279 .296 .7 r
.56789 .40037 .57483 .42428 .58811 .43995 .58105 .41298 Mtetra
.431 .379 .699 r
.58105 .41298 .58811 .43995 .60147 .44939 .5943 .42027 Mtetra
.562 .454 .688 r
.5943 .42027 .60147 .44939 .61473 .44928 .6075 .41946 Mtetra
.657 .511 .674 r
.6075 .41946 .61473 .44928 .62776 .43847 .62051 .40961 Mtetra
.721 .554 .663 r
.62051 .40961 .62776 .43847 .64046 .41833 .63328 .39183 Mtetra
.765 .588 .659 r
.63328 .39183 .64046 .41833 .65285 .3921 .6458 .36887 Mtetra
.793 .617 .662 r
.6458 .36887 .65285 .3921 .66502 .36375 .65816 .34407 Mtetra
.81 .643 .675 r
.65816 .34407 .66502 .36375 .67713 .33679 .67045 .3204 Mtetra
.817 .669 .699 r
.67045 .3204 .67713 .33679 .6893 .31349 .6828 .29983 Mtetra
.812 .695 .735 r
.6828 .29983 .6893 .31349 .70162 .29477 .69529 .28314 Mtetra
.796 .717 .778 r
.69529 .28314 .70162 .29477 .71416 .28045 .70795 .2702 Mtetra
.768 .733 .821 r
.70795 .2702 .71416 .28045 .72691 .26972 .7208 .26033 Mtetra
.736 .742 .857 r
.7208 .26033 .72691 .26972 .73984 .26158 .73382 .25267 Mtetra
.707 .744 .881 r
.73382 .25267 .73984 .26158 .75293 .25509 .74697 .24642 Mtetra
.687 .744 .895 r
.74697 .24642 .75293 .25509 .76614 .24957 .76023 .241 Mtetra
.674 .743 .902 r
.76023 .241 .76614 .24957 .77945 .24454 .77359 .236 Mtetra
.668 .742 .905 r
.77359 .236 .77945 .24454 .79284 .23976 .78702 .2312 Mtetra
.665 .742 .907 r
.78702 .2312 .79284 .23976 .8063 .23507 .80053 .22648 Mtetra
.664 .741 .908 r
.80053 .22648 .8063 .23507 .81982 .2304 .8141 .22177 Mtetra
.8141 .22177 .81982 .2304 .83341 .22573 .82774 .21706 Mtetra
.866 .419 .09 r
.20419 .46789 .21195 .47351 .22109 .49124 .21325 .48621 Mtetra
.889 .468 .177 r
.21325 .48621 .22109 .49124 .23012 .51228 .2222 .50784 Mtetra
.886 .465 .186 r
.2222 .50784 .23012 .51228 .23934 .53371 .23135 .52968 Mtetra
.851 .396 .102 r
.23135 .52968 .23934 .53371 .24907 .55148 .24106 .54749 Mtetra
.638 .082 0 r
.24106 .54749 .24907 .55148 .2596 .56145 .25163 .55702 Mtetra
.51 .791 .996 r
.25163 .55702 .2596 .56145 .27108 .56072 .26321 .55536 Mtetra
.844 .808 .815 r
.26321 .55536 .27108 .56072 .28344 .54871 .27572 .54214 Mtetra
.885 .767 .726 r
.27572 .54214 .28344 .54871 .29642 .52746 .28886 .51964 Mtetra
.89 .745 .695 r
.28886 .51964 .29642 .52746 .30968 .50091 .30227 .49201 Mtetra
.884 .733 .689 r
.30227 .49201 .30968 .50091 .32287 .47368 .3156 .46391 Mtetra
.868 .725 .702 r
.3156 .46391 .32287 .47368 .33575 .44991 .3286 .43934 Mtetra
.834 .714 .732 r
.3286 .43934 .33575 .44991 .34819 .43262 .34115 .42102 Mtetra
.763 .684 .776 r
.34115 .42102 .34819 .43262 .36018 .42347 .35325 .41026 Mtetra
.624 .606 .811 r
.35325 .41026 .36018 .42347 .37178 .4228 .36497 .40712 Mtetra
.437 .47 .796 r
.36497 .40712 .37178 .4228 .38312 .42965 .37644 .41055 Mtetra
.316 .355 .744 r
.37644 .41055 .38312 .42965 .39439 .44173 .38784 .4185 Mtetra
.326 .325 .705 r
.38784 .4185 .39439 .44173 .40576 .45553 .39931 .428 Mtetra
.413 .357 .686 r
.39931 .428 .40576 .45553 .4174 .4668 .411 .43564 Mtetra
.513 .409 .673 r
.411 .43564 .4174 .4668 .42939 .47161 .42298 .43832 Mtetra
.596 .458 .663 r
.42298 .43832 .42939 .47161 .44173 .46754 .43526 .43415 Mtetra
.658 .499 .657 r
.43526 .43415 .44173 .46754 .45431 .45454 .44776 .42308 Mtetra
.7 .531 .656 r
.44776 .42308 .45431 .45454 .467 .435 .46036 .40694 Mtetra
.727 .558 .662 r
.46036 .40694 .467 .435 .47967 .41282 .47296 .38874 Mtetra
.737 .579 .678 r
.47296 .38874 .47967 .41282 .49223 .39222 .48549 .37176 Mtetra
.726 .591 .705 r
.48549 .37176 .49223 .39222 .5047 .37663 .49794 .35871 Mtetra
.678 .584 .743 r
.49794 .35871 .5047 .37663 .51712 .3682 .51036 .35128 Mtetra
.574 .538 .777 r
.51036 .35128 .51712 .3682 .52957 .36764 .52281 .35005 Mtetra
.43 .447 .776 r
.52281 .35005 .52957 .36764 .54214 .37429 .53535 .35449 Mtetra
.329 .361 .743 r
.53535 .35449 .54214 .37429 .55491 .38622 .54805 .36305 Mtetra
.326 .331 .712 r
.54805 .36305 .55491 .38622 .56789 .40037 .56093 .37331 Mtetra
.394 .352 .693 r
.56093 .37331 .56789 .40037 .58105 .41298 .57396 .38229 Mtetra
.485 .396 .68 r
.57396 .38229 .58105 .41298 .5943 .42027 .58709 .38705 Mtetra
.568 .442 .668 r
.58709 .38705 .5943 .42027 .6075 .41946 .60019 .38543 Mtetra
.635 .484 .66 r
.60019 .38543 .6075 .41946 .62051 .40961 .61319 .37669 Mtetra
.687 .52 .655 r
.61319 .37669 .62051 .40961 .63328 .39183 .62601 .3617 Mtetra
.725 .552 .656 r
.62601 .3617 .63328 .39183 .6458 .36887 .63866 .34261 Mtetra
.752 .581 .664 r
.63866 .34261 .6458 .36887 .65816 .34407 .65119 .32202 Mtetra
.771 .61 .68 r
.65119 .32202 .65816 .34407 .67045 .3204 .66368 .3023 Mtetra
.78 .64 .706 r
.66368 .3023 .67045 .3204 .6828 .29983 .67622 .28499 Mtetra
.78 .669 .742 r
.67622 .28499 .6828 .29983 .69529 .28314 .68887 .27075 Mtetra
.768 .697 .784 r
.68887 .27075 .69529 .28314 .70795 .2702 .70167 .25948 Mtetra
.747 .718 .825 r
.70167 .25948 .70795 .2702 .7208 .26033 .71463 .25065 Mtetra
.721 .732 .859 r
.71463 .25065 .7208 .26033 .73382 .25267 .72773 .24358 Mtetra
.698 .738 .882 r
.72773 .24358 .73382 .25267 .74697 .24642 .74095 .23763 Mtetra
.682 .741 .895 r
.74095 .23763 .74697 .24642 .76023 .241 .75427 .23233 Mtetra
.672 .741 .902 r
.75427 .23233 .76023 .241 .77359 .236 .76768 .22737 Mtetra
.667 .741 .906 r
.76768 .22737 .77359 .236 .78702 .2312 .78116 .22256 Mtetra
.665 .741 .907 r
.78116 .22256 .78702 .2312 .80053 .22648 .79471 .21781 Mtetra
.664 .741 .908 r
.79471 .21781 .80053 .22648 .8141 .22177 .80833 .21307 Mtetra
.80833 .21307 .8141 .22177 .82774 .21706 .82201 .20832 Mtetra
.868 .423 .083 r
.19641 .46174 .20419 .46789 .21325 .48621 .20541 .48043 Mtetra
.893 .471 .164 r
.20541 .48043 .21325 .48621 .2222 .50784 .21429 .50242 Mtetra
.89 .467 .165 r
.21429 .50242 .2222 .50784 .23135 .52968 .22339 .52449 Mtetra
.85 .389 .061 r
.22339 .52449 .23135 .52968 .24106 .54749 .23308 .54232 Mtetra
.57 .017 0 r
.23308 .54232 .24106 .54749 .25163 .55702 .24367 .55156 Mtetra
.569 .778 .977 r
.24367 .55156 .25163 .55702 .26321 .55536 .25533 .54934 Mtetra
.844 .793 .802 r
.25533 .54934 .26321 .55536 .27572 .54214 .26794 .53539 Mtetra
.886 .764 .722 r
.26794 .53539 .27572 .54214 .28886 .51964 .28122 .51213 Mtetra
.895 .749 .692 r
.28122 .51213 .28886 .51964 .30227 .49201 .29476 .48381 Mtetra
.892 .741 .688 r
.29476 .48381 .30227 .49201 .3156 .46391 .30822 .45509 Mtetra
.879 .737 .701 r
.30822 .45509 .3156 .46391 .3286 .43934 .32134 .42979 Mtetra
.85 .73 .731 r
.32134 .42979 .3286 .43934 .34115 .42102 .334 .41038 Mtetra
.791 .707 .772 r
.334 .41038 .34115 .42102 .35325 .41026 .34623 .39785 Mtetra
.683 .645 .805 r
.34623 .39785 .35325 .41026 .36497 .40712 .3581 .39206 Mtetra
.546 .541 .8 r
.3581 .39206 .36497 .40712 .37644 .41055 .36974 .3919 Mtetra
.451 .444 .76 r
.36974 .3919 .37644 .41055 .38784 .4185 .38128 .39558 Mtetra
.44 .401 .719 r
.38128 .39558 .38784 .4185 .39931 .428 .39288 .40071 Mtetra
.482 .404 .691 r
.39288 .40071 .39931 .428 .411 .43564 .40464 .4047 Mtetra
.542 .428 .673 r
.40464 .4047 .411 .43564 .42298 .43832 .41662 .40523 Mtetra
.597 .458 .663 r
.41662 .40523 .42298 .43832 .43526 .43415 .42885 .40093 Mtetra
.642 .488 .659 r
.42885 .40093 .43526 .43415 .44776 .42308 .44125 .39173 Mtetra
.677 .516 .66 r
.44125 .39173 .44776 .42308 .46036 .40694 .45375 .37893 Mtetra
.7 .541 .669 r
.45375 .37893 .46036 .40694 .47296 .38874 .46626 .36466 Mtetra
.71 .563 .686 r
.46626 .36466 .47296 .38874 .48549 .37176 .47874 .35129 Mtetra
.701 .578 .713 r
.47874 .35129 .48549 .37176 .49794 .35871 .49118 .34077 Mtetra
.663 .577 .748 r
.49118 .34077 .49794 .35871 .51036 .35128 .50359 .33436 Mtetra
.587 .545 .775 r
.50359 .33436 .51036 .35128 .52281 .35005 .51603 .33247 Mtetra
.489 .483 .777 r
.51603 .33247 .52281 .35005 .53535 .35449 .52855 .33471 Mtetra
.424 .421 .752 r
.52855 .33471 .53535 .35449 .54805 .36305 .5412 .33993 Mtetra
.42 .392 .722 r
.5412 .33993 .54805 .36305 .56093 .37331 .55399 .34632 Mtetra
.461 .396 .698 r
.55399 .34632 .56093 .37331 .57396 .38229 .56691 .35172 Mtetra
.519 .418 .68 r
.56691 .35172 .57396 .38229 .58709 .38705 .57992 .35397 Mtetra
.576 .447 .668 r
.57992 .35397 .58709 .38705 .60019 .38543 .59294 .35152 Mtetra
.626 .477 .661 r
.59294 .35152 .60019 .38543 .61319 .37669 .60591 .34385 Mtetra
.667 .507 .659 r
.60591 .34385 .61319 .37669 .62601 .3617 .61877 .3316 Mtetra
.699 .535 .662 r
.61877 .3316 .62601 .3617 .63866 .34261 .63153 .31631 Mtetra
.724 .564 .673 r
.63153 .31631 .63866 .34261 .65119 .32202 .64421 .29989 Mtetra
.741 .594 .692 r
.64421 .29989 .65119 .32202 .66368 .3023 .65688 .28409 Mtetra
.751 .625 .72 r
.65688 .28409 .66368 .3023 .67622 .28499 .6696 .27005 Mtetra
.752 .657 .756 r
.6696 .27005 .67622 .28499 .68887 .27075 .68242 .25826 Mtetra
.744 .687 .797 r
.68242 .25826 .68887 .27075 .70167 .25948 .69535 .24868 Mtetra
.727 .711 .835 r
.69535 .24868 .70167 .25948 .71463 .25065 .70842 .24089 Mtetra
.707 .726 .865 r
.70842 .24089 .71463 .25065 .72773 .24358 .7216 .23441 Mtetra
.69 .735 .885 r
.7216 .23441 .72773 .24358 .74095 .23763 .73488 .22876 Mtetra
.677 .739 .897 r
.73488 .22876 .74095 .23763 .75427 .23233 .74826 .22359 Mtetra
.67 .74 .903 r
.74826 .22359 .75427 .23233 .76768 .22737 .76172 .21867 Mtetra
.666 .741 .906 r
.76172 .21867 .76768 .22737 .78116 .22256 .77525 .21385 Mtetra
.665 .741 .907 r
.77525 .21385 .78116 .22256 .79471 .21781 .78884 .20907 Mtetra
.664 .741 .908 r
.78884 .20907 .79471 .21781 .80833 .21307 .80251 .2043 Mtetra
.80251 .2043 .80833 .21307 .82201 .20832 .81623 .19951 Mtetra
.853 .402 .008 r
.18873 .454 .19641 .46174 .20541 .48043 .19773 .4723 Mtetra
.885 .457 .082 r
.19773 .4723 .20541 .48043 .21429 .50242 .20661 .49381 Mtetra
.878 .447 .055 r
.20661 .49381 .21429 .50242 .22339 .52449 .21571 .51535 Mtetra
.785 .325 0 r
.21571 .51535 .22339 .52449 .23308 .54232 .22541 .53265 Mtetra
0 .196 .718 r
.22541 .53265 .23308 .54232 .24367 .55156 .23603 .54146 Mtetra
.608 .662 .877 r
.23603 .54146 .24367 .55156 .25533 .54934 .24772 .53901 Mtetra
.803 .714 .767 r
.24772 .53901 .25533 .54934 .26794 .53539 .26038 .52506 Mtetra
.856 .72 .711 r
.26038 .52506 .26794 .53539 .28122 .51213 .2737 .50205 Mtetra
.875 .722 .689 r
.2737 .50205 .28122 .51213 .29476 .48381 .2873 .47409 Mtetra
.88 .726 .687 r
.2873 .47409 .29476 .48381 .30822 .45509 .30082 .44567 Mtetra
.874 .731 .7 r
.30082 .44567 .30822 .45509 .32134 .42979 .31401 .42038 Mtetra
.854 .733 .729 r
.31401 .42038 .32134 .42979 .334 .41038 .32677 .40041 Mtetra
.81 .722 .768 r
.32677 .40041 .334 .41038 .34623 .39785 .33912 .38654 Mtetra
.729 .68 .803 r
.33912 .38654 .34623 .39785 .3581 .39206 .35113 .37847 Mtetra
.626 .603 .808 r
.35113 .37847 .3581 .39206 .36974 .3919 .36293 .37516 Mtetra
.545 .521 .779 r
.36293 .37516 .36974 .3919 .38128 .39558 .37463 .37507 Mtetra
.519 .469 .741 r
.37463 .37507 .38128 .39558 .39288 .40071 .38635 .37636 Mtetra
.534 .452 .709 r
.38635 .37636 .39288 .40071 .40464 .4047 .39819 .37713 Mtetra
.567 .458 .689 r
.39819 .37713 .40464 .4047 .41662 .40523 .41019 .37576 Mtetra
.604 .474 .677 r
.41019 .37576 .41662 .40523 .42885 .40093 .42237 .3713 Mtetra
.637 .495 .673 r
.42237 .3713 .42885 .40093 .44125 .39173 .43469 .36367 Mtetra
.664 .518 .676 r
.43469 .36367 .44125 .39173 .45375 .37893 .4471 .3537 Mtetra
.683 .541 .687 r
.4471 .3537 .45375 .37893 .46626 .36466 .45953 .34282 Mtetra
.691 .564 .706 r
.45953 .34282 .46626 .36466 .47874 .35129 .47196 .33256 Mtetra
.685 .582 .734 r
.47196 .33256 .47874 .35129 .49118 .34077 .48437 .32425 Mtetra
.655 .586 .766 r
.48437 .32425 .49118 .34077 .50359 .33436 .49679 .31874 Mtetra
.599 .568 .79 r
.49679 .31874 .50359 .33436 .51603 .33247 .50923 .31628 Mtetra
.533 .525 .792 r
.50923 .31628 .51603 .33247 .52855 .33471 .52174 .3166 Mtetra
.488 .478 .772 r
.52174 .3166 .52855 .33471 .5412 .33993 .53436 .3189 Mtetra
.483 .448 .742 r
.53436 .3189 .5412 .33993 .55399 .34632 .54709 .32193 Mtetra
.508 .44 .715 r
.54709 .32193 .55399 .34632 .56691 .35172 .55993 .3242 Mtetra
.547 .449 .695 r
.55993 .3242 .56691 .35172 .57992 .35397 .57285 .32425 Mtetra
.587 .466 .681 r
.57285 .32425 .57992 .35397 .59294 .35152 .58581 .32105 Mtetra
.625 .487 .674 r
.58581 .32105 .59294 .35152 .60591 .34385 .59875 .31425 Mtetra
.657 .51 .673 r
.59875 .31425 .60591 .34385 .61877 .3316 .61164 .30431 Mtetra
.684 .536 .679 r
.61164 .30431 .61877 .3316 .63153 .31631 .62449 .29227 Mtetra
.705 .563 .692 r
.62449 .29227 .63153 .31631 .64421 .29989 .6373 .27945 Mtetra
.721 .593 .713 r
.6373 .27945 .64421 .29989 .65688 .28409 .65013 .26704 Mtetra
.73 .625 .742 r
.65013 .26704 .65688 .28409 .6696 .27005 .663 .25584 Mtetra
.731 .658 .777 r
.663 .25584 .6696 .27005 .68242 .25826 .67595 .2462 Mtetra
.723 .687 .815 r
.67595 .2462 .68242 .25826 .69535 .24868 .689 .23808 Mtetra
.71 .71 .848 r
.689 .23808 .69535 .24868 .70842 .24089 .70216 .23122 Mtetra
.695 .725 .874 r
.70216 .23122 .70842 .24089 .7216 .23441 .71542 .22525 Mtetra
.682 .734 .89 r
.71542 .22525 .7216 .23441 .73488 .22876 .72877 .21986 Mtetra
.673 .738 .899 r
.72877 .21986 .73488 .22876 .74826 .22359 .7422 .21479 Mtetra
.668 .74 .904 r
.7422 .21479 .74826 .22359 .76172 .21867 .7557 .20989 Mtetra
.666 .741 .906 r
.7557 .20989 .76172 .21867 .77525 .21385 .76928 .20507 Mtetra
.664 .741 .907 r
.76928 .20507 .77525 .21385 .78884 .20907 .78292 .20026 Mtetra
.664 .741 .908 r
.78292 .20026 .78884 .20907 .80251 .2043 .79663 .19544 Mtetra
.79663 .19544 .80251 .2043 .81623 .19951 .81041 .19061 Mtetra
.78 .33 0 r
.1812 .44415 .18873 .454 .19773 .4723 .1903 .46107 Mtetra
.815 .39 0 r
.1903 .46107 .19773 .4723 .20661 .49381 .19929 .48097 Mtetra
.755 .348 0 r
.19929 .48097 .20661 .49381 .21571 .51535 .20849 .50088 Mtetra
0 0 .473 r
.20849 .50088 .21571 .51535 .22541 .53265 .21826 .51684 Mtetra
.189 .324 .771 r
.21826 .51684 .22541 .53265 .23603 .54146 .22891 .52491 Mtetra
.598 .555 .777 r
.22891 .52491 .23603 .54146 .24772 .53901 .24058 .52252 Mtetra
.749 .63 .728 r
.24058 .52252 .24772 .53901 .26038 .52506 .25319 .50946 Mtetra
.811 .662 .698 r
.25319 .50946 .26038 .52506 .2737 .50205 .26645 .48792 Mtetra
.842 .682 .685 r
.26645 .48792 .2737 .50205 .2873 .47409 .27998 .46171 Mtetra
.857 .7 .687 r
.27998 .46171 .2873 .47409 .30082 .44567 .29346 .43486 Mtetra
.86 .716 .701 r
.29346 .43486 .30082 .44567 .31401 .42038 .30665 .41065 Mtetra
.85 .729 .73 r
.30665 .41065 .31401 .42038 .32677 .40041 .31945 .39099 Mtetra
.82 .733 .768 r
.31945 .39099 .32677 .40041 .33912 .38654 .33188 .37651 Mtetra
.763 .713 .805 r
.33188 .37651 .33912 .38654 .35113 .37847 .34402 .36686 Mtetra
.686 .661 .82 r
.34402 .36686 .35113 .37847 .36293 .37516 .35595 .36112 Mtetra
.618 .594 .804 r
.35595 .36112 .36293 .37516 .37463 .37507 .3678 .35805 Mtetra
.583 .54 .772 r
.3678 .35805 .37463 .37507 .38635 .37636 .37965 .35628 Mtetra
.58 .51 .741 r
.37965 .35628 .38635 .37636 .39819 .37713 .39157 .35449 Mtetra
.595 .501 .718 r
.39157 .35449 .39819 .37713 .41019 .37576 .4036 .35159 Mtetra
.617 .506 .705 r
.4036 .35159 .41019 .37576 .42237 .3713 .41576 .34693 Mtetra
.639 .519 .7 r
.41576 .34693 .42237 .3713 .43469 .36367 .42802 .34045 Mtetra
.659 .537 .704 r
.42802 .34045 .43469 .36367 .4471 .3537 .44035 .33265 Mtetra
.673 .558 .717 r
.44035 .33265 .4471 .3537 .45953 .34282 .45273 .32435 Mtetra
.68 .581 .738 r
.45273 .32435 .45953 .34282 .47196 .33256 .46512 .31653 Mtetra
.674 .601 .766 r
.46512 .31653 .47196 .33256 .48437 .32425 .47752 .30997 Mtetra
.651 .612 .797 r
.47752 .30997 .48437 .32425 .49679 .31874 .48994 .30518 Mtetra
.611 .604 .819 r
.48994 .30518 .49679 .31874 .50923 .31628 .50239 .30232 Mtetra
.566 .575 .822 r
.50239 .30232 .50923 .31628 .52174 .3166 .51492 .30118 Mtetra
.537 .539 .804 r
.51492 .30118 .52174 .3166 .53436 .3189 .52752 .30121 Mtetra
.532 .509 .776 r
.52752 .30121 .53436 .3189 .54709 .32193 .54022 .30161 Mtetra
.548 .494 .747 r
.54022 .30161 .54709 .32193 .55993 .3242 .55302 .30142 Mtetra
.574 .492 .724 r
.55302 .30142 .55993 .3242 .57285 .32425 .56588 .29972 Mtetra
.603 .499 .709 r
.56588 .29972 .57285 .32425 .58581 .32105 .5788 .29586 Mtetra
.632 .513 .701 r
.5788 .29586 .58581 .32105 .59875 .31425 .59173 .28964 Mtetra
.657 .532 .7 r
.59173 .28964 .59875 .31425 .61164 .30431 .60465 .28139 Mtetra
.678 .554 .707 r
.60465 .28139 .61164 .30431 .62449 .29227 .61757 .27179 Mtetra
.696 .58 .721 r
.61757 .27179 .62449 .29227 .6373 .27945 .63048 .2617 Mtetra
.708 .608 .743 r
.63048 .2617 .6373 .27945 .65013 .26704 .64342 .25188 Mtetra
.715 .639 .772 r
.64342 .25188 .65013 .26704 .663 .25584 .65641 .24287 Mtetra
.714 .669 .804 r
.65641 .24287 .663 .25584 .67595 .2462 .66948 .23488 Mtetra
.707 .695 .836 r
.66948 .23488 .67595 .2462 .689 .23808 .68263 .22789 Mtetra
.697 .715 .863 r
.68263 .22789 .689 .23808 .70216 .23122 .69587 .22172 Mtetra
.685 .728 .883 r
.69587 .22172 .70216 .23122 .71542 .22525 .70919 .21614 Mtetra
.676 .735 .895 r
.70919 .21614 .71542 .22525 .72877 .21986 .7226 .21094 Mtetra
.67 .739 .902 r
.7226 .21094 .72877 .21986 .7422 .21479 .73608 .20595 Mtetra
.667 .74 .905 r
.73608 .20595 .7422 .21479 .7557 .20989 .74964 .20106 Mtetra
.665 .741 .907 r
.74964 .20106 .7557 .20989 .76928 .20507 .76326 .19621 Mtetra
.664 .741 .907 r
.76326 .19621 .76928 .20507 .78292 .20026 .77695 .19137 Mtetra
.664 .741 .908 r
.77695 .19137 .78292 .20026 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
0 0 .385 r
.17382 .43242 .1812 .44415 .1903 .46107 .18312 .44705 Mtetra
0 0 .353 r
.18312 .44705 .1903 .46107 .19929 .48097 .19231 .46432 Mtetra
0 0 .463 r
.19231 .46432 .19929 .48097 .20849 .50088 .20169 .48165 Mtetra
0 .109 .642 r
.20169 .48165 .20849 .50088 .21826 .51684 .21159 .49556 Mtetra
.346 .355 .727 r
.21159 .49556 .21826 .51684 .22891 .52491 .22228 .50262 Mtetra
.582 .496 .723 r
.22228 .50262 .22891 .52491 .24058 .52252 .2339 .50057 Mtetra
.703 .57 .703 r
.2339 .50057 .24058 .52252 .25319 .50946 .24637 .48916 Mtetra
.768 .614 .688 r
.24637 .48916 .25319 .50946 .26645 .48792 .25944 .47025 Mtetra
.807 .647 .684 r
.25944 .47025 .26645 .48792 .27998 .46171 .2728 .44703 Mtetra
.831 .676 .69 r
.2728 .44703 .27998 .46171 .29346 .43486 .28613 .42297 Mtetra
.843 .703 .708 r
.28613 .42297 .29346 .43486 .30665 .41065 .29923 .40086 Mtetra
.844 .729 .737 r
.29923 .40086 .30665 .41065 .31945 .39099 .31202 .38235 Mtetra
.827 .748 .776 r
.31202 .38235 .31945 .39099 .33188 .37651 .3245 .36797 Mtetra
.789 .748 .815 r
.3245 .36797 .33188 .37651 .34402 .36686 .33673 .35743 Mtetra
.733 .719 .838 r
.33673 .35743 .34402 .36686 .35595 .36112 .34879 .35001 Mtetra
.678 .669 .834 r
.34879 .35001 .35595 .36112 .3678 .35805 .36076 .34474 Mtetra
.641 .618 .811 r
.36076 .34474 .3678 .35805 .37965 .35628 .37272 .34069 Mtetra
.626 .58 .782 r
.37272 .34069 .37965 .35628 .39157 .35449 .38473 .33696 Mtetra
.627 .56 .76 r
.38473 .33696 .39157 .35449 .4036 .35159 .3968 .33286 Mtetra
.636 .554 .746 r
.3968 .33286 .4036 .35159 .41576 .34693 .40896 .32798 Mtetra
.648 .559 .741 r
.40896 .32798 .41576 .34693 .42802 .34045 .42119 .32225 Mtetra
.66 .573 .746 r
.42119 .32225 .42802 .34045 .44035 .33265 .43349 .31593 Mtetra
.669 .592 .76 r
.43349 .31593 .44035 .33265 .45273 .32435 .44582 .30948 Mtetra
.672 .614 .782 r
.44582 .30948 .45273 .32435 .46512 .31653 .45819 .30342 Mtetra
.665 .636 .811 r
.45819 .30342 .46512 .31653 .47752 .30997 .47059 .29819 Mtetra
.647 .651 .84 r
.47059 .29819 .47752 .30997 .48994 .30518 .48302 .29403 Mtetra
.618 .651 .86 r
.48302 .29403 .48994 .30518 .50239 .30232 .4955 .29099 Mtetra
.59 .635 .865 r
.4955 .29099 .50239 .30232 .51492 .30118 .50804 .28891 Mtetra
.573 .61 .851 r
.50804 .28891 .51492 .30118 .52752 .30121 .52066 .2874 Mtetra
.572 .583 .826 r
.52066 .2874 .52752 .30121 .54022 .30161 .53336 .28596 Mtetra
.585 .564 .797 r
.53336 .28596 .54022 .30161 .55302 .30142 .54614 .28399 Mtetra
.605 .555 .772 r
.54614 .28399 .55302 .30142 .56588 .29972 .55899 .28095 Mtetra
.626 .554 .754 r
.55899 .28095 .56588 .29972 .5788 .29586 .57189 .27649 Mtetra
.648 .561 .743 r
.57189 .27649 .5788 .29586 .59173 .28964 .58483 .27053 Mtetra
.667 .574 .742 r
.58483 .27053 .59173 .28964 .60465 .28139 .59778 .2633 Mtetra
.683 .592 .748 r
.59778 .2633 .60465 .28139 .61757 .27179 .61075 .25526 Mtetra
.696 .614 .761 r
.61075 .25526 .61757 .27179 .63048 .2617 .62374 .24695 Mtetra
.704 .639 .782 r
.62374 .24695 .63048 .2617 .64342 .25188 .63677 .23885 Mtetra
.706 .665 .807 r
.63677 .23885 .64342 .25188 .65641 .24287 .64985 .23129 Mtetra
.704 .69 .834 r
.64985 .23129 .65641 .24287 .66948 .23488 .663 .2244 Mtetra
.696 .71 .858 r
.663 .2244 .66948 .23488 .68263 .22789 .67623 .21815 Mtetra
.687 .724 .878 r
.67623 .21815 .68263 .22789 .69587 .22172 .68954 .21244 Mtetra
.679 .733 .891 r
.68954 .21244 .69587 .22172 .70919 .21614 .70293 .20711 Mtetra
.672 .737 .899 r
.70293 .20711 .70919 .21614 .7226 .21094 .71639 .20201 Mtetra
.668 .74 .904 r
.71639 .20201 .7226 .21094 .73608 .20595 .72992 .19705 Mtetra
.666 .741 .906 r
.72992 .19705 .73608 .20595 .74964 .20106 .74352 .19216 Mtetra
.665 .741 .907 r
.74352 .19216 .74964 .20106 .76326 .19621 .75719 .18728 Mtetra
.664 .741 .908 r
.75719 .18728 .76326 .19621 .77695 .19137 .77093 .1824 Mtetra
.77093 .1824 .77695 .19137 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
0 .032 .6 r
.16652 .41963 .17382 .43242 .18312 .44705 .17606 .43147 Mtetra
0 0 .568 r
.17606 .43147 .18312 .44705 .19231 .46432 .18553 .44558 Mtetra
0 .071 .62 r
.18553 .44558 .19231 .46432 .20169 .48165 .19515 .45982 Mtetra
.16 .226 .683 r
.19515 .45982 .20169 .48165 .21159 .49556 .20521 .47134 Mtetra
.404 .369 .706 r
.20521 .47134 .21159 .49556 .22228 .50262 .21595 .47733 Mtetra
.568 .469 .702 r
.21595 .47733 .22228 .50262 .2339 .50057 .22747 .47588 Mtetra
.669 .536 .694 r
.22747 .47588 .2339 .50057 .24637 .48916 .23973 .46669 Mtetra
.734 .585 .689 r
.23973 .46669 .24637 .48916 .25944 .47025 .25254 .45114 Mtetra
.779 .626 .691 r
.25254 .45114 .25944 .47025 .2728 .44703 .26563 .43173 Mtetra
.81 .665 .702 r
.26563 .43173 .2728 .44703 .28613 .42297 .27874 .41122 Mtetra
.831 .703 .723 r
.27874 .41122 .28613 .42297 .29923 .40086 .29171 .39186 Mtetra
.841 .742 .754 r
.29171 .39186 .29923 .40086 .31202 .38235 .30444 .37502 Mtetra
.836 .775 .794 r
.30444 .37502 .31202 .38235 .3245 .36797 .31694 .3612 Mtetra
.812 .79 .833 r
.31694 .3612 .3245 .36797 .33673 .35743 .32924 .35025 Mtetra
.772 .779 .859 r
.32924 .35025 .33673 .35743 .34879 .35001 .34141 .34165 Mtetra
.729 .744 .864 r
.34141 .34165 .34879 .35001 .36076 .34474 .3535 .33478 Mtetra
.695 .7 .85 r
.3535 .33478 .36076 .34474 .37272 .34069 .36558 .32902 Mtetra
.673 .659 .829 r
.36558 .32902 .37272 .34069 .38473 .33696 .37766 .32382 Mtetra
.662 .632 .809 r
.37766 .32382 .38473 .33696 .3968 .33286 .38979 .31878 Mtetra
.659 .617 .796 r
.38979 .31878 .3968 .33286 .40896 .32798 .40197 .31364 Mtetra
.661 .615 .793 r
.40197 .31364 .40896 .32798 .42119 .32225 .4142 .30834 Mtetra
.664 .623 .798 r
.4142 .30834 .42119 .32225 .43349 .31593 .42648 .30299 Mtetra
.665 .638 .814 r
.42648 .30299 .43349 .31593 .44582 .30948 .4388 .29781 Mtetra
.662 .659 .837 r
.4388 .29781 .44582 .30948 .45819 .30342 .45116 .29303 Mtetra
.652 .681 .865 r
.45116 .29303 .45819 .30342 .47059 .29819 .46357 .28884 Mtetra
.634 .699 .893 r
.46357 .28884 .47059 .29819 .48302 .29403 .47602 .28532 Mtetra
.612 .708 .913 r
.47602 .28532 .48302 .29403 .4955 .29099 .48853 .28239 Mtetra
.596 .706 .92 r
.48853 .28239 .4955 .29099 .50804 .28891 .50111 .27989 Mtetra
.592 .694 .913 r
.50111 .27989 .50804 .28891 .52066 .2874 .51376 .27752 Mtetra
.601 .677 .894 r
.51376 .27752 .52066 .2874 .53336 .28596 .52648 .27494 Mtetra
.619 .66 .868 r
.52648 .27494 .53336 .28596 .54614 .28399 .53928 .27178 Mtetra
.639 .646 .841 r
.53928 .27178 .54614 .28399 .55899 .28095 .55214 .26774 Mtetra
.658 .639 .819 r
.55214 .26774 .55899 .28095 .57189 .27649 .56505 .26268 Mtetra
.675 .638 .805 r
.56505 .26268 .57189 .27649 .58483 .27053 .578 .25662 Mtetra
.689 .643 .799 r
.578 .25662 .58483 .27053 .59778 .2633 .59099 .24976 Mtetra
.699 .654 .802 r
.59099 .24976 .59778 .2633 .61075 .25526 .604 .24244 Mtetra
.705 .668 .811 r
.604 .24244 .61075 .25526 .62374 .24695 .61705 .23503 Mtetra
.707 .685 .826 r
.61705 .23503 .62374 .24695 .63677 .23885 .63015 .22782 Mtetra
.705 .702 .844 r
.63015 .22782 .63677 .23885 .64985 .23129 .6433 .22103 Mtetra
.699 .716 .862 r
.6433 .22103 .64985 .23129 .663 .2244 .65652 .21471 Mtetra
.691 .727 .878 r
.65652 .21471 .663 .2244 .67623 .21815 .66981 .20886 Mtetra
.682 .734 .89 r
.66981 .20886 .67623 .21815 .68954 .21244 .68317 .20337 Mtetra
.675 .739 .898 r
.68317 .20337 .68954 .21244 .70293 .20711 .69661 .19814 Mtetra
.67 .741 .903 r
.69661 .19814 .70293 .20711 .71639 .20201 .71012 .19308 Mtetra
.667 .741 .906 r
.71012 .19308 .71639 .20201 .72992 .19705 .7237 .18812 Mtetra
.665 .741 .907 r
.7237 .18812 .72992 .19705 .74352 .19216 .73735 .18319 Mtetra
.664 .741 .907 r
.73735 .18319 .74352 .19216 .75719 .18728 .75107 .17828 Mtetra
.664 .741 .908 r
.75107 .17828 .75719 .18728 .77093 .1824 .76485 .17335 Mtetra
.76485 .17335 .77093 .1824 .78473 .1775 .7787 .16842 Mtetra
.7787 .16842 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
0 .208 .732 r
.15916 .40687 .16652 .41963 .17606 .43147 .16898 .41594 Mtetra
0 .156 .688 r
.16898 .41594 .17606 .43147 .18553 .44558 .17873 .42693 Mtetra
.064 .196 .691 r
.17873 .42693 .18553 .44558 .19515 .45982 .1886 .43818 Mtetra
.25 .288 .706 r
.1886 .43818 .19515 .45982 .20521 .47134 .19881 .44749 Mtetra
.422 .383 .71 r
.19881 .44749 .20521 .47134 .21595 .47733 .20957 .45263 Mtetra
.552 .462 .707 r
.20957 .45263 .21595 .47733 .22747 .47588 .22098 .45204 Mtetra
.644 .525 .703 r
.22098 .45204 .22747 .47588 .23973 .46669 .23301 .44534 Mtetra
.71 .578 .704 r
.23301 .44534 .23973 .46669 .25254 .45114 .24551 .43342 Mtetra
.761 .627 .712 r
.24551 .43342 .25254 .45114 .26563 .43173 .2583 .41804 Mtetra
.8 .676 .727 r
.2583 .41804 .26563 .43173 .27874 .41122 .27117 .40124 Mtetra
.83 .727 .752 r
.27117 .40124 .27874 .41122 .29171 .39186 .28398 .38474 Mtetra
.848 .778 .784 r
.28398 .38474 .29171 .39186 .30444 .37502 .29666 .36967 Mtetra
.85 .821 .82 r
.29666 .36967 .30444 .37502 .31694 .3612 .30917 .3565 Mtetra
.834 .844 .854 r
.30917 .3565 .31694 .3612 .32924 .35025 .32155 .34526 Mtetra
.806 .842 .878 r
.32155 .34526 .32924 .35025 .34141 .34165 .33383 .33572 Mtetra
.773 .817 .887 r
.33383 .33572 .34141 .34165 .3535 .33478 .34604 .32755 Mtetra
.742 .778 .882 r
.34604 .32755 .3535 .33478 .36558 .32902 .35822 .32042 Mtetra
.716 .739 .869 r
.35822 .32042 .36558 .32902 .37766 .32382 .37039 .31405 Mtetra
.697 .707 .856 r
.37039 .31405 .37766 .32382 .38979 .31878 .38258 .30821 Mtetra
.683 .687 .847 r
.38258 .30821 .38979 .31878 .40197 .31364 .3948 .30277 Mtetra
.673 .678 .847 r
.3948 .30277 .40197 .31364 .4142 .30834 .40705 .29768 Mtetra
.664 .68 .855 r
.40705 .29768 .4142 .30834 .42648 .30299 .41933 .29297 Mtetra
.655 .691 .872 r
.41933 .29297 .42648 .30299 .4388 .29781 .43166 .28872 Mtetra
.641 .708 .896 r
.43166 .28872 .4388 .29781 .45116 .29303 .44402 .28497 Mtetra
.621 .73 .924 r
.44402 .28497 .45116 .29303 .46357 .28884 .45644 .28176 Mtetra
.596 .751 .951 r
.45644 .28176 .46357 .28884 .47602 .28532 .46892 .279 Mtetra
.573 .768 .971 r
.46892 .279 .47602 .28532 .48853 .28239 .48146 .27654 Mtetra
.561 .78 .981 r
.48146 .27654 .48853 .28239 .50111 .27989 .49408 .27413 Mtetra
.57 .788 .981 r
.49408 .27413 .50111 .27989 .51376 .27752 .50678 .27149 Mtetra
.599 .79 .972 r
.50678 .27149 .51376 .27752 .52648 .27494 .51955 .26834 Mtetra
.636 .786 .953 r
.51955 .26834 .52648 .27494 .53928 .27178 .53238 .26441 Mtetra
.671 .775 .928 r
.53238 .26441 .53928 .27178 .55214 .26774 .54528 .25959 Mtetra
.696 .762 .902 r
.54528 .25959 .55214 .26774 .56505 .26268 .55823 .25384 Mtetra
.713 .75 .881 r
.55823 .25384 .56505 .26268 .578 .25662 .57122 .24729 Mtetra
.723 .743 .868 r
.57122 .24729 .578 .25662 .59099 .24976 .58424 .2402 Mtetra
.726 .74 .862 r
.58424 .2402 .59099 .24976 .604 .24244 .5973 .23286 Mtetra
.725 .74 .863 r
.5973 .23286 .604 .24244 .61705 .23503 .61039 .22556 Mtetra
.72 .742 .869 r
.61039 .22556 .61705 .23503 .63015 .22782 .62354 .21853 Mtetra
.711 .744 .877 r
.62354 .21853 .63015 .22782 .6433 .22103 .63675 .21191 Mtetra
.701 .746 .886 r
.63675 .21191 .6433 .22103 .65652 .21471 .65002 .20572 Mtetra
.691 .746 .894 r
.65002 .20572 .65652 .21471 .66981 .20886 .66336 .19994 Mtetra
.682 .746 .9 r
.66336 .19994 .66981 .20886 .68317 .20337 .67677 .19447 Mtetra
.675 .745 .903 r
.67677 .19447 .68317 .20337 .69661 .19814 .69025 .18923 Mtetra
.67 .744 .906 r
.69025 .18923 .69661 .19814 .71012 .19308 .70381 .18414 Mtetra
.667 .743 .907 r
.70381 .18414 .71012 .19308 .7237 .18812 .71743 .17913 Mtetra
.665 .742 .907 r
.71743 .17913 .7237 .18812 .73735 .18319 .73113 .17416 Mtetra
.664 .742 .908 r
.73113 .17416 .73735 .18319 .75107 .17828 .74489 .1692 Mtetra
.74489 .1692 .75107 .17828 .76485 .17335 .75872 .16423 Mtetra
.664 .741 .908 r
.75872 .16423 .76485 .17335 .7787 .16842 .77261 .15925 Mtetra
.77261 .15925 .7787 .16842 .79262 .16346 .78658 .15424 Mtetra
.07 .329 .808 r
.15166 .39512 .15916 .40687 .16898 .41594 .1617 .4019 Mtetra
.052 .265 .759 r
.1617 .4019 .16898 .41594 .17873 .42693 .17169 .41034 Mtetra
.131 .272 .742 r
.17169 .41034 .17873 .42693 .1886 .43818 .18176 .41922 Mtetra
.267 .327 .74 r
.18176 .41922 .1886 .43818 .19881 .44749 .1921 .42688 Mtetra
.408 .401 .74 r
.1921 .42688 .19881 .44749 .20957 .45263 .20286 .43162 Mtetra
.527 .472 .738 r
.20286 .43162 .20957 .45263 .22098 .45204 .21413 .43214 Mtetra
.62 .537 .738 r
.21413 .43214 .22098 .45204 .23301 .44534 .22591 .42797 Mtetra
.694 .598 .744 r
.22591 .42797 .23301 .44534 .24551 .43342 .23813 .41952 Mtetra
.754 .659 .756 r
.23813 .41952 .24551 .43342 .2583 .41804 .25063 .40789 Mtetra
.804 .722 .775 r
.25063 .40789 .2583 .41804 .27117 .40124 .26328 .39444 Mtetra
.841 .786 .798 r
.26328 .39444 .27117 .40124 .28398 .38474 .27597 .38044 Mtetra
.863 .844 .824 r
.27597 .38044 .28398 .38474 .29666 .36967 .2886 .3668 Mtetra
.866 .885 .848 r
.2886 .3668 .29666 .36967 .30917 .3565 .30116 .35404 Mtetra
.855 .904 .868 r
.30116 .35404 .30917 .3565 .32155 .34526 .31363 .34238 Mtetra
.834 .9 .885 r
.31363 .34238 .32155 .34526 .33383 .33572 .32603 .33186 Mtetra
.81 .878 .896 r
.32603 .33186 .33383 .33572 .34604 .32755 .33838 .32245 Mtetra
.782 .844 .898 r
.33838 .32245 .34604 .32755 .35822 .32042 .35068 .31406 Mtetra
.754 .807 .895 r
.35068 .31406 .35822 .32042 .37039 .31405 .36295 .30661 Mtetra
.727 .774 .89 r
.36295 .30661 .37039 .31405 .38258 .30821 .37521 .30004 Mtetra
.702 .75 .888 r
.37521 .30004 .38258 .30821 .3948 .30277 .38748 .29428 Mtetra
.68 .736 .893 r
.38748 .29428 .3948 .30277 .40705 .29768 .39976 .2893 Mtetra
.656 .732 .905 r
.39976 .2893 .40705 .29768 .41933 .29297 .41206 .28509 Mtetra
.629 .738 .926 r
.41206 .28509 .41933 .29297 .43166 .28872 .42439 .28164 Mtetra
.595 .751 .952 r
.42439 .28164 .43166 .28872 .44402 .28497 .43677 .2789 Mtetra
.551 .768 .978 r
.43677 .2789 .44402 .28497 .45644 .28176 .4492 .27677 Mtetra
.499 .784 .996 r
.4492 .27677 .45644 .28176 .46892 .279 .4617 .27505 Mtetra
.449 .797 .998 r
.4617 .27505 .46892 .279 .48146 .27654 .47428 .27345 Mtetra
.422 .811 .988 r
.47428 .27345 .48146 .27654 .49408 .27413 .48694 .27163 Mtetra
.435 .834 .979 r
.48694 .27163 .49408 .27413 .50678 .27149 .49969 .26923 Mtetra
.491 .867 .98 r
.49969 .26923 .50678 .27149 .51955 .26834 .51252 .26594 Mtetra
.573 .899 .984 r
.51252 .26594 .51955 .26834 .53238 .26441 .52543 .26154 Mtetra
.653 .914 .979 r
.52543 .26154 .53238 .26441 .54528 .25959 .53839 .25599 Mtetra
.712 .908 .964 r
.53839 .25599 .54528 .25959 .55823 .25384 .55139 .24938 Mtetra
.747 .889 .944 r
.55139 .24938 .55823 .25384 .57122 .24729 .56443 .24196 Mtetra
.761 .865 .925 r
.56443 .24196 .57122 .24729 .58424 .2402 .5775 .23405 Mtetra
.762 .842 .912 r
.5775 .23405 .58424 .2402 .5973 .23286 .5906 .22602 Mtetra
.754 .821 .905 r
.5906 .22602 .5973 .23286 .61039 .22556 .60374 .21817 Mtetra
.741 .804 .902 r
.60374 .21817 .61039 .22556 .62354 .21853 .61692 .21071 Mtetra
.726 .789 .902 r
.61692 .21071 .62354 .21853 .63675 .21191 .63017 .20376 Mtetra
.711 .776 .903 r
.63017 .20376 .63675 .21191 .65002 .20572 .64348 .19732 Mtetra
.697 .766 .905 r
.64348 .19732 .65002 .20572 .66336 .19994 .65686 .19134 Mtetra
.686 .758 .906 r
.65686 .19134 .66336 .19994 .67677 .19447 .67031 .18572 Mtetra
.678 .752 .907 r
.67031 .18572 .67677 .19447 .69025 .18923 .68384 .18036 Mtetra
.672 .748 .908 r
.68384 .18036 .69025 .18923 .70381 .18414 .69744 .17518 Mtetra
.668 .745 .908 r
.69744 .17518 .70381 .18414 .71743 .17913 .71111 .1701 Mtetra
.666 .743 .908 r
.71111 .1701 .71743 .17913 .73113 .17416 .72485 .16506 Mtetra
.665 .742 .908 r
.72485 .16506 .73113 .17416 .74489 .1692 .73865 .16005 Mtetra
.664 .742 .908 r
.73865 .16005 .74489 .1692 .75872 .16423 .75253 .15503 Mtetra
.75253 .15503 .75872 .16423 .77261 .15925 .76647 .15 Mtetra
.664 .741 .908 r
.76647 .15 .77261 .15925 .78658 .15424 .78049 .14495 Mtetra
.121 .407 .856 r
.14391 .38495 .15166 .39512 .1617 .4019 .15412 .39019 Mtetra
.066 .33 .809 r
.15412 .39019 .1617 .4019 .17169 .41034 .16427 .39696 Mtetra
.099 .313 .789 r
.16427 .39696 .17169 .41034 .18176 .41922 .17447 .40437 Mtetra
.202 .349 .79 r
.17447 .40437 .18176 .41922 .1921 .42688 .18487 .41119 Mtetra
.335 .418 .799 r
.18487 .41119 .1921 .42688 .20286 .43162 .19558 .4161 Mtetra
.466 .498 .807 r
.19558 .4161 .20286 .43162 .21413 .43214 .2067 .41797 Mtetra
.58 .579 .816 r
.2067 .41797 .21413 .43214 .22591 .42797 .21827 .41621 Mtetra
.677 .661 .827 r
.21827 .41621 .22591 .42797 .23813 .41952 .23023 .41081 Mtetra
.756 .742 .84 r
.23023 .41081 .23813 .41952 .25063 .40789 .24251 .40231 Mtetra
.817 .82 .852 r
.24251 .40231 .25063 .40789 .26328 .39444 .25499 .39154 Mtetra
.857 .886 .857 r
.25499 .39154 .26328 .39444 .27597 .38044 .2676 .37937 Mtetra
.874 .93 .857 r
.2676 .37937 .27597 .38044 .2886 .3668 .28025 .36658 Mtetra
.874 .952 .857 r
.28025 .36658 .2886 .3668 .30116 .35404 .29289 .35377 Mtetra
.868 .955 .863 r
.29289 .35377 .30116 .35404 .31363 .34238 .3055 .34136 Mtetra
.857 .944 .875 r
.3055 .34136 .31363 .34238 .32603 .33186 .31805 .32966 Mtetra
.84 .921 .888 r
.31805 .32966 .32603 .33186 .33838 .32245 .33054 .3189 Mtetra
.815 .889 .897 r
.33054 .3189 .33838 .32245 .35068 .31406 .34297 .30922 Mtetra
.785 .855 .902 r
.34297 .30922 .35068 .31406 .36295 .30661 .35535 .30072 Mtetra
.752 .823 .907 r
.35535 .30072 .36295 .30661 .37521 .30004 .3677 .29341 Mtetra
.717 .797 .915 r
.3677 .29341 .37521 .30004 .38748 .29428 .38002 .28733 Mtetra
.679 .78 .927 r
.38002 .28733 .38748 .29428 .39976 .2893 .39233 .28244 Mtetra
.635 .771 .945 r
.39233 .28244 .39976 .2893 .41206 .28509 .40465 .27874 Mtetra
.579 .769 .969 r
.40465 .27874 .41206 .28509 .42439 .28164 .417 .27616 Mtetra
.503 .769 .991 r
.417 .27616 .42439 .28164 .43677 .2789 .42938 .27458 Mtetra
.4 .761 .994 r
.42938 .27458 .43677 .2789 .4492 .27677 .44182 .2738 Mtetra
.276 .733 .954 r
.44182 .2738 .4492 .27677 .4617 .27505 .45434 .27349 Mtetra
.162 .689 .869 r
.45434 .27349 .4617 .27505 .47428 .27345 .46695 .2732 Mtetra
.1 .655 .776 r
.46695 .2732 .47428 .27345 .48694 .27163 .47967 .27245 Mtetra
.108 .661 .718 r
.47967 .27245 .48694 .27163 .49969 .26923 .49248 .27072 Mtetra
.186 .714 .713 r
.49248 .27072 .49969 .26923 .51252 .26594 .50539 .26762 Mtetra
.319 .802 .754 r
.50539 .26762 .51252 .26594 .52543 .26154 .51837 .26292 Mtetra
.479 .896 .818 r
.51837 .26292 .52543 .26154 .53839 .25599 .53141 .2566 Mtetra
.624 .96 .876 r
.53141 .2566 .53839 .25599 .55139 .24938 .5445 .24888 Mtetra
.725 .981 .91 r
.5445 .24888 .55139 .24938 .56443 .24196 .5576 .24015 Mtetra
.777 .967 .923 r
.5576 .24015 .56443 .24196 .5775 .23405 .57073 .23088 Mtetra
.793 .936 .924 r
.57073 .23088 .5775 .23405 .5906 .22602 .58388 .22155 Mtetra
.788 .9 .921 r
.58388 .22155 .5906 .22602 .60374 .21817 .59706 .21255 Mtetra
.771 .864 .918 r
.59706 .21255 .60374 .21817 .61692 .21071 .61028 .20414 Mtetra
.75 .833 .915 r
.61028 .20414 .61692 .21071 .63017 .20376 .62356 .19642 Mtetra
.729 .807 .913 r
.62356 .19642 .63017 .20376 .64348 .19732 .63691 .18941 Mtetra
.71 .786 .911 r
.63691 .18941 .64348 .19732 .65686 .19134 .65032 .183 Mtetra
.694 .77 .91 r
.65032 .183 .65686 .19134 .67031 .18572 .66381 .17709 Mtetra
.683 .759 .909 r
.66381 .17709 .67031 .18572 .68384 .18036 .67738 .17152 Mtetra
.675 .752 .909 r
.67738 .17152 .68384 .18036 .69744 .17518 .69102 .16619 Mtetra
.67 .747 .908 r
.69102 .16619 .69744 .17518 .71111 .1701 .70473 .16101 Mtetra
.667 .744 .908 r
.70473 .16101 .71111 .1701 .72485 .16506 .71851 .15589 Mtetra
.665 .743 .908 r
.71851 .15589 .72485 .16506 .73865 .16005 .73237 .15082 Mtetra
.664 .742 .908 r
.73237 .15082 .73865 .16005 .75253 .15503 .74629 .14574 Mtetra
.74629 .14574 .75253 .15503 .76647 .15 .76028 .14066 Mtetra
.664 .741 .908 r
.76028 .14066 .76647 .15 .78049 .14495 .77434 .13557 Mtetra
.089 .441 .878 r
.1359 .3765 .14391 .38495 .15412 .39019 .14619 .38101 Mtetra
0 .345 .822 r
.14619 .38101 .15412 .39019 .16427 .39696 .15642 .38702 Mtetra
0 .299 .794 r
.15642 .38702 .16427 .39696 .17447 .40437 .16666 .39391 Mtetra
0 .317 .807 r
.16666 .39391 .17447 .40437 .18487 .41119 .17704 .40073 Mtetra
.107 .395 .85 r
.17704 .40073 .18487 .41119 .19558 .4161 .18767 .40636 Mtetra
.268 .514 .904 r
.18767 .40636 .19558 .4161 .2067 .41797 .19864 .40978 Mtetra
.441 .65 .947 r
.19864 .40978 .2067 .41797 .21827 .41621 .21001 .41023 Mtetra
.597 .78 .968 r
.21001 .41023 .21827 .41621 .23023 .41081 .22177 .40736 Mtetra
.716 .885 .959 r
.22177 .40736 .23023 .41081 .24251 .40231 .23388 .40128 Mtetra
.791 .951 .923 r
.23388 .40128 .24251 .40231 .25499 .39154 .24628 .39238 Mtetra
.83 .982 .879 r
.24628 .39238 .25499 .39154 .2676 .37937 .25888 .38128 Mtetra
.851 .991 .846 r
.25888 .38128 .2676 .37937 .28025 .36658 .2716 .36869 Mtetra
.865 .99 .832 r
.2716 .36869 .28025 .36658 .29289 .35377 .28438 .35531 Mtetra
.874 .982 .837 r
.28438 .35531 .29289 .35377 .3055 .34136 .29715 .34177 Mtetra
.875 .967 .85 r
.29715 .34177 .3055 .34136 .31805 .32966 .30988 .32864 Mtetra
.865 .943 .867 r
.30988 .32864 .31805 .32966 .33054 .3189 .32254 .31638 Mtetra
.843 .914 .883 r
.32254 .31638 .33054 .3189 .34297 .30922 .33512 .30534 Mtetra
.812 .883 .897 r
.33512 .30534 .34297 .30922 .35535 .30072 .34763 .29574 Mtetra
.772 .853 .911 r
.34763 .29574 .35535 .30072 .3677 .29341 .36006 .28772 Mtetra
.726 .828 .928 r
.36006 .28772 .3677 .29341 .38002 .28733 .37245 .28133 Mtetra
.67 .809 .949 r
.37245 .28133 .38002 .28733 .39233 .28244 .38479 .2766 Mtetra
.597 .793 .974 r
.38479 .2766 .39233 .28244 .40465 .27874 .39713 .2735 Mtetra
.492 .774 .994 r
.39713 .2735 .40465 .27874 .417 .27616 .40948 .27196 Mtetra
.336 .732 .983 r
.40948 .27196 .417 .27616 .42938 .27458 .42186 .27181 Mtetra
.129 .643 .893 r
.42186 .27181 .42938 .27458 .44182 .2738 .4343 .27273 Mtetra
0 .512 .717 r
.4343 .27273 .44182 .2738 .45434 .27349 .44683 .27426 Mtetra
.201 0 0 r
.44683 .27426 .45434 .27349 .46695 .2732 .45946 .27577 Mtetra
.239 0 0 r
.45946 .27577 .46695 .2732 .47967 .27245 .47223 .27654 Mtetra
.206 0 0 r
.47223 .27654 .47967 .27245 .49248 .27072 .48511 .27588 Mtetra
.115 0 0 r
.48511 .27588 .49248 .27072 .50539 .26762 .49811 .27323 Mtetra
0 0 0 r
.49811 .27323 .50539 .26762 .51837 .26292 .51119 .2683 Mtetra
.51119 .2683 .51837 .26292 .53141 .2566 .52434 .2611 Mtetra
.435 .83 .616 r
.52434 .2611 .53141 .2566 .5445 .24888 .53752 .25197 Mtetra
.623 .944 .738 r
.53752 .25197 .5445 .24888 .5576 .24015 .55071 .24148 Mtetra
.749 .994 .827 r
.55071 .24148 .5576 .24015 .57073 .23088 .56391 .23032 Mtetra
.808 .99 .878 r
.56391 .23032 .57073 .23088 .58388 .22155 .57712 .21914 Mtetra
.82 .958 .903 r
.57712 .21914 .58388 .22155 .59706 .21255 .59034 .20846 Mtetra
.806 .915 .913 r
.59034 .20846 .59706 .21255 .61028 .20414 .6036 .19863 Mtetra
.78 .872 .915 r
.6036 .19863 .61028 .20414 .62356 .19642 .61691 .18979 Mtetra
.752 .835 .915 r
.61691 .18979 .62356 .19642 .63691 .18941 .63029 .18192 Mtetra
.727 .805 .913 r
.63029 .18192 .63691 .18941 .65032 .183 .64373 .1749 Mtetra
.706 .783 .911 r
.64373 .1749 .65032 .183 .66381 .17709 .65726 .16855 Mtetra
.69 .767 .91 r
.65726 .16855 .66381 .17709 .67738 .17152 .67086 .1627 Mtetra
.68 .756 .909 r
.67086 .1627 .67738 .17152 .69102 .16619 .68454 .15718 Mtetra
.673 .75 .909 r
.68454 .15718 .69102 .16619 .70473 .16101 .69829 .15186 Mtetra
.668 .746 .908 r
.69829 .15186 .70473 .16101 .71851 .15589 .71212 .14666 Mtetra
.666 .744 .908 r
.71212 .14666 .71851 .15589 .73237 .15082 .72602 .14151 Mtetra
.665 .742 .908 r
.72602 .14151 .73237 .15082 .74629 .14574 .73999 .13638 Mtetra
.664 .742 .908 r
.73999 .13638 .74629 .14574 .76028 .14066 .75403 .13125 Mtetra
.75403 .13125 .76028 .14066 .77434 .13557 .76814 .1261 Mtetra
0 .422 .854 r
.12764 .36948 .1359 .3765 .14619 .38101 .13794 .37394 Mtetra
0 .285 .747 r
.13794 .37394 .14619 .38101 .15642 .38702 .14816 .38 Mtetra
0 .187 .659 r
.14816 .38 .15642 .38702 .16666 .39391 .15837 .38717 Mtetra
0 .156 .621 r
.15837 .38717 .16666 .39391 .17704 .40073 .16867 .39464 Mtetra
0 .198 .641 r
.16867 .39464 .17704 .40073 .18767 .40636 .17918 .40144 Mtetra
0 .319 .714 r
.17918 .40144 .18767 .40636 .19864 .40978 .19 .40651 Mtetra
0 .512 .812 r
.19 .40651 .19864 .40978 .21001 .41023 .20119 .40894 Mtetra
.213 .726 .883 r
.20119 .40894 .21001 .41023 .22177 .40736 .21281 .4081 Mtetra
.45 .882 .886 r
.21281 .4081 .22177 .40736 .23388 .40128 .22483 .40375 Mtetra
.621 .959 .849 r
.22483 .40375 .23388 .40128 .24628 .39238 .2372 .396 Mtetra
.734 .99 .813 r
.2372 .396 .24628 .39238 .25888 .38128 .24985 .3853 Mtetra
.808 .999 .796 r
.24985 .3853 .25888 .38128 .2716 .36869 .2627 .37235 Mtetra
.857 .997 .796 r
.2627 .37235 .2716 .36869 .28438 .35531 .27565 .35795 Mtetra
.885 .987 .807 r
.27565 .35795 .28438 .35531 .29715 .34177 .28863 .34298 Mtetra
.895 .969 .824 r
.28863 .34298 .29715 .34177 .30988 .32864 .30156 .32822 Mtetra
.887 .946 .843 r
.30156 .32822 .30988 .32864 .32254 .31638 .31441 .31436 Mtetra
.866 .92 .863 r
.31441 .31436 .32254 .31638 .33512 .30534 .32715 .30191 Mtetra
.833 .893 .884 r
.32715 .30191 .33512 .30534 .34763 .29574 .33979 .29121 Mtetra
.789 .868 .907 r
.33979 .29121 .34763 .29574 .36006 .28772 .35232 .28249 Mtetra
.733 .845 .934 r
.35232 .28249 .36006 .28772 .37245 .28133 .36476 .27586 Mtetra
.656 .824 .964 r
.36476 .27586 .37245 .28133 .38479 .2766 .37715 .27138 Mtetra
.541 .796 .992 r
.37715 .27138 .38479 .2766 .39713 .2735 .38949 .26905 Mtetra
.357 .737 .987 r
.38949 .26905 .39713 .2735 .40948 .27196 .40183 .26878 Mtetra
.088 .606 .883 r
.40183 .26878 .40948 .27196 .42186 .27181 .41419 .27035 Mtetra
.194 0 0 r
.41419 .27035 .42186 .27181 .4343 .27273 .42662 .27335 Mtetra
.373 0 0 r
.42662 .27335 .4343 .27273 .44683 .27426 .43914 .27715 Mtetra
.44 0 0 r
.43914 .27715 .44683 .27426 .45946 .27577 .4518 .2809 Mtetra
.434 0 0 r
.4518 .2809 .45946 .27577 .47223 .27654 .4646 .28362 Mtetra
.378 0 0 r
.4646 .28362 .47223 .27654 .48511 .27588 .47756 .28437 Mtetra
.277 0 0 r
.47756 .28437 .48511 .27588 .49811 .27323 .49066 .28237 Mtetra
.13 0 0 r
.49066 .28237 .49811 .27323 .51119 .2683 .50386 .27723 Mtetra
0 0 0 r
.50386 .27723 .51119 .2683 .52434 .2611 .51713 .269 Mtetra
.51713 .269 .52434 .2611 .53752 .25197 .53043 .25816 Mtetra
.528 .848 .552 r
.53043 .25816 .53752 .25197 .55071 .24148 .54373 .2455 Mtetra
.709 .959 .694 r
.54373 .2455 .55071 .24148 .56391 .23032 .55702 .23196 Mtetra
.813 .999 .795 r
.55702 .23196 .56391 .23032 .57712 .21914 .57029 .21843 Mtetra
.849 .987 .856 r
.57029 .21843 .57712 .21914 .59034 .20846 .58357 .20563 Mtetra
.842 .949 .888 r
.58357 .20563 .59034 .20846 .6036 .19863 .59687 .19399 Mtetra
.814 .903 .903 r
.59687 .19399 .6036 .19863 .61691 .18979 .61021 .18371 Mtetra
.78 .859 .909 r
.61021 .18371 .61691 .18979 .63029 .18192 .62362 .17476 Mtetra
.747 .822 .91 r
.62362 .17476 .63029 .18192 .64373 .1749 .63709 .16696 Mtetra
.72 .794 .91 r
.63709 .16696 .64373 .1749 .65726 .16855 .65065 .16008 Mtetra
.699 .774 .909 r
.65065 .16008 .65726 .16855 .67086 .1627 .66429 .15387 Mtetra
.685 .76 .909 r
.66429 .15387 .67086 .1627 .68454 .15718 .67801 .14812 Mtetra
.676 .752 .908 r
.67801 .14812 .68454 .15718 .69829 .15186 .6918 .14265 Mtetra
.67 .747 .908 r
.6918 .14265 .69829 .15186 .71212 .14666 .70567 .13734 Mtetra
.667 .744 .908 r
.70567 .13734 .71212 .14666 .72602 .14151 .71962 .13212 Mtetra
.665 .743 .908 r
.71962 .13212 .72602 .14151 .73999 .13638 .73363 .12693 Mtetra
.664 .742 .908 r
.73363 .12693 .73999 .13638 .75403 .13125 .74772 .12175 Mtetra
.74772 .12175 .75403 .13125 .76814 .1261 .76188 .11655 Mtetra
0 .356 .783 r
.11919 .36338 .12764 .36948 .13794 .37394 .12944 .36826 Mtetra
0 .173 .602 r
.12944 .36826 .13794 .37394 .14816 .38 .13959 .37489 Mtetra
.526 0 0 r
.13959 .37489 .14816 .38 .15837 .38717 .14971 .38285 Mtetra
.595 .03 0 r
.14971 .38285 .15837 .38717 .16867 .39464 .15989 .39141 Mtetra
.602 .031 0 r
.15989 .39141 .16867 .39464 .17918 .40144 .17026 .3996 Mtetra
.549 0 0 r
.17026 .3996 .17918 .40144 .19 .40651 .18092 .4063 Mtetra
.421 0 0 r
.18092 .4063 .19 .40651 .20119 .40894 .19198 .41046 Mtetra
.192 0 0 r
.19198 .41046 .20119 .40894 .21281 .4081 .20349 .41121 Mtetra
0 0 0 r
.20349 .41121 .21281 .4081 .22483 .40375 .21546 .40803 Mtetra
.447 .862 .713 r
.21546 .40803 .22483 .40375 .2372 .396 .22786 .40087 Mtetra
.674 .965 .757 r
.22786 .40087 .2372 .396 .24985 .3853 .24062 .39008 Mtetra
.807 .996 .773 r
.24062 .39008 .24985 .3853 .2627 .37235 .25363 .37638 Mtetra
.876 .994 .782 r
.25363 .37638 .2627 .37235 .27565 .35795 .26679 .36072 Mtetra
.907 .977 .791 r
.26679 .36072 .27565 .35795 .28863 .34298 .27998 .34417 Mtetra
.914 .956 .804 r
.27998 .34417 .28863 .34298 .30156 .32822 .29314 .32774 Mtetra
.904 .933 .821 r
.29314 .32774 .30156 .32822 .31441 .31436 .30618 .31227 Mtetra
.882 .911 .842 r
.30618 .31227 .31441 .31436 .32715 .30191 .31909 .29845 Mtetra
.849 .89 .868 r
.31909 .29845 .32715 .30191 .33979 .29121 .33186 .28671 Mtetra
.802 .87 .898 r
.33186 .28671 .33979 .29121 .35232 .28249 .34448 .27737 Mtetra
.736 .851 .934 r
.34448 .27737 .35232 .28249 .36476 .27586 .35699 .27059 Mtetra
.636 .826 .974 r
.35699 .27059 .36476 .27586 .37715 .27138 .3694 .26648 Mtetra
.467 .777 .997 r
.3694 .26648 .37715 .27138 .38949 .26905 .38174 .26506 Mtetra
.184 .65 .937 r
.38174 .26506 .38949 .26905 .40183 .26878 .39406 .26625 Mtetra
0 .41 .706 r
.39406 .26625 .40183 .26878 .41419 .27035 .40639 .26979 Mtetra
.433 0 0 r
.40639 .26979 .41419 .27035 .42662 .27335 .41879 .27518 Mtetra
.545 0 0 r
.41879 .27518 .42662 .27335 .43914 .27715 .43129 .2816 Mtetra
.567 .041 0 r
.43129 .2816 .43914 .27715 .4518 .2809 .44395 .28795 Mtetra
.537 .041 .026 r
.44395 .28795 .4518 .2809 .4646 .28362 .45679 .29296 Mtetra
.467 0 .048 r
.45679 .29296 .4646 .28362 .47756 .28437 .46982 .29536 Mtetra
.358 0 .029 r
.46982 .29536 .47756 .28437 .49066 .28237 .48302 .29416 Mtetra
.201 0 0 r
.48302 .29416 .49066 .28237 .50386 .27723 .49635 .28883 Mtetra
0 0 0 r
.49635 .28883 .50386 .27723 .51713 .269 .50977 .27944 Mtetra
.50977 .27944 .51713 .269 .53043 .25816 .52321 .26662 Mtetra
.52321 .26662 .53043 .25816 .54373 .2455 .53663 .25145 Mtetra
.71 .929 .604 r
.53663 .25145 .54373 .2455 .55702 .23196 .55003 .23516 Mtetra
.83 .988 .723 r
.55003 .23516 .55702 .23196 .57029 .21843 .56338 .21893 Mtetra
.878 .992 .803 r
.56338 .21893 .57029 .21843 .58357 .20563 .57672 .20366 Mtetra
.876 .962 .852 r
.57672 .20366 .58357 .20563 .59687 .19399 .59007 .18994 Mtetra
.847 .919 .881 r
.59007 .18994 .59687 .19399 .61021 .18371 .60345 .17801 Mtetra
.808 .875 .896 r
.60345 .17801 .61021 .18371 .62362 .17476 .61688 .16781 Mtetra
.769 .835 .903 r
.61688 .16781 .62362 .17476 .63709 .16696 .63039 .15912 Mtetra
.735 .803 .906 r
.63039 .15912 .63709 .16696 .65065 .16008 .64398 .15163 Mtetra
.709 .78 .907 r
.64398 .15163 .65065 .16008 .66429 .15387 .65766 .14502 Mtetra
.691 .764 .908 r
.65766 .14502 .66429 .15387 .67801 .14812 .67141 .13901 Mtetra
.679 .754 .908 r
.67141 .13901 .67801 .14812 .6918 .14265 .68525 .13337 Mtetra
.672 .748 .908 r
.68525 .13337 .6918 .14265 .70567 .13734 .69917 .12796 Mtetra
.668 .745 .908 r
.69917 .12796 .70567 .13734 .71962 .13212 .71316 .12265 Mtetra
.666 .743 .908 r
.71316 .12265 .71962 .13212 .73363 .12693 .72722 .1174 Mtetra
.665 .742 .908 r
.72722 .1174 .73363 .12693 .74772 .12175 .74135 .11216 Mtetra
.664 .742 .908 r
.74135 .11216 .74772 .12175 .76188 .11655 .75556 .10691 Mtetra
0 .279 .704 r
.11061 .35759 .11919 .36338 .12944 .36826 .12078 .3631 Mtetra
.49 0 0 r
.12078 .3631 .12944 .36826 .13959 .37489 .13084 .37053 Mtetra
.624 .064 0 r
.13084 .37053 .13959 .37489 .14971 .38285 .14084 .37948 Mtetra
.68 .133 0 r
.14084 .37948 .14971 .38285 .15989 .39141 .15089 .38924 Mtetra
.685 .141 0 r
.15089 .38924 .15989 .39141 .17026 .3996 .16111 .39882 Mtetra
.642 .091 0 r
.16111 .39882 .17026 .3996 .18092 .4063 .17163 .407 Mtetra
.537 0 0 r
.17163 .407 .18092 .4063 .19198 .41046 .18257 .41258 Mtetra
.327 0 0 r
.18257 .41258 .19198 .41046 .20349 .41121 .19401 .41451 Mtetra
0 0 0 r
.19401 .41451 .20349 .41121 .21546 .40803 .20597 .4121 Mtetra
.443 .864 .726 r
.20597 .4121 .21546 .40803 .22786 .40087 .21844 .40516 Mtetra
.723 .985 .792 r
.21844 .40516 .22786 .40087 .24062 .39008 .23132 .39401 Mtetra
.855 .998 .796 r
.23132 .39401 .24062 .39008 .25363 .37638 .24451 .37941 Mtetra
.909 .977 .788 r
.24451 .37941 .25363 .37638 .26679 .36072 .25788 .36248 Mtetra
.926 .951 .785 r
.25788 .36248 .26679 .36072 .27998 .34417 .27129 .34442 Mtetra
.925 .927 .79 r
.27129 .34442 .27998 .34417 .29314 .32774 .28466 .32642 Mtetra
.913 .906 .803 r
.28466 .32642 .29314 .32774 .30618 .31227 .2979 .30951 Mtetra
.89 .889 .823 r
.2979 .30951 .30618 .31227 .31909 .29845 .31097 .29447 Mtetra
.857 .874 .851 r
.31097 .29447 .31909 .29845 .33186 .28671 .32386 .28185 Mtetra
.809 .86 .887 r
.32386 .28185 .33186 .28671 .34448 .27737 .33658 .27201 Mtetra
.736 .845 .932 r
.33658 .27201 .34448 .27737 .35699 .27059 .34913 .26519 Mtetra
.612 .817 .979 r
.34913 .26519 .35699 .27059 .3694 .26648 .36156 .26155 Mtetra
.385 .738 .991 r
.36156 .26155 .3694 .26648 .38174 .26506 .3739 .26114 Mtetra
.007 .531 .855 r
.3739 .26114 .38174 .26506 .39406 .26625 .38618 .26391 Mtetra
.371 0 0 r
.38618 .26391 .39406 .26625 .40639 .26979 .39847 .26955 Mtetra
.574 0 0 r
.39847 .26955 .40639 .26979 .41879 .27518 .41081 .27747 Mtetra
.642 .108 0 r
.41081 .27747 .41879 .27518 .43129 .2816 .42328 .28668 Mtetra
.642 .142 .046 r
.42328 .28668 .43129 .2816 .44395 .28795 .43593 .29581 Mtetra
.601 .124 .094 r
.43593 .29581 .44395 .28795 .45679 .29296 .44879 .30328 Mtetra
.522 .062 .102 r
.44879 .30328 .45679 .29296 .46982 .29536 .46189 .30748 Mtetra
.398 0 .073 r
.46189 .30748 .46982 .29536 .48302 .29416 .4752 .30715 Mtetra
.217 0 0 r
.4752 .30715 .48302 .29416 .49635 .28883 .48867 .30162 Mtetra
0 0 0 r
.48867 .30162 .49635 .28883 .50977 .27944 .50224 .29099 Mtetra
.50224 .29099 .50977 .27944 .52321 .26662 .51583 .27607 Mtetra
.578 .821 .442 r
.51583 .27607 .52321 .26662 .53663 .25145 .52941 .25822 Mtetra
.767 .934 .582 r
.52941 .25822 .53663 .25145 .55003 .23516 .54292 .239 Mtetra
.871 .98 .687 r
.54292 .239 .55003 .23516 .56338 .21893 .55638 .21988 Mtetra
.91 .982 .763 r
.55638 .21988 .56338 .21893 .57672 .20366 .56979 .20201 Mtetra
.905 .958 .817 r
.56979 .20201 .57672 .20366 .59007 .18994 .58319 .18609 Mtetra
.875 .921 .854 r
.58319 .18609 .59007 .18994 .60345 .17801 .59661 .1724 Mtetra
.832 .88 .878 r
.59661 .1724 .60345 .17801 .61688 .16781 .61009 .16089 Mtetra
.788 .842 .892 r
.61009 .16089 .61688 .16781 .63039 .15912 .62363 .15127 Mtetra
.75 .809 .9 r
.62363 .15127 .63039 .15912 .64398 .15163 .63725 .14314 Mtetra
.719 .784 .904 r
.63725 .14314 .64398 .15163 .65766 .14502 .65096 .13611 Mtetra
.697 .767 .906 r
.65096 .13611 .65766 .14502 .67141 .13901 .66476 .12983 Mtetra
.683 .756 .907 r
.66476 .12983 .67141 .13901 .68525 .13337 .67864 .12402 Mtetra
.674 .749 .907 r
.67864 .12402 .68525 .13337 .69917 .12796 .6926 .11848 Mtetra
.669 .745 .908 r
.6926 .11848 .69917 .12796 .71316 .12265 .70664 .1131 Mtetra
.666 .743 .908 r
.70664 .1131 .71316 .12265 .72722 .1174 .72075 .10778 Mtetra
.665 .742 .908 r
.72075 .10778 .72722 .1174 .74135 .11216 .73493 .10248 Mtetra
.664 .742 .908 r
.73493 .10248 .74135 .11216 .75556 .10691 .74919 .09718 Mtetra
0 .227 .662 r
.10197 .35156 .11061 .35759 .12078 .3631 .11207 .35766 Mtetra
.538 0 0 r
.11207 .35766 .12078 .3631 .13084 .37053 .12203 .36584 Mtetra
.662 .113 0 r
.12203 .36584 .13084 .37053 .14084 .37948 .13192 .37569 Mtetra
.713 .177 0 r
.13192 .37569 .14084 .37948 .15089 .38924 .14184 .3865 Mtetra
.716 .183 0 r
.14184 .3865 .15089 .38924 .16111 .39882 .15194 .39721 Mtetra
.676 .131 0 r
.15194 .39721 .16111 .39882 .17163 .407 .16234 .40655 Mtetra
.569 0 0 r
.16234 .40655 .17163 .407 .18257 .41258 .17319 .41318 Mtetra
.33 0 0 r
.17319 .41318 .18257 .41258 .19401 .41451 .18459 .41592 Mtetra
.123 .67 .709 r
.18459 .41592 .19401 .41451 .20597 .4121 .19656 .41398 Mtetra
.588 .947 .872 r
.19656 .41398 .20597 .4121 .21844 .40516 .20909 .40707 Mtetra
.817 .994 .864 r
.20909 .40707 .21844 .40516 .23132 .39401 .2221 .3955 Mtetra
.898 .966 .822 r
.2221 .3955 .23132 .39401 .24451 .37941 .23546 .3801 Mtetra
.924 .932 .793 r
.23546 .3801 .24451 .37941 .25788 .36248 .24902 .36208 Mtetra
.929 .905 .779 r
.24902 .36208 .25788 .36248 .27129 .34442 .26264 .34279 Mtetra
.923 .884 .777 r
.26264 .34279 .27129 .34442 .28466 .32642 .2762 .32355 Mtetra
.909 .869 .787 r
.2762 .32355 .28466 .32642 .2979 .30951 .28961 .3055 Mtetra
.888 .858 .806 r
.28961 .3055 .2979 .30951 .31097 .29447 .30282 .28952 Mtetra
.856 .849 .835 r
.30282 .28952 .31097 .29447 .32386 .28185 .31583 .27624 Mtetra
.809 .841 .875 r
.31583 .27624 .32386 .28185 .33658 .27201 .32862 .26609 Mtetra
.731 .83 .926 r
.32862 .26609 .33658 .27201 .34913 .26519 .34122 .25935 Mtetra
.589 .797 .979 r
.34122 .25935 .34913 .26519 .36156 .26155 .35366 .25624 Mtetra
.31 .688 .978 r
.35366 .25624 .36156 .26155 .3739 .26114 .36598 .25685 Mtetra
0 .417 .78 r
.36598 .25685 .3739 .26114 .38618 .26391 .37822 .26115 Mtetra
.49 0 0 r
.37822 .26115 .38618 .26391 .39847 .26955 .39045 .26884 Mtetra
.654 .099 0 r
.39045 .26884 .39847 .26955 .41081 .27747 .40274 .27921 Mtetra
.702 .185 0 r
.40274 .27921 .41081 .27747 .42328 .28668 .41516 .29111 Mtetra
.695 .203 .073 r
.41516 .29111 .42328 .28668 .43593 .29581 .42778 .30294 Mtetra
.649 .172 .107 r
.42778 .30294 .43593 .29581 .44879 .30328 .44065 .31279 Mtetra
.561 .094 .102 r
.44065 .31279 .44879 .30328 .46189 .30748 .4538 .31875 Mtetra
.413 0 .054 r
.4538 .31875 .46189 .30748 .4752 .30715 .46721 .31927 Mtetra
.181 0 0 r
.46721 .31927 .4752 .30715 .48867 .30162 .48082 .31356 Mtetra
0 0 0 r
.48082 .31356 .48867 .30162 .50224 .29099 .49455 .30172 Mtetra
.49455 .30172 .50224 .29099 .51583 .27607 .50831 .28476 Mtetra
.721 .896 .516 r
.50831 .28476 .51583 .27607 .52941 .25822 .52204 .2643 Mtetra
.86 .957 .615 r
.52204 .2643 .52941 .25822 .54292 .239 .53569 .24224 Mtetra
.923 .971 .686 r
.53569 .24224 .54292 .239 .55638 .21988 .54925 .22033 Mtetra
.939 .961 .742 r
.54925 .22033 .55638 .21988 .56979 .20201 .56275 .19994 Mtetra
.926 .939 .79 r
.56275 .19994 .56979 .20201 .58319 .18609 .57622 .18191 Mtetra
.894 .909 .828 r
.57622 .18191 .58319 .18609 .59661 .1724 .5897 .16655 Mtetra
.85 .875 .858 r
.5897 .16655 .59661 .1724 .61009 .16089 .60321 .15378 Mtetra
.804 .84 .878 r
.60321 .15378 .61009 .16089 .62363 .15127 .61679 .14326 Mtetra
.762 .81 .891 r
.61679 .14326 .62363 .15127 .63725 .14314 .63045 .13452 Mtetra
.728 .786 .899 r
.63045 .13452 .63725 .14314 .65096 .13611 .64421 .12709 Mtetra
.703 .768 .903 r
.64421 .12709 .65096 .13611 .66476 .12983 .65804 .12055 Mtetra
.686 .757 .905 r
.65804 .12055 .66476 .12983 .67864 .12402 .67197 .11457 Mtetra
.676 .75 .906 r
.67197 .11457 .67864 .12402 .6926 .11848 .68597 .10892 Mtetra
.67 .746 .907 r
.68597 .10892 .6926 .11848 .70664 .1131 .70006 .10345 Mtetra
.667 .743 .908 r
.70006 .10345 .70664 .1131 .72075 .10778 .71421 .09807 Mtetra
.665 .742 .908 r
.71421 .09807 .72075 .10778 .73493 .10248 .72845 .09272 Mtetra
.664 .742 .908 r
.72845 .09272 .73493 .10248 .74919 .09718 .74275 .08736 Mtetra
0 .213 .668 r
.09334 .34485 .10197 .35156 .11207 .35766 .10338 .35133 Mtetra
.531 0 0 r
.10338 .35133 .11207 .35766 .12203 .36584 .11328 .35998 Mtetra
.657 .117 0 r
.11328 .35998 .12203 .36584 .13192 .37569 .12308 .3704 Mtetra
.71 .18 0 r
.12308 .3704 .13192 .37569 .14184 .3865 .13292 .38186 Mtetra
.714 .181 0 r
.13292 .38186 .14184 .3865 .15194 .39721 .14292 .39327 Mtetra
.667 .116 0 r
.14292 .39327 .15194 .39721 .16234 .40655 .15325 .4033 Mtetra
.529 0 0 r
.15325 .4033 .16234 .40655 .17319 .41318 .16405 .41054 Mtetra
0 .402 .685 r
.16405 .41054 .17319 .41318 .18459 .41592 .17542 .41375 Mtetra
.361 .801 .96 r
.17542 .41375 .18459 .41592 .19656 .41398 .18741 .41204 Mtetra
.72 .932 .959 r
.18741 .41204 .19656 .41398 .20909 .40707 .20001 .40509 Mtetra
.85 .919 .878 r
.20001 .40509 .20909 .40707 .2221 .3955 .21312 .39322 Mtetra
.894 .888 .817 r
.21312 .39322 .2221 .3955 .23546 .3801 .22661 .37729 Mtetra
.909 .863 .783 r
.22661 .37729 .23546 .3801 .24902 .36208 .24032 .35857 Mtetra
.911 .845 .766 r
.24032 .35857 .24902 .36208 .26264 .34279 .25409 .33851 Mtetra
.906 .834 .763 r
.25409 .33851 .26264 .34279 .2762 .32355 .2678 .3185 Mtetra
.895 .826 .772 r
.2678 .3185 .2762 .32355 .28961 .3055 .28135 .29976 Mtetra
.876 .821 .791 r
.28135 .29976 .28961 .3055 .30282 .28952 .29468 .28323 Mtetra
.848 .818 .82 r
.29468 .28323 .30282 .28952 .31583 .27624 .30777 .26959 Mtetra
.802 .815 .862 r
.30777 .26959 .31583 .27624 .32862 .26609 .32063 .25932 Mtetra
.723 .806 .916 r
.32063 .25932 .32862 .26609 .34122 .25935 .33327 .25277 Mtetra
.57 .769 .973 r
.33327 .25277 .34122 .25935 .35366 .25624 .34571 .25018 Mtetra
.262 .638 .963 r
.34571 .25018 .35366 .25624 .36598 .25685 .35801 .2517 Mtetra
0 .339 .744 r
.35801 .2517 .36598 .25685 .37822 .26115 .37022 .25733 Mtetra
.545 0 0 r
.37022 .25733 .37822 .26115 .39045 .26884 .38239 .26675 Mtetra
.695 .153 0 r
.38239 .26675 .39045 .26884 .40274 .27921 .39461 .27921 Mtetra
.742 .227 0 r
.39461 .27921 .40274 .27921 .41516 .29111 .40697 .29341 Mtetra
.736 .238 .047 r
.40697 .29341 .41516 .29111 .42778 .30294 .41956 .30754 Mtetra
.69 .196 .066 r
.41956 .30754 .42778 .30294 .44065 .31279 .43243 .31942 Mtetra
.591 .093 .038 r
.43243 .31942 .44065 .31279 .4538 .31875 .44563 .32687 Mtetra
.398 0 0 r
.44563 .32687 .4538 .31875 .46721 .31927 .45912 .32813 Mtetra
.053 0 0 r
.45912 .32813 .46721 .31927 .48082 .31356 .47285 .32225 Mtetra
0 0 0 r
.47285 .32225 .48082 .31356 .49455 .30172 .48673 .30937 Mtetra
.724 .919 .567 r
.48673 .30937 .49455 .30172 .50831 .28476 .50065 .29065 Mtetra
.88 .962 .63 r
.50065 .29065 .50831 .28476 .52204 .2643 .51453 .26796 Mtetra
.942 .958 .667 r
.51453 .26796 .52204 .2643 .53569 .24224 .52832 .24347 Mtetra
.96 .943 .699 r
.52832 .24347 .53569 .24224 .54925 .22033 .54201 .21919 Mtetra
.955 .926 .733 r
.54201 .21919 .54925 .22033 .56275 .19994 .55561 .19666 Mtetra
.935 .907 .77 r
.55561 .19666 .56275 .19994 .57622 .18191 .56915 .17683 Mtetra
.901 .884 .807 r
.56915 .17683 .57622 .18191 .5897 .16655 .58269 .16005 Mtetra
.859 .859 .839 r
.58269 .16005 .5897 .16655 .60321 .15378 .59625 .14622 Mtetra
.814 .832 .864 r
.59625 .14622 .60321 .15378 .61679 .14326 .60988 .13495 Mtetra
.77 .806 .882 r
.60988 .13495 .61679 .14326 .63045 .13452 .62359 .12569 Mtetra
.734 .784 .893 r
.62359 .12569 .63045 .13452 .64421 .12709 .63738 .11791 Mtetra
.707 .768 .899 r
.63738 .11791 .64421 .12709 .65804 .12055 .65126 .11114 Mtetra
.689 .757 .903 r
.65126 .11114 .65804 .12055 .67197 .11457 .66523 .10501 Mtetra
.677 .75 .906 r
.66523 .10501 .67197 .11457 .68597 .10892 .67928 .09926 Mtetra
.671 .746 .907 r
.67928 .09926 .68597 .10892 .70006 .10345 .69341 .09371 Mtetra
.667 .743 .907 r
.69341 .09371 .70006 .10345 .71421 .09807 .70762 .08827 Mtetra
.665 .742 .908 r
.70762 .08827 .71421 .09807 .72845 .09272 .7219 .08286 Mtetra
.664 .742 .908 r
.7219 .08286 .72845 .09272 .74275 .08736 .73626 .07745 Mtetra
0 .239 .714 r
.08475 .33719 .09334 .34485 .10338 .35133 .09478 .34371 Mtetra
0 .052 .532 r
.09478 .34371 .10338 .35133 .11328 .35998 .10465 .35242 Mtetra
.597 .076 0 r
.10465 .35242 .11328 .35998 .12308 .3704 .11443 .36293 Mtetra
.654 .136 0 r
.11443 .36293 .12308 .3704 .13292 .38186 .12423 .37449 Mtetra
.647 .127 0 r
.12423 .37449 .13292 .38186 .14292 .39327 .1342 .38603 Mtetra
.563 .034 0 r
.1342 .38603 .14292 .39327 .15325 .4033 .1445 .3962 Mtetra
0 .187 .65 r
.1445 .3962 .15325 .4033 .16405 .41054 .15528 .40358 Mtetra
.107 .521 .91 r
.15528 .40358 .16405 .41054 .17542 .41375 .16665 .40688 Mtetra
.525 .743 .975 r
.16665 .40688 .17542 .41375 .18741 .41204 .17866 .40522 Mtetra
.733 .801 .906 r
.17866 .40522 .18741 .41204 .20001 .40509 .1913 .39827 Mtetra
.819 .803 .836 r
.1913 .39827 .20001 .40509 .21312 .39322 .20448 .38631 Mtetra
.857 .796 .789 r
.20448 .38631 .21312 .39322 .22661 .37729 .21805 .37025 Mtetra
.874 .789 .762 r
.21805 .37025 .22661 .37729 .24032 .35857 .23185 .35135 Mtetra
.881 .784 .75 r
.23185 .35135 .24032 .35857 .25409 .33851 .24573 .33108 Mtetra
.88 .782 .749 r
.24573 .33108 .25409 .33851 .2678 .3185 .25953 .31088 Mtetra
.873 .782 .758 r
.25953 .31088 .2678 .3185 .28135 .29976 .27317 .29197 Mtetra
.858 .783 .777 r
.27317 .29197 .28135 .29976 .29468 .28323 .28658 .27533 Mtetra
.833 .785 .807 r
.28658 .27533 .29468 .28323 .30777 .26959 .29973 .26167 Mtetra
.79 .785 .848 r
.29973 .26167 .30777 .26959 .32063 .25932 .31263 .2515 Mtetra
.711 .777 .903 r
.31263 .2515 .32063 .25932 .33327 .25277 .32529 .24519 Mtetra
.556 .735 .959 r
.32529 .24519 .33327 .25277 .34571 .25018 .33775 .24305 Mtetra
.249 .598 .951 r
.33775 .24305 .34571 .25018 .35801 .2517 .35003 .24525 Mtetra
0 .306 .751 r
.35003 .24525 .35801 .2517 .37022 .25733 .3622 .25183 Mtetra
.539 0 0 r
.3622 .25183 .37022 .25733 .38239 .26675 .37432 .26246 Mtetra
.698 .165 0 r
.37432 .26246 .38239 .26675 .39461 .27921 .38649 .27635 Mtetra
.755 .238 0 r
.38649 .27635 .39461 .27921 .40697 .29341 .3988 .29213 Mtetra
.758 .244 0 r
.3988 .29213 .40697 .29341 .41956 .30754 .41135 .30785 Mtetra
.714 .188 0 r
.41135 .30785 .41956 .30754 .43243 .31942 .42422 .32114 Mtetra
.594 .037 0 r
.42422 .32114 .43243 .31942 .44563 .32687 .43744 .32962 Mtetra
.29 0 0 r
.43744 .32962 .44563 .32687 .45912 .32813 .451 .33137 Mtetra
.303 .778 .673 r
.451 .33137 .45912 .32813 .47285 .32225 .46483 .32536 Mtetra
.762 .989 .769 r
.46483 .32536 .47285 .32225 .48673 .30937 .47884 .31175 Mtetra
.916 .98 .738 r
.47884 .31175 .48673 .30937 .50065 .29065 .4929 .29178 Mtetra
.959 .942 .709 r
.4929 .29178 .50065 .29065 .51453 .26796 .50692 .26753 Mtetra
.968 .912 .7 r
.50692 .26753 .51453 .26796 .52832 .24347 .52085 .24135 Mtetra
.964 .892 .708 r
.52085 .24135 .52832 .24347 .54201 .21919 .53465 .21541 Mtetra
.951 .877 .727 r
.53465 .21541 .54201 .21919 .55561 .19666 .54835 .1914 Mtetra
.929 .865 .756 r
.54835 .1914 .55561 .19666 .56915 .17683 .56198 .17033 Mtetra
.898 .852 .789 r
.56198 .17033 .56915 .17683 .58269 .16005 .57558 .15256 Mtetra
.859 .836 .822 r
.57558 .15256 .58269 .16005 .59625 .14622 .58921 .13799 Mtetra
.816 .817 .85 r
.58921 .13799 .59625 .14622 .60988 .13495 .60289 .12617 Mtetra
.774 .798 .872 r
.60289 .12617 .60988 .13495 .62359 .12569 .61665 .11654 Mtetra
.738 .78 .887 r
.61665 .11654 .62359 .12569 .63738 .11791 .63049 .10851 Mtetra
.71 .766 .896 r
.63049 .10851 .63738 .11791 .65126 .11114 .64442 .10157 Mtetra
.69 .756 .901 r
.64442 .10157 .65126 .11114 .66523 .10501 .65843 .09533 Mtetra
.678 .749 .905 r
.65843 .09533 .66523 .10501 .67928 .09926 .67253 .08949 Mtetra
.671 .745 .906 r
.67253 .08949 .67928 .09926 .69341 .09371 .68671 .08388 Mtetra
.667 .743 .907 r
.68671 .08388 .69341 .09371 .70762 .08827 .70097 .07837 Mtetra
.665 .742 .908 r
.70097 .07837 .70762 .08827 .7219 .08286 .7153 .07291 Mtetra
.664 .742 .908 r
.7153 .07291 .7219 .08286 .73626 .07745 .7297 .06745 Mtetra
0 .295 .778 r
.07624 .32846 .08475 .33719 .09478 .34371 .0863 .33465 Mtetra
0 .13 .642 r
.0863 .33465 .09478 .34371 .10465 .35242 .09621 .34295 Mtetra
0 .013 .534 r
.09621 .34295 .10465 .35242 .11443 .36293 .10602 .353 Mtetra
0 0 .49 r
.10602 .353 .11443 .36293 .12423 .37449 .11585 .36408 Mtetra
0 0 .526 r
.11585 .36408 .12423 .37449 .1342 .38603 .12585 .37514 Mtetra
0 .107 .645 r
.12585 .37514 .1342 .38603 .1445 .3962 .13618 .38487 Mtetra
0 .309 .801 r
.13618 .38487 .1445 .3962 .15528 .40358 .14698 .39189 Mtetra
.32 .511 .887 r
.14698 .39189 .15528 .40358 .16665 .40688 .15837 .39496 Mtetra
.565 .629 .874 r
.15837 .39496 .16665 .40688 .17866 .40522 .1704 .3932 Mtetra
.7 .681 .828 r
.1704 .3932 .17866 .40522 .1913 .39827 .18306 .38629 Mtetra
.773 .704 .787 r
.18306 .38629 .1913 .39827 .20448 .38631 .19625 .37453 Mtetra
.812 .715 .758 r
.19625 .37453 .20448 .38631 .21805 .37025 .20985 .35876 Mtetra
.834 .723 .741 r
.20985 .35876 .21805 .37025 .23185 .35135 .22367 .34023 Mtetra
.846 .729 .734 r
.22367 .34023 .23185 .35135 .24573 .33108 .23758 .32037 Mtetra
.85 .735 .736 r
.23758 .32037 .24573 .33108 .25953 .31088 .25141 .30058 Mtetra
.847 .741 .747 r
.25141 .30058 .25953 .31088 .27317 .29197 .26508 .28205 Mtetra
.836 .748 .766 r
.26508 .28205 .27317 .29197 .28658 .27533 .27853 .26576 Mtetra
.814 .753 .796 r
.27853 .26576 .28658 .27533 .29973 .26167 .29171 .2524 Mtetra
.774 .755 .836 r
.29171 .2524 .29973 .26167 .31263 .2515 .30463 .24251 Mtetra
.698 .746 .888 r
.30463 .24251 .31263 .2515 .32529 .24519 .31731 .23649 Mtetra
.551 .702 .94 r
.31731 .23649 .32529 .24519 .33775 .24305 .32978 .23464 Mtetra
.27 .572 .938 r
.32978 .23464 .33775 .24305 .35003 .24525 .34206 .2372 Mtetra
0 .314 .786 r
.34206 .2372 .35003 .24525 .3622 .25183 .35421 .2442 Mtetra
0 .041 .534 r
.35421 .2442 .3622 .25183 .37432 .26246 .36631 .25534 Mtetra
.64 .129 0 r
.36631 .25534 .37432 .26246 .38649 .27635 .37844 .26982 Mtetra
.71 .203 0 r
.37844 .26982 .38649 .27635 .3988 .29213 .39072 .28623 Mtetra
.714 .201 0 r
.39072 .28623 .3988 .29213 .41135 .30785 .40324 .30258 Mtetra
.648 .112 0 r
.40324 .30258 .41135 .30785 .42422 .32114 .41609 .31642 Mtetra
.432 0 0 r
.41609 .31642 .42422 .32114 .43744 .32962 .42932 .3253 Mtetra
.115 .606 .908 r
.42932 .3253 .43744 .32962 .451 .33137 .44293 .32723 Mtetra
.669 .895 .978 r
.44293 .32723 .451 .33137 .46483 .32536 .45683 .32114 Mtetra
.866 .906 .857 r
.45683 .32114 .46483 .32536 .47884 .31175 .47093 .30719 Mtetra
.923 .874 .771 r
.47093 .30719 .47884 .31175 .4929 .29178 .4851 .28669 Mtetra
.94 .85 .726 r
.4851 .28669 .4929 .29178 .50692 .26753 .49924 .26178 Mtetra
.943 .835 .707 r
.49924 .26178 .50692 .26753 .52085 .24135 .51328 .23487 Mtetra
.939 .826 .707 r
.51328 .23487 .52085 .24135 .53465 .21541 .5272 .20824 Mtetra
.928 .822 .721 r
.5272 .20824 .53465 .21541 .54835 .1914 .54099 .1836 Mtetra
.91 .819 .745 r
.54099 .1836 .54835 .1914 .56198 .17033 .55471 .16199 Mtetra
.884 .815 .775 r
.55471 .16199 .56198 .17033 .57558 .15256 .56839 .1438 Mtetra
.851 .809 .809 r
.56839 .1438 .57558 .15256 .58921 .13799 .58208 .1289 Mtetra
.812 .798 .839 r
.58208 .1289 .58921 .13799 .60289 .12617 .59582 .11684 Mtetra
.773 .786 .864 r
.59582 .11684 .60289 .12617 .61665 .11654 .60963 .10703 Mtetra
.738 .773 .881 r
.60963 .10703 .61665 .11654 .63049 .10851 .62352 .09887 Mtetra
.71 .762 .893 r
.62352 .09887 .63049 .10851 .64442 .10157 .6375 .09183 Mtetra
.691 .754 .9 r
.6375 .09183 .64442 .10157 .65843 .09533 .65157 .08551 Mtetra
.679 .748 .904 r
.65157 .08551 .65843 .09533 .67253 .08949 .66572 .07961 Mtetra
.671 .745 .906 r
.66572 .07961 .67253 .08949 .68671 .08388 .67994 .07394 Mtetra
.667 .743 .907 r
.67994 .07394 .68671 .08388 .70097 .07837 .69425 .06838 Mtetra
.665 .742 .907 r
.69425 .06838 .70097 .07837 .7153 .07291 .70863 .06286 Mtetra
.664 .742 .908 r
.70863 .06286 .7153 .07291 .7297 .06745 .72309 .05735 Mtetra
.004 .364 .834 r
.06779 .31872 .07624 .32846 .0863 .33465 .07794 .3242 Mtetra
0 .231 .745 r
.07794 .3242 .0863 .33465 .09621 .34295 .08794 .33165 Mtetra
0 .135 .673 r
.08794 .33165 .09621 .34295 .10602 .353 .09785 .34073 Mtetra
0 .099 .649 r
.09785 .34073 .10602 .353 .11585 .36408 .10779 .35077 Mtetra
0 .133 .68 r
.10779 .35077 .11585 .36408 .12585 .37514 .11788 .36078 Mtetra
0 .232 .746 r
.11788 .36078 .12585 .37514 .13618 .38487 .12829 .36954 Mtetra
.203 .363 .802 r
.12829 .36954 .13618 .38487 .14698 .39189 .13915 .37576 Mtetra
.416 .478 .815 r
.13915 .37576 .14698 .39189 .15837 .39496 .15058 .37829 Mtetra
.57 .555 .798 r
.15058 .37829 .15837 .39496 .1704 .3932 .16262 .37632 Mtetra
.67 .603 .772 r
.16262 .37632 .1704 .3932 .18306 .38629 .17527 .36954 Mtetra
.732 .633 .749 r
.17527 .36954 .18306 .38629 .19625 .37453 .18844 .35823 Mtetra
.772 .654 .733 r
.18844 .35823 .19625 .37453 .20985 .35876 .20199 .34317 Mtetra
.797 .67 .724 r
.20199 .34317 .20985 .35876 .22367 .34023 .21578 .32553 Mtetra
.812 .683 .722 r
.21578 .32553 .22367 .34023 .23758 .32037 .22964 .30663 Mtetra
.82 .695 .727 r
.22964 .30663 .23758 .32037 .25141 .30058 .24345 .28779 Mtetra
.821 .706 .739 r
.24345 .28779 .25141 .30058 .26508 .28205 .2571 .27015 Mtetra
.813 .717 .759 r
.2571 .27015 .26508 .28205 .27853 .26576 .27053 .25461 Mtetra
.794 .725 .788 r
.27053 .25461 .27853 .26576 .29171 .2524 .28372 .24185 Mtetra
.756 .728 .826 r
.28372 .24185 .29171 .2524 .30463 .24251 .29665 .2324 Mtetra
.685 .717 .874 r
.29665 .2324 .30463 .24251 .31731 .23649 .30934 .22664 Mtetra
.551 .674 .919 r
.30934 .22664 .31731 .23649 .32978 .23464 .32182 .22491 Mtetra
.314 .559 .923 r
.32182 .22491 .32978 .23464 .34206 .2372 .33411 .22744 Mtetra
0 .349 .825 r
.33411 .22744 .34206 .2372 .35421 .2442 .34627 .23427 Mtetra
0 .118 .648 r
.34627 .23427 .35421 .2442 .36631 .25534 .35837 .24514 Mtetra
0 0 .501 r
.35837 .24514 .36631 .25534 .37844 .26982 .3705 .25926 Mtetra
0 0 .438 r
.3705 .25926 .37844 .26982 .39072 .28623 .38277 .27526 Mtetra
0 0 .471 r
.38277 .27526 .39072 .28623 .40324 .30258 .39528 .29117 Mtetra
0 .057 .606 r
.39528 .29117 .40324 .30258 .41609 .31642 .40813 .30462 Mtetra
0 .311 .802 r
.40813 .30462 .41609 .31642 .42932 .3253 .42137 .31319 Mtetra
.409 .566 .898 r
.42137 .31319 .42932 .3253 .44293 .32723 .43499 .31494 Mtetra
.675 .691 .857 r
.43499 .31494 .44293 .32723 .45683 .32114 .44892 .30883 Mtetra
.799 .732 .79 r
.44892 .30883 .45683 .32114 .47093 .30719 .46307 .295 Mtetra
.855 .745 .741 r
.46307 .295 .47093 .30719 .4851 .28669 .47731 .27476 Mtetra
.883 .751 .712 r
.47731 .27476 .4851 .28669 .49924 .26178 .49154 .25017 Mtetra
.895 .756 .7 r
.49154 .25017 .49924 .26178 .51328 .23487 .50566 .22363 Mtetra
.899 .761 .701 r
.50566 .22363 .51328 .23487 .5272 .20824 .51967 .19735 Mtetra
.895 .768 .714 r
.51967 .19735 .5272 .20824 .54099 .1836 .53355 .17302 Mtetra
.883 .774 .736 r
.53355 .17302 .54099 .1836 .55471 .16199 .54735 .15166 Mtetra
.863 .779 .766 r
.54735 .15166 .55471 .16199 .56839 .1438 .56111 .13366 Mtetra
.836 .781 .799 r
.56111 .13366 .56839 .1438 .58208 .1289 .57487 .11888 Mtetra
.802 .778 .831 r
.57487 .11888 .58208 .1289 .59582 .11684 .58867 .1069 Mtetra
.767 .772 .857 r
.58867 .1069 .59582 .11684 .60963 .10703 .60254 .09712 Mtetra
.734 .765 .877 r
.60254 .09712 .60963 .10703 .62352 .09887 .61649 .08896 Mtetra
.709 .757 .89 r
.61649 .08896 .62352 .09887 .6375 .09183 .63052 .08191 Mtetra
.69 .751 .898 r
.63052 .08191 .6375 .09183 .65157 .08551 .64464 .07555 Mtetra
.678 .747 .903 r
.64464 .07555 .65157 .08551 .66572 .07961 .65883 .06961 Mtetra
.671 .744 .905 r
.65883 .06961 .66572 .07961 .67994 .07394 .67311 .06389 Mtetra
.667 .743 .907 r
.67311 .06389 .67994 .07394 .69425 .06838 .68747 .05829 Mtetra
.665 .742 .907 r
.68747 .05829 .69425 .06838 .70863 .06286 .7019 .05272 Mtetra
.664 .742 .908 r
.7019 .05272 .70863 .06286 .72309 .05735 .71641 .04716 Mtetra
.146 .432 .87 r
.05939 .30813 .06779 .31872 .07794 .3242 .06968 .3126 Mtetra
.028 .33 .813 r
.06968 .3126 .07794 .3242 .08794 .33165 .07982 .31884 Mtetra
0 .255 .765 r
.07982 .31884 .08794 .33165 .09785 .34073 .08989 .32654 Mtetra
0 .226 .743 r
.08989 .32654 .09785 .34073 .10779 .35077 .09999 .33508 Mtetra
.041 .249 .748 r
.09999 .33508 .10779 .35077 .11788 .36078 .11023 .34358 Mtetra
.174 .311 .764 r
.11023 .34358 .11788 .36078 .12829 .36954 .12077 .35095 Mtetra
.327 .388 .772 r
.12077 .35095 .12829 .36954 .13915 .37576 .13173 .35604 Mtetra
.465 .459 .767 r
.13173 .35604 .13915 .37576 .15058 .37829 .14321 .3578 Mtetra
.571 .514 .753 r
.14321 .3578 .15058 .37829 .16262 .37632 .15527 .35553 Mtetra
.648 .556 .737 r
.15527 .35553 .16262 .37632 .17527 .36954 .16789 .34894 Mtetra
.701 .586 .724 r
.16789 .34894 .17527 .36954 .18844 .35823 .18099 .33829 Mtetra
.739 .611 .715 r
.18099 .33829 .18844 .35823 .20199 .34317 .19445 .32427 Mtetra
.765 .63 .712 r
.19445 .32427 .20199 .34317 .21578 .32553 .20814 .30792 Mtetra
.782 .648 .714 r
.20814 .30792 .21578 .32553 .22964 .30663 .2219 .29044 Mtetra
.792 .664 .721 r
.2219 .29044 .22964 .30663 .24345 .28779 .23562 .27299 Mtetra
.796 .678 .735 r
.23562 .27299 .24345 .28779 .2571 .27015 .2492 .25663 Mtetra
.79 .691 .755 r
.2492 .25663 .2571 .27015 .27053 .25461 .26259 .24216 Mtetra
.774 .701 .783 r
.26259 .24216 .27053 .25461 .28372 .24185 .27574 .23022 Mtetra
.739 .705 .819 r
.27574 .23022 .28372 .24185 .29665 .2324 .28867 .2213 Mtetra
.674 .695 .861 r
.28867 .2213 .29665 .2324 .30934 .22664 .30137 .21577 Mtetra
.558 .654 .899 r
.30137 .21577 .30934 .22664 .32182 .22491 .31387 .21395 Mtetra
.366 .557 .907 r
.31387 .21395 .32182 .22491 .33411 .22744 .3262 .21607 Mtetra
.113 .395 .849 r
.3262 .21607 .33411 .22744 .34627 .23427 .33839 .22218 Mtetra
0 .216 .74 r
.33839 .22218 .34627 .23427 .35837 .24514 .35053 .23203 Mtetra
0 .089 .645 r
.35053 .23203 .35837 .24514 .3705 .25926 .3627 .24489 Mtetra
0 .045 .612 r
.3627 .24489 .3705 .25926 .38277 .27526 .37499 .25948 Mtetra
0 .085 .645 r
.37499 .25948 .38277 .27526 .39528 .29117 .38752 .27396 Mtetra
0 .203 .718 r
.38752 .27396 .39528 .29117 .40813 .30462 .40038 .28612 Mtetra
.252 .356 .776 r
.40038 .28612 .40813 .30462 .42137 .31319 .41361 .29373 Mtetra
.482 .486 .785 r
.41361 .29373 .42137 .31319 .43499 .31494 .42723 .29496 Mtetra
.639 .57 .761 r
.42723 .29496 .43499 .31494 .44892 .30883 .44116 .28888 Mtetra
.734 .62 .732 r
.44116 .28888 .44892 .30883 .46307 .295 .45532 .27561 Mtetra
.791 .651 .708 r
.45532 .27561 .46307 .295 .47731 .27476 .46958 .25635 Mtetra
.825 .673 .694 r
.46958 .25635 .47731 .27476 .49154 .25017 .48384 .23303 Mtetra
.846 .69 .689 r
.48384 .23303 .49154 .25017 .50566 .22363 .49802 .20787 Mtetra
.856 .706 .694 r
.49802 .20787 .50566 .22363 .51967 .19735 .51209 .18293 Mtetra
.859 .72 .709 r
.51209 .18293 .51967 .19735 .53355 .17302 .52605 .15981 Mtetra
.853 .734 .731 r
.52605 .15981 .53355 .17302 .54735 .15166 .53992 .13944 Mtetra
.839 .746 .761 r
.53992 .13944 .54735 .15166 .56111 .13366 .55375 .1222 Mtetra
.817 .755 .794 r
.55375 .1222 .56111 .13366 .57487 .11888 .56758 .10799 Mtetra
.789 .759 .826 r
.56758 .10799 .57487 .11888 .58867 .1069 .58145 .09638 Mtetra
.758 .759 .854 r
.58145 .09638 .58867 .1069 .60254 .09712 .59538 .08683 Mtetra
.729 .756 .874 r
.59538 .08683 .60254 .09712 .61649 .08896 .60939 .0788 Mtetra
.705 .752 .888 r
.60939 .0788 .61649 .08896 .63052 .08191 .62347 .0718 Mtetra
.688 .748 .897 r
.62347 .0718 .63052 .08191 .64464 .07555 .63764 .06546 Mtetra
.677 .745 .902 r
.63764 .06546 .64464 .07555 .65883 .06961 .65189 .0595 Mtetra
.671 .743 .905 r
.65189 .0595 .65883 .06961 .67311 .06389 .66622 .05374 Mtetra
.667 .742 .907 r
.66622 .05374 .67311 .06389 .68747 .05829 .68062 .04809 Mtetra
.665 .742 .907 r
.68062 .04809 .68747 .05829 .7019 .05272 .69511 .04248 Mtetra
.664 .742 .908 r
.69511 .04248 .7019 .05272 .71641 .04716 .70967 .03687 Mtetra
.27 .49 .886 r
.05102 .29694 .05939 .30813 .06968 .3126 .06147 .3002 Mtetra
.188 .412 .848 r
.06147 .3002 .06968 .3126 .07982 .31884 .0718 .30499 Mtetra
.143 .352 .81 r
.0718 .30499 .07982 .31884 .08989 .32654 .08207 .31102 Mtetra
.151 .323 .784 r
.08207 .31102 .08989 .32654 .09999 .33508 .09237 .31777 Mtetra
.208 .33 .769 r
.09237 .31777 .09999 .33508 .11023 .34358 .10281 .32447 Mtetra
.299 .363 .76 r
.10281 .32447 .11023 .34358 .12077 .35095 .11351 .33018 Mtetra
.401 .408 .751 r
.11351 .33018 .12077 .35095 .13173 .35604 .1246 .33391 Mtetra
.495 .453 .74 r
.1246 .33391 .13173 .35604 .14321 .3578 .13615 .33476 Mtetra
.573 .494 .728 r
.13615 .33476 .14321 .3578 .15527 .35553 .14822 .33213 Mtetra
.633 .528 .718 r
.14822 .33213 .15527 .35553 .16789 .34894 .16078 .32578 Mtetra
.679 .557 .71 r
.16078 .32578 .16789 .34894 .18099 .33829 .17379 .31592 Mtetra
.714 .581 .706 r
.17379 .31592 .18099 .33829 .19445 .32427 .18712 .30315 Mtetra
.739 .603 .706 r
.18712 .30315 .19445 .32427 .20814 .30792 .20067 .28835 Mtetra
.757 .622 .71 r
.20067 .28835 .20814 .30792 .2219 .29044 .21429 .27257 Mtetra
.768 .64 .72 r
.21429 .27257 .2219 .29044 .23562 .27299 .22788 .25682 Mtetra
.773 .657 .735 r
.22788 .25682 .23562 .27299 .2492 .25663 .24135 .24198 Mtetra
.769 .672 .756 r
.24135 .24198 .2492 .25663 .26259 .24216 .25466 .22879 Mtetra
.755 .684 .783 r
.25466 .22879 .26259 .24216 .27574 .23022 .26778 .21781 Mtetra
.723 .688 .816 r
.26778 .21781 .27574 .23022 .28867 .2213 .28069 .20946 Mtetra
.666 .679 .852 r
.28069 .20946 .28867 .2213 .30137 .21577 .2934 .2041 Mtetra
.568 .642 .884 r
.2934 .2041 .30137 .21577 .31387 .21395 .30593 .20201 Mtetra
.419 .564 .892 r
.30593 .20201 .31387 .21395 .3262 .21607 .31831 .20341 Mtetra
.234 .441 .859 r
.31831 .20341 .3262 .21607 .33839 .22218 .33057 .20834 Mtetra
.066 .308 .792 r
.33057 .20834 .33839 .22218 .35053 .23203 .34278 .21656 Mtetra
0 .212 .731 r
.34278 .21656 .35053 .23203 .3627 .24489 .35501 .22744 Mtetra
0 .179 .702 r
.35501 .22744 .3627 .24489 .37499 .25948 .36737 .23983 Mtetra
.057 .208 .706 r
.36737 .23983 .37499 .25948 .38752 .27396 .37994 .25209 Mtetra
.204 .282 .722 r
.37994 .25209 .38752 .27396 .40038 .28612 .39282 .26227 Mtetra
.366 .37 .731 r
.39282 .26227 .40038 .28612 .41361 .29373 .40606 .26839 Mtetra
.508 .449 .725 r
.40606 .26839 .41361 .29373 .42723 .29496 .41965 .26886 Mtetra
.615 .51 .711 r
.41965 .26886 .42723 .29496 .44116 .28888 .43356 .26284 Mtetra
.69 .556 .697 r
.43356 .26284 .44116 .28888 .45532 .27561 .44768 .25046 Mtetra
.743 .59 .686 r
.44768 .25046 .45532 .27561 .46958 .25635 .46193 .23276 Mtetra
.778 .617 .68 r
.46193 .23276 .46958 .25635 .48384 .23303 .47618 .21144 Mtetra
.802 .641 .682 r
.47618 .21144 .48384 .23303 .49802 .20787 .49038 .18847 Mtetra
.817 .662 .69 r
.49038 .18847 .49802 .20787 .51209 .18293 .50449 .16566 Mtetra
.824 .682 .707 r
.50449 .16566 .51209 .18293 .52605 .15981 .51849 .14445 Mtetra
.823 .701 .73 r
.51849 .14445 .52605 .15981 .53992 .13944 .53243 .12567 Mtetra
.814 .718 .76 r
.53243 .12567 .53992 .13944 .55375 .1222 .54633 .10967 Mtetra
.796 .732 .793 r
.54633 .10967 .55375 .1222 .56758 .10799 .56023 .09636 Mtetra
.773 .742 .825 r
.56023 .09636 .56758 .10799 .58145 .09638 .57416 .08537 Mtetra
.746 .747 .853 r
.57416 .08537 .58145 .09638 .59538 .08683 .58815 .07622 Mtetra
.721 .748 .874 r
.58815 .07622 .59538 .08683 .60939 .0788 .60221 .06842 Mtetra
.7 .747 .888 r
.60221 .06842 .60939 .0788 .62347 .0718 .61635 .06153 Mtetra
.685 .745 .897 r
.61635 .06153 .62347 .0718 .63764 .06546 .63057 .05523 Mtetra
.676 .744 .902 r
.63057 .05523 .63764 .06546 .65189 .0595 .64488 .04927 Mtetra
.67 .743 .905 r
.64488 .04927 .65189 .0595 .66622 .05374 .65926 .04349 Mtetra
.667 .742 .906 r
.65926 .04349 .66622 .05374 .68062 .04809 .67371 .0378 Mtetra
.665 .742 .907 r
.67371 .0378 .68062 .04809 .69511 .04248 .68825 .03214 Mtetra
.664 .741 .908 r
.68825 .03214 .69511 .04248 .70967 .03687 .70286 .02648 Mtetra
.369 .538 .891 r
.04263 .28544 .05102 .29694 .06147 .3002 .05327 .28739 Mtetra
.312 .477 .862 r
.05327 .28739 .06147 .3002 .0718 .30499 .06381 .29061 Mtetra
.281 .426 .83 r
.06381 .29061 .0718 .30499 .08207 .31102 .0743 .29486 Mtetra
.285 .396 .801 r
.0743 .29486 .08207 .31102 .09237 .31777 .08483 .29969 Mtetra
.322 .39 .777 r
.08483 .29969 .09237 .31777 .10281 .32447 .09549 .30446 Mtetra
.382 .404 .758 r
.09549 .30446 .10281 .32447 .11351 .33018 .10638 .3084 Mtetra
.451 .429 .742 r
.10638 .3084 .11351 .33018 .1246 .33391 .11761 .31068 Mtetra
.518 .458 .729 r
.11761 .31068 .1246 .33391 .13615 .33476 .12924 .31056 Mtetra
.576 .488 .718 r
.12924 .31056 .13615 .33476 .14822 .33213 .14132 .30755 Mtetra
.625 .516 .71 r
.14132 .30755 .14822 .33213 .16078 .32578 .15383 .30145 Mtetra
.664 .541 .705 r
.15383 .30145 .16078 .32578 .17379 .31592 .16672 .29244 Mtetra
.694 .564 .703 r
.16672 .29244 .17379 .31592 .18712 .30315 .17991 .281 Mtetra
.718 .585 .706 r
.17991 .281 .18712 .30315 .20067 .28835 .19328 .26787 Mtetra
.736 .605 .712 r
.19328 .26787 .20067 .28835 .21429 .27257 .20673 .25391 Mtetra
.747 .625 .723 r
.20673 .25391 .21429 .27257 .22788 .25682 .22016 .23996 Mtetra
.753 .643 .739 r
.22016 .23996 .22788 .25682 .24135 .24198 .23351 .22677 Mtetra
.75 .659 .76 r
.23351 .22677 .24135 .24198 .25466 .22879 .24673 .21494 Mtetra
.738 .672 .787 r
.24673 .21494 .25466 .22879 .26778 .21781 .25979 .20496 Mtetra
.71 .678 .817 r
.25979 .20496 .26778 .21781 .28069 .20946 .27268 .19719 Mtetra
.66 .67 .848 r
.27268 .19719 .28069 .20946 .2934 .2041 .2854 .19194 Mtetra
.581 .639 .873 r
.2854 .19194 .2934 .2041 .30593 .20201 .29797 .18944 Mtetra
.468 .577 .881 r
.29797 .18944 .30593 .20201 .31831 .20341 .31042 .1899 Mtetra
.335 .485 .86 r
.31042 .1899 .31831 .20341 .33057 .20834 .32277 .19333 Mtetra
.219 .385 .816 r
.32277 .19333 .33057 .20834 .34278 .21656 .33508 .19955 Mtetra
.155 .31 .77 r
.33508 .19955 .34278 .21656 .35501 .22744 .34741 .208 Mtetra
.16 .279 .738 r
.34741 .208 .35501 .22744 .36737 .23983 .35986 .21769 Mtetra
.223 .29 .722 r
.35986 .21769 .36737 .23983 .37994 .25209 .37251 .22724 Mtetra
.322 .331 .714 r
.37251 .22724 .37994 .25209 .39282 .26227 .38543 .235 Mtetra
.428 .383 .706 r
.38543 .235 .39282 .26227 .40606 .26839 .39867 .23932 Mtetra
.524 .435 .697 r
.39867 .23932 .40606 .26839 .41965 .26886 .41224 .23886 Mtetra
.602 .481 .687 r
.41224 .23886 .41965 .26886 .43356 .26284 .42609 .23294 Mtetra
.662 .519 .679 r
.42609 .23294 .43356 .26284 .44768 .25046 .44016 .22164 Mtetra
.708 .552 .674 r
.44016 .22164 .44768 .25046 .46193 .23276 .45435 .20585 Mtetra
.742 .581 .674 r
.45435 .20585 .46193 .23276 .47618 .21144 .46857 .18699 Mtetra
.767 .606 .679 r
.46857 .18699 .47618 .21144 .49038 .18847 .48275 .1667 Mtetra
.784 .63 .691 r
.48275 .1667 .49038 .18847 .50449 .16566 .49686 .14653 Mtetra
.793 .654 .709 r
.49686 .14653 .50449 .16566 .51849 .14445 .5109 .12767 Mtetra
.795 .676 .734 r
.5109 .12767 .51849 .14445 .53243 .12567 .52489 .11086 Mtetra
.789 .697 .764 r
.52489 .11086 .53243 .12567 .54633 .10967 .53884 .0964 Mtetra
.775 .715 .796 r
.53884 .0964 .54633 .10967 .56023 .09636 .5528 .08422 Mtetra
.756 .729 .828 r
.5528 .08422 .56023 .09636 .57416 .08537 .5668 .074 Mtetra
.733 .737 .854 r
.5668 .074 .57416 .08537 .58815 .07622 .58085 .06535 Mtetra
.712 .741 .875 r
.58085 .06535 .58815 .07622 .60221 .06842 .59497 .05785 Mtetra
.695 .743 .888 r
.59497 .05785 .60221 .06842 .61635 .06153 .60917 .05112 Mtetra
.682 .743 .897 r
.60917 .05112 .61635 .06153 .63057 .05523 .62344 .04488 Mtetra
.674 .742 .902 r
.62344 .04488 .63057 .05523 .64488 .04927 .6378 .03893 Mtetra
.669 .742 .905 r
.6378 .03893 .64488 .04927 .65926 .04349 .65223 .03314 Mtetra
.666 .742 .907 r
.65223 .03314 .65926 .04349 .67371 .0378 .66674 .02741 Mtetra
.665 .741 .907 r
.66674 .02741 .67371 .0378 .68825 .03214 .68132 .0217 Mtetra
.664 .741 .908 r
.68132 .0217 .68825 .03214 .70286 .02648 .69599 .01599 Mtetra
.446 .578 .892 r
.03419 .27388 .04263 .28544 .05327 .28739 .04501 .27454 Mtetra
.406 .529 .868 r
.04501 .27454 .05327 .28739 .06381 .29061 .05577 .2762 Mtetra
.382 .485 .84 r
.05577 .2762 .06381 .29061 .0743 .29486 .0665 .27868 Mtetra
.382 .454 .811 r
.0665 .27868 .0743 .29486 .08483 .29969 .07727 .28162 Mtetra
.404 .44 .785 r
.07727 .28162 .08483 .29969 .09549 .30446 .08816 .28449 Mtetra
.443 .441 .762 r
.08816 .28449 .09549 .30446 .10638 .3084 .09924 .28669 Mtetra
.489 .453 .743 r
.09924 .28669 .10638 .3084 .11761 .31068 .11061 .28754 Mtetra
.537 .471 .729 r
.11061 .28754 .11761 .31068 .12924 .31056 .12233 .28648 Mtetra
.582 .492 .718 r
.12233 .28648 .12924 .31056 .14132 .30755 .13441 .2831 Mtetra
.621 .514 .711 r
.13441 .2831 .14132 .30755 .15383 .30145 .14687 .27724 Mtetra
.653 .535 .707 r
.14687 .27724 .15383 .30145 .16672 .29244 .15965 .26905 Mtetra
.681 .556 .708 r
.15965 .26905 .16672 .29244 .17991 .281 .17268 .25892 Mtetra
.702 .577 .712 r
.17268 .25892 .17991 .281 .19328 .26787 .18587 .24743 Mtetra
.719 .597 .72 r
.18587 .24743 .19328 .26787 .20673 .25391 .19915 .23526 Mtetra
.73 .617 .732 r
.19915 .23526 .20673 .25391 .22016 .23996 .21242 .22308 Mtetra
.735 .636 .749 r
.21242 .22308 .22016 .23996 .23351 .22677 .22564 .2115 Mtetra
.734 .653 .77 r
.22564 .2115 .23351 .22677 .24673 .21494 .23875 .20101 Mtetra
.723 .667 .794 r
.23875 .20101 .24673 .21494 .25979 .20496 .25175 .19201 Mtetra
.699 .673 .822 r
.25175 .19201 .25979 .20496 .27268 .19719 .26462 .18478 Mtetra
.658 .668 .848 r
.26462 .18478 .27268 .19719 .2854 .19194 .27736 .17958 Mtetra
.595 .643 .868 r
.27736 .17958 .2854 .19194 .29797 .18944 .28998 .17661 Mtetra
.511 .595 .874 r
.28998 .17661 .29797 .18944 .31042 .1899 .30251 .17602 Mtetra
.417 .525 .86 r
.30251 .17602 .31042 .1899 .32277 .19333 .31496 .17783 Mtetra
.335 .449 .828 r
.31496 .17783 .32277 .19333 .33508 .19955 .32739 .18189 Mtetra
.29 .387 .789 r
.32739 .18189 .33508 .19955 .34741 .208 .33985 .18772 Mtetra
.291 .354 .756 r
.33985 .18772 .34741 .208 .35986 .21769 .3524 .19454 Mtetra
.332 .351 .73 r
.3524 .19454 .35986 .21769 .37251 .22724 .36514 .20121 Mtetra
.397 .37 .712 r
.36514 .20121 .37251 .22724 .38543 .235 .37811 .20642 Mtetra
.469 .401 .698 r
.37811 .20642 .38543 .235 .39867 .23932 .39137 .20884 Mtetra
.537 .436 .687 r
.39137 .20884 .39867 .23932 .41224 .23886 .40491 .20741 Mtetra
.596 .47 .679 r
.40491 .20741 .41224 .23886 .42609 .23294 .41871 .20159 Mtetra
.645 .502 .673 r
.41871 .20159 .42609 .23294 .44016 .22164 .4327 .19144 Mtetra
.684 .531 .672 r
.4327 .19144 .44016 .22164 .45435 .20585 .44682 .17767 Mtetra
.715 .559 .675 r
.44682 .17767 .45435 .20585 .46857 .18699 .46098 .16141 Mtetra
.739 .585 .683 r
.46098 .16141 .46857 .18699 .48275 .1667 .47512 .14397 Mtetra
.756 .61 .697 r
.47512 .14397 .48275 .1667 .49686 .14653 .48923 .1266 Mtetra
.766 .636 .717 r
.48923 .1266 .49686 .14653 .5109 .12767 .50328 .11027 Mtetra
.77 .661 .742 r
.50328 .11027 .5109 .12767 .52489 .11086 .5173 .09558 Mtetra
.766 .684 .772 r
.5173 .09558 .52489 .11086 .53884 .0964 .53131 .08278 Mtetra
.755 .704 .804 r
.53131 .08278 .53884 .0964 .5528 .08422 .54532 .07181 Mtetra
.739 .72 .834 r
.54532 .07181 .5528 .08422 .5668 .074 .55938 .06244 Mtetra
.721 .731 .859 r
.55938 .06244 .5668 .074 .58085 .06535 .57349 .05433 Mtetra
.703 .737 .877 r
.57349 .05433 .58085 .06535 .59497 .05785 .58766 .04714 Mtetra
.689 .74 .89 r
.58766 .04714 .59497 .05785 .60917 .05112 .60192 .04059 Mtetra
.678 .741 .898 r
.60192 .04059 .60917 .05112 .62344 .04488 .61624 .03443 Mtetra
.672 .741 .903 r
.61624 .03443 .62344 .04488 .6378 .03893 .63065 .02849 Mtetra
.668 .741 .905 r
.63065 .02849 .6378 .03893 .65223 .03314 .64513 .02268 Mtetra
.666 .741 .907 r
.64513 .02268 .65223 .03314 .66674 .02741 .6597 .01691 Mtetra
.665 .741 .907 r
.6597 .01691 .66674 .02741 .68132 .0217 .67433 .01116 Mtetra
.664 .741 .908 r
.67433 .01116 .68132 .0217 .69599 .01599 .68905 .0054 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.3452 .83428 m
.371 .82219 L
.3968 .82168 L
.4226 .83231 L
.42741 .8354 L
.44744 .8612 L
.4484 .86428 L
.45333 .887 L
.44896 .9128 L
.4484 .91419 L
.43339 .9386 L
.4226 .94656 L
.3968 .95688 L
.371 .95639 L
.3452 .9446 L
.33758 .9386 L
.32107 .9128 L
.3194 .906 L
.31725 .887 L
.3194 .87247 L
.32258 .8612 L
.34358 .8354 L
.3452 .83428 L
s
.113 .49371 m
.1388 .49126 L
.1646 .49815 L
.16933 .5 L
.1904 .51645 L
.19707 .5258 L
.208 .5516 L
.20906 .5774 L
.20097 .6032 L
.1904 .61992 L
.1812 .629 L
.1646 .63754 L
.1388 .6443 L
.113 .64191 L
.08726 .629 L
.0872 .62897 L
.06469 .6032 L
.0614 .59475 L
.05693 .5774 L
.05806 .5516 L
.0614 .54065 L
.06812 .5258 L
.0872 .50546 L
.09746 .5 L
.113 .49371 L
s
.629 .82327 m
.6548 .81678 L
.6806 .81982 L
.7064 .83487 L
.70702 .8354 L
.72607 .8612 L
.73104 .887 L
.72737 .9128 L
.71121 .9386 L
.7064 .94312 L
.6806 .95785 L
.6548 .96075 L
.629 .95453 L
.60576 .9386 L
.6032 .93344 L
.5912 .9128 L
.58709 .887 L
.59264 .8612 L
.6032 .84028 L
.60862 .8354 L
.629 .82327 L
s
.3968 .42133 m
.40592 .4226 L
.4226 .42738 L
.44783 .4484 L
.4484 .44991 L
.4602 .4742 L
.4616 .5 L
.45243 .5258 L
.4484 .53288 L
.42689 .5516 L
.4226 .55335 L
.3968 .56052 L
.371 .55728 L
.35845 .5516 L
.3452 .54408 L
.33114 .5258 L
.32272 .5 L
.32397 .4742 L
.33623 .4484 L
.3452 .43839 L
.371 .42416 L
.37833 .4226 L
.3968 .42133 L
s
.113 .31416 m
.1388 .31728 L
.14452 .3194 L
.1646 .33032 L
.17752 .3452 L
.18798 .371 L
.1885 .3968 L
.17963 .4226 L
.1646 .44099 L
.15144 .4484 L
.1388 .45391 L
.113 .45702 L
.0872 .45003 L
.08309 .4484 L
.0614 .43041 L
.05657 .4226 L
.0468 .3968 L
.0474 .371 L
.05879 .3452 L
.0614 .34131 L
.0872 .32073 L
.09104 .3194 L
.113 .31416 L
s
.5516 .03332 m
.5774 .02225 L
.6032 .01771 L
.629 .02125 L
.6548 .03142 L
.66237 .0356 L
.6806 .05575 L
.68379 .0614 L
.69375 .0872 L
.69547 .113 L
.68959 .1388 L
.6806 .15822 L
.67467 .1646 L
.6548 .18217 L
.63806 .1904 L
.629 .19349 L
.6032 .1968 L
.5774 .19246 L
.56924 .1904 L
.5516 .17985 L
.5351 .1646 L
.5258 .15271 L
.52027 .1388 L
.51435 .113 L
.51609 .0872 L
.5258 .06191 L
.52606 .0614 L
.54771 .0356 L
.5516 .03332 L
s
.6548 .42038 m
.67237 .4226 L
.6806 .42479 L
.7064 .44102 L
.71281 .4484 L
.72598 .4742 L
.72822 .5 L
.72142 .5258 L
.7064 .5478 L
.69983 .5516 L
.6806 .56288 L
.6548 .56759 L
.629 .56291 L
.60969 .5516 L
.6032 .54786 L
.5881 .5258 L
.5813 .5 L
.58354 .4742 L
.59671 .4484 L
.6032 .44094 L
.629 .42476 L
.63716 .4226 L
.6548 .42038 L
s
.113 .77604 m
.1388 .77331 L
.1646 .77944 L
.17568 .7838 L
.1904 .79584 L
.20108 .8096 L
.21178 .8354 L
.21319 .8612 L
.2062 .887 L
.1904 .90997 L
.18788 .9128 L
.1646 .92656 L
.1388 .93244 L
.113 .92984 L
.0872 .91719 L
.08144 .9128 L
.06221 .887 L
.0614 .88495 L
.05487 .8612 L
.05641 .8354 L
.0614 .82074 L
.06675 .8096 L
.0872 .78798 L
.09483 .7838 L
.113 .77604 L
s
.1646 .0337 m
.1904 .03148 L
.21602 .0356 L
.2162 .03566 L
.242 .04751 L
.25908 .0614 L
.2678 .07126 L
.27708 .0872 L
.2858 .113 L
.28739 .1388 L
.2823 .1646 L
.26897 .1904 L
.2678 .19208 L
.24242 .2162 L
.242 .21647 L
.2162 .2288 L
.1904 .23317 L
.1646 .23086 L
.1388 .22119 L
.12993 .2162 L
.113 .2018 L
.10385 .1904 L
.0908 .1646 L
.0872 .1502 L
.08577 .1388 L
.0872 .11407 L
.0874 .113 L
.09588 .0872 L
.113 .06272 L
.1143 .0614 L
.1388 .04293 L
.15701 .0356 L
.1646 .0337 L
s
0 g
.03 w
.38522 .88924 Mdot
.13284 .5677 Mdot
.65925 .88883 Mdot
.39212 .49076 Mdot
.11778 .38552 Mdot
.60489 .10609 Mdot
.65476 .49377 Mdot
.134 .85284 Mdot
.18652 .13214 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.38235 .87633 m
.39716 .89216 L
.38235 .90178 L
.3716 .89216 L
.38235 .87633 L
s
.12745 .52399 m
.14706 .52922 L
.15495 .53922 L
.16212 .55882 L
.15823 .57843 L
.14706 .59023 L
.12745 .5937 L
.10784 .57971 L
.1069 .57843 L
.10161 .55882 L
.10784 .54102 L
.10889 .53922 L
.12745 .52399 L
s
.36275 .86187 m
.38235 .85492 L
.40196 .85966 L
.41482 .87255 L
.41913 .89216 L
.41053 .91176 L
.40196 .9205 L
.38235 .9252 L
.36275 .91716 L
.35663 .91176 L
.34717 .89216 L
.35089 .87255 L
.36275 .86187 L
s
.12745 .49902 m
.13688 .5 L
.14706 .50475 L
.16309 .51961 L
.16667 .52329 L
.17507 .53922 L
.17952 .55882 L
.17723 .57843 L
.16667 .59642 L
.16519 .59804 L
.14706 .61026 L
.12745 .61225 L
.10784 .60475 L
.09903 .59804 L
.08867 .57843 L
.08824 .57635 L
.08604 .55882 L
.08824 .54398 L
.08915 .53922 L
.09717 .51961 L
.10784 .50902 L
.12202 .5 L
.12745 .49902 L
s
.65686 .86256 m
.67647 .86889 L
.67996 .87255 L
.68535 .89216 L
.67647 .90876 L
.67219 .91176 L
.65686 .91616 L
.64611 .91176 L
.63725 .90368 L
.63132 .89216 L
.63725 .87389 L
.63824 .87255 L
.65686 .86256 L
s
.36275 .84536 m
.38235 .84082 L
.40196 .84409 L
.41625 .85294 L
.42157 .85818 L
.43058 .87255 L
.43355 .89216 L
.4278 .91176 L
.42157 .92223 L
.40741 .93137 L
.40196 .93394 L
.38235 .93712 L
.36275 .93204 L
.361 .93137 L
.34314 .91672 L
.34051 .91176 L
.33399 .89216 L
.3367 .87255 L
.34314 .86131 L
.34894 .85294 L
.36275 .84536 L
s
.10784 .83015 m
.12745 .81611 L
.14706 .8175 L
.16251 .83333 L
.16667 .84139 L
.16895 .85294 L
.16667 .86419 L
.16214 .87255 L
.14706 .88727 L
.12745 .88862 L
.10784 .8741 L
.10688 .87255 L
.09932 .85294 L
.10603 .83333 L
.10784 .83015 L
s
.65686 .47949 m
.65993 .48039 L
.66749 .5 L
.65686 .5079 L
.6415 .5 L
.64929 .48039 L
.65686 .47949 L
s
.12745 .45341 m
.13419 .46078 L
.14706 .47775 L
.15405 .48039 L
.16667 .49833 L
.16811 .5 L
.18124 .51961 L
.18627 .52915 L
.18937 .53922 L
.19286 .55882 L
.19098 .57843 L
.18627 .59144 L
.18298 .59804 L
.16667 .61555 L
.16329 .61765 L
.14706 .6249 L
.12745 .6265 L
.10784 .62077 L
.10126 .61765 L
.08824 .60555 L
.08296 .59804 L
.07471 .57843 L
.07262 .55882 L
.07511 .53922 L
.08157 .51961 L
.08824 .50596 L
.09004 .5 L
.10072 .48039 L
.10784 .47256 L
.11571 .46078 L
.12745 .45341 L
s
.10784 .39682 m
.12745 .38796 L
.13313 .40196 L
.13105 .42157 L
.12745 .43151 L
.11112 .42157 L
.10784 .41089 L
.10709 .40196 L
.10784 .39682 L
s
.59804 .10086 m
.61328 .10784 L
.59804 .11142 L
.59634 .10784 L
.59804 .10086 L
s
.63725 .84798 m
.65686 .84243 L
.67647 .84579 L
.68796 .85294 L
.69608 .86134 L
.70259 .87255 L
.7055 .89216 L
.6993 .91176 L
.69608 .91767 L
.67673 .93137 L
.67647 .93149 L
.65686 .93493 L
.64158 .93137 L
.63725 .93008 L
.61838 .91176 L
.61765 .90942 L
.61262 .89216 L
.61563 .87255 L
.61765 .86825 L
.62814 .85294 L
.63725 .84798 L
s
.36275 .83277 m
.38235 .82926 L
.40196 .83191 L
.40872 .83333 L
.42157 .84146 L
.43324 .85294 L
.44118 .86704 L
.44318 .87255 L
.44559 .89216 L
.44118 .91144 L
.44105 .91176 L
.42792 .93137 L
.42157 .93673 L
.40196 .94653 L
.38235 .94891 L
.36275 .94512 L
.34314 .93359 L
.34064 .93137 L
.3261 .91176 L
.32353 .9053 L
.32068 .89216 L
.32257 .87255 L
.32353 .86962 L
.33304 .85294 L
.34314 .8429 L
.36056 .83333 L
.36275 .83277 L
s
.10784 .80441 m
.12745 .79773 L
.14706 .79887 L
.16667 .80839 L
.17308 .81373 L
.18585 .83333 L
.18627 .83455 L
.18991 .85294 L
.18627 .87207 L
.1861 .87255 L
.17241 .89216 L
.16667 .89652 L
.14706 .90529 L
.12745 .90624 L
.10784 .89976 L
.09654 .89216 L
.08824 .88341 L
.0842 .87255 L
.08029 .85294 L
.0838 .83333 L
.08824 .82079 L
.09508 .81373 L
.10784 .80441 L
s
.63725 .45583 m
.65686 .452 L
.67647 .4586 L
.68038 .46078 L
.69464 .48039 L
.69569 .5 L
.68905 .51961 L
.67647 .53001 L
.65686 .5358 L
.63725 .53251 L
.62213 .51961 L
.61765 .51293 L
.61296 .5 L
.61483 .48039 L
.61765 .47449 L
.62958 .46078 L
.63725 .45583 L
s
.38235 .45737 m
.40196 .45747 L
.409 .46078 L
.42157 .47225 L
.42607 .48039 L
.42647 .5 L
.42157 .50934 L
.41106 .51961 L
.40196 .52439 L
.38235 .52474 L
.37215 .51961 L
.36275 .51079 L
.3569 .5 L
.35766 .48039 L
.36275 .47164 L
.37498 .46078 L
.38235 .45737 L
s
.10784 .35018 m
.12745 .34821 L
.14706 .36073 L
.14883 .36275 L
.15884 .38235 L
.16171 .40196 L
.16205 .42157 L
.16274 .44118 L
.16603 .46078 L
.16667 .46444 L
.17475 .48039 L
.18573 .5 L
.18627 .50101 L
.1959 .51961 L
.20285 .53922 L
.20564 .55882 L
.20396 .57843 L
.19723 .59804 L
.18627 .61477 L
.1837 .61765 L
.16667 .63102 L
.15244 .63725 L
.14706 .63871 L
.12745 .64004 L
.11334 .63725 L
.10784 .6353 L
.08824 .62327 L
.08223 .61765 L
.06888 .59804 L
.06863 .59749 L
.06226 .57843 L
.06047 .55882 L
.06253 .53922 L
.0676 .51961 L
.06863 .51649 L
.07421 .5 L
.08073 .48039 L
.08456 .46078 L
.08398 .44118 L
.08095 .42157 L
.0792 .40196 L
.08169 .38235 L
.08824 .3683 L
.09213 .36275 L
.10784 .35018 L
s
.57843 .06523 m
.59804 .05768 L
.61765 .05892 L
.63557 .06863 L
.63725 .07007 L
.65057 .08824 L
.65371 .10784 L
.64907 .12745 L
.63725 .14422 L
.6307 .14706 L
.61765 .1531 L
.59804 .15438 L
.57891 .14706 L
.57843 .14692 L
.56066 .12745 L
.55882 .12152 L
.55621 .10784 L
.55882 .09068 L
.55948 .08824 L
.57323 .06863 L
.57843 .06523 L
s
.63725 .83142 m
.65686 .82744 L
.67647 .8299 L
.68536 .83333 L
.69608 .83939 L
.70935 .85294 L
.71569 .86484 L
.71842 .87255 L
.72055 .89216 L
.71615 .91176 L
.71569 .91322 L
.70381 .93137 L
.69608 .93809 L
.67647 .94783 L
.65686 .95019 L
.63725 .94636 L
.61765 .93448 L
.61438 .93137 L
.60131 .91176 L
.59804 .90077 L
.59688 .89216 L
.59804 .87686 L
.59905 .87255 L
.60859 .85294 L
.61765 .84286 L
.63133 .83333 L
.63725 .83142 L
s
.34314 .82887 m
.36275 .8207 L
.38235 .8179 L
.40196 .82013 L
.42157 .82811 L
.42961 .83333 L
.44118 .84435 L
.44713 .85294 L
.45559 .87255 L
.45766 .89216 L
.45378 .91176 L
.44305 .93137 L
.44118 .93379 L
.42157 .95027 L
.42026 .95098 L
.40196 .95815 L
.38235 .96019 L
.36275 .95695 L
.34677 .95098 L
.34314 .94794 L
.32435 .93137 L
.32353 .93066 L
.31211 .91176 L
.30657 .89216 L
.30786 .87255 L
.31695 .85294 L
.32353 .84397 L
.33609 .83333 L
.34314 .82887 L
s
.10784 .78527 m
.12745 .77993 L
.14706 .78092 L
.16667 .78828 L
.17629 .79412 L
.18627 .80327 L
.19462 .81373 L
.20463 .83333 L
.20588 .83735 L
.20831 .85294 L
.20588 .87214 L
.20576 .87255 L
.19546 .89216 L
.18627 .90259 L
.17408 .91176 L
.16667 .91551 L
.14706 .9218 L
.12745 .92252 L
.10784 .91767 L
.09525 .91176 L
.08824 .90588 L
.0761 .89216 L
.06863 .87962 L
.06697 .87255 L
.06406 .85294 L
.06668 .83333 L
.06863 .8245 L
.07518 .81373 L
.08824 .79805 L
.09213 .79412 L
.10784 .78527 L
s
.63725 .43763 m
.65686 .43509 L
.67647 .43936 L
.68182 .44118 L
.69608 .45179 L
.70328 .46078 L
.71182 .48039 L
.71299 .5 L
.70743 .51961 L
.69608 .53599 L
.6932 .53922 L
.67647 .54823 L
.65686 .55238 L
.63725 .54988 L
.61765 .53956 L
.6172 .53922 L
.60082 .51961 L
.59804 .51286 L
.59493 .5 L
.5962 .48039 L
.59804 .47449 L
.60492 .46078 L
.61765 .44731 L
.62841 .44118 L
.63725 .43763 L
s
.38235 .43924 m
.40196 .43931 L
.40896 .44118 L
.42157 .44647 L
.43673 .46078 L
.44118 .46916 L
.44515 .48039 L
.4454 .5 L
.44118 .51245 L
.4375 .51961 L
.42157 .53509 L
.41222 .53922 L
.40196 .54234 L
.38235 .54265 L
.37034 .53922 L
.36275 .53611 L
.34523 .51961 L
.34314 .51566 L
.33765 .5 L
.33845 .48039 L
.34314 .46816 L
.34718 .46078 L
.36275 .44628 L
.37496 .44118 L
.38235 .43924 L
s
.08824 .33867 m
.10784 .32716 L
.12745 .32458 L
.14706 .33143 L
.16093 .34314 L
.16667 .3534 L
.17089 .36275 L
.17634 .38235 L
.17852 .40196 L
.17919 .42157 L
.18045 .44118 L
.18441 .46078 L
.18627 .46731 L
.19198 .48039 L
.20159 .5 L
.20588 .50885 L
.21032 .51961 L
.21632 .53922 L
.21859 .55882 L
.21683 .57843 L
.21083 .59804 L
.20588 .60857 L
.19978 .61765 L
.18627 .63257 L
.18103 .63725 L
.16667 .64593 L
.14706 .65283 L
.12745 .65407 L
.10784 .6497 L
.08824 .6394 L
.08519 .63725 L
.06863 .62073 L
.06634 .61765 L
.05557 .59804 L
.05004 .57843 L
.04902 .57068 L
.04851 .55882 L
.04902 .549 L
.05022 .53922 L
.05437 .51961 L
.05973 .5 L
.06453 .48039 L
.06684 .46078 L
.06611 .44118 L
.06388 .42157 L
.06256 .40196 L
.06415 .38235 L
.06863 .36682 L
.07015 .36275 L
.0832 .34314 L
Mistroke
.08824 .33867 L
Mfstroke
.16667 .08406 m
.18627 .08002 L
.20588 .08385 L
.21768 .08824 L
.22549 .09611 L
.23277 .10784 L
.23866 .12745 L
.23684 .14706 L
.22615 .16667 L
.22549 .16748 L
.20588 .18262 L
.19298 .18627 L
.18627 .18704 L
.17583 .18627 L
.16667 .18386 L
.14706 .16917 L
.14514 .16667 L
.13558 .14706 L
.13419 .12745 L
.14026 .10784 L
.14706 .09678 L
.15572 .08824 L
.16667 .08406 L
s
.57843 .04051 m
.59804 .03574 L
.61765 .03657 L
.63725 .04328 L
.64714 .04902 L
.65686 .05788 L
.66485 .06863 L
.67326 .08824 L
.67548 .10784 L
.67226 .12745 L
.66249 .14706 L
.65686 .15416 L
.64158 .16667 L
.63725 .16887 L
.61765 .17562 L
.59804 .17646 L
.57843 .17166 L
.5671 .16667 L
.55882 .16006 L
.54693 .14706 L
.53922 .13469 L
.53727 .12745 L
.53395 .10784 L
.53627 .08824 L
.53922 .07958 L
.54466 .06863 L
.55882 .05223 L
.56226 .04902 L
.57843 .04051 L
s
.65686 .81315 m
.6686 .81373 L
.67647 .8151 L
.69608 .82264 L
.711 .83333 L
.71569 .83808 L
.72594 .85294 L
.73318 .87255 L
.73486 .89216 L
.7314 .91176 L
.72189 .93137 L
.71569 .93948 L
.70278 .95098 L
.69608 .95497 L
.67647 .96256 L
.65686 .96452 L
.63725 .96136 L
.61765 .95238 L
.61545 .95098 L
.59804 .93488 L
.59549 .93137 L
.58533 .91176 L
.58148 .89216 L
.58338 .87255 L
.59124 .85294 L
.59804 .84248 L
.60684 .83333 L
.61765 .82522 L
.63725 .81629 L
.64968 .81373 L
.65686 .81315 L
s
.36275 .80874 m
.38235 .80643 L
.40196 .80838 L
.42081 .81373 L
.42157 .81505 L
.44118 .82795 L
.44681 .83333 L
.46078 .85221 L
.46114 .85294 L
.46835 .87255 L
.47022 .89216 L
.46675 .91176 L
.46078 .92777 L
.45769 .93137 L
.44118 .95046 L
.44058 .95098 L
.42157 .96333 L
.40196 .96995 L
.39845 .97059 L
.38235 .9717 L
.37081 .97059 L
.36275 .96892 L
.34314 .96132 L
.3272 .95098 L
.32353 .94793 L
.30819 .93137 L
.30392 .92657 L
.29683 .91176 L
.29012 .89216 L
.29045 .87255 L
.30046 .85294 L
.30392 .84416 L
.31562 .83333 L
.32353 .82666 L
.34314 .8153 L
.34543 .81373 L
.36275 .80874 L
s
.10784 .7664 m
.12745 .76147 L
.14706 .76245 L
.16667 .76912 L
.17723 .77451 L
.18627 .78149 L
.19974 .79412 L
.20588 .80123 L
.21426 .81373 L
.22404 .83333 L
.22549 .8373 L
.22687 .85294 L
.22759 .87255 L
.22549 .87865 L
.21761 .89216 L
.20588 .90722 L
.20071 .91176 L
.18627 .92276 L
.1698 .93137 L
.16667 .93248 L
.14706 .93746 L
.12745 .93804 L
.10784 .93414 L
.09931 .93137 L
.08824 .92497 L
.07211 .91176 L
.06863 .90797 L
.05818 .89216 L
.0509 .87255 L
.04902 .86132 L
.04855 .85294 L
.04902 .84366 L
.05067 .83333 L
.05748 .81373 L
.06863 .79587 L
.07007 .79412 L
.08824 .77708 L
.09113 .77451 L
.10784 .7664 L
s
.36275 .42904 m
.38235 .4235 L
.40196 .42359 L
.42157 .42931 L
.4399 .44118 L
.44118 .44233 L
.45553 .46078 L
.46078 .47326 L
.46247 .48039 L
.46269 .5 L
.46078 .50848 L
.45623 .51961 L
.44118 .53909 L
.44104 .53922 L
.42157 .55223 L
.40196 .55797 L
.38235 .55829 L
.36275 .55338 L
.34314 .5419 L
.34007 .53922 L
.32504 .51961 L
.32353 .51624 L
.31971 .5 L
.32085 .48039 L
.32353 .471 L
.32823 .46078 L
.34314 .44193 L
.34396 .44118 L
.36275 .42904 L
s
.63725 .42148 m
.65686 .41952 L
.67184 .42157 L
.67647 .42281 L
.69608 .43218 L
.70714 .44118 L
.71569 .45115 L
.72104 .46078 L
.72756 .48039 L
.72851 .5 L
.72412 .51961 L
.71569 .53652 L
.71325 .53922 L
.69608 .55525 L
.69204 .55882 L
.67647 .56453 L
.65686 .56779 L
.63725 .56581 L
.61879 .55882 L
.61765 .55823 L
.59804 .54307 L
.59472 .53922 L
.58279 .51961 L
.57843 .50478 L
.57779 .5 L
.57843 .48234 L
.5788 .48039 L
.58608 .46078 L
.59804 .44402 L
.60099 .44118 L
.61765 .42899 L
.63689 .42157 L
.63725 .42148 L
s
.12745 .30006 m
.14706 .30329 L
.1505 .30392 L
.16667 .31862 L
.17099 .32353 L
.18205 .34314 L
.18627 .35419 L
.18873 .36275 L
.19257 .38235 L
.19441 .40196 L
.19544 .42157 L
.19729 .44118 L
.20167 .46078 L
.20588 .47313 L
.20895 .48039 L
.21795 .5 L
.22549 .51719 L
.22617 .51961 L
.23103 .53922 L
.23262 .55882 L
.23054 .57843 L
.22549 .59759 L
.22492 .59804 L
.21518 .61765 L
.20588 .63088 L
.20035 .63725 L
.18627 .64997 L
.17706 .65686 L
.16667 .66188 L
.14706 .6685 L
.12745 .66975 L
.10784 .66537 L
.0891 .65686 L
.08824 .6561 L
.06863 .64022 L
.06574 .63725 L
.05123 .61765 L
.04902 .61394 L
.04229 .59804 L
.03751 .57843 L
.03616 .55882 L
.03764 .53922 L
.04118 .51961 L
.04561 .5 L
.04902 .48358 L
.04937 .48039 L
.05099 .46078 L
.05024 .44118 L
.04902 .42693 L
.0484 .42157 L
Mistroke
.04729 .40196 L
.04848 .38235 L
.04902 .37895 L
.05305 .36275 L
.06227 .34314 L
.06863 .33403 L
.0777 .32353 L
.08824 .31515 L
.10784 .304 L
.10804 .30392 L
.12745 .30006 L
Mfstroke
.14706 .06113 m
.16667 .05338 L
.18627 .05094 L
.20588 .05325 L
.22549 .06083 L
.23755 .06863 L
.2451 .07558 L
.25503 .08824 L
.26417 .10784 L
.26471 .10967 L
.26779 .12745 L
.26656 .14706 L
.26471 .15487 L
.26041 .16667 L
.24805 .18627 L
.2451 .18969 L
.22596 .20588 L
.22549 .20617 L
.20588 .21617 L
.18627 .22137 L
.16667 .22107 L
.14706 .2129 L
.13697 .20588 L
.12745 .19501 L
.12107 .18627 L
.11118 .16667 L
.10784 .15585 L
.10603 .14706 L
.10521 .12745 L
.10784 .11174 L
.10895 .10784 L
.11811 .08824 L
.12745 .07618 L
.13556 .06863 L
.14706 .06113 L
s
.55882 .02853 m
.57843 .02003 L
.59804 .01634 L
.61765 .017 L
.63725 .02208 L
.65279 .02941 L
.65686 .03239 L
.67471 .04902 L
.67647 .05112 L
.68691 .06863 L
.69326 .08824 L
.69502 .10784 L
.69249 .12745 L
.68523 .14706 L
.67647 .16117 L
.67176 .16667 L
.65686 .17983 L
.64685 .18627 L
.63725 .19027 L
.61765 .19539 L
.59804 .19604 L
.57843 .19235 L
.56246 .18627 L
.55882 .18376 L
.53922 .16824 L
.53774 .16667 L
.52405 .14706 L
.51961 .13962 L
.51671 .12745 L
.51414 .10784 L
.51597 .08824 L
.51961 .07554 L
.52244 .06863 L
.53479 .04902 L
.53922 .044 L
.55729 .02941 L
.55882 .02853 L
s
.61765 .80841 m
.63725 .80115 L
.65686 .7985 L
.67647 .80015 L
.69608 .80635 L
.7098 .81373 L
.71569 .81824 L
.73057 .83333 L
.73529 .83968 L
.74213 .85294 L
.74808 .87255 L
.7495 .89216 L
.74659 .91176 L
.73892 .93137 L
.73529 .93779 L
.72486 .95098 L
.71569 .95939 L
.69778 .97059 L
.69608 .97132 L
.67647 .97751 L
.65686 .97915 L
.63725 .97651 L
.61932 .97059 L
.61765 .96926 L
.59804 .95622 L
.59241 .95098 L
.57843 .93386 L
.57705 .93137 L
.56835 .91176 L
.56462 .89216 L
.56649 .87255 L
.5736 .85294 L
.57843 .84349 L
.58631 .83333 L
.59804 .82141 L
.60814 .81373 L
.61765 .80841 L
s
.08824 .75449 m
.10784 .74441 L
.12745 .73573 L
.14706 .73783 L
.16667 .74811 L
.18162 .7549 L
.18627 .75885 L
.20448 .77451 L
.20588 .77592 L
.22213 .79412 L
.22549 .79817 L
.2362 .81373 L
.2451 .82396 L
.25263 .83333 L
.26471 .8379 L
.28431 .83433 L
.28627 .83333 L
.30392 .82173 L
.3177 .81373 L
.32353 .81014 L
.34314 .80138 L
.36275 .79593 L
.37836 .79412 L
.38235 .79401 L
.38756 .79412 L
.40196 .79576 L
.42157 .80157 L
.44118 .81216 L
.44341 .81373 L
.46078 .82951 L
.46385 .83333 L
.47651 .85294 L
.48039 .86141 L
.48266 .87255 L
.48412 .89216 L
.48155 .91176 L
.48039 .91854 L
.47323 .93137 L
.46078 .94896 L
.45888 .95098 L
.44118 .96628 L
.43468 .97059 L
.42157 .97687 L
.40196 .98254 L
.38235 .98406 L
.36275 .98164 L
.34314 .97515 L
.33377 .97059 L
.32353 .96412 L
.30729 .95098 L
Mistroke
.30392 .94791 L
.28913 .93137 L
.28431 .92678 L
.27176 .91176 L
.26471 .9089 L
.2451 .90458 L
.23153 .91176 L
.22549 .91622 L
.20588 .93024 L
.20412 .93137 L
.18627 .94164 L
.16667 .94946 L
.16116 .95098 L
.14706 .95357 L
.12745 .95405 L
.10851 .95098 L
.10784 .9508 L
.08824 .94329 L
.06986 .93137 L
.06863 .93033 L
.0515 .91176 L
.04902 .9083 L
.04058 .89216 L
.03456 .87255 L
.03258 .85294 L
.03437 .83333 L
.04002 .81373 L
.04902 .79554 L
.04994 .79412 L
.06507 .77451 L
.06863 .77098 L
.08708 .7549 L
.08824 .75449 L
Mfstroke
.61765 .41146 m
.63725 .40532 L
.65686 .40372 L
.67647 .4065 L
.69608 .41406 L
.70826 .42157 L
.71569 .4279 L
.72735 .44118 L
.73529 .45401 L
.73804 .46078 L
.74329 .48039 L
.74408 .5 L
.74049 .51961 L
.73529 .53414 L
.73196 .53922 L
.71634 .55882 L
.71569 .55943 L
.69608 .57326 L
.6862 .57843 L
.67647 .58067 L
.65686 .58333 L
.63725 .5817 L
.62493 .57843 L
.61765 .57563 L
.59804 .56423 L
.59139 .55882 L
.57843 .54538 L
.57415 .53922 L
.56351 .51961 L
.55882 .5038 L
.55869 .5 L
.55882 .48287 L
.5593 .48039 L
.56651 .46078 L
.57843 .44175 L
.57895 .44118 L
.59804 .42287 L
.59974 .42157 L
.61765 .41146 L
s
.36275 .41244 m
.38235 .40804 L
.40196 .40817 L
.42157 .41284 L
.43967 .42157 L
.44118 .42266 L
.46078 .43962 L
.46206 .44118 L
.47501 .46078 L
.48039 .47397 L
.48107 .48039 L
.48117 .5 L
.48039 .50814 L
.47581 .51961 L
.46313 .53922 L
.46078 .54212 L
.44121 .55882 L
.44118 .55884 L
.42157 .56863 L
.40196 .57334 L
.38235 .57369 L
.36275 .56992 L
.34314 .56188 L
.33788 .55882 L
.32353 .54891 L
.3153 .53922 L
.30392 .52752 L
.30109 .51961 L
.29752 .5 L
.30255 .48039 L
.30392 .4702 L
.30843 .46078 L
.32151 .44118 L
.32353 .43869 L
.34314 .422 L
.34372 .42157 L
.36275 .41244 L
s
.16667 .02714 m
.18627 .02528 L
.20588 .02704 L
.21979 .02941 L
.22549 .0326 L
.2451 .04268 L
.25392 .04902 L
.26471 .059 L
.27275 .06863 L
.28431 .08815 L
.28435 .08824 L
.29108 .10784 L
.29381 .12745 L
.29283 .14706 L
.28811 .16667 L
.28431 .17688 L
.27923 .18627 L
.2652 .20588 L
.26471 .20645 L
.2451 .22497 L
.24447 .22549 L
.22549 .23901 L
.21658 .2451 L
.20588 .2513 L
.19148 .26471 L
.18627 .27346 L
.18517 .28431 L
.18627 .29232 L
.18952 .30392 L
.19608 .32353 L
.20195 .34314 L
.20588 .3601 L
.20637 .36275 L
.20922 .38235 L
.21096 .40196 L
.21247 .42157 L
.21513 .44118 L
.22056 .46078 L
.22549 .47262 L
.22711 .48039 L
.23765 .5 L
.2451 .51219 L
.24765 .51961 L
.25152 .53922 L
.24908 .55882 L
.24666 .57843 L
.2451 .58614 L
.2405 .59804 L
.23137 .61765 L
.22549 .62774 L
Mistroke
.21881 .63725 L
.20588 .6524 L
.20157 .65686 L
.18627 .66968 L
.1781 .67647 L
.16667 .68334 L
.14706 .69205 L
.12745 .69378 L
.10784 .68765 L
.08849 .67647 L
.08824 .67621 L
.06863 .66042 L
.06454 .65686 L
.04902 .63921 L
.04757 .63725 L
.03577 .61765 L
.02941 .60252 L
.02808 .59804 L
.0239 .57843 L
.0227 .55882 L
.02399 .53922 L
.02707 .51961 L
.02941 .50765 L
.03086 .5 L
.03397 .48039 L
.03522 .46078 L
.03449 .44118 L
.03289 .42157 L
.03192 .40196 L
.03287 .38235 L
.0366 .36275 L
.0438 .34314 L
.04902 .33303 L
.05506 .32353 L
.06863 .30678 L
.07111 .30392 L
.08824 .28782 L
.09119 .28431 L
.10784 .26865 L
.10945 .26471 L
.1152 .2451 L
.10907 .22549 L
.10784 .22199 L
.09942 .20588 L
.09052 .18627 L
.08824 .18073 L
.08388 .16667 L
.08012 .14706 L
.07954 .12745 L
.08237 .10784 L
Mistroke
.08824 .08955 L
.08906 .08824 L
.10054 .06863 L
.10784 .05974 L
.11925 .04902 L
.12745 .04306 L
.14706 .03282 L
.15362 .02941 L
.16667 .02714 L
Mfstroke
.6573 .0098 m
.67647 .02317 L
.68326 .02941 L
.69608 .04519 L
.69848 .04902 L
.70791 .06863 L
.71305 .08824 L
.7145 .10784 L
.71241 .12745 L
.70657 .14706 L
.69627 .16667 L
.69608 .16696 L
.6797 .18627 L
.67647 .18917 L
.65686 .20269 L
.65109 .20588 L
.63725 .21091 L
.61765 .21506 L
.59804 .21559 L
.57843 .21257 L
.55908 .20588 L
.55882 .20572 L
.53922 .19419 L
.52957 .18627 L
.51961 .17587 L
.51273 .16667 L
.50216 .14706 L
.5 .14377 L
.49619 .12745 L
.4941 .10784 L
.49565 .08824 L
.5 .07135 L
.50098 .06863 L
.51068 .04902 L
.51961 .03656 L
.52614 .02941 L
.53922 .01828 L
.55212 .0098 L
s
.6921 .9902 m
.69608 .98883 L
.71569 .97921 L
.72764 .97059 L
.73529 .9635 L
.74578 .95098 L
.7549 .93595 L
.75691 .93137 L
.76321 .91176 L
.76566 .89216 L
.76446 .87255 L
.75951 .85294 L
.7549 .84144 L
.7502 .83333 L
.73529 .81417 L
.73486 .81373 L
.71569 .79844 L
.70851 .79412 L
.69608 .78887 L
.67647 .78371 L
.65686 .78231 L
.63725 .78456 L
.61765 .79056 L
.60952 .79412 L
.59804 .80093 L
.58164 .81373 L
.57843 .8167 L
.5639 .83333 L
.55882 .83933 L
.55009 .85294 L
.54025 .87255 L
.53922 .87552 L
.53688 .89216 L
.53922 .90231 L
.54301 .91176 L
.55421 .93137 L
.55882 .93826 L
.56946 .95098 L
.57843 .96098 L
.5895 .97059 L
.59804 .97674 L
.61765 .98713 L
.6238 .9902 L
s
.0098 .58804 m
.01195 .59804 L
.01848 .61765 L
.02837 .63725 L
.02941 .63897 L
.0417 .65686 L
.04902 .6656 L
.05781 .67647 L
.06863 .68939 L
.0734 .69608 L
.07989 .71569 L
.07149 .73529 L
.06863 .74073 L
.05591 .7549 L
.04902 .76378 L
.04097 .77451 L
.02941 .7937 L
.0292 .79412 L
.02101 .81373 L
.01626 .83333 L
.01474 .85294 L
.01642 .87255 L
.02147 .89216 L
.02941 .91005 L
.03043 .91176 L
.04439 .93137 L
.04902 .93637 L
.0664 .95098 L
.06863 .95246 L
.08824 .96282 L
.10784 .96911 L
.11556 .97059 L
.12745 .9719 L
.14706 .97149 L
.15398 .97059 L
.16667 .96799 L
.18627 .96153 L
.20588 .95265 L
.20844 .95098 L
.22549 .94293 L
.2451 .93665 L
.26471 .94004 L
.28164 .95098 L
.28431 .95304 L
.30392 .96841 L
.30695 .97059 L
.32353 .98131 L
.34234 .9902 L
s
.69354 .0098 m
.69608 .0123 L
.71094 .02941 L
.71569 .03635 L
.72264 .04902 L
.73027 .06863 L
.73454 .08824 L
.73529 .09509 L
.73575 .10784 L
.73529 .11709 L
.73401 .12745 L
.72917 .14706 L
.72089 .16667 L
.71569 .17585 L
.70835 .18627 L
.69608 .20005 L
.68971 .20588 L
.67647 .21579 L
.65909 .22549 L
.65686 .22645 L
.63725 .23316 L
.61765 .23663 L
.59804 .23704 L
.57843 .23446 L
.55882 .2288 L
.55052 .22549 L
.53922 .21961 L
.51961 .20604 L
.51941 .20588 L
.50013 .18627 L
.5 .18611 L
.48702 .16667 L
.48039 .15319 L
.47824 .14706 L
.47318 .12745 L
.47142 .10784 L
.47288 .08824 L
.47753 .06863 L
.48039 .06015 L
.48568 .04902 L
.49791 .02941 L
.5 .02671 L
.51574 .0098 L
s
.42659 .9902 m
.44118 .98313 L
.45945 .97059 L
.46078 .96949 L
.47936 .95098 L
.48039 .94986 L
.49251 .93137 L
.5 .92382 L
.50535 .91176 L
.5115 .89216 L
.50802 .87255 L
.5 .85653 L
.49724 .85294 L
.48285 .83333 L
.48039 .82854 L
.466 .81373 L
.46078 .80897 L
.44118 .79532 L
.43914 .79412 L
.42157 .78654 L
.40196 .78154 L
.38235 .77994 L
.36275 .7815 L
.34314 .78588 L
.32353 .7925 L
.32071 .79412 L
.30392 .80031 L
.28431 .80605 L
.26471 .80353 L
.2508 .79412 L
.2451 .78884 L
.23127 .77451 L
.22549 .76816 L
.21345 .7549 L
.20588 .7486 L
.19651 .73529 L
.1871 .71569 L
.19313 .69608 L
.20588 .67951 L
.20846 .67647 L
.22476 .65686 L
.22549 .65592 L
.23876 .63725 L
.2451 .62719 L
.25023 .61765 L
.26031 .59804 L
.26471 .59014 L
.27118 .57843 L
.28431 .56509 L
.30392 .56574 L
Mistroke
.32353 .57383 L
.33521 .57843 L
.34314 .58178 L
.36275 .5875 L
.38235 .59034 L
.40196 .58993 L
.42157 .586 L
.44089 .57843 L
.44118 .57827 L
.46078 .56603 L
.46941 .55882 L
.48039 .54905 L
.48587 .53922 L
.5 .52869 L
.50786 .51961 L
.51961 .51257 L
.53151 .51961 L
.53922 .52943 L
.5511 .53922 L
.55882 .55201 L
.56558 .55882 L
.57843 .57107 L
.58796 .57843 L
.59804 .58485 L
.61765 .59398 L
.63182 .59804 L
.63725 .59905 L
.65686 .60039 L
.67647 .59821 L
.67759 .59804 L
.69608 .59205 L
.71569 .58127 L
.71962 .57843 L
.73529 .56367 L
.73922 .55882 L
.75119 .53922 L
.7549 .53172 L
.75815 .51961 L
.76112 .5 L
.76047 .48039 L
.75615 .46078 L
.7549 .45676 L
.74753 .44118 L
.73529 .4237 L
.73339 .42157 L
.71569 .40594 L
.70988 .40196 L
.69608 .39499 L
.67647 .38863 L
.65686 .38618 L
Mistroke
.63725 .38749 L
.61765 .39263 L
.59804 .40176 L
.59769 .40196 L
.57843 .41569 L
.57204 .42157 L
.55882 .43457 L
.55636 .44118 L
.53922 .45707 L
.5362 .46078 L
.51961 .47172 L
.50498 .46078 L
.5 .4546 L
.485 .44118 L
.48039 .43302 L
.46791 .42157 L
.46078 .41558 L
.44118 .40312 L
.43914 .40196 L
.42157 .39531 L
.40196 .3914 L
.38235 .39117 L
.36275 .39463 L
.34314 .40191 L
.34304 .40196 L
.32353 .41384 L
.31437 .42157 L
.30392 .43087 L
.29433 .44118 L
.28431 .45247 L
.27601 .46078 L
.26471 .46607 L
.25261 .46078 L
.2451 .45157 L
.2381 .44118 L
.23274 .42157 L
.23035 .40196 L
.22838 .38235 L
.22614 .36275 L
.22549 .35805 L
.22348 .34314 L
.22118 .32353 L
.2211 .30392 L
.22549 .28719 L
.22688 .28431 L
.24232 .26471 L
.2451 .26196 L
.26383 .2451 L
.26471 .24429 L
.28341 .22549 L
Mistroke
.28431 .22447 L
.29841 .20588 L
.30392 .19688 L
.30918 .18627 L
.31638 .16667 L
.32038 .14706 L
.32128 .12745 L
.31906 .10784 L
.31359 .08824 L
.30462 .06863 L
.30392 .06737 L
.29126 .04902 L
.28431 .0411 L
.27173 .02941 L
.26471 .02406 L
.2451 .01238 L
.23984 .0098 L
Mfstroke
.0098 .5263 m
.01108 .51961 L
.01428 .5 L
.01689 .48039 L
.0179 .46078 L
.01726 .44118 L
.0159 .42157 L
.01506 .40196 L
.01582 .38235 L
.01888 .36275 L
.0247 .34314 L
.02941 .33174 L
.03351 .32353 L
.04512 .30392 L
.04902 .29837 L
.05831 .28431 L
.06863 .26802 L
.06978 .26471 L
.07499 .2451 L
.07332 .22549 L
.06863 .2085 L
.06779 .20588 L
.06158 .18627 L
.05655 .16667 L
.0536 .14706 L
.05315 .12745 L
.05542 .10784 L
.06067 .08824 L
.06863 .06988 L
.06933 .06863 L
.08232 .04902 L
.08824 .04209 L
.10157 .02941 L
.10784 .02457 L
.12745 .01267 L
.13327 .0098 L
s
.0098 .78291 m
.01409 .77451 L
.02544 .7549 L
.02941 .75018 L
.03637 .73529 L
.04194 .71569 L
.03839 .69608 L
.02941 .67878 L
.02802 .67647 L
.01598 .65686 L
.0098 .64573 L
s
.58152 .9902 m
.57843 .98807 L
.55882 .97271 L
.55626 .97059 L
.53922 .9576 L
.51961 .95246 L
.5 .96237 L
.48729 .97059 L
.48039 .97814 L
.46399 .9902 L
s
.30196 .9902 m
.28431 .97978 L
.26606 .97059 L
.26471 .97008 L
.2451 .96697 L
.22669 .97059 L
.22549 .97097 L
.20588 .9783 L
.18627 .98543 L
.16898 .9902 L
s
.0098 .92 m
.01665 .93137 L
.02941 .94764 L
.03255 .95098 L
.04902 .96552 L
.05611 .97059 L
.06863 .97802 L
.08824 .98645 L
.1003 .9902 L
s
.72862 .0098 m
.73529 .01916 L
.74162 .02941 L
.75091 .04902 L
.7549 .05999 L
.75712 .06863 L
.7606 .08824 L
.7616 .10784 L
.76016 .12745 L
.75623 .14706 L
.7549 .152 L
.74949 .16667 L
.73963 .18627 L
.73529 .19324 L
.72591 .20588 L
.71569 .21722 L
.70689 .22549 L
.69608 .23404 L
.67902 .2451 L
.67647 .24641 L
.65686 .25508 L
.63725 .26096 L
.61765 .26393 L
.59804 .26408 L
.57843 .26159 L
.55882 .25657 L
.53922 .249 L
.53109 .2451 L
.51961 .2384 L
.50161 .22549 L
.5 .22416 L
.48112 .20588 L
.48039 .20508 L
.46584 .18627 L
.46078 .17877 L
.45459 .16667 L
.44603 .14706 L
.44118 .13001 L
.44102 .12745 L
.44021 .10784 L
.44118 .08862 L
.44125 .08824 L
.4466 .06863 L
.45459 .04902 L
.46078 .03647 L
.46517 .02941 L
.47937 .0098 L
s
.73504 .9902 m
.73529 .99 L
.7549 .97171 L
.75585 .97059 L
.76943 .95098 L
.77451 .94134 L
.77832 .93137 L
.78353 .91176 L
.78559 .89216 L
.78457 .87255 L
.78045 .85294 L
.77451 .83632 L
.77298 .83333 L
.76104 .81373 L
.7549 .80596 L
.74321 .79412 L
.73529 .7877 L
.71569 .77547 L
.7139 .77451 L
.69608 .7678 L
.67647 .76345 L
.65686 .76225 L
.63725 .76417 L
.61765 .76919 L
.6038 .77451 L
.59804 .7775 L
.57843 .78965 L
.57263 .79412 L
.55882 .80505 L
.54825 .81373 L
.53922 .82025 L
.51961 .82559 L
.5 .81591 L
.49609 .81373 L
.48039 .8003 L
.47214 .79412 L
.46078 .78612 L
.44118 .77509 L
.44 .77451 L
.42157 .7679 L
.40196 .7636 L
.38235 .76213 L
.36275 .76328 L
.34314 .7666 L
.32353 .77121 L
.30895 .77451 L
.30392 .7755 L
.28431 .77628 L
.27675 .77451 L
.26471 .76892 L
Mistroke
.24818 .7549 L
.2451 .752 L
.2333 .73529 L
.22603 .71569 L
.2287 .69608 L
.23881 .67647 L
.2451 .66601 L
.2514 .65686 L
.26447 .63725 L
.26471 .6369 L
.27773 .61765 L
.28431 .61129 L
.30392 .60062 L
.32353 .60107 L
.34314 .60496 L
.36275 .60867 L
.38235 .61063 L
.40196 .61012 L
.42157 .60678 L
.44118 .60055 L
.44731 .59804 L
.46078 .59117 L
.48039 .5794 L
.48197 .57843 L
.5 .56794 L
.51961 .56333 L
.53922 .57043 L
.55318 .57843 L
.55882 .58419 L
.57843 .59788 L
.57868 .59804 L
.59804 .60851 L
.61765 .61603 L
.6235 .61765 L
.63725 .62015 L
.65686 .62127 L
.67647 .61947 L
.68786 .61765 L
.69608 .61445 L
.71569 .60571 L
.72822 .59804 L
.73529 .5926 L
.75007 .57843 L
.7549 .5727 L
.76431 .55882 L
.77387 .53922 L
.77451 .53794 L
.77946 .51961 L
.78192 .5 L
.78138 .48039 L
Mistroke
.77782 .46078 L
.77451 .44936 L
.77089 .44118 L
.75988 .42157 L
.7549 .41465 L
.74359 .40196 L
.73529 .39448 L
.71844 .38235 L
.71569 .38083 L
.69608 .37177 L
.67647 .36593 L
.65686 .3634 L
.63725 .36434 L
.61765 .3689 L
.59804 .37683 L
.58699 .38235 L
.57843 .38778 L
.55882 .4015 L
.55858 .40196 L
.53922 .41481 L
.51961 .42065 L
.5 .4147 L
.48039 .40228 L
.47989 .40196 L
.46078 .39008 L
.4459 .38235 L
.44118 .38043 L
.42157 .37411 L
.40196 .37068 L
.38235 .3702 L
.36275 .37268 L
.34314 .37799 L
.33138 .38235 L
.32353 .38591 L
.30392 .39598 L
.29063 .40196 L
.28431 .404 L
.2697 .40196 L
.26471 .3975 L
.25577 .38235 L
.2526 .36275 L
.25144 .34314 L
.2528 .32353 L
.25891 .30392 L
.26471 .29319 L
.27193 .28431 L
.28431 .2706 L
.29014 .26471 L
.30392 .24999 L
.30823 .2451 L
Mistroke
.32349 .22549 L
.32353 .22544 L
.33556 .20588 L
.34314 .19088 L
.34496 .18627 L
.35156 .16667 L
.35583 .14706 L
.35719 .12745 L
.35518 .10784 L
.34997 .08824 L
.34314 .07012 L
.34234 .06863 L
.33095 .04902 L
.32353 .03824 L
.31637 .02941 L
.30392 .01612 L
.29705 .0098 L
Mfstroke
.0098 .32177 m
.01769 .30392 L
.02707 .28431 L
.02941 .28117 L
.03492 .26471 L
.03869 .2451 L
.03772 .22549 L
.03368 .20588 L
.02941 .18866 L
.02883 .18627 L
.02478 .16667 L
.02238 .14706 L
.022 .12745 L
.02384 .10784 L
.02807 .08824 L
.02941 .0835 L
.03491 .06863 L
.0447 .04902 L
.04902 .04201 L
.05819 .02941 L
.06863 .01758 L
.0767 .0098 L
s
.40196 .22159 m
.42157 .22213 L
.42892 .22549 L
.44118 .23314 L
.45791 .2451 L
.46078 .24793 L
.48039 .26266 L
.48326 .26471 L
.5 .2752 L
.51507 .28431 L
.51961 .28589 L
.53922 .29504 L
.55459 .30392 L
.55882 .30608 L
.57813 .32353 L
.56777 .34314 L
.55882 .35106 L
.54286 .36275 L
.53922 .36455 L
.51961 .37113 L
.5 .3684 L
.48602 .36275 L
.48039 .36106 L
.46078 .35258 L
.44118 .34459 L
.43709 .34314 L
.42157 .34031 L
.40196 .33705 L
.38235 .33522 L
.36275 .33201 L
.34314 .32992 L
.33041 .32353 L
.33136 .30392 L
.34306 .28431 L
.34314 .28418 L
.35739 .26471 L
.36275 .25774 L
.37252 .2451 L
.38235 .23527 L
.39418 .22549 L
.40196 .22159 L
s
.0098 .97657 m
.0251 .9902 L
s
.77964 .9902 m
.79386 .97059 L
.79412 .97018 L
.80365 .95098 L
.81077 .93137 L
.81373 .92141 L
.81493 .91176 L
.81643 .89216 L
.81568 .87255 L
.81373 .85812 L
.81256 .85294 L
.80638 .83333 L
.79749 .81373 L
.79412 .80749 L
.78493 .79412 L
.77451 .78151 L
.76761 .77451 L
.7549 .76372 L
.74269 .7549 L
.73529 .75085 L
.71569 .74129 L
.70002 .73529 L
.69608 .73484 L
.67647 .73256 L
.65686 .73176 L
.63725 .73309 L
.61783 .73529 L
.61765 .7354 L
.59804 .74298 L
.57843 .7523 L
.57338 .7549 L
.55882 .76349 L
.53922 .77373 L
.53716 .77451 L
.51961 .77797 L
.50372 .77451 L
.5 .77311 L
.48039 .76329 L
.465 .7549 L
.46078 .75296 L
.44118 .74477 L
.42157 .73826 L
.41047 .73529 L
.40196 .73476 L
.38235 .73386 L
.36275 .73416 L
.34314 .73514 L
.33998 .73529 L
.32353 .73672 L
.30392 .73539 L
Mistroke
.30352 .73529 L
.28431 .72481 L
.27793 .71569 L
.27605 .69608 L
.28345 .67647 L
.28431 .67455 L
.29682 .65686 L
.30392 .65083 L
.32353 .64162 L
.34314 .64022 L
.36275 .64099 L
.38235 .64158 L
.40196 .64087 L
.42157 .63852 L
.42946 .63725 L
.44118 .63364 L
.46078 .62633 L
.48039 .61843 L
.48247 .61765 L
.5 .61141 L
.51961 .60972 L
.53922 .61541 L
.54503 .61765 L
.55882 .6251 L
.57843 .63555 L
.58184 .63725 L
.59804 .6434 L
.61765 .64974 L
.63725 .65383 L
.65686 .65504 L
.67647 .65318 L
.69608 .6484 L
.71569 .64136 L
.7258 .63725 L
.73529 .63171 L
.7549 .61813 L
.75552 .61765 L
.77451 .59925 L
.77555 .59804 L
.78992 .57843 L
.79412 .57152 L
.80019 .55882 L
.80749 .53922 L
.81216 .51961 L
.81373 .50755 L
.81416 .5 L
.81377 .48039 L
.81373 .47984 L
.81077 .46078 L
.80516 .44118 L
Mistroke
.79698 .42157 L
.79412 .41582 L
.78538 .40196 L
.77451 .38764 L
.76983 .38235 L
.7549 .36792 L
.749 .36275 L
.73529 .35309 L
.72192 .34314 L
.71569 .33912 L
.69608 .32615 L
.69292 .32353 L
.68512 .30392 L
.69608 .29 L
.70227 .28431 L
.71569 .27068 L
.72468 .26471 L
.73529 .25451 L
.7448 .2451 L
.7549 .23357 L
.76123 .22549 L
.77433 .20588 L
.77451 .20558 L
.78426 .18627 L
.79187 .16667 L
.79412 .15972 L
.79705 .14706 L
.80012 .12745 L
.80127 .10784 L
.80047 .08824 L
.79774 .06863 L
.79412 .05252 L
.79299 .04902 L
.78577 .02941 L
.77624 .0098 L
Mfstroke
.41573 .0098 m
.40196 .01681 L
.38235 .01506 L
.37282 .0098 L
s
.0098 .01704 m
.01467 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0500000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`05ooooo`?o00004_ooool2o`00000300000?oooooooooo00Kooooo
00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool2o`00017ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo0<oooooo
0009ooooo`0500000?ooooooooooooooool000002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00
001<C4`0C4a<01H0C4a<0P00000703<c<`03o`00000I6AT06ATI00/06ATI1Ol0000;01TI6@03o`00
000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`2o`0000@0IVIV2ol0000606IVIP;o0000
101<C4`00ol00000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00@06ATI9P000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`T06ATI00?o000003<c<`0c<c<0
1@0c<c<00ol00000C4a<04a<C00904a<C0D000002`1<C4`00`000000<c<c03<c<`0503<c<`030000
000I6AT06ATI01T06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C003o`00
001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl02@1oOgl4o`0000@0IVIV00?o000004a<C01<C4`0
0P1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00D06ATI9@000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`P06ATI00?o000003<c<`0c<c<0
1@0c<c<00ol00000C4a<04a<C00604a<C0@000001@1VIVH300000003o`00001<C4`0C4a<00H0C4a<
00?o000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0G01TI6@03o`00000c<c<0<c<c00<0<c<c
00?o000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0206IVIP;o0000401oOgl00ol00000IVIV
06IVIP0206IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI
01TI6@0501TI6B@000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
ooooool801TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`01@1<C4`00`00003o0000
06IVIP0<06IVIP<000001P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI01L06ATI
00?o000003<c<`0c<c<00`0c<c<01Ol00000C4a<04a<C01<C4co000000@0IVIV00?o000007moO`1o
Ogl0101oOgl7o`0000D0Ogmo00?o000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C005
o`00000c<c<0<c<c03<c<ol000001`0I6ATT000000Cooooo00<00000ooooooooool0coooool000Wo
oooo00@00000oooooooooooooooo1`0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<
00@0C4a<0P00000B06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0F01TI6@03o`00000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00P1<C4`01Ol0
0000IVIV06IVIP1VIVKo000000D0Ogmo0_l0000709VIV@;o0000101oOgl00ol00000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@04
01TI6B@000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool7
01TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0C
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0D
01TI6@03o`00000c<c<0<c<c00<0<c<c00Go000004a<C01<C4`0C4a<o`00000306IVIP03o`00001o
Ogl0Ogmo00<0Ogmo00?o000009VIV@2IVIT02@2IVIT2o`0000<0Ogmo00?o000006IVIP1VIVH00P1V
IVH00ol00000C4a<04a<C00204a<C005o`00000c<c<0<c<c03<c<ol000001`0I6ATS000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1P0I6AT00ol00000<c<c
03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00<00000o`00001VIVH01@1VIVH:o`0000L0IVIV
0P00000404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT04P0I6AT00ol00000<c<c
03<c<`0303<c<`05o`00001<C4`0C4a<04a<C?l00000101VIVH01?l00000Ogmo07moO`1oOgl2o`00
00h0VIVI00Co000007moO`1oOgl0Ogmo0_l0000306IVIP05o`00001<C4`0C4a<04a<C?l00000100c
<c<00ol000006ATI01TI6@0401TI6@0300000?l000000000020000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool601TI6@03o`00000c<c<0<c<c00<0<c<c00?o
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0506IVIP03o`00001oOgl0Ogmo00P0Ogmo0_l0
000706IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0B01TI6@03o`00000c<c<0<c<c00<0<c<c00Go000004a<C01<C4`0C4a<o`00000306IVIP05o`00
001oOgl0Ogmo07moOol000001@2IVIT7o`0000D0VIVI00Go000007moO`1oOgl0Ogmoo`00000306IV
IP05o`00001<C4`0C4a<04a<C?l00000100c<c<00ol000006ATI01TI6@0501TI6B8000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool501TI6@03o`00000c<c<0
<c<c00<0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP;o00003@1oOgl2
o`0000D0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0
6ATI01006ATI00?o000003<c<`0c<c<00`0c<c<01Ol00000C4a<04a<C01<C4co000000<0IVIV00Go
000007moO`1oOgl0Ogmoo`00000409VIV@;o00001`2c/k<00ol00000VIVI09VIV@0309VIV@05o`00
001oOgl0Ogmo07moOol000000`1VIVH01Ol00000C4a<04a<C01<C4co000000@0<c<c00?o000001TI
6@0I6AT0100I6ATR000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooo
oooooooo100I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00P1VIVH2o`000140Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT03`0I6AT00ol00000<c<c03<c<`0203<c
<`03o`00001<C4`0C4a<0080C4a<00Co000006IVIP1VIVKo00000`1oOgl00ol00000VIVI09VIV@02
09VIV@03o`00002c/k<0/k>c00P0/k>c0_l0000409VIV@05o`00001oOgl0Ogmo07moOol000000P1V
IVH01Ol00000C4a<04a<C01<C4co000000@0<c<c00?o000001TI6@0I6AT0100I6ATR000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo100I6AT00ol00000<c<c
03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIVo`00000D07moO`03
o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03
0000000I6AT06ATI00l06ATI00?o000003<c<`0c<c<00P0c<c<01Ol00000C4a<04a<C01<C4co0000
00<0IVIV00Go000007moO`1oOgl0Ogmoo`00000409VIV@03o`00002c/k<0/k>c00T0/k>c00?o0000
09VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV00Go000004a<C01<C4`0C4a<
o`00000403<c<`03o`00000I6AT06ATI00@06ATI8P000004ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooo`<06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<
04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl01P1oOgl5o`0000L0Ogmo
00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c
00<0000001TI6@0I6AT03`0I6AT00ol00000<c<c03<c<`0203<c<`05o`00001<C4`0C4a<04a<C?l0
00000`1VIVH01?l00000Ogmo07moOol0000409VIV@03o`00002c/k<0/k>c00/0/k>c00Go000009VI
V@2IVIT0VIVIo`00000307moO`04o`00001VIVH0IVIVo`0000<0C4a<00?o000003<c<`0c<c<00P0c
<c<00ol000006ATI01TI6@0401TI6B8000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool301TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00`1<
C4`01@000000IVIV06IVIP1VIVKo000000H0Ogmo0ol0000509VIV@;o00001P1oOgl00ol00000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0=01TI6@03o`00000c<c<0<c<c00<0<c<c00Go000004a<C01<C4`0C4a<o`00000206IVIP05
o`00001oOgl0Ogmo07moOol00000102IVIT00ol00000/k>c0;>c/`0;0;>c/`03o`00002IVIT0VIVI
0080VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP05o`00001<C4`0C4a<04a<C?l00000100c
<c<00ol000006ATI01TI6@0401TI6B4000001?ooool00`00003oooooooooo`2;ooooo`;o0000@_oo
ool000Wooooo00@00000oooooooooooooooo0`0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<
C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`03o`00002I
VIT0VIVI00P0VIVI0_l0000507moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00d06ATI00?o000003<c<`0c<c<00`0c
<c<01Ol00000C4a<04a<C01<C4co00000080IVIV00Go000007moO`1oOgl0Ogmoo`00000309VIV@03
o`00002c/k<0/k>c00d0/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`04o`00001VIVH0IVIV
o`0000<0C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0401TI6B4000001?ooool0
0`00003oooooooooo`28ooooo`?o000000?oooooo`000?ooool0@Oooool000Wooooo00@00000oooo
oooooooooooo0`0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<0080C4a<00<00000
06IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00/0VIVI00?o0000
07moO`1oOgl00P1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0=01TI6@03o`00000c<c<0<c<c00<0<c<c00Go0000
04a<C01<C4`0C4a<o`00000206IVIP05o`00001oOgl0Ogmo07moOol000000`2IVIT00ol00000/k>c
0;>c/`0=0;>c/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl01?l00000IVIV06IVI_l0000304a<
C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I6ATQ000000Cooooo00<00000oooo
ooooool0Q_ooool2o`0000?ooooo00?oZKgXo`000?l00000@Oooool000Wooooo00@00000oooooooo
oooooooo0P0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IV
IP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00/0VIVI00?o000007mo
O`1oOgl00`1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0<01TI6@03o`00000c<c<0<c<c0080<c<c00Go000004a<
C01<C4`0C4a<o`00000306IVIP04o`00001oOgl0Ogmoo`0000<0VIVI00?o00000;>c/`2c/k<01@2c
/k<3o`0000L0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIVo`0000<0
C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0401TI6B4000001?ooool00`00003o
ooooooooo`23ooooo`?o00000_ooool01onZ_NSoZKgXojVmj?nY_NSo0000ooooool00000@?ooool0
00Wooooo00@00000oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`0303<c<`05o`00001<C4`0
C4a<04a<C0000000101VIVH00ol00000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00d0VIVI00?o
000007moO`1oOgl00`1oOgl01Ol00000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0<01TI6@03o`00000c<c<0<c<c0080<c<c00Go000004a<C01<C4`0
C4a<o`00000306IVIP04o`00001oOgl0Ogmoo`0000<0VIVI00?o00000;>c/`2c/k<01@2c/k<01?l0
0000c<c<o`000?l000060;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01?l00000IVIV06IV
I_l0000304a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I6ATQ000000Cooooo
00<00000ooooooooool0P?ooool3o`0000;ooooo1OnZ_NP2ojVmj003o`000?oooooo0000043ooooo
0009ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00`0c<c<01Ol00000C4a<
04a<C01<C4`0000000@0IVIV00?o000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0=09VIV@03
o`00001oOgl0Ogmo00<0Ogmo00Go000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT0300I6AT00ol00000<c<c03<c<`0203<c<`05o`00001<C4`0C4a<
04a<C?l000000`1VIVH01?l00000Ogmo07moOol0000309VIV@03o`00002c/k<0/k>c00D0/k>c0_l0
00080;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01?l00000IVIV06IVI_l0000304a<C003
o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I6ATQ000000Cooooo00<00000oooooooo
ool0O_ooool2o`0000?ooooo00?oZkgWojZmj?nZ_NP01OnZ_NP01OnY_NSo0000ojVmj?oooooo0000
03oooooo0009ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00P0c<c<00ol0
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00P1oOgl00ol0
0000VIVI09VIV@0?09VIV@03o`00001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH00`00
0000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0300I6AT00ol0
0000<c<c03<c<`0303<c<`05o`00001<C4`0C4a<04a<C?l000000P1VIVH01Ol00000Ogmo07moO`1o
Ogoo000000<0VIVI00?o00000;>c/`2c/k<03@2c/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo
00Co000006IVIP1VIVKo00000`1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00@0
6ATI8@000004ooooo`0300000?oooooooooo07_ooooo0ol00002ooooo`03ojbmion[_NOoZkgW00;o
ZkgW1onZ_NP01Ol0003oZKgXoooooooooooo000003kooooo0009ooooo`0400000?oooooooooooooo
o`806ATI00?o000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV
0080IVIV00?o000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0?09VIV@03o`00001oOgl0Ogmo
0080Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c
00<0<c<c00<0000001TI6@0I6AT0300I6AT00ol00000<c<c03<c<`0303<c<`05o`00001<C4`0C4a<
04a<C?l000000P1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<03@2c
/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00Co000006IVIP1VIVKo00000`1<C4`00ol00000
<c<c03<c<`0203<c<`03o`00000I6AT06ATI00@06ATI8@000004ooooo`0300000?oooooooooo07Wo
oooo0_l00003ooooo`04ojfmiOn/_NOo[;gWojbmi`?oZkgW1onZ_NP01Ol0003oZKgXojVmj?oooooo
000003kooooo0009ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00P0c<c<0
0ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00P1oOgl0
0ol00000VIVI09VIV@0?09VIV@03o`00001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH0
0`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0300I6AT0
0ol00000<c<c03<c<`0303<c<`05o`00001<C4`0C4a<04a<C?l000000P1VIVH01Ol00000Ogmo07mo
O`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<03@2c/k<01Ol00000VIVI09VIV@2IVIWo000000<0
Ogmo00Co000006IVIP1VIVKo00000`1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI
00@06ATI8@000004ooooo`0300000?oooooooooo07Kooooo0ol00002ooooo`03ok2mhon]_NGo[KgU
00;o[KgU00?o[;gWojbmi_n/_NH00on[_NL2ojZmj005ojZmionZ_NSoZ[gXojZmj?l000000onY_NP0
0ooooooo0000ooooo`0looooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0
<c<c0080<c<c00?o000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0
Ogmo0080Ogmo00?o000009VIV@2IVIT03`2IVIT00ol00000Ogmo07moO`0207moO`03o`00001VIVH0
IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT0
6ATI00`06ATI00?o000003<c<`0c<c<00`0c<c<01Ol00000C4a<04a<C01<C4co000000<0IVIV00Co
000007moO`1oOgoo0000102IVIT00ol00000/k>c0;>c/`0;0;>c/`05o`00002IVIT0VIVI09VIVOl0
00000`1oOgl01Ol00000IVIV06IVIP1VIVKo000000<0C4a<00?o000003<c<`0c<c<00P0c<c<00ol0
00006ATI01TI6@0401TI6B4000001?ooool00`00003oooooooooo`1dooooo`;o00001?ooool3ok2m
h`;o[KgU00?o[[kUojbmi_n/_NH00_n/_NH00on[_NOoZkkWoj^ni`03ojZmi`;oZ[gX00?o0000ojVm
j?nY_NP00_nY_NP00ol0003oooooooooo`0kooooo`002Oooool01000003oooooooooooooool201TI
6@03o`00000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IV
IP03o`00001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT03`2IVIT00ol00000Ogmo07moO`0207mo
O`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c
<`030000000I6AT06ATI00d06ATI00?o000003<c<`0c<c<00`0c<c<01?l00000C4a<04a<C?l00003
06IVIP05o`00001oOgl0Ogmo07moOol00000102IVIT00ol00000/k>c0;>c/`090;>c/`03o`00002I
VIT0VIVI0080VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP05o`00001<C4`0C4a<04a<C?l0
0000100c<c<00ol000006ATI01TI6@0401TI6B8000001?ooool00`00003oooooooooo`1aooooo`?o
00001?ooool2ok>lh0?o/;gS00Co/KkSojjniOn^_^Go[[kU0_n/_NH00on]_^KoZkkWoj^ni`02oj^n
i`06ojZmionZ_NSoZ[gXojZmj?l0003oZ[gX1?nY_NP00ol0003oooooooooo`0jooooo`002Oooool0
1000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT03`2I
VIT00ol00000Ogmo07moO`0207moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00d06ATI00?o000003<c<`0c<c<00`0c
<c<01Ol00000C4a<04a<C01<C4co000000<0IVIV00Go000007moO`1oOgl0Ogmoo`00000409VIV@?o
00001P2c/k<2o`0000@0VIVI00Go000007moO`1oOgl0Ogmoo`00000306IVIP05o`00001<C4`0C4a<
04a<C?l00000100c<c<00ol000006ATI01TI6@0401TI6B8000001?ooool00`00003oooooooooo`1^
ooooo`?o00001Oooool00onh^m_o/kcPok>lh002ok>lh006ok2mhona_^?o/KkSok6nhon^_^Go[kkU
1?n]_^H3oj^ni`CoZ[gX00?o0000ojZmj?nZ_NP00onY_NP00ooooooo0000ooooo`0jooooo`002Ooo
ool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00?o000004a<C01<C4`0
0P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT0
3`2IVIT00ol00000Ogmo07moO`0207moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00d06ATI00?o000003<c<`0c<c<0
0`0c<c<01Ol00000C4a<04a<C01<C4co000000<0IVIV00?o000007moO`1oOgl00P1oOgl00ol00000
VIVI09VIV@0409VIV@Ko00001@2IVIT00ol00000Ogmo07moO`0207moO`05o`00001VIVH0IVIV06IV
I_l000000`1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00@06ATI8P000004oooo
o`0300000?oooooooooo06cooooo0_l00006ooooo`Co^;_K0_nc_>02okJmg`;o/KkS00Co/koSojnn
iOn__^Go[kkU0on]_^H4oj^ni`06ojZmj?nZ_^SoZ[kXojZnj?l0003oZ[gX1?nY_NP00ol0003ooooo
ooooo`0iooooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c00<0<c<c
00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVKo000000D0Ogmo00?o000009VIV@2I
VIT03@2IVIT00ol00000Ogmo07moO`0307moO`05o`00001VIVH0IVIV06IVIP000000101<C4`00`00
0000<c<c03<c<`0303<c<`030000000I6AT06ATI00l06ATI00?o000003<c<`0c<c<00P0c<c<00ol0
0000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IVI_l00000101oOgl00ol00000VIVI09VIV@0=
09VIV@03o`00001oOgl0Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C003o`00000c
<c<0<c<c00<0<c<c00?o000001TI6@0I6AT0100I6ATR000000Cooooo00<00000ooooooooool0JOoo
ool3o`0000Oooooo0_nm^=D3okRkf`?o][gO00?o^;oOok>ohonc_n<00_nc_n<00on__^Go/;oUok2o
i@03ojfniPCoZkkW0onZ_^P00ol0003oZ[gXojZmj003ojVmj003ooooool0003ooooo03Wooooo0009
ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<
C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00`1oOgl00ol00000VIVI09VI
V@0;09VIV@03o`00001oOgl0Ogmo00<0Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT03`0I6AT00ol00000<c<c03<c
<`0303<c<`03o`00001<C4`0C4a<0080C4a<00Go000006IVIP1VIVH0IVIVo`00000407moO`;o0000
302IVIT00ol00000Ogmo07moO`0207moO`05o`00001VIVH0IVIV06IVI_l00000101<C4`00ol00000
<c<c03<c<`0203<c<`03o`00000I6AT06ATI00@06ATI00?o000000000000000080000004ooooo`03
00000?oooooooooo06Oooooo0_l00008ooooo`03ol6dcOnm^=Go_KSE00;o_KSE00Co^;_Kok^lf_nk
_=[o][gO0onh_ml2ok>oh`03okC0hon`_nGo/;oU00;o/;oU00?o[KkVojfoion[_^L00on[_^L3ojZn
j004o`000?nZ_NSoZ[gXojZmj0?oZKgX00?oooooo`000?ooool0>?ooool000Wooooo00@00000oooo
oooooooooooo0P0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<0080C4a<00<00000
06IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`;o00002`2IVIT2o`0000D0Ogmo00?o0000
06IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<00000
01TI6@0I6AT03`0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<0080C4a<00Co0000
06IVIP1VIVH0IVIV0_l0000507moO`?o00001P2IVIT3o`0000@0Ogmo00?o000006IVIP1VIVH00P1V
IVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I
6ATS000000Cooooo00<00000ooooooooool0I?ooool3o`0000Wooooo0oo1]<d2okfhe@05ol6jdonk
_=[o^kcJok^lf_nn_mX00onh_ml01?nj`Moo]<3SokC0hond`><2ok2oi@04ok30iOn]_nOo[KoWojfo
i`CoZkkW0_nZ_^P00ol0003oZ[gXojZmj002ojZmj0;oZKgX00?oooooo`000?ooool0>?ooool000Wo
oooo00@00000oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<
00<0C4a<00D0000006IVIP1VIVH0IVIVo`00000707moO`03o`00002IVIT0VIVI00H0VIVI0_l00006
07moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`03
03<c<`030000000I6AT06ATI01006ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C002
04a<C003o`00001VIVH0IVIV0080IVIV0_l0000607moO`Ko00001P1oOgl00ol00000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@05
01TI6B<000001?ooool00`00003oooooooooo`1Rooooo`;o00002oooool4ol6dc@Co`K[C00Go^kcJ
okjof_nn_m[o_[oJokRog`03ok[1g`03okC0hone`N?o/<3U00?o/<3U1?n]_nL2oj^ni`;oZ[kX00?o
0000ojZnj?nZ_NP00_nZ_NP3ojVmj003ooooool0003ooooo03Oooooo0009ooooo`0400000?oooooo
ooooooooo`<06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C0030000001V
IVH0IVIV0080IVIV00?o000007moO`1oOgl01@1oOgl2o`0000@0VIVI0_l0000807moO`03o`00001V
IVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I
6AT06ATI01806ATI00?o000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00304a<C003o`00001V
IVH0IVIV00<0IVIV00?o000007moO`1oOgl03@1oOgl2o`0000@0IVIV00?o000004a<C01<C4`00P1<
C4`00ol00000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00@06ATI90000004ooooo`0300000?oo
oooooooo05oooooo0ol0000<ooooo`;oa:o50_o1]<d2olJgb`;o`K[C00GoaKgCokjof_nn_m[o_[oJ
ol;2fP03ok[1g`04ok_3h?ne`N?o]L7SokG1h`;o/<3U0_n``NH3ojfoi`?oZkkW00?oZ[kXo`000?nZ
_^P01?nZ_NP3ojVmj003ooooool0003ooooo03Kooooo0009ooooo`0400000?ooooooooooooooo`<0
6ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C003o`00001VIVH0IVIV0080
IVIV00?o000007moO`1oOgl01`1oOgl4o`0000T0Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000
C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT04P0I6AT00ol00000
<c<c03<c<`0303<c<`;o0000101<C4`00ol00000IVIV06IVIP0306IVIP;o0000301oOgl00ol00000
IVIV06IVIP0206IVIP;o0000101<C4`00ol00000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00D0
6ATI90000004ooooo`0300000?oooooooooo05gooooo0_l0000>ooooo`?oa:o500Go`KC=olJgboo6
]l_oa[O;ol6jd`03olFmd`05okjof_o2`][o`/;Jol;2f_nj`Ml00onk`n001?ne`N?o]L?TokG3i?ne
`n@2ok31iPCo[KoW00CoZkkWoj^nj?n[_^So00000_nZ_^P3ojZmj0CoZKgX00?o0000ooooooooool0
=Oooool000Wooooo00@00000oooooooooooooooo0`0I6AT00ol00000<c<c03<c<`0303<c<`03o`00
001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0A07moO`;o0000
1@1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT0
4`0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<0080C4a<0_l0000506IVIP?o0000
1P1oOgl3o`0000@0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0303<c<`03o`00
000I6AT06ATI00H06ATI90000004ooooo`0300000?oooooooooo05[ooooo0ol0000?ooooo`;oaJVm
0_o4[lD01Oo9//?oa[O;olJgboo6]l_obk_;00?oaKgC0_o9`]<00oo2`][oa<GKolC5f`02ok_3h005
okc5hOne`nCo]L?TokG3i?nea>D00on``NH3ojfoi`?oZkkX00?o0000ojZnj?nZ_^P01?nZ_NP4ojVm
j003o`000?oooooooooo03Cooooo0009ooooo`0400000?ooooooooooooooo`@06ATI00?o000003<c
<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00?o000007mo
O`1oOgl03`1oOgl00ol00000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c
<`0c<c<00`0c<c<00`0000006ATI01TI6@0E01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<
C01<C4`00`1<C4`2o`0000H0IVIV1_l0000606IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c
<`0c<c<0100c<c<00ol000006ATI01TI6@0501TI6BD000001?ooool00`00003oooooooooo`1Goooo
o`?o00004Oooool3olFY_@05olB_aOo9//?obK;3olVb`oo6]l/00oo;^l/01?o5_M?obL;ColW2doo9
`]<3olC5f`05olG9gOnlaN7o_<GQokc5hOne`n@00onea>D00on``NKo/<7Wok31i`03ojfoi`;oZkkX
00Co0000ojZnj?nZ_^SoZ[kX1?nZ_NP3ojVmj003ooooool0003ooooo03Cooooo0009ooooo`040000
0?ooooooooooooooo`@06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C003
0000001VIVH0IVIV00@0IVIV00?o000007moO`1oOgl0301oOgl2o`0000H0IVIV00<0000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`0303<c<`030000000I6AT06ATI01L06ATI00?o000003<c<`0c
<c<0100c<c<00ol00000C4a<04a<C00404a<C0;o00003@1VIVH3o`0000D0C4a<00?o000003<c<`0c
<c<0100c<c<00ol000006ATI01TI6@0501TI6BH000001?ooool00`00003oooooooooo`1Eooooo`;o
00004oooool4olFY_@CobK;30oo;^l/01?oA`L_obL;ColW2doo9`]<2olg7e005olC5foo5bMgoaLWM
olG9gOnlaN400_nlan<2okG4i@03okC4i_n``NOo/<7W00;o/<7W0_n]_nL2oj^nj003o`000?n[_^So
Z[kX00?oZ[kX0_nZ_NP4ojVmj003o`000?oooooooooo03?ooooo0009ooooo`0400000?oooooooooo
ooooo`@06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0
IVIV00D0IVIV00?o000007moO`1oOgl02@1oOgl2o`0000L0IVIV00<0000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0303<c<`030000000I6AT06ATI01L06ATI00?o000003<c<`0c<c<01@0c<c<0
0ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00L0IVIV0ol0000704a<C003o`00000c<c<0
<c<c00@0<c<c00?o000001TI6@0I6AT01P0I6ATV000000Cooooo00<00000ooooooooool0D_ooool3
o`0001Gooooo00?oa::golFY_Oo5ZKd00_o;[K/2olVb``;od;O200Gobk_;om71booA`L_odL7;olW2
d`02olg7e005olo<e_o5bMgoaLWMolG9gOo6c=l00onlan<01?nkb>Co]<CVokC4i_nda>H2ok31i`06
ojo1ion]_nOo[KoWojfoion[_^So00000_n[_^P3ojZnj0?oZ[gX0onY_NP00ooooooo0000ooooo`0c
ooooo`002Oooool01000003oooooooooooooool401TI6@03o`00000c<c<0<c<c00<0<c<c00?o0000
04a<C01<C4`00`1<C4`00`000000IVIV06IVIP0506IVIP?o00001P1oOgl2o`0000P0IVIV00<00000
04a<C01<C4`0101<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI01T06ATI00?o0000
03<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00504a<C0Wo0000201<C4`2o`0000H0<c<c00?o0000
01TI6@0I6AT01P0I6ATW000000Cooooo00<00000ooooooooool0D?ooool2o`0001Oooooo0_o4X[L0
1Oo5ZKgobjfkol^]^oo;[K_obK;300?od;O200Koe[k2om71booA`L_odL7;omK7c?o=am@3olo<eP05
olG9gOo6c=ooa/cOolK<gonlan<00onkb>@00onda>Ko/lCWojo1i`03ojo1i`04ojfoion/_nSo[;oX
o`0000;oZkkX1?nZ_^P00onZ_NSoZKgXojVmj003ojVmj003o`000?oooooooooo03;ooooo0009oooo
o`0400000?ooooooooooooooo`D06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C003
04a<C0030000001VIVH0IVIV00L0IVIV1_l0000906IVIP030000001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0:01TI6@05o`0000000000000000000?l000002`0I
6AT00ol00000<c<c03<c<`0503<c<`;o00005@1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I
6AT06ATI00L06ATI9`000004ooooo`0300000?oooooooooo04gooooo0ol0000Hooooo`?oa::g1?o;
[K/01?oB/k[od;O2om2g`_o@]l82omJn`P04om71booFalcoe/O<omW?c`?oclcF0oo6c=l2olG>h@;o
^lST00Co^/WVok?4ionca>Oo/lCW0_n_`NL2ojk1j0;o[;oX00Co0000oj^nj?n[_^SoZkkX0onZ_^P6
ojVmj003ooooool0003ooooo03;ooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00?o0000
03<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV01@0IVIV0P000006
04a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02P0I6AT00ol00000000000000005
000000X06ATI0ol0000603<c<`Go00003@1<C4`3o`0000H0<c<c0_l0000901TI6BP000001?ooool0
0`00003oooooooooo`1;ooooo`;o00006_ooool01Oo1W;;oa::golBR]oo4X[OobjNe00?objfk0_oB
/kX01?o@]l;oe[k2omJn`_oF_/83omK7c0;ofLo?00CoclcFom3AfOo@dMWoa/cO0oo5c^44ok[9iP03
ok?4ionba>Oo//CW00;o[/7X00Ko[L7Xojboj?n/_nSo0000ojboj?n[_^P5ojZnj0KoZKgX00?ooooo
o`000?ooool0<Oooool000Wooooo00@00000oooooooooooooooo1@0I6AT00ol00000<c<c03<c<`03
03<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH04`1VIVH00`000000C4a<04a<C005
04a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02P0I6AT;000000/06ATI00?o0000
03<c<`0c<c<0200c<c<3o`0000H0C4a<1?l0000703<c<`;o00002P0I6AT00ol0000000000000000V
000000Cooooo00<00000ooooooooool0B?ooool3o`0001_ooooo0oo1W;801Oo4X[OobjNeol^W]Oo;
YkGobjfk00?od[>j1?oF_/800ooLalCoe/O<omW?c`02omW?c`?od=7I0_o@e=d00oo5c^7o`loTol??
i002ok[9iP;o^<SW00?o//CWok33j?n``nP00on]`NP00on/_nSo0000oj^oj005ojZnj0;oZ[gX1_nY
_NP00ol0003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool501TI6@03o`00000c
<c<0<c<c00<0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0@06IVIP8000001`1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI3P00000;01TI6@;o00002`0c
<c<6o`0000X0<c<c00?o000001TI6@0I6AT02@0I6ATZ000000Cooooo00<00000ooooooooool0AOoo
ool3o`0001gooooo1?o1W;801?o4X[OobjNeol^W]Oo;YkD4om:c^P03omZk^ooF_/;oe[k200;og<O4
0ooIcll2om_FdP03om3AfOo@e=god=CM00;ocMOP00?o`loToko?i_nocnH00onhb>L4ok33j004ojg1
j?n]`>SoZkoXo`0000;oZkoX1?nZ_^P00onZ_NSoZKgXojVmj005ojVmj003ooooool0003ooooo033o
oooo0009ooooo`0400000?ooooooooooooooo`D06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000
C4a<04a<C00404a<C0030000001VIVH0IVIV00h0IVIV0P00000704a<C08000001P0c<c<00`000000
6ATI01TI6@0901TI6@l0000000?o000001TI6@0I6AT02P0I6AT00ol00000<c<c03<c<`0G03<c<`03
o`00000I6AT06ATI00T06ATI:`000004ooooo`0300000?oooooooooo04?ooooo0_l0000Oooooo`03
okfE[_o1W;;o`Ibb00;o`Ibb1?o;YkD00ooB[[Cod[>jom:c^P02omZk^`03omJn`_oLalCog<O400;o
h]3600?ofLo?om_Fd_oKe]800_oKfmH01?o@e=gocMOPolgGh?o9en@4oko?iP03okS8ioneanSo]LOX
00;o/<?X00Ko[l;Xojg0j?n]`>So[L3Xo`000?n[_nP2oj^nj0?oZ[kX2OnY_NP00ooooooo0000oooo
o`0_ooooo`002Oooool01000003oooooooooooooool501TI6@03o`00000c<c<0<c<c00<0<c<c00?o
000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0=06IVIP030000001<C4`0C4a<00H0C4a<00<0
000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0901TI6A8000002`0I6AT3o`0001@0<c<c0ol0
000:01TI6B`000001?ooool00`00003oooooooooo`10ooooo`?o00008?ooool3okfE[P;o`Ibb0_o8
XK02ol^W]@;odZjd00Kod[>jomZk^ooJ^k_of[^kon;6_?oLal@3on;@aP03onGJbOoKe];ofm_F00;o
fm_F00?ofMoKolgGh?o9en@00_o9en@2oko?iP;o_<gW00?o]LOXok;6j?n_`^P00on_`^P01On]`>So
[;oXo`000?n/_nSoZkkX00GoZ[kX2?nY_NP00ooooooo0000ooooo`0_ooooo`002Oooool01000003o
ooooooooooooool501TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`0101<C4`00`00
0000IVIV06IVIP0=06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0901TI6A@000003@0I6AT4o`0000d0<c<c0ol0000<01TI6Bd000001?ooool00`00
003oooooooooo`0nooooo`;o00008_ooool4okfE[P05ol6L/_o8XK3ob:6`olRQ/?o;YkD00ooB[[@0
1_oK^;Gof[^komZk^ooJ^k_oh/JlonSA_P?oh]3600CoiM[9onKRc_oVh/kofm_F0_oIgm/2omCQh003
olWGi?o4eNOoa=GW00;o_<gW00Co^<_Xok;6j?nba^So//KX0_n_`^P2ojk1j003ojboj?l0003oZkoX
00GoZ[kX00?oZ[gXojVmj?nY_NP01onY_NP00ooooooo0000ooooo`0^ooooo`002Oooool01000003o
ooooooooooooool401TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`0101<C4`00`00
0000IVIV06IVIP0=06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0901TI6AD0000000?o000001TI6@0I6AT03P0I6AT3o`0000H0<c<c1?l0000>01TI
6Bh000001?ooool00`00003oooooooooo`0kooooo`?o00009?ooool01?ngSjco_IF^okfE[_nmUJh4
olRQ/0CodZjd0_oK^;D00ooJ^k_oh/Jlon;6_002onSA_P03on;@a_oUf/WoiM[900;oi^;>00Goi>SC
omWOfooDhN3oe>7PolkOi@03olCEi`Co^<_X00So//KXok34j?n`a>So/<CXojk1j?n/`>SoZkoXo`00
00;oZkoX0_nZ_^P4ojZmj0WoZKgX00?oooooo`000?ooool0;Oooool000Wooooo00@00000oooooooo
oooooooo100I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH0301VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00D0<c<c00<0000001TI
6@0I6AT02@0I6AT00ol0000000000000000E000001806ATI1_l0000A01TI6Bl000001?ooool00`00
003oooooooooo`0iooooo`;o00009_ooool2okN?[0?o_IF^00Goa9^]olRQ/?o8XK3ob:6`om6Y/002
om:^]0?ofkRe0_oRa[`3onSA_P04ongM`OoUf/Woi^;>onKRcP;oi>SC00?ogn_JomCQh?o>gnD00_o>
gnD00oo4eNOo_m;XokoBj002okS;j0;o]<SY0_n`a>P01on^`^So[<3Xojc0j?n/`>So0000oj^oj?n[
_^P00onZ_^P2ojZmj0_oZKgX00?o0000ooooooooool0;?ooool000Wooooo00@00000oooooooooooo
oooo100I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00<00000o`00001V
IVH0301VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00D0<c<c00?o000001TI6@0I
6AT02P0I6ATI000002H06ATI00<00000o`0000000000;P000004ooooo`0300000?oooooooooo03Ko
oooo0ol00009ooooo`;oV:CN0_n2V=l2ofZ6g0;oEG;C5_ooool3okN?[0;o_IF^0_o4Vjd2olRQ/0?o
dJV`00KodZjdom^h]OoK^;GofkReonG4]_oRa[`3onSA_P03ongM`Oo_j<Goi^;>00?oi>SC00Cogn_J
omS[hOo>gnGoc]oU0_o7fnP01_nod^So^/kYok[>jOnjc^Wo]<SYok75j0Co[/;X00?o[<3Xojboj?l0
00000on[_^P00onZ_^SoZ[gXojZmj00=ojVmj003o`000?oooooooooo02_ooooo0009ooooo`040000
0?ooooooooooooooo`<06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<C003
0000001VIVH0IVIV00d0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`03
0000000I6AT06ATI00X06ATI7@00000R01TI6C8000001?ooool00`00003oooooooooo`0cooooo`?o
00002_ooool2ojR[f@?oV:CN0_n2V=l2ofZ6g003oeEbdom:HlWoBV?901?ooooo00?o[hN/okN?[?ng
Sj`00_ngSj`01OnmUJkoa9^]olBK[Oo4Vjgob:6`00?odJV`0ooK^;D2onG4]P?oj=6n0_o]gL401Oo_
j<GokO3:ong`b_oTj=?ogn_J00;of>_Q0_o@inL00oo7fnSo`=GZol3EjP02ok[>j@04okG9jOnaaNSo
/LGXok75j0;o[/;X0_n]`>P00on/_nSo0000ojZnj003ojZnj0?oZ[gX3?nY_NP00ol0003ooooooooo
o`0[ooooo`002Oooool01000003oooooooooooooool301TI6@03o`00000c<c<0<c<c0080<c<c00?o
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0>06IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6Ah0000000?o000001TI6@0I6AT07P0I
6ATc000000Cooooo00<00000ooooooooool0<Oooool2o`0000_ooooo00?o/ZcBojR[fOnXZmT00_nX
ZmT01?nHY=koU:?OogNChOmgTn42oeElg0;oEG;C00CoBV?9odYJ`Om:F/7oBU[13oooool3ojn7[0?o
]hn/1?o4Vjd4om6Y/003om^d/OoK^;GoiLBf00;oiLBf00CokM:honSA__o]gL7okMg10_o_j<D2ong`
bP03onOedOoPm][of>_Q00;od>OW00CoamoZol3Ej_o0eN[o`=GZ1?nebNT00onaaNSo[l;Wojo2i`02
ojg0j004ojbnion[_^OoZkkWo`0000;oZ[kX00?oZ[gWojZmj?nZ_NP00_nZ_NP00onY_NSoZ[gXojVm
j009ojVmj003o`000?oooooooooo02[ooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00?o
000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00204a<C00300000?l00000IVIV00l0IVIV00<0
000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI8P00
000L01TI6@03o`00000000000000034000001?ooool00`00003oooooooooo`0^ooooo`?o00002ooo
ool01?niZ/_o/ZcBok:/d_nb[=83ojR[f@?oU:?O0_mgTn401OmEO=co>6;@ocQRd?lhH]3oBV?900;o
BU[100?oE5Vjooooooooool02oooool4ojn7[0;o]hn/00?o_IB/olBK[Oo4Vjd00_o4Vjd3om6Y/0;o
fkBa00?ofkReonG4]_oUa;H00_o]d[P2oo?P^P05ongM`Oo_j<GokO3:ong`b_oWmM400_oPm]X00ooG
l^?od>OWolOOjP02olOOjP03ol3Ej_njc^Wo^/kY00;o]LWY0_nba>L00on_`^Oo[[kVojjniP03ojbn
i`03oj^niol0003oZkgW00?oZ[gW0_nZ_NP2ojZmi`;oZ[gX2_nY_NP00ol0003oooooooooo`0Yoooo
o`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00?o000004a<
C01<C4`00P1<C4`00`000000IVIV06IVIP0@06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0:01TI6BD000006P0I6ATd000000Cooooo00<00000oooo
ooooool0;?ooool2o`0000cooooo1?niZ//00onb[=;o]JgAokF]d@03ojR[f@;oU:?O0omgTn401?mE
O=co>6;@ocQRd?lWClD2odYJ`@;oE5Vj2oooool2ojF0[0?o[hN/00Co]hn/okfD[?nmU:co_IB/0_o4
Vjd2olfT[P04om6Y/?oK];7ofkBaom^d/@;oiLBf0oo]d[P2oo?P^P04ooC]^oo`m[gokO3:onOed@;o
h?KJ0_oGl^<00oo>j^WoamoZolOOjP02okoEjP06ok[>jOnfa^Oo]/KWokK6ionba>Oo/;kT1?n^_^H0
1?n/_^Oo[;gUoj^miol00002oj^mi`03ojZmion[_NOoZkgW00?oZ[gW0onZ_NP9ojVmj003o`000?oo
oooooooo02Wooooo0009ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00P0c
<c<01Ol00000C4a<04a<C01<C4`0000000L0IVIV1000000806IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6BH00000600I6ATe000000Cooooo
00<00000ooooooooool0:Oooool3o`0000gooooo0_nkYlD3okVZb`Co]JgA00?oZ:_IojZ]f_nZ[MX0
0_nAY>82of^@i0;o>g3K0_lhH]001?lWClGoBU[1odYJ`OmDFKX2ofEN]P?oN6Jb1?ooool01?nHN:go
YH2/ojF0[?nUP:`3ojn7[0Co_IB/00Goa9^]olfT[_o=Y:kocJB^om6Y/003om^d/@04onK2/ooUa;Ko
kM:hongB^0?oln2j00?om>fkoo3f_OoXnl<00_oPoLd01?oIo=_oeo;SolkZjOo>j^T2olGMj`03okoE
j_nibNKo^LWV00;o]/KW00Co/kkRok2ni?n`_^Co/;kT0_n^_^H01_n^^n?o[;gUojbmiOn/_NGo0000
oj^mi`;o[;cV00?oZkgWoj^mi_nZ_NL00onZ_NL00onZ_NSoZ[gWojVmj009ojVmj003o`000?oooooo
oooo02Sooooo0009ooooo`0600000?ooooooooooooooo`0I6AWo0000100c<c<01Ol00000C4a<04a<
C01<C4`0000000D0IVIV0`00000407moO`0300000?l00000000000D0IVIV00<0000004a<C01<C4`0
0`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00X06ATI9`0000000ol000000000
01TI6@0D01TI6CH000001?ooool00`00003oooooooooo`0Wooooo`;o00003_ooool00onlX[oo^jO5
ok^Wa@02ok^Wa@03okVZbonl[<Wo_:c900;o]JgA00?o^K3@ojZ]f_nZ[MX00_nZ[MX2oi6ThP;oJi3T
00Oo>g3Koa1>b_l@C/[o9do5obQ7_?m:F/7oE5Vj00?oIEjf0_mhI[82ohU_[`?oV7R]0onUP:`3ojn7
[004okF=[?nmU:co_IB/okfD[0CocJB^0ooK];42onK2/`;ol=>d00CokM:hoo?P^_och;[om>fk0_o`
m[d00ooXnl?oh?g=omWlf`02om7ei`04olkZjOo5gN_oaMg[okg=iP?o^LWV1?nc_^800on`_^Co/;[P
ojjkh`03ojjkh`03ojbmiOn]^nCo000000;o[;cV00Co[KcUoj^mi_n[_NKoZkgV0_nZ_NL01?n[_NOo
Z[gWojZmionZ_NL2ojVmj003ojZmj?nY_NSoZKgX00GoZKgX00?o0000ooooooooool09oooool000Wo
oooo00H00000oooooooooooooooo01TI6Ol0000403<c<`05o`00001<C4`0C4a<04a<C0000000101V
IVH00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00X06ATI:P00000D01TI6CH000001?oo
ool00`00003oooooooooo`0Tooooo`?o00003oooool3okbR_`;o^jO500Go_jS2okb/bOnl[<Wo_:c9
okF]d@03okV`d0;oZZgJ00?o[;7LohjWi_n>YnH00_mMS^P2oaaUf@04oa1>b_l0=[_o9do5obQ7_0;o
E5Vj0_mUG[H2ogQV/P?oRFn_0onHN:d3ojF0[003ojn7[?neSJco]Hf/00?o_IB/00Koaif^olfT[_o=
Y:kocJB^omR`/?oK];43onK2/`;ol=>d00?om^Beoo?P^_odkK/00_o`m[d00ooXnl?oh?g=omWlf`02
om7ei`;obNK[00GoaMg[okg=i_nmcNKo_LgVokW9iP02okJnh0;o/kkR00Co/[OLok2jh?n`^^3o/;[P
0_n^^n<2ojnih003ojfki?l0003o[KcU00?o[KcU00?oZkgVojbli_n[_NL00on[_NL3ojZmi`?oZ[gX
1_nY_NP00ol0003oooooooooo`0Wooooo`002Oooool01@00003ooooooooooooooooo000000@0<c<c
00Go000004a<C01<C4`0C4a<0000000306IVIP800000301oOgl00ol00000IVIV06IVIP0206IVIP03
0000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0:01TI6B`0
0000500I6ATe000000Cooooo00<00000ooooooooool08_ooool2o`00017ooooo1?nlX[l01?nkYlGo
_jS2oknX`_noZ<82okb/b@05ol6_b?ni/=3o^K3@okV`d?nm]=400on//M`2ohjWiP;oGHkX00Go76GI
o`0g_Ol@C/[o03JkobQ7_002ocU:^0;oIEjf0omhI[82ohU_[`?oV7R]0_nUP:`01?nYQ:go]Hf/okF=
[?neSJ`2okfD[0;oaif^0_o=Y:h2omR`/003om^d/OoV`[?oi/:c00?ol=>d00Som^BeooGa/_o/n:oo
k?R_omkj[ooDo;Wod?o;olkmh0;obno/00?obNK[ol7Bioo1d^L00_nmcNH2okRmgP03okJnh?nd/mSo
];?H00?o/[OL00Wo/;[Pok:efonb]M_o/[GKojnih?nb]mco[k[Ro`000?n_^^800_n]_>D01?n^^n?o
[;cVojbli_n/_>H4oj^mi`;oZ[gW1?nZ_NP6ojVmj003o`000?oooooooooo02Kooooo0009ooooo`05
00000?ooooooooooooooool000000`0c<c<01Ol00000C4a<04a<C01<C4`0000000<0IVIV00<00000
07moO`1oOgl0101oOgl3000000H0Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<
C4`0000000D0<c<c00<0000001TI6@0I6AT02P0I6AT]000001@06ATI=0000004ooooo`0300000?oo
oooooooo01oooooo0ol0000Cooooo`04okZM^onlX[oo_::ookbR_`Co_jS200Go_:c9ol6_b?o1[lSo
`Jo8okV`d003okfdd@03ojbag?n_]mooSJc[00;oSJc[0_m@Sn`01?l0FM?o03Nmo`0f^olXAk`2ocU:
^0;oDUBf00?oIEjfogQV/_mhI[800_n9Kjl3oiQh[@03ojF0[?nYQ:goZHB]00Co]Hf/00Go_IB/olNM
[_o7WJkoaif^olfT[P02omR`/003onG1/ooV`[?oi/:c00;ol=>d0_ofi;D01_oelK;ok?R_omkj[ooN
nZood?o;olkmh0;obno/0_o3enT00oo1d^Oo^KgLokVmg003okRmgPCo];?H00?o/[OLokB`eOnb]M/0
0_nb]M/01Ond/MKo/[OLok:gg?nb]mco000000;o/KWO0on^^n<00on/_>Ko[KgUojfmi@02oj^mi`04
ojbmi_nZ_NOoZ[gWojZmi`?oZ[gX1_nY_NP00ooooooo0000ooooo`0Vooooo`002Oooool01000003o
ooooooooooooool403<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH00`000000Ogmo07moO`02
07moO`<000000`2IVIT2000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<
C4`0000000D0<c<c00<0000001TI6@0I6AT03@0I6ATZ000001@06ATI00?o0000000000000000<@00
0004ooooo`0300000?oooooooooo01cooooo0ol0000Eooooo`;o^Yfk0onlX[l01Oo0Y;go_jS2oknX
`_noZ<;oa:c100?o`Jo80onm]=401?o1^]?o[kOOojnggon_]ml3ohf/j`;oD8o/00Co05WCo`0g_Ol0
5ZGo:4Nl0_liB[P2oe9D]P;oN6Jb0on9Kjl00onHN:goVW^_ojV4[@03ojV4[@?o]Hf/1?o7WJh3omR`
/0;oiL6c00Koi/:coo3C]?ofi;Gom^BeooGa/_o/n:l2omkj[`04okGe/Onoo]?oa_O/ol;Mk0?o`mOY
1?ni_M`00onh_Mko]:oCokB_d`02okBcf005okBZc_nd/=Go];3EokB`eOnb]M/00ond/MH00onb]mco
]KGIo`000003ok6ig`04ojjkhon`_>;o/;cRojfmi@;o[[gU0on/_NH00onZ_NOoZkgWoj^mi`03ojZm
j0KoZKgX00?o0000ooooooooool09Oooool000Wooooo00@00000oooooooooooooooo0`0c<c<01Ol0
0000C4a<04a<C01<C4`000000080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@06
09VIV@030000001oOgl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c
<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0400I6ATV000001L06ATI<P000004ooooo`0300000?oo
oooooooo01[ooooo0_l0000Gooooo`Co^Yfk00Go_::ool2T_Oo0Y;go`:BmoknX`P03olB/`@04ol6_
b?o6/lSoa[?8okfdd@?o`K[C00Co[kOOok:nhonb_^?o/[kS0_n=/o02odFBl003o`1@bOl07ZGo01JU
00;o>DZh0_mBE;H2ofeR]0?oQVnb0_nJNjl4ojV4[@;o]Hf/00?o_YN_olNM[_o7WJh00_o7WJh00ooC
[;7of;2`onG1/`02onG1/`05oo7E]?o`dkCom^BeooKT]OoelK800_o4ki@00onemK7o_okColKgk003
ol;Mk003ol?GjOni_Mco^KgL00;o^KgL00Co]:_?okB_dond[m?o]:oC1?ndZ/h00ond/=Go]Z_=okBa
eP02okBaeP04okV_d?ne]MWo]KGIo`0000;o/KWO0_nd^Md00on`_>;o/[cQojjmi@03ojjmi@05ojbm
i_n/_^Ko[;kVoj^mion[_^L01?nZ_NP6ojVmj003o`000?oooooooooo02Cooooo0009ooooo`040000
0?ooooooooooooooo`<0<c<c00Go000004a<C01<C4`0C4a<0000000206IVIP050000001oOgl0Ogmo
07moOol000002P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00@0000004a<C01<C4`00000
100c<c<00`0000006ATI01TI6@0H01TI6Al000006@0I6AT`000000Cooooo00<00000ooooooooool0
5oooool3o`0001Sooooo0_nhV;P2okZM^`03oknO^Oo0Y;go`:Bm00;o`:Bm1?o4[<43olJcb005ol^i
bOo1^]?o`K[Col6jdoo6`MH00onb_^<4ohjlm@03ocnIlol0C/3o01JU00;o3SFd0_mBE;H2ofeR]0?o
QVnb0_nJNjl4ojV4[@04okF=[?nnUjoo_YN_okjG[`;oaif^0_oC[;401OoH/;3oiL6conG1/ooU`K?o
lMFd00;omnVc00GolOFZomcdWOo4kiCoWo6lokWkj002okoSl@;o`]g/0_ni_]h00oni_Mco/ZO=ok:W
c@03okB[c`03okB_dondXlSo]:?800;o]:[>00Go]j?5okJ[cOnfZlgo]Z_=okBaeP03okV_d0;o0000
00Co^[KEokBigOnd^Mgo^;_K0onb_>42ojjmi@;o[kkU00?o[;kVojfni_n[_^L00_n[_^L3ojZmj0Ko
ZKgX00?oooooo`000?ooool09?ooool000Wooooo00@00000oooooooooooooooo0P0c<c<01Ol00000
C4a<04a<C01<C4`000000080IVIV00D0000007moO`1oOgl0Ogmoo`00000<09VIV@050000001oOgl0
Ogmo07moO`0000000`1VIVH010000000C4a<04a<C000000403<c<`030000000I6AT06ATI01h06ATI
00<00000o`0000000000500000000ol000006ATI01TI6@0I01TI6@03o`0000000000000002`00000
1?ooool00`00003oooooooooo`0Fooooo`;o00006?ooool01OncTkKo^9RhokRH^?nhV;So^Yfk00?o
_ini0_o0Y;d2olFX_0;oa:c10_o:/<401Oo6/lSobkW9ol^ibOo;^LWo`K[C00?oa/7F00?o/[kSokK6
ionfa^L00_n>_?D2oi74n@03od>Sm_l0C/3o01JU00;o3SFd0_mBE;H01?m]H[CoQVnbohI_/_n6Kk83
oiYk[`?oZHB]1?nnUjl01?o7WJkodjbaom>//OoC[;43onG1/`;olMFd0_ogjK<00ooamJ[oa>nDoioe
h002okKXmP03okoSlOnf_n7o][oQ00?o^KkN1?nbYld00ondZloo/Yg2okBSb002okBSb007okBZc_ng
XlGo]j?5okNSaOnfZlgo^jS6okV_d003o`000003okZfeOl0003o^[KE00Co^;_K00?o/[cQokBnhOnd
_^400_n__^D01?n`_nGo[KkVojfni_n]_^H3oj^ni`?oZ[gX1_nY_NP00ol0003oooooooooo`0Soooo
o`002Oooool01000003oooooooooooooool203<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH0
10000000Ogmo07moO`00000309VIV@Ko0000102IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV
00@0000004a<C01<C4`00000100c<c<00`0000006ATI01TI6@0R01TI6A<000007P0I6AT]000000Co
oooo00<00000ooooooooool05_ooool00ol0003oooooo`00000Fooooo`;o/i>f0onhV;P4oknO^@05
ol2T_Oo5Z;coaJRlolFX_?o4[<400oo:/<43ol^ib@;od<3;0_o6`MH2ol[8f@05okK6ionic^[o^LkZ
okW>j_nAa?T00_nFc?X01_m?/?[o0020o`0;W?l>=KCo=4Rhoe9D]P;oKF:d0on6Kk82oiYk[`;oZHB]
00?o/8jbokjG[onnUjl00_nnUjl4om>//@04on;0]_oU`K?olMFdoo7E]0;omnVc00KolOFZomcdWOnW
jO[oYnWjokKXm_nb`nH4okJoh@03okVng_n`Y<co/:C<00;o/ZO=00Go[YNook:M`_nbWL;o/Yg2okBS
b002okFK_P?o]j?50ol000001oni[m3o_Zo<okj_c?nn[lco^[KEo`000?no]m<00_nh^m/2okbmf`03
okBnhOng`>7o/;oU00?o/;oU00?o[KkVojfoion]_nL00on[_^L00onZ_NSoZ[kXojZnj006ojVmj003
o`000?oooooooooo02;ooooo0009ooooo`0600000?ooooooooooooooo`0c<c?o00000`1<C4`01000
0000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VIVOl000001P2c/k<2o`0000<0VIVI00Go
000007moO`1oOgl0Ogmoo`00000206IVIP050000001<C4`0C4a<04a<C0000000100c<c<00`000000
6ATI01TI6@0T01TI6@h000008P0I6AT[000000Cooooo00<00000ooooooooool05_ooool01?l0003o
ooooooooool0000Dooooo`Co/i>f0_nhV;P01?nlV[Ko_inioknO^OnoWkT4olFX_006ol^]_?o:/<7o
b[31olZ``Oo@]l;obkW90oo@`</01OoEb<kob/SIol[8fOo:b=WocM3L00;o^LkZ0_nke>d01_nFc?[o
W=7joicAn_nLdO[o00^Lo`he]0;o=4Rh0_m]H[@3ohI_/P;oVW^_00CoZHB]ok2>/_n`S[;o/8jb0onn
Ujl3om>//@;oh/2f00Kol=Vioo7E]?oaeKComnVcoo7eZ_nhiH@2ojOYnP04oj_6kOnb`nKo//?Vok;3
iP;o][oQ00Go[:?>ok2Tc?n`Y<co/:C<ok:Wc@03ojjG_`;o/Yg20oneVkh3o`000004okZO_OnkZ<Ko
^jS6ol2X`@?o_Zo<0_no]m<00ol0003oa;_Bokbmf`02okbmf`?o]l3Q0_n`_nD2ok70i@;o[KoW1?n[
_^L2ojZnj0KoZKgX00?o0000ooooooooool08_ooool000Wooooo00H00000oooooooooooooooo03<c
<ol0000204a<C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVIo`0000090;>c
/`05o`00002IVIT0VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP00000304a<C003o`00000c
<c<0<c<c0080<c<c00<0000001TI6@0I6AT09@0I6AT00`00003o00000000000800000003o`00000I
6AT06ATI00`06ATI2000000>01TI6BX000001?ooool00`00003oooooooooo`0Fooooo`05o`000?oo
ooooooooooooool000004_ooool2ojj>]@?o/i>f00Go^9RhokbJ]_nlV[Ko_9ZfoknO^@02olBS^0?o
aJRl0_o;[K`01?o:/<7od;O2om2g`_oF_l@3om30b`;oeLS>00?ob/SIolg@g?o=d=`00_o?eml01Onk
e>go_=S^okcHk_nlf>koW=7j00;oX]?i00?o00^Lo`he]?ldB;P00_mMG[/3ohI_/P03oiYk[onMP[Ko
/8jb00?o/8jb0_nnUjl2olZV]@04om>//OoR`;Koh/2fon;0]P;ol=Vi00?olMFdooOY/onhiH@00onR
bO<2oj_6k@03ok;3i_nXXm7o[:?>00?o[:?>00?o/:C<ojZB_On^Ukl00on^Ukl00onbWL;o/YBho`00
0002o`000005okFK__njWkgo^YnmokZO_OnkZ<H00oo0Z<402?nn[lcoa;;8olBbb?no]m?oa;_Bo`00
0?o4^m;o_;gK0_no`M/00ong`>7o^<?RokS3hP02ok70i@04ok71i_n]_nOo[KoWojfoi`;oZkkW00Co
ZkkXojZnj?nZ_^SoZ[kX1_nY_NP00ol0003oooooooooo`0Qooooo`002Oooool01P00003ooooooooo
ooooool0<c<co`000080C4a<00@0000006IVIP1VIVH000000P1oOgl01Ol00000VIVI09VIV@2IVIWo
000000T0/k>c00Go000009VIV@2IVIT0VIVI0000000207moO`040000001VIVH0IVIV000000<0C4a<
00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0B01TI6@D000004@0I6AT6000000h06ATI
0`00000803<c<`@000002`0I6AT00ol0000000000000000V000000Cooooo00<00000ooooooooool0
5Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00CoYhRdojj>]On^S[Go
[Xje0oncTkH4okbJ]PCoa:>h00CoaJRlol^]_?o;[Kcobjfl0oo@]l82omJoa003om30booEb<koeLS>
00;ofM7A00GocM3LoloGgoo?emoocmOOoloLh`02okcHkP;o_=W_00GoX]?iojOBm_nWd_Ko01FUocA8
^002oeeN^`?oPW:i0onMP[H3ok2>/P05okjG[oo:Y[GobZJeolZV]OoC[;400_oR`;H3oo3I^@03ooGa
]OoQmZ7oVL[h00;oX/Wc00?oWZSNoj>UeonSYML00onXXm42ojbScP04ojF?__nZT[goZY:mojZB_@;o
[YNo0ol000001?nbU;So]I^nokFK__nhUkH3okZO_@Co`:S10oo4//P2olBkdP03o`000?o9`M;o_l7K
00;o_l7K0onh`n84ok71iP?o[KoW0on[_^P3ojZnj0KoZKgX00?o0000ooooooooool08?ooool000Wo
oooo00H00000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIV00000080Ogmo00D0
000009VIV@2IVIT0VIVIo`00000:0;>c/`04o`00002IVIT0VIVI00000080Ogmo00@0000006IVIP1V
IVH000000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00l06ATI0`00000503<c
<`L000003@0I6AT2000000h06ATI00<0000003<c<`0c<c<03@0c<c<3000000P06ATI:@000004oooo
o`0300000?oooooooooo01Gooooo00Co0000og:Ci?mbTnCoIhON0_mQO=L00ooooooo0000ooooo`0;
ooooo`03oij3]_nWR;CoYhRd00Co[Xje00?o/i>fokNE]?ngUK@00_nlV[H00oo1WkGoa:>holBS^002
olBS^0?objfl0_oB];d01_o@]l;oe[o4omJoa?oF_lCoflS6omG8cP?ofM7A0_oKfMD00oo?emoocmcS
oloLh`02olgNi@03okcIkonkf>oo^mS_00;oYm;f00?oZlobo`0c]oldB;P00_mMG[/2oh9b^@?oWH:f
0on`S[84olZV]@03omZn_OoR`;Koh/2f00?ol=Vi00ComO6eoiV]i?nI[NCoVJgT0onNZ=h2oj>Ue`03
ojRSdOnPSL7oYHnn00;oYHnn0_nZT[d3o`000005ojf=]?nbU;So/YBhok:D^?neVkh00onhUkH2okZO
_@03ol2O^?o0Z<7o`:S100;oaj^m00Soa;;8ol^gaoo;]lOoa;_BolW1d_l0003obL7Boko1f`;o`/GL
00?o^<?RokW5honiaN<00_na`NH2ok72i`03ojfoion]_nSoZkkX00?oZkkX0_nZ_^P6ojVmj003o`00
0?oooooooooo023ooooo0009ooooo`0600000?ooooooooooooooo`0c<c?o00000P1<C4`01P000000
IVIV06IVIP000000Ogmo000000<0VIVI00?o00000;>c/`2c/k<02@2c/k<01Ol00000VIVI09VIV@2I
VIT000000080Ogmo00@0000006IVIP1VIVH000000P1<C4`00`000000<c<c03<c<`0203<c<`030000
000I6AT06ATI00`06ATI0`00000?03<c<`030000000I6AT06ATI01P06ATI0P00000C03<c<`800000
1`0I6ATX000000Cooooo00<00000ooooooooool05Oooool01_l0003oooooog:Ci?mbTnCoIhONof5l
e`;oHGC?0_mWL<P7ooooo`04oiAm]onNPkKoWX>foij3]P?oYhRd0_n^S[D01OnaT;?o]iFdokNE]?ng
UKCo_9Zf00?o`Ine0_o4XkP2olZY^004ol^]_?oB];god[Bmom:d_@?oe[o40_oKb<H01OoPd/[ofM7A
omWAdOoIdM7ofmWE00;ofmoI00?ocmcSolgNiOo=g^D00_o9g^P01onkf>oo^M?]okWCkOnidngoZlob
ojg7kOl0<kL00_mMG[/3oh9b^@?oWH:f00?o/8jbok^N^onkW[/00oo:Y[D2omZn_@06on;0]_o`fKWo
l=ViooGa]OoQmZ7oUk7Y0onI[N@01?nNZ=koUI3<oiZ>aOnJS/D3oj2=`@05ojF?__l0003o0000o`00
0?nZT[d01?n]SK@2ok:D^0Co^9Nf00Co^Ynmol2O^?o0WkSo`:S10oo7Zkd3ol^ga`?obL7B00?o0000
olk8e?o2aM`00_o4bMl00oniaN?o^<KUokS6i@02ok72i`04ok32ion]_nSo[KoXojfoj0CoZkkX0_nZ
_^P6ojVmj003o`000?oooooooooo01oooooo0009ooooo`0600000?ooooooooooooooo`0c<c?o0000
0P1<C4`00`000000IVIVo`00000207moO`040000002IVIT0VIVIo`0000d0/k>c00Co000009VIV@2I
VIT000000P1oOgl010000000IVIV06IVIP00000204a<C0030000000c<c<0<c<c0080<c<c00<00000
01TI6@0I6AT0200I6AT4000001<0<c<c00?o00000000000000005@0I6AT2000000X0<c<c10000008
03<c<`03o`00000000006ATI00H06ATI9`000004ooooo`0300000?oooooooooo01Gooooo00Co0000
oooooomNRNCoGXWT0_m?N]`01?mQO=OoHGC?of5dcomWL<P2og5```;oOG>n0_n9N;X3oiAm]`?oWX>f
0_nWR;@00on^S[Go/I2cok6@/`03okNE]0Co`Ine00Coa:>holZY^?o:ZKSobZVh1?oB];d00ooH_Koo
e[o4om_8aP02om_8aP;oh=;:00?ofM7Aom_IeOoKgmT00_oKgmT00ooIhmkocMkUolWNj002olWNj0;o
aM[Y00Go^M?]okO<j_ngc>[o[LO]o`00N003od1KaP;oPW:i0_nMP[H00onSTL;o^ijkok^N^`02ok^N
^`06olZV]OoJ_[gof[jmomZn_Oo/glGol=Vi0_oelKD2oi:Lf@?oTYGC0_nET<`3oiZ>a@?o00000_nU
Skh00onZT[goZ8RcojR8/`03ojf=]003ok:D^?ndT;7o]92a00?o^9Nf0oo0WkP01_o7XkCoaj^molN[
_Oo7Zkgock6lol^ga`;odko700KobL7Bolk8e?o>b=Co0000om7?eoo4bMl2ol?=hP03okS6iOnganKo
/<;W00?o/<;W00?o[KoXojboj?n/_nP00_n[_^P01?nZ_^SoZ[gXojZmj?nZ_NP6ojVmj003o`000?oo
oooooooo01kooooo0009ooooo`0600000?ooooooooooooooo`0c<c?o00000P1<C4`00`000000IVIV
0000000207moO`040000002IVIT0VIVIo`0000H0/k>c0_l000050;>c/`04o`00002IVIT0VIVI0000
0080Ogmo00@0000006IVIP1VIVH000000P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT0
6ATI00H06ATI00<0000003<c<`0c<c<0200c<c<8000000P0<c<c0P00000A01TI6@8000001@0c<c<7
000000@0C4a<1000000603<c<`030000000I6AT06ATI00D06ATI00?o00000000000000008`000004
ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00_mNRN@01?m?N]coAfgDodQUcOm8
ILd2ofM`b003og5``ommLkkoOG>n00;oRGRj0onDOKL3oij3]P;oYhRd1?naT;<2okNE]004okfJ]?o1
WkGo`Ineol6O]@CobZVh00?odK6jom:d_OoB];d00_oH_Kl2omo8`P03om_8a_oPd/[oh=;:00;ohm_>
0_oShm800ooKgmWofN?NomWSgP02omGThP03olWNj?o5f^WoaM[Y00;o`=;X00Go]lcZok>ohon^_>Co
[[cTo`0>V`02od1KaP;oNgc80onSTL84ok^N^`Cof[jm00?ok=o5on[j_?oZn[`00_nGX]d2oi:Lf@?o
TYGC0_nET<`2o`0000?oX8g100?oYHnnoj63/onXR;<00_nXR;<3ojf=]0Co]92a00?o^9NfokfH/Onm
V;400_o0WkP2olNS]003olN[_Oo?/Kcock6l00?odko700Gof/W8olk8e?oAcmOo0000om;Ff`03ol?=
hP?o]lOV0_n``^L2ojo2j003ojboj?n[_nSoZ[kX00?oZ[kX00?oZ[gXojVmj?nY_NP01OnY_NP00ol0
003oooooooooo`0Nooooo`002Oooool01P00003oooooooooooooool0<c<co`000080C4a<00<00000
06IVIP0000000P1oOgl010000000VIVI09VIVOl000040;>c/`;o000000<0c<c<o`00002c/k<01@2c
/k<01_l00000VIVI09VIV@000000Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<0000000503<c
<`030000000I6AT06ATI00<06ATI0P00000803<c<`<00000201<C4`4000000H0<c<c00<0000001TI
6@0I6AT03@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00d0C4a<0`00000403<c
<`8000001P0I6ATU000000Cooooo00<00000ooooooooool05Oooool01Ol0003ooooooooooooooooo
AGgR00;o<6WI00CoAfgDodQUcOmBHlKoDV?60_maL<<2ogec_P;oRGRj0_nDOKL3oij3]P03ojN8]?nY
R[Co/I2c00?o/I2c00?o]iFdokfJ]?nmV[@00oo1WkD00oo8YKKobZVholZY^002om6a^P04om:d_OoH
_Koof;foomRm_`;oglS200?oiM?5on3Bb_oSflh00_oSflh2on?SdP04on7YeooIhmkoeNCRomGThP;o
cn;U00CoaM[Yol3Bj?o0d^So`=;X0onc_n<2ojjli003o`0>Vom0FlKoNgc800;oNgc80onSTL82ok^N
^`;oc;_:0_oJ_[d2oncOa@04on[j_?nNY]coUj;MoiNRg@;oTYcI0_nBUM<3o`000003oiZ>aOnBOKWo
VWne00;oVWne0_nQPk<4ojR8/`03ojf=]?n_RJgo]92a00?o]92a0onmV;401?o0WkSoaj>dolNS]?o7
Xk@3olna_00:omVk^ooC_lOof/W8om[9b?oPe<codLoGom;Ffol0003od]KKol?=hP;o`LoT00?o]lOV
okC6j?nda^P00_n_`^P01?n^`NSoZkoXoj^oj?n[_nP4ojZnj0SoZKgX00?o0000ooooooooool07Ooo
ool000Wooooo00H00000oooooooooooooooo03<c<ol0000204a<C0030000001VIVH000000080Ogmo
00@0000009VIV@2IVIWo0000102c/k<01Ol00000c<c<0<c<c03<c<co000000D0/k>c00Ko000009VI
V@2IVIT0000007moO`00000206IVIP050000001<C4`0C4a<04a<C00000001P0c<c<01Ol000000000
00000?l00000000000L0<c<c0`00000?04a<C08000001@0c<c<2000000/06ATI0P00000503<c<`80
0000201<C4`4o`0000L0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0401TI6B@0
00001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00KoAGgRoc1YfOlT
F/oo95[?odQUcOmBHlH2of5W`P;oOG>n0_n9N;X3oiAm]`03oij3]_nOQ;GoZHZd00;oZHZd0_naT;<0
0onfU;Co_IZdokfJ]002okfJ]005ol6O]Oo8YKKob:FfolRU]_o:ZKP00_oA/KX2omVl_005omRm_ooO
b<;oglS2omo8`_oUdlD00_oXg/T00ooSflkohn?Bon?SdP02on7Ye`04omg[g?oGjN;oenWRoloRi@?o
b=[V00Co`=;Xok[6honja^?o/koS0_n^[mP2ojb]f004o`1?cOm0FlKoNgc8og]lb0?oXi7200Go^ijk
olbkb_o<^l[oc;_:omZn_@02oncOa@03on[j_?nLV]7oW9[A00;oT9?B00GoRHW=o`000?l0003o0000
ohR2aP02ohan_`?oTWfi0_nJOkD3oj63/`;oZ8Rc00CoZ8:/ojn9[On_RJgo[hV]0_ndT;401?niT:co
_IRaokfH/OnmV;44olNS]004om6[/_o?/KcofK^komVk^`?of/W800Ooh=C<on;NdOoBe]_od]KKo`00
0?o@fN3o`LoT00;o_LkW00?o]<KXok;5j?nbaNP00on^`NP00on[_nSoZkkXoj^nj003ojZnj0WoZKgX
00?o0000ooooooooool07?ooool000Wooooo00H00000oooooooooooooooo03<c<ol0000204a<C003
0000001VIVH000000080Ogmo00@0000009VIV@2IVIWo0000102c/k<01Ol00000c<c<0<c<c03<c<co
000000D0/k>c00Ko000009VIV@2IVIT0000007moO`00000206IVIP050000001<C4`0C4a<04a<C000
0000400c<c<2000000H0C4a<2000000604a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT01P0I6AT2000000H0<c<c00<0000004a<C01<C4`0101<C4`4o`0000@0IVIV1?l0000404a<C003
o`00000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT00`0I6ATT000000Cooooo00<00000oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`;o9FkN00?o<6WIobAJcolVD/P00_mBHlH00omQIl;o
Lffmog=]_@02ohAe^P?oTgbg0_nOQ;D3ojV:]003ok6@/onfU;Co]YBd00Co_IZd1?o8YKH3om6a^P;o
fKbl0ooOb<82onGCa@;oj=k900GojNO=on?Sd_oQjMOohNWGomg[g003omOYhP03om3SiOo8f^Kob=[V
00;o`LkU00?o^/KSok:dfonb]=/00on^[mP00on/[MSoZIg;o`1?c@03og]lb003oj>A`_n//=_o[;3K
00?oc;_:0_oMim/01?o/glGoYYc<ojJLc?nLV]43o`0000;oRHW=0on8P/H01?n<O[ooTWfioi9m^OnB
OKT3oiYo]@;oXH>c00?oZ8RcojR2[?nXPZ`00on_RJd01?ndT;7o^I2/okV@[?niT:`2okfH/@03olFL
[_o7XkCoaj>d00;odJ^b00Gock6lomVk^ooI^k_ohlRmom[9b002on3Dc0;oh]kA00God]KKom3Ih?l0
003obm[Uokg>i`02okW<j@03ok;5j?n_`nWo[l?Y00?o[<3X00?oZkkXojZnj?nZ_^P00onZ_^P8ojVm
j003o`000?oooooooooo01cooooo0009ooooo`0600000?ooooooooooooooo`0c<c?o00000P1<C4`0
0`000000IVIV0000000207moO`040000002IVIT0VIVIo`0000@0/k>c00Go00000<c<c03<c<`0c<c<
o`0000050;>c/`06o`00002IVIT0VIVI0000001oOgl000000P1VIVH01@000000C4a<04a<C01<C4`0
000000l0<c<c00<0000004a<C01<C4`00`1<C4`3000000P0IVIV0`00000404a<C0030000000c<c<0
<c<c00@0<c<c0`00000301TI6@8000001`0c<c<00`000000C4a<04a<C00204a<C0?o0000301VIVH0
0ol00000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT00`0I6ATS
000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`06obE^g_l7E=3o
95[?obAJcolVD/SoDV?60_mQIl82og=]_@;oQ7Fj0_nCO;L3oin4]@;oZHZd1?nfU;@2okfJ]0;o`j6f
0_o8YKH2oln^^006om6a^_oI_;cofKblomVl_?oQb;ooglS20_oUdlD3onSNb@04onWWcOoWk];oinkB
on?be`;ogO7M00?oenWRom3SiOo8f>D00_o8f>D00oo1c^Go]kgNok:df`03ok:df`03ojj_f?nXWL_o
ZIg;00;oZIg;00?oZIo<ofR@iOmXT>D01?n//=/01Oo<^l[ogNOKomgWfoo3oLCoYYc<00?o000000?o
VI7:ohR6b_n8Q/X00omlN/D2ohR2aP;oS7jo0_nBOKT3oiYo]@03oj63/onOO:coZ8:/00?oZ8:/0_n_
RJd4okV@[004okfH/Oo5W:koaIb^olNS]0?odJ^b0_oI^k/2on?8_@04oncG_ooPe<coh]kAon;Nd@;o
hNKG00Kod=WPo`000?o;f^Goa=OXokW<jOndbNT4ojo3j@03ojc0j?n[_nSoZkoX00CoZ[kX2_nY_NP0
0ol0003oooooooooo`0Kooooo`002Oooool01P00003oooooooooooooool0<c<co`000080C4a<00<0
000006IVIP0000000P1oOgl010000000VIVI09VIVOl000040;>c/`05o`00003<c<`0c<c<0<c<c?l0
00001@2c/k<01_l00000VIVI09VIV@000000Ogmo000000<0IVIV00@0000004a<C01<C4`000003`0c
<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00`0IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0603<c<`<00000200c<c<00ol00000C4a<04a<C00204a<C003o`00001V
IVH0IVIV00D0IVIV1?l0000506IVIP03o`00001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c
<c<00`0000006ATI01TI6@0401TI6B8000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Gooooo00Co0EgEo`MDd?l0@L?o9U;80_leE<@00omQIl;oLffmog=]_@02ohAe^P?oTgbg
0_nOQ;D00onYR[Co[Hjeojf>]@03okJD]005okfJ]?o3XKKo`j6fol>Q]_o8YKH00oo?[[P3omVl_0;o
hLRo0_oWeL<01?oUdlGoj=k9onSNbOoYild3onO^dP04on?beooMlMgogO7MomO[h`;ocn3U00?ob=SU
okg7hOng_Mh00_ng_Mh2ok:df`06ojVQconXWL_oZ9g;ojRMbonYWL_oYHnm0_nXT[h2ofR@i@;o[;3K
0_n[iOX01_oMim_o0000o`000?l0003oYYc<ojNFa0?oVI7:0_n8Q/X2ogaja@;oNg:m0_n2L;L3oi9m
^@03oiYo]OnFMjkoWgb/00;oWgb/0onXPZ`2ojn9[@04ok:8ZOniT:co^I2/okV@[0?oaIb^1?oAZk80
1ooL]k;ofK^kon?8_OoSb;gok=Nooo3U`_oRg]400_oQi]L2om[YgP03ol_JiOl0003oa=OX00?o]<WY
0_n_`nT01?n]`^WoZkoXoj^oj?n[_nP3ojZnj0_oZKgX00?oooooo`000?ooool06oooool000Wooooo
00H00000oooooooooooooooo03<c<ol0000204a<C0030000001VIVH000000080Ogmo00@0000009VI
V@2IVIWo00001@2c/k<2o`0000030<c<c?l00000/k>c00@0/k>c00Ko000009VIV@2IVIT0000007mo
O`00000306IVIP040000001<C4`0C4a<000000d0<c<c0P00000304a<C0800000101VIVH8o`0000@0
IVIV0P00000304a<C003o`00000c<c<0<c<c00l0<c<c00@0000004a<C01<C4`0C4a<0_l0000406IV
IPCo0000101oOgl4o`000080IVIV0_l0000304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI
6@0I6AT00`0I6AT00ol0000000000000000O000000Cooooo00<00000ooooooooool05?ooool00ol0
003oooooooooo`06ooooo`05o`5MeOl0>kko03VnobIBb?leE<@00_m<G<800omcKKgoQ7FjohAe^P03
oi=l]`03oin4]OnRQkOo[Hje00;o[Hje0onfU;@4ol>Q]PCocjjh00?of;ZkomVl_?oQb;l00_oQb;l2
onOE``;ok>;600Gok>g:onWdcOoYm<goinkBon?be`02omgag@04omO[hoo?h>Gocn3UolGAh`?o_LOQ
00?o]kgNojbXe?n/Z=@00onYXLl01?nXWL_oXXfnojF?_OnUSkd3ojRB_P?o7I_X0ol00002ojbIa004
ojnD^onWU/CoYiK4ojNFa0;oVI7:0_n8Q/X2ogaja@;oNg:m0_n2L;L3ohab/@;oUWN^0onOO:`3ojR2
[003ojn9[OnbR:Wo/XRY00?o^I2/0oo5W:h00oo?Y:codJ^bom6[/P02ombg/P07onS6/ooSb;gok=No
oncG_oo`iL;ok_77on7Ve`02om[YgP;odNOV00Coa=OXo`000?nmd^[o]<WY0_naa^T00on]`^Wo[<3X
oj^oj003oj^oj0?oZ[kX2onY_NP00ol0003oooooooooo`0Jooooo`002Oooool01P00003ooooooooo
ooooool0<c<co`000080C4a<00H0000006IVIP1VIVKo000007moO`00000209VIV@03o`00002c/k<0
/k>c00D0/k>c00?o00000;>c/`2c/k<0102c/k<01_l00000VIVI09VIV@000000Ogmo000000<0IVIV
00@0000004a<C01<C4`00000300c<c<00`000000C4a<04a<C00204a<C0040000001VIVH0IVIV06IV
IP?o0000201oOgl3o`0000<0IVIV00D0000004a<C01<C4`0C4a<0000000?03<c<`050000001<C4`0
C4a<04a<C?l000000`1VIVH3o`0000`0Ogmo00Go000006IVIP1VIVH0IVIVo`00000204a<C0030000
000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00`0I6ATR000000Cooooo00<00000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`03o`1;aol08Zco03Vn00;o=EC400?oC5c2ofIX`?mVJ<00
0_n4MKX01?nCO;OoTWjjoj:7]onRQkL4ojf>]@03okJD]?nmW;Oo_Ibg00?o`j6f00?oc:^ioln^^?o?
[[P00_oH^[/3on78_`?oimG300Cok>;6onc]b_o/kL[ojOC=0_oUn=801OoOmmWofo7Oom_agooEi^;o
cn3U00?oaM7S00?o_LOQok6cfOn/Z=@00on/Z=@01?nYXLooX8o2oj:=__nRSKh3ojF?_@;oZ9:n0ol0
00000on/S[Oo[YBlojjD_004ojnD^`;oYiK400?oVI7:oiJ;a_mmNlH00_mmNlH2ogaja@;oNg:m0_n2
L;L2ohab/@;oUWN^0onOO:`3ojR2[0?o/XRY0_niT:`2ol2DZ@05olFL[_o?Y:cocjB/olnT[?oAZk80
0_oL]k800ooXa[?olmVconcG_`02oo3U`P03onkaaooWmloogOSK00;odNOV0_o7h>/01?l0003o]/g[
okK=jonaa^T2ojk3j@;o[<3X0_n[_nP3ojZnj0coZKgX00?oooooo`000?ooool06_ooool000Wooooo
00H00000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIV00000080Ogmo00@00000
09VIV@2IVIWo00003@2c/k<01?l00000VIVI09VIV@00000207moO`040000001VIVH0IVIV000000<0
C4a<00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IV
I_l000003P1oOgl01Ol00000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<02`0c<c<0
1Ol00000C4a<04a<C01<C4co000000<0IVIV00?o000007moO`1oOgl00P1oOgl7o`0000D0Ogmo00Go
000006IVIP1VIVH0IVIVo`00000204a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0
0`0I6ATQ000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`09ooooo`05o`0m
]_l08Zco2Snoo`Xo_om<G<800_mVJ<02ogic_@;oTWjj0onRQkL2ojf>]@03ok>F^OnmW;Oo_Ibg00;o
_Ibg00Co`j6folb[^Oo<ZkWocjjh0ooH^[/2on78_`;ojMS400GoimG3oncRa_o/kL[ok>g:onWdc@02
onGhdP03omogfOoKlMoofo7O00;oeNKR0_o>en000oo5dN?o^[kMokZng@02ok6cf@;o[:SD00?oX9C8
oj2?`_nPSl800onRSKh01OnUSkgo0000o`000?l0003oZ8Vd00?o[8jg00?o[YBlok2@]?n`T;@00on_
U;/00onWU/CoZI>ooiJ;aP02oiJ;aP;oOG_60_m/Jl02og]b_@;oPW2g0on<L[42oiIg[P?oWgb/00?o
Z8:/ojZ1Z?nbR:T00onbR:T01?niT:co`9BYol2DZOo5W:h3olnT[0;og;Nb0_oXa[<01?ocfK?on>Za
oo3U`_o^lLL2onOgc`04omghfooBlNOoan3[olOPj`;o_MO]00Go0000ok77j_naan[o[/?Yojc0j003
oj^oj0;oZ[kX00?oZ[gXojVmj?nY_NP03?nY_NP00ol0003oooooooooo`0Iooooo`002Oooool01P00
003oooooooooooooool0<c<co`000080C4a<00@0000006IVIP1VIVH000000P1oOgl010000000VIVI
09VIVOl0000=0;>c/`04o`00002IVIT0VIVI00000080Ogmo00@0000006IVIP1VIVH000000`1<C4`0
0`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00
000307moO`[o00000`1oOgl01Ol00000IVIV06IVIP1VIVH0000000<0C4a<00?o000003<c<`0c<c<0
2@0c<c<01@000000C4a<04a<C01<C4co000000<0IVIV00Co000007moO`1oOgl0Ogmo0_l0000709VI
V@?o00000`1oOgl01Ol00000IVIV06IVIP1VIVKo00000080C4a<00D0000003<c<`0c<c<0<c<c0000
000601TI6B0000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00Ko
03ffo`0IY_l:?koo;4o3odaL`_mVJ<02ogic_@?oTWjj0_nRQkL00on]S[Go/iJiok>F^@04okfL]`?o
c:^i00?oeKVmomRj^ooH^[/00ooQb;l2onWHa005ongWaoo]llSokO?8onSjb_oRo<h00_oOnmH01?oN
m=cof^ONom[Wg_oEi^82olkGh0;oaLOK00Co^[kMojf[eOnTW/ooY9k?1?nPU<P2oj2?`P04oj:=__l0
003o0000oj>4/`CoZ8Vd0_n/S[L3ok2@]0?o[iBk0onYTkl3oiJ;aP;oOG_600?oK6_0of]T^?m[I;P0
0_n2L;L3ohab/@;oUWN^0_nOO:`00onPNZWoZX6XojZ1Z004ok:8Z@?o`9BY1?o?Y:`00ooL/Jcog;Nb
onS6/`02oo?I/`06ooSZ/OobmJkoiOZaonOgcooMn=_od_7W0_o6iNh2okgGk@;o]/k/00?o0000ojk3
jOn^`nT00_n/`>P00on[_nSoZ[kXojZnj003ojZmj0koZKgX00?o0000ooooooooool06?ooool000Wo
oooo00H00000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIV00000080Ogmo00@0
000009VIV@2IVIWo00003@2c/k<01?l00000VIVI09VIV@00000207moO`040000001VIVH0IVIV0000
00<0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV
06IVI_l000000P1oOgl00ol00000VIVI09VIV@0809VIV@04o`00001oOgl0Ogmoo`0000<0IVIV00<0
000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<0080C4a<00Go
000006IVIP1VIVH0IVIVo`00000207moO`03o`00002IVIT0VIVI00X0VIVI00Go000007moO`1oOgl0
Ogmoo`00000206IVIP04o`00001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT0100I6ATP0000
00Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`04o`0fZol06JKo2Sno
oba?``;oIVS00_mnLkd2oi9n^P03oj:7]onUS[co/iJi00?o/iJi0_nmW;L2olFW^`;oc:^i0_oE^Kd0
0ooH^[_ohLRoon78_`03onWHa004ongWaoo]llSoj?[:onSjbP;ogo_F00Kog_CLom[Wg_oJimkof^ON
omGHf_o?b]D3olG7f`?o[J_E0_nTW/l3oj2Db0?o000000CoWH6doj>4/onSQ;?oXhBc0onXRK@00on/
S[Oo[XZ_ok2@]003ok2@]003ojnD^oncTkKo/i>f00;oZI>o0_nFRlH01?nBRLKoKW;6ofiba_m/Jl02
of]T^0?oMVFb0_n<L[42oiIg[P03oiml[?nPNZWoX7ZY00?oZX6X0onbR:T3ol2DZ@?ocjB/0_oL/J`2
onS6/`09oo?I/oohj[7on>Zaoo;e[_oUn[7of_k0om?of?o;mN_oa^G^00;o^mS^0_nfc^`2ok76jP03
o`000?n/_nOoZkkX00;oZkkX00?oZ[kXojZmionZ_NP00onZ_NP00onY_NSoZ[gXojVmj00;ojVmj003
o`000?oooooooooo01Oooooo0009ooooo`0600000?ooooooooooooooo`0c<c?o00000P1<C4`01000
0000IVIV06IVIP00000207moO`040000002IVIT0VIVIo`0000H0/k>c00?o00000;>c/`2c/k<0102c
/k<01?l00000VIVI09VIV@00000207moO`040000001VIVH0IVIV000000@0C4a<00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVI_l000000P1oOgl00ol0
0000VIVI09VIV@0909VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH00`000000C4a<04a<C002
04a<C0030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP02
06IVIP04o`00001oOgl0Ogmoo`0000D0VIVI1?l0000409VIV@05o`00001oOgl0Ogmo07moOol00000
0P1VIVH01?l00000C4a<04a<C000000303<c<`030000000I6AT06ATI00<06ATI80000004ooooo`03
00000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool01?l08Zko;4o3oe=SaOmCHlD2ogic
_@03oi9n^_nBPl3oYHjl00;oYHjl0oncU[T01OnmW;OoaJNkolFW^oo5Yk_oc:^i00?oeKVm00?oglW3
on78_ooYf<@00_oYf<@01?o]ilOokO?8onSjb_oXn/X2omgme005omocfooMh]WogN;Iom[Wg_oEf=X0
0oo?b]D00oo5am_o^kSFok^heP03ojf[e@04ojBNcol0003o0000o`0000;oV82g0_nMPK@3oj>4/`?o
Z8Vd0on^RZl2ok2@]006okF@[oncTkKo/i>fok>C]_nYTkoo[IFn0onBRLH2ofibaP03oeAL__m/Jl3o
JfBh00?oMVFb0_n4Jjh2oi=bZ`?oX7ZY0onZPJP2ok:8Z@;o^HfW00Co`9BYol^MZOo;WJWocjB/0ooL
/J`02Oo[a:goj<Jcoo?I/oohj[7ol_F^onGj/OoJo/3odooHol_ej`02ol7Tl003ok_Hk_ndc>_o]<c[
00;o/LKZ00Go[/7Wo`000?n/_nOo[;oWoj^nj002oj^mi`;oZ[gW0_nZ_NP2ojZmi`;oZ[gX2onY_NP0
0ol0003oooooooooo`0Gooooo`002Oooool01P00003oooooooooooooool0<c<co`000080C4a<00@0
000006IVIP1VIVH000000P1oOgl010000000VIVI09VIVOl000050;>c/`03o`00003<c<co000000D0
/k>c00Go000009VIV@2IVIT0VIVI0000000207moO`040000001VIVH0IVIV000000@0C4a<00<00000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C0040000001VIVH0IVIVo`000080Ogmo00?o
000009VIV@2IVIT00P2IVIT5o`0000@0VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP030000
001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C005o`00
001VIVH0IVIV06IVI_l000000P1oOgl01?l00000VIVI09VIV@2IVIT3o`0000@0/k>c0_l0000209VI
V@05o`00001oOgl0Ogmo07moOol000000P1VIVH01Ol00000C4a<04a<C01<C4`000000080<c<c00<0
000001TI6@0I6AT0100I6ATO000000Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`03o`0k__l/Cl?oDf?500;oMgG40_nBPl03ojF>_0?o/iJi1?o5Yk/3omFi_@;oglW30_oX
g<P00ooYf<CokNO7ongWa`02on3nb003om_obooMoMCogo?K00?ogN;I00?ofM;AomK6boo?b]D00_o?
b]D01?o9_m3o^kSFojnYdOnNV<d3o`000003oiF:aOnDP[goU8:m00;oV82g0onMPK@3oj>4/`03ojR9
]?nYQ:go[XZ_00;o[XZ_00Co/92dokF@[oneT:oo]I2_0_ncTkH3ojfE_P?oTXW600?oKW;6oeAL__mD
G;h00_m[I;P2ogIU/P;oQ6^^0onCLZ/3oj1jZ@;oZX6X00Go/XRYokV=YoniSJOo^HfWol2DZ@02ol^M
Z@03olnT[?oL/Jcog;6/00;ojlB]00WonM^Zoo?I/oohj[7ol_F^okKXRonim[3o`okLol;alOo1i?00
0_nhd^d00ondc>_o/<;Wok32i`03ojk1i`05o`000?n/_>Ko[;cVoj^mion[^nD00on[_>L6ojZmi`03
ojVmj?nZ_NSoZKgX00SoZKgX00?o0000ooooooooool05_ooool000Wooooo00H00000oooooooooooo
oooo03<c<ol0000204a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIWo0000102c
/k<01Ol00000c<c<0<c<c03<c<co000000@0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`04
0000001VIVH0IVIV000000D0C4a<1@00000504a<C0040000001VIVH0IVIVo`000080Ogmo00Co0000
09VIV@2IVIT0VIVI0_l000050;>c/`;o00000`2IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV
00<0000004a<C01<C4`00P1<C4`300000080<c<c0P00000404a<C005o`00001VIVH0IVIV06IVI_l0
00000P1oOgl01Ol00000VIVI09VIV@2IVIWo000000P0/k>c00Go000009VIV@2IVIT0VIVIo`000003
07moO`04o`00001VIVH0IVIVo`000080C4a<00Go000003<c<`0c<c<0<c<c0000000501TI6Al00000
1?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00Go0026o`0k__mCHlGo
Df?5ogMea003oi:3`0?oYHjl00?o/iJiok^R_onkX[l00oo5Yk/00oo?]l;oeKVmomo9``02omo9``;o
j=c80_o/k//01OoXn/Woh?k8om_obooIoMSognkK00;og=SB00?ogN;IomWBdOoId]400_oFa//00oo?
b]GobKo@olVod003o`0000?oWYS=0_nER/D2oiB2_@;oV82g0_nMPK@2oj>4/`04oj=n[?nYQ:goZHB]
ojV4[@;o[XZ_1?neT:l00oncTkKo^INdokVG]003ojfE_P;oTXW60_m^L/H00omDG;koDeBfof]T^003
ogIU/P04ohA[[_nCLZ_oTg:[oi=bZ`?oX7ZY0_nZPJP4okV=Y`03ol2DZOo;WJWobifY00?og;6/0_o[
a:d01ooifj[onNbOonC^S?o6iX3o^OJ`ol?ng?o2lO400_njf_001Onhd^go//CWok;4ion``^Oo[k[R
00Co[KcT00?o0000ojfjhon[^nD00_n[^nD00on[_>OoZkcVoj^liP06ojZmi`;oZ[gX2OnY_NP00ol0
003oooooooooo`0Eooooo`002Oooool01P00003oooooooooooooool0<c<co`000080C4a<00@00000
06IVIP1VIVH000000P1oOgl010000000VIVI09VIVOl000040;>c/`05o`00003<c<`0c<c<0<c<c?l0
0000102c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1VIVH000003P1<C4`0
1?l00000IVIV06IVI_l0000307moO`04o`00002IVIT0VIVIo`0000T0/k>c00Go000009VIV@2IVIT0
VIVIo`00000207moO`04o`00001VIVH0IVIV000000L0C4a<0P00000604a<C005o`00001VIVH0IVIV
06IVI_l000000P1oOgl01?l00000VIVI09VIVOl0000:0;>c/`04o`00002IVIT0VIVIo`0000<0Ogmo
00Co000006IVIP1VIVKo00000P1<C4`01@000000<c<c03<c<`0c<c<0000000D06ATI7`000004oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol008Ko<ec=oc=Lc@02ogMe
a0;oTX?00_nUS[`00on[V/Go^j:ook^R_`02ok^R_`03olFW^oo?]l;ockO200;ofl_900WoglW3onSL
b?oXg<Soj=c8onc^booXn/Woc_k5olkobooIoMP00_oOk]/2omcHdP05omW7b?oId]7oe/K;omK6booC
_lH00ol000001?o3]/ko[jWAojnYdOn_ZM42oijHc@;oUH[50_nDP[d2oiR0]`03oif1]?nJNJgoXgj/
00;oXgj/0onYQ:d2ojj:[`04ok>:ZoneT:oo]I2_okF@[`?o^INd0_n]UKh00oncW<7oSXc<ohj<c002
oeEXbP03oeAL__mCE;KoDeBf00?oMVFb0_n4Jjh2oi=bZ`?oX7ZY00?oZX6Xojn5Yon_QJL00oniSJL3
ol^MZ@04omV]Z_oL/Jcog;6/on_4[@;onM^Z00ConNbOonC^S?nOl;Oo^OW/0_njhO<01Onjf_3o]<KW
okC6ionba>Oo/;SO00?o[k[R0_n]_>@2ojjgh003o`000?n]^^?oZk_U00;o[K[S00?oZkcVojbki?n[
_>H00on[_>H00onZ_NOoZkgWojZmi`02ojZmi`03ojVmj?nZ_NSoZ[gX00GoZKgX00?o0000oooooooo
ool05Oooool000Wooooo00H00000oooooooooooooooo03<c<ol0000204a<C0060000001VIVH0IVIV
0000001oOgl000000P2IVIT00ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00<0c<c<00?o
00000;>c/`2c/k<00P2c/k<01?l00000VIVI09VIV@00000207moO`05o`00001VIVH0IVIV06IVI_l0
00003@1<C4`010000000IVIV06IVI_l0000307moO`04o`00002IVIT0VIVIo`0000X0/k>c00Co0000
09VIV@2IVIWo00000`1oOgl01?l00000IVIV06IVI_l0000=04a<C005o`00001VIVH0IVIV06IVI_l0
00000P1oOgl01?l00000VIVI09VIVOl0000<0;>c/`04o`00002IVIT0VIVIo`0000<0Ogmo00Co0000
06IVIP1VIVKo00000P1<C4`010000000<c<c03<c<`00000501TI6Al000001?ooool00`00003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00Ko01^Uoc=LcOmZN]3oJW[@oi:3`?nAS/`4oj^J
a@;o^j:o00CoaKC9olng`_o?]l;ockO20_oKblT2onCSd@06onSLb?o/k/_of_o;olknaOo>ol_ofOgH
0_oOk]/2omcHdP;ofLO800Goekg1o`000?l0003o0000om>oaP04ol>fcP04ojnYdOnPV/koRhG7oh^5
a`;oQ7Rm0_n8LkD2oi5e/0?oVWV]0onSOZ`2ojV4[@03ojj:[oncRZ_o/hZ[00?o]I2_0oniUk@4ok>L
`@;oSXc<00CoEFS:ob]7_?mDG;koDeBf0omTF[42ohA[[P?oTg:[0_nPNZT3ojn5Y`?o^HfW0_o;WJT3
omV]ZP;ojlB]00?onM^ZooW/WooTkX`00_nfioH2ok[Ql`;o]<OX00?o]<KWok6fgOn`^=l00_n`^=l0
0on_^^;o[k?Kojncf`02ojjgh006ok2cf_l0003o[[OPojjgh?n]^^?o[[WQ0on/^n@2oj^liP04ojbl
i_n[_NOoZkgWoj^mi`?oZ[gW0_nZ_NP6ojVmj003o`000?oooooooooo01Cooooo0009ooooo`060000
0?ooooooooooooooo`0c<c?o00000P1<C4`01P000000IVIV06IVIP000000Ogmo00000080VIVI00Go
00000;>c/`2c/k<0/k>co`0000070<c<c0;o00000`2c/k<01?l00000VIVI09VIV@00000207moO`04
0000001VIVH0IVIV000000`0C4a<00D0000006IVIP1VIVH0IVIVo`00000207moO`04o`00002IVIT0
VIVIo`0000/0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIV000000d0
C4a<00Co000006IVIP1VIVKo00000`1oOgl01?l00000VIVI09VIVOl000050;>c/`?o00001@2c/k<0
1?l00000VIVI09VIVOl0000207moO`04o`00001VIVH0IVIVo`000080C4a<00@0000003<c<`0c<c<0
00001@0I6ATO000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`0KYOlcG<goJW[@00?oTHk<0on[V/D01OnkX[ooaKC9olFdbOo5]<WockO200?ofl_90_oThm401OoU
mm;of_o;om[obonkoM3oe?_Q00;ofn;K00?oelW<omcHd_oIalP00ol000001OoH^[codko6om>oa_oC
_lKodK_400;o`kK>00Go^Zk=oj2Jc_nPV/koX9[>oh^5a`02ohAh_@;oR7>e0_nAMK03oiYi[@?oXgj/
0_nYQ:d4ok>:Z`03okF@[onlU:go_9B]00;o^INd00Co`ineok>L`OncW<7o/ic10_n>S<`2oeEXbP03
ob]7_?mCE;KoDeBf00;oI5Za0_mlIJh3oi=bZ`03oj1jZOnRNjSo[hFW00;o[hFW0_niSJL2ol>FZ00:
ol^MZOoI[J[ofJfZomV]Z_o[`j_ojlB]ooWKZ_oik9oo0000okKWmP;o/lSY0_ndanP01On`/m_o/KKM
ok6fgOna]]go/;SO00;o/:oF00?o[k?Kok6]e?n`/mX00on`/mX00ol0003o/KGLojjih@02ojjih@05
ojbki?n^^n?o[[_Sojbli_n]_>D01?n[_NL2ojZmi`?oZ[gX1_nY_NP00ol0003oooooooooo`0Coooo
o`002Oooool01P00003oooooooooooooool0<c<co`000080C4a<00H0000006IVIP1VIVKo000007mo
O`00000209VIV@05o`00002c/k<0/k>c0;>c/ol00000203<c<`01Ol00000/k>c0;>c/`2c/k?o0000
0080VIVI00@0000007moO`1oOgl000000P1VIVH00`000000C4a<04a<C00:04a<C0050000001VIVH0
IVIV06IVI_l000000P1oOgl01?l00000VIVI09VIVOl0000;0;>c/`05o`00002IVIT0VIVI09VIVOl0
00000P1oOgl01?l00000IVIV06IVIP00000=04a<C004o`00001VIVH0IVIVo`0000<0Ogmo00Co0000
09VIV@2IVIWo00001@2c/k<00ol00000c<c<o`0000050;>c/`04o`00002IVIT0VIVIo`000080Ogmo
00Co000006IVIP1VIVKo00000P1<C4`010000000<c<c03<c<`00000501TI6Al000001?ooool00`00
003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_l0Cld01OmZN]3oTHk<oi6>c?nAS/co
Zi[500;o/jkC0oo5]<T2om7=eP04om_;bOoThm7oi>?AonGgdP;of_o;00Co^og@omCkhOoKh]_ofn;K
0_oGbL`2o`000003omW7b?oG_L7oekg100;of;Zl00Codko6om6ka?oA^lCockS40onj[/d2oj2JcP;o
RhG70_n4N;d2ohQc]@;oTGF`0_nJNJd3oj=n[003ojV4[On]Q:So/hZ[00?o/hZ[0onlU:d01_niUkCo
`ineol>O]Oo3WkGo/ic1okb[b0;oR9GJ0_lWF/l00ol[Akco:Cjcoe=D]P02ofAJ/@;oO6F^0onALJ/2
oj9kZ0Co[hFW00Co^HfWol>FZ?o3UZSobifY0ooI[JX01?o[`j_onmjUooWKZ_nke602ok78k003ok?8
jOn_/MWo/;?K00?o/;?K00?o/KKMok2YdOn`[mH00_n`[mH3ok6]e0;o/;?J00Go/joDok6eg?l0003o
/KGLojjih@02ok6hgP03ojjkhon`^n;o[KcU00;o[KcU0_n[_NL2ojbmiP;oZ[gW0onZ_NP5ojVmj003
o`000?oooooooooo01?ooooo0009ooooo`0500000?ooooooooooooooool000000P1<C4`010000000
IVIV06IVIP1VIVH200000080VIVI00Go00000;>c/`2c/k<0/k>co`00000:0<c<c005o`00002c/k<0
/k>c0;>c/ol000000P2IVIT010000000Ogmo07moO`00000206IVIP030000001<C4`0C4a<00T0C4a<
00D0000006IVIP1VIVH0IVIVo`00000207moO`04o`00002IVIT0VIVIo`0000/0/k>c00Go000009VI
V@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIV000000d0C4a<00Co000006IVIP1VIVKo0000
0P1oOgl01?l00000VIVI09VIVOl000050;>c/`05o`00003<c<`0c<c<0<c<c?l00000102c/k<01?l0
0000VIVI09VIVOl0000207moO`04o`00001VIVH0IVIVo`000080C4a<00@0000003<c<`0c<c<00000
1@0I6ATO000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`05o`1?
cOmAP^?oDH;Soi6>c?n@XMl01?nc[]<00oo5]<WodLgFom7=eP02omW[h004onCSdOoAo]go^Oc:ojcg
`@;ob_?/0_oAdMX3o`0000;oe;[00_oG_L43omRj_0?odK_40_o?^<@01?nj[/go[ZG>oh^:c?n;R/`2
og=a`P;oQ7Rm0_n8LkD2oi5e/0?oVWV]0_nSOZ`3ojf4Z0?o/hZ[0onlU:d4ol>O]@?o_:_80_n8UMX0
1?lWF/oo02:]ob]7_?lY?[<2ofAJ/@?oO6F^0_nALJ/3oj9kZ0?o[hFW0oo3UZP3omV]ZP;ojl>[00Go
nmjUoo3[S?n/b>ko/LS/ojf_f@03ojnaf@;o/;?K00Go[jC=ok2YdOn`ZM7o/:WAok2_eP02ok:Vc@03
ok6]e?ndZ<co/joD00?o/joD00Co/KGLo`000?nd/mSo/KSN0_nd^=`2ok2khP03ojfliOn^_NCo[[gT
00?o[;gV0on[_NL3ojZmj0GoZKgX00?o0000ooooooooool04_ooool000Wooooo00D00000oooooooo
ooooooooo`00000204a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT01?l00000/k>c0;>c
/ol000040<c<c0Go00000`3<c<`2o`000080/k>c00Ko000009VIV@2IVIT0000007moO`00000306IV
IP030000001<C4`0C4a<00P0C4a<00D0000006IVIP1VIVH0IVIVo`00000207moO`04o`00002IVIT0
VIVIo`0000/0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`04o`00001VIVH0IVIV000000d0
C4a<00Co000006IVIP1VIVKo00000P1oOgl01?l00000VIVI09VIVOl000050;>c/`05o`00003<c<`0
c<c<0<c<c?l00000102c/k<01?l00000VIVI09VIVOl0000207moO`04o`00001VIVH0IVIVo`000080
C4a<00@0000003<c<`0c<c<000001@0I6ATO000000Cooooo00<00000ooooooooool04_ooool00ol0
003oooooooooo`0Fooooo`04oe62hon@XMooT:7Ooi2Qg`;o/jkC0_nkcNL01ooAcMKofN_PomW[h?oI
jn3odOkMokWlb_nNmMT00_o:ln`3o`000003olfha_oGbLcoe;[000;oe;[000Coe;>iomNm`OoH^[co
f;Zl0_oI^[X01?oA^lCockS4olnha?o:]<D3ojjUcP;oRh[<00?oLg72og1V^?m`I[P00_n8LkD2oi5e
/0?oVWV]00?oXgj/ojAlZ?n]Q:P00_n]Q:P2ok>:Z`;o^XjY0_nlU:d00oo6WJgo`ineol>O]@02oln^
^@03okb[b?o8aMOob<GG00;oN:O`00Co03Zlo`0R[OlY?[?o:Cjc0_mTF[42ogaU[P;oTG6[0onRNjP2
ojn5Y`06okR=ZOo3UZSo`iJXol>FZ?oCYj_ofJfZ0_o[`j/2oo_NY@03ok_DH?nZ[M[o[JoI00;o[JoI
00?o[k7IojbOb_n_Y<d00on_Y<d00on`ZM7o/9o6ok:Vc@02ok:Vc@?o]:S<0_nc[m@2okR]cP03o`00
0?ni/mCo];SL00;o];SL0onb_>400on^_NCo[kkTojnni002ojbmiP;oZkgW0_n[_^L2ojZmj0GoZKgX
00?o0000ooooooooool04_ooool000Wooooo00D00000ooooooooooooooooo`00000204a<C0060000
001VIVH0IVIV0000001oOgl000000P2IVIT01?l00000/k>c0;>c/ol000030<c<c003o`00003Vi^H0
i^KV00<0i^KV00Go00000<c<c03<c<`0c<c<o`0000020;>c/`06o`00002IVIT0VIVI0000001oOgl0
00000`1VIVH00`000000C4a<04a<C00804a<C0050000001VIVH0IVIV06IVI_l000000P1oOgl01?l0
0000VIVI09VIVOl0000;0;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01?l00000IVIV06IV
IP00000=04a<C004o`00001VIVH0IVIVo`000080Ogmo00Co000009VIV@2IVIWo00001P2c/k<00ol0
0000c<c<o`0000050;>c/`04o`00002IVIT0VIVIo`000080Ogmo00Co000006IVIP1VIVKo00000P1<
C4`010000000<c<c03<c<`00000501TI6Al000001?ooool00`00003oooooooooo`0Booooo`03o`00
0?oooooooooo01Oooooo00CoQ`00oi2Qgon6__WoQ[ki0onkcNL2okS^m@04omW[h?magKWoLn7RokOR
m@?o000000CodM7Jolfha_o=^<KocKS60ooD^/02omBc^@03omNc]OoH^[cofKZj00;ofKZj00?of[^j
olnha?o:]<D00_o:]<D2ojjUcP;oRh[<00?oLg72og1V^?m`I[P00_mkIk02ohY][0?oV7FY0_nTO:P3
ojf4Z005ok>:ZonjSZWo^XjYokZ>ZOnlU:d00_o6WJd01?o3WkGocjjioln^^Oo?[[T3olS5e`08om3X
iom5/_OoAK;godFbmol08Zgo:CjcodM;/omTF[42ogaU[P?oTG6[0_nRNjP01On_QJOo^8fYokR=ZOnh
SJWo`iJX00;odjN[00KofJfZon_3Zoo[`j_onmjUoo3[S?nV[=`2ojZ]fP03ojf_fOnYW<Wo[9o:00;o
[9o:0_n_Y<d01On^VL7o/9o6ok2Oa_n`WlKo/ZK=00;o]:3400?o]:S<okVUaOnh[Lh00_nh[Lh01Onm
[<Wo^K?Do`000?ni/mCo];SL00;o^;WJ00Go/[cQokFmh?ne_N3o[kkTok2oi003ojfniP?oZkkW0onZ
_NP5ojVmj003o`000?oooooooooo017ooooo0009ooooo`0500000?ooooooooooooooool000000P1<
C4`020000000IVIV06IVIP000000Ogmo0000002IVIWo00000`2c/k<01?l00000c<c<0<c<c?l00007
0>KViP07o`00003<c<`0c<c<0<c<c?l00000/k>co`00000209VIV@040000001oOgl0Ogmo000000<0
IVIV00<0000004a<C01<C4`01`1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00Co000009VI
V@2IVIWo00002P2c/k<01?l00000VIVI09VIVOl0000307moO`04o`00001VIVH0IVIV000000d0C4a<
00Co000006IVIP1VIVKo00000`1oOgl01?l00000VIVI09VIVOl000060;>c/`03o`00002c/k<0/k>c
00@0/k>c00Co000009VIV@2IVIWo00000P1oOgl01?l00000IVIV06IVI_l0000204a<C0040000000c
<c<0<c<c000000D06ATI7`000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0
6?ooool2o`0e^`04o`1V[on6__WoQ[kiok_=i`;o^>ke00?oU_;Oog2Vl_l000000_l00003ol6me`06
ol6X`Oo=^<KocKS6olfha_o<[K[oe;[00ooD/kT00ooG/kGog;NcomVj^P02omVj^P03omZk^_oI^[_o
b[C500;ob[C50_nOVll2ofmhb`03oe1J__mcLL;oL6Jh00;oNfN`0on:KJ`2oiQeZ@?oY7bX0_n]Q:P4
okZ>Z@03okbD[Oo6WJgoaYf]00Cocjji00?oglJoolS5eoo@j>L00_njo>401?n4i[goXOKFo`0R[OlY
?[<2odM;/`?oO6F^0_nALJ/2oj9kZ0Co^8fY00Co`iJXom>WZooCYj_ojL:^0_o[`j/00ookgZGol>^<
oj>Ib`02ojJJb@?oZIc900?o[9o:oj^C_On^VL400on^VL400on`WlKo/YRlokBPa002okBPa0?o^JG5
00So^:g>okf/bOnm[<Wo_Jc9okVce?l0003o_[GAokRifP;o_;cI00?o]KgPokNohOn`_n@00_n`_n@0
0on]_^Ko[KkWojfni`02oj^ni`CoZ[gX1OnY_NP00ol0003oooooooooo`0@ooooo`002Oooool01@00
003ooooooooooooooooo00000080C4a<00<0000006IVIP0000000P1oOgl00`000000VIVIo`000002
0;>c/`04o`00003<c<`0c<c<o`0000T0i^KV00Co00000<c<c03<c<co00000P2c/k<00ol00000VIVI
0000000207moO`050000001VIVH0IVIV06IVI_l000002@1<C4`01@000000IVIV06IVIP1VIVKo0000
00<0Ogmo00Go000009VIV@2IVIT0VIVIo`0000080;>c/`05o`00002IVIT0VIVI09VIVOl000000`1o
Ogl01?l00000IVIV06IVIP00000504a<C0<000001P1<C4`01?l00000IVIV06IVI_l0000207moO`04
o`00002IVIT0VIVIo`0000`0/k>c00Co000009VIV@2IVIWo00000P1oOgl01?l00000IVIV06IVI_l0
000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATO000000Cooooo00<00000ooooooooool0
4Oooool00ol0003oooooooooo`0Iooooo`06o`0e^ol=@l;o8DFmoc=Ib_mEJlcoMgo>0ol00004ojfY
d`05ol6meoo1Z<7o`JS1ol6X`Oo=^<H00_o<[KX00oo?Z[?oe;>iomBc^@02omNc]@;og;Nc00?ofKZj
omZk^_oJ^kX00_oI^[/00oo:]<Go`jo6ol>_aP02oinKc`03ofmhbom@F[koD5Zn00;oL6Jh00CoNfN`
ohY][?n:KJcoRVf/0_nHMJT3ojAlZ0;o[HBX1?njSZT3olJM[@03omB//?o?[[Wocjji00;oglJo00Go
k^G5onSk_Oo1m:?oVnBFojoji@02okK[mP03o`0R[OlY?[?oAd^c00?oKV6b0_nALJ/00onRNjSoZ8:/
ojR2[003okR=Z@03ol>FZ?oCYj_odjN[00;ojL:^0_okgZD3oj>Ib`;oYY[900?oZIc9ojN?_?n[Tkd0
0_n[Tkd3ojjI`@?o/YRl00?o]:34okRL_?nhW;`00_niYLD3okf/b@04ol>^a_nn]M7o_[GAo`0000?o
_;cI0ong_n401?n`_nCo/L3Uok70iOn]_^L2ojfoi`;oZkkW0_nZ_NP00onZ_^SoZKgXojVmj003ojVm
j003o`000?oooooooooo013ooooo0009ooooo`0500000?ooooooooooooooool000000P1<C4`00`00
0000IVIV0000000207moO`050000002IVIWo00000;>c/ol000000P3<c<`00ol00000i^KV0>KViP09
0>KViP04o`00003<c<`0c<c<o`000080/k>c00?o000009VIV@0000000P1oOgl01@000000IVIV06IV
IP1VIVH0000000P0C4a<00D0000006IVIP1VIVH0IVIVo`00000307moO`03o`00002IVIT0VIVI0080
VIVI0_l000040;>c/`;o00000`2IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV00<0000004a<
C01<C4`00`1<C4`01@000000<c<c03<c<`0c<c<0000000D0C4a<00Co000006IVIP1VIVKo00000P1o
Ogl01?l00000VIVI09VIV@2IVIT2o`0000X0/k>c00Co000009VIV@2IVIWo00000P1oOgl01?l00000
IVIV06IVI_l0000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6ATO000000Cooooo00<00000
ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`08VOl0=K_o8DFm00?o00000_mgOlh2
oiBDd0?o[JWC1?o1Z<43olb]^P;ocjZc00?oe;>iomNc]OoL]k<00_oL]k<2omZk^P?ofKZk0oo3[lH2
oinKc`;oKgS;00?oD5Znoe=C]?m`I[P00_mkIk02ohY][0?oV7FY0_nTO:P00on]Q:So/hNWok>7Y`03
okZ>Z@;oaYf]0ooD[;001_o?[[WoglJoomo6_oo^iLGoj?^mo`0000;o/_;d00Go]^_fok;Dl_nbe?;o
01BSodM;/`03ofiQ/P;oSgB`0onXPZ`3okR=Z@;odjN[0ooY`Zh00ookiZOodN5coj2Jc`02oj>Ib`03
ojJJbOnSS;coYhnl00;oYhnl0on[Tkd00on^VL7o[i6gojnA]`02ok:H_0?o^9bl00Co^JG5okjT_onn
Y;oo_Jc90_o3[/H01Onn]M7oa;W?o`000?o4^Loo_;cI00;o`<3J00Co]koQokW2h_ni`^;o/L3U0_na
`NH2ojfoi`?oZkkX0_nZ_^P6ojVmj003o`000?oooooooooo00oooooo0009ooooo`0500000?oooooo
ooooooooool000000P1<C4`00`000000IVIV0000000207moO`050000002IVIWo00000;>c/ol00000
0P3<c<`01?l00000i^KV0>KViP3Vi^H4o`0000@0i^KV00Co00000<c<c03<c<co00000P2c/k<00ol0
0000VIVI0000000207moO`050000001VIVH0IVIV06IVIP0000002@1<C4`01Ol00000IVIV06IVIP1V
IVKo000000<0Ogmo00?o000009VIV@2IVIT00`2IVIT4o`0000D0VIVI00Co000007moO`1oOgoo0000
0`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`0
0`1<C4`01?l00000IVIV06IVI_l0000307moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c
/k<01P2c/k<01Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Co000006IVIP1VIVKo00000P1<C4`0
1@000000<c<c03<c<`0c<c<0000000D06ATI7`000004ooooo`0300000?oooooooooo017ooooo00?o
0000ooooooooool06Oooool3o`000004ob55_Om4DkgoJ6JmofQV_@;oMgo>0_nDU=000on]ZM?o/IVn
ok6I_P02ol6X`@;o`Z2f00Coc:fjolnZ/oo?Z[?ocjZc0_oG/kD3ombg/`03omnk/ooJ^k[ofKZk00;o
fKZk00?oeKJkol>_a_nkZ<H00on?TM401?m8Hl[oD5Znoe=C]?mCDk@2og]W/0?oRVf/0_nHMJT2ojAl
Z0?o/hNW0_njSZT2olBHZP0;olJM[OoD[;3oe:b`omB//?oVa;CoglJoonkUaOoXnkgo0000ojCdl?nb
l_@00_ncfO<00onbe?;o[l;Xo`0DX`02odM;/`;oKV6b0_n?M;03ojR2[0?o^8fY00?oain_om>WZooY
`Zh00_oY`Zh00ookiZOoX9[?oiZ;`P02oij:_P?oXhbl0_nWSk`2oj^C_@05oj^;]?n_TKOo[i6gojnA
]onbV;`00_nfU;D2okRL_0?o_ZBo0oo3[/H01_o:/lCoa;W?olBicol0003ob[o@ol30fP;o`lGK00Co
^L;RokW5honiaN?o/L7V0_na`^H2ojfoi`?oZkkX0_nZ_^P6ojVmj003o`000?oooooooooo00kooooo
0009ooooo`0400000?ooooooooooooooo`80C4a<00X0000006IVIP1VIVH0000007moO`000000VIVI
o`00002c/k?o00000P3<c<`01Ol00000i^KV0>KViP3Vi^Ko000000@0oooo0_l000030>KViP04o`00
003<c<`0c<c<o`000080/k>c00?o000009VIV@0000000P1oOgl010000000IVIV06IVIP00000:04a<
C0050000001VIVH0IVIV06IVI_l000000`1oOgl00ol00000VIVI09VIV@0:09VIV@04o`00001oOgl0
Ogmoo`0000<0IVIV00@0000004a<C01<C4`0C4a<0P00000603<c<`<000000`1<C4`01?l00000IVIV
06IVI_l0000307moO`03o`00002IVIT0VIVI0080VIVI0ol000020;>c/`?o00000`2IVIT01?l00000
Ogmo07moOol0000206IVIP05o`00001<C4`0C4a<04a<C00000000P0c<c<00`0000006ATI01TI6@03
01TI6B0000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo0ol00000
1Ooooooo00RIo`0W/?l@<[3oA5>m00;oJ6Jm0_n6N;`2oij9_0?o/IVn00Co`JS1ol:P]_o2X;Ko`Z2f
1?o?Z[<01?oD[K3oek>eombg/ooL]k<2omnk/`?ofKZk0_oE][/3ok^XaP?oSi7A00?o63Zfoe1J__mC
Dk@00_mYFjl3ohY][0;oV7FY00?oY7bXojQoZ?ncQjL00_ncQjL01OnjSZWoa9RZolBHZ_o4V:[oaYf]
00?oe:b`00Ooi/BdooOS/oo^iLGo_>9kojCdl?nag?Ko[l?X00?o/<?X00Co[l;Xojfdg_l05:?oAd^c
0om^HK82ohmd/0?oZ8:/00Co^8fYolNO[oo7WjoodjN[0_oY`Zh01?okiZOoVX_2oiZ;`_nJRl83oij:
_P;oXhbl00?oYhnlojJ6/_n[Rk@00on[Rk@2ojnA]`?o]YBe00Co^9blokfL]_nmW;Ko_ZBo0_o5Yk/0
0oo3[/Kob[?4olZca003olZod004o`000?o3aM_o`lGKolG:gP;o^LGS0_nianD00ona`^Ko/<;Wojfo
j002ojfoj0?oZkkX0_nZ_^P5ojVmj003o`000?oooooooooo00kooooo0009ooooo`0400000?oooooo
ooooooooo`80C4a<00X0000006IVIP1VIVH0000007moO`000000VIVIo`00002c/k?o00000P3<c<`0
1?l00000i^KV0>KVi_l000070?ooo`07o`00003Vi^H0i^KV0>KVi_l00000c<c<o`0000020;>c/`03
o`00002IVIT000000080Ogmo00@0000006IVIP1VIVH000002`1<C4`01@000000IVIV06IVIP1VIVKo
000000<0Ogmo1?l0000409VIV@Co00000P1oOgl01Ol00000IVIV06IVIP1VIVKo000000<0C4a<00<0
000003<c<`0c<c<02@0c<c<01@000000C4a<04a<C01<C4co00000080IVIV00Go000007moO`1oOgl0
Ogmoo`00000609VIV@;o0000102IVIT2o`000080Ogmo0_l0000206IVIP04o`00001<C4`0C4a<o`00
00<0<c<c00<0000001TI6@0I6AT00`0I6ATP000000Cooooo00<00000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`;o00001Oooool01Ol029Wo43:`ocm9]?m4DkgoJ6Jm00;oQWRl0onNRK`2
ok6I_PCo`Z2f00?oaj2`olnZ/oo?Z[<00_oD[K02ombg/`?ogk^c00?ohKbcomVj^ooE][/00_oE][/0
0oo?[k[o^jS6ok^XaP03oh:<e003oaA:a_lH>[KoDe>d00;oJE^_0on3J:`2oiQeZ@?oZ7nX0_ncQjL4
olBHZP?oe:b`0_oVa;@00ooghk?okOBQojcMn002ojk2j0;o[l?X00Ko/<?Xojjafon^/M_o[KCNojfX
d_l4;k43ofiQ/P;oSgB`0_nXPZ`01?ncTkOoain_olNO[oo7Wjl2onW2[P03oo_VYonHS/OoV8k700?o
VX_20_nNR[h00onSS;coX8:bojJ6/P02ojJ6/P?oZh^d00?o[i6gok6=/?nfU;D00_nfU;D3okfL]P?o
aJNk0oo:/l@01OoB_<Cob[o@om37dOo@am7o000000;oaL[N00CoaLkQokW7iOnianGo^<SV0on``^L0
1On]_nSo[;oXojboj?n[_^SoZ[kX00?oZ[gX00GoZKgXooooooooooooooooo`00000@ooooo`002Ooo
ool01000003oooooooooooooool204a<C00:0000001VIVH0IVIV0000001oOgl0000009VIVOl00000
/k>co`000080c<c<00Co00000>KViP3Vi^Ko00001`3oool01ol00000i^KV0>KViP3Vi^Ko00000<c<
c?l000000P2c/k<00ol00000VIVI0000000207moO`040000001VIVH0IVIV000000/0C4a<00<00000
06IVIP1VIVH00P1VIVH2o`0000D0Ogmo1?l0000507moO`04o`00001VIVH0IVIV06IVIP8000000`1<
C4`00`000000<c<c03<c<`0903<c<`050000001<C4`0C4a<04a<C?l000000`1VIVH00ol00000Ogmo
07moO`03o`0000T0VIVI00Go000007moO`1oOgl0Ogmoo`00000406IVIP04o`00001<C4`0C4a<0000
00<0<c<c00<0000001TI6@0I6AT00`0I6ATP000000Cooooo00<00000ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`?o00002?ooool00ol0097o?dVdocm9]002ofQV_@;oQWRl0_nNRK`00ona
VKko]I>dokFC]002ol:P]P;oaj2`00KocjZcomB]/?oD[K3oe:f`om^c[ooL]k<2omnk/`;ohKbc00?o
g[VcomFf^ooE][/00_o?[kX00onkZ<Ko]j?5okNSa@03oh:<e003oaA:a_mCDkCoDe>d00;oJE^_0_n3
J:`2oiQeZ@?oZ7nX0_ncQjL01_nlTJWoa9RZolBHZ_o4V:[odjV]omB//0;oi/Bd0_oghk<2ojc1j@03
ojk2j?n/[=So[JoI00;o[JoI00Go[[7KojfScOn]Z=;o[JSBo`00LP03odmK_`;oSgB`00?oZ8:/ok>C
]oncTkL00oo7Wjl00ooQ`[WojL:^oo_VY`03oiR>a`;oVX_200CoWXZnoiYo]?nPP[;oX8:b0onVQ[83
oj^;]0?o/Hf`0_nfU;D01?njU:oo_IbfokfL]_o4Wk82olFW^`09olf]^Oo:/lCod[c4om:la?oKalGo
d<OAomC@eOl0003oaL[N00;oaLkQ00?o`m7TokS8i_neanP00on_`^P2ojboj0;oZkoX0_nZ_^P00onZ
_NSoooooooooo`03ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooo
o`80C4a<00X0000006IVIP1VIVH0000007moO`000000VIVIo`00002c/k?o00000P3<c<`01?l00000
i^KV0>KVi_l000080?ooo`06o`00003Vi^H0i^KVo`00003<c<co00000P2c/k<00ol00000VIVI0000
000207moO`040000001VIVH0IVIV000000`0C4a<0P00000406IVIP03o`00001oOgl0Ogmo00X0Ogmo
00Go000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0<c<c00/0<c<c00<0000004a<C01<
C4`00_l0000306IVIP03o`00001oOgl0Ogmo0080Ogmo1?l0000209VIV@?o00000`1oOgl00ol00000
IVIV06IVIP0206IVIP04o`00001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT0100I6ATP0000
00Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`?o00002oooool00ol0
097o43:`ocm9]002ofaR]@;oQWRl00?oWXVlojB6/oneTk@00oneTk@00oo2X;Koaj2`olNP/003omB]
/0;ofk>_0_oQ^Jl00ooO^k?ohKbcon6l/`02omji/`04omFf^oo?[k[ocjnjol^X]`?o]j?50_n2S=@0
0olDB/Ko63Zfoe=C]002ofUK[`;oPfR/0_nHMJT3ojQoZ003ok>7YonlTJWo_96Y00;oa9RZ0_oCZJd2
onK4]0;omn>c00?okOBQojc1jOnZZmP00on/[=P00on][mWoZik:ojfSc@02ojfSc@03ojfXd_n^WLKo
001b00;oCe^o0_n=O[h4ok>C]`05olNO[ooQ`[WohL:ioo?d/on>QLD00on@P;h2oiAn^0;oVWnd0onP
P[83ojJ6/P03oj^;]?n/Qjgo/Hf`00;o/Hf`00Co]YBeokZD[onjU:oo_Ibf0_o4Wk800oo5Yk_ocJfi
olf]^@03om:la006om_7aOoSe<Soe=3EomKHf_l0003oaLkQ0_o3dN@3okG7j003ojo2j?n^`^So[/;X
00;oZkoX2_ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool204a<
C0030000001VIVH000000080Ogmo00L0000009VIVOl00000/k>co`00003<c<co00000080i^KV00?o
00000?ooo`3oool01`3oool02Ol00000i^KV0>KViP3Vi^Ko00000<c<c?l00000/k>co`00000209VI
V@030000001oOgl000000080IVIV00<0000004a<C01<C4`0301<C4`00`000000IVIV06IVIP0206IV
IP?o00001P1oOgl3o`0000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0<03<c
<`03o`00001<C4`0C4a<0080C4a<00Go000006IVIP1VIVH0IVIVo`00000707moO`;o00001@1oOgl0
0ol00000IVIV06IVIP0206IVIP05o`00001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI
6@0301TI6B4000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0
000?ooooo`04o`00TOloBKCoK6:eofaR]@;oSGJd0_nTQ[<4okFC]0?oaj2`00?ocZF_omB]/?oD[K00
0_oK/jl2on6i[`;ohKbc0ooN^K<3oln_^P;objRg00Oo]j?5okRS`omoT=[oOi3Jo`0a^OlDB/Ko7cJ_
00;oJE^_0on3J:`2oiQeZ@;oZ7nX1?nlTJT01Oo4V:[odjV]om>Y[OoXa;7oi/Bd00;omn>c00KoZJ_I
ojZ[f?nZZmSoZZ_Hojb/f?nYVlP3oj^NbP03ojfScOn]Ul3o[Yg600;o[Yg600Co001bodmK_on=O[ko
SGjn1?ncTkL01?o7WjoohL:ion72^Oocm;<2ohj5a@;oT82n0_nDO[P3oiYo]0;oX8:b0_nVQ[801?nV
PJco[8N]ojb7[On/Qjd2ok6=/0?o^YB_0oo4Wk83olf]^@0:omRg^?oB_<CoflO5om_7aOoSe<Soin7=
omKHf_oCgMoo0000ol?Ai0;o_m7W00Co]LOXok;6jOnba^Wo[/;X3Oooool00ol0003oooooooooo`0=
ooooo`002Oooool01000003oooooooooooooool204a<C0050000001VIVH0000007moO`0000000P2I
VIT01Ol00000/k>co`00003<c<co00000080i^KV00?o00000?ooo`3oool0203oool02?l00000i^KV
0>KVi_l00000c<c<o`00002c/k?o00000P2IVIT00`000000Ogmo0000000206IVIP030000001<C4`0
C4a<00d0C4a<00<00000o`0000000000101VIVH6o`0000@0IVIV0P00000404a<C0030000000c<c<0
<c<c00h0<c<c00<0000004a<C01<C4`00P1<C4`01?l00000IVIV06IVIP1VIVH4o`0000T0Ogmo0_l0
000206IVIP;o00000`1<C4`01@000000<c<c03<c<`0c<c<0000000H06ATI8@000004ooooo`030000
0?oooooooooo013ooooo00?o0000ooooooooool02Oooool3o`0001;ooooo00Co001JobPi[_loBKCo
K6:e0_n=M[@3ojB6/`;o]I>d0_nkUK001_o7X;3ocZF_oljU[oo>YJooe:f`om^c[`?ohKV_00?oi;f`
on6l/ooN^K<00_oN^K<00ooH/[;ocjnjol^X]`02ol^X]`?o^:?30_moT=X01Ol0<KWo00NJodY</Om:
C;7oJE^_00;oPfR/0_nHMJT2ojQoZ0Co_96Y0_oCZJd2onS4/@;onNJ]00GogNb7ojV[fOnYZmWoZZ_H
ojJIb003ojVKb003oj^Nb_nZTKco[IO000;o[IO00_n^WLH00on_U;_o03c0odmK_`02ohen_P;o/i>g
00Gob[k?on72^OoQ`[WoloBcohAoaP03ohj5a@;oT82n0_nDO[P2oiYo]0;oX8:b00?oYXJbojJ1[?nV
PJ`00on/Qjd2ok6=/0?o^YB_0oo4Wk801_o>Y[3ocJfiomRg^?oH]kSohlFiom_7a@;ohmC800Koin7=
onG[dooCgMoo0000olkOiOnodNL2ok[?j@03ok;6jOoooooooooo00gooooo00?o0000ooooooooool0
3Oooool000Wooooo00@00000oooooooooooooooo0P1<C4`01@000000IVIV0000001oOgl000000080
VIVI00Go00000;>c/ol00000c<c<o`0000020>KViP03o`00003oool0oooo00P0oooo00So00000>KV
iP3Vi^Ko00000<c<c?l00000/k>co`000080VIVI00<0000007moO`0000000P1VIVH00`000000C4a<
04a<C00304a<C0H000001`1<C4`00`000000IVIV06IVIP0:06IVIP030000001<C4`0C4a<0080C4a<
00<00000o`00000c<c<01P0c<c<5000000H0<c<c00<0000004a<C01<C4`00P1<C4`2o`0000D0IVIV
0ol0000207moO`Co00000P1VIVH2o`0000<0C4a<00<00000o`00000c<c<00`0c<c<00`0000006ATI
01TI6@0401TI6B4000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo
0ol0000Eooooo`03o`00F_lX>Jko:3V^00;oK6:e0_n=M[@2ojB6/`05okFC]?nkUK3o^iF`ok^E/?o7
X;000oo>YJl2om^c[`;ohKV_0_oT_K03omji/`;of;:b0oo;Z;L2olVU]0;o^:?300Go`:W2ohbQh_n<
XN;o00NJoalf[`02odY</@;oPfR/0_nHMJT00onXOjSo[hR[ojn8Z`03okbAZ@04olbS[_oCZJgoj<Ba
onS4/@;onNJ]00?oYI_<ojFIbOnUVLT00onVVLP00onYVlSoYXfjojZA_002ojZA_0;o[IO000Go[Yg6
ojnD^on_U;_o[iBko`0l`002ohen_P07ok>C]oo:_/oob[k?olZncooQ`[WoloBcohAoaP03oh9g_P;o
QWBg0_nDO[P2oiYo]003oj22/_nOO:coYX6/00?oYX6/0_n/Qjd01?naSK3o]Xf[okJ=ZonjU:l2ol6H
[003olBO/_o>Y[3ocZJ`00?of;Nh00?ohlFionkF^_oSe<P00_oWhLd01_oUjm?ogo3KolkOiOl0003o
a]cYok[?jA7ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo0P1<
C4`02P000000IVIV06IVIP000000Ogmo0000002IVIWo00000;>c/ol000020<c<c004o`00003Vi^H0
i^KVo`0000P0oooo00Co00000>KViP3Vi^Ko00000P3<c<`01Ol00000/k>co`00002IVIT000000080
Ogmo00@0000006IVIP1VIVH00000101<C4`00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<
00D0C4a<0`00000306IVIPH000000`1<C4`2000000H0<c<c0`00000501TI6@<00000100c<c<20000
00@0C4a<00?o000006IVIP1VIVH01@1VIVH2o`0000@0IVIV0_l0000404a<C0030000000c<c<0<c<c
00<0<c<c00<0000001TI6@0I6AT0100I6ATR000000Cooooo00<00000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`?o00006Oooool01?l005[o:3V^ofMN]?mWG[@2ohef]003ojB6/on[RK7o
^iF`00?o^iF`1?o>YJl01?oG[Zoofk>_on6i[ooQ^Jl2onBm/003on:k/?oN^K?of;:b00;of;:b00?o
dZV_ol^X]oo9YK@00_o9YK@00onhXl?o`:W2ol2Y`P03ojJmjP03o`07V_m:C;7oBTba00;oN6Ja0_nJ
NZh3ojn8Z`;o_96Y0_o<Xjh01OoCZJgoj<BaooWV[OoiiZgogNb700;oYI_<0_nUVLT01?nVVLSoXhZj
ojJ=^_nVSKX3ojZA_003ojfG`?n]S[Go[iBk00?o[iBk00Co[Y[3ognQjOmoXNWoOj7Y0oo:_/l01?nh
nlOoSh_;ohAoa_n4OlH2oh9g_P;oQWBg0_n>MK82oiMh[P?oWgb/0onVPJ`2ojb7[@?o]Xf[00Co^YB_
ol6H[?o1V:coa9nb0_o>Y[002?oJ/K3of;Nhon?5^OoSaKWok]JjooCX^ooWhLgoiN_C0_oOl=/00ooE
knGoa]cYo`00000Booooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooo
o`80C4a<00X0000006IVIP1VIVH0000007moOol00000VIVIo`00002c/k?o00000P3<c<`01?l00000
i^KV0>KVi_l000080?ooo`04o`00003Vi^H0i^KVo`000080c<c<00Go00000;>c/ol00000VIVI0000
000207moO`040000001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<01P0c<c<4000000H0C4a<
0`00000704a<C08000001P0c<c<2000000/06ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<
04a<C00204a<C0Co0000201VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c
00?o000001TI6@0I6AT0100I6AT00ol0000000000000000P000000Cooooo00<00000ooooooooool0
3oooool01?l0003oooooooooooooool3o`0001gooooo00?o:3V^ofMN]?mWG[@00_nAN;<3oj^9/@?o
^iF`00?oa9f`oljU[oo>YJl00_oG[Zl2on6i[`;oi;f`0_oR^k000ooL/joof;:bomRb/P02om:Y[`Co
bJFd0oo0ZL801_o=]<;oY[gZolCIjOo4fNWo002BodY</@;oN6Ja0_nJNZh3ojn8Z`04okbAZOo<Xjko
c:>^olbS[P;oj<Ba00?onNJ]ojC>G_nXX<h00_nUVl`01?nUVLWoX8Vloj>:^_nSR[X3ojJ=^P;oZY6l
0on]S[D3ojnD^`;o/IFj0omoXNT01?o:_/oo^?_7ohB1aon4PLL2ogAb`P?oPWNn00?oQWBgohie/_n>
MK800_nGN:h3oiml[0?oYX6/00?o[8N]ok26ZOnfSJ/00_nfSJ/3ol6H[0;ocZJ`0_oJ/K02on?5^@;o
k]Jj00Gom>Rkoo7e_?oWo<;ogo3KomG_i@03ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03Oooool000Wooooo00@00000oooooooooooooooo0P1<C4`02P000000IVIV06IVIP000000
Ogmo0000002IVIWo00000;>c/ol000020<c<c003o`00003Vi^H0i^KV00;o00001P3oool01Ol00000
i^KV0>KViP3Vi^Ko00000080c<c<00Go00000;>c/ol00000VIVI0000000207moO`040000001VIVH0
IVIV000000<0C4a<00<0000003<c<`0c<c<02P0c<c<3000000`0C4a<00<0000003<c<`0c<c<01@0c
<c<00`00003o000001TI6@0<01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`01@1<
C4`8o`0000D0C4a<00<00000o`00000c<c<00`0c<c<00`0000006ATI01TI6@0501TI6B<000001?oo
ool00`00003oooooooooo`0?ooooo`Co00008?ooool2obPi[P03ofMN]?nAN;?oTGRc00?oZhVa0_nk
UK02olBM/006oljU[ooG[Zooejj_omN^[ooO^;3ohKV_0_oT_K02on:k/0;og;>_00Cof;:bom:Y[ooB
ZJoocZB]0_o9YK@2olfV/P03ol2Y`_o=]<;ocKC200;og<?100Goa=WYo`00T_l0:JooBTbaogQV/@03
oiYj[P;o[hR[1?o<Xjh01OoUa;Koj<BaojC>G_nXX<koX93300;oWX^o0_nPRK`3oj>:^P;oYXfj00?o
ZY6lojZ8/On]S[D00on]S[D00on_U;_o/Xncok:?/`02ok6E^P?o[IBn0_nKSlH2ohB1a`04ogAb`_mc
J[[oLfZjog=Z^P;oQWBg0_n>MK82oiMh[P;oWgb/0onVPJ`3ok26Z@;o]Xf[0oo1V:`01oo;Wj_ocZJ`
omZa/?oJ/K3oj<:_on?5^Oo^e[X00_odj;/00ooamKcoioc2omcnd004ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03Oooool000Wooooo00L00000ooooooooooooooooo`00001<C4`0
00000080IVIV00D0000007moO`000000VIVIo`0000020;>c/`03o`00003<c<co000000@0i^KV00?o
00000?ooo`3oool00ol000030>KViP04o`00003<c<`0c<c<o`000080/k>c00?o000009VIV@000000
0P1oOgl00`000000IVIV0000000304a<C0030000000c<c<0<c<c00h0<c<c0`00000304a<C0H00000
1`0c<c<00`0000006ATI01TI6@0>01TI6@030000000c<c<0<c<c00<0<c<c0`00000?04a<C0800000
1@0c<c<00`0000006ATI01TI6@0501TI6B@000001?ooool00`00003oooooooooo`0?ooooo`;o0000
8oooool00olX>JkoIejdofMN]002oi5h/`?oZhVa00?o^iF`olBM/?o4WK000ooG[Zl2omnh/0;oiKna
00?oi;f`on:k/?oL/jl00_oL/jl2om:Y[`;ocZB]00CobJFdolfV/_o=Y[;ocJJb0oo=]<82omc3`@04
onWD_oobhkco002Bo`0Y[`;oN6Ja0_nJNZh2ojn8Z`03okjK]?o<Xjkoc:>^00;oiLBf00?om_6_ojJG
a_nPT<<00_nPT<<2oij;_`;oX8Vl0_nSR[X00onVSK[oYH>`ojZ8/@02ojZ8/@;o[Hje00Go[hV]ok:?
/onbSk?o/Xncok6E^P02okBC]0;o[IBn00CoVho6oiV=aOmgN<OoMgS70_mdL/82og=Z^P;oNfVc0_n>
MK82oiMh[P?oWgb/00?oYX6/ojR0Z?n`QZT00_n`QZT01?nfSJ_o_92Yokb@ZOo1V:`2ol^OZ`0:oljV
/?oJ/K3of[6`onS2[oofejgok]JjooCX^ooamKcoioc2omcnd0Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`002Oooool01@00003ooooooooooooooooo00000080C4a<00<0
000006IVIP0000000P1oOgl01@000000VIVIo`00002c/k?o00000080c<c<00?o00000>KViP3Vi^H0
0P3Vi^H2o`0000H0i^KV00So00000<c<c03<c<co00000;>c/ol00000VIVI00000080Ogmo00@00000
06IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`0A03<c<`<000002`0c<c<2000001806ATI00<0
000003<c<`0c<c<01@0c<c<3000000X0C4a<0P00000603<c<`030000000I6AT06ATI00D06ATI9@00
0004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool08?ooool00ol06jCoIejdofMN
]002oi5h/`;oZhVa00Go/i6colBM/?o4WK3oa9f`olnY/P02omN^[`;ogkR`0_oU_k42on:k/0?og;>_
00Coe:V/om:Y[oo>Y:gocZB]1?o=Y[801?oD[[7ocKC2omc3`OoL`l42onWD_`05oo;S_?oek[So02V_
oemV`_mhI[400_nJNZh00on_R:_o_Y^dokjK]002olbS[P;oiLBf0onVUlH2oj2@``;oWX^o0_nPRK`0
1?nSR[[oX7n`ojF3/?nUPk03ojZ8/@03ojf>]On_RJgo[hV]00?o/Xnc0ondTk@00on]U;ko/9JkoiV=
a@02oiV=a@03ogMhaomNHkooGV>o00;oLfZj0_mkJK<2ohM][P;oUgR^0_nOO:`01?nONJWoZ82XojR0
Z?nXP:P2ok26Z@?o_92Y00Go`IR/ol^OZoo;Wj_of:b[omZa/002onS2[`04ooKG[OojjZGojo2Folo]
R`Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`002Oooool01@00003o
oooooooooooooooo00000080C4a<00<0000006IVIP0000000P1oOgl00`000000VIVIo`0000020;>c
/`04o`00003<c<co0000o`0000T0i^KV0_l000020<c<c006o`00002c/k<0/k>co`00002IVIT00000
0P1oOgl00`000000IVIV0000000304a<C0030000000c<c<0<c<c00@0<c<c1`00000A03<c<`040000
0?l000000000000001D06ATI0P00000803<c<`03o`0000000000000000L000001P0c<c<00`00003o
000001TI6@0601TI6BH000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo023o
oooo0_mHF[X2oi5h/`05oj^9/OncTK?o/i6cok>A/oo4WK000oo?ZK800ooG[ZoogkR`onFo/@02onFo
/@04on>n/OoR^k3og;>_ombc[`;oe:V/00CodZV_oljT[Oo>Y:god:B[0_o=Y[82omB^/@08on2j/OoL
`l7ojMBoonWD_oobhkcomNjhooCaX_l0:Jl2oemV`P03oiYj[_nOR[go_Y^d00?o_Y^d00Coc:>^onG4
]_oflJoo[ik60_nVUlH01?nPT<?oV86ioiQm]OnHOKD2oi]m/@;oX7n`0onUPk02ojZ8/@Co[hV]0_nb
Sk<3okBC]0?o/9Jk0_nISLD2ogMha`;oGV>o0_mcJ[X00omkJK?oQff^ohM][P02oiAcZ`?oWgVY0onX
P:P2ok26Z@?o_92Y0oo;Wj/2omR/Z`06onS2[oofejgom]N]oo[ZYOo[l9Kocnf;2_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0009ooooo`0500000?ooooooooooooooool0
00000P1<C4`00ol00000IVIV0000000207moO`030000002IVIWo000000<0/k>c00?o00000<c<c03<
c<`00ol000050>KViP05o`00003<c<`0c<c<0<c<c?l000000`2c/k<00ol00000VIVI0000000207mo
O`030000001VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<2000000L06ATI1000000903<c
<`@000006`0I6AT2000001@0<c<c0P00000801TI6BL000001?ooool00`00003oooooooooo`0Coooo
o`03o`000?oooooooooo01oooooo0_mHF[X2oiAn^@Co/i6c00Coa9f`olnY/_o?ZK;ocjVb0_oO^;02
onFo/@;ohkja0_oL/jl3omBY[0;ocZB]0oo@Y:/01?o=Y[;oe:jaomB^/OoP^[42ong:/007onWD_oob
hkcom?6RooCaX_o]mJKo02V_oemV`P03oin:_@;o_Y^d0_oIa/L00ooUa;Ko[ik6ojNB_`02oif9_@;o
V86i0_nHOKD2oi]m/@?oX7n`0_nUPk000onZR;7oZhBZoj^4ZP03ojn9[@03ok:?/onfSjgo]Xn]00;o
]9>d00?o^iJaok2F^on`U[/00_nGSlT2of9_bP;oGV>o00?oG5^gog=Z^_mkJK<00on7KJh2oiAcZ`;o
WgVY0onXP:P00on`QZWo]HVWokF9Y`02okb@Z@03olJHZ?o;Wj_obin[00;of:b[00Goj<:_ooKG[Ooj
jZGojo2Folo]R`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wo
oooo00P00000oooooooooooooooo03<c<ol00000C4a<00000080IVIV00H0000007moO`1oOgl00000
09VIVOl000030;>c/`03o`00003<c<`0c<c<0080c<c<1Ol000030<c<c007o`00002c/k<0/k>c0;>c
/ol00000VIVIo`00000207moO`030000001VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<0
0`0000006ATI01TI6@0;01TI6@T000003P0I6AT8000000/06ATI0`00000?03<c<`8000002@0I6ATX
000000Cooooo00<00000ooooooooool05?ooool2o`00023ooooo00CoF5ZjoiAn^OnDO[WoU7ji0onc
TK<4olnY/P03om^h]_oO^;3oiKna00?ohkja00?og;F`ombc[ooDZJ`00_oDZJ`00oo?XZ[ocZB]om2T
Z`02om2TZ`;oe:ja0_oP^[42ong:/006ooOK[_ojjJSom?6RongeY_o^mLKog]7;0_mOI/82oin:_@05
okjK]?oIa/OofLK7omW6aooCo;H00onWT[l2oif9_@;oV86i0_nHOKD2oi]m/@;oX7n`00?oYH>`ojEn
ZOn[Q:X00_n[Q:X3ojn9[@?o]Xn]00Co]9>dok^F/OnkU[7o/9Jk0_ngVk`2oiN?b@03of9_b_lhCkko
GV>o00;oG5^g0_mkJK<2ohM][P;oU7>[0onONJT2ojR0Z0?o]HVW00Co_92YolJHZ?o6V:SoaYRX0ooH
[:/01?ojfJCom]N]oo[ZYOl0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool000Wooooo00H00000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIV0000
0080Ogmo00@0000009VIVOl0003o00000P2c/k<00ol00000c<c<0<c<c0070<c<c0;o00000P2c/k<2
o`00000509VIV@000000Ogmo07moO`0000000P1VIVH010000000C4a<04a<C000000403<c<`03o`00
000I6AT06ATI02006ATI2`0000000ol0000000000000000;01TI6@04o`00000000000000000000P0
<c<c00<00000o`00000000002@0I6ATZ000000Cooooo00<00000ooooooooool05_ooool00ol0003o
ooooooooo`0Mooooo`;oF5Zj0_nDO[T3ok>A/`03oknQ^_o?ZK;ocjVb00;ofkRf00Coh/>honFo/OoS
_[7ohkja0_oL]K03omBY[0;ocj:Z00OocZB]om2TZoo@Y:_od:B[omJYZ_oD[[7oh;Za00?okLZ`00Wo
mm^^ooCaX_oHjXCoh?FNonkea_oNdL_obk2oo`1Ac?nOR[d00_nX_^T3omW6a`;o/iVm0_nWT[l2oif9
_@;oV86i0_nHOKD2oi]m/@03oj1o/?nNNJWoYGjY00;oYGjY0on[Q:X00on_RJgo/hVXokJ?[@02okJ?
[@?o^iJa0ongVk`2oiN?b@;oHVo:00Go>4nnoeiS_omLFkOoJejbog]Y/`02ohM][P;oU7>[0onONJT2
ojR0Z0?o]HVW00Co_92YolJHZ?o6V:SoaYRX0_oH[:/01OoY_j[on]VTooKXSOo7eV7o000000kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`002Oooool01P00003ooooooooo
ooooool0<c<co`000080C4a<00@0000006IVIP1VIVH000000P1oOgl01?l00000VIVI09VIV@2IVIT2
o`0000040;>c/ol0003o0000o`0000D0c<c<00Go00000;>c/`2c/k<0/k>co`00000309VIV@040000
001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`00000100c<c<00`0000006ATI01TI6@0O01TI
6A0000003P0I6AT8000000/06ATI:`000004ooooo`0300000?oooooooooo01Oooooo00?o0000oooo
ooooool07Oooool01Ol`D/GoU7jioiAn^OnDO[Wo/i6c00;o_j6j00KocjVbom^h]_oK^;KofkRfon;3
^?oRa;T2on>n/@;og;F`00?odZR]omBY[?oDZJ`00_o?XZX3om2TZ`;oeZVZ00Koe:jaon2j/Oo]b[3o
kLZ`ooOK[_ojjJP2omSZQ003onkea_oNdL_og]7;00;obk2o1?nX_^T01_oIa/Oo^ibiok>I_OncVKgo
Yi:ooin8^`;oTWbh0_n>M;82oi5c[P;oUgF[0_nNNJT3ojEnZ@?oZhBZ0oncRJP2okJ?[@04okbAZ_nk
U[7o^iJaol>L/0;o]i^l0_nDUm<3oc]Sd004ocQ?__mLFkOoJejbof]N/P?oQff^0_nDLj/2oimiZ@03
ojR0Z?n/PZOo]HVW00;o]HVW1?o6V:P01_oDYZSof:b[onVoZ_ojfJCom^R=o`00013ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool2
03<c<`04o`00001<C4`0C4a<00000080IVIV00@0000007moO`1oOgl00000102IVIT01?l00000/k>c
0;>c/`2c/k<5o`0000<0/k>c00Go000009VIV@2IVIT0VIVI0000000207moO`040000001VIVH0IVIV
00000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0M01TI6AD000007P0I6AT/
000000Cooooo00<00000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`04olQC0?nIS/Ko
VHk6oiV>aP?o_j6j0ooK^;H2on;3^0;oh/Bi00?ohkjaombe/?oBZ:d00_oBZ:d00ooDZJcocj:ZolnR
ZP03om2TZ`;oeZVZ00?oh;F[on2j/Oo]b[000_ogfjh01OojjJSof>Z4onGl^ooPelkog]7;00?obk2o
00?o`J:iojRnjOnX_^T00onkW;T01?ncVKgo[i>join8^onOR;/2oi9l^0;oSWBb0_nALjh2oiMeZ`;o
WWVY0onUOZT3oj^4ZP?o/hVX00Co]Xn]okbAZ_nlTJ[o^iJa0_o3W;000ongVkco`:S1ol2X`@02oiBG
d`;o>f?@00Co>4nnocE5]OmLFkOoJejb0omnIjh2oiAcZ`03oimiZOnPNZSo[8:W00;o[8:W0_neRJL0
0onnTJOoaYRXolJHZ002omBVZ004omR/ZooY_j[on]VTolOFHA7ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooool203<c<`04o`00001<
C4`0C4a<000000<0IVIV00@0000007moO`1oOgl00000102IVIT00ol00000/k>c0;>c/`060;>c/`;o
00000`2IVIT01?l00000Ogmo07moOol0000306IVIP040000001<C4`0C4a<000000@0<c<c00<00000
01TI6@0I6AT06P0I6ATI000001/06ATI;P000004ooooo`0300000?oooooooooo01Wooooo0_l0000M
ooooo`04o`0b]onIS/KoVHk6oiV>aP;o_j6j00CocKK4om^h]_oR`kSoh/>h0ooRa;T2ombe/0?odZR]
0_o?XZX2olnQZ007om2TZooFZJ[oeZVZomJYZ_oP]J_ok/J[ong:/002ooOK[P;of>Z400?oiObkon3G
c_o9[[l00oo;/;l01?o1W[Ko`J:iol6R^OnnVk@2ok^L^@?o[i>j0_nOR;/2oi9l^003ohid/_nALjko
TG>^00;oUgF[0onNNJT3ojEnZ@03oj^4Z_n^PjKo/hVX00;o/hVX0onlTJX3ol>L/0?o`:S10on>ZNP0
1Ol0A/Oo>f?@ocQ?__leAKGoJejb00?oOVN^0_nALJ/2oj1jZ0?o[8:W00?o]HVWokjAYonnTJL00_o6
V:P2omBVZ004onVoZ_ojfJCom^R=o`000a;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`002Oooool01000003oooooooooooooool303<c<`05o`00001<C4`0C4a<00000?l0
00000P1VIVH20000000407moO`00003o000000000080VIVI2?l0000309VIV@8000000P1oOgl01@00
0000IVIV06IVIP1VIVH000000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@09
01TI6@P000000`0I6AT500000003o`0000000000000001P0000000Co000000000000000000005P0I
6AT_000000Cooooo00<00000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`04o`0b]onI
S/KoVHk6oknQ^P;ocKK40_oHbld00ooR`kSoh/Bion;4^@02omVh^006ombe/?oBZ:godZR]om:X[Oo<
Wj[ocj:Z0_o?XJP00oo@Y:_oeZVZomJYZP02on2eZ`07onk6ZoojfjOon]^Woo[ZV_oHjXCoiObkon3G
cP03olV^_`04ol^`_oo1W[Ko`Ijfol6R^@;o_Y^d00?o^ibiokZI]_njVKH00_n_TkX2oin8^`;oTWbh
0_n>M;82oi5c[P;oUgF[0_nNNJT2ojEnZ@04ojMlYOn^PjKo[X>Vojj3YP;o/hVX0onlTJX3ol>L/005
olnX/Oo0Z<7oc[g:oljmb_n>ZNP00_m``_h00on1003o02ZbocE5]@02of]N/P;oOVN^0_nALJ/2oj1j
Z0?o[8:W00?o]HVWokjAYonnTJL00_o6V:P2omBVZ003onRmZOojfJCom^R=01Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`002Oooool01@00003ooooooooooooooooo0000
0080<c<c00Go000004a<C01<C4`0C4a<0000000406IVIP050000001oOgl0Ogmo07moO`0000002@2I
VIT3000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0050000000c<c<0<c<c03<c<`00
00002@0I6ATe000001006ATI0P0000000ol0000000000000000]000000Cooooo00<00000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`;oVjWP0oo=]/@2omS;c@03omS>d?oRa;WofKRh00;o
fKRh0ooBZ:d2olbOZP04olnRZ_o?XJSocj6XomBVZ0;oeZVZ00?oh;F[onk6Zoo^aZ/00_ojfjL00ooX
jhSo^o:RomgNeP03olV^_`04okfJ]?o1W[Ko`Ijfol6N]P?o_Y^d0onjVKH01?n_Tk[oZY2joiAo^_nD
OkX2ohA`]0;oSWBb0_nALjh2oiMeZ`;oWWVY00?oYGjYojMlYOnWO:D00on^PjH01?ncRJSo^XbVokZ<
Y_nlTJX2olJIZ@03ol>L/?o?Z;7ocjRa00?oc[g:00SogMoGomSne_nRkjooooooo`0Z/_leAKGoCTnb
of]N/P;oOVN^0_nALJ/3oj1jZ0;o[8:W1?nnTJL2omBVZ0;oj;fY00?oo=bPooooooooool05?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0500000?oooooooooo
ooooool000000`0c<c<01Ol00000C4a<04a<C01<C4`0000000@0IVIV00@0000007moO`1oOgl0Ogmo
0`00000509VIV@030000001oOgl0Ogmo0080Ogmo0P00000306IVIP050000001<C4`0C4a<04a<C000
00000`0c<c<00`0000006ATI01TI6@0501TI6C/000002P0I6ATe000000Cooooo00<00000oooooooo
ool07Oooool00ol0003oooooooooo`0Kooooo`;oVjWP00KocKK4omS;cOoHblgof<_=omS>d?o=_L/3
omVh^003olfW/ooBZ:goc9nZ00;oc9nZ0oo?XJP2omBVZ003omJYZ_oP]J_ok/J[00;on]^W00?on^ZJ
o`000?oMg]H00_o4Zl401?o9[[oo_IZdokfJ]?nmV[@2ol6N]P04okjG/?nnVkCo_Y^doknI/@;o^YVf
0_nZT;X2oiAo^P;oQ72d0_n2JJh2oi5c[P;oUgF[00?oWWVYoiifYOnWO:D00_nWO:D3ojj3YP04ok>9
Z?njS:Ko^XbVokbAZP;oaYVY00So`ib`olnX/Oo?Z;7oh;bdoljmb_oMgmOof?kFoj;_[`?ooooo00?o
02ZbocE5]Om>Ck800omnIjh2oi5aZ`;oX7ZX0_n/PZL01?ncRJSo_Y6WokjAYonnTJL2omBVZ0;oj;fY
00?oo=bPooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo
0009ooooo`0600000?ooooooooooooooo`0I6AWo00000`0c<c<01Ol00000C4a<04a<C01<C4`00000
00@0IVIV0P00000407moO`D000000`1oOgl2000000@0IVIV00D0000004a<C01<C4`0C4a<00000003
03<c<`030000000I6AT06ATI00D06ATIN`000004ooooo`0300000?oooooooooo01kooooo0_l0000M
ooooo`;oTLOj00?of<_=omS>d?oHc]000_o=_L/01?oI^;SocJNcolfW/ooBZ:d3olbOZP;ocj6X0ooD
YZP2on2eZ`05onk6ZoojfjOon]^Woo[ZV_oAinH00oo4Zl44okfJ]004ol6N]_nnUk3o_YN`okjK]0;o
_iVa00?o^YVfok^J]_nkV[H00_nZT;X2oiAo^P03ohA`]?n2JJkoPVV^00;oRFZY0_nDKjH2oiifY@Co
YgbU0_n^PjH3okZ<YP?oaYVY0_o?Z;42on2l]003oo;I]_oelZWoc>V500Gooooo00Go=DFeodi?/_m`
H;7oL62aogiW[P02oi5aZ`;oX7ZX00?o[8:Wok>9Z?ncRJP00onnTJL01?o=X:[oe:JXonRmZOolg:0H
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool000Wooooo00H00000oooo
oooooooooooo01TI6Ol0000403<c<`06o`00001<C4`0C4a<04a<C?l000000000101VIVH00`000000
Ogmo07moO`0707moO`8000001@1VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c03<c
<`0000001`0I6AUk000000Cooooo00<00000ooooooooool08?ooool00ol0003oooooooooo`0Koooo
o`;oP/[n00Cof<k@olfmboo=_L_o_JC00oo=Yk<3olbOZP;obYfY00Gocj6XomBVZ?oDYZSoe:JXomnb
Z@02onk6Z`;on]^W00CodNOVokZWa_njYlKoa:_10_nhUK<3okfJ]0?o_YN`0onoVK43ok^J]P;oZY2j
0_nDOkX2ohA`]003oh9Y[_n9JZWoRFZY00;oU6nV0onNMZD3ojMlY@;o[X>V0onjS:H3olJIZ@06om>U
ZOo?Z;7oh;bdon2l]?obfKKomO:Y1_ooool00ol06ZKoCTnbodi?/P02og1P/@;oTG6[00?oX7ZXoj=n
ZoncRJP00_ncRJP2okjAY`;ocJ2Z0_oX_JT00oolg:3oooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo0P0I6AT00ol0
0000<c<c03<c<`0203<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH30000
0080Ogmo1000000606IVIP030000001<C4`0C4a<0080C4a<00D0000003<c<`0c<c<0<c<c00000007
01TI6G`000001?ooool00`00003oooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo00CoYD@0
ohFbl_n5/_;ocKg;0onmY<02olfW/`03olBK[_o<Wj[obYfY00;obYfY00?ocj6XomBVZ?oDYZP00_oO
/ZT01?o_aj[on]^Woo[KYoojjYX3okZWaPCo^9Fc00?o_IZdokZC[_njTjh00_nnUk000onoUjgo_iVa
oknI/@03ok^J]P;oY8nn0_n3MK`00om^HK?oQ72doh9Y[P02ohUZZ@?oU6nV0_nNMZD3ojMlY@04ojj3
Y_ndQJCo]8FTokZ<YP;o`i>U00?oaYVYom>UZOoCYJT00_oP_;@00oobfKKomO:Yo`000007ooooo`04
o``_[om>Ck;oL62aog1P/@;oSG6^0onSOZ/3ok>9Z003okjAYoo=X:[ocJ2Z00;oj;fY00?oo=bPoooo
ooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`04
00000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00304a<
C0030000001VIVH0IVIV00@0IVIV0P00000806IVIP800000101<C4`00`000000<c<c03<c<`0203<c
<`030000000I6AT06ATI00@06ATIO@000004ooooo`0300000?oooooooooo02;ooooo00?o0000oooo
ooooool06_ooool00ol0::ooQHoFokfT`003okfT`004olfW/oo4Vjkoa9^^olbOZP?obYfY0ooDYZP2
omnbZ@03ono7Z_olh:?oo>2S00;oZJ3=00?o^ZO6ojn?]On_SkD00onhUK<3okZC[P04okjG/?noUjgo
_iN]oknI/@;o`ib`0_nkV[H01?nmW[WoY8nnojB?__n3MK`2ofiQ/`;oPVV^0_n9JZT2oiA_YP;oWWJU
0onWO:D3okB5Y004okZ<Y_o3TjGo`i>UolJIZ@;odjFY00CoiKZYon2l]?obfKKomO:Y2?ooool01?l0
6ZKo32n_og1P/Om`H;42ohea[P?oXgj[0oncRJP3olfPZP03onBk[Oolg:3ooooo01[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool3
01TI6@03o`00000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00`1<C4`2000000`0IVIV0P000004
04a<C003o`0000000000<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000001j
000000Cooooo00<00000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03ojE40?l0::oo
QHoF00?o_JC00oo4Vjh4olZMZ@;oe:JX0_oO/ZT2ono7ZP;oo>2S00?oZJ3=oj:7]on_SkD00_n_SkD3
okRE/`?o^Y>^0onoUjd3ol>L/003ok^J]_nmW[Wo_Iji00;oY8nn0_n3MK`00om^HK?oL5b/oh9Y[P02
ohUZZ@;oU6nV0onNMZD2ojMlY@?o]8FT00Go^XbVol>CYOo3TjGoaYVYom>UZ@02onFjZ@03ooWFYOoe
j8_ooooo00Wooooo0_l<;jl2og1P/@04ohea[_nSOZ_oXgj[oj=nZ`?o/hVX0_o=X:X2onBk[@03oocU
X_oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`002Ooo
ool01000003oooooooooooooool301TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`0
101<C4`00`000000IVIV06IVIP0706IVIP8000001P1<C4`00`000000<c<c03<c<`0303<c<`030000
000I6AT06ATI00D06ATIO@000004ooooo`0300000?oooooooooo02Cooooo0_l0000Jooooo`05o`0X
[omoN/?oOg[3okfT`?naT[L00oo4Vjh00oo0UjgobYfYolZMZ@02olnRZ@04omBVZ?oO/ZWogk:Yono7
ZP;oo>2S00?oknZ9oj:7]onRQkL01?n_SkD00onhUK?o]8f]okB=[@02okZC[P?o_iN]0oo3W;03okfN
^@;oUi3:00?oGFC1oh=e_?m^HK<00_m`G:`2ohUZZ@?oU6nV0_nNMZD00onWO:GoZgjSokB5Y002okB5
Y0?o`i>U0_oCYJT2onFjZ@03ooWFYOoej8_ooooo00[ooooo00?o32n_odiE^_m`H;400_n=LJh3oj=n
Z`04ok>9Z?o0Ujko`9N^olfPZP;oi;^]00?oo>FRooooooooool06oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooo`@06ATI00?o0000
03<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00404a<C0<000001@1VIVH00`000000C4a<04a<C005
04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AUn000000Cooooo00<00000
ooooooooool09_ooool00ol0003oooooooooo`0Gooooo`03o`0X[omoN/?oOg[300?o/I:g00?oa9^^
ol2G[Oo0Ujd00_o:WJT2olnRZ@06omBVZ?oO/ZWoklNZono7Z_olh:?oknZ90_n@O[/2oj:7]`;o[hne
00GoZhJ^okB=[OndSJgo]8f]okZC[P02okbBZ`03oknG[Oo5VjgoaI^]00;o`ib`00CobJBcokfN^Oo1
Z/?o`J[30_nGT<X01?mMI<7oKV6cofiQ/om`G:`2ogmRZ0?oU6nV00?oWWJUoimfY?n[OZ<00_n[OZ<2
okB5Y0?o`i>U00GodJ6Vom>UZOoU^ZWonMJUooGXR`0<ooooo`03o`00K?l<;jooCUFj00;oSG6^0_nS
OZ/01on[RkCo`9N^ol2G[_o0UjkocJ2ZonBk[OoliJ807_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00?o000003<c<`0c
<c<00`0c<c<00ol00000C4a<04a<C00604a<C0D000001`1<C4`00`000000<c<c03<c<`0303<c<`03
0000000I6AT06ATI00H06ATIOP000004ooooo`0300000?oooooooooo02Oooooo00?o0000oooooooo
ool05oooool00ol0::ooOg[3ogmj``02ok6B]`05olBK[_o0Ujgo`9N]ol2G[Oo:WJT00_o?XZT2omnb
Z@;oklNZ00Coo>2Sol3GI?mhJ;GoT7jk0_nRQkL00on_SkGoZhJ^oj^6[P03okB=[@?o_9:[00Co_iN]
olFK[Oo5Vjgo`ib`0_o9Y;<3ol6Z``;oUi3:00CoGFC1od17/_m^HK?oL5b/0_moHZP3oi1/Y@;oWgJT
0on[OZ<01?ndQJCo_8fTokb=Y?o3TjD2om6QYP;oiKZY00?onMJUooGXRoooool03?ooool01Ol006co
CUFjohIf^_n6M[[oXgj[00;oZh^d0oo0Ujh2onBk[@03oocUX_oooooooooo01gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool501TI
6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`04P1<C4`00`000000<c<c03<c<`0303<c
<`030000000I6AT06ATI00H06ATIOP000004ooooo`0300000?oooooooooo02Sooooo00?o0000oooo
ooooool05_ooool01Ol07jKoOg[3ogmj`onaT[Oo[8bd00Co`9N]0oo?XZT01OoK/:cogk:Yono7Z_ol
h:?o`=MT00;oN6Re00?oSWBboimn[onOOZl01?n[QZh2okB=[@?o_9:[0oo5Vjd3olVT/`03om>b^?o1
Z/?oaL;G00;oaL;G00CoGFC1od17/_m0Ak;oL5b/0_moHZP3oi1/Y@;oWgJT0on[OZ<01?ndQJCo_8fT
okb=Y?o3TjD2om6QYP;oiKZY00?onMJUooooooooool03Oooool00om>EK[oQWJjohIf^P04oj^;]0;o
`9N^00?ofKVhonBk[Oooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`0400000?ooooooooooooooo`D06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000
C4a<04a<C00B04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AUn000000Co
oooo00<00000ooooooooool0:Oooool2o`0001Kooooo00?o01nVogQ__?mhKk`00_n/S;@4ol2G[@;o
cj:Y0_oK/:`2onk;[`04oo[[Xom<C[?oG5bhogQX]@;oSWBb0_nOOZl3oj^6[P03okB=[OnfSJ_o]Xf[
00;o_9:[0oo5Vjd01?o=Y:oobJBcom>b^?oC/[P3olG2e`;o]Nkf00CoGFC1od17/_m`G:coL5b/0_mo
HZP2oi1/Y@?oWgJT0_n[OZ<01?ndQJCo_8fTokb=Y?o3TjD2om6QYP03onFgY_oieZGomNR;013ooooo
00?oCUFjohIf^_n6M[X00on[Rk@01?o0UjkofKVhomVi^?oam[0Rooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo1@0I6AT00ol00000
<c<c03<c<`0403<c<`03o`00001<C4`0C4a<0100C4a<00<0000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0601TI6Gh000001?ooool00`00003oooooooooo`0[ooooo`03o`000?oooooooooo01Co
oooo00?o01nVogQ__?n/S;@00_n/S;@2ol2G[@;oa9b^00?ocj:Yom^`[?oK/:`00_o^bjl00oo0efCo
C4jcoda>/`02ogQX]@03ohid/_nOOZooWgj_00?oZhJ^0onfSJ/01?nlTZ_o`YN[ol:GZoo5Vjd2olfT
[`05olVT/ooC/[Sodk:hon7<`_o5`]L00_nek_H2ooooo`;o@4Nb00?oL5b/ogmRZ?moHZP00on@K:D2
oimfY0;oZgjS0onlSJ@2om6QYP;oiKNV00?oo=NNo`000?ooool03oooool00ol09:ooQWJjohIf^P03
oj^;]0?ofKVh8oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`0400000?ooooooooooooooo`D06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00@
04a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6AUn000000Cooooo00<00000
ooooooooool0;?ooool00ol0003oooooooooo`0Cooooo`03o`00T?mhKkcoN6nl00;o[8bd00Ko`9N]
olBL[_o4W:koa9b^olnRZOoK/:`2onk;[`07oo[[Xol01YSo9Sbcoda>/om_HK;oN6Reohid/P03oimn
[`03oj^6[_n/QJ_o]Xf[00;o]Xf[00Co_9:[ol:GZoo2Uj_oaI^]0_o=Y:l01?oJ];;odk:hon7<`_oQ
c<82on_bb`Cooooo00Co@4Nbode8ZomoHZSoOf:X0on@K:D2oimfY0;oZgjS0onlSJ@2om6QYP;oiKNV
00?oo=NNooooooooool04?ooool3ofR7g@05oj^;]?nl[lgo_:o=omVi^?oam[009?ooool01Ol0003o
oooooooooooooooo000000_ooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00?o000003<c
<`0c<c<0100c<c<00ol00000C4a<04a<C00@04a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT01`0I6AT00ol0000000000000001j000000Cooooo00<00000ooooooooool0;Oooool00ol0
003oooooooooo`0Booooo`05o`00T?mXJL3oJ6W0ojb<]?n/SkP01?o4W:h2om^`[0;ok/^_00Con^^S
ooooool05Z7oC4jc0_m_HK82ohid/P03oimn[onNO:go[8F[00;o[8F[0_nfSJ/3ol:GZ`?ocJB_00?o
f[Bbon_>^?oQc<800_o[l//6ooooo`04ode8Zom]FJ[oKEVZogmRZ0;oT6bU0_nOMZ@01?n[OZ?o/XFT
okb=Y?nlSJ@2ol^KYP04om6QY_oU]jKoo=NNonGNKA?ooooo0_mXQmd3okb_cBOooooo00Co0000oooo
oooooooo00002oooool000Wooooo00@00000oooooooooooooooo100I6AT00ol00000<c<c03<c<`04
03<c<`03o`00001<C4`0C4a<0180C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@08
01TI6G/000001?ooool00`00003oooooooooo`0^ooooo`;o00004oooool2ofQY`0;o[8nh1?o4W:h0
1?oA[[Gofk2/onk;[oojjj<2ooooo`04o`0FXOm<C[?oC4jcofmQ/P;oRg2_0_nNO:d3ojb5Z`;o]Xf[
0oo2Uj/01Oo<XZgocJB_omZd/_oJ];;ojljh00;om^ne00?ob^^9ooooooooool01?ooool01?l00iKo
CDR[ofeIZ_m]FJX2oi1/Y@03oimfY?nRNZKo/XFT00;o/XFT00?o_8fTol^KY_o;VjH00_oU]jH00ool
eikoooooooooo`0Eooooo`03okb_cOoooooooooo02Oooooo00?o0000ooooool000002oooool000Wo
oooo00@00000oooooooooooooooo100I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<
00D0C4a<1000000:04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT02P0I6AT70000
0003o`0000000000000003`0000000?o0000000000000000<0000004ooooo`0300000?oooooooooo
033ooooo00?o0000ooooooooool04?ooool00ol0093oJ6W0ojb?^002ojb?^0;oa9b^0_oA[[D00ooZ
e/3ok/^_omKcV@03ooooo`03ob<f[Om<C[?oKf6b00;oRg2_0onNO:d2ojb5Z`04okJ=ZonkTZ_o^i:[
ol:GZ`;oc::]00CocJB_omZd/_o[c[Sojljh0_ofkkD8ooooo`03ode8Zom]FJ[oKEVZ00;oS6^X0_nR
NZH3ok:5Y003okb=Y?o;VjKobi^V00;oiKNV00?oo=NNooooooooool0?oooool00ol0003oooooo`00
000;ooooo`002Oooool01000003oooooooooooooool401TI6@03o`00000c<c<0<c<c00<0<c<c00?o
000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0206IVIP@000001P1<C4`00`000000<c<c03<c
<`0303<c<`030000000I6AT06ATI01l06ATI8@00000C01TI6C0000001?ooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo013ooooo0_mXJL02ojb?^005olBL[_oA[[GodJjeom6^]OoZe/00
0_oFliT3ooooo`04o`0FXOlS=ZgoKf6bofmQ/P;oRg2_0_nNO:d2ojb5Z`?o^i:[00?o`YN[olbR[Oo<
XZd00_oJ];800oo[c[Som^neooK_]@09ooooo`03o`03U_m]FJ[oKEVZ00;oS6^X0_nRNZH3ok:5Y0?o
bi^V00?oh[FXoocGW_oUgVd0@_ooool00ol0003oooooo`00000:ooooo`002Oooool01000003ooooo
ooooooooool301TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`2000000T0
IVIV0P00000504a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT08@0I6ATM000001H0
6ATI;P000004ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool01?lcI=?o
[8nhokBTb?ndY<P2om6^]@;oj]K000?oe_>Iooooooooool00_ooool01?l006So8cJ]oeaG/omLEk<2
oh]`[`;oWWb]00?o[8F[ok6:[OnkTZ/00_nkTZ/3olbR[@05omZd/OoJ];;ojljhooGaZOn^df@02_oo
ool01?m=B:_oKEVZoha[Z?n<JjP3oj9jYP;o/XFT0_o;VjH2on:eZ003oogOWOoooooooooo04;ooooo
0_l0000:ooooo`002Oooool01000003oooooooooooooool301TI6@03o`00000c<c<0<c<c00<0<c<c
00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0;06IVIP030000001<C4`0C4a<0080C4a<
0P00000503<c<`030000000I6AT06ATI02<06ATI5@0000000ol00000000001TI6@0I01TI6Bd00000
1?ooool00`00003oooooooooo`0cooooo`;o00004Oooool01olcI=?o]:C8okBTb?ndY<SodJjeon[F
`?oFliT01_ooool00olS=ZgoG5NcoeaG/`02ohE_/P03oiil[OnPOjoo/HZ]00;o/HZ]0_nkTZ/01Oo6
WJkoc::]omZd/OoJ];7ok]6f00;omO6Y2oooool00ol059goKEVZofeIZP02oha[Z0;oXWZV0_nbQJ@2
ol^KYP;oh[FX00?ooMnMooooooooool0@Oooool3o`0000[ooooo0009ooooo`0400000?oooooooooo
ooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C0;o00003`1VIVH0
0ol00000000004a<C00304a<C0030000000c<c<0<c<c00<0<c<c00?o00000000000I6AT08`0I6AT0
0ol0000000000000000A000001d06ATI00?o0000000000000000:@000004ooooo`0300000?oooooo
oooo03Gooooo00?o0000ooooooooool04?ooool01?ndY<So`N_aol7[lOoZe/08ooooo`04ob<f[OmL
Ek?oQFnbohE_/P;oX7n_0onaRZd01?nkTZ_oaYf^olJM[_o<XZd2omZd/@03onkA]_oelJWooooo00co
oooo00Co?dB_ofeIZ_n<JjSoS6^X0_nRNZH01onbQJCo_i:XoknBZ?o;VjKoh[FXoogOWOn^_Sd0?ooo
ool4o`0000gooooo0009ooooo`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00P0c
<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV00@0IVIV2?l0000506IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0>01TI6@/000002`0I
6AT?000000/06ATI3000000;01TI6BT000001?ooool00`00003oooooooooo`0fooooo`03o`000?oo
oooooooo013ooooo00?o`N_aooooooooool02?ooool01?l009?oG5NcoeaG/on5Kk83oj1o[`;o/HZ]
0oo6WJh2omZd/@03onkA]_oelJWo000000gooooo0_loA:l2oha[Z0;oXWZV00?o/XFToknBZ?noTZP0
0_oR]JP00oomgigoooooooooo`0kooooo`?o00004Oooool000Wooooo00H00000oooooooooooooooo
01TI6Ol0000403<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH3o`0000P0
Ogmo0_l0000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<2000000X0
6ATI1000000;03<c<`@000002@0I6AT;000000X06ATI0`00000<03<c<`<000002@0I6ATX000000Co
oooo00<00000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`04ob]3]omLEk?oQFnbohE_
/P;oX7n_0_naRZd3olJM[P04omJb]OoJ];7ok]6fo`0000kooooo00Ko01BMocm4[on3KK;oPffboj9j
Y_nZQJd3oknBZ0;oh[FX00?ooMnMooooooooool0=oooool4o`0001Cooooo0009ooooo`0500000?oo
ooooooooooooool00000100c<c<01_l00000C4a<04a<C01<C4co0000000000<0IVIV0_l0000=07mo
O`;o00000`1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0<c<c00D0<c<c00<00000o`00
000000000`0000001?l00000000000000000000C03<c<`800000200I6AT00`00003o000000000005
000000/06ATI00?o000003<c<`0c<c<0400c<c<00`00003o00000000000701TI6BL000001?ooool0
0`00003oooooooooo`0hooooo`;o00006oooool01?l009?o:d>gohE_/_n5Kk82oj1o[`04ok6:[Onj
U[;o^YJbolJM[P;oe[:e00?ok]Vlon;dW?ooool03oooool00oloA:ooPffboh=]/P02ojZ5[@?o_i:X
00?ofK:aoogOWOooool0=Oooool4o`0001Sooooo0009ooooo`0500000?ooooooooooooooool00000
100c<c<01Ol00000C4a<04a<C01<C4`0000000<0IVIV0_l0000407moO`Oo00001@1oOgl01?l00000
IVIV06IVIP00000404a<C0030000000c<c<0<c<c01<0<c<c2`00000603<c<`8000002P0I6AT20000
00/06ATI0P00000F03<c<`030000000I6AT06ATI00D06ATI00?o00000000000000008`000004oooo
o`0300000?oooooooooo03[ooooo00?o0000ooooooooool06Oooool01Ol[@kOoNW6mogYa_OnPOjoo
Y8Vh00?o^YJb00GoaYf^omJb]OoF/[Gok]Vlo`00000@ooooo`;o?dB_00GoPffbojZ5[OnZQJgoZXF]
oknBZ002omVb/@03ooK`Y?oooooooooo033ooooo1?l0000Looooo`002Oooool01@00003ooooooooo
oooooooo000000<0<c<c00Go000004a<C01<C4`0C4a<0000000306IVIP04o`00001oOgl0Ogmo07mo
O`?o00001`2IVIT00ol00000Ogmo07moO`0207moO`05o`00001VIVH0IVIV06IVIP000000101<C4`0
0`000000<c<c03<c<`0>03<c<`@000002`1<C4`3000000D0<c<c00<0000001TI6@0I6AT04P0I6AT2
000000H0<c<c3?l0000703<c<`030000000I6AT06ATI00@06ATI9P000004ooooo`0300000?oooooo
oooo03_ooooo00?o0000ooooooooool06?ooool00ol008So:d>gogYa_@03ojB9^0;o^YJb0_oF/[D0
0oo^fKcoh_BLooooo`0Aooooo`03ocm4[on3KK;oPffb00;oZXF]00Co_i:XomVb/OoI/[7om_2T;ooo
ool3o`00023ooooo0009ooooo`0400000?ooooooooooooooo`@0<c<c00Go000004a<C01<C4`0C4a<
0000000206IVIP05o`00001oOgl0Ogmo07moOol000002`2IVIT2o`0000<0Ogmo00Go000006IVIP1V
IVH0IVIV0000000404a<C0030000000c<c<0<c<c00/0<c<c00?o00000000001<C4`04@1<C4`00`00
0000<c<c03<c<`0303<c<`030000000I6AT06ATI01006ATI00?o000003<c<`0c<c<0100c<c<2o`00
00`0C4a<0_l0000603<c<`030000000I6AT06ATI00@06ATI9@000004ooooo`0300000?oooooooooo
03cooooo00?o0000ooooooooool06?ooool00ol008SoNW6mogYa_@02ojB9^005okZF/_o;[kkobjnn
omJb]Oo^fK`04oooool00ol0073oPffboh=]/P02ojZ5[@;ofK:a00?om_2Tooooooooool0:_ooool4
o`0002?ooooo0009ooooo`0400000?ooooooooooooooo`<0<c<c00Go000004a<C01<C4`0C4a<0000
000206IVIP05o`00001oOgl0Ogmo07moOol00000102IVIT7o`0000<0VIVI0_l0000207moO`06o`00
001VIVH0IVIV06IVI_l0000000000`1<C4`00ol0000000000000000903<c<`8000001@1<C4`40000
00;o00001@00000404a<C0800000100c<c<00`0000006ATI01TI6@0>01TI6@030000000c<c<0<c<c
00<0<c<c0_l0000604a<C0Co00001P1<C4`3o`0000@0<c<c00<0000001TI6@0I6AT0100I6ATT0000
00Cooooo00<00000ooooooooool0?Oooool2o`0001Wooooo0_m=Mm/00onTRKSo[JG@ol^__P02ol^_
_P03onOXd?oooooooooo01?ooooo0_mDM]L01OnZQJgo_ZW5okjYaOoI/[7om_2T02Sooooo1?l0000W
ooooo`002Oooool01000003oooooooooooooool303<c<`05o`00001<C4`0C4a<04a<C00000000P1V
IVH01?l00000Ogmo07moOol0000309VIV@;o00001`2c/k<00ol00000VIVI09VIV@0209VIV@04o`00
001oOgl0Ogmoo`0000<0IVIV00<0000004a<C01<C4`0101<C4`300000080<c<c1000000304a<C0@0
00002`1VIVH3000000<0C4a<0P00000303<c<`03o`00000000006ATI00`06ATI00<0000003<c<`0c
<c<00P0c<c<2o`0000@0C4a<1?l0000406IVIPCo00001@1<C4`00ol00000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00@06ATI8`000004ooooo`0300000?oooooooooo03oooooo00?o0000oooooooo
ool05_ooool00ol0003oCGOKojfUd002ojfUd003ol^___oWj=3ooooo01Kooooo00GoE7KGokjYaOnn
ZLGo_ZW5omVb/@0Uooooo`Co0000:oooool000Wooooo00@00000oooooooooooooooo0P0c<c<01Ol0
0000C4a<04a<C01<C4`000000080IVIV00Co000007moO`1oOgoo00000`2IVIT00ol00000/k>c0;>c
/`080;>c/`;o00000P2IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00<0000004a<C01<C4`0
1P1<C4`2000000D0C4a<0P00000406IVIP_o00000`1VIVH00`000000C4a<04a<C00204a<C0030000
000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0200I6AT2000000@0<c<c00?o000004a<C01<C4`0
0P1<C4`2o`0000`0IVIV0ol0000304a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0
100I6ATR000000Cooooo00<00000ooooooooool0@?ooool00ol0003oooooooooo`0Dooooo`06o`00
0?oooooooooooooooon]YM3oV^ke6oooool00onnZLGoooooooooo`0Rooooo`?o0000;oooool000Wo
oooo00@00000oooooooooooooooo0P0c<c<01?l00000C4a<04a<C000000206IVIP04o`00001oOgl0
Ogmoo`0000<0VIVI00?o00000;>c/`2c/k<02`2c/k<01?l00000VIVI09VIVOl0000307moO`05o`00
001VIVH0IVIV06IVIP0000003@1<C4`01?l00000IVIV06IVIP1VIVH3o`0000/0Ogmo0_l0000206IV
IP8000000P1<C4`00ol00000<c<c03<c<`0303<c<`8000001P0I6AT2000000D0<c<c00Co000004a<
C01<C4`0C4a<0_l0000506IVIPSo0000101VIVH01Ol00000C4a<04a<C01<C4co000000@0<c<c00?o
000001TI6@0I6AT00`0I6AT00ol0000000000000000O000000Cooooo00<00000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo1?l0000booooo`002Oooool0
1000003oooooooooooooool203<c<`04o`00001<C4`0C4a<00000080IVIV00Co000007moO`1oOgoo
00000P2IVIT00ol00000/k>c0;>c/`020;>c/`Ko0000102c/k<01?l00000VIVI09VIVOl0000307mo
O`05o`00001VIVH0IVIV06IVIP000000301<C4`00`000000IVIV06IVIP02o`0000<0Ogmo2_l00003
07moO`05o`00001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c03<c<`0403<c<`8000000P0I
6AT2000000H0<c<c00Go000004a<C01<C4`0C4a<o`00000406IVIP?o0000201oOgl00ol00000IVIV
06IVIP0206IVIP04o`00001<C4`0C4a<o`0000@0<c<c00<0000001TI6@0I6AT00`0I6ATR000000Co
oooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o0000ooooooooool0>oooool4o`0003Ko
oooo0009ooooo`0400000?ooooooooooooooo`80<c<c00Co000004a<C01<C4`000000P1VIVH00ol0
0000Ogmoo`00000309VIV@05o`00002c/k<0/k>c0;>c/ol000001P3<c<`00ol00000/k>c0;>c/`02
0;>c/`04o`00002IVIT0VIVIo`0000<0Ogmo00Go000006IVIP1VIVH0IVIV0000000904a<C0800000
0P1VIVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00P0VIVI0_l0000207moO`05o`00
001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c03<c<`0503<c<`800000200c<c<01Ol00000
C4a<04a<C01<C4co00000080IVIV0_l0000<07moO`;o00000P1VIVH01Ol00000C4a<04a<C01<C4co
000000@0<c<c00<0000001TI6@0I6AT00`0I6ATQ000000Cooooo00<00000ooooooooool0A?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0000jooooo`002Oooool01P00
003oooooooooooooool0<c<co`000080C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l00000VIVI
09VIVOl000030;>c/`03o`00003<c<`0c<c<00H0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VI
V@05o`00001oOgl0Ogmo07moOol00000101VIVH00`000000C4a<04a<C00504a<C0030000001VIVH0
IVIV0080IVIV00?o000007moO`1oOgl00_l0000209VIV@So00000`2IVIT01?l00000Ogmo07moOol0
000306IVIP04o`00001<C4`0C4a<000000l0<c<c00Go000004a<C01<C4`0C4a<o`00000206IVIP03
o`00001oOgl0Ogmo0080Ogmo2?l0000407moO`04o`00001VIVH0IVIVo`0000<0C4a<00Go000003<c
<`0c<c<0<c<c0000000501TI6B4000001?ooool00`00003oooooooooo`15ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo0009ooooo`0600000?oooooooooo
ooooo`0c<c?o00000P1<C4`010000000IVIV06IVI_l0000207moO`04o`00002IVIT0VIVIo`0000<0
/k>c00?o00000<c<c03<c<`01`3<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00Go000007mo
O`1oOgl0Ogmoo`00000406IVIPD0000000?o00000000001VIVH00P1VIVH2o`00000307moOol0003o
000000<0VIVI0_l000070;>c/`?o000000D0VIVIo`00001oOgl0Ogmoo`00000206IVIP040000001<
C4`0C4a<o`0000h0<c<c00?o000004a<C01<C4`00_l0000206IVIP04o`00001oOgl0Ogmo07moO`;o
0000202IVIT2o`0000<0Ogmo0_l000000`1VIVKo000004a<C00204a<C005o`00000c<c<0<c<c03<c
<`0000001@0I6ATP000000Cooooo00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo033ooooo0ol00012ooooo`002Oooool01P00003oooooooooooooool0<c<c
o`000080C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l00000VIVI09VIVOl000030;>c/`03o`00
003<c<`0c<c<00L0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@05o`00001oOgl0Ogmo07mo
Ool000003@1VIVH01?l00000Ogmo07moOol0000309VIV@;o00000`2c/k<7o`000080/k>c00?o0000
09VIVOl000000P1oOgl00ol00000IVIV0000000304a<C0030000000c<c<0<c<c00X0<c<c00Co0000
04a<C01<C4co00000`1VIVH00ol00000Ogmo07moO`02o`0000@0VIVI1?l0000409VIV@;o00000P1o
Ogl01?l00000IVIV06IVI_l0000304a<C004o`00000c<c<0<c<c000000D06ATI80000004ooooo`03
00000?oooooooooo04Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co
0000AOooool000Wooooo00D00000ooooooooooooooooo`00000304a<C0060000001VIVH0IVIVo`00
001oOgoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000X0c<c<00?o00000;>c/`2c/k<00P2c
/k<01?l00000VIVI09VIVOl0000207moO`03o`00001VIVH0IVIV00/0IVIV00Co000007moO`1oOgoo
00000P2IVIT00ol00000/k>c0;>c/`03o`0000L0c<c<00Ko00000;>c/`2c/k?o000009VIVOl00002
07moO`03o`00001VIVH0000000<0C4a<00<0000003<c<`0c<c<0200c<c<01Ol00000C4a<04a<C01<
C4co000000<0IVIV00Co000007moO`1oOgoo00000P2IVIT3o`0000@0/k>c0ol0000309VIV@06o`00
001oOgl0Ogmoo`00001VIVKo00000`1<C4`01Ol00000<c<c03<c<`0c<c<0000000D06ATI7`000004
ooooo`0300000?oooooooooo04Sooooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo1?l00019
ooooo`002Oooool01@00003ooooooooooooooooo000000<0C4a<00<0000006IVI_l000000P1oOgl0
1?l00000VIVI09VIVOl000020;>c/`03o`00003<c<`0c<c<00X0c<c<00Go00000;>c/`2c/k<0/k>c
o`00000209VIV@04o`00001oOgl0Ogmoo`0000`0IVIV00Co000007moO`1oOgoo00000P2IVIT01?l0
0000/k>c0;>c/ol000040<c<c0Co00000`3<c<`01_l00000/k>c0;>c/ol00000VIVIo`000080Ogmo
00?o000006IVIP0000000`1<C4`00`000000<c<c03<c<`0603<c<`03o`00001<C4`0C4a<0080C4a<
00Co000006IVIP1VIVKo00000P1oOgl01?l00000VIVI09VIVOl0000:0;>c/`05o`00002IVIT0VIVI
09VIVOl000000P1oOgl00ol00000IVIVo`00000204a<C005o`00000c<c<0<c<c03<c<`0000001@0I
6ATO000000Cooooo00<00000ooooooooool0B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Cooooo1?l0001=ooooo`002Oooool01@00003ooooooooooooooooo000000<0C4a<00<0
000006IVI_l000000P1oOgl01?l00000VIVI09VIVOl000020;>c/`03o`00003<c<`0c<c<00X0c<c<
00Go00000;>c/`2c/k<0/k>co`00000209VIV@04o`00001oOgl0Ogmoo`0000`0IVIV00Co000007mo
O`1oOgoo00000P2IVIT01?l00000/k>c0;>c/ol000020<c<c0;o0000103Vi^H02Ol00000c<c<0<c<
c03<c<co00000;>c/ol00000VIVIo`00000207moO`03o`00001VIVH0000000<0C4a<00?o000003<c
<`0c<c<01P0c<c<00ol00000C4a<04a<C00204a<C004o`00001VIVH0IVIVo`000080Ogmo00Co0000
09VIV@2IVIWo00002P2c/k<01Ol00000VIVI09VIV@2IVIWo00000080Ogmo00?o000006IVI_l00000
0P1<C4`01Ol00000<c<c03<c<`0c<c<0000000D06ATI00?o000000000000000070000004ooooo`03
00000?oooooooooo04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`?o
0000DOooool000Wooooo00D00000ooooooooooooooooo`00000304a<C0060000001VIVH0IVIVo`00
001oOgoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000X0c<c<00Go00000;>c/`2c/k<0/k>c
o`00000209VIV@05o`00001oOgl0Ogmo07moOol000002`1VIVH01?l00000Ogmo07moOol0000209VI
V@04o`00002c/k<0/k>co`000080c<c<00?o00000>KViP3Vi^H0103Vi^H01Ol00000c<c<0<c<c03<
c<co00000080/k>c00Go000009VIVOl00000Ogmoo`00000206IVIP040000001<C4`0C4a<000000P0
<c<c00Go000004a<C01<C4`0C4a<o`00000206IVIP04o`00001oOgl0Ogmoo`000080VIVI00?o0000
0;>c/`2c/k<00P2c/k<4o`0000@0/k>c00Wo000009VIV@2IVIT0VIVIo`00001oOgoo000006IVI_l0
00000P1<C4`01Ol00000<c<c03<c<`0c<c<0000000D06ATI7`000004ooooo`0300000?oooooooooo
04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool000Wo
oooo00H00000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIVo`000080Ogmo00Co
000009VIV@2IVIWo00000P2c/k<00ol00000c<c<0<c<c0080<c<c005o`00002c/k<0/k>c0;>c/ol0
00000P2IVIT01Ol00000Ogmo07moO`1oOgoo000000/0IVIV00Ko000007moO`1oOgoo000009VIVOl0
00030;>c/`03o`00003<c<co000000P0i^KV00Wo00000<c<c03<c<`0c<c<o`00002c/k?o000009VI
VOl000000P1oOgl00ol00000IVIV0000000304a<C0030000000c<c<0<c<c00@0<c<c00?o000004a<
C01<C4`00P1<C4`01?l00000IVIV06IVI_l0000207moO`03o`00002IVIWo000000@0/k>c00?o0000
0<c<c03<c<`00P3<c<`2o`000080/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`03o`00001V
IVKo00000080C4a<00Go000003<c<`0c<c<0<c<c0000000401TI6Al000001?ooool00`00003ooooo
ooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wooooo00H0
0000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIVo`000080Ogmo00Co000009VI
V@2IVIWo00000`2c/k<2o`0000L0c<c<0_l000030;>c/`04o`00002IVIT0VIVIo`0000<0Ogmo00?o
000006IVIP1VIVH0201VIVH01?l00000Ogmo07moOol0000209VIV@06o`00002c/k<0/k>co`00003<
c<co00001@3Vi^H00ol00000i^KV0>KViP020>KViP06o`00003<c<`0c<c<o`00002c/k?o00000P2I
VIT01Ol00000Ogmoo`00001VIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<2o`0000<0C4a<
00Co000006IVIP1VIVKo00000P1oOgl01?l00000VIVI09VIVOl000030;>c/`03o`00003<c<`0c<c<
00@0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@06o`00001oOgl0Ogmoo`00001VIVKo0000
0P1<C4`01Ol00000<c<c03<c<`0c<c<0000000@06ATI7`000004ooooo`0300000?oooooooooo04oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wooooo
00H00000oooooooooooooooo03<c<ol0000204a<C0040000001VIVH0IVIVo`000080Ogmo00Go0000
09VIV@2IVIT0VIVIo`0000040;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00P2c
/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00?o000006IVIP1VIVH0201VIVH01?l00000Ogmo
07moOol0000209VIV@06o`00002c/k<0/k>co`00003<c<co00001@3Vi^H00ol00000i^KV0>KViP02
0>KViP06o`00003<c<`0c<c<o`00002c/k?o00000P2IVIT01Ol00000Ogmoo`00001VIVH0000000@0
C4a<00<0000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00204a<C004o`00001VIVH0IVIVo`00
0080Ogmo00Co000009VIV@2IVIWo00000`2c/k<00ol00000c<c<0<c<c0040<c<c005o`00002c/k<0
/k>c0;>c/ol000000P2IVIT01_l00000Ogmo07moOol00000IVIVo`000080C4a<00Go000003<c<`0c
<c<0<c<c0000000401TI6Al000001?ooool00`00003oooooooooo`1@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009ooooo`0400000?oooooooooooooo
o`80<c<c00Co000004a<C01<C4`000000P1VIVH00ol00000Ogmoo`00000309VIV@03o`00002c/k<0
/k>c00<0/k>c1Ol000040;>c/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl00ol00000IVIV06IV
IP0906IVIP04o`00001oOgl0Ogmoo`000080VIVI00Go00000;>c/ol00000c<c<o`0000050>KViP03
o`00003ooooo000000@0i^KV00[o00000<c<c03<c<co00000;>c/ol00000VIVIo`00001oOgoo0000
0P1VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c03<c<ol00000101<C4`01?l00000
IVIV06IVI_l0000207moO`03o`00002IVIWo000000<0/k>c00?o00000<c<c03<c<`01P3<c<`01Ol0
0000/k>c0;>c/`2c/k?o00000080VIVI00?o000007moOol000000P1VIVH01?l00000C4a<04a<C?l0
000203<c<`030000000I6AT06ATI00<06ATI7P000004ooooo`0300000?oooooooooo057ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000Hoooool000Wooooo00@00000
oooooooooooooooo0P0c<c<01?l00000C4a<04a<C000000206IVIP03o`00001oOgl0Ogmo00;o0000
0P2IVIT2o`0000/0/k>c00?o000009VIV@2IVIT00P2IVIT01?l00000Ogmo07moOol0000<06IVIP04
o`00001oOgl0Ogmoo`000080VIVI00Go00000;>c/ol00000c<c<o`0000040>KViP05o`00003oool0
oooo0?ooool000000`3Vi^H02_l00000c<c<0<c<c?l00000/k>co`00002IVIWo000007moOol00002
06IVIP030000001<C4`0C4a<0080C4a<00D0000003<c<`0c<c<0<c<co`00000404a<C004o`00001V
IVH0IVIVo`000080Ogmo00?o000009VIVOl000000`2c/k<00ol00000c<c<0<c<c0060<c<c005o`00
002c/k<0/k>c0;>c/ol000000P2IVIT00ol00000Ogmoo`00000206IVIP04o`00001<C4`0C4a<o`00
0080<c<c00<0000001TI6@0I6AT00`0I6ATN000000Cooooo00<00000ooooooooool0D_ooool2o`00
00?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo0009ooooo`0400000?oooooooooooooo
o`80<c<c00Co000004a<C01<C4`000000P1VIVH00ol00000Ogmo07moO`0207moO`04o`00002IVIT0
VIVI09VIV@?o00001P2c/k<2o`0000@0VIVI00Go000007moO`1oOgl0Ogmoo`00000<06IVIP04o`00
001oOgl0Ogmoo`000080VIVI00Go00000;>c/ol00000c<c<o`0000050>KViP03o`00003ooooo0000
00@0i^KV00[o00000<c<c03<c<co00000;>c/ol00000VIVIo`00001oOgoo00000P1VIVH00`000000
C4a<04a<C00204a<C0050000000c<c<0<c<c03<c<ol00000101<C4`01?l00000IVIV06IVI_l00002
07moO`03o`00002IVIWo000000<0/k>c00?o00000<c<c03<c<`01P3<c<`01Ol00000/k>c0;>c/`2c
/k?o00000080VIVI00?o000007moOol000000P1VIVH01?l00000C4a<04a<C?l0000203<c<`030000
000I6AT06ATI00<06ATI7P000004ooooo`0300000?oooooooooo05Cooooo00Co0000oooooooooooo
00002?ooool4o`0006_ooooo0009ooooo`0400000?ooooooooooooooo`<0<c<c00Co000004a<C01<
C4`000000P1VIVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00<0VIVI1_l0000409VI
V@;o00000`1oOgl00ol00000IVIV06IVIP0206IVIP@000001P1VIVH01_l00000Ogmo07moOol00000
VIVIo`000080/k>c00?o00000<c<c?l000001@3Vi^H00ol00000i^KV0>KViP020>KViP08o`00003<
c<`0c<c<o`00002c/k?o000009VIVOl0000207moO`03o`00001VIVH0000000@0C4a<00<0000003<c
<`0c<c<00P0c<c<00ol00000C4a<04a<C00304a<C006o`00001VIVH0IVIVo`00001oOgoo00000P2I
VIT01Ol00000/k>c0;>c/`2c/k?o000000H0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@03
o`00001oOgoo00000080IVIV00Co000004a<C01<C4co00000`0c<c<00`0000006ATI01TI6@0201TI
6Al000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo0ol0001_oooo
o`002Oooool01000003oooooooooooooool303<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH2
o`0000<0Ogmo00?o000009VIV@2IVIT02P2IVIT2o`0000<0Ogmo0_l0000406IVIP03o`00001<C4`0
C4a<0080C4a<0P0000001Ol00000IVIV06IVIP1VIVKo00000080Ogmo00Ko000009VIV@2IVIWo0000
0;>c/ol000020<c<c003o`00003Vi^H0i^KV00L0i^KV00So00000<c<c03<c<co00000;>c/ol00000
VIVIo`000080Ogmo00?o000006IVIP0000000`1<C4`00`000000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<0080C4a<00Ko000006IVIP1VIVKo000007moOol0000209VIV@03o`00002c/k<0/k>c0080
/k>c0_l000020<c<c0?o00000`2c/k<01_l00000VIVI09VIVOl00000Ogmoo`000080IVIV00Co0000
04a<C01<C4co00000`0c<c<00`0000006ATI01TI6@0201TI6Al000001?ooool00`00003ooooooooo
o`1Fooooo`;o000000?oooooo`000?l000000_l0001booooo`002Oooool01000003ooooooooooooo
ool303<c<`05o`00001<C4`0C4a<04a<C0000000101VIVH01Ol00000Ogmo07moO`1oOgoo000000T0
VIVI0_l0000407moO`03o`00001VIVH0IVIV0080IVIV0P00000704a<C0050000001VIVH0IVIV06IV
I_l000000P1oOgl01?l00000VIVI09VIVOl000020;>c/`03o`00003<c<`0c<c<00;o00001P3Vi^H0
2Ol00000c<c<0<c<c03<c<co00000;>c/ol00000VIVIo`00000207moO`03o`00001VIVH0000000<0
C4a<00<0000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<C006o`00001VIVH0IVIVo`00
001oOgoo00000`2IVIT00ol00000/k>c0;>c/`030;>c/`;o00001P2c/k<01_l00000VIVI09VIVOl0
0000Ogmoo`000080IVIV00Co000004a<C01<C4co00000`0c<c<00`0000006ATI01TI6@0201TI6Al0
00001?ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo00D00000oooooooooooo
ooooo`00000303<c<`05o`00001<C4`0C4a<04a<C0000000101VIVH01?l00000Ogmo07moO`1oOgl9
o`0000@0Ogmo0_l0000406IVIP030000001<C4`0C4a<00P0C4a<00D0000006IVIP1VIVH0IVIVo`00
000207moO`04o`00002IVIT0VIVIo`000080/k>c00Co00000<c<c03<c<`0c<c<0_l000020>KViP;o
00000P3<c<`2o`0000040;>c/ol00000VIVIo`000080Ogmo00Co000006IVIP1VIVH000000P1<C4`0
0`000000<c<c03<c<`0603<c<`05o`00001<C4`0C4a<04a<C?l000000P1VIVH01?l00000Ogmo07mo
Ool0000309VIV@03o`00002c/k<0/k>c00P0/k>c0_l0000309VIV@03o`00001oOgoo00000080IVIV
00Co000004a<C01<C4co00000`0c<c<00`0000006ATI01TI6@0201TI6Al000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01@00003ooooooooooooooooo000000@0<c<c00Go000004a<C01<
C4`0C4a<0000000406IVIP03o`00001oOgl0Ogmo00`0Ogmo00?o000006IVIP1VIVH00`1VIVH00`00
0000C4a<04a<C00:04a<C0070000001VIVH0IVIV06IVI_l00000Ogmoo`00000209VIV@05o`00002c
/k<0/k>c0;>c/ol00000103<c<`2o`0000<0c<c<00Oo00000;>c/`2c/k<0/k>co`00002IVIWo0000
0080Ogmo00Co000006IVIP1VIVH000000P1<C4`00`000000<c<c03<c<`0603<c<`03o`00001<C4`0
C4a<0080C4a<00Co000006IVIP1VIVKo00000P1oOgl01Ol00000VIVI09VIV@2IVIWo000000P0/k>c
00?o000009VIV@2IVIT00P2IVIT00ol00000Ogmoo`00000206IVIP04o`00001<C4`0C4a<o`0000<0
<c<c00<0000001TI6@0I6AT00`0I6ATO000000Cooooo00<00000ooooooooool0coooool000Wooooo
00H00000oooooooooooooooo01TI6Ol0000403<c<`04o`00001<C4`0C4a<04a<C08000000`1VIVH5
o`0000H0Ogmo0ol0000406IVIP8000003P1<C4`01?l00000IVIV06IVI_l0000207moO`;o000000D0
VIVIo`000?l0003o00000;>c/`03o`0000<0c<c<0ol000030;>c/`03o`00002IVIWo00000080Ogmo
00Co000006IVIP1VIVH000000P1<C4`00ol00000<c<c03<c<`0803<c<`05o`00001<C4`0C4a<04a<
C?l000000P1VIVH01?l00000Ogmo07moO`1oOgl2o`000080VIVI0ol000020;>c/`?o00000`2IVIT2
o`000080Ogmo00Co000006IVIP1VIVKo00000P1<C4`01Ol00000<c<c03<c<`0c<c<0000000D06ATI
7`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0600000?ooooooooooooooo`0I6AWo
00001@0c<c<2o`0000<0C4a<0P00000606IVIPKo00001P1VIVH00`000000C4a<04a<C00504a<C0Oo
00000`1<C4`010000000IVIV06IVI_l0000307moO`05o`00002IVIT0VIVI09VIVOl000000`2c/k<3
o`0000@0/k>c0_l000001@2IVIWo000007moO`1oOgoo000000<0IVIV00@0000004a<C01<C4`00000
2`0c<c<01Ol00000C4a<04a<C01<C4co00000080IVIV0_l0000307moO`03o`00002IVIT0VIVI0080
VIVI0_l0000409VIV@;o00000P1oOgl2o`000080IVIV00Go000004a<C01<C4`0C4a<o`00000303<c
<`030000000I6AT06ATI00<06ATI7`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`04
00000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<
C0<00000301VIVH3000000D0C4a<0ol0000703<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH0
1Ol00000Ogmo07moO`1oOgoo000000<0VIVI0ol000050;>c/`;o00000P2IVIT01?l00000Ogmo07mo
Ool0000306IVIP040000001<C4`0C4a<000000d0<c<c00Go000004a<C01<C4`0C4a<o`00000306IV
IP05o`00001oOgl0Ogmo07moOol00000202IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00Go
000004a<C01<C4`0C4a<o`00000303<c<`030000000I6AT06ATI00<06ATI80000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<06ATI0_l0000503<c<`03o`00
001<C4`0C4a<00@0C4a<0`00000506IVIP80000000?o00000000001<C4`01@1<C4`2o`0000/0<c<c
00Go000004a<C01<C4`0C4a<0000000206IVIP?o000000@0Ogmoo`000?l0003o00000`2IVIT5o`00
000409VIVOl0003o0000o`000080Ogmo00Go000006IVIP1VIVH00000o`00000204a<C0030000000c
<c<0<c<c00d0<c<c00Go000004a<C01<C4`0C4a<o`00000306IVIP04o`00001oOgl0Ogmo07moO`So
00000`1oOgl01Ol00000IVIV06IVIP1VIVKo000000<0C4a<00Go000003<c<`0c<c<0<c<co`000005
01TI6B4000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool5
01TI6@03o`00000c<c<0<c<c0080<c<c0_l0000804a<C0D00000201<C4`2o`0000d0<c<c0_l00003
04a<C0030000001VIVH0IVIV0080IVIV00Co000007moO`1oOgl0Ogmo0ol0000509VIV@03o`00001o
Ogl0Ogmo0080Ogmo00Co000006IVIP1VIVH00000101<C4`00`000000<c<c03<c<`0203<c<`Go0000
1P0c<c<00ol00000C4a<04a<C00204a<C003o`00001VIVH0IVIV00?o00002P1oOgl2o`0000@0IVIV
00Go000004a<C01<C4`0C4a<o`00000303<c<`030000000I6AT06ATI00<06ATI8@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`H06ATI00?o000003<c<`0c
<c<00`0c<c<2o`0000l0C4a<1?l0000A03<c<`05o`00001<C4`0C4a<04a<C0000000101VIVH2o`00
00@0Ogmo1Ol0000407moO`04o`00001VIVH0IVIV000000@0C4a<00@0000003<c<`0c<c<0<c<c0_l0
000501TI6@;o00001@0c<c<00ol00000C4a<04a<C00204a<C003o`00001VIVH0IVIV0080IVIV1?l0
000207moO`Co0000101VIVH2o`0000<0C4a<00Go000003<c<`0c<c<0<c<c0000000601TI6B400000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool701TI6@03o`00
000c<c<0<c<c00@0<c<c0ol0000904a<C0?o00002`0c<c<4o`0000L0<c<c00Co000004a<C01<C4`0
C4a<0P00000406IVIP03o`00001oOgl0Ogmo00L0Ogmo0ol0000206IVIP03o`00001<C4`0C4a<0080
C4a<00D0000003<c<`0c<c<0<c<co`00000901TI6@03o`00000c<c<0<c<c00<0<c<c00?o000004a<
C01<C4`00P1<C4`00ol00000IVIV06IVIP0506IVIP;o00001`1VIVH00ol00000C4a<04a<C00204a<
C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00`0I6ATR000000Cooooo00<00000oooo
ooooool0coooool000Wooooo00@00000oooooooooooooooo200I6AT2o`0000L0<c<c2Ol0000:03<c
<`Co0000100I6AT3o`0000D0<c<c0_l0000304a<C08000000`1VIVH9o`0000<0IVIV0P00000204a<
C00300000?l00000000000<0<c<c00?o000001TI6@0I6AT02@0I6AT2o`0000@0<c<c0_l0000304a<
C0Co00002@1VIVH3o`0000<0C4a<0_l0000303<c<`8000001P0I6ATR000000Cooooo00<00000oooo
ooooool0coooool000Wooooo00D00000ooooooooooooooooo`00000901TI6@;o00005@0c<c<3o`00
00/06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<C0<000002@1VIVH30000
00<0C4a<00<0000003<c<`0c<c<00P0c<c<2o`0000h06ATI00?o000003<c<`0c<c<00`0c<c<2o`00
00D0C4a<2Ol0000404a<C0;o0000100c<c<00`0000006ATI01TI6@0501TI6B<000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01P00003oooooooooooooool00000o`0000X06ATI0_l0000B
03<c<`03o`00000I6AT06ATI00d06ATI0ol0000403<c<`?o0000101<C4`9000000@0C4a<0P000004
03<c<`03o`00000I6AT06ATI00l06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00=
04a<C0;o00001@0c<c<00`0000006ATI01TI6@0501TI6B@000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003oooooooooooooool200000003o`00000I6AT06ATI00T06ATI0ol0000;
03<c<`Co00004`0I6AT00ol00000<c<c03<c<`0403<c<`;o00003@1<C4`2000000D0<c<c00?o0000
01TI6@0I6AT04@0I6AT2o`0000D0<c<c0_l0000<04a<C003o`00000c<c<0<c<c00@0<c<c00<00000
01TI6@0I6AT01@0I6ATU000000Cooooo00<00000ooooooooool0coooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
coooool000Wooooo]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00017o
oooo]P00000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00@00000oooooooooooo00002_ooool00ol0003ooooo
ooooo`06ooooo`;o00004_ooool2o`00000300000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool2000000Gooooo0P00000;ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
0oooool2000001;ooooo0P000004ooooo`03o`000000003ooooo00Cooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK106P0okK11P000?lO0?nf`BGooooo00?o0000ooooooooool03oooool00`00003oooooo`00
000:0?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/405@3o]/400`000000okK10?nf
`@060?nf`@03o`00003o]/40okK100/0okK11@00000=0?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@060?nf`@P000001P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/4010000000okK10?nf
`@3o]/4Uooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK106@0okK11000
0?l60?nf`@<0003o703o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/402P3o
]/400`000000okK10?nf`@050?nf`@030000003o]/40okK101L0okK100<000000?nf`@3o]/401@3o
]/400`000000okK10?nf`@0L0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@030?nf`@@00000203o]/42000000D0okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/409Ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@1R0?nf`@80003o3@3o]/42
0000oaX0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100T0okK100<00000
0?nf`@3o]/40103o]/42000000P0okK12`0000080?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/406P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400P3o]/400ol0000000000?nf`@0=0?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/409Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0J0?nf
`@T0003o?P3o]/400ol00?l0okK10?nf`@0?0?nf`@80003o603o]/4Uooooo`03o`000?oooooooooo
00oooooo00<00000ooooo`3o]/40203o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00D0okK100<00000o`00000000002`3o]/400ol000000000000000060?nf`@03o`00003o]/40okK1
00D0okK10P00000I0?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@020?nf`@0300000?l00000okK100l0okK100?o00000000003o]/400`3o]/400`00
0000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/401@3o]/400`00
0000okK1ooooo`0Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101P0
okK10P000?l90?nf`@<0003o>P3o]/400ol00?l0okK10?nf`@0B0?nf`@030000o`3o]/40okK101D0
okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100L0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@040?nf`@8000004@3o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK100H0okK100<000000?nf`@3o]/405@3o]/400ol00000okK10?nf`@040?nf`@05
0000003o]/40okK10?nf`Ol00000103o]/400`000000okK10?nf`@050?nf`@So00001@3o]/400`00
0000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@05
0?nf`@030000003o]/7ooooo02Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/405@3o]/430000o`h0okK10`000?lf0?nf`@030000o`3o]/40okK101@0okK100<0003o0?nf
`@3o]/40503o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/401P3o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/404P3o]/420000
00D0okK10P0000060?nf`@030000003o]/40okK101D0okK100<000000?nf`@3o]/400`3o]/401@00
0000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/400`3o]/43o`0000P0okK10_l00004
0?nf`@030000003o]/40okK10080okK100Go00000?nf`@3o]/40okK1000000040?nf`@030000003o
]/40okK100D0okK100<00000ooooooooool08oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?nf`@0D0?nf`@030000o`3o]/40okK10180okK10P000?lc0?nf`@030000o`3o]/40
okK101H0okK100<0003o0?nf`@3o]/404`3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000
ooooo`3o]/401@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o0000
0?nf`@3o]/401`3o]/45000000T0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK101<0okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o
]/40000000@0okK100?o00000?nf`@3o]/400P3o]/42o`0000d0okK100?o00000?nf`@3o]/400P3o
]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@040?nf`@0300000?oooooooooo02?ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/404`3o]/400`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK102l0okK100<0
003o0?nf`@3o]/40603o]/400ol00?l0okK10?nf`@0B0?nf`BGooooo00?o0000ooooooooool03ooo
ool00`00003ooooo0?nf`@050?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@050?nf`@<000001@3o]/43000000L0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK101<0okK100<000000?nf`@3o]/400`3o
]/401@000000okK10?nf`@3o]/40000000@0okK100D000000?nf`@3o]/40okK1o`00000@0?nf`@05
o`00003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
0080okK100<000000?nf`@3o]/401@3o]/400ol0003oooooooooo`0Rooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK10180okK100<0003o0?nf`@3o]/405`3o]/400`000?l0
okK10?nf`@0]0?nf`@030000o`3o]/40okK101X0okK100<0003o0?nf`@3o]/404@3o]/4Uooooo`03
o`000?oooooooooo00oooooo00<00000ooooo`3o]/40103o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/42000000/0okK10P0000060?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0B0?nf`@03
0000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/400000
00@0okK100?o00000?nf`@3o]/400`3o]/47o`0000D0okK100Go00000?nf`@3o]/40okK100000003
0?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`000000okK10?nf`@040?nf`@0300000?oo
oooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404P3o]/40
0ol00?l0okK10?nf`@0H0?nf`@030000o`3o]/40okK102`0okK100<0003o0?nf`@3o]/406P3o]/40
0`000?l0okK10?nf`@0A0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@04
0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/404@3o]/400`000000okK10?nf`@03
0?nf`@050000003o]/40okK10?nf`@000000103o]/401@000000okK10?nf`@3o]/7o000000@0okK1
0_l000070?nf`@03o`00003o]/40okK10080okK100Go00000?nf`@3o]/40okK1000000030?nf`@03
0000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@03
00000?oooooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
4@3o]/400`000?l0okK10?nf`@0J0?nf`@030000o`3o]/40okK102X0okK100<0003o0?nf`@3o]/40
6`3o]/400`000?l0okK10?nf`@0A0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo
0?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@030?nf`@8000004@3o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40okK10080okK1
00H000000?nf`@3o]/40okK1o`00000000030?nf`@050000003o]/40okK10?nf`Ol00000103o]/40
0ol00000okK10?nf`@080?nf`@03o`00003o]/40okK10080okK100Go00000?nf`@3o]/40okK10000
00030?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@040?nf`@030000
0?oooooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40403o
]/400`000?l0okK10?nf`@0K0?nf`@030000o`3o]/40okK102X0okK100<0003o0?nf`@3o]/40703o
]/400`000?l0okK10?nf`@0@0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf
`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10180okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40403o]/400`000000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/400ol00000okK10?nf`@020?nf`@05o`00
003o]/40okK10?nf`Ol00000303o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100D000000?nf
`@3o]/40okK1000000030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/40
0`00003oooooooooo`0Rooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
00l0okK100<0003o0?nf`@3o]/407@3o]/400`000?l0okK10?nf`@0Y0?nf`@030000o`3o]/40okK1
01`0okK100<0003o0?nf`@3o]/40403o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000oooo
o`3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@[o00001P3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0>0?nf
`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40
okK10?nf`Ol000000`3o]/400ol00000okK10?nf`@0<0?nf`@05o`00003o]/40okK10?nf`Ol00000
0`3o]/401@000000okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@030?nf`@03ooooo`00003ooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/403P3o]/400`000?l0okK10?nf`@0N0?nf`@030000o`3o]/40okK102P0okK1
00<0003o0?nf`@3o]/407@3o]/400`000?l0okK10?nf`@0@0?nf`BGooooo00?o0000ooooooooool0
3oooool00`00003ooooo0?nf`@020?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o]/40
203o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK10080okK100?o00000000003o]/40
0`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/40
0`3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1o`0000030?nf
`@03o`00003o]/40okK100h0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@050000003o]/40
okK10?nf`@0000000`3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100?o
oooo00000?ooool08_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0>
0?nf`@030000o`3o]/40okK101h0okK100<0003o0?nf`@3o]/40:03o]/400`000?l0okK10?nf`@0M
0?nf`@030000o`3o]/40okK10100okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0
okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@090?nf`@03o`00003o]/40
okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@030?nf`@050000003o]/40
okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`@3o]/40
3P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100D000000?nf`@3o]/40okK1000000030?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400oooool00000ooooo`0Roooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100h0okK100<0003o0?nf`@3o
]/407`3o]/400`000?l0okK10?nf`@0W0?nf`@030000o`3o]/40okK100`0okK10ol0000>0?nf`@03
0000o`3o]/40okK10100okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@0;0?nf`@03o`00003o]/40okK100<0
okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@030?nf`@050000003o]/40okK10?nf
`@0000000P3o]/401@000000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`@3o]/40103o]/42
o`0000P0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@050000003o]/40okK10?nf`@000000
0`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100?ooooo00000?ooool0
8_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@030000o`3o
]/40okK10200okK100<0003o0?nf`@3o]/409`3o]/400`000?l0okK10?nf`@0;0?nf`@Go00003P3o
]/400`000?l0okK10?nf`@0?0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf
`@3o]/40000000D0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK100<0okK100?o00000?nf`@3o]/40303o]/400ol00000okK10?nf`@030?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK100d0okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0
okK100D000000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK100@0okK100?o00000?nf
`Ol000001`3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100@000000?nf`@3o]/4000000`3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100?ooooo00000?ooool08_oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@030000o`3o]/40
okK10200okK100<0003o0?nf`@3o]/409`3o]/400`000?l0okK10?nf`@0;0?nf`@Go00003P3o]/40
0`000?l0okK10?nf`@0?0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o
]/40000000D0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK10080okK100?o00000?nf`@3o]/403P3o]/400ol00000okK10?nf`@030?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100d0okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK1
00D000000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK100@0okK11?l000060?nf`@05
o`00003o]/40okK10?nf`Ol000000`3o]/4010000000okK10?nf`@0000030?nf`@03o`00003o]/40
okK10080okK100<000000?nf`@3o]/400`3o]/400oooool00000ooooo`0Rooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100d0okK100<0003o0?nf`@3o]/408@3o]/400`00
0?l0okK10?nf`@0V0?nf`@030000o`3o]/40okK100/0okK11Ol0000>0?nf`@030000o`3o]/40okK1
00l0okK19Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000001@3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/40
0ol00000okK10?nf`@0>0?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/403@3o]/40
0`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf
`@3o]/7o000000<0okK100?o00000?nf`@3o]/403P3o]/401Ol00000okK10?nf`@3o]/7o000000<0
okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
00<0okK100?ooooo00000?ooool08_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0=0?nf`@030000o`3o]/40okK100h0okK10ol0000@0?nf`@030000o`3o]/40okK102H0
okK100<0003o0?nf`@3o]/40303o]/43o`0000l0okK100<0003o0?nf`@3o]/403`3o]/4Uooooo`03
o`000?oooooooooo00oooooo00D00000ooooo`3o]/40okK1000000050?nf`@050000003o]/40okK1
0?nf`@000000103o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK10100okK100?o0000
0?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@0<0?nf`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1
000000020?nf`@050000003o]/40okK10?nf`Ol000000`3o]/400ol00000okK10?nf`@0=0?nf`@03
o`00003o]/40okK10080okK100Co00000?nf`@3o]/4000000`3o]/401@000000okK10?nf`@3o]/40
000000<0okK100<000000?nf`@3o]/40103o]/400oooool00000ooooo`0Rooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100d0okK100<0003o0?nf`@3o]/403@3o]/45o`00
00l0okK100<0003o0?nf`@3o]/409P3o]/400`000?l0okK10?nf`@0N0?nf`@030000o`3o]/40okK1
00l0okK19Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000001@3o]/40
1@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf
`@0@0?nf`@03o`00003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000040?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf`@030?nf`@050000
003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/7o000000<0okK100?o00000?nf
`@3o]/403@3o]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40okK1000000<0okK100D00000
0?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK100@0okK100?ooooo00000?ooool08_oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@030000o`3o]/40
okK100d0okK11Ol0000?0?nf`@030000o`3o]/40okK102L0okK100<0003o0?nf`@3o]/40703o]/40
0`000?l0okK10?nf`@0@0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o
]/40000000D0okK100D000000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK10080okK1
00?o00000?nf`@3o]/40403o]/400ol00000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@00
0000103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100`0okK100?o00000?nf`@3o
]/400`3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1o`000004
0?nf`@03o`00003o]/40okK100`0okK100?o00000?nf`@3o]/400P3o]/401?l00000okK10?nf`@00
00030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@040?nf`@03oooo
o`00003ooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o
]/400`000?l0okK10?nf`@0=0?nf`@Go00003`3o]/400`000?l0okK10?nf`@0W0?nf`@030000o`3o
]/40okK101`0okK100<0003o0?nf`@3o]/40403o]/4Uooooo`03o`000?oooooooooo00oooooo00D0
0000ooooo`3o]/40okK1000000050?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000
okK10?nf`@020?nf`@03o`00003o]/40okK10100okK100?o00000?nf`@3o]/400`3o]/401@000000
okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0<0?nf
`@030000003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40
okK10?nf`Ol00000103o]/400ol00000okK10?nf`@0:0?nf`@03o`00003o]/40okK10080okK100Go
00000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000
okK10?nf`@040?nf`@03ooooo`00003ooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/403@3o]/400`000?l0okK10?nf`@0>0?nf`@?o0000403o]/400`000?l0okK1
0?nf`@0W0?nf`@030000o`3o]/40okK101`0okK100<0003o0?nf`@3o]/40403o]/4Uooooo`03o`00
0?oooooooooo00oooooo00D00000ooooo`3o]/40okK1000000050?nf`@030000003o]/40okK10080
okK100D000000?nf`@3o]/40okK1000000050?nf`@03o`00003o]/40okK100l0okK100?o00000?nf
`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK100<0okK100@000000?nf
`@3o]/4000000`3o]/401@000000okK10?nf`@3o]/7o000000D0okK100?o00000?nf`@3o]/40203o
]/400ol00000okK10?nf`@030?nf`@04o`00003o]/40okK1000000<0okK100D000000?nf`@3o]/40
okK1000000040?nf`@030000003o]/40okK100@0okK100<00000ooooooooool08_ooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@030000o`3o]/40okK10240okK1
00<0003o0?nf`@3o]/40:03o]/400`000?l0okK10?nf`@0J0?nf`@030000o`3o]/40okK10140okK1
9Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000001@3o]/400`000000
okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400ol00000okK10?nf`@0?0?nf
`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100<0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@030?nf
`@050000003o]/40okK10?nf`Ol000000`3o]/401@000000okK10?nf`@3o]/7o000000D0okK10ol0
00050?nf`@;o00001@3o]/401Ol00000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40
okK1000000040?nf`@03o`00003o]/40okK100@0okK100<00000ooooooooool08_ooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@030000o`3o]/40okK10200okK1
00<0003o0?nf`@3o]/40:@3o]/400`000?l0okK10?nf`@0J0?nf`@030000o`3o]/40okK10140okK1
9Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000001@3o]/400`000000
okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/400P3o]/400ol00000
okK10?nf`@0?0?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/403P3o]/400`000000
okK10?nf`@030?nf`@05o`00003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@020?nf
`@03o`00003o]/40okK100D0okK11Ol000050?nf`@;o00000`3o]/400`000000okK10?nf`@020?nf
`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@040?nf`@0300000?oooooo
oooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403P3o]/400`00
0?l0okK10?nf`@0O0?nf`@030000o`3o]/40okK102X0okK100<0003o0?nf`@3o]/40603o]/400ol0
0?l0okK10?nf`@0B0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/403@3o]/400ol00000okK10?nf`@030?nf
`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100l0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40
okK10?nf`@000000103o]/42o`0000h0okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`000000okK10?nf`@040?nf`@030000
0?oooooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403P3o
]/400`000?l0okK10?nf`@0O0?nf`@030000o`3o]/40okK102/0okK100<0003o0?nf`@3o]/405@3o
]/420000oaD0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@0;0?nf`@;o00001@3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@0?0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf
`@3o]/40000000D0okK10_l0000;0?nf`@03o`00003o]/40okK100<0okK100D000000?nf`@3o]/40
okK1000000030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400ol0003o
ooooooooo`0Sooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100h0okK1
00<0003o0?nf`@3o]/407`3o]/400`000?l0okK10?nf`@0/0?nf`@030000o`3o]/40okK101<0okK1
00<0003o0?nf`@3o]/405@3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@040?nf`@;o00002P3o]/400ol00000okK10?nf`@050?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100l0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK100?o00000000003o]/40103o]/43o`0000H0okK10_l000050?nf`@030000
003o]/40okK10080okK100D000000?nf`@3o]/40okK1000000050?nf`@030000003o]/40okK100@0
okK100<00000ooooooooool08oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0?0?nf`@030000o`3o]/40okK101d0okK100<0003o0?nf`@3o]/40;P3o]/400`000?l0okK1
0?nf`@0A0?nf`@030000o`3o]/40okK101H0okK19Oooool00ol0003oooooooooo`0?ooooo`030000
0?ooool0okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@060?nf`@03o`00
003o]/40okK100D0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/404@3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@Ko0000
1P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000001@3o]/400`000000
okK10?nf`@050?nf`@0300000?oooooooooo02?ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/403`3o]/400`000?l0okK10?nf`@0M0?nf`@030000o`3o]/40okK102l0okK1
0P000?l?0?nf`@80003o6@3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@060?nf`@;o0000103o]/42o`0000P0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
4@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@0>0?nf`@800000103o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK1ooooo`0Tooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100l0okK100<0003o0?nf`@3o]/407@3o
]/400`000?l0okK10?nf`@0a0?nf`@030000o`3o]/40okK100/0okK100<0003o0?nf`@3o]/406@3o
]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/400`3o]/400`000000okK10?nf
`@070?nf`@Co0000203o]/400`00003o00000?nf`@040?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@0C0?nf`@030000003o]/40okK100<0okK10P00
00040?nf`@800000103o]/400ol0000000000000000;0?nf`@800000103o]/400`00003o00000?nf
`@030?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/401@3o]/400`000000okK1oooo
o`0Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10100okK100<0003o
0?nf`@3o]/406P3o]/420000ocD0okK100<0003oo`00o`000?l00P000?l40?nf`@<0003o00?o003o
0?nf`@3o]/406P3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@0A0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@03o`00003o]/40okK101@0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@030?nf`@8000001@3o]/4300000080okK11P0000050?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@060?nf`@030000003o]/7o
oooo02Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404@3o]/400`00
0?l0okK10?nf`@0H0?nf`@030000o`3o]/40okK103X0okK110000?lP0?nf`BGooooo00?o0000oooo
ooooool03oooool00`00003ooooo0?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100l0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/405@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/401@3o]/42000000X0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf
`@030000003o]/40okK100H0okK100<000000?nf`@3o]/409Oooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@0B0?nf`@80003o5`3o]/400`000?l0okK10?nf`@1O0?nf`BGo
oooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@030?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100`0
okK10P0000060?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/40103o]/400`000000
okK10?nf`@0G0?nf`@030000003o]/40okK100@0okK10P0000050?nf`@8000003P3o]/4200000003
o`00003o]/40okK10080okK10P0000050?nf`@030000003o]/40okK100H0okK100@000000?nf`@3o
]/40okK19Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0D0?nf`@03
0000o`3o]/40okK100/0okK12?ooool00`000?ooooooooooo`25ooooo`03o`000?oooooooooo00oo
oooo00<00000ooooo`3o]/400`3o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK10080
okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@080?nf`@03ooooo`000000000000Oo
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`04ooooo`8000002Oooool3000000Ko
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo02Ko
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/405@3o]/400`000?l0okK1
0?nf`@0:0?nf`@Kooooo0P000?n8ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/40
0`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
1@3o]/43000000H0okK10P000008ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
1Oooool9000000Oooooo0P000006ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
9oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0F0?nf`@03o`00o`00
0?l0okK100T0okK11?ooool20000oh[ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf
`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@070?nf`@H0000000<0okK1ooooooooool01_ooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool02Oooool6000000_ooooo00<00000ooooooooool01_oo
ool2000001Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo02Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40603o]/43
0000o`L0okK10oooool00`000?ooooooooooo`2:ooooo`03o`000?oooooooooo00oooooo00<00000
ooooo`3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100?o0000
0?nf`@3o]/403P3o]/46ooooo`8000001_ooool00`00003oooooooooo`05ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool01?ooool2000000[ooooo00<00000o`00000000001oooool0
0`00003oooooooooo`0>ooooo`<000001oooool2000000Wooooo00<00000ooooooooool0:?ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0K0?nf`@X0003oSOooool00ol0
003oooooooooo`0?ooooo`0300000?ooool0okK100@0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100h0okK11Oooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool02Oooool00`00003oooooooooo`07oooo
o`8000002oooool00`00003oooooooooo`05ooooo`03o`0000000000000000[ooooo0`000008oooo
o`8000002_ooool00ol0003oooooooooo`0Yooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100@0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100d0
okK10oooool2000000Oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`08ooooo`80
00003?ooool00`00003oooooooooo`09ooooo`8000002?ooool:000000[ooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100@0okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100d0okK1
0_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
2?ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0P00000Iooooo`03o`00
0?oooooooooo00Wooooo00<00000ooooooooool0:oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf
`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@0=0?nf`@03ooooo`00003ooooo00Oooooo00<00000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`0300000?oooooooooo00gooooo0P00000=ooooo`8000005Oooool2000000_ooooo00<0
0000ooooooooool0;?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R
0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@040?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0=0?nf`@0300000?oooooo
oooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`08ooooo`0300000?oooooo
oooo013ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0>ooooo`@000003?ooool0
0`00003oooooooooo`0]ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
0280okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100<0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100d0okK100<00000oooo
ooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Wooooo00<00000oooo
ooooool04Oooool00`00003oooooooooo`0<ooooo`L000001_ooool3000000oooooo00<00000oooo
ooooool0;_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3o
oooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@030?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0<0?nf`@030000003o]/7ooooo00Ko
oooo00<00000ooooooooool01Oooool2000000_ooooo00?o0000ooooooooool04oooool2000001?o
oooo1P00000@ooooo`800000<Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@030?nf`@030000
003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@0<0?nf`@030000
003o]/7ooooo00Kooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo01Gooooo00<00000ooooooooool09Oooool00`00003oooooooooo`0aooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003ooooooooo
o`0?ooooo`0300000?ooool0okK10080okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK100`0okK100<000000?nf`@3o]/401_ooool00`00003ooooooooo
o`05ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool05oooool2000002Gooooo00<0
0000ooooooooool0<Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R
0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0=0?nf`@030000003o]/40
okK100Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo01[ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?oooo
o`0300000?ooool0okK10080okK100?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf
`@03o`0000000000okK100l0okK100?o00000?nf`@3o]/401?ooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool07?ooool01?l00000000000000000000N
ooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40403o]/400`00
0000okK10?nf`@04ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00`00
003oooooooooo`0Pooooo`8000006oooool00ol0003oooooooooo`0dooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`05
00000?ooool0okK10?nf`@000000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
00D0okK1100000080?nf`@030000003o]/40okK100?ooooo00<00000ooooooooool01Oooool00`00
003oooooooooo`0:ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool05oooool00`00
003oooooooooo`0eooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280
okK1T?ooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK1000000@0okK100?o00000?nf
`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@<00000103o]/42000000H0okK100<000000?nf
`@3o]/400oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00[ooooo00<00000oooo
ooooool09Oooool00ol000000000ooooo`0Eooooo`0300000?oooooooooo03Kooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oo
oooo00@00000ooooo`3o]/400000103o]/400`000000okK10?nf`@020?nf`@04o`00003o]/40okK1
0?nf`@8000002@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100?ooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02Oooooo00<00000
ooooooooool04oooool00`00003oooooooooo`0fooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK10100okK11@000?l=0?nf`I3ooooo00?o0000ooooooooool03oooool00`00
003ooooo000000040?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK10000000<
0?nf`@030000003o]/40okK100<0okK100<000000?nf`Oooool00_ooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0B
ooooo`0300000?oooooooooo03Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/40303o]/4010000?oo003o0000o`000?l50?nf`@040000ool00?l0003o0000o`T0okK1T?oo
ool00ol0003oooooooooo`0?ooooo`0300000?ooool0000000@0okK100D000000?nf`@3o]/40okK1
000000030?nf`@030000003o]/40okK100`0okK100?o00000?nf`@3o]/400P3o]/400`000000okK1
ooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0Yooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0=Oooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0;0?nf`@030000o`3o]/40okK100/0okK10P00
0?l70?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@030?nf`@050000003o
]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@020?nf`@L000001@3o]/400`000000okK1
0?nf`@020?nf`@0500000?ooooooooooooooo`0000001Oooool00`00003oooooooooo`0;ooooo`80
0000:oooool00`00003oooooooooo`0Aooooo`0300000?l00000000003Gooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/402P3o]/400`000?l0okK10?nf`@0>0?nf`@030000
o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK1
00Go00000?nf`@3o]/40okK1o`0000040?nf`@030000003o]/40okK1008000001`3o]/42000000<0
okK100<000000?nf`@3o]/400P3o]/401@00003oooooooooooooool0000000Gooooo00<00000oooo
ooooool03Oooool7000002Cooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0boooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100T0okK100<0003o0?nf`@3o
]/403`3o]/400`000?l0okK10?nf`@040?nf`I3ooooo00?o0000ooooooooool03oooool00`00003o
oooo0?nf`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/4200000080okK100?o00000?nf
`@3o]/402@3o]/401@000000okK10?nf`@3o]/40000000@0okK100D00000oooooooooooooooo0000
0004ooooo`0300000?oooooooooo01Cooooo1`00000Looooo`0300000?oooooooooo01Kooooo0P00
000booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100P0okK100<0003o
0?nf`@3o]/404@3o]/400`000?l0okK10?nf`@030?nf`I3ooooo00?o0000ooooooooool03oooool0
0`00003ooooo0?nf`@020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1
o`00000=0?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@00003oooooooooooooool00000
00Cooooo00<00000ooooooooool06oooool400000003o`000000003ooooo01Cooooo00<00000oooo
ooooool06Oooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100P0okK100?o003o0?nf`@3o]/404P3o]/400`000?l0okK10?nf`@020?nf`I3o
oooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@040000003o]/40okK10000
0080okK100D000000?nf`@3o]/40okK1000000040?nf`@Go0000103o]/401@000000okK10?nf`@3o
]/40000000<0okK100D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo027ooooo
00<00000ooooooooool04Oooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo02kooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf
`@0B0?nf`@030000o`3o]/40okK10080okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?oo
ool0okK10080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000040?nf`@03
o`00003o]/40okK100<0okK10_l000030?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@00
003oooooooooooooool0000000Cooooo00<00000ooooooooool08_ooool3000000kooooo0P00000O
ooooo`0300000?oooooooooo02gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/401`3o]/400`000?l0okK10?nf`@0D0?nf`@040000o`3o]/40okK10?nf`I3ooooo00?o0000
ooooooooool03oooool01@00003ooooo0?nf`@3o]/4000000080okK100@000000?nf`@3o]/400000
0`3o]/401@000000okK10?nf`@3o]/7o000000P0okK100Co00000?nf`@3o]/4000000`3o]/401000
0000okK10?nf`Ol00003ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool09Oooool2
000000_ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0/ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/40503o]/401000
0?l0okK10?nf`@3o]/6@ooooo`03o`000?oooooooooo00oooooo00D00000ooooo`3o]/40okK10000
00020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1o`0000090?nf`@05
o`00003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@000003ooooo`03o`000?oooooo
oooo00;ooooo00<00000ooooooooool09oooool00ol000000000ooooo`05ooooo`<000003oooool;
000000[ooooo0P00000/ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
00H0okK100<0003o0?nf`@3o]/405P3o]/400`000?l0okK10?nf`@2@ooooo`03o`000?oooooooooo
00oooooo00D00000ooooo`3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100@0
00000?nf`@3o]/7o00002P3o]/401Ol00000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o
]/4000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo2000000>oooo
o`H000003_ooool4000000_ooooo0`000009ooooo`0300000?oooooooooo02Wooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@080?nf`@?o
00002`3o]/400`000?l0okK10?nf`@2@ooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o
]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`Ol000002`3o
]/401Ol00000okK10?nf`@3o]/4000000080okK100@000000?nf`Oooool000000_ooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo00cooooo1`000008ooooo`<000007?ooool3000001;o
oooo00<00000ooooooooool01oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o]/401`3o]/45o`0000X0okK1
00<0003o0?nf`@3o]/40T?ooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK100000080
okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`Ol0000=0?nf`@04o`00003o]/40
okK100000080okK100@000000?nf`Oooool000000_ooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00_ooooo00?o0000ooooooooool04?ooool200000003o`000?oooooooooo01Kooooo
00?o0000ooooooooool05?ooool00`00003o000000000007ooooo`0300000?oooooooooo02Oooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf
`@070?nf`@Go00002P3o]/400`000?l0okK10?nf`@2@ooooo`03o`000?oooooooooo00oooooo00@0
0000ooooo`3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1o`00
00H0okK10_l000050?nf`@04o`00003o]/40okK100000080okK100@000000?nf`Oooool000000_oo
ool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Wooooo0P00000Fooooo`0300000?oo
oooooooo01?ooooo0P000008ooooo`X000002?ooool00`00003oooooooooo`05ooooo`03o`000?oo
oooooooo02Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/40
0`000?l0okK10?nf`@070?nf`@Go00002P3o]/400`000?l0okK10?nf`@2@ooooo`03o`000?oooooo
oooo00oooooo00@00000ooooo`3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000
003o]/40okK1o`0000D0okK100?o00000?nf`Ol000001@3o]/401?l00000okK10?nf`@0000020?nf
`@040000003o]/7ooooo000000;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`06
ooooo`8000001oooool;000000Oooooo0P00000Booooo`0300000?oooooooooo00Gooooo0`00000:
ooooo`8000001oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02Kooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@080?nf
`@?o00002`3o]/400`000?l0okK10?nf`@2@ooooo`03o`000?oooooooooo00oooooo00@00000oooo
o`3o]/4000000P3o]/401P000000okK10?nf`@000000okK100000080okK100?o00000?nf`@3o]/40
0`3o]/401Ol00000okK10?nf`@3o]/7o000000@0okK100Co00000?nf`@3o]/4000000P3o]/401000
0000okK1ooooo`000003ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00oooool2
000000Oooooo0P00000;ooooo`<000001_ooool2000000oooooo00<00000ooooooooool01?ooool2
000000oooooo0P000005ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool09Oooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40okK1
01H0okK100<0003o0?nf`@3o]/40T?ooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK1
00000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@03o`00003o]/40okK10080okK1
00?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40okK100000080
okK100@000000?nf`Oooool000000oooool00`00003oooooooooo`04ooooo`03o`00000000000000
008000001oooool20000013ooooo00<00000o`00000000001Oooool2000000_ooooo0P000005oooo
o`8000001Oooool8000000Kooooo00<00000ooooooooool00oooool2000000Kooooo00<00000oooo
ooooool09?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@03
0000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/40J`3o]/4Uooooo`03o`000?oooooooooo00oo
oooo00@00000ooooo`3o]/4000000P3o]/401P000000okK10?nf`@000000okK100000080okK100?o
00000?nf`@3o]/400`3o]/401Ol00000okK10?nf`@3o]/7o000000@0okK100Co00000?nf`@3o]/40
00000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK100l0okK100<000000?nf
`@3o]/401@3o]/48000000H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@070?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf
`@<00000103o]/400ol0000000000?nf`@040?nf`@030000003o]/40okK100@0okK100<00000oooo
ooooool08oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@070?nf`@03
0000o`3o]/40okK101@0okK100<0003o0?nf`@3o]/40K03o]/4Uooooo`03o`000?oooooooooo00oo
oooo00@00000ooooo`3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40
okK1o`0000@0okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@07o`00003o]/40okK10?nf`@00
0000okK1000000030?nf`@040000003o]/40okK1000000l0okK10P0000040?nf`@@00000203o]/43
000000@0okK10P0000050?nf`@<000000`3o]/43000000D0okK10P0000040?nf`@<00000303o]/43
000000<0okK10P0000040?nf`@030000003o]/40okK100@0okK100<00000ooooooooool08_ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o]/40okK1
01@0okK100<0003o0?nf`@3o]/408P3o]/430000ob`0okK110000?lG0?nf`BGooooo00?o0000oooo
ooooool03oooool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK100000080okK100@0
00000?nf`@3o]/7o0000103o]/42o`000080okK100?o00000?nf`@3o]/400P3o]/401ol00000okK1
0?nf`@3o]/4000000?nf`@0000000`3o]/4010000000okK10?nf`@00000>0?nf`@030000003o]/40
okK10080okK10P00000?0?nf`@0300000?l00000okK100<0okK100<000000?nf`@3o]/401@3o]/43
000000L0okK100<000000?nf`@3o]/400P3o]/42000000@0okK100<00000o`00000000001@000000
0ol00000okK10?nf`@030?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1o`00
00060?nf`@03o`000?oooooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0D0?nf`@030000o`3o]/40okK101h0okK100@0003o
o`00o`000?l0003o0`3o]/450000ob<0okK100@0003oo`00o`000?l0003o103o]/4010000?oo003o
0000o`000?lC0?nf`BGooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000020?nf
`@040000003o]/40okK1o`000080okK100@000000?nf`@3o]/7o00001P3o]/400ol00000okK1o`00
00040?nf`@07o`00003o]/40okK10?nf`@000000okK1000000030?nf`@040000003o]/40okK10000
00d0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@P00000103o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/400P3o]/400ol0
0000okK10?nf`@020?nf`@030000003o]/40okK100H0okK10`0000030?nf`@030000003o]/40okK1
0080okK100Go00000?nf`@3o]/40okK1000000060?nf`@0300000?oooooooooo02;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400ol00?l0003o0?nf`@0B0?nf
`@030000o`3o]/40okK101d0okK10P000?l<0?nf`@030000o`3o]/40okK101h0okK10P000?l<0?nf
`@80003o4@3o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o]/40
10000000okK10?nf`@0000020?nf`@040000003o]/40okK1o`0000L0okK100?o00000?nf`@3o]/40
0`3o]/401ol00000okK10?nf`@3o]/4000000?nf`@0000000`3o]/4010000000okK10?nf`@00000<
0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/43000000P0okK10P000003
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf`@02
0?nf`@040000003o]/40okK10?nf`@800000303o]/4200000080okK10P0000020?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400`3o]/400oooool00000ooooo`0Rooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK100X0okK100<0003o0?nf`@3o]/403`3o]/40
0`000?l0okK10?nf`@0M0?nf`@030000o`3o]/40okK100d0okK100<0003o0?nf`@3o]/40703o]/40
0`000?l0okK10?nf`@0>0?nf`@030000o`3o]/40okK100h0okK19Oooool00ol0003oooooooooo`0?
ooooo`0400000?ooool0okK100000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK1
0?nf`Ol0000>0?nf`@04o`00003o]/40okK100000080okK100@000000?nf`@3o]/4000000`3o]/40
0`000000okK10?nf`@080?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/40okK10P00
000=0?nf`@8000000P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100/0okK100?o
00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000@0okK11ol000050?nf`@050000
003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000D0okK100?ooooo0000
0?ooool08_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0;0?nf`@03
0000o`3o]/40okK100`0okK10P000?lO0?nf`@030000o`3o]/40okK100l0okK100<0003o0?nf`@3o
]/406P3o]/400`000?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100d0okK19Oooool00ol0003o
ooooooooo`0?ooooo`0400000?ooool0okK100000080okK100@000000?nf`@3o]/4000000P3o]/40
10000000okK10?nf`Ol0000>0?nf`@04o`00003o]/40okK100000080okK100@000000?nf`@3o]/40
00000`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK10080okK100Go00000?nf`@3o
]/40okK1000000040?nf`@Wo0000103o]/401@000000okK10?nf`Ol00000000000<0okK100<00000
0?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/4000000080okK100?o00000000003o]/400P3o
]/42o`0000L0okK10ol000030?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK1
0?nf`@3o]/40000000@0okK10_ooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK100`0okK100<0003o0?nf`@3o]/40203o]/430000ob00okK1
00<0003o0?nf`@3o]/404@3o]/400`000?l0okK10?nf`@0H0?nf`@03o`00o`3o]/40okK10180okK1
00<0003o0?nf`@3o]/40303o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/40
00000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1o`0000h0okK100Co0000
0?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK100H0okK1
00<000000?nf`@3o]/400`3o]/4010000000okK10?nf`@0000030?nf`@;o00002@3o]/42o`000080
okK100D000000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100P0okK100D000000?nf
`@3o]/40okK1000000030?nf`@030000003o]/40okK100;o0000303o]/401?l00000okK10?nf`@00
00030?nf`@040000003o]/40okK1000000@0okK100Co00000?nf`@3o]/40okK10_ooool00`00003o
ooooooooo`0Pooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100d0okK1
00Co003o0000o`000?l0003o0`3o]/430000ob<0okK100<0003o0?nf`@3o]/404@3o]/400`000?l0
okK10?nf`@0H0?nf`@030000o`3o]/40okK10180okK100<0003o0?nf`@3o]/40303o]/4Uooooo`03
o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o]/4010000000okK10?nf`@000002
0?nf`@040000003o]/40okK1o`0000H0okK10_l000060?nf`@04o`00003o]/40okK1000000<0okK1
00@000000?nf`@3o]/4000000`3o]/42000000D0okK100?o00000?nf`@3o]/400`3o]/4010000000
okK10?nf`@0000030?nf`@03o`00003o]/40okK100/0okK100Co00000?nf`@3o]/4000000`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100H0okK100D000000?nf`@3o]/40okK10000
00030?nf`@040000003o]/40okK1o`0000H0okK11Ol000040?nf`@04o`00003o]/40okK1o`0000<0
okK100Co00000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@3o]/43ooooo`0300000?oooooo
oooo01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404@3o]/430000
obD0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0F0?nf`@030000o`3o]/40okK1
01@0okK100<0003o0?nf`@3o]/402`3o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000oooo
o`3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1o`0000D0okK1
00Co00000?nf`@3o]/7o00001@3o]/401?l00000okK10?nf`@0000030?nf`@040000003o]/40okK1
000000D0okK10P0000000`3o]/400000000000050?nf`@040000003o]/40okK1000000<0okK100?o
00000?nf`@3o]/400P3o]/47o`0000@0okK100Co00000?nf`@3o]/4000000`3o]/400`000000okK1
0?nf`@020?nf`@03o`0000000000okK10080okK10P0000001Ol00000okK10?nf`@3o]/40000000<0
okK100@000000?nf`@3o]/7o0000103o]/43o`0000D0okK10_l000030?nf`@04o`00003o]/40okK1
00000080okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK100?ooooo00<0
0000ooooooooool07oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0i
0?nf`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/405P3o]/400`000?l0okK10?nf`@0D
0?nf`@030000o`3o]/40okK100/0okK19Oooool00ol0003oooooooooo`0?ooooo`0400000?ooool0
okK100000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`Ol000050?nf`@04
o`00003o]/40okK1o`0000D0okK100Co00000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@00
00070?nf`@030000003o]/40okK100D0okK100@000000?nf`@3o]/4000000`3o]/401Ol00000okK1
0?nf`@3o]/7o000000H0okK100?o00000?nf`@3o]/400P3o]/401?l00000okK10?nf`@0000030?nf
`@030000003o]/40okK100@0okK100<000000?nf`@0000001P3o]/401@000000okK10?nf`@3o]/40
00000080okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@060?nf`@05o`00003o]/40
okK10?nf`Ol000000P3o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf`@00
00000P3o]/43ooooo`0300000?oooooooooo01oooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/40>@3o]/400`000?l0okK10?nf`@0C0?nf`@030000o`3o]/40okK101H0okK1
00<0003o0?nf`@3o]/40503o]/400`000?l0okK10?nf`@0;0?nf`BGooooo00?o0000ooooooooool0
3oooool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK100000080okK100@000000?nf
`@3o]/7o0000103o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100Go0000
0?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000003@3o]/401@000000okK1
0?nf`@3o]/4000000080okK100Go00000?nf`@3o]/40okK1o`0000080?nf`@03o`00003o]/40okK1
0080okK100Co00000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100D0okK100L000000?nf`@3o]/40okK10000003o]/7o000000@0okK100?o00000?nf`@3o]/40
203o]/401Ol00000okK10?nf`@3o]/7o00000080okK100<000000?nf`@0000000`3o]/401@000000
okK10?nf`@3o]/4000000080okK10oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK103P0okK100<0003o0?nf`@3o]/405@3o]/400`000?l0
okK10?nf`@0D0?nf`@030000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/402P3o]/4Uooooo`03
o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o]/4010000000okK10?nf`@000002
0?nf`@040000003o]/40okK1o`0000<0okK10_l000050?nf`@03o`00003o]/40okK10080okK100Co
00000?nf`@3o]/4000000P3o]/401Ol00000okK10?nf`@3o]/7o000000d0okK100D000000?nf`@3o
]/40okK1000000020?nf`@05o`00003o]/40okK10?nf`Ol000002@3o]/401Ol00000okK10?nf`@3o
]/7o00000080okK100Go00000?nf`@3o]/40okK1o`00000=0?nf`@050000003o]/40okK10?nf`@00
00000P3o]/401Ol00000okK10?nf`@3o]/7o000000`0okK100Co00000?nf`@3o]/7o00000P3o]/40
10000000okK10?nf`@0000030?nf`@040000003o]/40okK100000080okK10oooool00`00003ooooo
ooooo`0Oooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103P0okK100<0
003o0?nf`@3o]/40203o]/43o`0000X0okK100<0003o0?nf`@3o]/40503o]/400`000?l0okK10?nf
`@0F0?nf`@030000o`3o]/40okK100X0okK19Oooool00ol0003oooooooooo`0?ooooo`0400000?oo
ool0okK100000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`Ol000020?nf
`@03o`00003o]/40okK100H0okK10_l000030?nf`@04o`00003o]/40okK100000080okK100@00000
0?nf`@3o]/4000003@3o]/4010000000okK10?nf`@0000020?nf`@05o`00003o]/40okK10?nf`Ol0
00002`3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100@000000?nf`@3o]/4000003@3o]/40
1@000000okK10?nf`@3o]/4000000080okK100Co00000?nf`@3o]/7o00001@3o]/43o`0000H0okK1
00Co00000?nf`@3o]/7o00000P3o]/400`000000okK1000000030?nf`@040000003o]/40okK10000
0080okK10oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK103P0okK100<0003o0?nf`@3o]/401`3o]/45o`0000T0okK100<0003o0?nf`@3o
]/40503o]/400`000?l0okK10?nf`@080?nf`@?o00002`3o]/400`000?l0okK10?nf`@0:0?nf`BGo
oooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK1
o`000080okK100@000000?nf`@3o]/7o00000P3o]/400ol00000okK10?nf`@070?nf`@05o`00003o
]/40okK10?nf`Ol000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK100/0
okK100@000000?nf`@3o]/4000000P3o]/401Ol00000okK10?nf`@3o]/7o000000/0okK100Go0000
0?nf`@3o]/40okK1o`0000020?nf`@040000003o]/40okK1000000d0okK100D000000?nf`@3o]/40
okK1000000020?nf`@04o`00003o]/40okK1o`0000D0okK100?o00000?nf`Ol000001P3o]/401?l0
0000okK10?nf`Ol000020?nf`@030000003o]/40000000<0okK100@000000?nf`@3o]/4000000P3o
]/43ooooo`0300000?oooooooooo01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/404@3o]/490000oad0okK100<0003o0?nf`@3o]/40203o]/45o`0000X0okK100<0003o
0?nf`@3o]/404P3o]/400`000?l0okK10?nf`@080?nf`@Go00002`3o]/400`000?l0okK10?nf`@09
0?nf`BGooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@040000003o
]/40okK100000080okK100H000000?nf`@3o]/7o00000?nf`Ol0000;0?nf`@05o`00003o]/40okK1
0?nf`Ol000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK100X0okK100@0
00000?nf`@3o]/4000000P3o]/401Ol00000okK10?nf`@3o]/7o000000/0okK100Go00000?nf`@3o
]/40okK1o`0000020?nf`@040000003o]/40okK1000000d0okK100D000000?nf`@3o]/40okK10000
00020?nf`@04o`00003o]/40okK1o`0000D0okK100Co00000?nf`@3o]/7o00001@3o]/401?l00000
okK10?nf`Ol000020?nf`@030000003o]/40000000<0okK100@000000?nf`@3o]/4000000P3o]/43
ooooo`0300000?oooooooooo01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/40403o]/400`000?l0okK10?nf`@070?nf`@030000ool00?l0okK101X0okK100<0003o0?nf
`@3o]/40203o]/45o`0000X0okK100<0003o0?nf`@3o]/404P3o]/400`000?l0okK10?nf`@080?nf
`@Go00002`3o]/400`000?l0okK10?nf`@090?nf`BGooooo00?o0000ooooooooool03oooool01000
003ooooo0?nf`@0000020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/7o00000P3o
]/400ol00000okK10?nf`@030?nf`@;o00001@3o]/401?l00000okK10?nf`Ol000020?nf`@040000
003o]/40okK100000080okK100<000000?nf`@3o]/402@3o]/401@000000okK10?nf`@3o]/400000
0080okK100Go00000?nf`@3o]/40okK1o`00000;0?nf`@05o`00003o]/40okK10?nf`Ol000000P3o
]/4010000000okK10?nf`@00000=0?nf`@050000003o]/40okK10?nf`@0000000P3o]/401?l00000
okK10?nf`Ol000040?nf`@05o`00003o]/40okK10?nf`Ol000001@3o]/401?l00000okK10?nf`Ol0
00020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/43ooooo`03
00000?oooooooooo01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
3P3o]/420000o``0okK10P000?lI0?nf`@030000o`3o]/40okK100T0okK10ol0000;0?nf`@030000
o`3o]/40okK10180okK100<0003o0?nf`@3o]/40203o]/45o`0000/0okK100<0003o0?nf`@3o]/40
2@3o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o]/400`000000
okK1000000020?nf`@060000003o]/40okK1o`00003o]/7o0000103o]/42o`000080okK10ol00003
0?nf`@04o`00003o]/40okK1o`000080okK100Co00000?nf`@3o]/4000000P3o]/400`000000okK1
0?nf`@080?nf`@050000003o]/40okK10?nf`@0000000P3o]/401Ol00000okK10?nf`@3o]/7o0000
00/0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04o`00003o]/40okK1o`0000d0okK100D0
00000?nf`@3o]/40okK1000000020?nf`@04o`00003o]/40okK1o`0000@0okK10ol000000`3o]/7o
0000o`0000040?nf`@04o`00003o]/40okK1o`000080okK100@000000?nf`@3o]/4000000P3o]/40
10000000okK10?nf`@0000020?nf`@?ooooo00<00000ooooooooool07oooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@0<0?nf`@80003o403o]/400`000?l0okK10?nf`@0F
0?nf`@030000o`3o]/40okK101L0okK100<0003o0?nf`@3o]/404P3o]/400`000?l0okK10?nf`@09
0?nf`@?o0000303o]/400`000?l0okK10?nf`@090?nf`BGooooo00?o0000ooooooooool03oooool0
1P00003ooooo0?nf`@000000okK1o`000080okK100@000000?nf`@3o]/4000000P3o]/400ol00000
okK1o`0000030?nf`@03o`00003o]/40okK100D0okK100Co00000?nf`@3o]/7o00000P3o]/401?l0
0000okK10?nf`@0000020?nf`@040000003o]/40okK1000000X0okK100D000000?nf`@3o]/40okK1
000000020?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/401`3o]/400ol00000okK1
0?nf`@020?nf`@03o`00003o]/40000000<0okK100<000000?nf`@3o]/402`3o]/401@000000okK1
0?nf`@3o]/4000000080okK100Co00000?nf`@3o]/7o00001`3o]/400ol00000okK10?nf`@040?nf
`@04o`00003o]/40okK1o`000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf
`@0000020?nf`@?ooooo00?o0000ooooooooool07oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0;0?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/405P3o
]/400`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/405`3o
]/400`000?l0okK10?nf`@0:0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0000
00020?nf`@060000003o]/40okK10000003o]/4000000P3o]/401?l00000okK10?nf`Ol000020?nf
`@03o`00003o]/40okK100L0okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK100000003
0?nf`@040000003o]/40okK1o`0000X0okK100D000000?nf`@3o]/40okK1000000020?nf`@05o`00
003o]/40okK10?nf`Ol00000203o]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40okK10000
00<0okK100<000000?nf`@3o]/400`3o]/43000000H0okK100@000000?nf`@3o]/4000000P3o]/40
1Ol00000okK10?nf`@3o]/7o000000`0okK100Co00000?nf`@3o]/7o00000P3o]/4010000000okK1
0?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/43ooooo`0300000?oooooooooo
01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402P3o]/400`000?l0
okK10?nf`@0C0?nf`@03o`00o`3o]/40okK101D0okK100<0003o0?nf`@3o]/405@3o]/400`000?l0
okK10?nf`@0D0?nf`@030000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/402P3o]/4Uooooo`03
o`000?oooooooooo00oooooo00<00000ooooo`0000000P3o]/401`000000okK10?nf`@000000okK1
0000003o]/400_l000001@3o]/7o00000?nf`@3o]/7o000000/0okK100Co00000?nf`@3o]/7o0000
0P3o]/400ol00000okK1000000020?nf`@050000003o]/40okK10?nf`@0000002@3o]/401@000000
okK10?nf`@3o]/7o000000<0okK100Co00000?nf`@3o]/40okK10_l000050?nf`@03o`00003o]/40
okK10080okK100Go00000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100<0okK100D0
00000?nf`@3o]/40okK1000000050?nf`@040000003o]/40okK1000000<0okK100Go00000?nf`@3o
]/40okK1o`00000:0?nf`@;o00000P3o]/401?l00000okK10?nf`@0000020?nf`@040000003o]/40
okK1000000<0okK100<000000?nf`@3o]/400oooool00`00003oooooooooo`0Oooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK100T0okK100<0003o0?nf`@3o]/405@3o]/40
0`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK101<0okK100?o003o0?nf`@3o]/405@3o]/40
0`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK100/0okK19Oooool00ol0003oooooooooo`0?
ooooo`0300000?oooooo00000080okK100P000000?nf`@3o]/4000000?nf`@000000okK1o`000080
okK100Co00000?nf`@3o]/7o0000103o]/43o`0000@0okK100Co00000?nf`@3o]/7o00000P3o]/40
0ol00000okK1000000020?nf`@050000003o]/40okK10?nf`@0000002@3o]/401@000000okK10?nf
`@3o]/40000000@0okK100?o00000?nf`@3o]/400P3o]/45o`0000@0okK100?o00000?nf`@3o]/40
0P3o]/4010000000okK10?nf`@0000040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/4010000000okK10?nf`@0000030?nf`@03o`00003o]/40okK10080okK100?o00000?nf
`@3o]/401P3o]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40okK100000080okK100@00000
0?nf`@3o]/4000000`3o]/400`000000okK10?nf`@03ooooo`0300000?oooooooooo01oooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402@3o]/400`000?l0okK10?nf`@0E
0?nf`@030000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/404@3o]/400`000?l0okK10?nf`@0F
0?nf`@030000o`3o]/40okK101D0okK100<0003o0?nf`@3o]/402`3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00<00000ooooo`3o]/400P3o]/4020000000okK10?nf`@000000okK10000003o]/7o
00000P3o]/400ol00000okK1o`0000040?nf`@04o`00003o]/40okK10?nf`@;o00000P3o]/402Ol0
0000okK10?nf`@3o]/7o00000?nf`Ol00000okK1000000020?nf`@050000003o]/40okK10?nf`@00
00002@3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o
]/402@3o]/400ol00000okK10?nf`@020?nf`@040000003o]/40okK1000000@0okK100<000000?nf
`@3o]/401@3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK1000000<0okK100?o0000
0?nf`@3o]/400P3o]/43o`0000<0okK10_l000040?nf`@04o`00003o]/40okK100000080okK100D0
00000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK10?nf`@?ooooo00<00000oooooooo
ool07oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000
o`3o]/40okK101L0okK100<0003o0?nf`@3o]/405P3o]/400`000?l0okK10?nf`@0?0?nf`@030000
o`3o]/40okK101P0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0<0?nf`BGooooo
00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/4000000080okK100D000000?nf`@00
0000okK1o`0000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/400`3o]/40
1Ol00000okK10?nf`@3o]/7o00000080okK100Ko00000?nf`@3o]/7o00000?nf`@0000020?nf`@05
0000003o]/40okK10?nf`@0000002@3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
0080okK100?o00000?nf`@3o]/401`3o]/401?l00000okK10?nf`@3o]/42000000<0okK100D00000
0?nf`@3o]/40okK1000000090?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@000000okK1
0?nf`@3o]/7o000000H0okK10ol000050?nf`@04o`00003o]/40okK1o`0000<0okK100Go00000?nf
`@3o]/40okK1000000020?nf`@040000003o]/40okK10?nf`@;ooooo00<00000ooooooooool08?oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o]/40
okK101L0okK100<0003o0?nf`@3o]/405`3o]/400`000?l0okK10?nf`@0=0?nf`@030000o`3o]/40
okK101X0okK100<0003o0?nf`@3o]/404P3o]/400`000?l0okK10?nf`@0<0?nf`BGooooo00?o0000
ooooooooool03oooool01@00003ooooo0?nf`@3o]/4000000080okK100D000000?nf`@000000okK1
o`0000020?nf`@03o`00003o]/7o000000<0okK100?o00000?nf`@3o]/401@3o]/401ol00000okK1
0?nf`@3o]/7o00000?nf`Ol000000P3o]/400ol00000okK1000000020?nf`@050000003o]/40okK1
0?nf`@0000002P3o]/42000000<0okK10P0000030?nf`@Wo00000`3o]/4200000080okK100<00000
o`00003o]/400P3o]/400`000000okK10?nf`@090?nf`@050000003o]/40okK10?nf`@0000000`3o
]/4200000080okK10_l0000:0?nf`@;o00000`3o]/4010000000okK10?nf`@0000030?nf`@050000
003o]/40okK10?nf`Ol000000`3o]/42ooooo`0300000?oooooooooo023ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf`@0G0?nf`@030000
o`3o]/40okK101P0okK100<0003o0?nf`@3o]/402`3o]/400`000?l0okK10?nf`@0L0?nf`@030000
o`3o]/40okK10100okK100?o003o0?nf`@3o]/403@3o]/4Uooooo`03o`000?oooooooooo00oooooo
00D00000ooooo`3o]/40okK1000000020?nf`@050000003o]/7o00000?nf`Ol000000P3o]/400ol0
0000okK1o`0000030?nf`@03o`00003o]/40okK100D0okK100Oo00000?nf`@3o]/40okK1o`00003o
]/7o00000080okK100?o00000?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000`0okK1
00<000000?nf`@3o]/400P3o]/42000000/0okK10P0000030?nf`@030000003o]/40okK10080okK1
00?o00000?nf`@3o]/402P3o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK1
00D000000?nf`@3o]/40okK1o`0000060?nf`@?o0000103o]/401@000000okK10?nf`@3o]/400000
00<0okK100D000000?nf`@3o]/40okK1000000030?nf`@;ooooo00<00000ooooooooool08?ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o]/40okK1
01P0okK100<0003o0?nf`@3o]/40603o]/420000o`L0okK10`000?l00ol00?l0okK10?nf`@0N0?nf
`@03o`00o`000?l0okK100d0okK10P000?l@0?nf`BGooooo00?o0000ooooooooool03oooool01@00
003ooooo0?nf`@3o]/4000000080okK100L000000?nf`@000000okK1o`00003o]/7o00000080okK1
00Co00000?nf`@3o]/7o00002@3o]/402Ol00000okK10?nf`@3o]/7o00000?nf`Ol00000okK1o`00
00020?nf`@030000003o]/4000000080okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf
`@030?nf`@<000001P3o]/42000000@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@0<0?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf
`@3o]/46o`0000H0okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf
`@000000103o]/400oooool00000ooooo`0Rooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100P0okK100<0003o0?nf`@3o]/402@3o]/43o`0000`0okK100<0003o0?nf`@3o
]/406P3o]/470000obH0okK10P000?l:0?nf`@80003o4P3o]/4Uooooo`03o`000?oooooooooo00oo
oooo00D00000ooooo`3o]/40okK1000000020?nf`@070000003o]/4000000?nf`Ol00000okK1o`00
00020?nf`@03o`00003o]/7o000000X0okK100Wo00000?nf`@3o]/40okK1o`00003o]/7o00000?nf
`Ol000000P3o]/400`000000okK1000000020?nf`@030000003o]/40okK100d0okK100<000000?nf
`@3o]/401@3o]/46000000@0okK10P0000030?nf`@800000403o]/42000000<0okK100<000000?nf
`@3o]/400P3o]/43000000T0okK10P0000001Ol00000okK10?nf`@00003o000000<0okK100D00000
0?nf`@3o]/40okK1000000050?nf`@03ooooo`00003ooooo02;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf`@080?nf`@Go00002`3o]/40
0`000?l0okK10?nf`@190?nf`@<0003o103o]/430000oa@0okK19Oooool00ol0003oooooooooo`0?
ooooo`0500000?ooool0okK10?nf`@0000000P3o]/401`000000okK10000003o]/7o00000?nf`Ol0
00000P3o]/400ol00000okK1o`00000:0?nf`@09o`00003o]/40okK10?nf`Ol00000okK1o`00003o
]/7o00000080okK100<000000?nf`@0000000P3o]/400`000000okK10?nf`@030?nf`@H000001@3o
]/400ol0000000000000000<0?nf`@800000103o]/400`000000okK10?nf`@060?nf`@D000001`3o
]/401P000000okK10?nf`@3o]/7o0000000000D0okK10`0000030?nf`@<00000103o]/400`000000
okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400oooool0
0000ooooo`0Rooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100L0okK1
00<0003o0?nf`@3o]/402@3o]/45o`0000/0okK100<0003o0?nf`@3o]/40C03o]/440000oaL0okK1
9Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000000P3o]/401`000000
okK10000003o]/7o00000?nf`Ol000000P3o]/400ol00000okK1o`00000:0?nf`@09o`00003o]/40
okK10?nf`Ol00000okK1o`00003o]/7o00000080okK100<000000?nf`@0000000P3o]/400`000000
okK10?nf`@030?nf`@030000003o]/40okK100<0okK10P0000060?nf`@@000001P3o]/42000000D0
okK100<000000?nf`@3o]/40103o]/43000000D0okK10P0000060?nf`@030000003o]/40okK10080
okK10P0000060?nf`@<000001P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/40103o]/400`00003oooooooooo`0Rooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/402@3o]/45o`0000/0okK1
00<0003o0?nf`@3o]/40I`3o]/4Uooooo`03o`000?oooooooooo00oooooo00D00000ooooo`3o]/40
okK1000000020?nf`@050000003o]/4000000?nf`Ol000000P3o]/400ol00000okK1o`0000020?nf
`@03o`00003o]/40okK100L0okK100Co00000?nf`@3o]/7o00000P3o]/401Ol00000okK1o`00003o
]/4000000080okK100@000000?nf`@3o]/400000103o]/400`000000okK10?nf`@060?nf`@800000
203o]/46000000H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@080?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0:0?nf`@800000
103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<00000ooooooooool0
8_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o
]/40okK100X0okK10ol0000<0?nf`@030000o`3o]/40okK106L0okK19Oooool00ol0003ooooooooo
o`0?ooooo`0500000?ooool0okK10?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080
okK100?o00000?nf`Ol000000P3o]/43o`0000L0okK100Co00000?nf`@3o]/7o00000P3o]/401Ol0
0000okK1o`00003o]/4000000080okK100@000000?nf`@3o]/7o00000`3o]/400`000000okK10?nf
`@090?nf`@04o`00000000000000000000d0okK10`0000050?nf`@800000303o]/400ol00000okK1
0?nf`@030?nf`@8000001@3o]/400ol00000000000000002000000<0okK1100000030?nf`@030000
0?l00000000000@0okK100<00000o`00003o]/401@3o]/400`00003oooooooooo`0Sooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/406@3o
]/400`000?l0okK10?nf`@1W0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0000
003o]/4000000080okK100D000000?nf`@000000okK1o`0000020?nf`@03o`00003o]/7o000000D0
okK100?o00000?nf`@3o]/400`3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Go00000?nf
`Ol00000okK1000000020?nf`@030000003o]/40000000@0okK100<000000?nf`@3o]/403@3o]/44
000000H0okK10`0000060?nf`@8000003`3o]/42000000D0okK10P0000080?nf`@<000001P3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`Oooool09?ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o]/40okK1
01L0okK100<0003o0?nf`@3o]/40J03o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000oooo
o`0000000P3o]/4020000000okK10?nf`@000000okK10000003o]/7o00000P3o]/400ol00000okK1
o`0000050?nf`@Go00000`3o]/402?l00000okK10?nf`Ol00000okK1o`00003o]/4000000P3o]/40
10000000okK10?nf`@0000030?nf`@030000003o]/40okK10180okK11P0000070?nf`@8000004`3o
]/42000000D0okK10P00000=0?nf`@8000001P3o]/400`000000okK10?nf`@050?nf`@030000003o
]/40okK102Gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/40
0`000?l0okK10?nf`@0G0?nf`@030000o`3o]/40okK106P0okK19Oooool00ol0003oooooooooo`0?
ooooo`0300000?ooool000000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@03o`00
003o]/7o00000080okK10_l000090?nf`@;o00000P3o]/401_l00000okK10?nf`Ol00000okK10000
0080okK100@000000?nf`@3o]/4000000P3o]/400ol00000okK10?nf`@0O0?nf`@030000003o]/40
okK101D0okK10P0000050?nf`@80000000Co000000000000000000000`3o]/401000003o00000000
000000060?nf`@0300000?l00000okK100H0okK100@000000?nf`@3o]/40okK19Oooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@090?nf`@03o`00o`3o]/40okK101D0okK1
00<0003oooooooooool0S_ooool00ol0003oooooooooo`0?ooooo`0300000?ooool000000080okK1
00Ko00000?nf`@3o]/4000000?nf`@0000020?nf`@03o`00003o]/7o000000@0okK10_l000060?nf
`@05o`00003o]/40okK10?nf`Ol000000`3o]/400ol0003ooooo00000002ooooo`0400000?oooooo
oooo000000;ooooo00<00000ooooooooool01?ooool;000000gooooo0P0000000ol0003ooooooooo
o`0Hooooo`0300000?oooooooooo00Sooooo0`000009ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool09_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@09
0?nf`@030000o`3o]/40okK101D0okK100<0003oooooooooool0S_ooool00ol0003oooooooooo`0?
ooooo`0300000?ooool000000080okK100L000000?nf`@3o]/40okK10000003o]/4000000080okK1
00?o00000?nf`Ol000001@3o]/400ol00000okK10?nf`@03o`0000<0okK100Oo00000?nf`@3o]/40
okK1o`00003o]/40000000;ooooo00@00000ooooooooool000000_ooool00`00003oooooooooo`03
ooooo`8000002oooool4000000;ooooo1`00000>ooooo`D000002oooool30000017ooooo0P000009
ooooo`0300000?oooooooooo02Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/402P3o]/400`000?l0okK10?nf`@0C0?nf`@030000o`3o]/7ooooo08oooooo00?o0000oooo
ooooool03oooool01000003ooooo0?nf`@0000020?nf`@060000003o]/40okK10000003o]/400000
0P3o]/401?l00000okK10?nf`Ol000050?nf`@;o00001@3o]/401Ol00000okK10?nf`@3o]/7o0000
0080okK100@00000ooooooooool000000_ooool01000003oooooooooo`000004ooooo`0300000?oo
oooooooo00oooooo0P00000Booooo`<000001Oooool00`00003o0000ooooo`0;ooooo`0300000?l0
003ooooo00_ooooo0`00000:ooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/402`3o]/400`000?l0okK10?nf`@0B0?nf`@030000o`3o]/7o
oooo08oooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000030?nf`@030000003o
]/7o00000080okK100@00000o`00003o]/7o00000P3o]/45o`0000H0okK10_l000000`3o]/7o0000
o`0000020?nf`@0400000?oooooooooo000000;ooooo00@00000ooooooooool000001?ooool00ol0
003oooooooooo`0Pooooo`@000002_ooool2000000cooooo3000000;ooooo`800000:oooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0<0?nf`@030000o`3o]/40okK10100
okK100<0003o0?nf`@3o]/40T?ooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK10000
00<0okK100@000000?nf`@3o]/4000000`3o]/4010000000okK1o`000?l000050?nf`@Ko00000P3o
]/402?l00000okK10?nf`@3o]/4000000?nf`Oooool000000oooool01000003oooooooooo`000004
ooooo`0300000?oooooooooo01gooooo0`00000@ooooo`8000007oooool2000002gooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/420000o`h0okK10P000?l30?nf
`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/40000000<0okK100@00000
0?nf`@3o]/4000000`3o]/400`000000okK10?nf`@02o`0000T0okK10_l000030?nf`@04o`00003o
]/40okK1o`0000?ooooo00Co0000ooooooooool000001?ooool00`00003oooooooooo`0Mooooo`03
00000?oooooooooo01?ooooo0P00000Kooooo`800000;oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0?0?nf`@<0003o203o]/430000o`D0okK1T?ooool00ol0003ooooo
ooooo`0?ooooo`0300000?ooool0okK10080okK100Go00000?nf`@3o]/40okK1000000020?nf`@05
0000003o]/40okK10?nf`@0000000`3o]/43o`0000D0okK100Co00000?nf`@3o]/40okK10P000002
0?nf`@0500000?ooooooooooooooo`0000000_ooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo01[ooooo1000000Hooooo`<000005_ooool20000037ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/404P3o]/430000o`80okK10`000?l80?nf`I3ooooo00?o0000
ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@050000003o]/40okK10?nf`Ol000000`3o
]/401Ol00000okK10?nf`Ol00000000000D0okK11Ol000030?nf`@030000003o]/40okK10080okK1
00@00000ooooooooool000000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Oo
oooo4`00000Oooooo`8000004_ooool2000003?ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/405@3o]/420000o`/0okK1T?ooool00ol0003oooooooooo`0?ooooo`030000
0?ooool0000000<0okK100D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK10?nf
`@8000002@3o]/42000000@0okK100@000000?nf`Oooool000000oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Kooooo0P00000dooooo`8000003?ooool4000003Gooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo
00oooooo00<00000ooooo`000000103o]/401@000000okK10?nf`@3o]/40000000<0okK100<00000
0?nf`@3o]/400P3o]/49000000@0okK10P0000020?nf`@03o`000?oooooooooo00;ooooo00<00000
ooooooooool00_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Kooooo1P000003
ooooo`<00000>Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf
`I3ooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000040?nf`@05o`00003o]/40
okK10?nf`@0000000`3o]/43000000`0okK10P0000030?nf`@8000000oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool3000003cooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooo
oooo00oooooo00@00000ooooo`3o]/4000001@3o]/401P000000okK10?nf`@3o]/7o0000000000@0
okK1100000060?nf`@800000103o]/400`000000okK1ooooo`02ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01Oooool00`00003oooooooooo`1mooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`050000
0?ooool0okK10?nf`@0000001@3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100D0
okK11P0000040?nf`@8000000P3o]/42ooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`1nooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@8000003P3o]/400`000000okK1
0?nf`@020?nf`@03ooooo`00003ooooo00?ooooo00?o0000ooooooooool01Oooool00`00003ooooo
ooooo`1oooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?oo
ool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100?o00000?nf`@3o]/400`3o
]/400`000000okK10?nf`@040?nf`@8000002`3o]/400`000000okK10?nf`@030?nf`@03o`000?oo
oooooooo00?ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`1oooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?
ooooo`0300000?ooool0okK10080okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@05
0?nf`@8000001`3o]/42000000H0okK100<00000ooooooooool00_ooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo07oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400`3o]/400`00
0000okK10?nf`@040?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/40100000070?nf
`@0300000?oooooooooo00?ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`20oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003o
ooooooooo`0?ooooo`0300000?ooool0okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000
okK10?nf`@070?nf`@8000002P3o]/400`000000okK1ooooo`03ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool0P?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@040?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/404`3o]/400`000000okK1ooooo`03ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool0P?ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf
`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/404P3o]/400`000000okK1oooo
o`03ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0P?ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool0
0`00003ooooo0?nf`@050?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/404@3o]/40
0`000000okK10?nf`@04ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0P?ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000oooo
ooooool03oooool00`00003ooooo0?nf`@050?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/40403o]/400`000000okK10?nf`@04ooooo`0300000?oooooooooo00Kooooo00<00000oooo
ooooool0P?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3o
oooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@050?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/40403o]/400`000000okK10?nf`@04ooooo`0300000?oooooooooo00Oo
oooo00?o000000000?ooool0Ooooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@040?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/404P3o]/400`000000okK1ooooo`04ooooo`030000
0?oooooooooo00Sooooo0P00000nooooo`D00000>oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf
`@040?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/401P3o]/44000000X0okK100<0
0000ooooooooool00oooool00`00003oooooooooo`0:oooooa<0000000?o000000000?ooool08Ooo
ool7000000Gooooo1@0000000ol000000000ooooo`0cooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0
okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40
okK10080okK1100000060?nf`@0300000?oooooooooo00?ooooo00<00000ooooooooool07oooool3
000001cooooo0`00000Cooooo`800000<_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@030?nf
`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/42000000T0okK10P0000050?nf
`@0300000?oooooooooo00?ooooo00<00000ooooooooool08Oooool4000001Oooooo00<00000oooo
ooooool05_ooool20000033ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000
okK10?nf`@030?nf`@030000003o]/40okK100<0okK10P00000=0?nf`@030000003o]/40okK10080
okK100?ooooo00000?ooool01?ooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool06Oooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`030000
0?ooool0okK10080okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@030000
0?l00000okK100l0okK100Co00000000003o]/40okK10_ooool00`00003oooooooooo`03ooooo`03
o`000000003ooooo02Cooooo00?o00000000000000004?ooool2000001gooooo00?o000000000000
0000;?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo
00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@050000003o]/40okK10?nf`@00
0000103o]/400`000000okK10?nf`@050?nf`@So00001@3o]/400`000000okK1ooooo`02ooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool03_ooool<000000_ooooo0P00000;ooooo`<0
00002oooool;000000cooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo
0?nf`@3o]/40000000@0okK100D000000?nf`@3o]/40okK1000000050?nf`@?o0000203o]/42o`00
00@0okK100<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`8000002oooool30000
00cooooo0`00000:ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02Oooool30000
00_ooooo10000009ooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/404@3o]/490000o`P0okK1T?ooool00ol0003oooooooooo`0?ooooo`04
00000?ooool0okK1000000@0okK100D000000?nf`@3o]/40okK1o`0000040?nf`@;o00003@3o]/42
o`0000<0okK100<00000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`0300000?l00000
000000<0000000?o00000000000000000P00000Booooo`<000002?ooool01000003o000000000000
0002ooooo`80000000?o0000ooooooooool02?ooool00ol000000000ooooo`0Aooooo`8000002?oo
ool00`00003oooooooooo`0Wooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK100l0okK10P000?l90?nf`@<0003o1@3o]/6@ooooo`03o`000?oooooooooo00oooooo00@00000
ooooo`3o]/400000103o]/401@000000okK10?nf`@3o]/40000000<0okK100?o00000?nf`@3o]/40
0`3o]/47o`0000D0okK100Co00000?nf`@3o]/4000001?ooool00`00003oooooooooo`0Cooooo``0
00001_ooool00`00003oooooooooo`09ooooo`8000002oooool2000001Kooooo00<00000oooooooo
ool01_ooool00ol0003oooooooooo`0Vooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK100h0okK100<0003o0?nf`@3o]/40303o]/420000o`<0okK1T?ooool00ol0003ooooo
ooooo`0?ooooo`0300000?ooool0000000@0okK100D000000?nf`@3o]/40okK1000000030?nf`@04
o`00003o]/40okK10?nf`@?o00001`3o]/400ol00000okK10?nf`@020?nf`@05o`00003o]/40okK1
ooooo`0000001?ooool00`00003oooooooooo`0?ooooo`<000003?ooool2000000Gooooo00<00000
ooooooooool05?ooool00`00003oooooooooo`05ooooo`/000001oooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/40303o]/400`000?oo003o0?nf`@0@0?nf`@030000o`3o]/40okK1093ooooo00?o0000oooo
ooooool03oooool00`00003ooooo0?nf`@030?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
1Ol00000okK10?nf`@3o]/7o000000/0okK10_l000030?nf`@05o`00003o]/7oooooooooo`000000
1?ooool00`00003oooooooooo`0<ooooo`03o`000000003ooooo013ooooo00<00000ooooooooool0
0oooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0`00000;ooooo`<00000
1Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02Gooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/402`3o]/400`000?l0okK10?nf`@0B0?nf`@030000o`3o
]/7ooooo08oooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@050000003o
]/40okK10?nf`@0000000`3o]/400ol00000okK10?nf`@02o`0000@0okK11?l000060?nf`@;o0000
0P3o]/401_l0003ooooooooooooooooo0000000000?ooooo00?o00000000000000002Oooool20000
00Gooooo10000002o`0000H000000oooool00`00003o000000000003ooooo`8000004?ooool20000
00Cooooo0P000006ooooo`D000001_ooool00`00003o000000000003ooooo`03o`000000003ooooo
00Gooooo00<00000ooooooooool09?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0:0?nf`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/40JP3o]/4Uooooo`03
o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/401@000000okK10?nf`@3o]/400000
00<0okK100Co00000?nf`@3o]/7o0000103o]/400ol00000okK10?nf`@020?nf`@Co0000103o]/40
1?l00000okK10?nf`Ol000030?nf`@030000003o]/40okK100@0okK10`0000020?nf`@@00000103o
]/43000000`0okK10P0000040?nf`@030000003o]/40okK10080okK10P00000=0?nf`@030000003o
]/40okK10080okK10P0000050?nf`@<000001@3o]/43000000H0okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@040?nf`@0300000?oooooooooo02?ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/402@3o]/400`000?l0okK10?nf`@0E0?nf`@030000o`3o]/40
okK106T0okK19Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000000`3o
]/401@000000okK10?nf`@3o]/7o00000080okK100Co00000?nf`@3o]/40okK10_l000090?nf`@05
o`00003o]/40okK10?nf`Ol000000`3o]/401Ol00000okK10?nf`@3o]/40000000P0okK10P000007
0?nf`@030000003o]/40okK10080okK12ol000020?nf`@8000000`3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK100P0okK10P0000040?nf`@030000003o]/40okK10080okK10`00000;
0?nf`@<00000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<00000
ooooooooool08_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@090?nf
`@030000o`3o]/40okK101D0okK100<0003o0?nf`@3o]/40J@3o]/4Uooooo`03o`000?oooooooooo
00oooooo00D00000ooooo`3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`Ol000000P3o
]/400ol00000okK10?nf`@02o`0000`0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@05o`00
003o]/40okK10?nf`@0000003@3o]/400`00003o0000000000020?nf`@?o00002`3o]/42o`000080
okK100D000000?nf`@3o]/40okK1o`0000050?nf`@030000003o]/40okK100H0okK100?o00000?nf
`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100@0okK11ol000040?nf
`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@030?nf
`@03o`000?oooooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/40203o]/400`000?l0okK10?nf`@0G0?nf`@030000o`3o]/40okK104`0okK12@000?lC0?nf`BGo
oooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/4000000080okK100D000000?nf
`@3o]/40okK1o`0000020?nf`@03o`00003o]/7o000000D0okK11_l000030?nf`@05o`00003o]/40
okK10?nf`Ol000000`3o]/401Ol00000okK10?nf`@3o]/40000000`0okK100<000000?nf`@3o]/40
0P3o]/401?l00000okK10?nf`@3o]/4:o`0000<0okK100Co00000?nf`@3o]/4000000`3o]/400`00
0000okK10?nf`@020?nf`@03o`0000000000000000<0okK10`0000060?nf`@050000003o]/40okK1
0?nf`@000000103o]/43o`0000L0okK10_l000030?nf`@050000003o]/40okK10?nf`@000000103o
]/400`000000okK10?nf`@030?nf`@0300000?oooooooooo02;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf`@0G0?nf`@030000o`3o]/40
okK101X0okK12?l00?lW0?nf`@<0003o2@3o]/420000oa40okK19Oooool00ol0003oooooooooo`0?
ooooo`0500000?ooool0okK10?nf`@0000000P3o]/4010000000okK10?nf`Ol000020?nf`@04o`00
003o]/40okK1o`0000@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@05
o`00003o]/40okK10?nf`Ol000000`3o]/401Ol00000okK10?nf`@3o]/40000000T0okK10P000004
0?nf`@03o`00003o]/40okK100;o00002P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100D0
00000?nf`@3o]/40okK1000000060?nf`@<00000203o]/401@000000okK10?nf`@3o]/40000000<0
okK10_l0000<0?nf`@;o00000P3o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf
`@3o]/400P3o]/400oooool00000ooooo`0Rooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/40603o]/400`000?l0okK10?nf`@0H0?nf`@;o
003o203o]/42o`00ob<0okK10P000?l>0?nf`@030000o`3o]/40okK100h0okK19Oooool00ol0003o
ooooooooo`0?ooooo`0400000?ooool0okK100000080okK100D000000?nf`@3o]/40okK1o`000002
0?nf`@03o`00003o]/7o000000@0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@02
0?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK10080okK10_l000020?nf`@03o`00003o]/40okK100<0okK11?l0
00040?nf`@;o00000P3o]/401?l00000okK10?nf`Ol000030?nf`@030000003o]/40okK100d0okK1
00D000000?nf`@3o]/40okK1000000030?nf`@04o`00003o]/40okK10?nf`@Wo0000103o]/401?l0
0000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf`@000000103o]/400oooool00000oooo
o`0Rooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o
0?nf`@3o]/406@3o]/400`000?l0okK10?nf`@0E0?nf`@;o003o303o]/42o`00ob00okK100<0003o
0?nf`@3o]/403`3o]/400`000?l0okK10?nf`@0=0?nf`BGooooo00?o0000ooooooooool03oooool0
1000003ooooo0?nf`@0000020?nf`@040000003o]/40okK1o`000080okK100Co00000?nf`@3o]/7o
00000`3o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK10080okK100Co00000?nf`@3o
]/7o00000`3o]/400ol00000okK10?nf`@020?nf`@8000000P3o]/400`00003o0000000000040?nf
`@05o`00003o]/40okK10?nf`Ol000000P3o]/44o`0000@0okK11?l000020?nf`@04o`00003o]/40
okK1o`000080okK100@000000?nf`@3o]/7o00003P3o]/401Ol00000okK10?nf`@3o]/4000000080
okK10_l000020?nf`@;o00002@3o]/42o`0000<0okK100Co00000?nf`@3o]/7o00000`3o]/401@00
0000okK10?nf`@3o]/40000000<0okK10_ooool00`00003oooooooooo`0Pooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/402P3o]/43o`00
00`0okK100<0003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0<0?nf`@03o`00o`3o]/40okK1
01d0okK100?o003o0?nf`@3o]/40403o]/400`000?l0okK10?nf`@0=0?nf`BGooooo00?o0000oooo
ooooool03oooool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK1o`000080okK100Co
00000?nf`@3o]/7o00000`3o]/400ol00000okK10?nf`@080?nf`@05o`00003o]/40okK10?nf`Ol0
00000P3o]/401Ol00000okK10?nf`@3o]/7o000000H0okK10P0000060?nf`@06o`00003o]/40okK1
0?nf`Ol00000okK10_l000040?nf`@Co0000103o]/401_l00000okK10?nf`Ol00000okK1o`000080
okK100D000000?nf`@3o]/40okK10000000<0?nf`@030000003o]/40okK10080okK100<000000?nf
`Ol000000`3o]/400ol00000okK10?nf`@020?nf`@Go0000103o]/401?l00000okK10?nf`Ol00003
0?nf`@050000003o]/40okK10?nf`Ol000000P3o]/4010000000okK10?nf`@3o]/42ooooo`030000
0?oooooooooo023ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o
]/400`000?l0okK10?nf`@090?nf`@Go00002`3o]/400`000?l0okK10?nf`@0D0?nf`@03o`00o`3o
]/40okK100h0okK100?o003o0?nf`@3o]/40703o]/400`000?l0okK10?nf`@0A0?nf`@030000o`3o
]/40okK100`0okK19Oooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK100000080okK1
00@000000?nf`@3o]/7o00000P3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/40okK1
00T0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@04o`00003o]/40okK1o`0000d0okK100?o
00000?nf`@3o]/400_l000000`3o]/7o00000?nf`@020?nf`@?o0000103o]/43o`000080okK100Ko
00000?nf`@3o]/7o00000?nf`Ol000020?nf`@050000003o]/40okK10?nf`@0000002`3o]/401@00
0000okK10?nf`@3o]/4000000080okK100Co00000?nf`@3o]/7o00000`3o]/42o`0000D0okK10_l0
00030?nf`@04o`00003o]/40okK1o`000080okK100D000000?nf`@3o]/40okK1000000030?nf`@03
0000003o]/40okK100?ooooo00<00000ooooooooool07oooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o]/40okK100T0okK11Ol0000<0?nf`@030000
o`3o]/40okK10180okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0J0?nf`@030000
o`3o]/40okK101<0okK100<0003o0?nf`@3o]/402`3o]/4Uooooo`03o`000?oooooooooo00oooooo
00@00000ooooo`3o]/4000000P3o]/4010000000okK10?nf`Ol000020?nf`@04o`00003o]/40okK1
o`000080okK100?o00000?nf`@3o]/402P3o]/401?l00000okK10?nf`Ol000030?nf`@04o`00003o
]/40okK1o`0000`0okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK10?nf`@02o`0000X0
okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK1o`0000020?nf`@050000003o]/40okK1
0?nf`@0000002@3o]/401@000000okK10?nf`@3o]/7o00000080okK100Co00000?nf`@3o]/7o0000
0`3o]/400ol00000okK10?nf`@070?nf`@05o`00003o]/40okK10?nf`Ol000000P3o]/401?l00000
okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/43ooooo`0300000?oooooo
oooo01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`00
0?l0okK10?nf`@090?nf`@Go0000303o]/400`000?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK1
0180okK100?o003o0?nf`@3o]/406@3o]/400`000?l0okK10?nf`@0C0?nf`@030000o`3o]/40okK1
00/0okK19Oooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK100000080okK100@00000
0?nf`@3o]/7o00000P3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/40okK100X0okK1
00Co00000?nf`@3o]/7o00000`3o]/401?l00000okK10?nf`Ol0000<0?nf`@04o`00003o]/40okK1
o`000080okK100Co00000?nf`@3o]/7o0000103o]/44o`0000@0okK100?o00000?nf`Ol000000P3o
]/400ol00000okK1o`0000020?nf`@050000003o]/40okK10?nf`Ol000002@3o]/401@000000okK1
0?nf`@3o]/4000000080okK100Co00000?nf`@3o]/7o00000`3o]/400ol00000okK10?nf`@080?nf
`@04o`00003o]/40okK1o`000080okK100Co00000?nf`@3o]/4000000P3o]/401@000000okK10?nf
`@3o]/4000000080okK10oooool00ol0003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/402P3o]/43o`0000d0okK100<0
003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK101L0okK100<0
003o0?nf`@3o]/405@3o]/400`000?l0okK10?nf`@0:0?nf`BGooooo00?o0000ooooooooool03ooo
ool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK1o`000080okK100Co00000?nf`@3o
]/7o00000P3o]/400ol00000okK10?nf`@090?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/40
1?l00000okK10?nf`Ol0000<0?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o]/401?l00000
okK10?nf`@3o]/42o`0000@0okK10_l000020?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o
]/401?l00000okK10?nf`@0000020?nf`@030000003o]/40okK100H0okK100D000000?nf`@3o]/40
okK1000000030?nf`@03o`00003o]/7o000000<0okK100?o00000?nf`@3o]/400P3o]/44o`0000@0
okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK1000000020?nf`@050000003o]/40okK1
0?nf`@0000000P3o]/43ooooo`0300000?oooooooooo01oooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0J0?nf`@030000o`3o]/40okK1
0100okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0G0?nf`@030000o`3o]/40okK1
01D0okK100<0003o0?nf`@3o]/402P3o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000oooo
o`3o]/4000000P3o]/4010000000okK10?nf`Ol000020?nf`@04o`00003o]/40okK1o`0000<0okK1
00?o00000?nf`@3o]/40203o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o
]/40okK1o`00000;0?nf`@04o`00003o]/40okK1o`000080okK100Co00000?nf`@3o]/7o00000P3o
]/400ol00000okK10?nf`@060?nf`@04o`00003o]/40okK1o`000080okK100Go00000?nf`Ol00000
okK1o`0000020?nf`@050000003o]/40okK10?nf`@0000001`3o]/401@000000okK10?nf`@3o]/40
00000080okK100Co00000?nf`@3o]/7o00000P3o]/401?l00000okK10?nf`@3o]/42o`0000@0okK1
00Go00000?nf`@3o]/40okK1o`0000020?nf`@04o`00003o]/40okK1o`000080okK100@000000?nf
`@3o]/4000000`3o]/400`000000okK1ooooo`03ooooo`0300000?oooooooooo01kooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0I0?nf
`@030000o`3o]/40okK10140okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0G0?nf
`@030000o`3o]/40okK101D0okK100<0003o0?nf`@3o]/402P3o]/4Uooooo`03o`000?oooooooooo
00oooooo00@00000ooooo`3o]/4000000P3o]/4010000000okK10?nf`Ol000020?nf`@04o`00003o
]/40okK1o`0000<0okK10_l000080?nf`@03o`00003o]/40okK10080okK100Co00000?nf`@3o]/7o
00000`3o]/400ol00000okK10?nf`@090?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o]/40
1?l00000okK10?nf`Ol0000:0?nf`@08o`00003o]/40okK1o`00003o]/7o00000?nf`Ol000020?nf
`@03o`00003o]/40000000@0okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40
000000<0okK100?o00000?nf`Ol000000P3o]/401Ol00000okK10?nf`@3o]/7o000000L0okK100Go
00000?nf`@3o]/40okK1o`0000020?nf`@06o`00003o]/40okK1o`00003o]/4000000P3o]/401P00
0000okK10?nf`@3o]/4000000?nf`@Cooooo00<00000ooooooooool07_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o]/40okK101P0okK100<0003o
0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@080?nf`@?o00002P3o]/400ol00?l0okK10?nf`@0E
0?nf`@030000o`3o]/40okK100T0okK10ol0000;0?nf`@030000o`3o]/40okK100T0okK19Oooool0
0ol0003oooooooooo`0?ooooo`0400000?ooool0okK100000080okK100@000000?nf`@3o]/7o0000
0`3o]/400ol00000okK1o`0000050?nf`@03o`00003o]/40okK100D0okK100Go00000?nf`@3o]/40
okK1o`0000030?nf`@05o`00003o]/40okK10?nf`Ol000002`3o]/401_l00000okK10?nf`Ol00000
okK1o`000080okK100Co00000?nf`@3o]/7o0000103o]/42o`0000@0okK100So00000?nf`@3o]/7o
00000?nf`Ol00000okK1o`000080okK100?o00000?nf`@000000103o]/400`000000okK10?nf`@03
0?nf`@050000003o]/40okK10?nf`@0000000`3o]/400ol00000okK1o`0000020?nf`@05o`00003o
]/40okK10?nf`Ol000001`3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100Ko00000?nf`@3o
]/7o00000?nf`@0000020?nf`@060000003o]/40okK10?nf`@000000okK11?ooool00`00003ooooo
ooooo`0Nooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100P0okK100<0
003o0?nf`@3o]/405`3o]/400`000?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100P0okK11Ol0
00090?nf`@03o`00o`3o]/40okK101D0okK100<0003o0?nf`@3o]/40203o]/45o`0000X0okK100<0
003o0?nf`@3o]/402@3o]/4Uooooo`03o`000?oooooooooo00oooooo00D00000ooooo`3o]/40okK1
000000020?nf`@040000003o]/40okK1o`000080okK100?o00000?nf`@3o]/400_l000040?nf`@03
o`00003o]/40okK100<0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@05o`00003o]/40okK1
0?nf`Ol00000303o]/402?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000P3o]/400ol00000
okK10?nf`@020?nf`@04o`00003o]/40okK1o`0000@0okK100?o00000?nf`Ol000000P3o]/401Ol0
0000okK1o`00003o]/7o00000080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o
]/40000000@0okK100@000000?nf`@3o]/7o00000P3o]/401?l00000okK10?nf`Ol000020?nf`@03
o`00003o]/40okK100L0okK100Oo00000?nf`@3o]/40okK1o`00003o]/7o00000080okK100Ko0000
0?nf`@3o]/4000000?nf`@0000030?nf`@030000003o]/7ooooo00?ooooo00<00000ooooooooool0
7_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o
]/40okK101L0okK100<0003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@080?nf`@Go00002@3o
]/400ol00?l0okK10?nf`@0E0?nf`@030000o`3o]/40okK100P0okK11Ol0000:0?nf`@030000o`3o
]/40okK100T0okK19Oooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@000000
0P3o]/401@000000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o]/40okK1o`0000040?nf
`@Go00000`3o]/401Ol00000okK10?nf`@3o]/7o000000<0okK100?o00000?nf`@3o]/402`3o]/40
2?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000P3o]/401Ol00000okK10?nf`@3o]/7o0000
00<0okK10_l000030?nf`@03o`00003o]/7o00000080okK100Go00000?nf`Ol00000okK1o`000002
0?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1000000040?nf`@040000003o
]/40okK1o`000080okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK10?nf`@070?nf`@07
o`00003o]/40okK10?nf`Ol00000okK1o`0000020?nf`@06o`00003o]/40okK10000003o]/400000
0`3o]/400`000000okK1ooooo`03ooooo`0300000?oooooooooo01kooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/402@3o]/400`000?l0okK10?nf`@0E0?nf`@030000o`3o
]/40okK10180okK100?o003o0?nf`@3o]/40203o]/45o`0000T0okK100?o003o0?nf`@3o]/405@3o
]/400`000?l0okK10?nf`@080?nf`@Go00002P3o]/400`000?l0okK10?nf`@090?nf`BGooooo00?o
0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/4000000080okK100D000000?nf`@3o]/40
okK1o`0000020?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/401`3o]/42o`0000@0
okK100Go00000?nf`@3o]/40okK1o`00000=0?nf`@08o`00003o]/40okK1o`00003o]/7o00000?nf
`Ol000020?nf`@03o`00003o]/40okK10080okK100?o00000?nf`Ol000001@3o]/400ol00000okK1
o`0000020?nf`@05o`00003o]/7o00000?nf`Ol000000P3o]/400`000000okK10?nf`@020?nf`@05
0000003o]/40okK10?nf`@000000103o]/4010000000okK10?nf`Ol000020?nf`@04o`00003o]/40
okK1o`000080okK100?o00000?nf`@3o]/401`3o]/401ol00000okK10?nf`@3o]/7o00000?nf`Ol0
00000P3o]/401_l00000okK10?nf`@000000okK1000000<0okK100<000000?nf`Oooool00oooool0
0`00003oooooooooo`0Nooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
00X0okK100<0003o0?nf`@3o]/40503o]/400`000?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK1
00P0okK10ol000090?nf`@03o`00o`3o]/40okK101L0okK100<0003o0?nf`@3o]/40203o]/43o`00
00/0okK100<0003o0?nf`@3o]/402@3o]/4Uooooo`03o`000?oooooooooo00oooooo00D00000oooo
o`3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`Ol000000P3o]/400ol00000okK10?nf
`@020?nf`@?o00001@3o]/400ol00000okK10?nf`@030?nf`@05o`00003o]/40okK10?nf`Ol00000
3P3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/7o00000080okK100?o00000?nf`@3o
]/400P3o]/400ol00000okK10?nf`@030?nf`@04o`00003o]/40okK1o`000080okK100Go00000?nf
`Ol00000okK1o`0000020?nf`@050000003o]/40okK10?nf`@0000001@3o]/401@000000okK10?nf
`@3o]/4000000080okK100Co00000?nf`@3o]/7o00000P3o]/401Ol00000okK10?nf`@3o]/7o0000
00L0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@04o`00003o]/40okK1o`000080okK100<0
00000?nf`@0000000`3o]/400`000000okK1ooooo`03ooooo`0300000?oooooooooo01kooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402`3o]/400`000?l0okK10?nf`@0C
0?nf`@030000o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0G
0?nf`@030000o`3o]/40okK101H0okK100<0003o0?nf`@3o]/402@3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00<00000ooooo`3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK100Co
00000?nf`@3o]/7o00001P3o]/45o`0000D0okK100Go00000?nf`@3o]/40okK1o`0000050?nf`@H0
00001@3o]/402?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000P3o]/400ol00000okK10?nf
`@080?nf`@03o`00003o]/7o00000080okK100Go00000?nf`Ol00000okK1o`0000020?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@060000
003o]/40okK1o`00003o]/7o00000`3o]/401Ol00000okK10?nf`@3o]/7o000000D0okK100?o0000
0?nf`@3o]/400P3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100@000000?nf`@3o]/40
00000`3o]/400`000000okK1ooooo`02ooooo`0300000?oooooooooo01oooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/40303o]/400`000?l0okK10?nf`@0?0?nf`@80003o
00?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK101L0okK1
00<0003o0?nf`@3o]/405P3o]/400`000?l0okK10?nf`@090?nf`BGooooo00?o0000ooooooooool0
3oooool00`00003ooooo0?nf`@020?nf`@06o`0000000000okK10?nf`Ol0000000000P3o]/42o`00
0080okK10ol0000;0?nf`@;o00000`3o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK1
00@0okK100?o00000?nf`@3o]/400P3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100Co
00000?nf`@3o]/7o0000203o]/401?l00000okK10?nf`Ol000020?nf`@05o`00003o]/7o00000?nf
`Ol000000P3o]/401Ol00000okK10?nf`@3o]/40000000H0okK100<000000?nf`@3o]/400P3o]/40
10000000okK10?nf`Ol000020?nf`@04o`00003o]/40okK1o`0000@0okK10_l000020?nf`@;o0000
0`3o]/400ol00000okK10?nf`@02o`0000050?nf`Ol00000okK10?nf`@0000000P3o]/401P000000
okK10?nf`@3o]/4000000?nf`@?ooooo00<00000ooooooooool07oooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@03o`00o`000?l0okK100d0okK100<0003o0?nf
`@3o]/405`3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK101L0okK100<0003o0?nf
`@3o]/405P3o]/400`000?l0okK10?nf`@090?nf`BGooooo00?o0000ooooooooool03oooool00`00
003ooooo000000030?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1o`000004
0?nf`@?o00001P3o]/42o`0000@0okK100?o00000?nf`@3o]/400P3o]/42000000L0okK100<00000
0?nf`@3o]/400P3o]/401?l00000okK10?nf`Ol000020?nf`@04o`00003o]/7o0000o`000080okK1
0ol000050?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o]/400ol00000okK1o`0000020?nf
`@050000003o]/40okK10?nf`@0000001P3o]/400`000000okK10?nf`@020?nf`@040000003o]/40
okK1o`000080okK100Go00000?nf`@3o]/40okK1o`0000050?nf`@;o0000103o]/42o`000080okK1
00Co00000?nf`@3o]/7o00000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/7ooooo
00;ooooo00<00000ooooooooool07oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0?0?nf`@<0003o2P3o]/400`000?l0okK10?nf`@0I0?nf`@03o`00o`3o]/40okK10180
okK100?o003o0?nf`@3o]/406@3o]/400`000?l0okK10?nf`@0D0?nf`@030000o`3o]/40okK100X0
okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0000000@0okK100<000000?nf`@3o
]/400P3o]/4010000000okK10?nf`@3o]/42o`0000D0okK11_l000040?nf`@;o00000`3o]/420000
00X0okK100<000000?nf`@3o]/400P3o]/401?l00000okK10?nf`Ol000020?nf`@04o`00003o]/40
okK1o`0000@0okK11Ol000001@3o]/7o0000o`00003o]/7o00000080okK100?o00000?nf`Ol00000
0`3o]/4010000000okK10?nf`@0000080?nf`@030000003o]/40okK10080okK100@000000?nf`@3o
]/7o00000P3o]/401Ol00000okK10?nf`@3o]/7o000000P0okK10_l000030?nf`@04o`00003o]/40
okK1o`000080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@03ooooo`030000
0?oooooooooo01oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404P3o
]/430000o`@0okK10`000?lM0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/406P3o
]/400`000?l0okK10?nf`@0C0?nf`@030000o`3o]/40okK100/0okK19Oooool00ol0003ooooooooo
o`0?ooooo`0400000?ooool0okK1000000@0okK100?o00000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@020?nf`@;o00002`3o]/42o`0000<0okK10P00000=0?nf`@0400000?l00000okK10?nf`@;o
00000P3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/40okK100H0okK100Co00000?nf
`@3o]/7o00000P3o]/401?l00000okK10?nf`Ol000020?nf`@040000003o]/40okK1o`0000X0okK1
00D000000?nf`@3o]/40okK1000000030?nf`@04o`00003o]/40okK1o`0000<0okK11?l000020?nf
`@;o0000103o]/401Ol00000okK10?nf`@3o]/7o00000080okK100@000000?nf`@3o]/4000000`3o
]/400`000000okK10?nf`@03ooooo`03o`000?oooooooooo01oooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/405@3o]/440000ob00okK100?o003o0?nf`@3o]/40403o]/40
0ol00?l0okK10?nf`@0K0?nf`@030000o`3o]/40okK10180okK100<0003o0?nf`@3o]/402`3o]/4U
ooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000001@3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100<0okK10ol000060?nf`@;o0000103o]/400`000000okK10?nf
`@050?nf`@@000001P3o]/401@000000okK10?nf`@3o]/7o00000080okK100Co00000?nf`Ol0003o
00000P3o]/43o`000080okK10ol000000`3o]/7o0000o`0000020?nf`@;o00000P3o]/401?l00000
okK10?nf`@0000020?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/400P3o]/401?l0
0000okK10?nf`Ol000030?nf`@;o00001@3o]/42o`0000H0okK100Co00000?nf`@3o]/7o00000`3o
]/4010000000okK10?nf`Ol000030?nf`@030000003o]/40okK100?ooooo00<00000ooooooooool0
7oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0j0?nf`@;o003o3P3o
]/42o`00oal0okK100?o003o0000o`3o]/40403o]/400ol00?l0okK10?nf`@0<0?nf`BGooooo00?o
0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/40000000D0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@050?nf`@Ko0000103o]/42000000L0okK100<000000?nf`@3o]/40
0P3o]/43000000@0okK100D000000?nf`@3o]/40okK1o`0000020?nf`@03o`00003o]/40okK100;o
00000`3o]/42o`0000<0okK100Go00000?nf`@3o]/40okK1o`0000030?nf`@04o`00003o]/40okK1
00000080okK100<000000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/40000000<0okK100?o
00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@070?nf`@?o00000P3o]/401Ol00000okK10?nf
`@3o]/40000000<0okK100@000000?nf`@3o]/4000000`3o]/42ooooo`0300000?oooooooooo023o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40?03o]/42o`00o`X0okK1
0_l00?lS0?nf`@030000o`3o]/40okK100`0okK10P000?l?0?nf`BGooooo00?o0000ooooooooool0
3oooool00`00003ooooo0?nf`@020?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/43000000`0okK10P0000070?nf`@800000203o]/400`000000okK10?nf`@020?nf`@050000
003o]/40okK10?nf`Ol000000P3o]/401?l00000okK10?nf`@3o]/43o`000080okK10ol000030?nf
`@05o`00003o]/40okK10?nf`Ol000000P3o]/401@000000okK10?nf`@3o]/40000000d0okK100D0
00000?nf`@3o]/40okK1000000030?nf`@03o`00003o]/40okK10080okK10ol000030?nf`@?o0000
103o]/401Ol00000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK1000000030?nf
`@;ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0n0?nf`@;o003o1P3o]/42o`00obH0okK100<0003o0?nf`@3o]/40203o]/430000oa40
okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100<0okK100<000000?nf`@3o
]/400`3o]/400ol000000000000000040?nf`@@000000P3o]/4500000003o`00003o]/40okK100<0
okK100@00000o`000000000000002`3o]/42000000<0okK100?o00000000003o]/400_l000020?nf
`@?o00000`3o]/42o`0000@0okK10_l000020?nf`@;o00000P3o]/400`000000okK10?nf`@020000
00D0okK1100000060?nf`@050000003o]/40okK10?nf`@0000000`3o]/43o`0000@0okK10ol00006
0?nf`@05o`00003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40000000@0okK1
00?ooooo00000?ooool08_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@100?nf`@Ko003o:@3o]/430000o`@0okK10`000?lD0?nf`BGooooo00?o0000ooooooooool03ooo
ool00`00003ooooo0?nf`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401@3o
]/42000000X0okK100<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@020?nf`@040000003o
]/40okK1o`0000@0okK10ol000020?nf`@Co00000P3o]/42o`0000<0okK100@000000?nf`@3o]/40
00001@3o]/42000000@0okK10P0000050?nf`@060000003o]/40okK10?nf`Ol000000000103o]/40
0ol00000okK10?nf`@070?nf`@?o00000`3o]/401@000000okK10?nf`@3o]/40000000@0okK100<0
00000?nf`@3o]/400P3o]/400oooool00000ooooo`0Rooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK10780okK110000?lG0?nf`BGooooo00?o0000ooooooooool03oooool0
0`00003ooooo0?nf`@050?nf`@030000003o]/40okK100D0okK10`00000=0?nf`@<000004`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100?o0000103o]/42o`0000@0okK10_l00004
0?nf`@040000003o]/40okK1000000D0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK10080okK10P0000030?nf`@Wo0000103o]/42000000<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@0300000?oooooooooo02;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00<00000ooooo`3o]/401P3o]/400ol00000okK10?nf`@070?nf`@0300000?l00000
okK100L0okK10`00000;0?nf`@H000001P3o]/401Ol00000okK10?nf`@3o]/40000000D0okK10_l0
00060?nf`@;o00001@3o]/401?l00000okK10?nf`@0000050?nf`@030000003o]/40okK100P0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100`0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00<00000ooooooooool08_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@2=0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@070?nf`@<00000203o
]/4600000003o`0000000000okK100T0okK1100000050?nf`@03o`0000000000000000D0okK10`00
00000`3o]/40000000000002000000<0okK11_l000050?nf`@8000000P3o]/400`00003o00000?nf
`@030?nf`@03o`00003o]/40okK100X0okK10P0000040?nf`@03o`00003o]/40okK10080okK100?o
00000000000000002@3o]/43000000@0okK10P0000030?nf`@8000001P3o]/400ol0003ooooooooo
o`0Rooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK108d0okK19Oooool0
0ol0003oooooooooo`0?ooooo`0400000?ooool00000000000T0okK10`00000D0?nf`@<00000303o
]/42000000H0okK10P0000030?nf`@8000002@3o]/43000000<0okK100<000000?nf`@3o]/400P3o
]/42000000l0okK100<000000?nf`@3o]/400P3o]/42000000D0okK12@0000040?nf`@<00000103o
]/400`000000okK10?nf`@050?nf`@0300000?oooooooooo02?ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00oooooo00D00000
ooooo`3o]/40okK10000000;0?nf`@8000003`3o]/4300000140okK10P0000060?nf`@030000003o
]/40okK10080okK12@0000040?nf`@800000103o]/400`000000okK10?nf`@0@0?nf`@030000003o
]/40okK100<0okK10P00000?0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o
]/400`000000okK1ooooo`0Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK108d0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<00000
0?nf`@3o]/402P3o]/400`000000okK10?nf`@0:0?nf`@8000005P3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100`0okK10P0000050?nf`@030000003o]/40okK10180okK100<00000
0?nf`@3o]/40103o]/42o`0000/0okK100?o00000000003o]/401@3o]/400`000000okK10?nf`@05
0?nf`@030000003o]/40okK102Gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo]_l0000AoooookH000002_ooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0280112 0.397669 0.000793611 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16387 -0.0125 -3 -9 ]
[.16387 -0.0125 3 0 ]
[.30392 -0.0125 -6 -9 ]
[.30392 -0.0125 6 0 ]
[.44398 -0.0125 -6 -9 ]
[.44398 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.72409 -0.0125 -6 -9 ]
[.72409 -0.0125 6 0 ]
[.86415 -0.0125 -6 -9 ]
[.86415 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00086 -24 -4.5 ]
[-0.0125 .00086 0 4.5 ]
[-0.0125 .08022 -24 -4.5 ]
[-0.0125 .08022 0 4.5 ]
[-0.0125 .15959 -24 -4.5 ]
[-0.0125 .15959 0 4.5 ]
[-0.0125 .23895 -24 -4.5 ]
[-0.0125 .23895 0 4.5 ]
[-0.0125 .31831 -24 -4.5 ]
[-0.0125 .31831 0 4.5 ]
[-0.0125 .39767 -6 -4.5 ]
[-0.0125 .39767 0 4.5 ]
[-0.0125 .47703 -18 -4.5 ]
[-0.0125 .47703 0 4.5 ]
[-0.0125 .55639 -18 -4.5 ]
[-0.0125 .55639 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.16387 0 m
.16387 .61803 L
s
.30392 0 m
.30392 .61803 L
s
.44398 0 m
.44398 .61803 L
s
.58403 0 m
.58403 .61803 L
s
.72409 0 m
.72409 .61803 L
s
.86415 0 m
.86415 .61803 L
s
0 .08022 m
1 .08022 L
s
0 .15959 m
1 .15959 L
s
0 .23895 m
1 .23895 L
s
0 .31831 m
1 .31831 L
s
0 .39767 m
1 .39767 L
s
0 .47703 m
1 .47703 L
s
0 .55639 m
1 .55639 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16387 0 m
.16387 .00625 L
s
[(5)] .16387 -0.0125 0 1 Mshowa
.30392 0 m
.30392 .00625 L
s
[(10)] .30392 -0.0125 0 1 Mshowa
.44398 0 m
.44398 .00625 L
s
[(15)] .44398 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(20)] .58403 -0.0125 0 1 Mshowa
.72409 0 m
.72409 .00625 L
s
[(25)] .72409 -0.0125 0 1 Mshowa
.86415 0 m
.86415 .00625 L
s
[(30)] .86415 -0.0125 0 1 Mshowa
.125 Mabswid
.05182 0 m
.05182 .00375 L
s
.07983 0 m
.07983 .00375 L
s
.10784 0 m
.10784 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.19188 0 m
.19188 .00375 L
s
.21989 0 m
.21989 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.27591 0 m
.27591 .00375 L
s
.33193 0 m
.33193 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.38796 0 m
.38796 .00375 L
s
.41597 0 m
.41597 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.5 0 m
.5 .00375 L
s
.52801 0 m
.52801 .00375 L
s
.55602 0 m
.55602 .00375 L
s
.61204 0 m
.61204 .00375 L
s
.64006 0 m
.64006 .00375 L
s
.66807 0 m
.66807 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.7521 0 m
.7521 .00375 L
s
.78011 0 m
.78011 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.83613 0 m
.83613 .00375 L
s
.89216 0 m
.89216 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.94818 0 m
.94818 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00086 m
.00625 .00086 L
s
[(-500)] -0.0125 .00086 1 0 Mshowa
0 .08022 m
.00625 .08022 L
s
[(-400)] -0.0125 .08022 1 0 Mshowa
0 .15959 m
.00625 .15959 L
s
[(-300)] -0.0125 .15959 1 0 Mshowa
0 .23895 m
.00625 .23895 L
s
[(-200)] -0.0125 .23895 1 0 Mshowa
0 .31831 m
.00625 .31831 L
s
[(-100)] -0.0125 .31831 1 0 Mshowa
0 .39767 m
.00625 .39767 L
s
[(0)] -0.0125 .39767 1 0 Mshowa
0 .47703 m
.00625 .47703 L
s
[(100)] -0.0125 .47703 1 0 Mshowa
0 .55639 m
.00625 .55639 L
s
[(200)] -0.0125 .55639 1 0 Mshowa
.125 Mabswid
0 .01674 m
.00375 .01674 L
s
0 .03261 m
.00375 .03261 L
s
0 .04848 m
.00375 .04848 L
s
0 .06435 m
.00375 .06435 L
s
0 .0961 m
.00375 .0961 L
s
0 .11197 m
.00375 .11197 L
s
0 .12784 m
.00375 .12784 L
s
0 .14371 m
.00375 .14371 L
s
0 .17546 m
.00375 .17546 L
s
0 .19133 m
.00375 .19133 L
s
0 .2072 m
.00375 .2072 L
s
0 .22307 m
.00375 .22307 L
s
0 .25482 m
.00375 .25482 L
s
0 .27069 m
.00375 .27069 L
s
0 .28656 m
.00375 .28656 L
s
0 .30244 m
.00375 .30244 L
s
0 .33418 m
.00375 .33418 L
s
0 .35005 m
.00375 .35005 L
s
0 .36592 m
.00375 .36592 L
s
0 .3818 m
.00375 .3818 L
s
0 .41354 m
.00375 .41354 L
s
0 .42941 m
.00375 .42941 L
s
0 .44529 m
.00375 .44529 L
s
0 .46116 m
.00375 .46116 L
s
0 .4929 m
.00375 .4929 L
s
0 .50877 m
.00375 .50877 L
s
0 .52465 m
.00375 .52465 L
s
0 .54052 m
.00375 .54052 L
s
0 .57226 m
.00375 .57226 L
s
0 .58814 m
.00375 .58814 L
s
0 .60401 m
.00375 .60401 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.16387 .61178 m
.16387 .61803 L
s
.30392 .61178 m
.30392 .61803 L
s
.44398 .61178 m
.44398 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.72409 .61178 m
.72409 .61803 L
s
.86415 .61178 m
.86415 .61803 L
s
.125 Mabswid
.05182 .61428 m
.05182 .61803 L
s
.07983 .61428 m
.07983 .61803 L
s
.10784 .61428 m
.10784 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.19188 .61428 m
.19188 .61803 L
s
.21989 .61428 m
.21989 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.27591 .61428 m
.27591 .61803 L
s
.33193 .61428 m
.33193 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.38796 .61428 m
.38796 .61803 L
s
.41597 .61428 m
.41597 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52801 .61428 m
.52801 .61803 L
s
.55602 .61428 m
.55602 .61803 L
s
.61204 .61428 m
.61204 .61803 L
s
.64006 .61428 m
.64006 .61803 L
s
.66807 .61428 m
.66807 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.7521 .61428 m
.7521 .61803 L
s
.78011 .61428 m
.78011 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.83613 .61428 m
.83613 .61803 L
s
.89216 .61428 m
.89216 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.94818 .61428 m
.94818 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00086 m
1 .00086 L
s
.99375 .08022 m
1 .08022 L
s
.99375 .15959 m
1 .15959 L
s
.99375 .23895 m
1 .23895 L
s
.99375 .31831 m
1 .31831 L
s
.99375 .39767 m
1 .39767 L
s
.99375 .47703 m
1 .47703 L
s
.99375 .55639 m
1 .55639 L
s
.125 Mabswid
.99625 .01674 m
1 .01674 L
s
.99625 .03261 m
1 .03261 L
s
.99625 .04848 m
1 .04848 L
s
.99625 .06435 m
1 .06435 L
s
.99625 .0961 m
1 .0961 L
s
.99625 .11197 m
1 .11197 L
s
.99625 .12784 m
1 .12784 L
s
.99625 .14371 m
1 .14371 L
s
.99625 .17546 m
1 .17546 L
s
.99625 .19133 m
1 .19133 L
s
.99625 .2072 m
1 .2072 L
s
.99625 .22307 m
1 .22307 L
s
.99625 .25482 m
1 .25482 L
s
.99625 .27069 m
1 .27069 L
s
.99625 .28656 m
1 .28656 L
s
.99625 .30244 m
1 .30244 L
s
.99625 .33418 m
1 .33418 L
s
.99625 .35005 m
1 .35005 L
s
.99625 .36592 m
1 .36592 L
s
.99625 .3818 m
1 .3818 L
s
.99625 .41354 m
1 .41354 L
s
.99625 .42941 m
1 .42941 L
s
.99625 .44529 m
1 .44529 L
s
.99625 .46116 m
1 .46116 L
s
.99625 .4929 m
1 .4929 L
s
.99625 .50877 m
1 .50877 L
s
.99625 .52465 m
1 .52465 L
s
.99625 .54052 m
1 .54052 L
s
.99625 .57226 m
1 .57226 L
s
.99625 .58814 m
1 .58814 L
s
.99625 .60401 m
1 .60401 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.05182 .26281 L
.07983 .30527 L
.10784 .33581 L
.13585 .36749 L
.16387 .40094 L
.19188 .4333 L
.21989 .46252 L
.2479 .49009 L
.27591 .51549 L
.30392 .53365 L
.33193 .54491 L
.35994 .55174 L
.38796 .55691 L
.41597 .56249 L
.44398 .57052 L
.47199 .58108 L
.5 .58802 L
.52801 .59049 L
.55602 .59181 L
.58403 .59287 L
.61204 .59383 L
.64006 .59474 L
.66807 .59562 L
.69608 .59649 L
.72409 .59734 L
.7521 .59817 L
.78011 .59896 L
.80812 .59972 L
.83613 .60043 L
.86415 .6011 L
.89216 .60172 L
.92017 .6023 L
.94818 .60283 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.05182 .26281 Mdot
.07983 .30527 Mdot
.10784 .33581 Mdot
.13585 .36749 Mdot
.16387 .40094 Mdot
.19188 .4333 Mdot
.21989 .46252 Mdot
.2479 .49009 Mdot
.27591 .51549 Mdot
.30392 .53365 Mdot
.33193 .54491 Mdot
.35994 .55174 Mdot
.38796 .55691 Mdot
.41597 .56249 Mdot
.44398 .57052 Mdot
.47199 .58108 Mdot
.5 .58802 Mdot
.52801 .59049 Mdot
.55602 .59181 Mdot
.58403 .59287 Mdot
.61204 .59383 Mdot
.64006 .59474 Mdot
.66807 .59562 Mdot
.69608 .59649 Mdot
.72409 .59734 Mdot
.7521 .59817 Mdot
.78011 .59896 Mdot
.80812 .59972 Mdot
.83613 .60043 Mdot
.86415 .6011 Mdot
.89216 .60172 Mdot
.92017 .6023 Mdot
.94818 .60283 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`00027ooooo0ol0000Oooooo`?o0000
1?ooool2o`0001_ooooo0ol00003ooooo`?o00006_ooool5o`0000?ooooo0_l0000Kooooo`Go0000
0_ooool3o`0001_ooooo0ol00004ooooo`;o00008Oooool001oooooo00Co0000oooooooooooo0000
7oooool01Ol0003ooooooooooooooooo000001oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Kooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0H
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00008?ooool001oooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
6oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01kooooo000Oooooo`04
o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0J
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06Oooool2o`0000?ooooo00Co0000oooooooooooo0000
8?ooool001oooooo00Co0000oooooooooooo00007oooool4o`00023ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Kooooo`04o`000?ooooooooooooooo`Co00006_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006_ooool01_l0003ooooooooo
oooooooo0000ooooo`Co00007_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
01kooooo000Oooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool08?ooool2o`00
00Cooooo00Co0000oooooooooooo00006_ooool2o`0000?ooooo00?o0000ooooooooool06oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006_ooool01ol0003ooooo
oooooooooooo0000ooooool000007Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00008?ooool0023ooooo0_l0000Pooooo`Go00007oooool00ol0003oooooooooo`03
ooooo`;o00007?ooool01?l0003oooooooooooooool5o`0001[ooooo0ol00004ooooo`;o00007?oo
ool3o`0000;ooooo1Ol0000Jooooo`?o00001?ooool2o`00027ooooo003oooooob7ooooo003ooooo
ob7ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo0006ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`000?oooooo2_ooool000Go00001Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o0000o`00003oo`00007o00000@00
0001ooooo`002_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool10000007ooooo0006ooooo`Co00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00_ooool3ool002;o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023o
oooo0@000001ooooo`001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool01000003oooooooooooooool5ool0027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001
ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool01000003o0000ooooooooool5
ool0027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo01oooooo0Ol000010000007ooooo000Kooooo`0400000?ooooooooooooooo`Goo`008Oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool1
0000007ooooo000Kooooo`0300000?oooooooooo00;ooooo0ooo000Rooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_o
oooo00<00000ooooooooool00oooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo
00<00000o`000?ooool00oooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Oooooo`7o00000@000001ooooo`006ooo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool08_ooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00003o0000
ooooo`04ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo01oooooo0Ol000010000007ooooo000Kooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooooooo
00Cooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?l0003ooooo00Co
oooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool07oooool1o`00004000000Oooool000Sooooo0ol00003ooooo`;o0000
1?ooool2o`0000Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Pooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`400000
0Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo01oo
oooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023o
oooo0@000001ooooo`001Ol000000ooooooo0000o`000003o`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool07oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08?ooool10000007ooooo0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o00D0001o00<0
00000000O`0007l0m`0007l1o`00004000000Oooool000Oooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool0
8Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool000Sooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`03
00000?oooooooooo01oooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo023ooooo0@000001ooooo`002Oooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Oooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`400000
0Oooool001_ooooo00<00000o`000?ooool01Oooool00`00003oooooooooo`0Oooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Oooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo01oooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001
ooooo`006oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo01oooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001oooo
o`006oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo01kooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`00
6oooool00`00003o0000ooooo`06ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo01oooooo0Ol000010000007ooooo
000Kooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool07_ooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000K
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Koooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`03
00000?l0003ooooo00Kooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool07oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000o`00
0?ooool01oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Oooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01gooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo
0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool07Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08?ooool10000007ooooo0005o`0000Gooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l01`0007l0
0`000000001o0000O`3e0000O`7o00000@000001ooooo`002?ooool2o`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool07Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08?ooool10000007ooooo000:ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool07Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08?ooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool000Oooooo0ol00004ooooo`;o
00001?ooool2o`0000Gooooo00<00000o`000?ooool01oooool00`00003oooooooooo`0Mooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Oooooo`7o
00000@000001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01cooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo
0@000001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01cooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01cooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001
ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01cooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001oooo
o`006oooool00`00003o0000ooooo`08ooooo`0300000?oooooooooo01cooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo01oooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool07?ooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo
000Kooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool07?ooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000K
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Koooo
o`0300000?l0003ooooo00Sooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool07oooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo
00<00000ooooooooool02Oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000
o`000?ooool02Oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Oooooo`7o00000@000001ooooo`001_ooool5o`00
00?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo
01_ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
023ooooo0@000001ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo01_ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo023ooooo0@000001ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool06oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08?ooool10000007ooooo0009ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`000000
07l02@0007l00`000000001o0000O`3c0000O`7o00000@000001ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0R
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo0006oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Jooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`400000
0Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool02_oo
ool00`00003oooooooooo`0Jooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000o`000?ooool02Oooool3
ool001_ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo01oooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Sooooo1Ooo000Joooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Poooo
o`4000000Oooool001_ooooo00<00000ooooooooool02?ooool5ool001[ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`00
6oooool00`00003oooooooooo`08ooooo`Goo`006_ooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?l0
003ooooo00Wooooo0ooo000Kooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Oooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Q
ooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00003oooooooooo`0<oooo
o`0300000?oooooooooo01Sooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00003oooooooooo`0=ooooo`03
00000?oooooooooo01Oooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0>ooooo`030000
0?oooooooooo01Kooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo01oooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00kooooo00<0
0000ooooooooool05_ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool05Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00@00000ool0
0?oo003oo`005?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001o
ooooooooool08?ooool10000007ooooo000Kooooo`0300000?l0003ooooo00oooooo1Ooo000Coooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qoooo
o`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Ooooo
o`7o00000@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`Goo`004oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007o
oooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00oooooo
1Ooo000Cooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Pooooo`4000000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool04?ooool3ool00003
00000?oooooooooo017ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo023ooooo0@000001ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool04?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08?ooool10000007ooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000
001o01D0001o00<000000000O`0007l0i`0007l1o`00004000000Oooool000Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool05_ooool00`00003oooooooooo`0>ooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool000Oooooo0_l00004
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0Gooooo`0400000?oo003oo`00ool000cooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`002?ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool05oooool5ool000_ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo
0@000001ooooo`006oooool00`00003o0000ooooo`0Gooooo`Goo`002oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool07oooool1o`00004000000Ooo
ool001_ooooo00<00000ooooooooool05oooool5ool000_ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Hooooo`?oo`003?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooooooo01_o
oooo00<00000ooooooooool02Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?l0003ooooo01cooooo
00<00000ooooooooool02?ooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool07oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool07Ooo
ool00`00003oooooooooo`07ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000ooooooooool07_ooool0
1000003oo`00ool00?oo0005ooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000ooooooooool07_ooool5
ool000Cooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo023ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Nooooo`Goo`001?ooool00`00
07ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool07oooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool07_ooool5ool000Cooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0Oooooo`?oo`001Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo02;ooooo00<00000ooooooooool00_ooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?l0003o
oooo02?ooooo00D00000oooooooooooooooo0000O`0Tooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool07oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool09?ooool0
1000003oooooooooo`0007lTooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?oo
ool10000007ooooo000Dooooo`;o00001Oooool00`00003oooooooooo`0Tooooo`0400000?oooooo
oooo0000ObCooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Uooooo`0400000?oo
003oo`00ool002?ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`400000
0Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`0U0000O`Goo`00
e@0007l1o`00004000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0Uooooo`Goo`008_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo
0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Gooooo
1Ooo000Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool09_ooool3ool000030000
0?oooooooooo023ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`400000
0Oooool001Cooooo0_l00005ooooo`0300000?l0003ooooo02Oooooo00@0001oooooooooool00000
8Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo01oooooo0Ol000010000007ooooo
000Kooooo`0300000?oooooooooo02Oooooo00D0001ooooooooooooooooo0000000Pooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo02Oooooo00<0001oooooooooool00_ooool00`00003oooooooooo`0Mooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooo
oooo02Oooooo00<0001oooooooooool00oooool01000003oo`00ool00?oo000Kooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?l0003o
oooo02Oooooo00<0001oooooooooool00oooool5ool001[ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Oooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Woooo
o`030000Oooooooooooo00?ooooo1Ooo000Jooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001ooooo
ooooool08?ooool10000007ooooo000Kooooo`0300000?oooooooooo02Oooooo00<0001ooooooooo
ool00oooool5ool001[ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`40
00000Oooool001_ooooo00<00000ooooooooool09oooool00`0007ooooooooooo`04ooooo`?oo`00
6oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Wooooo`030000Oooooooooooo00Oooooo00<00000ooooooooool06?oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_oo
ool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool0
0`00003o0000ooooo`0Wooooo`030000Oooooooooooo00Sooooo00<00000ooooooooool05oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo01oooooo0Ol000010000007ooooo000Koooo
o`0300000?oooooooooo02Oooooo00<0001oooooooooool02Oooool00`00003oooooooooo`0Foooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`03
00000?oooooooooo02Oooooo00<0001oooooooooool02_ooool01000003oo`00ool00?oo000Doooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`03
00000?oooooooooo02Oooooo00<0001oooooooooool02_ooool5ool001?ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0001ooooooooo
ool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000o`000?ooool0
9oooool00`0007ooooooooooo`0:ooooo`Goo`004oooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo01oooooo0Ol000010000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool02_ooool5ool001?ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool09oooool00`0007ooooooooooo`0;ooooo`?oo`0000<00000ooooooooool0
4Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo00oooooo00<00000oooooooo
ool04?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001ooooooooo
ool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`00
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003o00000000O`0j0000O`030000000007l0001o0<80001o0Ol000010000
007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool04Oooool0
1000003oo`00ool00?oo000=ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?oo
ool10000007ooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Aooooo`Goo`00
3?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool0
8_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`002?oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool09ooo
ool00`0007ooooooooooo`0Aooooo`Goo`003?ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo023ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Wooooo`030000Oooooooo
oooo017ooooo1Ooo000<ooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool07oooool1
o`00004000000Oooool001_ooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Boooo
o`?oo`0000<00000ooooooooool02_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo
023ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo01Ko
oooo00<00000ooooooooool02Oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023o
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo01Oooooo
00<00000ooooooooool02?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo
0@000001ooooo`006oooool00`00003o0000ooooo`0Wooooo`030000Oooooooooooo01Sooooo00@0
0000ool00?oo003oo`001_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo01oooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool06?oo
ool5ool000Gooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Hooooo`Goo`001Oooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Wooooo`030000Oooooooooooo01Sooooo1Ooo00000`00003oooooooooo`02oooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Roooo
o`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`03
00000?l0003ooooo02Oooooo00<0001oooooooooool06Oooool3ool000;ooooo0P000002ooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`03
0000Oooooooooooo027ooooo00<0001oooooooooool07oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool09oooool00`0007ooooooooooo`0Pooooo`0400000?oo003oo`00ool002;o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool08?ooool10000007ooooo000Kooooo`0300000?oooooooooo02Oooooo
00<0001oooooooooool08?ooool5ool0027ooooo00<0001oooooooooool08Oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool10000007ooooo
000Kooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool08?ooool5ool00080000000Co
ooooool00?oo003oo`006oooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;ooooo
00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_ooooo00<0
0000o`000?ooool09oooool00`0007ooooooooooo`0Pooooo`Goo`000_ooool5ool001[ooooo00<0
001oooooooooool08Oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0
001oooooooooool07oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool09oooool0
0`0007ooooooooooo`0Qooooo`?oo`000oooool5ool000?ooooo0ooo000Dooooo`030000Oooooooo
oooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooo
oooo023ooooo0@000001ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00
003oooooooooo`0Wooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool00_ooool5ool0
008000001Ooo000Cooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`00
07ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`001oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Wooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool00ooo
ool3ool000?ooooo1Ooo0003ooooo`?oo`003Oooool00`0007ooooooooooo`0Qooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Ooo
ool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000o`00000007l0F00007l5ool0008000001Ooo00040000O`?oo`00
U00007l1o`00004000000Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0Wooooo`03
0000Oooooooooooo02;ooooo00<0001oooooooooool02_ooool3ool000?ooooo1Ooo000200000003
oooooooo003oo`0000?oo`001?ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo02;o
oooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool000Kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo02;ooooo00<0001o
ooooooooool04?ooool5ool000;ooooo00<00000ool00?oo00000ooo0003ooooo`?oo`008_ooool0
0`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?ooool1
0000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool09oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo017ooooo0ooo0004ooooo`Goo`000P000005ool0027ooooo
00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo
0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003o0000oooo
o`0Wooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool06Oooool3ool000?ooooo1Ooo
000Qooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oooooooooo
o`0Oooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Wooooo`030000Oooooooo
oooo02;ooooo00<0001oooooooooool07oooool5ool00080000000Coooooool00?oo003oo`006ooo
ool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool08?oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02Oooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Pooooo`?oo`000oooool5ool001[ooooo00<0001oooooooooool08_ooool0
0`0007ooooooooooo`0Qooooo`030000Oooooooooooo023ooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Wooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`00
07ooooooooooo`02ooooo`Goo`000oooool3ool000Gooooo0ooo000<ooooo`030000Oooooooooooo
02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`0Pooooo`4000000Oooool001_o
oooo00<00000ooooooooool09oooool00`0007ooooooooooo`0Rooooo`030000Oooooooooooo027o
oooo00<0001oooooooooool00_ooool5ool0008000001Ooo0003ooooo`Goo`000oooool3ool000Co
oooo0ooo0005ooooo`?oo`001?ooool3ool001Cooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Pooooo`4000000Oooool001_ooooo00<00000o`000?ooool09oooool00`0007oooooo
ooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool00oooool3ool000?ooooo
1Ooo0003000000Goo`000P000005ool000;ooooo1Ooo0003ooooo`Goo`000_ooool5ool000?ooooo
0ooo0004ooooo`?oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`005?ooool00`0007oooooo
ooooo`0Oooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Wooooo`030000Oooo
oooooooo02;ooooo00<0001oooooooooool08Oooool00`0007ooooooooooo`09ooooo`Goo`000ooo
ool5ool000;ooooo1Ooo0002000000Goo`000`000005ool0008000001Ooo0002000000Goo`000_oo
ool5ool000?ooooo1Ooo0002ooooo`Goo`000_ooool5ool000?ooooo0ooo0005ooooo`?oo`001?oo
ool3ool000Cooooo0ooo0005ooooo`?oo`001?ooool3ool000_ooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0Wooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool0
0`0007ooooooooooo`0:ooooo`?oo`001Oooool3ool000?ooooo1Ooo0002ooooo`Goo`000oooool5
ool000;ooooo1Ooo0002ooooo`Goo`000P000005ool000<000001Ooo0002000000Goo`000P000005
ool0008000001Ooo0003ooooo`Goo`000_ooool5ool000;ooooo1Ooo0003ooooo`Goo`000_ooool5
ool000?ooooo0ooo0004ooooo`4000000Oooool001_ooooo00<00000ooooooooool09oooool00`00
07ooooooooooo`0Rooooo`030000Oooooooooooo027ooooo00<0001oooooooooool06Oooool3ool0
00Cooooo0ooo0005ooooo`?oo`001?ooool3ool000?ooooo1Ooo0002ooooo`Goo`000oooool5ool0
00;ooooo1Ooo0002ooooo`Goo`000_ooool5ool000<000001Ooo0002000000Goo`000P000005ool0
00<000001Ooo0002000000Goo`000P000005ool000?ooooo0@000001ooooo`006oooool00`00003o
0000ooooo`0Wooooo`030000Oooooooooooo02;ooooo00<0001oooooooooool08Oooool00`0007oo
ooooooooo`0Qooooo`030000Oooooooooooo01;ooooo0ooo0004ooooo`?oo`001Oooool3ool000Co
oooo0ooo0004ooooo`?oo`000oooool5ool000?ooooo1Ooo0002ooooo`Goo`000_ooool5ool000?o
oooo1Ooo0002ooooo`Goo`000_ooool5ool000;ooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo02Oooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Qooooo`030000
Oooooooooooo027ooooo00<0001oooooooooool08_ooool00`0007ooooooooooo`0Aooooo`?oo`00
1Oooool3ool000Cooooo0ooo0004ooooo`?oo`001Oooool3ool000Cooooo0ooo0003ooooo`Goo`00
0oooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool3ool000Cooooo0@000001ooooo`006ooooooo000000D000000Oooool00?oooooo8Oooool00?oo
oooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.59655, -570.796, \
0.137505, 4.85336}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(scalar1\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #2: red class, full covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes full covariance matrices", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 4;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[data1, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.19999999999998863`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PolygonalAllPlot[poly, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .79903 m
.02002 .78846 L
.02233 .76923 L
.0258 .75 L
.03046 .73077 L
.03638 .71154 L
.03846 .70562 L
.04361 .69231 L
.05219 .67308 L
.05769 .66219 L
.06228 .65385 L
.07402 .63462 L
.07692 .63027 L
.08763 .61538 L
.09615 .60461 L
.10335 .59615 L
.11538 .58315 L
.12158 .57692 L
.13462 .56481 L
.14288 .55769 L
.15385 .54894 L
.16811 .53846 L
.17308 .53508 L
.19231 .52298 L
.19878 .51923 L
.21154 .51242 L
.23077 .50317 L
.23798 .5 L
.25 .49518 L
.26923 .48829 L
.28846 .48238 L
.29429 .48077 L
.30769 .47749 L
.32692 .47348 L
.34615 .47028 L
.36538 .46785 L
.38462 .46614 L
.40385 .46513 L
.42308 .46477 L
.44231 .46501 L
.46154 .4658 L
.48077 .46712 L
.5 .46892 L
.51923 .47116 L
.53846 .47382 L
.55769 .47687 L
.57692 .48029 L
.57944 .48077 L
.59615 .4841 L
.61538 .48829 L
.63462 .4929 L
.65385 .49796 L
.66111 .5 L
.67308 .50353 L
.69231 .50969 L
.71154 .51651 L
.71866 .51923 L
.73077 .52409 L
.75 .53252 L
.7624 .53846 L
.76923 .54191 L
.78846 .55236 L
.79752 .55769 L
.80769 .56401 L
.82681 .57692 L
.82692 .577 L
.84615 .59152 L
.85187 .59615 L
.86538 .60778 L
.87365 .61538 L
.88462 .62611 L
.89278 .63462 L
.90385 .64694 L
.90967 .65385 L
.92308 .67096 L
.92464 .67308 L
.93789 .69231 L
.94231 .69928 L
.94959 .71154 L
.95987 .73077 L
.96154 .73415 L
.96882 .75 L
.97652 .76923 L
.98077 .78138 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .79903 m
.02002 .78846 L
.02233 .76923 L
.0258 .75 L
.03046 .73077 L
.03638 .71154 L
.03846 .70562 L
.04361 .69231 L
.05219 .67308 L
.05769 .66219 L
.06228 .65385 L
.07402 .63462 L
.07692 .63027 L
.08763 .61538 L
.09615 .60461 L
.10335 .59615 L
.11538 .58315 L
.12158 .57692 L
.13462 .56481 L
.14288 .55769 L
.15385 .54894 L
.16811 .53846 L
.17308 .53508 L
.19231 .52298 L
.19878 .51923 L
.21154 .51242 L
.23077 .50317 L
.23798 .5 L
.25 .49518 L
.26923 .48829 L
.28846 .48238 L
.29429 .48077 L
.30769 .47749 L
.32692 .47348 L
.34615 .47028 L
.36538 .46785 L
.38462 .46614 L
.40385 .46513 L
.42308 .46477 L
.44231 .46501 L
.46154 .4658 L
.48077 .46712 L
.5 .46892 L
.51923 .47116 L
.53846 .47382 L
.55769 .47687 L
.57692 .48029 L
.57944 .48077 L
.59615 .4841 L
.61538 .48829 L
Mistroke
.63462 .4929 L
.65385 .49796 L
.66111 .5 L
.67308 .50353 L
.69231 .50969 L
.71154 .51651 L
.71866 .51923 L
.73077 .52409 L
.75 .53252 L
.7624 .53846 L
.76923 .54191 L
.78846 .55236 L
.79752 .55769 L
.80769 .56401 L
.82681 .57692 L
.82692 .577 L
.84615 .59152 L
.85187 .59615 L
.86538 .60778 L
.87365 .61538 L
.88462 .62611 L
.89278 .63462 L
.90385 .64694 L
.90967 .65385 L
.92308 .67096 L
.92464 .67308 L
.93789 .69231 L
.94231 .69928 L
.94959 .71154 L
.95987 .73077 L
.96154 .73415 L
.96882 .75 L
.97652 .76923 L
.98077 .78138 L
Mfstroke
.01923 .83954 m
.01968 .84615 L
.02174 .86538 L
.0249 .88462 L
.0292 .90385 L
.03466 .92308 L
.03846 .93448 L
.04132 .94231 L
.04919 .96154 L
.05769 .97959 L
.05829 .98077 L
.01923 .98077 L
F
.01923 .83954 m
.01968 .84615 L
.02174 .86538 L
.0249 .88462 L
.0292 .90385 L
.03466 .92308 L
.03846 .93448 L
.04132 .94231 L
.04919 .96154 L
.05769 .97959 L
.05829 .98077 L
s
.2 g
.71913 .98077 m
.72614 .96154 L
.73077 .945 L
.73137 .94231 L
.73487 .92308 L
.73674 .90385 L
.73703 .88462 L
.73576 .86538 L
.73296 .84615 L
.73077 .83525 L
.72861 .82692 L
.72269 .80769 L
.71519 .78846 L
.71154 .7803 L
.70604 .76923 L
.69517 .75 L
.69231 .74538 L
.68246 .73077 L
.67308 .71814 L
.66779 .71154 L
.65385 .69544 L
.65093 .69231 L
.63462 .67591 L
.63159 .67308 L
.61538 .65879 L
.60935 .65385 L
.59615 .64364 L
.58354 .63462 L
.57692 .63015 L
.55769 .61812 L
.55299 .61538 L
.53846 .60743 L
.51923 .59794 L
.51533 .59615 L
.5 .58963 L
.48077 .58241 L
.46384 .57692 L
.46154 .57625 L
.44231 .57119 L
.42308 .56715 L
.40385 .56416 L
.38462 .56223 L
.36538 .56139 L
.34615 .56166 L
.32692 .56308 L
.30769 .56571 L
.28846 .5696 L
.26923 .57482 L
.26265 .57692 L
.25 .58153 L
.23077 .58986 L
.21835 .59615 L
.21154 .59998 L
.19231 .61221 L
.18784 .61538 L
.17308 .62694 L
.16434 .63462 L
.15385 .6448 L
.14544 .65385 L
.13462 .66687 L
.12994 .67308 L
.11716 .69231 L
.11538 .6953 L
.10667 .71154 L
.09815 .73077 L
.09615 .73593 L
.09142 .75 L
.08631 .76923 L
.08271 .78846 L
.08056 .80769 L
.07982 .82692 L
.08044 .84615 L
.08243 .86538 L
.08579 .88462 L
.09052 .90385 L
.09615 .92165 L
.09667 .92308 L
.10433 .94231 L
.11353 .96154 L
.11538 .96505 L
.12442 .98077 L
F
0 g
.71913 .98077 m
.72614 .96154 L
.73077 .945 L
.73137 .94231 L
.73487 .92308 L
.73674 .90385 L
.73703 .88462 L
.73576 .86538 L
.73296 .84615 L
.73077 .83525 L
.72861 .82692 L
.72269 .80769 L
.71519 .78846 L
.71154 .7803 L
.70604 .76923 L
.69517 .75 L
.69231 .74538 L
.68246 .73077 L
.67308 .71814 L
.66779 .71154 L
.65385 .69544 L
.65093 .69231 L
.63462 .67591 L
.63159 .67308 L
.61538 .65879 L
.60935 .65385 L
.59615 .64364 L
.58354 .63462 L
.57692 .63015 L
.55769 .61812 L
.55299 .61538 L
.53846 .60743 L
.51923 .59794 L
.51533 .59615 L
.5 .58963 L
.48077 .58241 L
.46384 .57692 L
.46154 .57625 L
.44231 .57119 L
.42308 .56715 L
.40385 .56416 L
.38462 .56223 L
.36538 .56139 L
.34615 .56166 L
.32692 .56308 L
.30769 .56571 L
.28846 .5696 L
.26923 .57482 L
.26265 .57692 L
.25 .58153 L
Mistroke
.23077 .58986 L
.21835 .59615 L
.21154 .59998 L
.19231 .61221 L
.18784 .61538 L
.17308 .62694 L
.16434 .63462 L
.15385 .6448 L
.14544 .65385 L
.13462 .66687 L
.12994 .67308 L
.11716 .69231 L
.11538 .6953 L
.10667 .71154 L
.09815 .73077 L
.09615 .73593 L
.09142 .75 L
.08631 .76923 L
.08271 .78846 L
.08056 .80769 L
.07982 .82692 L
.08044 .84615 L
.08243 .86538 L
.08579 .88462 L
.09052 .90385 L
.09615 .92165 L
.09667 .92308 L
.10433 .94231 L
.11353 .96154 L
.11538 .96505 L
.12442 .98077 L
Mfstroke
.3 g
.6434 .98077 m
.65143 .96154 L
.65385 .95465 L
.65737 .94231 L
.66139 .92308 L
.66363 .90385 L
.66416 .88462 L
.66301 .86538 L
.6602 .84615 L
.65574 .82692 L
.65385 .82029 L
.64956 .80769 L
.6416 .78846 L
.63462 .77438 L
.63178 .76923 L
.61992 .75 L
.61538 .74344 L
.60582 .73077 L
.59615 .71921 L
.58918 .71154 L
.57692 .69917 L
.56952 .69231 L
.55769 .68216 L
.5461 .67308 L
.53846 .66753 L
.51923 .65488 L
.51753 .65385 L
.5 .64397 L
.4808 .63462 L
.48077 .6346 L
.46154 .6267 L
.44231 .62014 L
.42512 .61538 L
.42308 .6149 L
.40385 .61097 L
.38462 .60831 L
.36538 .60694 L
.34615 .60688 L
.32692 .6082 L
.30769 .61094 L
.28846 .6152 L
.28774 .61538 L
.26923 .62114 L
.25 .6289 L
.2383 .63462 L
.23077 .63876 L
.21154 .6511 L
.20777 .65385 L
.19231 .66651 L
.18529 .67308 L
.17308 .68601 L
.16781 .69231 L
.15394 .71154 L
.15385 .71168 L
.14294 .73077 L
.13462 .74925 L
.13432 .75 L
.12782 .76923 L
.12319 .78846 L
.12031 .80769 L
.1191 .82692 L
.11949 .84615 L
.12147 .86538 L
.12504 .88462 L
.13022 .90385 L
.13462 .91681 L
.13706 .92308 L
.14568 .94231 L
.15385 .95758 L
.15618 .96154 L
.16876 .98077 L
F
0 g
.6434 .98077 m
.65143 .96154 L
.65385 .95465 L
.65737 .94231 L
.66139 .92308 L
.66363 .90385 L
.66416 .88462 L
.66301 .86538 L
.6602 .84615 L
.65574 .82692 L
.65385 .82029 L
.64956 .80769 L
.6416 .78846 L
.63462 .77438 L
.63178 .76923 L
.61992 .75 L
.61538 .74344 L
.60582 .73077 L
.59615 .71921 L
.58918 .71154 L
.57692 .69917 L
.56952 .69231 L
.55769 .68216 L
.5461 .67308 L
.53846 .66753 L
.51923 .65488 L
.51753 .65385 L
.5 .64397 L
.4808 .63462 L
.48077 .6346 L
.46154 .6267 L
.44231 .62014 L
.42512 .61538 L
.42308 .6149 L
.40385 .61097 L
.38462 .60831 L
.36538 .60694 L
.34615 .60688 L
.32692 .6082 L
.30769 .61094 L
.28846 .6152 L
.28774 .61538 L
.26923 .62114 L
.25 .6289 L
.2383 .63462 L
.23077 .63876 L
.21154 .6511 L
.20777 .65385 L
.19231 .66651 L
.18529 .67308 L
Mistroke
.17308 .68601 L
.16781 .69231 L
.15394 .71154 L
.15385 .71168 L
.14294 .73077 L
.13462 .74925 L
.13432 .75 L
.12782 .76923 L
.12319 .78846 L
.12031 .80769 L
.1191 .82692 L
.11949 .84615 L
.12147 .86538 L
.12504 .88462 L
.13022 .90385 L
.13462 .91681 L
.13706 .92308 L
.14568 .94231 L
.15385 .95758 L
.15618 .96154 L
.16876 .98077 L
Mfstroke
.4 g
.59561 .98077 m
.59615 .97974 L
.60526 .96154 L
.61237 .94231 L
.61538 .9319 L
.61721 .92308 L
.61998 .90385 L
.6208 .88462 L
.61975 .86538 L
.61684 .84615 L
.61538 .83904 L
.61205 .82692 L
.60533 .80769 L
.59659 .78846 L
.59615 .78762 L
.58562 .76923 L
.57692 .75632 L
.57221 .75 L
.55769 .73264 L
.55597 .73077 L
.53846 .7135 L
.53627 .71154 L
.51923 .69758 L
.51204 .69231 L
.5 .6842 L
.48104 .67308 L
.48077 .67293 L
.46154 .66353 L
.44231 .65581 L
.43672 .65385 L
.42308 .64968 L
.40385 .64507 L
.38462 .64195 L
.36538 .64032 L
.34615 .64021 L
.32692 .64168 L
.30769 .64481 L
.28846 .64974 L
.27629 .65385 L
.26923 .65668 L
.25 .66593 L
.23795 .67308 L
.23077 .67794 L
.21282 .69231 L
.21154 .69348 L
.19432 .71154 L
.19231 .71399 L
.18022 .73077 L
.17308 .74288 L
.16945 .75 L
.16138 .76923 L
.15564 .78846 L
.15385 .79539 L
.152 .80769 L
.15031 .82692 L
.15047 .84615 L
.15244 .86538 L
.15385 .87457 L
.15623 .88462 L
.16187 .90385 L
.16945 .92308 L
.17308 .93088 L
.17909 .94231 L
.191 .96154 L
.19231 .96343 L
.2055 .98077 L
F
0 g
.59561 .98077 m
.59615 .97974 L
.60526 .96154 L
.61237 .94231 L
.61538 .9319 L
.61721 .92308 L
.61998 .90385 L
.6208 .88462 L
.61975 .86538 L
.61684 .84615 L
.61538 .83904 L
.61205 .82692 L
.60533 .80769 L
.59659 .78846 L
.59615 .78762 L
.58562 .76923 L
.57692 .75632 L
.57221 .75 L
.55769 .73264 L
.55597 .73077 L
.53846 .7135 L
.53627 .71154 L
.51923 .69758 L
.51204 .69231 L
.5 .6842 L
.48104 .67308 L
.48077 .67293 L
.46154 .66353 L
.44231 .65581 L
.43672 .65385 L
.42308 .64968 L
.40385 .64507 L
.38462 .64195 L
.36538 .64032 L
.34615 .64021 L
.32692 .64168 L
.30769 .64481 L
.28846 .64974 L
.27629 .65385 L
.26923 .65668 L
.25 .66593 L
.23795 .67308 L
.23077 .67794 L
.21282 .69231 L
.21154 .69348 L
.19432 .71154 L
.19231 .71399 L
.18022 .73077 L
.17308 .74288 L
.16945 .75 L
Mistroke
.16138 .76923 L
.15564 .78846 L
.15385 .79539 L
.152 .80769 L
.15031 .82692 L
.15047 .84615 L
.15244 .86538 L
.15385 .87457 L
.15623 .88462 L
.16187 .90385 L
.16945 .92308 L
.17308 .93088 L
.17909 .94231 L
.191 .96154 L
.19231 .96343 L
.2055 .98077 L
Mfstroke
.5 g
.55606 .98077 m
.55769 .97835 L
.56801 .96154 L
.57664 .94231 L
.57692 .94162 L
.58251 .92308 L
.58595 .90385 L
.58715 .88462 L
.58621 .86538 L
.58317 .84615 L
.57802 .82692 L
.57692 .82357 L
.57065 .80769 L
.56091 .78846 L
.55769 .78299 L
.54854 .76923 L
.53846 .7562 L
.53311 .75 L
.51923 .7357 L
.51387 .73077 L
.5 .71924 L
.48947 .71154 L
.48077 .70578 L
.46154 .69476 L
.45668 .69231 L
.44231 .68586 L
.42308 .67885 L
.40385 .67362 L
.40184 .67308 L
.38462 .67013 L
.36538 .66834 L
.34615 .66828 L
.32692 .67004 L
.30986 .67308 L
.30769 .67374 L
.28846 .67959 L
.26923 .6879 L
.26101 .69231 L
.25 .69921 L
.23398 .71154 L
.23077 .71441 L
.21522 .73077 L
.21154 .73536 L
.20151 .75 L
.19231 .76735 L
.19147 .76923 L
.1844 .78846 L
.17986 .80769 L
.17761 .82692 L
.17751 .84615 L
.17947 .86538 L
.1835 .88462 L
.18965 .90385 L
.19231 .91063 L
.19804 .92308 L
.20888 .94231 L
.21154 .94643 L
.2225 .96154 L
.23077 .97141 L
.23946 .98077 L
F
0 g
.55606 .98077 m
.55769 .97835 L
.56801 .96154 L
.57664 .94231 L
.57692 .94162 L
.58251 .92308 L
.58595 .90385 L
.58715 .88462 L
.58621 .86538 L
.58317 .84615 L
.57802 .82692 L
.57692 .82357 L
.57065 .80769 L
.56091 .78846 L
.55769 .78299 L
.54854 .76923 L
.53846 .7562 L
.53311 .75 L
.51923 .7357 L
.51387 .73077 L
.5 .71924 L
.48947 .71154 L
.48077 .70578 L
.46154 .69476 L
.45668 .69231 L
.44231 .68586 L
.42308 .67885 L
.40385 .67362 L
.40184 .67308 L
.38462 .67013 L
.36538 .66834 L
.34615 .66828 L
.32692 .67004 L
.30986 .67308 L
.30769 .67374 L
.28846 .67959 L
.26923 .6879 L
.26101 .69231 L
.25 .69921 L
.23398 .71154 L
.23077 .71441 L
.21522 .73077 L
.21154 .73536 L
.20151 .75 L
.19231 .76735 L
.19147 .76923 L
.1844 .78846 L
.17986 .80769 L
.17761 .82692 L
.17751 .84615 L
Mistroke
.17947 .86538 L
.1835 .88462 L
.18965 .90385 L
.19231 .91063 L
.19804 .92308 L
.20888 .94231 L
.21154 .94643 L
.2225 .96154 L
.23077 .97141 L
.23946 .98077 L
Mfstroke
.6 g
.51836 .98077 m
.51923 .9798 L
.53381 .96154 L
.53846 .95419 L
.54461 .94231 L
.55187 .92308 L
.55618 .90385 L
.55769 .889 L
.55786 .88462 L
.55769 .87339 L
.55708 .86538 L
.5539 .84615 L
.5483 .82692 L
.54014 .80769 L
.53846 .80436 L
.52915 .78846 L
.51923 .77455 L
.51491 .76923 L
.5 .75323 L
.49658 .75 L
.48077 .73674 L
.47254 .73077 L
.46154 .72368 L
.44231 .71334 L
.43846 .71154 L
.42308 .70535 L
.40385 .69947 L
.38462 .6956 L
.36538 .6937 L
.34615 .69379 L
.32692 .69599 L
.30769 .70048 L
.28846 .70759 L
.28021 .71154 L
.26923 .71789 L
.25186 .73077 L
.25 .7324 L
.2334 .75 L
.23077 .75339 L
.22055 .76923 L
.21168 .78846 L
.21154 .7888 L
.20599 .80769 L
.20304 .82692 L
.20259 .84615 L
.20453 .86538 L
.20883 .88462 L
.21154 .89352 L
.21559 .90385 L
.22498 .92308 L
.23077 .93276 L
.23734 .94231 L
.25 .95798 L
.25327 .96154 L
.26923 .97683 L
.27388 .98077 L
F
0 g
.51836 .98077 m
.51923 .9798 L
.53381 .96154 L
.53846 .95419 L
.54461 .94231 L
.55187 .92308 L
.55618 .90385 L
.55769 .889 L
.55786 .88462 L
.55769 .87339 L
.55708 .86538 L
.5539 .84615 L
.5483 .82692 L
.54014 .80769 L
.53846 .80436 L
.52915 .78846 L
.51923 .77455 L
.51491 .76923 L
.5 .75323 L
.49658 .75 L
.48077 .73674 L
.47254 .73077 L
.46154 .72368 L
.44231 .71334 L
.43846 .71154 L
.42308 .70535 L
.40385 .69947 L
.38462 .6956 L
.36538 .6937 L
.34615 .69379 L
.32692 .69599 L
.30769 .70048 L
.28846 .70759 L
.28021 .71154 L
.26923 .71789 L
.25186 .73077 L
.25 .7324 L
.2334 .75 L
.23077 .75339 L
.22055 .76923 L
.21168 .78846 L
.21154 .7888 L
.20599 .80769 L
.20304 .82692 L
.20259 .84615 L
.20453 .86538 L
.20883 .88462 L
.21154 .89352 L
.21559 .90385 L
.22498 .92308 L
Mistroke
.23077 .93276 L
.23734 .94231 L
.25 .95798 L
.25327 .96154 L
.26923 .97683 L
.27388 .98077 L
Mfstroke
.7 g
.47659 .98077 m
.48077 .9777 L
.49888 .96154 L
.5 .96031 L
.51321 .94231 L
.51923 .93118 L
.52252 .92308 L
.52806 .90385 L
.53041 .88462 L
.52986 .86538 L
.52653 .84615 L
.52036 .82692 L
.51923 .82408 L
.51114 .80769 L
.5 .79053 L
.49843 .78846 L
.48135 .76923 L
.48077 .76867 L
.46154 .75251 L
.45803 .75 L
.44231 .74021 L
.42308 .73095 L
.42266 .73077 L
.40385 .72427 L
.38462 .71998 L
.36538 .71799 L
.34615 .71834 L
.32692 .72118 L
.30769 .72683 L
.29811 .73077 L
.28846 .73586 L
.26923 .74946 L
.26861 .75 L
.25083 .76923 L
.25 .77035 L
.23921 .78846 L
.23189 .80769 L
.23077 .81188 L
.22798 .82692 L
.22706 .84615 L
.22894 .86538 L
.23077 .87672 L
.23358 .88462 L
.24111 .90385 L
.25 .92023 L
.25185 .92308 L
.26639 .94231 L
.26923 .9455 L
.28596 .96154 L
.28846 .96359 L
.30769 .97724 L
.31352 .98077 L
F
0 g
.47659 .98077 m
.48077 .9777 L
.49888 .96154 L
.5 .96031 L
.51321 .94231 L
.51923 .93118 L
.52252 .92308 L
.52806 .90385 L
.53041 .88462 L
.52986 .86538 L
.52653 .84615 L
.52036 .82692 L
.51923 .82408 L
.51114 .80769 L
.5 .79053 L
.49843 .78846 L
.48135 .76923 L
.48077 .76867 L
.46154 .75251 L
.45803 .75 L
.44231 .74021 L
.42308 .73095 L
.42266 .73077 L
.40385 .72427 L
.38462 .71998 L
.36538 .71799 L
.34615 .71834 L
.32692 .72118 L
.30769 .72683 L
.29811 .73077 L
.28846 .73586 L
.26923 .74946 L
.26861 .75 L
.25083 .76923 L
.25 .77035 L
.23921 .78846 L
.23189 .80769 L
.23077 .81188 L
.22798 .82692 L
.22706 .84615 L
.22894 .86538 L
.23077 .87672 L
.23358 .88462 L
.24111 .90385 L
.25 .92023 L
.25185 .92308 L
.26639 .94231 L
.26923 .9455 L
.28596 .96154 L
.28846 .96359 L
Mistroke
.30769 .97724 L
.31352 .98077 L
Mfstroke
.8 g
.32692 .74722 m
.34615 .74335 L
.36538 .74257 L
.38462 .74462 L
.40385 .74947 L
.40553 .75 L
.42308 .75725 L
.44231 .76846 L
.44343 .76923 L
.46154 .78404 L
.46595 .78846 L
.48077 .80662 L
.48149 .80769 L
.4923 .82692 L
.49927 .84615 L
.5 .849 L
.50281 .86538 L
.50298 .88462 L
.5 .90234 L
.4996 .90385 L
.49211 .92308 L
.48077 .94039 L
.47911 .94231 L
.46154 .95839 L
.457 .96154 L
.44231 .96924 L
.42308 .97572 L
.40385 .97879 L
.38462 .97881 L
.36538 .97601 L
.34615 .97041 L
.32692 .96179 L
.32645 .96154 L
.30769 .94951 L
.29881 .94231 L
.28846 .93232 L
.28051 .92308 L
.26923 .90657 L
.26772 .90385 L
.25904 .88462 L
.25393 .86538 L
.25216 .84615 L
.25379 .82692 L
.25918 .80769 L
.26923 .78854 L
.26929 .78846 L
.28623 .76923 L
.28846 .76734 L
.30769 .75477 L
.31796 .75 L
F
0 g
.32692 .74722 m
.34615 .74335 L
.36538 .74257 L
.38462 .74462 L
.40385 .74947 L
.40553 .75 L
.42308 .75725 L
.44231 .76846 L
.44343 .76923 L
.46154 .78404 L
.46595 .78846 L
.48077 .80662 L
.48149 .80769 L
.4923 .82692 L
.49927 .84615 L
.5 .849 L
.50281 .86538 L
.50298 .88462 L
.5 .90234 L
.4996 .90385 L
.49211 .92308 L
.48077 .94039 L
.47911 .94231 L
.46154 .95839 L
.457 .96154 L
.44231 .96924 L
.42308 .97572 L
.40385 .97879 L
.38462 .97881 L
.36538 .97601 L
.34615 .97041 L
.32692 .96179 L
.32645 .96154 L
.30769 .94951 L
.29881 .94231 L
.28846 .93232 L
.28051 .92308 L
.26923 .90657 L
.26772 .90385 L
.25904 .88462 L
.25393 .86538 L
.25216 .84615 L
.25379 .82692 L
.25918 .80769 L
.26923 .78854 L
.26929 .78846 L
.28623 .76923 L
.28846 .76734 L
.30769 .75477 L
.31796 .75 L
Mistroke
.32692 .74722 L
Mfstroke
.9 g
.32692 .77664 m
.34615 .77083 L
.36538 .76926 L
.38462 .77133 L
.40385 .77702 L
.42308 .78683 L
.42563 .78846 L
.44231 .80187 L
.44786 .80769 L
.46154 .82675 L
.46163 .82692 L
.47002 .84615 L
.47386 .86538 L
.47337 .88462 L
.46806 .90385 L
.46154 .91677 L
.45643 .92308 L
.44231 .93632 L
.43307 .94231 L
.42308 .94658 L
.40385 .95156 L
.38462 .95242 L
.36538 .94964 L
.34615 .94315 L
.34419 .94231 L
.32692 .93252 L
.31488 .92308 L
.30769 .91608 L
.29785 .90385 L
.28846 .88769 L
.28722 .88462 L
.28131 .86538 L
.27975 .84615 L
.28267 .82692 L
.28846 .81065 L
.29099 .80769 L
.30769 .78849 L
.30772 .78846 L
F
0 g
.32692 .77664 m
.34615 .77083 L
.36538 .76926 L
.38462 .77133 L
.40385 .77702 L
.42308 .78683 L
.42563 .78846 L
.44231 .80187 L
.44786 .80769 L
.46154 .82675 L
.46163 .82692 L
.47002 .84615 L
.47386 .86538 L
.47337 .88462 L
.46806 .90385 L
.46154 .91677 L
.45643 .92308 L
.44231 .93632 L
.43307 .94231 L
.42308 .94658 L
.40385 .95156 L
.38462 .95242 L
.36538 .94964 L
.34615 .94315 L
.34419 .94231 L
.32692 .93252 L
.31488 .92308 L
.30769 .91608 L
.29785 .90385 L
.28846 .88769 L
.28722 .88462 L
.28131 .86538 L
.27975 .84615 L
.28267 .82692 L
.28846 .81065 L
.29099 .80769 L
.30769 .78849 L
.30772 .78846 L
.32692 .77664 L
s
1 g
.34615 .80637 m
.36538 .80232 L
.38462 .80445 L
.39417 .80769 L
.40385 .81211 L
.42171 .82692 L
.42308 .82769 L
.43393 .84615 L
.43844 .86538 L
.43617 .88462 L
.42421 .90385 L
.42308 .90497 L
.40385 .91672 L
.38462 .91962 L
.36538 .91684 L
.34615 .90787 L
.34028 .90385 L
.32692 .89039 L
.3234 .88462 L
.31544 .86538 L
.31447 .84615 L
.32119 .82692 L
.32692 .81846 L
.34215 .80769 L
F
0 g
.34615 .80637 m
.36538 .80232 L
.38462 .80445 L
.39417 .80769 L
.40385 .81211 L
.42171 .82692 L
.42308 .82769 L
.43393 .84615 L
.43844 .86538 L
.43617 .88462 L
.42421 .90385 L
.42308 .90497 L
.40385 .91672 L
.38462 .91962 L
.36538 .91684 L
.34615 .90787 L
.34028 .90385 L
.32692 .89039 L
.3234 .88462 L
.31544 .86538 L
.31447 .84615 L
.32119 .82692 L
.32692 .81846 L
.34215 .80769 L
.34615 .80637 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.465 .722 .98 r
.39871 .60632 .40487 .61082 .41505 .61055 .4089 .60639 Mtetra
.374 .696 .983 r
.4089 .60639 .41505 .61055 .42526 .61096 .41912 .60722 Mtetra
.237 .644 .96 r
.41912 .60722 .42526 .61096 .43551 .61214 .42938 .60893 Mtetra
.043 .542 .881 r
.42938 .60893 .43551 .61214 .44581 .61418 .43968 .6116 Mtetra
0 .383 .719 r
.43968 .6116 .44581 .61418 .45616 .61716 .45004 .61532 Mtetra
.404 0 0 r
.45004 .61532 .45616 .61716 .46657 .62112 .46046 .62013 Mtetra
.555 0 0 r
.46046 .62013 .46657 .62112 .47705 .62605 .47095 .62602 Mtetra
.643 .097 0 r
.47095 .62602 .47705 .62605 .48761 .63192 .48153 .63294 Mtetra
.689 .179 .021 r
.48153 .63294 .48761 .63192 .49826 .63862 .4922 .64077 Mtetra
.709 .231 .11 r
.4922 .64077 .49826 .63862 .50901 .64599 .50298 .64931 Mtetra
.715 .261 .171 r
.50298 .64931 .50901 .64599 .51987 .6538 .51387 .6583 Mtetra
.712 .276 .213 r
.51387 .6583 .51987 .6538 .53084 .66177 .52489 .66742 Mtetra
.701 .279 .241 r
.52489 .66742 .53084 .66177 .54193 .66956 .53602 .67629 Mtetra
.684 .272 .258 r
.53602 .67629 .54193 .66956 .55312 .67679 .54728 .68448 Mtetra
.66 .255 .265 r
.54728 .68448 .55312 .67679 .56442 .68307 .55864 .69155 Mtetra
.628 .227 .263 r
.55864 .69155 .56442 .68307 .5758 .68802 .57009 .6971 Mtetra
.587 .187 .251 r
.57009 .6971 .5758 .68802 .58725 .69129 .58162 .70072 Mtetra
.531 .131 .228 r
.58162 .70072 .58725 .69129 .59875 .6926 .59319 .70213 Mtetra
.457 .056 .189 r
.59319 .70213 .59875 .6926 .61027 .69174 .60479 .70111 Mtetra
.357 0 .13 r
.60479 .70111 .61027 .69174 .6218 .68861 .61638 .69757 Mtetra
.221 0 .044 r
.61638 .69757 .6218 .68861 .6333 .68323 .62795 .69155 Mtetra
.04 0 0 r
.62795 .69155 .6333 .68323 .64476 .67573 .63947 .6832 Mtetra
0 0 0 r
.63947 .6832 .64476 .67573 .65617 .66633 .65093 .67279 Mtetra
.65093 .67279 .65617 .66633 .66752 .65536 .66233 .66069 Mtetra
.62 .875 .534 r
.66233 .66069 .66752 .65536 .67882 .64317 .67366 .64731 Mtetra
.764 .956 .643 r
.67366 .64731 .67882 .64317 .69006 .63017 .68493 .6331 Mtetra
.849 .987 .715 r
.68493 .6331 .69006 .63017 .70126 .61676 .69616 .61849 Mtetra
.891 .99 .762 r
.69616 .61849 .70126 .61676 .71245 .60331 .70736 .60389 Mtetra
.906 .977 .794 r
.70736 .60389 .71245 .60331 .72362 .59015 .71855 .58966 Mtetra
.904 .959 .817 r
.71855 .58966 .72362 .59015 .73481 .57753 .72975 .57607 Mtetra
.893 .938 .836 r
.72975 .57607 .73481 .57753 .74604 .56566 .74098 .56333 Mtetra
.876 .916 .851 r
.74098 .56333 .74604 .56566 .75731 .55465 .75226 .55157 Mtetra
.855 .895 .864 r
.75226 .55157 .75731 .55465 .76865 .54457 .76361 .54084 Mtetra
.832 .875 .875 r
.76361 .54084 .76865 .54457 .78006 .53542 .77503 .53114 Mtetra
.808 .856 .885 r
.77503 .53114 .78006 .53542 .79154 .52715 .78654 .52241 Mtetra
.786 .838 .892 r
.78654 .52241 .79154 .52715 .80311 .51968 .79812 .51457 Mtetra
.765 .823 .898 r
.79812 .51457 .80311 .51968 .81476 .51292 .8098 .50751 Mtetra
.747 .809 .902 r
.8098 .50751 .81476 .51292 .8265 .50674 .82155 .5011 Mtetra
.731 .798 .905 r
.82155 .5011 .8265 .50674 .83831 .50105 .83339 .49521 Mtetra
.719 .789 .907 r
.83339 .49521 .83831 .50105 .85019 .49573 .8453 .48974 Mtetra
.709 .782 .908 r
.8453 .48974 .85019 .49573 .86213 .49068 .85728 .48458 Mtetra
.702 .776 .909 r
.85728 .48458 .86213 .49068 .87414 .48584 .86932 .47963 Mtetra
.698 .772 .909 r
.86932 .47963 .87414 .48584 .88621 .48112 .88142 .47483 Mtetra
.694 .77 .909 r
.88142 .47483 .88621 .48112 .89832 .47647 .89357 .47012 Mtetra
.693 .768 .909 r
.89357 .47012 .89832 .47647 .91049 .47187 .90578 .46545 Mtetra
.692 .766 .909 r
.90578 .46545 .91049 .47187 .92271 .46727 .91803 .4608 Mtetra
.691 .765 .908 r
.91803 .4608 .92271 .46727 .93497 .46266 .93032 .45614 Mtetra
.93032 .45614 .93497 .46266 .94727 .45803 .94267 .45146 Mtetra
.692 .764 .907 r
.94267 .45146 .94727 .45803 .95962 .45337 .95505 .44676 Mtetra
.95505 .44676 .95962 .45337 .97201 .44868 .96748 .44203 Mtetra
.436 .709 .98 r
.39251 .60176 .39871 .60632 .4089 .60639 .4027 .60216 Mtetra
.331 .674 .977 r
.4027 .60216 .4089 .60639 .41912 .60722 .41293 .60341 Mtetra
.175 .605 .94 r
.41293 .60341 .41912 .60722 .42938 .60893 .4232 .60562 Mtetra
0 .483 .839 r
.4232 .60562 .42938 .60893 .43968 .6116 .43351 .60891 Mtetra
0 .308 .657 r
.43351 .60891 .43968 .6116 .45004 .61532 .44387 .61334 Mtetra
.471 0 0 r
.44387 .61334 .45004 .61532 .46046 .62013 .45429 .61897 Mtetra
.603 .033 0 r
.45429 .61897 .46046 .62013 .47095 .62602 .46479 .62577 Mtetra
.677 .142 0 r
.46479 .62577 .47095 .62602 .48153 .63294 .47538 .63369 Mtetra
.715 .213 .041 r
.47538 .63369 .48153 .63294 .4922 .64077 .48607 .64257 Mtetra
.732 .257 .119 r
.48607 .64257 .4922 .64077 .50298 .64931 .49687 .65221 Mtetra
.736 .282 .174 r
.49687 .65221 .50298 .64931 .51387 .6583 .5078 .66229 Mtetra
.731 .293 .21 r
.5078 .66229 .51387 .6583 .52489 .66742 .51885 .67246 Mtetra
.719 .292 .234 r
.51885 .67246 .52489 .66742 .53602 .67629 .53003 .68229 Mtetra
.7 .28 .246 r
.53003 .68229 .53602 .67629 .54728 .68448 .54133 .69132 Mtetra
.673 .257 .248 r
.54133 .69132 .54728 .68448 .55864 .69155 .55275 .69907 Mtetra
.637 .222 .239 r
.55275 .69907 .55864 .69155 .57009 .6971 .56427 .70508 Mtetra
.588 .171 .218 r
.56427 .70508 .57009 .6971 .58162 .70072 .57587 .70895 Mtetra
.519 .098 .181 r
.57587 .70895 .58162 .70072 .59319 .70213 .58751 .71035 Mtetra
.422 0 .122 r
.58751 .71035 .59319 .70213 .60479 .70111 .59918 .70908 Mtetra
.284 0 .033 r
.59918 .70908 .60479 .70111 .61638 .69757 .61084 .70507 Mtetra
.089 0 0 r
.61084 .70507 .61638 .69757 .62795 .69155 .62247 .69836 Mtetra
0 0 0 r
.62247 .69836 .62795 .69155 .63947 .6832 .63405 .68915 Mtetra
.63405 .68915 .63947 .6832 .65093 .67279 .64557 .67776 Mtetra
.655 .905 .581 r
.64557 .67776 .65093 .67279 .66233 .66069 .65701 .66458 Mtetra
.799 .972 .673 r
.65701 .66458 .66233 .66069 .67366 .64731 .66838 .65008 Mtetra
.877 .988 .726 r
.66838 .65008 .67366 .64731 .68493 .6331 .67968 .63474 Mtetra
.912 .981 .757 r
.67968 .63474 .68493 .6331 .69616 .61849 .69093 .61904 Mtetra
.924 .964 .778 r
.69093 .61904 .69616 .61849 .70736 .60389 .70215 .60342 Mtetra
.922 .945 .794 r
.70215 .60342 .70736 .60389 .71855 .58966 .71336 .58823 Mtetra
.913 .926 .809 r
.71336 .58823 .71855 .58966 .72975 .57607 .72458 .57378 Mtetra
.897 .908 .823 r
.72458 .57378 .72975 .57607 .74098 .56333 .73583 .56028 Mtetra
.879 .89 .837 r
.73583 .56028 .74098 .56333 .75226 .55157 .74713 .54786 Mtetra
.857 .873 .85 r
.74713 .54786 .75226 .55157 .76361 .54084 .7585 .53658 Mtetra
.835 .857 .862 r
.7585 .53658 .76361 .54084 .77503 .53114 .76994 .52641 Mtetra
.812 .841 .872 r
.76994 .52641 .77503 .53114 .78654 .52241 .78146 .5173 Mtetra
.789 .827 .881 r
.78146 .5173 .78654 .52241 .79812 .51457 .79307 .50915 Mtetra
.768 .814 .889 r
.79307 .50915 .79812 .51457 .8098 .50751 .80477 .50183 Mtetra
.75 .802 .895 r
.80477 .50183 .8098 .50751 .82155 .5011 .81655 .49521 Mtetra
.734 .792 .899 r
.81655 .49521 .82155 .5011 .83339 .49521 .82842 .48917 Mtetra
.721 .784 .902 r
.82842 .48917 .83339 .49521 .8453 .48974 .84036 .48357 Mtetra
.711 .778 .904 r
.84036 .48357 .8453 .48974 .85728 .48458 .85237 .4783 Mtetra
.704 .773 .906 r
.85237 .4783 .85728 .48458 .86932 .47963 .86445 .47327 Mtetra
.699 .769 .906 r
.86445 .47327 .86932 .47963 .88142 .47483 .87658 .4684 Mtetra
.695 .767 .907 r
.87658 .4684 .88142 .47483 .89357 .47012 .88877 .46363 Mtetra
.693 .765 .907 r
.88877 .46363 .89357 .47012 .90578 .46545 .90101 .45891 Mtetra
.692 .764 .907 r
.90101 .45891 .90578 .46545 .91803 .4608 .9133 .4542 Mtetra
.692 .763 .906 r
.9133 .4542 .91803 .4608 .93032 .45614 .92564 .4495 Mtetra
.692 .762 .906 r
.92564 .4495 .93032 .45614 .94267 .45146 .93802 .44478 Mtetra
.692 .762 .905 r
.93802 .44478 .94267 .45146 .95505 .44676 .95044 .44003 Mtetra
.95044 .44003 .95505 .44676 .96748 .44203 .96291 .43526 Mtetra
.41 .695 .979 r
.38625 .5971 .39251 .60176 .4027 .60216 .39646 .59781 Mtetra
.294 .651 .969 r
.39646 .59781 .4027 .60216 .41293 .60341 .40669 .59945 Mtetra
.124 .569 .921 r
.40669 .59945 .41293 .60341 .4232 .60562 .41697 .60213 Mtetra
0 .433 .806 r
.41697 .60213 .4232 .60562 .43351 .60891 .42728 .60598 Mtetra
.326 0 0 r
.42728 .60598 .43351 .60891 .44387 .61334 .43765 .61107 Mtetra
.512 0 0 r
.43765 .61107 .44387 .61334 .45429 .61897 .44808 .61744 Mtetra
.633 .07 0 r
.44808 .61744 .45429 .61897 .46479 .62577 .45858 .62507 Mtetra
.7 .169 0 r
.45858 .62507 .46479 .62577 .47538 .63369 .46918 .63389 Mtetra
.735 .234 .037 r
.46918 .63389 .47538 .63369 .48607 .64257 .47988 .64371 Mtetra
.751 .273 .109 r
.47988 .64371 .48607 .64257 .49687 .65221 .4907 .65431 Mtetra
.754 .294 .158 r
.4907 .65431 .49687 .65221 .5078 .66229 .50165 .66534 Mtetra
.748 .302 .19 r
.50165 .66534 .5078 .66229 .51885 .67246 .51273 .67641 Mtetra
.736 .297 .209 r
.51273 .67641 .51885 .67246 .53003 .68229 .52395 .68705 Mtetra
.715 .28 .215 r
.52395 .68705 .53003 .68229 .54133 .69132 .5353 .69675 Mtetra
.686 .25 .209 r
.5353 .69675 .54133 .69132 .55275 .69907 .54677 .705 Mtetra
.643 .203 .189 r
.54677 .705 .55275 .69907 .56427 .70508 .55834 .71133 Mtetra
.581 .133 .151 r
.55834 .71133 .56427 .70508 .57587 .70895 .57 .7153 Mtetra
.489 .03 .088 r
.57 .7153 .57587 .70895 .58751 .71035 .58171 .71659 Mtetra
.347 0 0 r
.58171 .71659 .58751 .71035 .59918 .70908 .59344 .71499 Mtetra
.132 0 0 r
.59344 .71499 .59918 .70908 .61084 .70507 .60517 .71045 Mtetra
0 0 0 r
.60517 .71045 .61084 .70507 .62247 .69836 .61686 .70304 Mtetra
.481 .829 .554 r
.61686 .70304 .62247 .69836 .63405 .68915 .62849 .693 Mtetra
.715 .956 .679 r
.62849 .693 .63405 .68915 .64557 .67776 .64006 .68068 Mtetra
.844 .992 .737 r
.64006 .68068 .64557 .67776 .65701 .66458 .65154 .66653 Mtetra
.904 .985 .759 r
.65154 .66653 .65701 .66458 .66838 .65008 .66295 .65103 Mtetra
.928 .964 .768 r
.66295 .65103 .66838 .65008 .67968 .63474 .67429 .63472 Mtetra
.934 .942 .774 r
.67429 .63472 .67968 .63474 .69093 .61904 .68557 .61809 Mtetra
.931 .921 .78 r
.68557 .61809 .69093 .61904 .70215 .60342 .69682 .60159 Mtetra
.922 .903 .788 r
.69682 .60159 .70215 .60342 .71336 .58823 .70806 .58562 Mtetra
.909 .888 .798 r
.70806 .58562 .71336 .58823 .72458 .57378 .7193 .57047 Mtetra
.893 .874 .81 r
.7193 .57047 .72458 .57378 .73583 .56028 .73058 .55636 Mtetra
.875 .861 .823 r
.73058 .55636 .73583 .56028 .74713 .54786 .7419 .54342 Mtetra
.855 .848 .836 r
.7419 .54342 .74713 .54786 .7585 .53658 .75329 .53169 Mtetra
.833 .836 .849 r
.75329 .53169 .7585 .53658 .76994 .52641 .76476 .52116 Mtetra
.811 .825 .861 r
.76476 .52116 .76994 .52641 .78146 .5173 .77631 .51175 Mtetra
.79 .814 .871 r
.77631 .51175 .78146 .5173 .79307 .50915 .78795 .50336 Mtetra
.769 .803 .88 r
.78795 .50336 .79307 .50915 .80477 .50183 .79968 .49584 Mtetra
.751 .794 .887 r
.79968 .49584 .80477 .50183 .81655 .49521 .81149 .48907 Mtetra
.735 .785 .893 r
.81149 .48907 .81655 .49521 .82842 .48917 .82339 .4829 Mtetra
.722 .779 .897 r
.82339 .4829 .82842 .48917 .84036 .48357 .83536 .47719 Mtetra
.712 .773 .9 r
.83536 .47719 .84036 .48357 .85237 .4783 .84741 .47184 Mtetra
.705 .769 .902 r
.84741 .47184 .85237 .4783 .86445 .47327 .85952 .46674 Mtetra
.699 .766 .903 r
.85952 .46674 .86445 .47327 .87658 .4684 .87169 .46181 Mtetra
.696 .763 .904 r
.87169 .46181 .87658 .4684 .88877 .46363 .88392 .45699 Mtetra
.693 .762 .904 r
.88392 .45699 .88877 .46363 .90101 .45891 .8962 .45222 Mtetra
.692 .761 .904 r
.8962 .45222 .90101 .45891 .9133 .4542 .90853 .44748 Mtetra
.692 .76 .904 r
.90853 .44748 .9133 .4542 .92564 .4495 .9209 .44273 Mtetra
.9209 .44273 .92564 .4495 .93802 .44478 .93332 .43797 Mtetra
.93332 .43797 .93802 .44478 .95044 .44003 .94579 .43318 Mtetra
.692 .76 .903 r
.94579 .43318 .95044 .44003 .96291 .43526 .9583 .42837 Mtetra
.39 .681 .976 r
.37996 .5923 .38625 .5971 .39646 .59781 .39017 .59328 Mtetra
.266 .63 .962 r
.39017 .59328 .39646 .59781 .40669 .59945 .40041 .59525 Mtetra
.091 .539 .908 r
.40041 .59525 .40669 .59945 .41697 .60213 .41069 .59835 Mtetra
0 .398 .788 r
.41069 .59835 .41697 .60213 .42728 .60598 .42101 .60268 Mtetra
.353 0 0 r
.42101 .60268 .42728 .60598 .43765 .61107 .43138 .60834 Mtetra
.53 0 0 r
.43138 .60834 .43765 .61107 .44808 .61744 .44181 .61535 Mtetra
.646 .087 0 r
.44181 .61535 .44808 .61744 .45858 .62507 .45232 .62369 Mtetra
.712 .181 0 r
.45232 .62369 .45858 .62507 .46918 .63389 .46292 .63326 Mtetra
.748 .241 .01 r
.46292 .63326 .46918 .63389 .47988 .64371 .47363 .64387 Mtetra
.765 .278 .077 r
.47363 .64387 .47988 .64371 .4907 .65431 .48446 .65525 Mtetra
.769 .297 .121 r
.48446 .65525 .4907 .65431 .50165 .66534 .49543 .66704 Mtetra
.764 .301 .148 r
.49543 .66704 .50165 .66534 .51273 .67641 .50654 .6788 Mtetra
.751 .292 .159 r
.50654 .6788 .51273 .67641 .52395 .68705 .51778 .69003 Mtetra
.729 .268 .155 r
.51778 .69003 .52395 .68705 .5353 .69675 .52917 .7002 Mtetra
.694 .226 .135 r
.52917 .7002 .5353 .69675 .54677 .705 .54069 .70877 Mtetra
.641 .159 .093 r
.54069 .70877 .54677 .705 .55834 .71133 .55231 .71524 Mtetra
.555 .053 .018 r
.55231 .71524 .55834 .71133 .57 .7153 .56402 .71917 Mtetra
.411 0 0 r
.56402 .71917 .57 .7153 .58171 .71659 .57578 .72022 Mtetra
.167 0 0 r
.57578 .72022 .58171 .71659 .59344 .71499 .58757 .71822 Mtetra
0 0 0 r
.58757 .71822 .59344 .71499 .60517 .71045 .59935 .71312 Mtetra
.554 .917 .739 r
.59935 .71312 .60517 .71045 .61686 .70304 .61109 .70504 Mtetra
.775 .997 .809 r
.61109 .70504 .61686 .70304 .62849 .693 .62278 .69424 Mtetra
.875 .991 .812 r
.62278 .69424 .62849 .693 .64006 .68068 .63439 .68111 Mtetra
.915 .962 .798 r
.63439 .68111 .64006 .68068 .65154 .66653 .64592 .66612 Mtetra
.929 .932 .785 r
.64592 .66612 .65154 .66653 .66295 .65103 .65738 .6498 Mtetra
.931 .907 .776 r
.65738 .6498 .66295 .65103 .67429 .63472 .66875 .6327 Mtetra
.927 .887 .773 r
.66875 .6327 .67429 .63472 .68557 .61809 .68008 .61534 Mtetra
.92 .871 .774 r
.68008 .61534 .68557 .61809 .69682 .60159 .69136 .59819 Mtetra
.91 .859 .778 r
.69136 .59819 .69682 .60159 .70806 .58562 .70263 .58163 Mtetra
.897 .848 .787 r
.70263 .58163 .70806 .58562 .7193 .57047 .71391 .56598 Mtetra
.883 .839 .797 r
.71391 .56598 .7193 .57047 .73058 .55636 .72522 .55144 Mtetra
.867 .831 .81 r
.72522 .55144 .73058 .55636 .7419 .54342 .73658 .53814 Mtetra
.848 .823 .823 r
.73658 .53814 .7419 .54342 .75329 .53169 .748 .52611 Mtetra
.829 .815 .837 r
.748 .52611 .75329 .53169 .76476 .52116 .7595 .51533 Mtetra
.808 .807 .85 r
.7595 .51533 .76476 .52116 .77631 .51175 .77109 .50573 Mtetra
.788 .8 .862 r
.77109 .50573 .77631 .51175 .78795 .50336 .78276 .49717 Mtetra
.769 .792 .872 r
.78276 .49717 .78795 .50336 .79968 .49584 .79452 .48953 Mtetra
.751 .785 .88 r
.79452 .48953 .79968 .49584 .81149 .48907 .80637 .48265 Mtetra
.735 .778 .887 r
.80637 .48265 .81149 .48907 .82339 .4829 .81831 .47639 Mtetra
.722 .773 .892 r
.81831 .47639 .82339 .4829 .83536 .47719 .83032 .47061 Mtetra
.712 .768 .896 r
.83032 .47061 .83536 .47719 .84741 .47184 .8424 .4652 Mtetra
.705 .765 .899 r
.8424 .4652 .84741 .47184 .85952 .46674 .85455 .46005 Mtetra
.699 .762 .9 r
.85455 .46005 .85952 .46674 .87169 .46181 .86676 .45507 Mtetra
.696 .76 .901 r
.86676 .45507 .87169 .46181 .88392 .45699 .87902 .45021 Mtetra
.694 .759 .902 r
.87902 .45021 .88392 .45699 .8962 .45222 .89134 .4454 Mtetra
.692 .758 .902 r
.89134 .4454 .8962 .45222 .90853 .44748 .90371 .44062 Mtetra
.90371 .44062 .90853 .44748 .9209 .44273 .91612 .43583 Mtetra
.91612 .43583 .9209 .44273 .93332 .43797 .92858 .43103 Mtetra
.692 .757 .902 r
.92858 .43103 .93332 .43797 .94579 .43318 .94109 .42621 Mtetra
.94109 .42621 .94579 .43318 .9583 .42837 .95364 .42136 Mtetra
.377 .668 .972 r
.37362 .58732 .37996 .5923 .39017 .59328 .38384 .58852 Mtetra
.25 .613 .956 r
.38384 .58852 .39017 .59328 .40041 .59525 .39409 .59076 Mtetra
.076 .519 .901 r
.39409 .59076 .40041 .59525 .41069 .59835 .40437 .59419 Mtetra
0 .379 .787 r
.40437 .59419 .41069 .59835 .42101 .60268 .4147 .59891 Mtetra
0 .209 .617 r
.4147 .59891 .42101 .60268 .43138 .60834 .42507 .60501 Mtetra
.525 0 0 r
.42507 .60501 .43138 .60834 .44181 .61535 .4355 .61252 Mtetra
.641 .083 0 r
.4355 .61252 .44181 .61535 .45232 .62369 .44601 .6214 Mtetra
.711 .175 0 r
.44601 .6214 .45232 .62369 .46292 .63326 .45662 .63154 Mtetra
.75 .234 0 r
.45662 .63154 .46292 .63326 .47363 .64387 .46734 .64273 Mtetra
.77 .27 .017 r
.46734 .64273 .47363 .64387 .48446 .65525 .47818 .65467 Mtetra
.777 .286 .055 r
.47818 .65467 .48446 .65525 .49543 .66704 .48916 .66698 Mtetra
.773 .287 .073 r
.48916 .66698 .49543 .66704 .50654 .6788 .50028 .67919 Mtetra
.759 .27 .071 r
.50028 .67919 .50654 .6788 .51778 .69003 .51155 .69079 Mtetra
.733 .234 .048 r
.51155 .69079 .51778 .69003 .52917 .7002 .52297 .70119 Mtetra
.687 .17 0 r
.52297 .70119 .52917 .7002 .54069 .70877 .53452 .70986 Mtetra
.607 .062 0 r
.53452 .70986 .54069 .70877 .55231 .71524 .54618 .71628 Mtetra
.459 0 0 r
.54618 .71628 .55231 .71524 .56402 .71917 .55793 .72001 Mtetra
.181 0 0 r
.55793 .72001 .56402 .71917 .57578 .72022 .56974 .72074 Mtetra
.239 .756 .798 r
.56974 .72074 .57578 .72022 .58757 .71822 .58157 .71828 Mtetra
.605 .947 .925 r
.58157 .71828 .58757 .71822 .59935 .71312 .59339 .71262 Mtetra
.79 .973 .912 r
.59339 .71262 .59935 .71312 .61109 .70504 .60519 .70392 Mtetra
.866 .944 .866 r
.60519 .70392 .61109 .70504 .62278 .69424 .61692 .69246 Mtetra
.896 .91 .826 r
.61692 .69246 .62278 .69424 .63439 .68111 .62858 .67866 Mtetra
.908 .881 .797 r
.62858 .67866 .63439 .68111 .64592 .66612 .64016 .66303 Mtetra
.911 .86 .778 r
.64016 .66303 .64592 .66612 .65738 .6498 .65165 .64611 Mtetra
.909 .843 .767 r
.65165 .64611 .65738 .6498 .66875 .6327 .66308 .62846 Mtetra
.905 .831 .762 r
.66308 .62846 .66875 .6327 .68008 .61534 .67444 .61062 Mtetra
.899 .822 .763 r
.67444 .61062 .68008 .61534 .69136 .59819 .68577 .59305 Mtetra
.891 .815 .767 r
.68577 .59305 .69136 .59819 .70263 .58163 .69709 .57615 Mtetra
.881 .81 .775 r
.69709 .57615 .70263 .58163 .71391 .56598 .70841 .56021 Mtetra
.869 .806 .786 r
.70841 .56021 .71391 .56598 .72522 .55144 .71976 .54544 Mtetra
.855 .802 .798 r
.71976 .54544 .72522 .55144 .73658 .53814 .73116 .53196 Mtetra
.839 .798 .812 r
.73116 .53196 .73658 .53814 .748 .52611 .74262 .51979 Mtetra
.821 .794 .827 r
.74262 .51979 .748 .52611 .7595 .51533 .75416 .50889 Mtetra
.803 .79 .841 r
.75416 .50889 .7595 .51533 .77109 .50573 .76579 .4992 Mtetra
.784 .785 .853 r
.76579 .4992 .77109 .50573 .78276 .49717 .7775 .49057 Mtetra
.766 .78 .865 r
.7775 .49057 .78276 .49717 .79452 .48953 .7893 .48286 Mtetra
.749 .775 .874 r
.7893 .48286 .79452 .48953 .80637 .48265 .80119 .47594 Mtetra
.734 .77 .882 r
.80119 .47594 .80637 .48265 .81831 .47639 .81316 .46963 Mtetra
.722 .766 .888 r
.81316 .46963 .81831 .47639 .83032 .47061 .82521 .46382 Mtetra
.712 .763 .892 r
.82521 .46382 .83032 .47061 .8424 .4652 .83733 .45837 Mtetra
.704 .76 .895 r
.83733 .45837 .8424 .4652 .85455 .46005 .84952 .45319 Mtetra
.699 .758 .898 r
.84952 .45319 .85455 .46005 .86676 .45507 .86177 .44818 Mtetra
.696 .757 .899 r
.86177 .44818 .86676 .45507 .87902 .45021 .87408 .44328 Mtetra
.693 .756 .9 r
.87408 .44328 .87902 .45021 .89134 .4454 .88643 .43843 Mtetra
.692 .755 .9 r
.88643 .43843 .89134 .4454 .90371 .44062 .89884 .43362 Mtetra
.89884 .43362 .90371 .44062 .91612 .43583 .91129 .4288 Mtetra
.91129 .4288 .91612 .43583 .92858 .43103 .92379 .42397 Mtetra
.92379 .42397 .92858 .43103 .94109 .42621 .93634 .41912 Mtetra
.93634 .41912 .94109 .42621 .95364 .42136 .94893 .41423 Mtetra
.372 .658 .968 r
.36724 .58211 .37362 .58732 .38384 .58852 .37747 .58347 Mtetra
.248 .601 .952 r
.37747 .58347 .38384 .58852 .39409 .59076 .38773 .5859 Mtetra
.082 .509 .901 r
.38773 .5859 .39409 .59076 .40437 .59419 .39802 .58956 Mtetra
0 .377 .8 r
.39802 .58956 .40437 .59419 .4147 .59891 .40835 .59455 Mtetra
0 .22 .652 r
.40835 .59455 .4147 .59891 .42507 .60501 .41872 .60096 Mtetra
.492 0 0 r
.41872 .60096 .42507 .60501 .4355 .61252 .42916 .6088 Mtetra
.612 .058 0 r
.42916 .6088 .4355 .61252 .44601 .6214 .43967 .61803 Mtetra
.689 .148 0 r
.43967 .61803 .44601 .6214 .45662 .63154 .45028 .62852 Mtetra
.734 .207 0 r
.45028 .62852 .45662 .63154 .46734 .64273 .461 .64005 Mtetra
.758 .242 0 r
.461 .64005 .46734 .64273 .47818 .65467 .47185 .6523 Mtetra
.766 .255 0 r
.47185 .6523 .47818 .65467 .48916 .66698 .48284 .66486 Mtetra
.761 .248 0 r
.48284 .66486 .48916 .66698 .50028 .67919 .49398 .67726 Mtetra
.741 .218 0 r
.49398 .67726 .50028 .67919 .51155 .69079 .50527 .68894 Mtetra
.698 .157 0 r
.50527 .68894 .51155 .69079 .52297 .70119 .5167 .69933 Mtetra
.615 .048 0 r
.5167 .69933 .52297 .70119 .53452 .70986 .52828 .70788 Mtetra
.451 0 0 r
.52828 .70788 .53452 .70986 .54618 .71628 .53996 .71406 Mtetra
0 .431 .735 r
.53996 .71406 .54618 .71628 .55793 .72001 .55174 .71745 Mtetra
.266 .719 .956 r
.55174 .71745 .55793 .72001 .56974 .72074 .56358 .71775 Mtetra
.58 .853 .995 r
.56358 .71775 .56974 .72074 .58157 .71828 .57545 .71481 Mtetra
.739 .871 .942 r
.57545 .71481 .58157 .71828 .59339 .71262 .58731 .70863 Mtetra
.813 .855 .88 r
.58731 .70863 .59339 .71262 .60519 .70392 .59914 .69939 Mtetra
.848 .834 .833 r
.59914 .69939 .60519 .70392 .61692 .69246 .61092 .68742 Mtetra
.866 .816 .799 r
.61092 .68742 .61692 .69246 .62858 .67866 .62262 .67314 Mtetra
.875 .803 .776 r
.62262 .67314 .62858 .67866 .64016 .66303 .63424 .65709 Mtetra
.879 .793 .761 r
.63424 .65709 .64016 .66303 .65165 .64611 .64578 .63982 Mtetra
.88 .786 .753 r
.64578 .63982 .65165 .64611 .66308 .62846 .65726 .62189 Mtetra
.878 .781 .75 r
.65726 .62189 .66308 .62846 .67444 .61062 .66867 .60384 Mtetra
.875 .778 .751 r
.66867 .60384 .67444 .61062 .68577 .59305 .68005 .58612 Mtetra
.869 .776 .756 r
.68005 .58612 .68577 .59305 .69709 .57615 .69142 .56912 Mtetra
.862 .776 .764 r
.69142 .56912 .69709 .57615 .70841 .56021 .70279 .55313 Mtetra
.853 .775 .775 r
.70279 .55313 .70841 .56021 .71976 .54544 .71419 .53835 Mtetra
.841 .775 .789 r
.71419 .53835 .71976 .54544 .73116 .53196 .72564 .52486 Mtetra
.827 .775 .803 r
.72564 .52486 .73116 .53196 .74262 .51979 .73715 .51271 Mtetra
.812 .775 .818 r
.73715 .51271 .74262 .51979 .75416 .50889 .74874 .50183 Mtetra
.796 .773 .833 r
.74874 .50183 .75416 .50889 .76579 .4992 .76041 .49216 Mtetra
.778 .771 .846 r
.76041 .49216 .76579 .4992 .7775 .49057 .77217 .48355 Mtetra
.762 .769 .859 r
.77217 .48355 .7775 .49057 .7893 .48286 .78402 .47586 Mtetra
.746 .766 .869 r
.78402 .47586 .7893 .48286 .80119 .47594 .79595 .46894 Mtetra
.732 .763 .877 r
.79595 .46894 .80119 .47594 .81316 .46963 .80796 .46263 Mtetra
.72 .76 .884 r
.80796 .46263 .81316 .46963 .82521 .46382 .82006 .45681 Mtetra
.711 .757 .889 r
.82006 .45681 .82521 .46382 .83733 .45837 .83222 .45135 Mtetra
.703 .756 .893 r
.83222 .45135 .83733 .45837 .84952 .45319 .84445 .44615 Mtetra
.698 .754 .895 r
.84445 .44615 .84952 .45319 .86177 .44818 .85673 .44112 Mtetra
.695 .753 .897 r
.85673 .44112 .86177 .44818 .87408 .44328 .86908 .4362 Mtetra
.693 .753 .898 r
.86908 .4362 .87408 .44328 .88643 .43843 .88148 .43133 Mtetra
.692 .753 .898 r
.88148 .43133 .88643 .43843 .89884 .43362 .89392 .42649 Mtetra
.691 .753 .899 r
.89392 .42649 .89884 .43362 .91129 .4288 .90642 .42164 Mtetra
.90642 .42164 .91129 .4288 .92379 .42397 .91896 .41678 Mtetra
.692 .753 .899 r
.91896 .41678 .92379 .42397 .93634 .41912 .93155 .4119 Mtetra
.93155 .4119 .93634 .41912 .94893 .41423 .94418 .40699 Mtetra
.375 .651 .964 r
.36082 .57665 .36724 .58211 .37747 .58347 .37107 .57809 Mtetra
.259 .595 .95 r
.37107 .57809 .37747 .58347 .38773 .5859 .38134 .58063 Mtetra
.106 .509 .907 r
.38134 .58063 .38773 .5859 .39802 .58956 .39164 .5844 Mtetra
0 .39 .824 r
.39164 .5844 .39802 .58956 .40835 .59455 .40197 .58953 Mtetra
0 .249 .702 r
.40197 .58953 .40835 .59455 .41872 .60096 .41235 .59607 Mtetra
0 .109 .563 r
.41235 .59607 .41872 .60096 .42916 .6088 .42279 .60406 Mtetra
.551 .009 0 r
.42279 .60406 .42916 .6088 .43967 .61803 .43331 .61343 Mtetra
.633 .096 0 r
.43331 .61343 .43967 .61803 .45028 .62852 .44392 .62403 Mtetra
.683 .153 0 r
.44392 .62403 .45028 .62852 .461 .64005 .45465 .63564 Mtetra
.707 .184 0 r
.45465 .63564 .461 .64005 .47185 .6523 .4655 .64793 Mtetra
.711 .188 0 r
.4655 .64793 .47185 .6523 .48284 .66486 .47649 .66046 Mtetra
.693 .166 0 r
.47649 .66046 .48284 .66486 .49398 .67726 .48764 .67276 Mtetra
.644 .109 0 r
.48764 .67276 .49398 .67726 .50527 .68894 .49894 .68425 Mtetra
.545 .004 0 r
.49894 .68425 .50527 .68894 .5167 .69933 .51038 .69438 Mtetra
0 .168 .625 r
.51038 .69438 .5167 .69933 .52828 .70788 .52197 .70258 Mtetra
0 .394 .828 r
.52197 .70258 .52828 .70788 .53996 .71406 .53368 .70835 Mtetra
.26 .594 .949 r
.53368 .70835 .53996 .71406 .55174 .71745 .54547 .71128 Mtetra
.509 .703 .958 r
.54547 .71128 .55174 .71745 .56358 .71775 .55734 .71109 Mtetra
.655 .742 .913 r
.55734 .71109 .56358 .71775 .57545 .71481 .56923 .70765 Mtetra
.737 .751 .863 r
.56923 .70765 .57545 .71481 .58731 .70863 .58112 .70101 Mtetra
.784 .75 .822 r
.58112 .70101 .58731 .70863 .59914 .69939 .59298 .69136 Mtetra
.812 .746 .791 r
.59298 .69136 .59914 .69939 .61092 .68742 .60479 .67904 Mtetra
.829 .742 .768 r
.60479 .67904 .61092 .68742 .62262 .67314 .61653 .6645 Mtetra
.84 .74 .753 r
.61653 .6645 .62262 .67314 .63424 .65709 .6282 .64828 Mtetra
.847 .738 .743 r
.6282 .64828 .63424 .65709 .64578 .63982 .63979 .63093 Mtetra
.851 .738 .739 r
.63979 .63093 .64578 .63982 .65726 .62189 .65131 .613 Mtetra
.852 .739 .738 r
.65131 .613 .65726 .62189 .66867 .60384 .66278 .59501 Mtetra
.851 .74 .741 r
.66278 .59501 .66867 .60384 .68005 .58612 .67421 .57742 Mtetra
.848 .743 .747 r
.67421 .57742 .68005 .58612 .69142 .56912 .68564 .56058 Mtetra
.843 .745 .756 r
.68564 .56058 .69142 .56912 .70279 .55313 .69707 .54477 Mtetra
.836 .749 .767 r
.69707 .54477 .70279 .55313 .71419 .53835 .70853 .53017 Mtetra
.826 .752 .781 r
.70853 .53017 .71419 .53835 .72564 .52486 .72003 .51688 Mtetra
.815 .754 .796 r
.72003 .51688 .72564 .52486 .73715 .51271 .7316 .50489 Mtetra
.802 .756 .811 r
.7316 .50489 .73715 .51271 .74874 .50183 .74325 .49417 Mtetra
.787 .758 .826 r
.74325 .49417 .74874 .50183 .76041 .49216 .75497 .48463 Mtetra
.772 .758 .841 r
.75497 .48463 .76041 .49216 .77217 .48355 .76678 .47612 Mtetra
.756 .758 .854 r
.76678 .47612 .77217 .48355 .78402 .47586 .77867 .46852 Mtetra
.742 .757 .865 r
.77867 .46852 .78402 .47586 .79595 .46894 .79065 .46166 Mtetra
.729 .755 .874 r
.79065 .46166 .79595 .46894 .80796 .46263 .80271 .4554 Mtetra
.718 .754 .881 r
.80271 .4554 .80796 .46263 .82006 .45681 .81484 .4496 Mtetra
.709 .752 .886 r
.81484 .4496 .82006 .45681 .83222 .45135 .82705 .44415 Mtetra
.702 .751 .89 r
.82705 .44415 .83222 .45135 .84445 .44615 .83932 .43895 Mtetra
.697 .75 .893 r
.83932 .43895 .84445 .44615 .85673 .44112 .85165 .43391 Mtetra
.694 .75 .895 r
.85165 .43391 .85673 .44112 .86908 .4362 .86403 .42897 Mtetra
.692 .75 .896 r
.86403 .42897 .86908 .4362 .88148 .43133 .87647 .42409 Mtetra
.691 .75 .896 r
.87647 .42409 .88148 .43133 .89392 .42649 .88896 .41922 Mtetra
.691 .75 .897 r
.88896 .41922 .89392 .42649 .90642 .42164 .9015 .41436 Mtetra
.9015 .41436 .90642 .42164 .91896 .41678 .91408 .40947 Mtetra
.691 .751 .897 r
.91408 .40947 .91896 .41678 .93155 .4119 .92671 .40456 Mtetra
.92671 .40456 .93155 .4119 .94418 .40699 .93938 .39963 Mtetra
.385 .647 .96 r
.35437 .57091 .36082 .57665 .37107 .57809 .36463 .57236 Mtetra
.28 .594 .948 r
.36463 .57236 .37107 .57809 .38134 .58063 .37491 .5749 Mtetra
.145 .516 .915 r
.37491 .5749 .38134 .58063 .39164 .5844 .38522 .57867 Mtetra
0 .413 .851 r
.38522 .57867 .39164 .5844 .40197 .58953 .39557 .58379 Mtetra
0 .291 .759 r
.39557 .58379 .40197 .58953 .41235 .59607 .40596 .5903 Mtetra
0 .168 .651 r
.40596 .5903 .41235 .59607 .42279 .60406 .41641 .59824 Mtetra
0 .063 .549 r
.41641 .59824 .42279 .60406 .43331 .61343 .42693 .60752 Mtetra
.53 .016 0 r
.42693 .60752 .43331 .61343 .44392 .62403 .43755 .61799 Mtetra
.576 .066 0 r
.43755 .61799 .44392 .62403 .45465 .63564 .44828 .62942 Mtetra
.591 .086 0 r
.44828 .62942 .45465 .63564 .4655 .64793 .45913 .64146 Mtetra
.574 .075 0 r
.45913 .64146 .4655 .64793 .47649 .66046 .47013 .65368 Mtetra
.518 .028 0 r
.47013 .65368 .47649 .66046 .48764 .67276 .48128 .66559 Mtetra
0 .061 .582 r
.48128 .66559 .48764 .67276 .49894 .68425 .49258 .67664 Mtetra
0 .193 .709 r
.49258 .67664 .49894 .68425 .51038 .69438 .50403 .68627 Mtetra
.006 .349 .826 r
.50403 .68627 .51038 .69438 .52197 .70258 .51562 .69392 Mtetra
.249 .486 .888 r
.51562 .69392 .52197 .70258 .53368 .70835 .52734 .69912 Mtetra
.442 .577 .893 r
.52734 .69912 .53368 .70835 .54547 .71128 .53914 .70149 Mtetra
.575 .629 .868 r
.53914 .70149 .54547 .71128 .55734 .71109 .55102 .70077 Mtetra
.661 .656 .834 r
.55102 .70077 .55734 .71109 .56923 .70765 .56292 .69686 Mtetra
.717 .67 .803 r
.56292 .69686 .56923 .70765 .58112 .70101 .57483 .68984 Mtetra
.754 .679 .778 r
.57483 .68984 .58112 .70101 .59298 .69136 .58672 .67992 Mtetra
.78 .684 .758 r
.58672 .67992 .59298 .69136 .60479 .67904 .59856 .66745 Mtetra
.797 .688 .744 r
.59856 .66745 .60479 .67904 .61653 .6645 .61033 .65288 Mtetra
.81 .692 .734 r
.61033 .65288 .61653 .6645 .6282 .64828 .62204 .63674 Mtetra
.818 .695 .729 r
.62204 .63674 .6282 .64828 .63979 .63093 .63368 .61958 Mtetra
.824 .7 .727 r
.63368 .61958 .63979 .63093 .65131 .613 .64525 .60192 Mtetra
.827 .704 .728 r
.64525 .60192 .65131 .613 .66278 .59501 .65678 .58428 Mtetra
.829 .709 .733 r
.65678 .58428 .66278 .59501 .67421 .57742 .66827 .56707 Mtetra
.828 .714 .74 r
.66827 .56707 .67421 .57742 .68564 .56058 .67975 .55063 Mtetra
.824 .72 .749 r
.67975 .55063 .68564 .56058 .69707 .54477 .69125 .53523 Mtetra
.819 .725 .761 r
.69125 .53523 .69707 .54477 .70853 .53017 .70277 .52101 Mtetra
.812 .731 .775 r
.70277 .52101 .70853 .53017 .72003 .51688 .71434 .50807 Mtetra
.802 .736 .79 r
.71434 .50807 .72003 .51688 .7316 .50489 .72597 .4964 Mtetra
.791 .74 .806 r
.72597 .4964 .7316 .50489 .74325 .49417 .73768 .48596 Mtetra
.778 .744 .822 r
.73768 .48596 .74325 .49417 .75497 .48463 .74946 .47664 Mtetra
.764 .746 .837 r
.74946 .47664 .75497 .48463 .76678 .47612 .76132 .46833 Mtetra
.75 .748 .85 r
.76132 .46833 .76678 .47612 .77867 .46852 .77327 .46086 Mtetra
.737 .748 .861 r
.77327 .46086 .77867 .46852 .79065 .46166 .7853 .45411 Mtetra
.725 .748 .871 r
.7853 .45411 .79065 .46166 .80271 .4554 .7974 .44793 Mtetra
.715 .748 .878 r
.7974 .44793 .80271 .4554 .81484 .4496 .80958 .44219 Mtetra
.707 .747 .884 r
.80958 .44219 .81484 .4496 .82705 .44415 .82183 .43677 Mtetra
.7 .747 .888 r
.82183 .43677 .82705 .44415 .83932 .43895 .83414 .43158 Mtetra
.696 .747 .891 r
.83414 .43158 .83932 .43895 .85165 .43391 .84651 .42655 Mtetra
.693 .747 .893 r
.84651 .42655 .85165 .43391 .86403 .42897 .85894 .4216 Mtetra
.692 .747 .894 r
.85894 .4216 .86403 .42897 .87647 .42409 .87142 .41671 Mtetra
.691 .747 .895 r
.87142 .41671 .87647 .42409 .88896 .41922 .88395 .41183 Mtetra
.69 .748 .895 r
.88395 .41183 .88896 .41922 .9015 .41436 .89653 .40694 Mtetra
.69 .748 .896 r
.89653 .40694 .9015 .41436 .91408 .40947 .90915 .40204 Mtetra
.691 .749 .896 r
.90915 .40204 .91408 .40947 .92671 .40456 .92182 .39711 Mtetra
.92182 .39711 .92671 .40456 .93938 .39963 .93454 .39215 Mtetra
.402 .645 .956 r
.34788 .5649 .35437 .57091 .36463 .57236 .35816 .56627 Mtetra
.309 .597 .947 r
.35816 .56627 .36463 .57236 .37491 .5749 .36846 .56871 Mtetra
.193 .529 .922 r
.36846 .56871 .37491 .5749 .38522 .57867 .37879 .57236 Mtetra
.059 .441 .876 r
.37879 .57236 .38522 .57867 .39557 .58379 .38915 .57732 Mtetra
0 .34 .81 r
.38915 .57732 .39557 .58379 .40596 .5903 .39955 .58364 Mtetra
0 .238 .733 r
.39955 .58364 .40596 .5903 .41641 .59824 .41001 .59132 Mtetra
0 .15 .661 r
.41001 .59132 .41641 .59824 .42693 .60752 .42054 .60029 Mtetra
0 .085 .606 r
.42054 .60029 .42693 .60752 .43755 .61799 .43117 .6104 Mtetra
0 .048 .578 r
.43117 .6104 .43755 .61799 .44828 .62942 .4419 .62138 Mtetra
0 .042 .58 r
.4419 .62138 .44828 .62942 .45913 .64146 .45276 .63291 Mtetra
0 .07 .613 r
.45276 .63291 .45913 .64146 .47013 .65368 .46376 .64455 Mtetra
0 .13 .672 r
.46376 .64455 .47013 .65368 .48128 .66559 .47491 .65582 Mtetra
0 .22 .742 r
.47491 .65582 .48128 .66559 .49258 .67664 .48621 .66618 Mtetra
.067 .322 .803 r
.48621 .66618 .49258 .67664 .50403 .68627 .49766 .67509 Mtetra
.244 .418 .836 r
.49766 .67509 .50403 .68627 .51562 .69392 .50925 .68202 Mtetra
.396 .492 .84 r
.50925 .68202 .51562 .69392 .52734 .69912 .52096 .68653 Mtetra
.512 .545 .826 r
.52096 .68653 .52734 .69912 .53914 .70149 .53277 .68827 Mtetra
.596 .58 .805 r
.53277 .68827 .53914 .70149 .55102 .70077 .54464 .68701 Mtetra
.656 .603 .783 r
.54464 .68701 .55102 .70077 .56292 .69686 .55656 .68269 Mtetra
.7 .619 .763 r
.55656 .68269 .56292 .69686 .57483 .68984 .56848 .6754 Mtetra
.731 .631 .747 r
.56848 .6754 .57483 .68984 .58672 .67992 .58038 .66536 Mtetra
.754 .641 .735 r
.58038 .66536 .58672 .67992 .59856 .66745 .59224 .65293 Mtetra
.772 .649 .726 r
.59224 .65293 .59856 .66745 .61033 .65288 .60404 .63856 Mtetra
.785 .656 .721 r
.60404 .63856 .61033 .65288 .62204 .63674 .61579 .62275 Mtetra
.794 .663 .718 r
.61579 .62275 .62204 .63674 .63368 .61958 .62747 .60603 Mtetra
.801 .67 .718 r
.62747 .60603 .63368 .61958 .64525 .60192 .6391 .58891 Mtetra
.806 .676 .721 r
.6391 .58891 .64525 .60192 .65678 .58428 .65068 .57186 Mtetra
.808 .684 .727 r
.65068 .57186 .65678 .58428 .66827 .56707 .66224 .55527 Mtetra
.809 .691 .735 r
.66224 .55527 .66827 .56707 .67975 .55063 .67379 .53945 Mtetra
.807 .698 .745 r
.67379 .53945 .67975 .55063 .69125 .53523 .68535 .52464 Mtetra
.803 .706 .758 r
.68535 .52464 .69125 .53523 .70277 .52101 .69694 .51099 Mtetra
.797 .713 .772 r
.69694 .51099 .70277 .52101 .71434 .50807 .70858 .49855 Mtetra
.789 .72 .787 r
.70858 .49855 .71434 .50807 .72597 .4964 .72028 .48733 Mtetra
.779 .726 .803 r
.72028 .48733 .72597 .4964 .73768 .48596 .73204 .47726 Mtetra
.768 .732 .819 r
.73204 .47726 .73768 .48596 .74946 .47664 .74388 .46826 Mtetra
.756 .736 .834 r
.74388 .46826 .74946 .47664 .76132 .46833 .7558 .4602 Mtetra
.743 .739 .848 r
.7558 .4602 .76132 .46833 .77327 .46086 .7678 .45293 Mtetra
.731 .741 .859 r
.7678 .45293 .77327 .46086 .7853 .45411 .77988 .44633 Mtetra
.72 .742 .869 r
.77988 .44633 .7853 .45411 .7974 .44793 .79204 .44026 Mtetra
.711 .742 .876 r
.79204 .44026 .7974 .44793 .80958 .44219 .80427 .43459 Mtetra
.704 .743 .882 r
.80427 .43459 .80958 .44219 .82183 .43677 .81656 .42922 Mtetra
.698 .743 .886 r
.81656 .42922 .82183 .43677 .83414 .43158 .82892 .42406 Mtetra
.695 .744 .889 r
.82892 .42406 .83414 .43158 .84651 .42655 .84133 .41904 Mtetra
.692 .744 .891 r
.84133 .41904 .84651 .42655 .85894 .4216 .8538 .4141 Mtetra
.691 .744 .892 r
.8538 .4141 .85894 .4216 .87142 .41671 .86632 .4092 Mtetra
.69 .745 .893 r
.86632 .4092 .87142 .41671 .88395 .41183 .87889 .40431 Mtetra
.69 .745 .894 r
.87889 .40431 .88395 .41183 .89653 .40694 .89151 .3994 Mtetra
.69 .746 .894 r
.89151 .3994 .89653 .40694 .90915 .40204 .90418 .39448 Mtetra
.69 .747 .895 r
.90418 .39448 .90915 .40204 .92182 .39711 .91689 .38953 Mtetra
.91689 .38953 .92182 .39711 .93454 .39215 .92965 .38456 Mtetra
.422 .646 .951 r
.34136 .55861 .34788 .5649 .35816 .56627 .35166 .55982 Mtetra
.343 .603 .944 r
.35166 .55982 .35816 .56627 .36846 .56871 .36198 .56208 Mtetra
.247 .544 .926 r
.36198 .56208 .36846 .56871 .37879 .57236 .37233 .56549 Mtetra
.137 .471 .894 r
.37233 .56549 .37879 .57236 .38915 .57732 .3827 .57014 Mtetra
.025 .389 .849 r
.3827 .57014 .38915 .57732 .39955 .58364 .39312 .5761 Mtetra
0 .308 .797 r
.39312 .5761 .39955 .58364 .41001 .59132 .4036 .58335 Mtetra
0 .238 .749 r
.4036 .58335 .41001 .59132 .42054 .60029 .41415 .59181 Mtetra
0 .188 .715 r
.41415 .59181 .42054 .60029 .43117 .6104 .42478 .60132 Mtetra
0 .165 .7 r
.42478 .60132 .43117 .6104 .4419 .62138 .43552 .61163 Mtetra
0 .168 .705 r
.43552 .61163 .4419 .62138 .45276 .63291 .44639 .62241 Mtetra
0 .199 .728 r
.44639 .62241 .45276 .63291 .46376 .64455 .45739 .63323 Mtetra
0 .251 .759 r
.45739 .63323 .46376 .64455 .47491 .65582 .46854 .64364 Mtetra
.119 .316 .786 r
.46854 .64364 .47491 .65582 .48621 .66618 .47984 .6531 Mtetra
.249 .381 .802 r
.47984 .6531 .48621 .66618 .49766 .67509 .49128 .66112 Mtetra
.367 .44 .804 r
.49128 .66112 .49766 .67509 .50925 .68202 .50287 .6672 Mtetra
.466 .486 .795 r
.50287 .6672 .50925 .68202 .52096 .68653 .51457 .67094 Mtetra
.545 .522 .781 r
.51457 .67094 .52096 .68653 .53277 .68827 .52637 .67201 Mtetra
.605 .549 .765 r
.52637 .67201 .53277 .68827 .54464 .68701 .53823 .67024 Mtetra
.651 .57 .75 r
.53823 .67024 .54464 .68701 .55656 .68269 .55014 .66557 Mtetra
.686 .586 .737 r
.55014 .66557 .55656 .68269 .56848 .6754 .56207 .65812 Mtetra
.713 .599 .727 r
.56207 .65812 .56848 .6754 .58038 .66536 .57398 .64812 Mtetra
.734 .61 .719 r
.57398 .64812 .58038 .66536 .59224 .65293 .58585 .63592 Mtetra
.751 .62 .714 r
.58585 .63592 .59224 .65293 .60404 .63856 .59769 .62195 Mtetra
.764 .629 .711 r
.59769 .62195 .60404 .63856 .61579 .62275 .60946 .6067 Mtetra
.774 .638 .71 r
.60946 .6067 .61579 .62275 .62747 .60603 .62119 .59066 Mtetra
.782 .646 .712 r
.62119 .59066 .62747 .60603 .6391 .58891 .63287 .5743 Mtetra
.787 .655 .717 r
.63287 .5743 .6391 .58891 .65068 .57186 .64451 .55805 Mtetra
.79 .663 .723 r
.64451 .55805 .65068 .57186 .66224 .55527 .65613 .54227 Mtetra
.792 .672 .732 r
.65613 .54227 .66224 .55527 .67379 .53945 .66775 .52726 Mtetra
.791 .681 .743 r
.66775 .52726 .67379 .53945 .68535 .52464 .67938 .51321 Mtetra
.788 .69 .756 r
.67938 .51321 .68535 .52464 .69694 .51099 .69104 .50026 Mtetra
.784 .699 .771 r
.69104 .50026 .69694 .51099 .70858 .49855 .70275 .48844 Mtetra
.777 .707 .786 r
.70275 .48844 .70858 .49855 .72028 .48733 .71452 .47776 Mtetra
.768 .715 .802 r
.71452 .47776 .72028 .48733 .73204 .47726 .72635 .46816 Mtetra
.758 .721 .818 r
.72635 .46816 .73204 .47726 .74388 .46826 .73825 .45954 Mtetra
.747 .727 .833 r
.73825 .45954 .74388 .46826 .7558 .4602 .75023 .45178 Mtetra
.736 .731 .846 r
.75023 .45178 .7558 .4602 .7678 .45293 .76229 .44476 Mtetra
.725 .734 .858 r
.76229 .44476 .7678 .45293 .77988 .44633 .77442 .43834 Mtetra
.716 .736 .867 r
.77442 .43834 .77988 .44633 .79204 .44026 .78663 .4324 Mtetra
.707 .738 .875 r
.78663 .4324 .79204 .44026 .80427 .43459 .7989 .42683 Mtetra
.701 .739 .881 r
.7989 .42683 .80427 .43459 .81656 .42922 .81124 .42152 Mtetra
.696 .74 .885 r
.81124 .42152 .81656 .42922 .82892 .42406 .82364 .4164 Mtetra
.693 .74 .888 r
.82364 .4164 .82892 .42406 .84133 .41904 .8361 .4114 Mtetra
.691 .741 .89 r
.8361 .4114 .84133 .41904 .8538 .4141 .84861 .40647 Mtetra
.69 .742 .891 r
.84861 .40647 .8538 .4141 .86632 .4092 .86118 .40156 Mtetra
.689 .743 .892 r
.86118 .40156 .86632 .4092 .87889 .40431 .87379 .39666 Mtetra
.689 .743 .893 r
.87379 .39666 .87889 .40431 .89151 .3994 .88645 .39175 Mtetra
.689 .744 .893 r
.88645 .39175 .89151 .3994 .90418 .39448 .89916 .38681 Mtetra
.689 .745 .893 r
.89916 .38681 .90418 .39448 .91689 .38953 .91192 .38185 Mtetra
.69 .745 .894 r
.91192 .38185 .91689 .38953 .92965 .38456 .92472 .37685 Mtetra
.445 .649 .945 r
.3348 .55206 .34136 .55861 .35166 .55982 .34513 .55305 Mtetra
.379 .61 .94 r
.34513 .55305 .35166 .55982 .36198 .56208 .35547 .55503 Mtetra
.3 .56 .927 r
.35547 .55503 .36198 .56208 .37233 .56549 .36584 .55809 Mtetra
.214 .5 .904 r
.36584 .55809 .37233 .56549 .3827 .57014 .37625 .56233 Mtetra
.127 .434 .873 r
.37625 .56233 .3827 .57014 .39312 .5761 .38669 .56778 Mtetra
.052 .369 .838 r
.38669 .56778 .39312 .5761 .4036 .58335 .39718 .57443 Mtetra
0 .315 .805 r
.39718 .57443 .4036 .58335 .41415 .59181 .40775 .5822 Mtetra
0 .278 .781 r
.40775 .5822 .41415 .59181 .42478 .60132 .4184 .59093 Mtetra
0 .261 .768 r
.4184 .59093 .42478 .60132 .43552 .61163 .42916 .60036 Mtetra
.016 .266 .767 r
.42916 .60036 .43552 .61163 .44639 .62241 .44003 .61018 Mtetra
.082 .289 .773 r
.44003 .61018 .44639 .62241 .45739 .63323 .45104 .62 Mtetra
.167 .326 .78 r
.45104 .62 .45739 .63323 .46854 .64364 .46218 .62935 Mtetra
.261 .368 .784 r
.46218 .62935 .46854 .64364 .47984 .6531 .47348 .63777 Mtetra
.353 .411 .782 r
.47348 .63777 .47984 .6531 .49128 .66112 .48491 .64477 Mtetra
.435 .449 .775 r
.48491 .64477 .49128 .66112 .50287 .6672 .49648 .64991 Mtetra
.505 .481 .764 r
.49648 .64991 .50287 .6672 .51457 .67094 .50817 .65282 Mtetra
.563 .508 .752 r
.50817 .65282 .51457 .67094 .52637 .67201 .51995 .65323 Mtetra
.609 .53 .74 r
.51995 .65323 .52637 .67201 .53823 .67024 .53181 .65098 Mtetra
.646 .548 .73 r
.53181 .65098 .53823 .67024 .55014 .66557 .54371 .64606 Mtetra
.676 .563 .721 r
.54371 .64606 .55014 .66557 .56207 .65812 .55563 .63857 Mtetra
.7 .577 .714 r
.55563 .63857 .56207 .65812 .57398 .64812 .56754 .62876 Mtetra
.719 .588 .709 r
.56754 .62876 .57398 .64812 .58585 .63592 .57943 .61696 Mtetra
.735 .599 .706 r
.57943 .61696 .58585 .63592 .59769 .62195 .59128 .60358 Mtetra
.747 .609 .705 r
.59128 .60358 .59769 .62195 .60946 .6067 .60309 .58908 Mtetra
.757 .619 .706 r
.60309 .58908 .60946 .6067 .62119 .59066 .61486 .57389 Mtetra
.765 .628 .709 r
.61486 .57389 .62119 .59066 .63287 .5743 .62658 .55847 Mtetra
.771 .638 .714 r
.62658 .55847 .63287 .5743 .64451 .55805 .63828 .5432 Mtetra
.775 .648 .722 r
.63828 .5432 .64451 .55805 .65613 .54227 .64997 .52839 Mtetra
.777 .658 .731 r
.64997 .52839 .65613 .54227 .66775 .52726 .66165 .51432 Mtetra
.777 .668 .743 r
.66165 .51432 .66775 .52726 .67938 .51321 .67335 .50115 Mtetra
.775 .678 .756 r
.67335 .50115 .67938 .51321 .69104 .50026 .68509 .489 Mtetra
.771 .688 .771 r
.68509 .489 .69104 .50026 .70275 .48844 .69687 .4779 Mtetra
.765 .697 .787 r
.69687 .4779 .70275 .48844 .71452 .47776 .7087 .46783 Mtetra
.757 .705 .803 r
.7087 .46783 .71452 .47776 .72635 .46816 .7206 .45875 Mtetra
.748 .713 .819 r
.7206 .45875 .72635 .46816 .73825 .45954 .73257 .45056 Mtetra
.738 .719 .834 r
.73257 .45056 .73825 .45954 .75023 .45178 .74461 .44315 Mtetra
.728 .724 .847 r
.74461 .44315 .75023 .45178 .76229 .44476 .75672 .43639 Mtetra
.719 .728 .858 r
.75672 .43639 .76229 .44476 .77442 .43834 .76891 .43018 Mtetra
.711 .731 .867 r
.76891 .43018 .77442 .43834 .78663 .4324 .78117 .42439 Mtetra
.703 .734 .874 r
.78117 .42439 .78663 .4324 .7989 .42683 .79349 .41892 Mtetra
.698 .735 .88 r
.79349 .41892 .7989 .42683 .81124 .42152 .80587 .41368 Mtetra
.694 .737 .884 r
.80587 .41368 .81124 .42152 .82364 .4164 .81832 .40861 Mtetra
.691 .738 .887 r
.81832 .40861 .82364 .4164 .8361 .4114 .83082 .40363 Mtetra
.689 .739 .889 r
.83082 .40363 .8361 .4114 .84861 .40647 .84338 .39871 Mtetra
.688 .74 .89 r
.84338 .39871 .84861 .40647 .86118 .40156 .85598 .39381 Mtetra
.688 .74 .891 r
.85598 .39381 .86118 .40156 .87379 .39666 .86864 .3889 Mtetra
.688 .741 .892 r
.86864 .3889 .87379 .39666 .88645 .39175 .88134 .38398 Mtetra
.688 .742 .892 r
.88134 .38398 .88645 .39175 .89916 .38681 .89409 .37903 Mtetra
.689 .743 .893 r
.89409 .37903 .89916 .38681 .91192 .38185 .90689 .37405 Mtetra
.689 .744 .893 r
.90689 .37405 .91192 .38185 .92472 .37685 .91974 .36904 Mtetra
.469 .653 .94 r
.3282 .54528 .3348 .55206 .34513 .55305 .33856 .54599 Mtetra
.414 .619 .935 r
.33856 .54599 .34513 .55305 .35547 .55503 .34894 .54761 Mtetra
.351 .576 .925 r
.34894 .54761 .35547 .55503 .36584 .55809 .35934 .55024 Mtetra
.283 .526 .908 r
.35934 .55024 .36584 .55809 .37625 .56233 .36977 .55396 Mtetra
.218 .472 .885 r
.36977 .55396 .37625 .56233 .38669 .56778 .38024 .55879 Mtetra
.163 .42 .859 r
.38024 .55879 .38669 .56778 .39718 .57443 .39076 .56471 Mtetra
.127 .377 .834 r
.39076 .56471 .39718 .57443 .40775 .5822 .40135 .57164 Mtetra
.113 .347 .813 r
.40135 .57164 .40775 .5822 .4184 .59093 .41202 .57943 Mtetra
.125 .333 .799 r
.41202 .57943 .4184 .59093 .42916 .60036 .42279 .58783 Mtetra
.161 .334 .79 r
.42279 .58783 .42916 .60036 .44003 .61018 .43368 .59655 Mtetra
.215 .349 .784 r
.43368 .59655 .44003 .61018 .45104 .62 .44469 .6052 Mtetra
.281 .372 .779 r
.44469 .6052 .45104 .62 .46218 .62935 .45584 .61338 Mtetra
.35 .4 .773 r
.45584 .61338 .46218 .62935 .47348 .63777 .46713 .62064 Mtetra
.417 .428 .764 r
.46713 .62064 .47348 .63777 .48491 .64477 .47855 .62655 Mtetra
.477 .455 .754 r
.47855 .62655 .48491 .64477 .49648 .64991 .49011 .63071 Mtetra
.53 .479 .744 r
.49011 .63071 .49648 .64991 .50817 .65282 .50178 .63279 Mtetra
.574 .5 .734 r
.50178 .63279 .50817 .65282 .51995 .65323 .51354 .63256 Mtetra
.612 .519 .724 r
.51354 .63256 .51995 .65323 .53181 .65098 .52538 .62989 Mtetra
.642 .535 .717 r
.52538 .62989 .53181 .65098 .54371 .64606 .53727 .62479 Mtetra
.668 .549 .71 r
.53727 .62479 .54371 .64606 .55563 .63857 .54917 .61738 Mtetra
.689 .561 .705 r
.54917 .61738 .55563 .63857 .56754 .62876 .56108 .60789 Mtetra
.707 .573 .702 r
.56108 .60789 .56754 .62876 .57943 .61696 .57298 .59663 Mtetra
.721 .584 .701 r
.57298 .59663 .57943 .61696 .59128 .60358 .58485 .58399 Mtetra
.733 .595 .702 r
.58485 .58399 .59128 .60358 .60309 .58908 .59669 .57038 Mtetra
.743 .605 .704 r
.59669 .57038 .60309 .58908 .61486 .57389 .60849 .5562 Mtetra
.751 .615 .708 r
.60849 .5562 .61486 .57389 .62658 .55847 .62026 .54184 Mtetra
.757 .626 .715 r
.62026 .54184 .62658 .55847 .63828 .5432 .63202 .52766 Mtetra
.761 .636 .723 r
.63202 .52766 .63828 .5432 .64997 .52839 .64376 .51394 Mtetra
.763 .647 .733 r
.64376 .51394 .64997 .52839 .66165 .51432 .65551 .50089 Mtetra
.763 .658 .745 r
.65551 .50089 .66165 .51432 .67335 .50115 .66729 .48868 Mtetra
.762 .668 .759 r
.66729 .48868 .67335 .50115 .68509 .489 .67909 .4774 Mtetra
.759 .679 .774 r
.67909 .4774 .68509 .489 .69687 .4779 .69094 .46706 Mtetra
.753 .689 .79 r
.69094 .46706 .69687 .4779 .7087 .46783 .70284 .45766 Mtetra
.747 .698 .806 r
.70284 .45766 .7087 .46783 .7206 .45875 .71481 .44913 Mtetra
.739 .707 .821 r
.71481 .44913 .7206 .45875 .73257 .45056 .72684 .44139 Mtetra
.73 .714 .835 r
.72684 .44139 .73257 .45056 .74461 .44315 .73894 .43434 Mtetra
.721 .719 .848 r
.73894 .43434 .74461 .44315 .75672 .43639 .75111 .42787 Mtetra
.713 .724 .859 r
.75111 .42787 .75672 .43639 .76891 .43018 .76335 .42187 Mtetra
.706 .727 .867 r
.76335 .42187 .76891 .43018 .78117 .42439 .77566 .41624 Mtetra
.7 .73 .874 r
.77566 .41624 .78117 .42439 .79349 .41892 .78803 .41088 Mtetra
.695 .732 .879 r
.78803 .41088 .79349 .41892 .80587 .41368 .80046 .40572 Mtetra
.691 .734 .883 r
.80046 .40572 .80587 .41368 .81832 .40861 .81295 .40069 Mtetra
.689 .735 .886 r
.81295 .40069 .81832 .40861 .83082 .40363 .8255 .39575 Mtetra
.688 .737 .888 r
.8255 .39575 .83082 .40363 .84338 .39871 .8381 .39084 Mtetra
.687 .738 .889 r
.8381 .39084 .84338 .39871 .85598 .39381 .85074 .38594 Mtetra
.687 .739 .89 r
.85074 .38594 .85598 .39381 .86864 .3889 .86344 .38103 Mtetra
.687 .74 .891 r
.86344 .38103 .86864 .3889 .88134 .38398 .87619 .3761 Mtetra
.688 .74 .891 r
.87619 .3761 .88134 .38398 .89409 .37903 .88898 .37114 Mtetra
.688 .741 .892 r
.88898 .37114 .89409 .37903 .90689 .37405 .90183 .36614 Mtetra
.688 .742 .892 r
.90183 .36614 .90689 .37405 .91974 .36904 .91472 .36112 Mtetra
.493 .658 .934 r
.32157 .53831 .3282 .54528 .33856 .54599 .33196 .53869 Mtetra
.448 .628 .93 r
.33196 .53869 .33856 .54599 .34894 .54761 .34237 .5399 Mtetra
.397 .591 .922 r
.34237 .5399 .34894 .54761 .35934 .55024 .3528 .54203 Mtetra
.345 .549 .908 r
.3528 .54203 .35934 .55024 .36977 .55396 .36327 .54514 Mtetra
.295 .504 .89 r
.36327 .54514 .36977 .55396 .38024 .55879 .37377 .54926 Mtetra
.255 .461 .868 r
.37377 .54926 .38024 .55879 .39076 .56471 .38433 .55435 Mtetra
.23 .425 .847 r
.38433 .55435 .39076 .56471 .40135 .57164 .39495 .56035 Mtetra
.224 .399 .827 r
.39495 .56035 .40135 .57164 .41202 .57943 .40564 .56709 Mtetra
.236 .385 .81 r
.40564 .56709 .41202 .57943 .42279 .58783 .41644 .57435 Mtetra
.266 .383 .796 r
.41644 .57435 .42279 .58783 .43368 .59655 .42734 .58186 Mtetra
.308 .39 .784 r
.42734 .58186 .43368 .59655 .44469 .6052 .43836 .58926 Mtetra
.358 .404 .773 r
.43836 .58926 .44469 .6052 .45584 .61338 .44951 .59619 Mtetra
.409 .422 .762 r
.44951 .59619 .45584 .61338 .46713 .62064 .46079 .60224 Mtetra
.46 .442 .752 r
.46079 .60224 .46713 .62064 .47855 .62655 .47221 .60702 Mtetra
.506 .461 .741 r
.47221 .60702 .47855 .62655 .49011 .63071 .48375 .6102 Mtetra
.547 .48 .732 r
.48375 .6102 .49011 .63071 .50178 .63279 .4954 .61147 Mtetra
.583 .497 .723 r
.4954 .61147 .50178 .63279 .51354 .63256 .50714 .61065 Mtetra
.614 .512 .715 r
.50714 .61065 .51354 .63256 .52538 .62989 .51896 .60764 Mtetra
.64 .527 .709 r
.51896 .60764 .52538 .62989 .53727 .62479 .53082 .60245 Mtetra
.662 .54 .704 r
.53082 .60245 .53727 .62479 .54917 .61738 .54272 .59522 Mtetra
.681 .552 .701 r
.54272 .59522 .54917 .61738 .56108 .60789 .55462 .58615 Mtetra
.697 .563 .7 r
.55462 .58615 .56108 .60789 .57298 .59663 .56652 .57555 Mtetra
.71 .574 .7 r
.56652 .57555 .57298 .59663 .58485 .58399 .57841 .56375 Mtetra
.722 .585 .701 r
.57841 .56375 .58485 .58399 .59669 .57038 .59026 .55112 Mtetra
.731 .595 .705 r
.59026 .55112 .59669 .57038 .60849 .5562 .6021 .53803 Mtetra
.738 .606 .71 r
.6021 .53803 .60849 .5562 .62026 .54184 .61392 .52482 Mtetra
.744 .617 .717 r
.61392 .52482 .62026 .54184 .63202 .52766 .62572 .5118 Mtetra
.748 .628 .726 r
.62572 .5118 .63202 .52766 .64376 .51394 .63753 .49921 Mtetra
.751 .639 .737 r
.63753 .49921 .64376 .51394 .65551 .50089 .64935 .48724 Mtetra
.751 .651 .749 r
.64935 .48724 .65551 .50089 .66729 .48868 .66118 .47602 Mtetra
.75 .662 .763 r
.66118 .47602 .66729 .48868 .67909 .4774 .67306 .46563 Mtetra
.747 .673 .778 r
.67306 .46563 .67909 .4774 .69094 .46706 .68497 .45608 Mtetra
.743 .684 .794 r
.68497 .45608 .69094 .46706 .70284 .45766 .69695 .44735 Mtetra
.737 .693 .81 r
.69695 .44735 .70284 .45766 .71481 .44913 .70898 .43938 Mtetra
.73 .702 .824 r
.70898 .43938 .71481 .44913 .72684 .44139 .72107 .4321 Mtetra
.722 .71 .838 r
.72107 .4321 .72684 .44139 .73894 .43434 .73323 .42542 Mtetra
.714 .716 .85 r
.73323 .42542 .73894 .43434 .75111 .42787 .74546 .41923 Mtetra
.707 .721 .86 r
.74546 .41923 .75111 .42787 .76335 .42187 .75775 .41345 Mtetra
.701 .724 .868 r
.75775 .41345 .76335 .42187 .77566 .41624 .77011 .40797 Mtetra
.696 .727 .875 r
.77011 .40797 .77566 .41624 .78803 .41088 .78253 .40273 Mtetra
.692 .73 .879 r
.78253 .40273 .78803 .41088 .80046 .40572 .795 .39765 Mtetra
.689 .732 .883 r
.795 .39765 .80046 .40572 .81295 .40069 .80754 .39267 Mtetra
.687 .733 .886 r
.80754 .39267 .81295 .40069 .8255 .39575 .82013 .38775 Mtetra
.686 .735 .887 r
.82013 .38775 .8255 .39575 .8381 .39084 .83277 .38286 Mtetra
.686 .736 .889 r
.83277 .38286 .8381 .39084 .85074 .38594 .84546 .37796 Mtetra
.686 .737 .889 r
.84546 .37796 .85074 .38594 .86344 .38103 .8582 .37305 Mtetra
.686 .738 .89 r
.8582 .37305 .86344 .38103 .87619 .3761 .87099 .36811 Mtetra
.687 .739 .891 r
.87099 .36811 .87619 .3761 .88898 .37114 .88383 .36314 Mtetra
.687 .74 .891 r
.88383 .36314 .88898 .37114 .90183 .36614 .89672 .35814 Mtetra
.688 .741 .891 r
.89672 .35814 .90183 .36614 .91472 .36112 .90965 .3531 Mtetra
.515 .664 .929 r
.3149 .53118 .32157 .53831 .33196 .53869 .32532 .53121 Mtetra
.478 .637 .925 r
.32532 .53121 .33196 .53869 .34237 .5399 .33577 .53197 Mtetra
.438 .605 .917 r
.33577 .53197 .34237 .5399 .3528 .54203 .34624 .53355 Mtetra
.397 .569 .905 r
.34624 .53355 .3528 .54203 .36327 .54514 .35675 .53601 Mtetra
.36 .531 .89 r
.35675 .53601 .36327 .54514 .37377 .54926 .36729 .53935 Mtetra
.33 .495 .871 r
.36729 .53935 .37377 .54926 .38433 .55435 .37788 .54356 Mtetra
.312 .464 .851 r
.37788 .54356 .38433 .55435 .39495 .56035 .38853 .54855 Mtetra
.308 .44 .831 r
.38853 .54855 .39495 .56035 .40564 .56709 .39926 .55418 Mtetra
.319 .425 .813 r
.39926 .55418 .40564 .56709 .41644 .57435 .41008 .56025 Mtetra
.342 .42 .797 r
.41008 .56025 .41644 .57435 .42734 .58186 .421 .56649 Mtetra
.374 .422 .782 r
.421 .56649 .42734 .58186 .43836 .58926 .43203 .57261 Mtetra
.412 .429 .768 r
.43203 .57261 .43836 .58926 .44951 .59619 .44319 .57826 Mtetra
.452 .441 .756 r
.44319 .57826 .44951 .59619 .46079 .60224 .45447 .5831 Mtetra
.49 .454 .745 r
.45447 .5831 .46079 .60224 .47221 .60702 .46588 .58677 Mtetra
.527 .469 .734 r
.46588 .58677 .47221 .60702 .48375 .6102 .4774 .58899 Mtetra
.56 .483 .725 r
.4774 .58899 .48375 .6102 .4954 .61147 .48903 .5895 Mtetra
.59 .497 .717 r
.48903 .5895 .4954 .61147 .50714 .61065 .50075 .58815 Mtetra
.616 .51 .711 r
.50075 .58815 .50714 .61065 .51896 .60764 .51255 .58487 Mtetra
.638 .523 .706 r
.51255 .58487 .51896 .60764 .53082 .60245 .52439 .57968 Mtetra
.658 .535 .703 r
.52439 .57968 .53082 .60245 .54272 .59522 .53627 .5727 Mtetra
.675 .546 .7 r
.53627 .5727 .54272 .59522 .55462 .58615 .54817 .56414 Mtetra
.689 .557 .7 r
.54817 .56414 .55462 .58615 .56652 .57555 .56007 .55425 Mtetra
.701 .568 .701 r
.56007 .55425 .56652 .57555 .57841 .56375 .57196 .54336 Mtetra
.712 .579 .704 r
.57196 .54336 .57841 .56375 .59026 .55112 .58384 .53177 Mtetra
.721 .589 .708 r
.58384 .53177 .59026 .55112 .6021 .53803 .59571 .51981 Mtetra
.728 .6 .714 r
.59571 .51981 .6021 .53803 .61392 .52482 .60756 .50778 Mtetra
.733 .612 .722 r
.60756 .50778 .61392 .52482 .62572 .5118 .61942 .49593 Mtetra
.737 .623 .731 r
.61942 .49593 .62572 .5118 .63753 .49921 .63128 .48448 Mtetra
.74 .635 .743 r
.63128 .48448 .63753 .49921 .64935 .48724 .64316 .47359 Mtetra
.74 .646 .756 r
.64316 .47359 .64935 .48724 .66118 .47602 .65506 .46336 Mtetra
.739 .658 .77 r
.65506 .46336 .66118 .47602 .67306 .46563 .667 .45385 Mtetra
.737 .67 .785 r
.667 .45385 .67306 .46563 .68497 .45608 .67898 .44507 Mtetra
.733 .681 .8 r
.67898 .44507 .68497 .45608 .69695 .44735 .69101 .437 Mtetra
.727 .69 .815 r
.69101 .437 .69695 .44735 .70898 .43938 .70311 .42959 Mtetra
.721 .699 .829 r
.70311 .42959 .70898 .43938 .72107 .4321 .71526 .42276 Mtetra
.714 .707 .842 r
.71526 .42276 .72107 .4321 .73323 .42542 .72748 .41643 Mtetra
.708 .713 .853 r
.72748 .41643 .73323 .42542 .74546 .41923 .73976 .41052 Mtetra
.701 .718 .862 r
.73976 .41052 .74546 .41923 .75775 .41345 .75211 .40495 Mtetra
.696 .722 .87 r
.75211 .40495 .75775 .41345 .77011 .40797 .76451 .39963 Mtetra
.692 .725 .875 r
.76451 .39963 .77011 .40797 .78253 .40273 .77698 .39449 Mtetra
.689 .728 .88 r
.77698 .39449 .78253 .40273 .795 .39765 .7895 .38948 Mtetra
.687 .73 .883 r
.7895 .38948 .795 .39765 .80754 .39267 .80208 .38455 Mtetra
.686 .732 .885 r
.80208 .38455 .80754 .39267 .82013 .38775 .81471 .37966 Mtetra
.685 .733 .887 r
.81471 .37966 .82013 .38775 .83277 .38286 .8274 .37478 Mtetra
.685 .734 .888 r
.8274 .37478 .83277 .38286 .84546 .37796 .84013 .36988 Mtetra
.685 .735 .889 r
.84013 .36988 .84546 .37796 .8582 .37305 .85292 .36497 Mtetra
.686 .737 .89 r
.85292 .36497 .8582 .37305 .87099 .36811 .86575 .36003 Mtetra
.686 .738 .89 r
.86575 .36003 .87099 .36811 .88383 .36314 .87863 .35505 Mtetra
.87863 .35505 .88383 .36314 .89672 .35814 .89156 .35004 Mtetra
.687 .739 .891 r
.89156 .35004 .89672 .35814 .90965 .3531 .90454 .34499 Mtetra
.536 .67 .924 r
.30819 .52395 .3149 .53118 .32532 .53121 .31865 .52359 Mtetra
.506 .647 .92 r
.31865 .52359 .32532 .53121 .33577 .53197 .32913 .52389 Mtetra
.474 .619 .913 r
.32913 .52389 .33577 .53197 .34624 .53355 .33965 .5249 Mtetra
.442 .588 .902 r
.33965 .5249 .34624 .53355 .35675 .53601 .35019 .52668 Mtetra
.413 .555 .888 r
.35019 .52668 .35675 .53601 .36729 .53935 .36077 .52922 Mtetra
.39 .524 .871 r
.36077 .52922 .36729 .53935 .37788 .54356 .3714 .53252 Mtetra
.376 .496 .852 r
.3714 .53252 .37788 .54356 .38853 .54855 .38209 .53648 Mtetra
.374 .473 .833 r
.38209 .53648 .38853 .54855 .39926 .55418 .39286 .54098 Mtetra
.382 .458 .814 r
.39286 .54098 .39926 .55418 .41008 .56025 .40371 .54584 Mtetra
.399 .45 .797 r
.40371 .54584 .41008 .56025 .421 .56649 .41465 .55083 Mtetra
.424 .448 .781 r
.41465 .55083 .421 .56649 .43203 .57261 .4257 .55567 Mtetra
.453 .451 .766 r
.4257 .55567 .43203 .57261 .44319 .57826 .43687 .56008 Mtetra
.483 .458 .753 r
.43687 .56008 .44319 .57826 .45447 .5831 .44815 .56373 Mtetra
.514 .467 .742 r
.44815 .56373 .45447 .5831 .46588 .58677 .45955 .56634 Mtetra
.543 .477 .732 r
.45955 .56634 .46588 .58677 .4774 .58899 .47106 .56766 Mtetra
.571 .489 .723 r
.47106 .56766 .4774 .58899 .48903 .5895 .48267 .56748 Mtetra
.595 .5 .716 r
.48267 .56748 .48903 .5895 .50075 .58815 .49437 .56567 Mtetra
.618 .511 .711 r
.49437 .56567 .50075 .58815 .51255 .58487 .50614 .56218 Mtetra
.637 .522 .707 r
.50614 .56218 .51255 .58487 .52439 .57968 .51797 .55705 Mtetra
.654 .533 .704 r
.51797 .55705 .52439 .57968 .53627 .5727 .52983 .55039 Mtetra
.67 .544 .703 r
.52983 .55039 .53627 .5727 .54817 .56414 .54172 .54238 Mtetra
.683 .555 .703 r
.54172 .54238 .54817 .56414 .56007 .55425 .55362 .53325 Mtetra
.694 .565 .705 r
.55362 .53325 .56007 .55425 .57196 .54336 .56552 .52328 Mtetra
.704 .576 .708 r
.56552 .52328 .57196 .54336 .58384 .53177 .57742 .51274 Mtetra
.712 .587 .714 r
.57742 .51274 .58384 .53177 .59571 .51981 .58931 .5019 Mtetra
.719 .598 .72 r
.58931 .5019 .59571 .51981 .60756 .50778 .60121 .49103 Mtetra
.724 .609 .729 r
.60121 .49103 .60756 .50778 .61942 .49593 .6131 .48033 Mtetra
.728 .621 .739 r
.6131 .48033 .61942 .49593 .63128 .48448 .62502 .47 Mtetra
.73 .633 .751 r
.62502 .47 .63128 .48448 .64316 .47359 .63695 .46014 Mtetra
.73 .645 .764 r
.63695 .46014 .64316 .47359 .65506 .46336 .64891 .45086 Mtetra
.729 .657 .778 r
.64891 .45086 .65506 .46336 .667 .45385 .66091 .4422 Mtetra
.727 .668 .792 r
.66091 .4422 .667 .45385 .67898 .44507 .67296 .43416 Mtetra
.723 .679 .807 r
.67296 .43416 .67898 .44507 .69101 .437 .68505 .42671 Mtetra
.718 .689 .821 r
.68505 .42671 .69101 .437 .70311 .42959 .69721 .41982 Mtetra
.713 .698 .834 r
.69721 .41982 .70311 .42959 .71526 .42276 .70942 .41341 Mtetra
.707 .705 .846 r
.70942 .41341 .71526 .42276 .72748 .41643 .72169 .40742 Mtetra
.701 .712 .856 r
.72169 .40742 .72748 .41643 .73976 .41052 .73402 .40177 Mtetra
.696 .717 .865 r
.73402 .40177 .73976 .41052 .75211 .40495 .74642 .39639 Mtetra
.692 .721 .871 r
.74642 .39639 .75211 .40495 .76451 .39963 .75887 .39121 Mtetra
.689 .724 .877 r
.75887 .39121 .76451 .39963 .77698 .39449 .77139 .38617 Mtetra
.686 .726 .881 r
.77139 .38617 .77698 .39449 .7895 .38948 .78395 .38123 Mtetra
.685 .729 .883 r
.78395 .38123 .7895 .38948 .80208 .38455 .79658 .37634 Mtetra
.684 .73 .885 r
.79658 .37634 .80208 .38455 .81471 .37966 .80925 .37147 Mtetra
.684 .732 .887 r
.80925 .37147 .81471 .37966 .8274 .37478 .82198 .3666 Mtetra
.684 .733 .888 r
.82198 .3666 .8274 .37478 .84013 .36988 .83476 .36171 Mtetra
.684 .734 .889 r
.83476 .36171 .84013 .36988 .85292 .36497 .84758 .3568 Mtetra
.685 .735 .889 r
.84758 .3568 .85292 .36497 .86575 .36003 .86046 .35185 Mtetra
.685 .736 .89 r
.86046 .35185 .86575 .36003 .87863 .35505 .87338 .34686 Mtetra
.686 .737 .89 r
.87338 .34686 .87863 .35505 .89156 .35004 .88636 .34184 Mtetra
.686 .738 .891 r
.88636 .34184 .89156 .35004 .90454 .34499 .89938 .33679 Mtetra
.555 .677 .92 r
.30143 .51665 .30819 .52395 .31865 .52359 .31193 .51591 Mtetra
.53 .657 .916 r
.31193 .51591 .31865 .52359 .32913 .52389 .32246 .51574 Mtetra
.505 .632 .909 r
.32246 .51574 .32913 .52389 .33965 .5249 .33301 .51618 Mtetra
.479 .605 .9 r
.33301 .51618 .33965 .5249 .35019 .52668 .3436 .51727 Mtetra
.457 .577 .886 r
.3436 .51727 .35019 .52668 .36077 .52922 .35423 .51903 Mtetra
.439 .549 .871 r
.35423 .51903 .36077 .52922 .3714 .53252 .3649 .52141 Mtetra
.428 .523 .853 r
.3649 .52141 .3714 .53252 .38209 .53648 .37563 .52436 Mtetra
.425 .502 .835 r
.37563 .52436 .38209 .53648 .39286 .54098 .38643 .52776 Mtetra
.431 .486 .816 r
.38643 .52776 .39286 .54098 .40371 .54584 .39731 .53144 Mtetra
.444 .476 .799 r
.39731 .53144 .40371 .54584 .41465 .55083 .40829 .53521 Mtetra
.462 .472 .782 r
.40829 .53521 .41465 .55083 .4257 .55567 .41936 .53883 Mtetra
.484 .471 .768 r
.41936 .53883 .4257 .55567 .43687 .56008 .43053 .54204 Mtetra
.509 .475 .754 r
.43053 .54204 .43687 .56008 .44815 .56373 .44182 .54458 Mtetra
.533 .48 .743 r
.44182 .54458 .44815 .56373 .45955 .56634 .45322 .54621 Mtetra
.557 .488 .733 r
.45322 .54621 .45955 .56634 .47106 .56766 .46472 .54671 Mtetra
.58 .496 .725 r
.46472 .54671 .47106 .56766 .48267 .56748 .47632 .54591 Mtetra
.601 .506 .719 r
.47632 .54591 .48267 .56748 .49437 .56567 .488 .54371 Mtetra
.62 .515 .714 r
.488 .54371 .49437 .56567 .50614 .56218 .49975 .54009 Mtetra
.637 .525 .71 r
.49975 .54009 .50614 .56218 .51797 .55705 .51155 .53507 Mtetra
.652 .535 .708 r
.51155 .53507 .51797 .55705 .52983 .55039 .5234 .52875 Mtetra
.666 .545 .708 r
.5234 .52875 .52983 .55039 .54172 .54238 .53528 .52131 Mtetra
.678 .555 .709 r
.53528 .52131 .54172 .54238 .55362 .53325 .54718 .51294 Mtetra
.688 .566 .711 r
.54718 .51294 .55362 .53325 .56552 .52328 .55908 .50388 Mtetra
.697 .576 .716 r
.55908 .50388 .56552 .52328 .57742 .51274 .571 .49435 Mtetra
.705 .587 .721 r
.571 .49435 .57742 .51274 .58931 .5019 .58292 .48459 Mtetra
.711 .598 .729 r
.58292 .48459 .58931 .5019 .60121 .49103 .59485 .47482 Mtetra
.716 .61 .738 r
.59485 .47482 .60121 .49103 .6131 .48033 .60679 .46522 Mtetra
.719 .622 .748 r
.60679 .46522 .6131 .48033 .62502 .47 .61875 .45592 Mtetra
.721 .634 .76 r
.61875 .45592 .62502 .47 .63695 .46014 .63073 .44704 Mtetra
.721 .646 .773 r
.63073 .44704 .63695 .46014 .64891 .45086 .64275 .43865 Mtetra
.72 .658 .787 r
.64275 .43865 .64891 .45086 .66091 .4422 .65481 .43077 Mtetra
.718 .669 .801 r
.65481 .43077 .66091 .4422 .67296 .43416 .66691 .42341 Mtetra
.714 .68 .815 r
.66691 .42341 .67296 .43416 .68505 .42671 .67906 .41654 Mtetra
.71 .689 .828 r
.67906 .41654 .68505 .42671 .69721 .41982 .69127 .41013 Mtetra
.705 .698 .841 r
.69127 .41013 .69721 .41982 .70942 .41341 .70354 .4041 Mtetra
.7 .705 .851 r
.70354 .4041 .70942 .41341 .72169 .40742 .71587 .39842 Mtetra
.696 .711 .86 r
.71587 .39842 .72169 .40742 .73402 .40177 .72825 .393 Mtetra
.691 .716 .868 r
.72825 .393 .73402 .40177 .74642 .39639 .74069 .38779 Mtetra
.688 .72 .874 r
.74069 .38779 .74642 .39639 .75887 .39121 .7532 .38274 Mtetra
.686 .723 .878 r
.7532 .38274 .75887 .39121 .77139 .38617 .76575 .37779 Mtetra
.684 .725 .881 r
.76575 .37779 .77139 .38617 .78395 .38123 .77837 .3729 Mtetra
.683 .728 .884 r
.77837 .3729 .78395 .38123 .79658 .37634 .79103 .36805 Mtetra
.682 .729 .886 r
.79103 .36805 .79658 .37634 .80925 .37147 .80375 .3632 Mtetra
.682 .731 .887 r
.80375 .3632 .80925 .37147 .82198 .3666 .81652 .35834 Mtetra
.683 .732 .888 r
.81652 .35834 .82198 .3666 .83476 .36171 .82934 .35346 Mtetra
.683 .733 .888 r
.82934 .35346 .83476 .36171 .84758 .3568 .84221 .34854 Mtetra
.684 .734 .889 r
.84221 .34854 .84758 .3568 .86046 .35185 .85513 .34358 Mtetra
.684 .735 .889 r
.85513 .34358 .86046 .35185 .87338 .34686 .8681 .33859 Mtetra
.685 .736 .89 r
.8681 .33859 .87338 .34686 .88636 .34184 .88111 .33356 Mtetra
.685 .737 .89 r
.88111 .33356 .88636 .34184 .89938 .33679 .89418 .32849 Mtetra
.571 .684 .917 r
.29462 .50932 .30143 .51665 .31193 .51591 .30516 .50821 Mtetra
.552 .666 .913 r
.30516 .50821 .31193 .51591 .32246 .51574 .31573 .50757 Mtetra
.531 .645 .906 r
.31573 .50757 .32246 .51574 .33301 .51618 .32633 .50746 Mtetra
.511 .622 .897 r
.32633 .50746 .33301 .51618 .3436 .51727 .33696 .5079 Mtetra
.493 .597 .886 r
.33696 .5079 .3436 .51727 .35423 .51903 .34764 .50889 Mtetra
.478 .572 .871 r
.34764 .50889 .35423 .51903 .3649 .52141 .35836 .51041 Mtetra
.469 .548 .855 r
.35836 .51041 .3649 .52141 .37563 .52436 .36913 .51239 Mtetra
.467 .528 .837 r
.36913 .51239 .37563 .52436 .38643 .52776 .37997 .51473 Mtetra
.47 .512 .82 r
.37997 .51473 .38643 .52776 .39731 .53144 .39089 .5173 Mtetra
.48 .501 .802 r
.39089 .5173 .39731 .53144 .40829 .53521 .40189 .51993 Mtetra
.493 .494 .786 r
.40189 .51993 .40829 .53521 .41936 .53883 .41299 .5224 Mtetra
.511 .491 .772 r
.41299 .5224 .41936 .53883 .43053 .54204 .42418 .5245 Mtetra
.53 .492 .759 r
.42418 .5245 .43053 .54204 .44182 .54458 .43548 .52603 Mtetra
.549 .495 .747 r
.43548 .52603 .44182 .54458 .45322 .54621 .44687 .52676 Mtetra
.569 .5 .738 r
.44687 .52676 .45322 .54621 .46472 .54671 .45837 .52653 Mtetra
.588 .507 .73 r
.45837 .52653 .46472 .54671 .47632 .54591 .46995 .52519 Mtetra
.606 .514 .724 r
.46995 .52519 .47632 .54591 .488 .54371 .48162 .52268 Mtetra
.622 .522 .72 r
.48162 .52268 .488 .54371 .49975 .54009 .49335 .51897 Mtetra
.637 .531 .717 r
.49335 .51897 .49975 .54009 .51155 .53507 .50514 .51409 Mtetra
.651 .54 .715 r
.50514 .51409 .51155 .53507 .5234 .52875 .51698 .50814 Mtetra
.663 .549 .715 r
.51698 .50814 .5234 .52875 .53528 .52131 .52885 .50126 Mtetra
.674 .559 .717 r
.52885 .50126 .53528 .52131 .54718 .51294 .54074 .49362 Mtetra
.683 .569 .72 r
.54074 .49362 .54718 .51294 .55908 .50388 .55266 .48541 Mtetra
.692 .58 .725 r
.55266 .48541 .55908 .50388 .571 .49435 .56458 .47684 Mtetra
.698 .59 .731 r
.56458 .47684 .571 .49435 .58292 .48459 .57653 .46809 Mtetra
.704 .602 .739 r
.57653 .46809 .58292 .48459 .59485 .47482 .58849 .45934 Mtetra
.708 .613 .749 r
.58849 .45934 .59485 .47482 .60679 .46522 .60046 .45074 Mtetra
.711 .625 .76 r
.60046 .45074 .60679 .46522 .61875 .45592 .61247 .4424 Mtetra
.713 .637 .771 r
.61247 .4424 .61875 .45592 .63073 .44704 .6245 .4344 Mtetra
.713 .649 .784 r
.6245 .4344 .63073 .44704 .64275 .43865 .63657 .42681 Mtetra
.712 .661 .798 r
.63657 .42681 .64275 .43865 .65481 .43077 .64868 .41964 Mtetra
.71 .672 .811 r
.64868 .41964 .65481 .43077 .66691 .42341 .66084 .41289 Mtetra
.706 .682 .824 r
.66084 .41289 .66691 .42341 .67906 .41654 .67305 .40654 Mtetra
.702 .691 .836 r
.67305 .40654 .67906 .41654 .69127 .41013 .68531 .40054 Mtetra
.698 .699 .847 r
.68531 .40054 .69127 .41013 .70354 .4041 .69763 .39486 Mtetra
.694 .706 .856 r
.69763 .39486 .70354 .4041 .71587 .39842 .71001 .38944 Mtetra
.69 .711 .864 r
.71001 .38944 .71587 .39842 .72825 .393 .72244 .38422 Mtetra
.687 .716 .871 r
.72244 .38422 .72825 .393 .74069 .38779 .73493 .37917 Mtetra
.685 .719 .876 r
.73493 .37917 .74069 .38779 .7532 .38274 .74748 .37422 Mtetra
.683 .722 .88 r
.74748 .37422 .7532 .38274 .76575 .37779 .76008 .36935 Mtetra
.682 .725 .882 r
.76008 .36935 .76575 .37779 .77837 .3729 .77273 .36451 Mtetra
.681 .727 .884 r
.77273 .36451 .77837 .3729 .79103 .36805 .78544 .35969 Mtetra
.681 .728 .886 r
.78544 .35969 .79103 .36805 .80375 .3632 .7982 .35486 Mtetra
.681 .73 .887 r
.7982 .35486 .80375 .3632 .81652 .35834 .81101 .35 Mtetra
.682 .731 .888 r
.81101 .35 .81652 .35834 .82934 .35346 .82388 .34512 Mtetra
.682 .732 .888 r
.82388 .34512 .82934 .35346 .84221 .34854 .83679 .34019 Mtetra
.683 .734 .889 r
.83679 .34019 .84221 .34854 .85513 .34358 .84975 .33523 Mtetra
.684 .735 .889 r
.84975 .33523 .85513 .34358 .8681 .33859 .86276 .33023 Mtetra
.684 .736 .89 r
.86276 .33023 .8681 .33859 .88111 .33356 .87583 .32519 Mtetra
.685 .736 .89 r
.87583 .32519 .88111 .33356 .89418 .32849 .88894 .32011 Mtetra
.586 .691 .914 r
.28776 .50199 .29462 .50932 .30516 .50821 .29835 .50053 Mtetra
.57 .675 .91 r
.29835 .50053 .30516 .50821 .31573 .50757 .30896 .49946 Mtetra
.554 .657 .905 r
.30896 .49946 .31573 .50757 .32633 .50746 .3196 .49882 Mtetra
.538 .637 .896 r
.3196 .49882 .32633 .50746 .33696 .5079 .33028 .49864 Mtetra
.523 .615 .885 r
.33028 .49864 .33696 .5079 .34764 .50889 .341 .49891 Mtetra
.511 .593 .872 r
.341 .49891 .34764 .50889 .35836 .51041 .35177 .49962 Mtetra
.504 .572 .857 r
.35177 .49962 .35836 .51041 .36913 .51239 .36259 .5007 Mtetra
.501 .553 .841 r
.36259 .5007 .36913 .51239 .37997 .51473 .37347 .50208 Mtetra
.503 .537 .825 r
.37347 .50208 .37997 .51473 .39089 .5173 .38443 .50362 Mtetra
.509 .525 .808 r
.38443 .50362 .39089 .5173 .40189 .51993 .39546 .5052 Mtetra
.52 .517 .793 r
.39546 .5052 .40189 .51993 .41299 .5224 .40658 .50663 Mtetra
.533 .512 .779 r
.40658 .50663 .41299 .5224 .42418 .5245 .41779 .50774 Mtetra
.548 .51 .766 r
.41779 .50774 .42418 .5245 .43548 .52603 .4291 .50834 Mtetra
.564 .511 .755 r
.4291 .50834 .43548 .52603 .44687 .52676 .4405 .50829 Mtetra
.58 .514 .746 r
.4405 .50829 .44687 .52676 .45837 .52653 .45199 .50741 Mtetra
.596 .519 .738 r
.45199 .50741 .45837 .52653 .46995 .52519 .46357 .50563 Mtetra
.611 .525 .732 r
.46357 .50563 .46995 .52519 .48162 .52268 .47522 .50286 Mtetra
.625 .532 .728 r
.47522 .50286 .48162 .52268 .49335 .51897 .48694 .4991 Mtetra
.638 .539 .726 r
.48694 .4991 .49335 .51897 .50514 .51409 .49872 .49439 Mtetra
.65 .547 .725 r
.49872 .49439 .50514 .51409 .51698 .50814 .51055 .4888 Mtetra
.661 .556 .726 r
.51055 .4888 .51698 .50814 .52885 .50126 .52241 .48245 Mtetra
.671 .566 .728 r
.52241 .48245 .52885 .50126 .54074 .49362 .53431 .47549 Mtetra
.679 .575 .731 r
.53431 .47549 .54074 .49362 .55266 .48541 .54623 .46807 Mtetra
.687 .586 .737 r
.54623 .46807 .55266 .48541 .56458 .47684 .55817 .46036 Mtetra
.693 .596 .744 r
.55817 .46036 .56458 .47684 .57653 .46809 .57014 .45252 Mtetra
.698 .608 .752 r
.57014 .45252 .57653 .46809 .58849 .45934 .58212 .44469 Mtetra
.702 .619 .761 r
.58212 .44469 .58849 .45934 .60046 .45074 .59414 .43698 Mtetra
.704 .631 .772 r
.59414 .43698 .60046 .45074 .61247 .4424 .60618 .42949 Mtetra
.705 .643 .784 r
.60618 .42949 .61247 .4424 .6245 .4344 .61826 .42228 Mtetra
.705 .654 .796 r
.61826 .42228 .6245 .4344 .63657 .42681 .63038 .41539 Mtetra
.704 .665 .809 r
.63038 .41539 .63657 .42681 .64868 .41964 .64254 .40884 Mtetra
.702 .676 .821 r
.64254 .40884 .64868 .41964 .66084 .41289 .65475 .40262 Mtetra
.699 .685 .833 r
.65475 .40262 .66084 .41289 .67305 .40654 .667 .39672 Mtetra
.696 .694 .844 r
.667 .39672 .67305 .40654 .68531 .40054 .67932 .39109 Mtetra
.692 .701 .853 r
.67932 .39109 .68531 .40054 .69763 .39486 .69168 .3857 Mtetra
.689 .707 .862 r
.69168 .3857 .69763 .39486 .71001 .38944 .70411 .3805 Mtetra
.686 .712 .868 r
.70411 .3805 .71001 .38944 .72244 .38422 .71659 .37546 Mtetra
.683 .716 .874 r
.71659 .37546 .72244 .38422 .73493 .37917 .72912 .37053 Mtetra
.682 .72 .878 r
.72912 .37053 .73493 .37917 .74748 .37422 .74171 .36567 Mtetra
.68 .722 .881 r
.74171 .36567 .74748 .37422 .76008 .36935 .75436 .36086 Mtetra
.68 .725 .883 r
.75436 .36086 .76008 .36935 .77273 .36451 .76706 .35606 Mtetra
.68 .726 .885 r
.76706 .35606 .77273 .36451 .78544 .35969 .77981 .35126 Mtetra
.68 .728 .886 r
.77981 .35126 .78544 .35969 .7982 .35486 .79261 .34644 Mtetra
.68 .729 .887 r
.79261 .34644 .7982 .35486 .81101 .35 .80547 .34159 Mtetra
.681 .731 .888 r
.80547 .34159 .81101 .35 .82388 .34512 .81837 .3367 Mtetra
.681 .732 .888 r
.81837 .3367 .82388 .34512 .83679 .34019 .83133 .33177 Mtetra
.682 .733 .889 r
.83133 .33177 .83679 .34019 .84975 .33523 .84433 .3268 Mtetra
.683 .734 .889 r
.84433 .3268 .84975 .33523 .86276 .33023 .85739 .32179 Mtetra
.683 .735 .89 r
.85739 .32179 .86276 .33023 .87583 .32519 .87049 .31674 Mtetra
.684 .736 .89 r
.87049 .31674 .87583 .32519 .88894 .32011 .88365 .31166 Mtetra
.599 .697 .912 r
.28085 .49468 .28776 .50199 .29835 .50053 .29148 .49289 Mtetra
.586 .684 .909 r
.29148 .49289 .29835 .50053 .30896 .49946 .30213 .49143 Mtetra
.573 .669 .903 r
.30213 .49143 .30896 .49946 .3196 .49882 .31282 .49031 Mtetra
.56 .651 .896 r
.31282 .49031 .3196 .49882 .33028 .49864 .32355 .48956 Mtetra
.548 .632 .886 r
.32355 .48956 .33028 .49864 .341 .49891 .33431 .48918 Mtetra
.539 .613 .875 r
.33431 .48918 .341 .49891 .35177 .49962 .34513 .48915 Mtetra
.532 .594 .861 r
.34513 .48915 .35177 .49962 .36259 .5007 .35599 .48942 Mtetra
.529 .576 .846 r
.35599 .48942 .36259 .5007 .37347 .50208 .36692 .48992 Mtetra
.53 .561 .831 r
.36692 .48992 .37347 .50208 .38443 .50362 .37791 .49055 Mtetra
.534 .548 .816 r
.37791 .49055 .38443 .50362 .39546 .5052 .38898 .49118 Mtetra
.542 .539 .801 r
.38898 .49118 .39546 .5052 .40658 .50663 .40013 .49169 Mtetra
.552 .533 .788 r
.40013 .49169 .40658 .50663 .41779 .50774 .41136 .49192 Mtetra
.564 .53 .776 r
.41136 .49192 .41779 .50774 .4291 .50834 .42268 .49172 Mtetra
.577 .529 .765 r
.42268 .49172 .4291 .50834 .4405 .50829 .43409 .49098 Mtetra
.59 .53 .756 r
.43409 .49098 .4405 .50829 .45199 .50741 .44558 .48956 Mtetra
.603 .533 .749 r
.44558 .48956 .45199 .50741 .46357 .50563 .45716 .48739 Mtetra
.616 .538 .744 r
.45716 .48739 .46357 .50563 .47522 .50286 .4688 .48442 Mtetra
.628 .544 .74 r
.4688 .48442 .47522 .50286 .48694 .4991 .48051 .48065 Mtetra
.64 .55 .738 r
.48051 .48065 .48694 .4991 .49872 .49439 .49228 .4761 Mtetra
.65 .558 .737 r
.49228 .4761 .49872 .49439 .51055 .4888 .5041 .47085 Mtetra
.66 .566 .738 r
.5041 .47085 .51055 .4888 .52241 .48245 .51597 .46499 Mtetra
.669 .575 .741 r
.51597 .46499 .52241 .48245 .53431 .47549 .52786 .45864 Mtetra
.676 .584 .745 r
.52786 .45864 .53431 .47549 .54623 .46807 .53979 .45193 Mtetra
.683 .594 .751 r
.53979 .45193 .54623 .46807 .55817 .46036 .55175 .44499 Mtetra
.688 .605 .758 r
.55175 .44499 .55817 .46036 .57014 .45252 .56374 .43795 Mtetra
.692 .616 .766 r
.56374 .43795 .57014 .45252 .58212 .44469 .57575 .43092 Mtetra
.696 .627 .776 r
.57575 .43092 .58212 .44469 .59414 .43698 .5878 .42398 Mtetra
.697 .638 .786 r
.5878 .42398 .59414 .43698 .60618 .42949 .59988 .41723 Mtetra
.698 .65 .798 r
.59988 .41723 .60618 .42949 .61826 .42228 .612 .41069 Mtetra
.698 .66 .809 r
.612 .41069 .61826 .42228 .63038 .41539 .62416 .40441 Mtetra
.697 .671 .821 r
.62416 .40441 .63038 .41539 .64254 .40884 .63637 .39839 Mtetra
.695 .68 .832 r
.63637 .39839 .64254 .40884 .65475 .40262 .64863 .39262 Mtetra
.692 .689 .842 r
.64863 .39262 .65475 .40262 .667 .39672 .66093 .38709 Mtetra
.689 .697 .852 r
.66093 .38709 .667 .39672 .67932 .39109 .67329 .38177 Mtetra
.687 .703 .86 r
.67329 .38177 .67932 .39109 .69168 .3857 .68571 .37662 Mtetra
.684 .709 .867 r
.68571 .37662 .69168 .3857 .70411 .3805 .69818 .37161 Mtetra
.682 .713 .872 r
.69818 .37161 .70411 .3805 .71659 .37546 .7107 .36671 Mtetra
.68 .717 .877 r
.7107 .36671 .71659 .37546 .72912 .37053 .72328 .36188 Mtetra
.679 .72 .88 r
.72328 .36188 .72912 .37053 .74171 .36567 .73591 .3571 Mtetra
.678 .722 .883 r
.73591 .3571 .74171 .36567 .75436 .36086 .7486 .35233 Mtetra
.678 .724 .885 r
.7486 .35233 .75436 .36086 .76706 .35606 .76134 .34756 Mtetra
.678 .726 .886 r
.76134 .34756 .76706 .35606 .77981 .35126 .77413 .34277 Mtetra
.679 .728 .887 r
.77413 .34277 .77981 .35126 .79261 .34644 .78698 .33796 Mtetra
.679 .729 .888 r
.78698 .33796 .79261 .34644 .80547 .34159 .79987 .3331 Mtetra
.68 .73 .888 r
.79987 .3331 .80547 .34159 .81837 .3367 .81282 .32821 Mtetra
.681 .731 .889 r
.81282 .32821 .81837 .3367 .83133 .33177 .82582 .32327 Mtetra
.681 .732 .889 r
.82582 .32327 .83133 .33177 .84433 .3268 .83887 .31829 Mtetra
.682 .733 .889 r
.83887 .31829 .84433 .3268 .85739 .32179 .85197 .31327 Mtetra
.683 .734 .89 r
.85197 .31327 .85739 .32179 .87049 .31674 .86512 .30822 Mtetra
.683 .735 .89 r
.86512 .30822 .87049 .31674 .88365 .31166 .87832 .30312 Mtetra
.609 .704 .911 r
.27389 .48742 .28085 .49468 .29148 .49289 .28455 .48533 Mtetra
.6 .693 .908 r
.28455 .48533 .29148 .49289 .30213 .49143 .29525 .4835 Mtetra
.589 .679 .903 r
.29525 .4835 .30213 .49143 .31282 .49031 .30598 .48196 Mtetra
.579 .664 .897 r
.30598 .48196 .31282 .49031 .32355 .48956 .31675 .48071 Mtetra
.57 .648 .888 r
.31675 .48071 .32355 .48956 .33431 .48918 .32756 .47975 Mtetra
.562 .631 .878 r
.32756 .47975 .33431 .48918 .34513 .48915 .33842 .47906 Mtetra
.556 .614 .866 r
.33842 .47906 .34513 .48915 .35599 .48942 .34933 .47861 Mtetra
.553 .598 .853 r
.34933 .47861 .35599 .48942 .36692 .48992 .3603 .47834 Mtetra
.553 .584 .839 r
.3603 .47834 .36692 .48992 .37791 .49055 .37134 .47815 Mtetra
.556 .572 .825 r
.37134 .47815 .37791 .49055 .38898 .49118 .38244 .47797 Mtetra
.561 .562 .811 r
.38244 .47797 .38898 .49118 .40013 .49169 .39362 .47767 Mtetra
.569 .555 .799 r
.39362 .47767 .40013 .49169 .41136 .49192 .40488 .47714 Mtetra
.578 .55 .787 r
.40488 .47714 .41136 .49192 .42268 .49172 .41621 .47626 Mtetra
.588 .548 .777 r
.41621 .47626 .42268 .49172 .43409 .49098 .42763 .47493 Mtetra
.599 .548 .769 r
.42763 .47493 .43409 .49098 .44558 .48956 .43913 .47306 Mtetra
.61 .55 .762 r
.43913 .47306 .44558 .48956 .45716 .48739 .4507 .47057 Mtetra
.621 .554 .757 r
.4507 .47057 .45716 .48739 .4688 .48442 .46235 .46745 Mtetra
.632 .558 .754 r
.46235 .46745 .4688 .48442 .48051 .48065 .47406 .46368 Mtetra
.642 .564 .752 r
.47406 .46368 .48051 .48065 .49228 .4761 .48582 .45929 Mtetra
.651 .571 .752 r
.48582 .45929 .49228 .4761 .5041 .47085 .49764 .45434 Mtetra
.659 .578 .753 r
.49764 .45434 .5041 .47085 .51597 .46499 .50951 .44891 Mtetra
.667 .587 .756 r
.50951 .44891 .51597 .46499 .52786 .45864 .52141 .4431 Mtetra
.673 .596 .76 r
.52141 .4431 .52786 .45864 .53979 .45193 .53335 .437 Mtetra
.679 .605 .766 r
.53335 .437 .53979 .45193 .55175 .44499 .54532 .43072 Mtetra
.684 .615 .773 r
.54532 .43072 .55175 .44499 .56374 .43795 .55733 .42437 Mtetra
.687 .626 .782 r
.55733 .42437 .56374 .43795 .57575 .43092 .56937 .41801 Mtetra
.69 .637 .791 r
.56937 .41801 .57575 .43092 .5878 .42398 .58145 .41174 Mtetra
.691 .647 .801 r
.58145 .41174 .5878 .42398 .59988 .41723 .59357 .4056 Mtetra
.692 .658 .812 r
.59357 .4056 .59988 .41723 .612 .41069 .60573 .39963 Mtetra
.692 .668 .822 r
.60573 .39963 .612 .41069 .62416 .40441 .61793 .39386 Mtetra
.69 .677 .832 r
.61793 .39386 .62416 .40441 .63637 .39839 .63018 .38827 Mtetra
.689 .686 .842 r
.63018 .38827 .63637 .39839 .64863 .39262 .64248 .38288 Mtetra
.686 .694 .851 r
.64248 .38288 .64863 .39262 .66093 .38709 .65483 .37766 Mtetra
.684 .7 .859 r
.65483 .37766 .66093 .38709 .67329 .38177 .66723 .37258 Mtetra
.682 .706 .866 r
.66723 .37258 .67329 .38177 .68571 .37662 .67969 .36763 Mtetra
.68 .711 .871 r
.67969 .36763 .68571 .37662 .69818 .37161 .6922 .36277 Mtetra
.679 .715 .876 r
.6922 .36277 .69818 .37161 .7107 .36671 .70477 .35798 Mtetra
.678 .718 .879 r
.70477 .35798 .7107 .36671 .72328 .36188 .71739 .35323 Mtetra
.677 .721 .882 r
.71739 .35323 .72328 .36188 .73591 .3571 .73007 .34849 Mtetra
.677 .723 .884 r
.73007 .34849 .73591 .3571 .7486 .35233 .7428 .34376 Mtetra
.677 .725 .886 r
.7428 .34376 .7486 .35233 .76134 .34756 .75558 .33901 Mtetra
.677 .726 .887 r
.75558 .33901 .76134 .34756 .77413 .34277 .76841 .33423 Mtetra
.678 .728 .887 r
.76841 .33423 .77413 .34277 .78698 .33796 .7813 .32941 Mtetra
.678 .729 .888 r
.7813 .32941 .78698 .33796 .79987 .3331 .79424 .32455 Mtetra
.679 .73 .888 r
.79424 .32455 .79987 .3331 .81282 .32821 .80723 .31965 Mtetra
.68 .731 .889 r
.80723 .31965 .81282 .32821 .82582 .32327 .82027 .31471 Mtetra
.681 .732 .889 r
.82027 .31471 .82582 .32327 .83887 .31829 .83336 .30972 Mtetra
.681 .733 .89 r
.83336 .30972 .83887 .31829 .85197 .31327 .8465 .30469 Mtetra
.682 .734 .89 r
.8465 .30469 .85197 .31327 .86512 .30822 .8597 .29962 Mtetra
.682 .735 .89 r
.8597 .29962 .86512 .30822 .87832 .30312 .87295 .29452 Mtetra
.618 .71 .911 r
.26687 .48019 .27389 .48742 .28455 .48533 .27757 .47785 Mtetra
.611 .7 .908 r
.27757 .47785 .28455 .48533 .29525 .4835 .2883 .47571 Mtetra
.603 .689 .903 r
.2883 .47571 .29525 .4835 .30598 .48196 .29908 .47378 Mtetra
.595 .677 .898 r
.29908 .47378 .30598 .48196 .31675 .48071 .30989 .47209 Mtetra
.587 .663 .89 r
.30989 .47209 .31675 .48071 .32756 .47975 .32075 .47063 Mtetra
.581 .648 .882 r
.32075 .47063 .32756 .47975 .33842 .47906 .33165 .46937 Mtetra
.576 .633 .871 r
.33165 .46937 .33842 .47906 .34933 .47861 .34261 .4683 Mtetra
.573 .619 .86 r
.34261 .4683 .34933 .47861 .3603 .47834 .35362 .46736 Mtetra
.573 .606 .848 r
.35362 .46736 .3603 .47834 .37134 .47815 .3647 .46648 Mtetra
.574 .594 .835 r
.3647 .46648 .37134 .47815 .38244 .47797 .37583 .4656 Mtetra
.578 .585 .823 r
.37583 .4656 .38244 .47797 .39362 .47767 .38704 .46461 Mtetra
.584 .577 .811 r
.38704 .46461 .39362 .47767 .40488 .47714 .39833 .46344 Mtetra
.591 .572 .801 r
.39833 .46344 .40488 .47714 .41621 .47626 .40969 .46198 Mtetra
.599 .569 .791 r
.40969 .46198 .41621 .47626 .42763 .47493 .42112 .46016 Mtetra
.608 .568 .784 r
.42112 .46016 .42763 .47493 .43913 .47306 .43263 .4579 Mtetra
.617 .569 .777 r
.43263 .4579 .43913 .47306 .4507 .47057 .44421 .45516 Mtetra
.626 .571 .773 r
.44421 .45516 .4507 .47057 .46235 .46745 .45585 .45191 Mtetra
.635 .575 .769 r
.45585 .45191 .46235 .46745 .47406 .46368 .46756 .44816 Mtetra
.644 .58 .768 r
.46756 .44816 .47406 .46368 .48582 .45929 .47933 .44391 Mtetra
.652 .586 .768 r
.47933 .44391 .48582 .45929 .49764 .45434 .49115 .43923 Mtetra
.659 .593 .77 r
.49115 .43923 .49764 .45434 .50951 .44891 .50302 .43417 Mtetra
.666 .601 .773 r
.50302 .43417 .50951 .44891 .52141 .4431 .51493 .42881 Mtetra
.671 .609 .777 r
.51493 .42881 .52141 .4431 .53335 .437 .52688 .42323 Mtetra
.676 .618 .783 r
.52688 .42323 .53335 .437 .54532 .43072 .53887 .41751 Mtetra
.68 .628 .79 r
.53887 .41751 .54532 .43072 .55733 .42437 .5509 .41172 Mtetra
.683 .637 .798 r
.5509 .41172 .55733 .42437 .56937 .41801 .56297 .40594 Mtetra
.685 .647 .807 r
.56297 .40594 .56937 .41801 .58145 .41174 .57508 .40021 Mtetra
.686 .657 .816 r
.57508 .40021 .58145 .41174 .59357 .4056 .58723 .39458 Mtetra
.686 .667 .825 r
.58723 .39458 .59357 .4056 .60573 .39963 .59943 .38907 Mtetra
.686 .676 .835 r
.59943 .38907 .60573 .39963 .61793 .39386 .61167 .3837 Mtetra
.685 .684 .844 r
.61167 .3837 .61793 .39386 .63018 .38827 .62396 .37847 Mtetra
.683 .692 .852 r
.62396 .37847 .63018 .38827 .64248 .38288 .6363 .37337 Mtetra
.681 .698 .859 r
.6363 .37337 .64248 .38288 .65483 .37766 .64869 .36839 Mtetra
.68 .704 .866 r
.64869 .36839 .65483 .37766 .66723 .37258 .66114 .36352 Mtetra
.678 .709 .871 r
.66114 .36352 .66723 .37258 .67969 .36763 .67364 .35872 Mtetra
.677 .713 .876 r
.67364 .35872 .67969 .36763 .6922 .36277 .6862 .35397 Mtetra
.676 .716 .879 r
.6862 .35397 .6922 .36277 .70477 .35798 .6988 .34926 Mtetra
.675 .719 .882 r
.6988 .34926 .70477 .35798 .71739 .35323 .71147 .34456 Mtetra
.675 .721 .884 r
.71147 .34456 .71739 .35323 .73007 .34849 .72418 .33987 Mtetra
.675 .723 .886 r
.72418 .33987 .73007 .34849 .7428 .34376 .73695 .33515 Mtetra
.676 .725 .887 r
.73695 .33515 .7428 .34376 .75558 .33901 .74977 .33041 Mtetra
.676 .726 .887 r
.74977 .33041 .75558 .33901 .76841 .33423 .76265 .32563 Mtetra
.677 .728 .888 r
.76265 .32563 .76841 .33423 .7813 .32941 .77558 .32081 Mtetra
.678 .729 .888 r
.77558 .32081 .7813 .32941 .79424 .32455 .78856 .31594 Mtetra
.679 .73 .889 r
.78856 .31594 .79424 .32455 .80723 .31965 .80159 .31103 Mtetra
.679 .731 .889 r
.80159 .31103 .80723 .31965 .82027 .31471 .81467 .30607 Mtetra
.68 .732 .889 r
.81467 .30607 .82027 .31471 .83336 .30972 .82781 .30107 Mtetra
.681 .733 .89 r
.82781 .30107 .83336 .30972 .8465 .30469 .84099 .29603 Mtetra
.681 .734 .89 r
.84099 .29603 .8465 .30469 .8597 .29962 .85424 .29096 Mtetra
.681 .735 .891 r
.85424 .29096 .8597 .29962 .87295 .29452 .86753 .28584 Mtetra
.626 .715 .91 r
.25978 .47302 .26687 .48019 .27757 .47785 .27052 .47045 Mtetra
.62 .707 .908 r
.27052 .47045 .27757 .47785 .2883 .47571 .2813 .46803 Mtetra
.614 .698 .904 r
.2813 .46803 .2883 .47571 .29908 .47378 .29211 .46579 Mtetra
.607 .688 .899 r
.29211 .46579 .29908 .47378 .30989 .47209 .30297 .46372 Mtetra
.602 .676 .893 r
.30297 .46372 .30989 .47209 .32075 .47063 .31387 .46182 Mtetra
.596 .664 .886 r
.31387 .46182 .32075 .47063 .33165 .46937 .32482 .46009 Mtetra
.592 .651 .877 r
.32482 .46009 .33165 .46937 .34261 .4683 .33582 .45848 Mtetra
.59 .638 .867 r
.33582 .45848 .34261 .4683 .35362 .46736 .34687 .45698 Mtetra
.589 .627 .857 r
.34687 .45698 .35362 .46736 .3647 .46648 .35798 .45552 Mtetra
.59 .616 .846 r
.35798 .45552 .3647 .46648 .37583 .4656 .36916 .45405 Mtetra
.593 .607 .835 r
.36916 .45405 .37583 .4656 .38704 .46461 .3804 .45249 Mtetra
.597 .599 .825 r
.3804 .45249 .38704 .46461 .39833 .46344 .39171 .45077 Mtetra
.603 .594 .815 r
.39171 .45077 .39833 .46344 .40969 .46198 .40309 .44884 Mtetra
.609 .59 .807 r
.40309 .44884 .40969 .46198 .42112 .46016 .41454 .44661 Mtetra
.616 .589 .799 r
.41454 .44661 .42112 .46016 .43263 .4579 .42606 .44404 Mtetra
.624 .589 .794 r
.42606 .44404 .43263 .4579 .44421 .45516 .43765 .44109 Mtetra
.631 .59 .789 r
.43765 .44109 .44421 .45516 .45585 .45191 .44931 .43775 Mtetra
.639 .593 .787 r
.44931 .43775 .45585 .45191 .46756 .44816 .46102 .43401 Mtetra
.646 .597 .785 r
.46102 .43401 .46756 .44816 .47933 .44391 .4728 .42989 Mtetra
.653 .603 .786 r
.4728 .42989 .47933 .44391 .49115 .43923 .48462 .42543 Mtetra
.659 .609 .787 r
.48462 .42543 .49115 .43923 .50302 .43417 .4965 .42068 Mtetra
.664 .616 .791 r
.4965 .42068 .50302 .43417 .51493 .42881 .50842 .41569 Mtetra
.669 .624 .795 r
.50842 .41569 .51493 .42881 .52688 .42323 .52039 .41053 Mtetra
.673 .632 .8 r
.52039 .41053 .52688 .42323 .53887 .41751 .5324 .40526 Mtetra
.676 .641 .807 r
.5324 .40526 .53887 .41751 .5509 .41172 .54445 .39994 Mtetra
.679 .65 .814 r
.54445 .39994 .5509 .41172 .56297 .40594 .55655 .39461 Mtetra
.68 .659 .822 r
.55655 .39461 .56297 .40594 .57508 .40021 .56868 .38931 Mtetra
.681 .668 .83 r
.56868 .38931 .57508 .40021 .58723 .39458 .58087 .38409 Mtetra
.681 .676 .839 r
.58087 .38409 .58723 .39458 .59943 .38907 .5931 .37895 Mtetra
.68 .684 .846 r
.5931 .37895 .59943 .38907 .61167 .3837 .60538 .3739 Mtetra
.679 .691 .854 r
.60538 .3739 .61167 .3837 .62396 .37847 .61771 .36894 Mtetra
.678 .697 .861 r
.61771 .36894 .62396 .37847 .6363 .37337 .63009 .36408 Mtetra
.677 .703 .867 r
.63009 .36408 .6363 .37337 .64869 .36839 .64252 .35929 Mtetra
.676 .708 .872 r
.64252 .35929 .64869 .36839 .66114 .36352 .65501 .35455 Mtetra
.675 .712 .876 r
.65501 .35455 .66114 .36352 .67364 .35872 .66755 .34987 Mtetra
.674 .715 .879 r
.66755 .34987 .67364 .35872 .6862 .35397 .68015 .3452 Mtetra
.674 .718 .882 r
.68015 .3452 .6862 .35397 .6988 .34926 .69279 .34055 Mtetra
.674 .72 .884 r
.69279 .34055 .6988 .34926 .71147 .34456 .7055 .33589 Mtetra
.674 .722 .886 r
.7055 .33589 .71147 .34456 .72418 .33987 .71825 .33121 Mtetra
.674 .724 .887 r
.71825 .33121 .72418 .33987 .73695 .33515 .73106 .32651 Mtetra
.675 .725 .888 r
.73106 .32651 .73695 .33515 .74977 .33041 .74393 .32176 Mtetra
.676 .727 .888 r
.74393 .32176 .74977 .33041 .76265 .32563 .75684 .31698 Mtetra
.676 .728 .889 r
.75684 .31698 .76265 .32563 .77558 .32081 .76981 .31215 Mtetra
.677 .729 .889 r
.76981 .31215 .77558 .32081 .78856 .31594 .78283 .30727 Mtetra
.678 .73 .889 r
.78283 .30727 .78856 .31594 .80159 .31103 .7959 .30235 Mtetra
.679 .731 .89 r
.7959 .30235 .80159 .31103 .81467 .30607 .80903 .29738 Mtetra
.679 .732 .89 r
.80903 .29738 .81467 .30607 .82781 .30107 .82221 .29237 Mtetra
.68 .733 .89 r
.82221 .29237 .82781 .30107 .84099 .29603 .83544 .28731 Mtetra
.68 .734 .891 r
.83544 .28731 .84099 .29603 .85424 .29096 .84873 .28223 Mtetra
.681 .734 .891 r
.84873 .28223 .85424 .29096 .86753 .28584 .86207 .2771 Mtetra
.632 .719 .91 r
.25264 .46589 .25978 .47302 .27052 .47045 .26342 .46312 Mtetra
.627 .713 .908 r
.26342 .46312 .27052 .47045 .2813 .46803 .27423 .46048 Mtetra
.623 .706 .905 r
.27423 .46048 .2813 .46803 .29211 .46579 .28508 .45796 Mtetra
.618 .697 .901 r
.28508 .45796 .29211 .46579 .30297 .46372 .29598 .45557 Mtetra
.613 .688 .896 r
.29598 .45557 .30297 .46372 .31387 .46182 .30692 .45331 Mtetra
.609 .678 .89 r
.30692 .45331 .31387 .46182 .32482 .46009 .31791 .45117 Mtetra
.606 .667 .883 r
.31791 .45117 .32482 .46009 .33582 .45848 .32895 .44913 Mtetra
.604 .656 .874 r
.32895 .44913 .33582 .45848 .34687 .45698 .34005 .44716 Mtetra
.603 .646 .865 r
.34005 .44716 .34687 .45698 .35798 .45552 .3512 .44522 Mtetra
.604 .636 .856 r
.3512 .44522 .35798 .45552 .36916 .45405 .36241 .44326 Mtetra
.606 .628 .847 r
.36241 .44326 .36916 .45405 .3804 .45249 .37368 .44123 Mtetra
.609 .621 .838 r
.37368 .44123 .3804 .45249 .39171 .45077 .38502 .43907 Mtetra
.613 .616 .83 r
.38502 .43907 .39171 .45077 .40309 .44884 .39643 .43674 Mtetra
.618 .612 .822 r
.39643 .43674 .40309 .44884 .41454 .44661 .4079 .43418 Mtetra
.624 .61 .816 r
.4079 .43418 .41454 .44661 .42606 .44404 .41944 .43136 Mtetra
.63 .609 .811 r
.41944 .43136 .42606 .44404 .43765 .44109 .43104 .42824 Mtetra
.636 .61 .807 r
.43104 .42824 .43765 .44109 .44931 .43775 .44271 .42482 Mtetra
.642 .612 .805 r
.44271 .42482 .44931 .43775 .46102 .43401 .45443 .42109 Mtetra
.648 .616 .804 r
.45443 .42109 .46102 .43401 .4728 .42989 .46621 .41707 Mtetra
.654 .62 .804 r
.46621 .41707 .4728 .42989 .48462 .42543 .47805 .41279 Mtetra
.659 .626 .806 r
.47805 .41279 .48462 .42543 .4965 .42068 .48994 .40829 Mtetra
.663 .632 .809 r
.48994 .40829 .4965 .42068 .50842 .41569 .50188 .4036 Mtetra
.667 .639 .813 r
.50188 .4036 .50842 .41569 .52039 .41053 .51386 .39878 Mtetra
.67 .647 .818 r
.51386 .39878 .52039 .41053 .5324 .40526 .52589 .39386 Mtetra
.673 .654 .824 r
.52589 .39386 .5324 .40526 .54445 .39994 .53797 .3889 Mtetra
.675 .662 .83 r
.53797 .3889 .54445 .39994 .55655 .39461 .55009 .38393 Mtetra
.676 .67 .837 r
.55009 .38393 .55655 .39461 .56868 .38931 .56226 .37898 Mtetra
.676 .678 .844 r
.56226 .37898 .56868 .38931 .58087 .38409 .57447 .37406 Mtetra
.676 .685 .851 r
.57447 .37406 .58087 .38409 .5931 .37895 .58674 .3692 Mtetra
.676 .692 .857 r
.58674 .3692 .5931 .37895 .60538 .3739 .59906 .3644 Mtetra
.675 .697 .863 r
.59906 .3644 .60538 .3739 .61771 .36894 .61142 .35965 Mtetra
.674 .703 .868 r
.61142 .35965 .61771 .36894 .63009 .36408 .62384 .35496 Mtetra
.674 .707 .873 r
.62384 .35496 .63009 .36408 .64252 .35929 .63631 .3503 Mtetra
.673 .711 .877 r
.63631 .3503 .64252 .35929 .65501 .35455 .64884 .34567 Mtetra
.672 .715 .88 r
.64884 .34567 .65501 .35455 .66755 .34987 .66142 .34106 Mtetra
.672 .717 .883 r
.66142 .34106 .66755 .34987 .68015 .3452 .67405 .33646 Mtetra
.672 .72 .885 r
.67405 .33646 .68015 .3452 .69279 .34055 .68674 .33184 Mtetra
.672 .722 .886 r
.68674 .33184 .69279 .34055 .7055 .33589 .69948 .3272 Mtetra
.673 .723 .887 r
.69948 .3272 .7055 .33589 .71825 .33121 .71228 .32253 Mtetra
.673 .725 .888 r
.71228 .32253 .71825 .33121 .73106 .32651 .72513 .31782 Mtetra
.674 .726 .889 r
.72513 .31782 .73106 .32651 .74393 .32176 .73803 .31307 Mtetra
.675 .727 .889 r
.73803 .31307 .74393 .32176 .75684 .31698 .75099 .30828 Mtetra
.676 .728 .889 r
.75099 .30828 .75684 .31698 .76981 .31215 .764 .30344 Mtetra
.676 .729 .889 r
.764 .30344 .76981 .31215 .78283 .30727 .77706 .29855 Mtetra
.677 .73 .89 r
.77706 .29855 .78283 .30727 .7959 .30235 .79018 .29361 Mtetra
.678 .731 .89 r
.79018 .29361 .7959 .30235 .80903 .29738 .80335 .28863 Mtetra
.679 .732 .89 r
.80335 .28863 .80903 .29738 .82221 .29237 .81657 .2836 Mtetra
.679 .733 .891 r
.81657 .2836 .82221 .29237 .83544 .28731 .82985 .27853 Mtetra
.68 .733 .891 r
.82985 .27853 .83544 .28731 .84873 .28223 .84318 .27343 Mtetra
.68 .734 .892 r
.84318 .27343 .84873 .28223 .86207 .2771 .85656 .2683 Mtetra
.637 .723 .91 r
.24544 .45879 .25264 .46589 .26342 .46312 .25625 .45586 Mtetra
.634 .718 .909 r
.25625 .45586 .26342 .46312 .27423 .46048 .2671 .45302 Mtetra
.63 .713 .906 r
.2671 .45302 .27423 .46048 .28508 .45796 .27799 .45028 Mtetra
.626 .706 .903 r
.27799 .45028 .28508 .45796 .29598 .45557 .28893 .44763 Mtetra
.623 .698 .899 r
.28893 .44763 .29598 .45557 .30692 .45331 .29991 .44507 Mtetra
.62 .69 .894 r
.29991 .44507 .30692 .45331 .31791 .45117 .31094 .4426 Mtetra
.617 .681 .888 r
.31094 .4426 .31791 .45117 .32895 .44913 .32202 .4402 Mtetra
.615 .672 .881 r
.32202 .4402 .32895 .44913 .34005 .44716 .33315 .43784 Mtetra
.615 .663 .874 r
.33315 .43784 .34005 .44716 .3512 .44522 .34434 .43551 Mtetra
.615 .655 .866 r
.34434 .43551 .3512 .44522 .36241 .44326 .35558 .43315 Mtetra
.616 .648 .859 r
.35558 .43315 .36241 .44326 .37368 .44123 .36689 .43074 Mtetra
.619 .642 .851 r
.36689 .43074 .37368 .44123 .38502 .43907 .37826 .42823 Mtetra
.622 .636 .844 r
.37826 .42823 .38502 .43907 .39643 .43674 .38969 .42558 Mtetra
.626 .633 .837 r
.38969 .42558 .39643 .43674 .4079 .43418 .40118 .42275 Mtetra
.63 .63 .832 r
.40118 .42275 .4079 .43418 .41944 .43136 .41274 .41972 Mtetra
.635 .63 .828 r
.41274 .41972 .41944 .43136 .43104 .42824 .42436 .41647 Mtetra
.64 .63 .824 r
.42436 .41647 .43104 .42824 .44271 .42482 .43604 .41298 Mtetra
.645 .632 .822 r
.43604 .41298 .44271 .42482 .45443 .42109 .44778 .40926 Mtetra
.65 .635 .821 r
.44778 .40926 .45443 .42109 .46621 .41707 .45958 .40532 Mtetra
.654 .638 .822 r
.45958 .40532 .46621 .41707 .47805 .41279 .47143 .40117 Mtetra
.659 .643 .823 r
.47143 .40117 .47805 .41279 .48994 .40829 .48334 .39685 Mtetra
.662 .649 .826 r
.48334 .39685 .48994 .40829 .50188 .4036 .49529 .3924 Mtetra
.665 .655 .83 r
.49529 .3924 .50188 .4036 .51386 .39878 .50729 .38783 Mtetra
.668 .661 .834 r
.50729 .38783 .51386 .39878 .52589 .39386 .51935 .38319 Mtetra
.67 .668 .839 r
.51935 .38319 .52589 .39386 .53797 .3889 .53145 .37851 Mtetra
.671 .674 .845 r
.53145 .37851 .53797 .3889 .55009 .38393 .5436 .37381 Mtetra
.672 .681 .85 r
.5436 .37381 .55009 .38393 .56226 .37898 .5558 .36911 Mtetra
.672 .687 .856 r
.5558 .36911 .56226 .37898 .57447 .37406 .56804 .36443 Mtetra
.672 .693 .861 r
.56804 .36443 .57447 .37406 .58674 .3692 .58034 .35977 Mtetra
.672 .699 .866 r
.58034 .35977 .58674 .3692 .59906 .3644 .59269 .35515 Mtetra
.672 .703 .871 r
.59269 .35515 .59906 .3644 .61142 .35965 .6051 .35055 Mtetra
.671 .708 .875 r
.6051 .35055 .61142 .35965 .62384 .35496 .61755 .34598 Mtetra
.671 .711 .879 r
.61755 .34598 .62384 .35496 .63631 .3503 .63006 .34142 Mtetra
.671 .714 .881 r
.63006 .34142 .63631 .3503 .64884 .34567 .64263 .33686 Mtetra
.67 .717 .884 r
.64263 .33686 .64884 .34567 .66142 .34106 .65525 .3323 Mtetra
.671 .719 .885 r
.65525 .3323 .66142 .34106 .67405 .33646 .66792 .32772 Mtetra
.671 .721 .887 r
.66792 .32772 .67405 .33646 .68674 .33184 .68065 .32312 Mtetra
.671 .723 .888 r
.68065 .32312 .68674 .33184 .69948 .3272 .69343 .31849 Mtetra
.672 .724 .889 r
.69343 .31849 .69948 .3272 .71228 .32253 .70626 .31382 Mtetra
.673 .725 .889 r
.70626 .31382 .71228 .32253 .72513 .31782 .71915 .3091 Mtetra
.673 .726 .889 r
.71915 .3091 .72513 .31782 .73803 .31307 .7321 .30434 Mtetra
.674 .727 .89 r
.7321 .30434 .73803 .31307 .75099 .30828 .74509 .29953 Mtetra
.675 .728 .89 r
.74509 .29953 .75099 .30828 .764 .30344 .75814 .29467 Mtetra
.676 .729 .89 r
.75814 .29467 .764 .30344 .77706 .29855 .77125 .28977 Mtetra
.677 .73 .89 r
.77125 .28977 .77706 .29855 .79018 .29361 .7844 .28481 Mtetra
.677 .731 .891 r
.7844 .28481 .79018 .29361 .80335 .28863 .79762 .27981 Mtetra
.678 .732 .891 r
.79762 .27981 .80335 .28863 .81657 .2836 .81088 .27477 Mtetra
.679 .733 .891 r
.81088 .27477 .81657 .2836 .82985 .27853 .8242 .26969 Mtetra
.679 .733 .892 r
.8242 .26969 .82985 .27853 .84318 .27343 .83758 .26458 Mtetra
.679 .734 .892 r
.83758 .26458 .84318 .27343 .85656 .2683 .85101 .25943 Mtetra
.641 .727 .911 r
.23818 .45171 .24544 .45879 .25625 .45586 .24902 .44865 Mtetra
.638 .723 .909 r
.24902 .44865 .25625 .45586 .2671 .45302 .2599 .44565 Mtetra
.636 .718 .907 r
.2599 .44565 .2671 .45302 .27799 .45028 .27083 .44272 Mtetra
.633 .713 .905 r
.27083 .44272 .27799 .45028 .28893 .44763 .2818 .43985 Mtetra
.63 .707 .901 r
.2818 .43985 .28893 .44763 .29991 .44507 .29282 .43705 Mtetra
.628 .7 .897 r
.29282 .43705 .29991 .44507 .31094 .4426 .30389 .43431 Mtetra
.626 .693 .893 r
.30389 .43431 .31094 .4426 .32202 .4402 .31501 .43162 Mtetra
.625 .686 .887 r
.31501 .43162 .32202 .4402 .33315 .43784 .32618 .42896 Mtetra
.624 .679 .882 r
.32618 .42896 .33315 .43784 .34434 .43551 .3374 .4263 Mtetra
.624 .672 .875 r
.3374 .4263 .34434 .43551 .35558 .43315 .34868 .42363 Mtetra
.625 .666 .869 r
.34868 .42363 .35558 .43315 .36689 .43074 .36002 .42091 Mtetra
.627 .66 .863 r
.36002 .42091 .36689 .43074 .37826 .42823 .37142 .41811 Mtetra
.629 .656 .857 r
.37142 .41811 .37826 .42823 .38969 .42558 .38288 .41521 Mtetra
.632 .652 .852 r
.38288 .41521 .38969 .42558 .40118 .42275 .3944 .41217 Mtetra
.636 .65 .847 r
.3944 .41217 .40118 .42275 .41274 .41972 .40598 .40897 Mtetra
.64 .649 .843 r
.40598 .40897 .41274 .41972 .42436 .41647 .41762 .4056 Mtetra
.644 .649 .841 r
.41762 .4056 .42436 .41647 .43604 .41298 .42932 .40206 Mtetra
.647 .65 .839 r
.42932 .40206 .43604 .41298 .44778 .40926 .44107 .39834 Mtetra
.651 .653 .838 r
.44107 .39834 .44778 .40926 .45958 .40532 .45289 .39445 Mtetra
.655 .656 .839 r
.45289 .39445 .45958 .40532 .47143 .40117 .46476 .3904 Mtetra
.658 .66 .84 r
.46476 .3904 .47143 .40117 .48334 .39685 .47668 .38622 Mtetra
.661 .664 .842 r
.47668 .38622 .48334 .39685 .49529 .3924 .48866 .38193 Mtetra
.664 .669 .845 r
.48866 .38193 .49529 .3924 .50729 .38783 .50068 .37756 Mtetra
.666 .675 .849 r
.50068 .37756 .50729 .38783 .51935 .38319 .51276 .37312 Mtetra
.667 .68 .853 r
.51276 .37312 .51935 .38319 .53145 .37851 .52489 .36863 Mtetra
.668 .686 .857 r
.52489 .36863 .53145 .37851 .5436 .37381 .53706 .36413 Mtetra
.669 .691 .862 r
.53706 .36413 .5436 .37381 .5558 .36911 .54929 .35962 Mtetra
.669 .696 .866 r
.54929 .35962 .5558 .36911 .56804 .36443 .56157 .3551 Mtetra
.669 .701 .87 r
.56157 .3551 .56804 .36443 .58034 .35977 .57391 .3506 Mtetra
.669 .705 .874 r
.57391 .3506 .58034 .35977 .59269 .35515 .58629 .3461 Mtetra
.669 .709 .878 r
.58629 .3461 .59269 .35515 .6051 .35055 .59873 .3416 Mtetra
.669 .712 .881 r
.59873 .3416 .6051 .35055 .61755 .34598 .61122 .3371 Mtetra
.669 .715 .883 r
.61122 .3371 .61755 .34598 .63006 .34142 .62377 .3326 Mtetra
.669 .717 .885 r
.62377 .3326 .63006 .34142 .64263 .33686 .63637 .32809 Mtetra
.669 .719 .887 r
.63637 .32809 .64263 .33686 .65525 .3323 .64903 .32355 Mtetra
.669 .721 .888 r
.64903 .32355 .65525 .3323 .66792 .32772 .66174 .31899 Mtetra
.67 .723 .889 r
.66174 .31899 .66792 .32772 .68065 .32312 .6745 .31439 Mtetra
.671 .724 .889 r
.6745 .31439 .68065 .32312 .69343 .31849 .68732 .30975 Mtetra
.671 .725 .89 r
.68732 .30975 .69343 .31849 .70626 .31382 .7002 .30507 Mtetra
.672 .726 .89 r
.7002 .30507 .70626 .31382 .71915 .3091 .71313 .30034 Mtetra
.673 .727 .89 r
.71313 .30034 .71915 .3091 .7321 .30434 .72611 .29557 Mtetra
.674 .728 .89 r
.72611 .29557 .7321 .30434 .74509 .29953 .73915 .29074 Mtetra
.675 .729 .891 r
.73915 .29074 .74509 .29953 .75814 .29467 .75224 .28586 Mtetra
.675 .73 .891 r
.75224 .28586 .75814 .29467 .77125 .28977 .76539 .28094 Mtetra
.676 .73 .891 r
.76539 .28094 .77125 .28977 .7844 .28481 .77859 .27596 Mtetra
.677 .731 .891 r
.77859 .27596 .7844 .28481 .79762 .27981 .79184 .27095 Mtetra
.677 .732 .891 r
.79184 .27095 .79762 .27981 .81088 .27477 .80515 .26589 Mtetra
.678 .733 .892 r
.80515 .26589 .81088 .27477 .8242 .26969 .81852 .26079 Mtetra
.678 .734 .892 r
.81852 .26079 .8242 .26969 .83758 .26458 .83194 .25566 Mtetra
.679 .734 .892 r
.83194 .25566 .83758 .26458 .85101 .25943 .84542 .2505 Mtetra
.644 .729 .911 r
.23086 .44464 .23818 .45171 .24902 .44865 .24173 .44147 Mtetra
.642 .726 .91 r
.24173 .44147 .24902 .44865 .2599 .44565 .25265 .43834 Mtetra
.64 .723 .908 r
.25265 .43834 .2599 .44565 .27083 .44272 .26361 .43525 Mtetra
.638 .719 .906 r
.26361 .43525 .27083 .44272 .2818 .43985 .27462 .43221 Mtetra
.636 .714 .904 r
.27462 .43221 .2818 .43985 .29282 .43705 .28567 .42922 Mtetra
.634 .709 .9 r
.28567 .42922 .29282 .43705 .30389 .43431 .29677 .42626 Mtetra
.633 .703 .897 r
.29677 .42626 .30389 .43431 .31501 .43162 .30793 .42334 Mtetra
.632 .698 .893 r
.30793 .42334 .31501 .43162 .32618 .42896 .31913 .42043 Mtetra
.631 .692 .888 r
.31913 .42043 .32618 .42896 .3374 .4263 .33039 .41752 Mtetra
.631 .686 .883 r
.33039 .41752 .3374 .4263 .34868 .42363 .34171 .4146 Mtetra
.632 .681 .878 r
.34171 .4146 .34868 .42363 .36002 .42091 .35308 .41163 Mtetra
.633 .677 .873 r
.35308 .41163 .36002 .42091 .37142 .41811 .3645 .40861 Mtetra
.635 .673 .869 r
.3645 .40861 .37142 .41811 .38288 .41521 .37599 .4055 Mtetra
.638 .67 .864 r
.37599 .4055 .38288 .41521 .3944 .41217 .38754 .40228 Mtetra
.64 .668 .861 r
.38754 .40228 .3944 .41217 .40598 .40897 .39914 .39895 Mtetra
.643 .667 .858 r
.39914 .39895 .40598 .40897 .41762 .4056 .4108 .39549 Mtetra
.646 .667 .855 r
.4108 .39549 .41762 .4056 .42932 .40206 .42253 .39189 Mtetra
.649 .667 .854 r
.42253 .39189 .42932 .40206 .44107 .39834 .43431 .38816 Mtetra
.652 .669 .853 r
.43431 .38816 .44107 .39834 .45289 .39445 .44614 .3843 Mtetra
.655 .672 .854 r
.44614 .3843 .45289 .39445 .46476 .3904 .45803 .38032 Mtetra
.658 .675 .855 r
.45803 .38032 .46476 .3904 .47668 .38622 .46998 .37624 Mtetra
.66 .678 .857 r
.46998 .37624 .47668 .38622 .48866 .38193 .48197 .37206 Mtetra
.662 .682 .859 r
.48197 .37206 .48866 .38193 .50068 .37756 .49402 .36782 Mtetra
.663 .687 .862 r
.49402 .36782 .50068 .37756 .51276 .37312 .50613 .36352 Mtetra
.665 .691 .865 r
.50613 .36352 .51276 .37312 .52489 .36863 .51828 .35918 Mtetra
.665 .695 .868 r
.51828 .35918 .52489 .36863 .53706 .36413 .53049 .35481 Mtetra
.666 .699 .871 r
.53049 .35481 .53706 .36413 .54929 .35962 .54275 .35042 Mtetra
.666 .703 .875 r
.54275 .35042 .54929 .35962 .56157 .3551 .55506 .34602 Mtetra
.667 .707 .878 r
.55506 .34602 .56157 .3551 .57391 .3506 .56743 .34161 Mtetra
.667 .71 .88 r
.56743 .34161 .57391 .3506 .58629 .3461 .57985 .33719 Mtetra
.667 .713 .883 r
.57985 .33719 .58629 .3461 .59873 .3416 .59232 .33276 Mtetra
.667 .716 .885 r
.59232 .33276 .59873 .3416 .61122 .3371 .60485 .32831 Mtetra
.667 .718 .887 r
.60485 .32831 .61122 .3371 .62377 .3326 .61743 .32384 Mtetra
.668 .72 .888 r
.61743 .32384 .62377 .3326 .63637 .32809 .63007 .31934 Mtetra
.668 .721 .889 r
.63007 .31934 .63637 .32809 .64903 .32355 .64276 .31481 Mtetra
.669 .723 .89 r
.64276 .31481 .64903 .32355 .66174 .31899 .65551 .31025 Mtetra
.669 .724 .89 r
.65551 .31025 .66174 .31899 .6745 .31439 .66832 .30564 Mtetra
.67 .725 .891 r
.66832 .30564 .6745 .31439 .68732 .30975 .68118 .30099 Mtetra
.671 .726 .891 r
.68118 .30099 .68732 .30975 .7002 .30507 .69409 .29629 Mtetra
.672 .727 .891 r
.69409 .29629 .7002 .30507 .71313 .30034 .70706 .29154 Mtetra
.673 .728 .891 r
.70706 .29154 .71313 .30034 .72611 .29557 .72008 .28675 Mtetra
.72008 .28675 .72611 .29557 .73915 .29074 .73316 .2819 Mtetra
.674 .729 .891 r
.73316 .2819 .73915 .29074 .75224 .28586 .74629 .277 Mtetra
.675 .73 .891 r
.74629 .277 .75224 .28586 .76539 .28094 .75948 .27205 Mtetra
.676 .731 .891 r
.75948 .27205 .76539 .28094 .77859 .27596 .77272 .26706 Mtetra
.676 .731 .892 r
.77272 .26706 .77859 .27596 .79184 .27095 .78602 .26202 Mtetra
.677 .732 .892 r
.78602 .26202 .79184 .27095 .80515 .26589 .79938 .25695 Mtetra
.677 .733 .892 r
.79938 .25695 .80515 .26589 .81852 .26079 .81279 .25184 Mtetra
.678 .734 .893 r
.81279 .25184 .81852 .26079 .83194 .25566 .82625 .24669 Mtetra
.678 .735 .893 r
.82625 .24669 .83194 .25566 .84542 .2505 .83978 .24151 Mtetra
.646 .732 .911 r
.22348 .43757 .23086 .44464 .24173 .44147 .23438 .4343 Mtetra
.645 .729 .91 r
.23438 .4343 .24173 .44147 .25265 .43834 .24533 .43107 Mtetra
.643 .726 .909 r
.24533 .43107 .25265 .43834 .26361 .43525 .25632 .42786 Mtetra
.642 .723 .907 r
.25632 .42786 .26361 .43525 .27462 .43221 .26736 .42468 Mtetra
.64 .72 .905 r
.26736 .42468 .27462 .43221 .28567 .42922 .27845 .42153 Mtetra
.639 .716 .903 r
.27845 .42153 .28567 .42922 .29677 .42626 .28959 .4184 Mtetra
.638 .712 .9 r
.28959 .4184 .29677 .42626 .30793 .42334 .30078 .41529 Mtetra
.637 .707 .897 r
.30078 .41529 .30793 .42334 .31913 .42043 .31202 .41218 Mtetra
.637 .703 .894 r
.31202 .41218 .31913 .42043 .33039 .41752 .32331 .40908 Mtetra
.637 .698 .89 r
.32331 .40908 .33039 .41752 .34171 .4146 .33466 .40595 Mtetra
.637 .694 .886 r
.33466 .40595 .34171 .4146 .35308 .41163 .34606 .40279 Mtetra
.638 .69 .882 r
.34606 .40279 .35308 .41163 .3645 .40861 .35752 .39959 Mtetra
.64 .687 .879 r
.35752 .39959 .3645 .40861 .37599 .4055 .36903 .39631 Mtetra
.642 .685 .875 r
.36903 .39631 .37599 .4055 .38754 .40228 .3806 .39296 Mtetra
.644 .683 .872 r
.3806 .39296 .38754 .40228 .39914 .39895 .39224 .38951 Mtetra
.646 .682 .87 r
.39224 .38951 .39914 .39895 .4108 .39549 .40392 .38597 Mtetra
.648 .682 .868 r
.40392 .38597 .4108 .39549 .42253 .39189 .41567 .38232 Mtetra
.651 .682 .867 r
.41567 .38232 .42253 .39189 .43431 .38816 .42747 .37857 Mtetra
.653 .684 .866 r
.42747 .37857 .43431 .38816 .44614 .3843 .43933 .37473 Mtetra
.655 .685 .866 r
.43933 .37473 .44614 .3843 .45803 .38032 .45125 .37078 Mtetra
.657 .688 .867 r
.45125 .37078 .45803 .38032 .46998 .37624 .46321 .36676 Mtetra
.659 .691 .869 r
.46321 .36676 .46998 .37624 .48197 .37206 .47524 .36266 Mtetra
.66 .694 .87 r
.47524 .36266 .48197 .37206 .49402 .36782 .48731 .3585 Mtetra
.662 .697 .872 r
.48731 .3585 .49402 .36782 .50613 .36352 .49944 .35429 Mtetra
.663 .7 .875 r
.49944 .35429 .50613 .36352 .51828 .35918 .51163 .35004 Mtetra
.663 .704 .877 r
.51163 .35004 .51828 .35918 .53049 .35481 .52386 .34576 Mtetra
.664 .707 .879 r
.52386 .34576 .53049 .35481 .54275 .35042 .53616 .34145 Mtetra
.664 .71 .882 r
.53616 .34145 .54275 .35042 .55506 .34602 .5485 .33712 Mtetra
.665 .712 .884 r
.5485 .33712 .55506 .34602 .56743 .34161 .5609 .33277 Mtetra
.665 .715 .886 r
.5609 .33277 .56743 .34161 .57985 .33719 .57335 .32839 Mtetra
.665 .717 .887 r
.57335 .32839 .57985 .33719 .59232 .33276 .58586 .32399 Mtetra
.666 .719 .888 r
.58586 .32399 .59232 .33276 .60485 .32831 .59843 .31956 Mtetra
.666 .721 .889 r
.59843 .31956 .60485 .32831 .61743 .32384 .61105 .3151 Mtetra
.667 .722 .89 r
.61105 .3151 .61743 .32384 .63007 .31934 .62372 .3106 Mtetra
.667 .723 .891 r
.62372 .3106 .63007 .31934 .64276 .31481 .63645 .30607 Mtetra
.668 .724 .891 r
.63645 .30607 .64276 .31481 .65551 .31025 .64924 .30149 Mtetra
.669 .725 .892 r
.64924 .30149 .65551 .31025 .66832 .30564 .66208 .29687 Mtetra
.67 .726 .892 r
.66208 .29687 .66832 .30564 .68118 .30099 .67498 .2922 Mtetra
.67 .727 .892 r
.67498 .2922 .68118 .30099 .69409 .29629 .68793 .28747 Mtetra
.671 .727 .892 r
.68793 .28747 .69409 .29629 .70706 .29154 .70094 .2827 Mtetra
.672 .728 .892 r
.70094 .2827 .70706 .29154 .72008 .28675 .714 .27788 Mtetra
.673 .729 .892 r
.714 .27788 .72008 .28675 .73316 .2819 .72712 .27301 Mtetra
.674 .73 .892 r
.72712 .27301 .73316 .2819 .74629 .277 .7403 .26809 Mtetra
.675 .73 .892 r
.7403 .26809 .74629 .277 .75948 .27205 .75353 .26312 Mtetra
.675 .731 .892 r
.75353 .26312 .75948 .27205 .77272 .26706 .76681 .2581 Mtetra
.676 .732 .892 r
.76681 .2581 .77272 .26706 .78602 .26202 .78016 .25305 Mtetra
.676 .733 .893 r
.78016 .25305 .78602 .26202 .79938 .25695 .79355 .24796 Mtetra
.677 .733 .893 r
.79355 .24796 .79938 .25695 .81279 .25184 .80701 .24282 Mtetra
.677 .734 .893 r
.80701 .24282 .81279 .25184 .82625 .24669 .82052 .23766 Mtetra
.677 .735 .894 r
.82052 .23766 .82625 .24669 .83978 .24151 .8341 .23247 Mtetra
.648 .733 .911 r
.21603 .43048 .22348 .43757 .23438 .4343 .22696 .42714 Mtetra
.647 .731 .911 r
.22696 .42714 .23438 .4343 .24533 .43107 .23794 .42381 Mtetra
.646 .729 .91 r
.23794 .42381 .24533 .43107 .25632 .42786 .24897 .4205 Mtetra
.645 .727 .908 r
.24897 .4205 .25632 .42786 .26736 .42468 .26004 .41721 Mtetra
.644 .724 .907 r
.26004 .41721 .26736 .42468 .27845 .42153 .27116 .41393 Mtetra
.643 .721 .905 r
.27116 .41393 .27845 .42153 .28959 .4184 .28234 .41066 Mtetra
.642 .718 .903 r
.28234 .41066 .28959 .4184 .30078 .41529 .29356 .40741 Mtetra
.641 .715 .901 r
.29356 .40741 .30078 .41529 .31202 .41218 .30483 .40415 Mtetra
.641 .711 .898 r
.30483 .40415 .31202 .41218 .32331 .40908 .31615 .40089 Mtetra
.641 .708 .895 r
.31615 .40089 .32331 .40908 .33466 .40595 .32753 .3976 Mtetra
.642 .705 .892 r
.32753 .3976 .33466 .40595 .34606 .40279 .33897 .39429 Mtetra
.642 .702 .889 r
.33897 .39429 .34606 .40279 .35752 .39959 .35046 .39094 Mtetra
.643 .699 .887 r
.35046 .39094 .35752 .39959 .36903 .39631 .362 .38753 Mtetra
.645 .697 .884 r
.362 .38753 .36903 .39631 .3806 .39296 .3736 .38406 Mtetra
.646 .696 .882 r
.3736 .38406 .3806 .39296 .39224 .38951 .38526 .38053 Mtetra
.648 .695 .88 r
.38526 .38053 .39224 .38951 .40392 .38597 .39698 .37691 Mtetra
.65 .695 .878 r
.39698 .37691 .40392 .38597 .41567 .38232 .40875 .37322 Mtetra
.652 .695 .877 r
.40875 .37322 .41567 .38232 .42747 .37857 .42058 .36944 Mtetra
.653 .696 .877 r
.42058 .36944 .42747 .37857 .43933 .37473 .43246 .36559 Mtetra
.655 .697 .877 r
.43246 .36559 .43933 .37473 .45125 .37078 .4444 .36166 Mtetra
.657 .699 .877 r
.4444 .36166 .45125 .37078 .46321 .36676 .4564 .35766 Mtetra
.658 .701 .878 r
.4564 .35766 .46321 .36676 .47524 .36266 .46845 .35361 Mtetra
.659 .703 .879 r
.46845 .35361 .47524 .36266 .48731 .3585 .48055 .3495 Mtetra
.66 .706 .881 r
.48055 .3495 .48731 .3585 .49944 .35429 .49271 .34534 Mtetra
.661 .708 .882 r
.49271 .34534 .49944 .35429 .51163 .35004 .50492 .34114 Mtetra
.662 .71 .884 r
.50492 .34114 .51163 .35004 .52386 .34576 .51719 .33691 Mtetra
.662 .713 .885 r
.51719 .33691 .52386 .34576 .53616 .34145 .52951 .33264 Mtetra
.663 .715 .887 r
.52951 .33264 .53616 .34145 .5485 .33712 .54189 .32834 Mtetra
.663 .717 .888 r
.54189 .32834 .5485 .33712 .5609 .33277 .55433 .32401 Mtetra
.664 .719 .889 r
.55433 .32401 .5609 .33277 .57335 .32839 .56681 .31966 Mtetra
.664 .72 .89 r
.56681 .31966 .57335 .32839 .58586 .32399 .57936 .31526 Mtetra
.665 .721 .891 r
.57936 .31526 .58586 .32399 .59843 .31956 .59196 .31084 Mtetra
.665 .723 .892 r
.59196 .31084 .59843 .31956 .61105 .3151 .60461 .30637 Mtetra
.666 .724 .892 r
.60461 .30637 .61105 .3151 .62372 .3106 .61733 .30186 Mtetra
.667 .725 .892 r
.61733 .30186 .62372 .3106 .63645 .30607 .63009 .29731 Mtetra
.668 .725 .893 r
.63009 .29731 .63645 .30607 .64924 .30149 .64292 .29271 Mtetra
.669 .726 .893 r
.64292 .29271 .64924 .30149 .66208 .29687 .6558 .28806 Mtetra
.669 .727 .893 r
.6558 .28806 .66208 .29687 .67498 .2922 .66873 .28337 Mtetra
.67 .728 .893 r
.66873 .28337 .67498 .2922 .68793 .28747 .68173 .27862 Mtetra
.671 .728 .893 r
.68173 .27862 .68793 .28747 .70094 .2827 .69477 .27382 Mtetra
.672 .729 .892 r
.69477 .27382 .70094 .2827 .714 .27788 .70788 .26897 Mtetra
.673 .729 .892 r
.70788 .26897 .714 .27788 .72712 .27301 .72104 .26407 Mtetra
.673 .73 .893 r
.72104 .26407 .72712 .27301 .7403 .26809 .73425 .25913 Mtetra
.674 .731 .893 r
.73425 .25913 .7403 .26809 .75353 .26312 .74753 .25413 Mtetra
.675 .731 .893 r
.74753 .25413 .75353 .26312 .76681 .2581 .76086 .2491 Mtetra
.675 .732 .893 r
.76086 .2491 .76681 .2581 .78016 .25305 .77424 .24402 Mtetra
.676 .733 .893 r
.77424 .24402 .78016 .25305 .79355 .24796 .78769 .23891 Mtetra
.676 .734 .893 r
.78769 .23891 .79355 .24796 .80701 .24282 .80119 .23376 Mtetra
.677 .734 .894 r
.80119 .23376 .80701 .24282 .82052 .23766 .81475 .22857 Mtetra
.677 .735 .894 r
.81475 .22857 .82052 .23766 .8341 .23247 .82836 .22336 Mtetra
.649 .734 .911 r
.20853 .42337 .21603 .43048 .22696 .42714 .21949 .41996 Mtetra
.649 .733 .911 r
.21949 .41996 .22696 .42714 .23794 .42381 .2305 .41656 Mtetra
.648 .731 .91 r
.2305 .41656 .23794 .42381 .24897 .4205 .24155 .41316 Mtetra
.647 .73 .909 r
.24155 .41316 .24897 .4205 .26004 .41721 .25266 .40978 Mtetra
.646 .728 .908 r
.25266 .40978 .26004 .41721 .27116 .41393 .26381 .4064 Mtetra
.646 .725 .907 r
.26381 .4064 .27116 .41393 .28234 .41066 .27502 .40302 Mtetra
.645 .723 .905 r
.27502 .40302 .28234 .41066 .29356 .40741 .28627 .39965 Mtetra
.645 .721 .903 r
.28627 .39965 .29356 .40741 .30483 .40415 .29757 .39627 Mtetra
.644 .718 .901 r
.29757 .39627 .30483 .40415 .31615 .40089 .30893 .39288 Mtetra
.644 .715 .899 r
.30893 .39288 .31615 .40089 .32753 .3976 .32034 .38947 Mtetra
.645 .713 .897 r
.32034 .38947 .32753 .3976 .33897 .39429 .33181 .38603 Mtetra
.645 .711 .895 r
.33181 .38603 .33897 .39429 .35046 .39094 .34333 .38256 Mtetra
.646 .709 .893 r
.34333 .38256 .35046 .39094 .362 .38753 .3549 .37905 Mtetra
.647 .707 .891 r
.3549 .37905 .362 .38753 .3736 .38406 .36653 .37549 Mtetra
.648 .706 .889 r
.36653 .37549 .3736 .38406 .38526 .38053 .37822 .37187 Mtetra
.65 .705 .888 r
.37822 .37187 .38526 .38053 .39698 .37691 .38996 .36819 Mtetra
.651 .705 .886 r
.38996 .36819 .39698 .37691 .40875 .37322 .40176 .36445 Mtetra
.652 .705 .886 r
.40176 .36445 .40875 .37322 .42058 .36944 .41362 .36064 Mtetra
.654 .706 .885 r
.41362 .36064 .42058 .36944 .43246 .36559 .42553 .35677 Mtetra
.655 .706 .885 r
.42553 .35677 .43246 .36559 .4444 .36166 .4375 .35284 Mtetra
.656 .708 .885 r
.4375 .35284 .4444 .36166 .4564 .35766 .44952 .34885 Mtetra
.657 .709 .886 r
.44952 .34885 .4564 .35766 .46845 .35361 .4616 .34481 Mtetra
.658 .711 .886 r
.4616 .34481 .46845 .35361 .48055 .3495 .47373 .34071 Mtetra
.659 .712 .887 r
.47373 .34071 .48055 .3495 .49271 .34534 .48592 .33658 Mtetra
.66 .714 .888 r
.48592 .33658 .49271 .34534 .50492 .34114 .49817 .3324 Mtetra
.661 .716 .889 r
.49817 .3324 .50492 .34114 .51719 .33691 .51047 .32819 Mtetra
.661 .717 .89 r
.51047 .32819 .51719 .33691 .52951 .33264 .52282 .32394 Mtetra
.662 .719 .891 r
.52282 .32394 .52951 .33264 .54189 .32834 .53523 .31965 Mtetra
.662 .72 .892 r
.53523 .31965 .54189 .32834 .55433 .32401 .5477 .31532 Mtetra
.663 .722 .892 r
.5477 .31532 .55433 .32401 .56681 .31966 .56022 .31096 Mtetra
.664 .723 .893 r
.56022 .31096 .56681 .31966 .57936 .31526 .5728 .30656 Mtetra
.664 .724 .893 r
.5728 .30656 .57936 .31526 .59196 .31084 .58544 .30212 Mtetra
.665 .724 .893 r
.58544 .30212 .59196 .31084 .60461 .30637 .59813 .29763 Mtetra
.666 .725 .894 r
.59813 .29763 .60461 .30637 .61733 .30186 .61088 .2931 Mtetra
.667 .726 .894 r
.61088 .2931 .61733 .30186 .63009 .29731 .62369 .28853 Mtetra
.667 .727 .894 r
.62369 .28853 .63009 .29731 .64292 .29271 .63655 .2839 Mtetra
.668 .727 .894 r
.63655 .2839 .64292 .29271 .6558 .28806 .64947 .27922 Mtetra
.669 .728 .893 r
.64947 .27922 .6558 .28806 .66873 .28337 .66244 .2745 Mtetra
.67 .728 .893 r
.66244 .2745 .66873 .28337 .68173 .27862 .67547 .26972 Mtetra
.671 .729 .893 r
.67547 .26972 .68173 .27862 .69477 .27382 .68856 .26489 Mtetra
.672 .729 .893 r
.68856 .26489 .69477 .27382 .70788 .26897 .7017 .26001 Mtetra
.672 .73 .893 r
.7017 .26001 .70788 .26897 .72104 .26407 .71491 .25509 Mtetra
.673 .731 .893 r
.71491 .25509 .72104 .26407 .73425 .25913 .72816 .25012 Mtetra
.674 .731 .893 r
.72816 .25012 .73425 .25913 .74753 .25413 .74148 .2451 Mtetra
.674 .732 .893 r
.74148 .2451 .74753 .25413 .76086 .2491 .75485 .24004 Mtetra
.675 .733 .894 r
.75485 .24004 .76086 .2491 .77424 .24402 .76828 .23494 Mtetra
.76828 .23494 .77424 .24402 .78769 .23891 .78177 .2298 Mtetra
.676 .734 .894 r
.78177 .2298 .78769 .23891 .80119 .23376 .79532 .22463 Mtetra
.676 .735 .894 r
.79532 .22463 .80119 .23376 .81475 .22857 .80892 .21943 Mtetra
.676 .735 .895 r
.80892 .21943 .81475 .22857 .82836 .22336 .82259 .2142 Mtetra
.65 .735 .911 r
.20097 .41622 .20853 .42337 .21949 .41996 .21196 .41275 Mtetra
.65 .734 .911 r
.21196 .41275 .21949 .41996 .2305 .41656 .22299 .40929 Mtetra
.649 .733 .91 r
.22299 .40929 .2305 .41656 .24155 .41316 .23408 .40582 Mtetra
.649 .732 .91 r
.23408 .40582 .24155 .41316 .25266 .40978 .24521 .40236 Mtetra
.648 .73 .909 r
.24521 .40236 .25266 .40978 .26381 .4064 .2564 .3989 Mtetra
.648 .729 .908 r
.2564 .3989 .26381 .4064 .27502 .40302 .26763 .39543 Mtetra
.647 .727 .907 r
.26763 .39543 .27502 .40302 .28627 .39965 .27892 .39196 Mtetra
.647 .725 .905 r
.27892 .39196 .28627 .39965 .29757 .39627 .29025 .38848 Mtetra
.647 .723 .904 r
.29025 .38848 .29757 .39627 .30893 .39288 .30164 .38499 Mtetra
.647 .721 .902 r
.30164 .38499 .30893 .39288 .32034 .38947 .31308 .38148 Mtetra
.647 .719 .901 r
.31308 .38148 .32034 .38947 .33181 .38603 .32458 .37794 Mtetra
.648 .718 .899 r
.32458 .37794 .33181 .38603 .34333 .38256 .33613 .37438 Mtetra
.648 .716 .898 r
.33613 .37438 .34333 .38256 .3549 .37905 .34774 .37078 Mtetra
.649 .715 .896 r
.34774 .37078 .3549 .37905 .36653 .37549 .3594 .36713 Mtetra
.65 .714 .895 r
.3594 .36713 .36653 .37549 .37822 .37187 .37111 .36344 Mtetra
.651 .713 .894 r
.37111 .36344 .37822 .37187 .38996 .36819 .38288 .3597 Mtetra
.652 .713 .893 r
.38288 .3597 .38996 .36819 .40176 .36445 .39471 .35591 Mtetra
.653 .713 .892 r
.39471 .35591 .40176 .36445 .41362 .36064 .4066 .35207 Mtetra
.654 .713 .891 r
.4066 .35207 .41362 .36064 .42553 .35677 .41854 .34817 Mtetra
.655 .714 .891 r
.41854 .34817 .42553 .35677 .4375 .35284 .43053 .34422 Mtetra
.656 .715 .891 r
.43053 .34422 .4375 .35284 .44952 .34885 .44259 .34022 Mtetra
.657 .715 .891 r
.44259 .34022 .44952 .34885 .4616 .34481 .4547 .33618 Mtetra
.658 .717 .892 r
.4547 .33618 .4616 .34481 .47373 .34071 .46686 .33208 Mtetra
.659 .718 .892 r
.46686 .33208 .47373 .34071 .48592 .33658 .47908 .32795 Mtetra
.659 .719 .893 r
.47908 .32795 .48592 .33658 .49817 .3324 .49136 .32377 Mtetra
.66 .72 .893 r
.49136 .32377 .49817 .3324 .51047 .32819 .50369 .31955 Mtetra
.661 .721 .894 r
.50369 .31955 .51047 .32819 .52282 .32394 .51608 .31529 Mtetra
.661 .722 .894 r
.51608 .31529 .52282 .32394 .53523 .31965 .52852 .311 Mtetra
.662 .723 .894 r
.52852 .311 .53523 .31965 .5477 .31532 .54102 .30666 Mtetra
.663 .724 .895 r
.54102 .30666 .5477 .31532 .56022 .31096 .55358 .30228 Mtetra
.663 .725 .895 r
.55358 .30228 .56022 .31096 .5728 .30656 .5662 .29786 Mtetra
.664 .725 .895 r
.5662 .29786 .5728 .30656 .58544 .30212 .57887 .29339 Mtetra
.665 .726 .895 r
.57887 .29339 .58544 .30212 .59813 .29763 .5916 .28888 Mtetra
.666 .727 .895 r
.5916 .28888 .59813 .29763 .61088 .2931 .60438 .28432 Mtetra
.667 .727 .895 r
.60438 .28432 .61088 .2931 .62369 .28853 .61723 .27971 Mtetra
.667 .728 .895 r
.61723 .27971 .62369 .28853 .63655 .2839 .63013 .27505 Mtetra
.668 .728 .894 r
.63013 .27505 .63655 .2839 .64947 .27922 .64308 .27034 Mtetra
.669 .729 .894 r
.64308 .27034 .64947 .27922 .66244 .2745 .6561 .26559 Mtetra
.67 .729 .894 r
.6561 .26559 .66244 .2745 .67547 .26972 .66917 .26078 Mtetra
.671 .73 .894 r
.66917 .26078 .67547 .26972 .68856 .26489 .6823 .25592 Mtetra
.6823 .25592 .68856 .26489 .7017 .26001 .69548 .25101 Mtetra
.672 .731 .894 r
.69548 .25101 .7017 .26001 .71491 .25509 .70872 .24605 Mtetra
.673 .731 .894 r
.70872 .24605 .71491 .25509 .72816 .25012 .72202 .24105 Mtetra
.673 .732 .894 r
.72202 .24105 .72816 .25012 .74148 .2451 .73538 .23601 Mtetra
.674 .732 .894 r
.73538 .23601 .74148 .2451 .75485 .24004 .7488 .23093 Mtetra
.675 .733 .894 r
.7488 .23093 .75485 .24004 .76828 .23494 .76227 .2258 Mtetra
.675 .734 .894 r
.76227 .2258 .76828 .23494 .78177 .2298 .77581 .22064 Mtetra
.675 .734 .895 r
.77581 .22064 .78177 .2298 .79532 .22463 .7894 .21545 Mtetra
.676 .735 .895 r
.7894 .21545 .79532 .22463 .80892 .21943 .80305 .21023 Mtetra
.80305 .21023 .80892 .21943 .82259 .2142 .81676 .20497 Mtetra
.651 .736 .911 r
.19334 .40903 .20097 .41622 .21196 .41275 .20436 .40551 Mtetra
.651 .735 .911 r
.20436 .40551 .21196 .41275 .22299 .40929 .21543 .40199 Mtetra
.65 .734 .911 r
.21543 .40199 .22299 .40929 .23408 .40582 .22654 .39846 Mtetra
.65 .733 .91 r
.22654 .39846 .23408 .40582 .24521 .40236 .2377 .39494 Mtetra
.649 .732 .91 r
.2377 .39494 .24521 .40236 .2564 .3989 .24892 .3914 Mtetra
.649 .731 .909 r
.24892 .3914 .2564 .3989 .26763 .39543 .26018 .38786 Mtetra
.649 .73 .908 r
.26018 .38786 .26763 .39543 .27892 .39196 .2715 .38431 Mtetra
.649 .728 .907 r
.2715 .38431 .27892 .39196 .29025 .38848 .28287 .38075 Mtetra
.649 .727 .906 r
.28287 .38075 .29025 .38848 .30164 .38499 .29429 .37718 Mtetra
.649 .725 .905 r
.29429 .37718 .30164 .38499 .31308 .38148 .30576 .37358 Mtetra
.649 .724 .903 r
.30576 .37358 .31308 .38148 .32458 .37794 .31729 .36997 Mtetra
.649 .723 .902 r
.31729 .36997 .32458 .37794 .33613 .37438 .32887 .36632 Mtetra
.65 .722 .901 r
.32887 .36632 .33613 .37438 .34774 .37078 .3405 .36264 Mtetra
.65 .721 .9 r
.3405 .36264 .34774 .37078 .3594 .36713 .35219 .35893 Mtetra
.651 .72 .899 r
.35219 .35893 .3594 .36713 .37111 .36344 .36394 .35517 Mtetra
.652 .719 .898 r
.36394 .35517 .37111 .36344 .38288 .3597 .37574 .35138 Mtetra
.653 .719 .897 r
.37574 .35138 .38288 .3597 .39471 .35591 .3876 .34754 Mtetra
.653 .719 .896 r
.3876 .34754 .39471 .35591 .4066 .35207 .39951 .34365 Mtetra
.654 .719 .896 r
.39951 .34365 .4066 .35207 .41854 .34817 .41149 .33972 Mtetra
.655 .719 .896 r
.41149 .33972 .41854 .34817 .43053 .34422 .42351 .33574 Mtetra
.656 .72 .896 r
.42351 .33574 .43053 .34422 .44259 .34022 .43559 .33172 Mtetra
.657 .72 .895 r
.43559 .33172 .44259 .34022 .4547 .33618 .44773 .32765 Mtetra
.658 .721 .896 r
.44773 .32765 .4547 .33618 .46686 .33208 .45993 .32354 Mtetra
.658 .722 .896 r
.45993 .32354 .46686 .33208 .47908 .32795 .47218 .31939 Mtetra
.659 .722 .896 r
.47218 .31939 .47908 .32795 .49136 .32377 .48449 .3152 Mtetra
.66 .723 .896 r
.48449 .3152 .49136 .32377 .50369 .31955 .49686 .31096 Mtetra
.66 .724 .896 r
.49686 .31096 .50369 .31955 .51608 .31529 .50928 .30668 Mtetra
.661 .725 .896 r
.50928 .30668 .51608 .31529 .52852 .311 .52176 .30236 Mtetra
.662 .725 .896 r
.52176 .30236 .52852 .311 .54102 .30666 .53429 .298 Mtetra
.663 .726 .896 r
.53429 .298 .54102 .30666 .55358 .30228 .54689 .29359 Mtetra
.54689 .29359 .55358 .30228 .5662 .29786 .55954 .28914 Mtetra
.664 .727 .896 r
.55954 .28914 .5662 .29786 .57887 .29339 .57225 .28464 Mtetra
.665 .727 .896 r
.57225 .28464 .57887 .29339 .5916 .28888 .58501 .2801 Mtetra
.666 .728 .896 r
.58501 .2801 .5916 .28888 .60438 .28432 .59784 .2755 Mtetra
.667 .728 .895 r
.59784 .2755 .60438 .28432 .61723 .27971 .61072 .27086 Mtetra
.61072 .27086 .61723 .27971 .63013 .27505 .62365 .26617 Mtetra
.668 .729 .895 r
.62365 .26617 .63013 .27505 .64308 .27034 .63665 .26142 Mtetra
.669 .729 .895 r
.63665 .26142 .64308 .27034 .6561 .26559 .6497 .25663 Mtetra
.67 .73 .895 r
.6497 .25663 .6561 .26559 .66917 .26078 .66281 .25179 Mtetra
.671 .73 .895 r
.66281 .25179 .66917 .26078 .6823 .25592 .67598 .2469 Mtetra
.671 .731 .894 r
.67598 .2469 .6823 .25592 .69548 .25101 .68921 .24196 Mtetra
.672 .731 .894 r
.68921 .24196 .69548 .25101 .70872 .24605 .70249 .23697 Mtetra
.673 .732 .894 r
.70249 .23697 .70872 .24605 .72202 .24105 .71584 .23194 Mtetra
.71584 .23194 .72202 .24105 .73538 .23601 .72924 .22687 Mtetra
.674 .733 .895 r
.72924 .22687 .73538 .23601 .7488 .23093 .7427 .22176 Mtetra
.7427 .22176 .7488 .23093 .76227 .2258 .75621 .21661 Mtetra
.675 .734 .895 r
.75621 .21661 .76227 .2258 .77581 .22064 .76979 .21143 Mtetra
.675 .735 .895 r
.76979 .21143 .77581 .22064 .7894 .21545 .78343 .20621 Mtetra
.675 .735 .896 r
.78343 .20621 .7894 .21545 .80305 .21023 .79713 .20096 Mtetra
.675 .736 .896 r
.79713 .20096 .80305 .21023 .81676 .20497 .81089 .19569 Mtetra
.652 .736 .911 r
.18566 .40179 .19334 .40903 .20436 .40551 .1967 .39822 Mtetra
.651 .736 .911 r
.1967 .39822 .20436 .40551 .21543 .40199 .2078 .39465 Mtetra
.651 .735 .911 r
.2078 .39465 .21543 .40199 .22654 .39846 .21894 .39107 Mtetra
.651 .734 .91 r
.21894 .39107 .22654 .39846 .2377 .39494 .23013 .38749 Mtetra
.65 .733 .91 r
.23013 .38749 .2377 .39494 .24892 .3914 .24138 .38389 Mtetra
.65 .732 .909 r
.24138 .38389 .24892 .3914 .26018 .38786 .25267 .38029 Mtetra
.65 .731 .909 r
.25267 .38029 .26018 .38786 .2715 .38431 .26402 .37667 Mtetra
.65 .73 .908 r
.26402 .37667 .2715 .38431 .28287 .38075 .27542 .37305 Mtetra
.65 .729 .907 r
.27542 .37305 .28287 .38075 .29429 .37718 .28687 .3694 Mtetra
.65 .728 .906 r
.28687 .3694 .29429 .37718 .30576 .37358 .29837 .36573 Mtetra
.65 .727 .905 r
.29837 .36573 .30576 .37358 .31729 .36997 .30993 .36204 Mtetra
.651 .726 .904 r
.30993 .36204 .31729 .36997 .32887 .36632 .32154 .35833 Mtetra
.651 .726 .903 r
.32154 .35833 .32887 .36632 .3405 .36264 .33321 .35458 Mtetra
.651 .725 .903 r
.33321 .35458 .3405 .36264 .35219 .35893 .34493 .35081 Mtetra
.652 .724 .902 r
.34493 .35081 .35219 .35893 .36394 .35517 .3567 .347 Mtetra
.653 .724 .901 r
.3567 .347 .36394 .35517 .37574 .35138 .36854 .34315 Mtetra
.653 .723 .9 r
.36854 .34315 .37574 .35138 .3876 .34754 .38043 .33926 Mtetra
.654 .723 .9 r
.38043 .33926 .3876 .34754 .39951 .34365 .39237 .33533 Mtetra
.655 .723 .899 r
.39237 .33533 .39951 .34365 .41149 .33972 .40437 .33136 Mtetra
.40437 .33136 .41149 .33972 .42351 .33574 .41643 .32734 Mtetra
.656 .724 .899 r
.41643 .32734 .42351 .33574 .43559 .33172 .42854 .32329 Mtetra
.657 .724 .898 r
.42854 .32329 .43559 .33172 .44773 .32765 .44071 .31919 Mtetra
.658 .724 .898 r
.44071 .31919 .44773 .32765 .45993 .32354 .45294 .31505 Mtetra
.658 .725 .898 r
.45294 .31505 .45993 .32354 .47218 .31939 .46523 .31087 Mtetra
.659 .725 .898 r
.46523 .31087 .47218 .31939 .48449 .3152 .47757 .30665 Mtetra
.66 .726 .898 r
.47757 .30665 .48449 .3152 .49686 .31096 .48997 .30238 Mtetra
.48997 .30238 .49686 .31096 .50928 .30668 .50243 .29808 Mtetra
.661 .726 .898 r
.50243 .29808 .50928 .30668 .52176 .30236 .51494 .29372 Mtetra
.662 .727 .898 r
.51494 .29372 .52176 .30236 .53429 .298 .52751 .28933 Mtetra
.663 .727 .897 r
.52751 .28933 .53429 .298 .54689 .29359 .54014 .28489 Mtetra
.663 .728 .897 r
.54014 .28489 .54689 .29359 .55954 .28914 .55283 .2804 Mtetra
.664 .728 .897 r
.55283 .2804 .55954 .28914 .57225 .28464 .56557 .27586 Mtetra
.665 .728 .897 r
.56557 .27586 .57225 .28464 .58501 .2801 .57837 .27128 Mtetra
.666 .729 .896 r
.57837 .27128 .58501 .2801 .59784 .2755 .59123 .26665 Mtetra
.667 .729 .896 r
.59123 .26665 .59784 .2755 .61072 .27086 .60415 .26197 Mtetra
.60415 .26197 .61072 .27086 .62365 .26617 .61713 .25724 Mtetra
.668 .73 .896 r
.61713 .25724 .62365 .26617 .63665 .26142 .63016 .25246 Mtetra
.669 .73 .895 r
.63016 .25246 .63665 .26142 .6497 .25663 .64326 .24763 Mtetra
.67 .73 .895 r
.64326 .24763 .6497 .25663 .66281 .25179 .65641 .24275 Mtetra
.67 .731 .895 r
.65641 .24275 .66281 .25179 .67598 .2469 .66962 .23783 Mtetra
.671 .731 .895 r
.66962 .23783 .67598 .2469 .68921 .24196 .68288 .23285 Mtetra
.672 .732 .895 r
.68288 .23285 .68921 .24196 .70249 .23697 .69621 .22784 Mtetra
.69621 .22784 .70249 .23697 .71584 .23194 .7096 .22278 Mtetra
.673 .733 .895 r
.7096 .22278 .71584 .23194 .72924 .22687 .72304 .21768 Mtetra
.72304 .21768 .72924 .22687 .7427 .22176 .73654 .21254 Mtetra
.674 .734 .895 r
.73654 .21254 .7427 .22176 .75621 .21661 .75011 .20737 Mtetra
.674 .734 .896 r
.75011 .20737 .75621 .21661 .76979 .21143 .76373 .20216 Mtetra
.674 .735 .896 r
.76373 .20216 .76979 .21143 .78343 .20621 .77741 .19691 Mtetra
.675 .736 .896 r
.77741 .19691 .78343 .20621 .79713 .20096 .79116 .19164 Mtetra
.79116 .19164 .79713 .20096 .81089 .19569 .80497 .18634 Mtetra
.652 .736 .911 r
.17791 .39449 .18566 .40179 .1967 .39822 .18899 .39089 Mtetra
.18899 .39089 .1967 .39822 .2078 .39465 .20011 .38727 Mtetra
.652 .735 .911 r
.20011 .38727 .2078 .39465 .21894 .39107 .21128 .38364 Mtetra
.651 .735 .91 r
.21128 .38364 .21894 .39107 .23013 .38749 .2225 .38 Mtetra
.651 .734 .91 r
.2225 .38 .23013 .38749 .24138 .38389 .23377 .37636 Mtetra
.651 .733 .91 r
.23377 .37636 .24138 .38389 .25267 .38029 .2451 .3727 Mtetra
.651 .733 .909 r
.2451 .3727 .25267 .38029 .26402 .37667 .25647 .36902 Mtetra
.651 .732 .909 r
.25647 .36902 .26402 .37667 .27542 .37305 .2679 .36533 Mtetra
.651 .731 .908 r
.2679 .36533 .27542 .37305 .28687 .3694 .27938 .36162 Mtetra
.651 .73 .907 r
.27938 .36162 .28687 .3694 .29837 .36573 .29092 .3579 Mtetra
.29092 .3579 .29837 .36573 .30993 .36204 .30251 .35414 Mtetra
.652 .729 .906 r
.30251 .35414 .30993 .36204 .32154 .35833 .31415 .35037 Mtetra
.652 .728 .905 r
.31415 .35037 .32154 .35833 .33321 .35458 .32584 .34656 Mtetra
.652 .728 .904 r
.32584 .34656 .33321 .35458 .34493 .35081 .3376 .34273 Mtetra
.653 .727 .904 r
.3376 .34273 .34493 .35081 .3567 .347 .34941 .33886 Mtetra
.653 .727 .903 r
.34941 .33886 .3567 .347 .36854 .34315 .36127 .33496 Mtetra
.654 .727 .902 r
.36127 .33496 .36854 .34315 .38043 .33926 .37319 .33102 Mtetra
.654 .726 .902 r
.37319 .33102 .38043 .33926 .39237 .33533 .38516 .32705 Mtetra
.655 .726 .901 r
.38516 .32705 .39237 .33533 .40437 .33136 .3972 .32303 Mtetra
.656 .726 .901 r
.3972 .32303 .40437 .33136 .41643 .32734 .40929 .31898 Mtetra
.40929 .31898 .41643 .32734 .42854 .32329 .42143 .31489 Mtetra
.657 .726 .9 r
.42143 .31489 .42854 .32329 .44071 .31919 .43364 .31075 Mtetra
.658 .727 .9 r
.43364 .31075 .44071 .31919 .45294 .31505 .4459 .30658 Mtetra
.4459 .30658 .45294 .31505 .46523 .31087 .45822 .30236 Mtetra
.659 .727 .9 r
.45822 .30236 .46523 .31087 .47757 .30665 .47059 .2981 Mtetra
.66 .727 .899 r
.47059 .2981 .47757 .30665 .48997 .30238 .48302 .2938 Mtetra
.66 .728 .899 r
.48302 .2938 .48997 .30238 .50243 .29808 .49552 .28945 Mtetra
.661 .728 .899 r
.49552 .28945 .50243 .29808 .51494 .29372 .50806 .28506 Mtetra
.662 .728 .899 r
.50806 .28506 .51494 .29372 .52751 .28933 .52067 .28063 Mtetra
.663 .728 .898 r
.52067 .28063 .52751 .28933 .54014 .28489 .53334 .27615 Mtetra
.663 .729 .898 r
.53334 .27615 .54014 .28489 .55283 .2804 .54606 .27162 Mtetra
.664 .729 .898 r
.54606 .27162 .55283 .2804 .56557 .27586 .55884 .26705 Mtetra
.665 .729 .897 r
.55884 .26705 .56557 .27586 .57837 .27128 .57168 .26242 Mtetra
.666 .729 .897 r
.57168 .26242 .57837 .27128 .59123 .26665 .58458 .25775 Mtetra
.667 .73 .897 r
.58458 .25775 .59123 .26665 .60415 .26197 .59754 .25303 Mtetra
.667 .73 .896 r
.59754 .25303 .60415 .26197 .61713 .25724 .61055 .24826 Mtetra
.668 .73 .896 r
.61055 .24826 .61713 .25724 .63016 .25246 .62363 .24344 Mtetra
.669 .731 .896 r
.62363 .24344 .63016 .25246 .64326 .24763 .63676 .23858 Mtetra
.67 .731 .896 r
.63676 .23858 .64326 .24763 .65641 .24275 .64995 .23366 Mtetra
.64995 .23366 .65641 .24275 .66962 .23783 .6632 .2287 Mtetra
.671 .732 .896 r
.6632 .2287 .66962 .23783 .68288 .23285 .67651 .2237 Mtetra
.672 .732 .896 r
.67651 .2237 .68288 .23285 .69621 .22784 .68988 .21865 Mtetra
.672 .733 .896 r
.68988 .21865 .69621 .22784 .7096 .22278 .7033 .21356 Mtetra
.673 .733 .896 r
.7033 .21356 .7096 .22278 .72304 .21768 .71679 .20843 Mtetra
.673 .734 .896 r
.71679 .20843 .72304 .21768 .73654 .21254 .73034 .20327 Mtetra
.73034 .20327 .73654 .21254 .75011 .20737 .74395 .19806 Mtetra
.674 .735 .896 r
.74395 .19806 .75011 .20737 .76373 .20216 .75762 .19283 Mtetra
.75762 .19283 .76373 .20216 .77741 .19691 .77135 .18756 Mtetra
.674 .736 .897 r
.77135 .18756 .77741 .19691 .79116 .19164 .78514 .18226 Mtetra
.78514 .18226 .79116 .19164 .80497 .18634 .799 .17693 Mtetra
.653 .736 .911 r
.17011 .38714 .17791 .39449 .18899 .39089 .18121 .38349 Mtetra
.652 .736 .911 r
.18121 .38349 .18899 .39089 .20011 .38727 .19236 .37983 Mtetra
.19236 .37983 .20011 .38727 .21128 .38364 .20356 .37616 Mtetra
.652 .735 .91 r
.20356 .37616 .21128 .38364 .2225 .38 .21481 .37247 Mtetra
.21481 .37247 .2225 .38 .23377 .37636 .22611 .36877 Mtetra
.652 .734 .91 r
.22611 .36877 .23377 .37636 .2451 .3727 .23746 .36506 Mtetra
.652 .734 .909 r
.23746 .36506 .2451 .3727 .25647 .36902 .24887 .36134 Mtetra
.652 .733 .909 r
.24887 .36134 .25647 .36902 .2679 .36533 .26033 .35759 Mtetra
.652 .732 .908 r
.26033 .35759 .2679 .36533 .27938 .36162 .27184 .35383 Mtetra
.27184 .35383 .27938 .36162 .29092 .3579 .2834 .35004 Mtetra
.652 .731 .907 r
.2834 .35004 .29092 .3579 .30251 .35414 .29502 .34624 Mtetra
.29502 .34624 .30251 .35414 .31415 .35037 .30669 .34241 Mtetra
.653 .73 .906 r
.30669 .34241 .31415 .35037 .32584 .34656 .31842 .33855 Mtetra
.31842 .33855 .32584 .34656 .3376 .34273 .3302 .33466 Mtetra
.653 .729 .905 r
.3302 .33466 .3376 .34273 .34941 .33886 .34204 .33074 Mtetra
.654 .729 .904 r
.34204 .33074 .34941 .33886 .36127 .33496 .35394 .32679 Mtetra
.35394 .32679 .36127 .33496 .37319 .33102 .36589 .3228 Mtetra
.655 .729 .903 r
.36589 .3228 .37319 .33102 .38516 .32705 .3779 .31878 Mtetra
.655 .728 .903 r
.3779 .31878 .38516 .32705 .3972 .32303 .38996 .31472 Mtetra
.656 .728 .902 r
.38996 .31472 .3972 .32303 .40929 .31898 .40208 .31062 Mtetra
.657 .728 .902 r
.40208 .31062 .40929 .31898 .42143 .31489 .41426 .30648 Mtetra
.41426 .30648 .42143 .31489 .43364 .31075 .4265 .30231 Mtetra
.658 .728 .901 r
.4265 .30231 .43364 .31075 .4459 .30658 .43879 .29809 Mtetra
.659 .728 .901 r
.43879 .29809 .4459 .30658 .45822 .30236 .45115 .29383 Mtetra
.659 .729 .901 r
.45115 .29383 .45822 .30236 .47059 .2981 .46356 .28953 Mtetra
.66 .729 .9 r
.46356 .28953 .47059 .2981 .48302 .2938 .47602 .28519 Mtetra
.661 .729 .9 r
.47602 .28519 .48302 .2938 .49552 .28945 .48855 .2808 Mtetra
.48855 .2808 .49552 .28945 .50806 .28506 .50113 .27637 Mtetra
.662 .729 .899 r
.50113 .27637 .50806 .28506 .52067 .28063 .51378 .27189 Mtetra
.663 .729 .899 r
.51378 .27189 .52067 .28063 .53334 .27615 .52648 .26737 Mtetra
.664 .73 .899 r
.52648 .26737 .53334 .27615 .54606 .27162 .53924 .2628 Mtetra
.664 .73 .898 r
.53924 .2628 .54606 .27162 .55884 .26705 .55206 .25818 Mtetra
.665 .73 .898 r
.55206 .25818 .55884 .26705 .57168 .26242 .56493 .25352 Mtetra
.666 .73 .898 r
.56493 .25352 .57168 .26242 .58458 .25775 .57787 .2488 Mtetra
.667 .73 .897 r
.57787 .2488 .58458 .25775 .59754 .25303 .59087 .24404 Mtetra
.667 .731 .897 r
.59087 .24404 .59754 .25303 .61055 .24826 .60392 .23923 Mtetra
.668 .731 .897 r
.60392 .23923 .61055 .24826 .62363 .24344 .61703 .23438 Mtetra
.669 .731 .897 r
.61703 .23438 .62363 .24344 .63676 .23858 .63021 .22947 Mtetra
.67 .732 .896 r
.63021 .22947 .63676 .23858 .64995 .23366 .64344 .22452 Mtetra
.64344 .22452 .64995 .23366 .6632 .2287 .65673 .21953 Mtetra
.671 .732 .896 r
.65673 .21953 .6632 .2287 .67651 .2237 .67008 .21449 Mtetra
.671 .733 .896 r
.67008 .21449 .67651 .2237 .68988 .21865 .68349 .20941 Mtetra
.672 .733 .896 r
.68349 .20941 .68988 .21865 .7033 .21356 .69696 .20429 Mtetra
.672 .734 .896 r
.69696 .20429 .7033 .21356 .71679 .20843 .71049 .19913 Mtetra
.673 .734 .896 r
.71049 .19913 .71679 .20843 .73034 .20327 .72409 .19393 Mtetra
.673 .735 .897 r
.72409 .19393 .73034 .20327 .74395 .19806 .73774 .1887 Mtetra
.73774 .1887 .74395 .19806 .75762 .19283 .75145 .18344 Mtetra
.674 .736 .897 r
.75145 .18344 .75762 .19283 .77135 .18756 .76523 .17814 Mtetra
.76523 .17814 .77135 .18756 .78514 .18226 .77907 .17281 Mtetra
.674 .737 .898 r
.77907 .17281 .78514 .18226 .799 .17693 .79297 .16746 Mtetra
.653 .736 .911 r
.16224 .37973 .17011 .38714 .18121 .38349 .17337 .37603 Mtetra
.17337 .37603 .18121 .38349 .19236 .37983 .18454 .37233 Mtetra
.653 .736 .91 r
.18454 .37233 .19236 .37983 .20356 .37616 .19577 .36862 Mtetra
.652 .735 .91 r
.19577 .36862 .20356 .37616 .21481 .37247 .20705 .36489 Mtetra
.20705 .36489 .21481 .37247 .22611 .36877 .21838 .36114 Mtetra
.21838 .36114 .22611 .36877 .23746 .36506 .22976 .35738 Mtetra
.652 .734 .909 r
.22976 .35738 .23746 .36506 .24887 .36134 .2412 .35361 Mtetra
.2412 .35361 .24887 .36134 .26033 .35759 .25269 .34981 Mtetra
.652 .733 .909 r
.25269 .34981 .26033 .35759 .27184 .35383 .26423 .346 Mtetra
.653 .733 .908 r
.26423 .346 .27184 .35383 .2834 .35004 .27582 .34216 Mtetra
.653 .732 .908 r
.27582 .34216 .2834 .35004 .29502 .34624 .28747 .3383 Mtetra
.653 .732 .907 r
.28747 .3383 .29502 .34624 .30669 .34241 .29918 .33442 Mtetra
.653 .731 .907 r
.29918 .33442 .30669 .34241 .31842 .33855 .31093 .33051 Mtetra
.654 .731 .906 r
.31093 .33051 .31842 .33855 .3302 .33466 .32275 .32657 Mtetra
.32275 .32657 .3302 .33466 .34204 .33074 .33462 .3226 Mtetra
.654 .73 .905 r
.33462 .3226 .34204 .33074 .35394 .32679 .34655 .31859 Mtetra
.655 .73 .905 r
.34655 .31859 .35394 .32679 .36589 .3228 .35853 .31456 Mtetra
.655 .73 .904 r
.35853 .31456 .36589 .3228 .3779 .31878 .37057 .31049 Mtetra
.656 .73 .904 r
.37057 .31049 .3779 .31878 .38996 .31472 .38267 .30638 Mtetra
.656 .73 .903 r
.38267 .30638 .38996 .31472 .40208 .31062 .39482 .30224 Mtetra
.657 .73 .903 r
.39482 .30224 .40208 .31062 .41426 .30648 .40703 .29806 Mtetra
.658 .73 .903 r
.40703 .29806 .41426 .30648 .4265 .30231 .4193 .29384 Mtetra
.658 .73 .902 r
.4193 .29384 .4265 .30231 .43879 .29809 .43163 .28957 Mtetra
.659 .73 .902 r
.43163 .28957 .43879 .29809 .45115 .29383 .44402 .28527 Mtetra
.66 .73 .901 r
.44402 .28527 .45115 .29383 .46356 .28953 .45646 .28093 Mtetra
.45646 .28093 .46356 .28953 .47602 .28519 .46896 .27654 Mtetra
.661 .73 .901 r
.46896 .27654 .47602 .28519 .48855 .2808 .48153 .27211 Mtetra
.662 .73 .9 r
.48153 .27211 .48855 .2808 .50113 .27637 .49415 .26763 Mtetra
.49415 .26763 .50113 .27637 .51378 .27189 .50682 .26311 Mtetra
.663 .73 .899 r
.50682 .26311 .51378 .27189 .52648 .26737 .51956 .25854 Mtetra
.664 .73 .899 r
.51956 .25854 .52648 .26737 .53924 .2628 .53236 .25393 Mtetra
.665 .73 .899 r
.53236 .25393 .53924 .2628 .55206 .25818 .54521 .24927 Mtetra
.665 .731 .898 r
.54521 .24927 .55206 .25818 .56493 .25352 .55813 .24456 Mtetra
.666 .731 .898 r
.55813 .24456 .56493 .25352 .57787 .2488 .5711 .23981 Mtetra
.667 .731 .898 r
.5711 .23981 .57787 .2488 .59087 .24404 .58414 .235 Mtetra
.667 .731 .897 r
.58414 .235 .59087 .24404 .60392 .23923 .59723 .23015 Mtetra
.668 .732 .897 r
.59723 .23015 .60392 .23923 .61703 .23438 .61039 .22526 Mtetra
.669 .732 .897 r
.61039 .22526 .61703 .23438 .63021 .22947 .6236 .22032 Mtetra
.6236 .22032 .63021 .22947 .64344 .22452 .63687 .21533 Mtetra
.67 .733 .897 r
.63687 .21533 .64344 .22452 .65673 .21953 .6502 .2103 Mtetra
.671 .733 .897 r
.6502 .2103 .65673 .21953 .67008 .21449 .6636 .20523 Mtetra
.6636 .20523 .67008 .21449 .68349 .20941 .67705 .20011 Mtetra
.672 .734 .897 r
.67705 .20011 .68349 .20941 .69696 .20429 .69057 .19496 Mtetra
.69057 .19496 .69696 .20429 .71049 .19913 .70414 .18977 Mtetra
.672 .735 .897 r
.70414 .18977 .71049 .19913 .72409 .19393 .71778 .18454 Mtetra
.673 .735 .897 r
.71778 .18454 .72409 .19393 .73774 .1887 .73148 .17928 Mtetra
.673 .736 .897 r
.73148 .17928 .73774 .1887 .75145 .18344 .74524 .17398 Mtetra
.74524 .17398 .75145 .18344 .76523 .17814 .75906 .16866 Mtetra
.673 .736 .898 r
.75906 .16866 .76523 .17814 .77907 .17281 .77295 .1633 Mtetra
.673 .737 .898 r
.77295 .1633 .77907 .17281 .79297 .16746 .7869 .15792 Mtetra
.653 .736 .91 r
.15431 .37225 .16224 .37973 .17337 .37603 .16546 .36852 Mtetra
.16546 .36852 .17337 .37603 .18454 .37233 .17667 .36477 Mtetra
.17667 .36477 .18454 .37233 .19577 .36862 .18792 .36101 Mtetra
.653 .735 .91 r
.18792 .36101 .19577 .36862 .20705 .36489 .19923 .35724 Mtetra
.19923 .35724 .20705 .36489 .21838 .36114 .21059 .35345 Mtetra
.21059 .35345 .21838 .36114 .22976 .35738 .222 .34965 Mtetra
.653 .734 .909 r
.222 .34965 .22976 .35738 .2412 .35361 .23347 .34582 Mtetra
.23347 .34582 .2412 .35361 .25269 .34981 .24498 .34198 Mtetra
.24498 .34198 .25269 .34981 .26423 .346 .25656 .33812 Mtetra
.653 .733 .908 r
.25656 .33812 .26423 .346 .27582 .34216 .26818 .33423 Mtetra
.26818 .33423 .27582 .34216 .28747 .3383 .27986 .33032 Mtetra
.653 .733 .907 r
.27986 .33032 .28747 .3383 .29918 .33442 .2916 .32639 Mtetra
.654 .732 .907 r
.2916 .32639 .29918 .33442 .31093 .33051 .30339 .32243 Mtetra
.30339 .32243 .31093 .33051 .32275 .32657 .31523 .31844 Mtetra
.654 .732 .906 r
.31523 .31844 .32275 .32657 .33462 .3226 .32713 .31442 Mtetra
.655 .731 .906 r
.32713 .31442 .33462 .3226 .34655 .31859 .33909 .31037 Mtetra
.655 .731 .905 r
.33909 .31037 .34655 .31859 .35853 .31456 .35111 .30628 Mtetra
.656 .731 .905 r
.35111 .30628 .35853 .31456 .37057 .31049 .36318 .30217 Mtetra
.656 .731 .904 r
.36318 .30217 .37057 .31049 .38267 .30638 .37531 .29801 Mtetra
.657 .731 .904 r
.37531 .29801 .38267 .30638 .39482 .30224 .3875 .29382 Mtetra
.657 .731 .903 r
.3875 .29382 .39482 .30224 .40703 .29806 .39974 .28959 Mtetra
.658 .731 .903 r
.39974 .28959 .40703 .29806 .4193 .29384 .41205 .28532 Mtetra
.659 .731 .903 r
.41205 .28532 .4193 .29384 .43163 .28957 .42441 .28102 Mtetra
.659 .73 .902 r
.42441 .28102 .43163 .28957 .44402 .28527 .43683 .27667 Mtetra
.66 .73 .902 r
.43683 .27667 .44402 .28527 .45646 .28093 .44931 .27228 Mtetra
.66 .73 .901 r
.44931 .27228 .45646 .28093 .46896 .27654 .46185 .26784 Mtetra
.661 .731 .901 r
.46185 .26784 .46896 .27654 .48153 .27211 .47444 .26337 Mtetra
.662 .731 .901 r
.47444 .26337 .48153 .27211 .49415 .26763 .4871 .25884 Mtetra
.663 .731 .9 r
.4871 .25884 .49415 .26763 .50682 .26311 .49981 .25428 Mtetra
.49981 .25428 .50682 .26311 .51956 .25854 .51259 .24966 Mtetra
.664 .731 .899 r
.51259 .24966 .51956 .25854 .53236 .25393 .52542 .24501 Mtetra
.665 .731 .899 r
.52542 .24501 .53236 .25393 .54521 .24927 .53832 .2403 Mtetra
.53832 .2403 .54521 .24927 .55813 .24456 .55127 .23555 Mtetra
.666 .731 .898 r
.55127 .23555 .55813 .24456 .5711 .23981 .56428 .23075 Mtetra
.667 .732 .898 r
.56428 .23075 .5711 .23981 .58414 .235 .57736 .22591 Mtetra
.57736 .22591 .58414 .235 .59723 .23015 .59049 .22102 Mtetra
.668 .732 .898 r
.59049 .22102 .59723 .23015 .61039 .22526 .60368 .21608 Mtetra
.669 .732 .897 r
.60368 .21608 .61039 .22526 .6236 .22032 .61694 .2111 Mtetra
.669 .733 .897 r
.61694 .2111 .6236 .22032 .63687 .21533 .63025 .20608 Mtetra
.67 .733 .897 r
.63025 .20608 .63687 .21533 .6502 .2103 .64363 .20101 Mtetra
.64363 .20101 .6502 .2103 .6636 .20523 .65706 .1959 Mtetra
.671 .734 .897 r
.65706 .1959 .6636 .20523 .67705 .20011 .67056 .19075 Mtetra
.67056 .19075 .67705 .20011 .69057 .19496 .68412 .18557 Mtetra
.672 .735 .897 r
.68412 .18557 .69057 .19496 .70414 .18977 .69774 .18034 Mtetra
.69774 .18034 .70414 .18977 .71778 .18454 .71142 .17508 Mtetra
.672 .735 .898 r
.71142 .17508 .71778 .18454 .73148 .17928 .72516 .16979 Mtetra
.673 .736 .898 r
.72516 .16979 .73148 .17928 .74524 .17398 .73897 .16447 Mtetra
.73897 .16447 .74524 .17398 .75906 .16866 .75284 .15911 Mtetra
.673 .737 .898 r
.75284 .15911 .75906 .16866 .77295 .1633 .76678 .15372 Mtetra
.673 .737 .899 r
.76678 .15372 .77295 .1633 .7869 .15792 .78078 .14831 Mtetra
.654 .736 .91 r
.14631 .3647 .15431 .37225 .16546 .36852 .1575 .36093 Mtetra
.653 .736 .91 r
.1575 .36093 .16546 .36852 .17667 .36477 .16873 .35715 Mtetra
.16873 .35715 .17667 .36477 .18792 .36101 .18001 .35335 Mtetra
.653 .735 .91 r
.18001 .35335 .18792 .36101 .19923 .35724 .19135 .34953 Mtetra
.19135 .34953 .19923 .35724 .21059 .35345 .20274 .3457 Mtetra
.653 .735 .909 r
.20274 .3457 .21059 .35345 .222 .34965 .21418 .34185 Mtetra
.21418 .34185 .222 .34965 .23347 .34582 .22567 .33798 Mtetra
.653 .734 .909 r
.22567 .33798 .23347 .34582 .24498 .34198 .23722 .33409 Mtetra
.23722 .33409 .24498 .34198 .25656 .33812 .24882 .33018 Mtetra
.654 .734 .908 r
.24882 .33018 .25656 .33812 .26818 .33423 .26048 .32625 Mtetra
.654 .733 .908 r
.26048 .32625 .26818 .33423 .27986 .33032 .27219 .32229 Mtetra
.27219 .32229 .27986 .33032 .2916 .32639 .28395 .31831 Mtetra
.654 .733 .907 r
.28395 .31831 .2916 .32639 .30339 .32243 .29577 .3143 Mtetra
.29577 .3143 .30339 .32243 .31523 .31844 .30765 .31026 Mtetra
.655 .732 .906 r
.30765 .31026 .31523 .31844 .32713 .31442 .31959 .30619 Mtetra
.31959 .30619 .32713 .31442 .33909 .31037 .33158 .30209 Mtetra
.656 .732 .905 r
.33158 .30209 .33909 .31037 .35111 .30628 .34362 .29796 Mtetra
.34362 .29796 .35111 .30628 .36318 .30217 .35573 .29379 Mtetra
.657 .732 .905 r
.35573 .29379 .36318 .30217 .37531 .29801 .36789 .28959 Mtetra
.657 .731 .904 r
.36789 .28959 .37531 .29801 .3875 .29382 .38011 .28535 Mtetra
.658 .731 .904 r
.38011 .28535 .3875 .29382 .39974 .28959 .39239 .28108 Mtetra
.658 .731 .903 r
.39239 .28108 .39974 .28959 .41205 .28532 .40473 .27676 Mtetra
.659 .731 .903 r
.40473 .27676 .41205 .28532 .42441 .28102 .41713 .27241 Mtetra
.659 .731 .902 r
.41713 .27241 .42441 .28102 .43683 .27667 .42958 .26801 Mtetra
.66 .731 .902 r
.42958 .26801 .43683 .27667 .44931 .27228 .4421 .26357 Mtetra
.661 .731 .902 r
.4421 .26357 .44931 .27228 .46185 .26784 .45467 .25909 Mtetra
.661 .731 .901 r
.45467 .25909 .46185 .26784 .47444 .26337 .4673 .25457 Mtetra
.662 .731 .901 r
.4673 .25457 .47444 .26337 .4871 .25884 .47999 .25 Mtetra
.663 .731 .9 r
.47999 .25 .4871 .25884 .49981 .25428 .49275 .24539 Mtetra
.49275 .24539 .49981 .25428 .51259 .24966 .50556 .24073 Mtetra
.664 .731 .9 r
.50556 .24073 .51259 .24966 .52542 .24501 .51843 .23603 Mtetra
.665 .732 .899 r
.51843 .23603 .52542 .24501 .53832 .2403 .53136 .23128 Mtetra
.666 .732 .899 r
.53136 .23128 .53832 .2403 .55127 .23555 .54435 .22648 Mtetra
.54435 .22648 .55127 .23555 .56428 .23075 .5574 .22164 Mtetra
.667 .732 .898 r
.5574 .22164 .56428 .23075 .57736 .22591 .57052 .21675 Mtetra
.57052 .21675 .57736 .22591 .59049 .22102 .58369 .21182 Mtetra
.668 .733 .898 r
.58369 .21182 .59049 .22102 .60368 .21608 .59692 .20685 Mtetra
.669 .733 .898 r
.59692 .20685 .60368 .21608 .61694 .2111 .61022 .20183 Mtetra
.61022 .20183 .61694 .2111 .63025 .20608 .62357 .19677 Mtetra
.67 .733 .898 r
.62357 .19677 .63025 .20608 .64363 .20101 .63699 .19166 Mtetra
.67 .734 .898 r
.63699 .19166 .64363 .20101 .65706 .1959 .65047 .18652 Mtetra
.671 .734 .898 r
.65047 .18652 .65706 .1959 .67056 .19075 .66401 .18134 Mtetra
.671 .735 .898 r
.66401 .18134 .67056 .19075 .68412 .18557 .67761 .17611 Mtetra
.67761 .17611 .68412 .18557 .69774 .18034 .69128 .17086 Mtetra
.672 .735 .898 r
.69128 .17086 .69774 .18034 .71142 .17508 .705 .16556 Mtetra
.672 .736 .898 r
.705 .16556 .71142 .17508 .72516 .16979 .71879 .16024 Mtetra
.71879 .16024 .72516 .16979 .73897 .16447 .73265 .15488 Mtetra
.672 .737 .898 r
.73265 .15488 .73897 .16447 .75284 .15911 .74657 .14949 Mtetra
.673 .737 .899 r
.74657 .14949 .75284 .15911 .76678 .15372 .76055 .14408 Mtetra
.76055 .14408 .76678 .15372 .78078 .14831 .7746 .13863 Mtetra
.654 .736 .91 r
.13826 .35709 .14631 .3647 .1575 .36093 .14947 .35328 Mtetra
.14947 .35328 .1575 .36093 .16873 .35715 .16073 .34946 Mtetra
.16073 .34946 .16873 .35715 .18001 .35335 .17204 .34561 Mtetra
.654 .735 .91 r
.17204 .34561 .18001 .35335 .19135 .34953 .1834 .34176 Mtetra
.653 .735 .909 r
.1834 .34176 .19135 .34953 .20274 .3457 .19482 .33788 Mtetra
.654 .735 .909 r
.19482 .33788 .20274 .3457 .21418 .34185 .20629 .33399 Mtetra
.20629 .33399 .21418 .34185 .22567 .33798 .21781 .33008 Mtetra
.654 .734 .909 r
.21781 .33008 .22567 .33798 .23722 .33409 .22939 .32614 Mtetra
.654 .734 .908 r
.22939 .32614 .23722 .33409 .24882 .33018 .24102 .32219 Mtetra
.24102 .32219 .24882 .33018 .26048 .32625 .25271 .31821 Mtetra
.25271 .31821 .26048 .32625 .27219 .32229 .26445 .3142 Mtetra
.654 .733 .908 r
.26445 .3142 .27219 .32229 .28395 .31831 .27625 .31017 Mtetra
.655 .733 .907 r
.27625 .31017 .28395 .31831 .29577 .3143 .2881 .30611 Mtetra
.2881 .30611 .29577 .3143 .30765 .31026 .30001 .30203 Mtetra
.655 .733 .906 r
.30001 .30203 .30765 .31026 .31959 .30619 .31197 .29791 Mtetra
.656 .732 .906 r
.31197 .29791 .31959 .30619 .33158 .30209 .324 .29376 Mtetra
.324 .29376 .33158 .30209 .34362 .29796 .33608 .28958 Mtetra
.656 .732 .905 r
.33608 .28958 .34362 .29796 .35573 .29379 .34822 .28537 Mtetra
.657 .732 .905 r
.34822 .28537 .35573 .29379 .36789 .28959 .36041 .28112 Mtetra
.657 .732 .904 r
.36041 .28112 .36789 .28959 .38011 .28535 .37267 .27683 Mtetra
.658 .732 .904 r
.37267 .27683 .38011 .28535 .39239 .28108 .38498 .2725 Mtetra
.659 .732 .903 r
.38498 .2725 .39239 .28108 .40473 .27676 .39735 .26814 Mtetra
.39735 .26814 .40473 .27676 .41713 .27241 .40978 .26374 Mtetra
.66 .732 .903 r
.40978 .26374 .41713 .27241 .42958 .26801 .42227 .25929 Mtetra
.66 .732 .902 r
.42227 .25929 .42958 .26801 .4421 .26357 .43482 .25481 Mtetra
.661 .732 .902 r
.43482 .25481 .4421 .26357 .45467 .25909 .44743 .25028 Mtetra
.662 .732 .901 r
.44743 .25028 .45467 .25909 .4673 .25457 .4601 .24571 Mtetra
.4601 .24571 .4673 .25457 .47999 .25 .47283 .24109 Mtetra
.663 .732 .901 r
.47283 .24109 .47999 .25 .49275 .24539 .48562 .23644 Mtetra
.664 .732 .9 r
.48562 .23644 .49275 .24539 .50556 .24073 .49847 .23173 Mtetra
.49847 .23173 .50556 .24073 .51843 .23603 .51138 .22698 Mtetra
.665 .732 .9 r
.51138 .22698 .51843 .23603 .53136 .23128 .52435 .22219 Mtetra
.666 .732 .899 r
.52435 .22219 .53136 .23128 .54435 .22648 .53738 .21735 Mtetra
.53738 .21735 .54435 .22648 .5574 .22164 .55047 .21247 Mtetra
.667 .732 .899 r
.55047 .21247 .5574 .22164 .57052 .21675 .56362 .20754 Mtetra
.667 .733 .899 r
.56362 .20754 .57052 .21675 .58369 .21182 .57683 .20257 Mtetra
.668 .733 .898 r
.57683 .20257 .58369 .21182 .59692 .20685 .59011 .19755 Mtetra
.669 .733 .898 r
.59011 .19755 .59692 .20685 .61022 .20183 .60344 .19249 Mtetra
.669 .734 .898 r
.60344 .19249 .61022 .20183 .62357 .19677 .61684 .18739 Mtetra
.67 .734 .898 r
.61684 .18739 .62357 .19677 .63699 .19166 .6303 .18225 Mtetra
.6303 .18225 .63699 .19166 .65047 .18652 .64382 .17707 Mtetra
.671 .735 .898 r
.64382 .17707 .65047 .18652 .66401 .18134 .6574 .17185 Mtetra
.6574 .17185 .66401 .18134 .67761 .17611 .67105 .1666 Mtetra
.67105 .1666 .67761 .17611 .69128 .17086 .68476 .1613 Mtetra
.672 .736 .898 r
.68476 .1613 .69128 .17086 .705 .16556 .69853 .15598 Mtetra
.69853 .15598 .705 .16556 .71879 .16024 .71237 .15062 Mtetra
.672 .736 .899 r
.71237 .15062 .71879 .16024 .73265 .15488 .72627 .14523 Mtetra
.672 .737 .899 r
.72627 .14523 .73265 .15488 .74657 .14949 .74024 .13981 Mtetra
.74024 .13981 .74657 .14949 .76055 .14408 .75427 .13436 Mtetra
.672 .738 .899 r
.75427 .13436 .76055 .14408 .7746 .13863 .76837 .12888 Mtetra
.654 .736 .91 r
.13014 .34941 .13826 .35709 .14947 .35328 .14137 .34556 Mtetra
.14137 .34556 .14947 .35328 .16073 .34946 .15266 .3417 Mtetra
.15266 .3417 .16073 .34946 .17204 .34561 .164 .33781 Mtetra
.654 .735 .909 r
.164 .33781 .17204 .34561 .1834 .34176 .1754 .33391 Mtetra
.1754 .33391 .1834 .34176 .19482 .33788 .18684 .33 Mtetra
.18684 .33 .19482 .33788 .20629 .33399 .19834 .32606 Mtetra
.19834 .32606 .20629 .33399 .21781 .33008 .20989 .3221 Mtetra
.654 .734 .909 r
.20989 .3221 .21781 .33008 .22939 .32614 .2215 .31812 Mtetra
.654 .734 .908 r
.2215 .31812 .22939 .32614 .24102 .32219 .23316 .31412 Mtetra
.23316 .31412 .24102 .32219 .25271 .31821 .24488 .3101 Mtetra
.24488 .3101 .25271 .31821 .26445 .3142 .25665 .30605 Mtetra
.655 .733 .907 r
.25665 .30605 .26445 .3142 .27625 .31017 .26848 .30197 Mtetra
.26848 .30197 .27625 .31017 .2881 .30611 .28036 .29786 Mtetra
.28036 .29786 .2881 .30611 .30001 .30203 .2923 .29373 Mtetra
.656 .733 .906 r
.2923 .29373 .30001 .30203 .31197 .29791 .3043 .28957 Mtetra
.3043 .28957 .31197 .29791 .324 .29376 .31636 .28537 Mtetra
.31636 .28537 .324 .29376 .33608 .28958 .32847 .28114 Mtetra
.657 .732 .905 r
.32847 .28114 .33608 .28958 .34822 .28537 .34064 .27688 Mtetra
.34064 .27688 .34822 .28537 .36041 .28112 .35287 .27258 Mtetra
.658 .732 .904 r
.35287 .27258 .36041 .28112 .37267 .27683 .36516 .26824 Mtetra
.36516 .26824 .37267 .27683 .38498 .2725 .3775 .26387 Mtetra
.659 .732 .904 r
.3775 .26387 .38498 .2725 .39735 .26814 .38991 .25946 Mtetra
.659 .732 .903 r
.38991 .25946 .39735 .26814 .40978 .26374 .40238 .25501 Mtetra
.66 .732 .903 r
.40238 .25501 .40978 .26374 .42227 .25929 .4149 .25052 Mtetra
.661 .732 .902 r
.4149 .25052 .42227 .25929 .43482 .25481 .42749 .24598 Mtetra
.42749 .24598 .43482 .25481 .44743 .25028 .44013 .24141 Mtetra
.662 .732 .902 r
.44013 .24141 .44743 .25028 .4601 .24571 .45284 .23679 Mtetra
.663 .732 .901 r
.45284 .23679 .4601 .24571 .47283 .24109 .4656 .23213 Mtetra
.4656 .23213 .47283 .24109 .48562 .23644 .47843 .22742 Mtetra
.664 .732 .9 r
.47843 .22742 .48562 .23644 .49847 .23173 .49131 .22267 Mtetra
.49131 .22267 .49847 .23173 .51138 .22698 .50426 .21788 Mtetra
.665 .732 .9 r
.50426 .21788 .51138 .22698 .52435 .22219 .51727 .21304 Mtetra
.666 .732 .9 r
.51727 .21304 .52435 .22219 .53738 .21735 .53034 .20816 Mtetra
.666 .733 .899 r
.53034 .20816 .53738 .21735 .55047 .21247 .54347 .20323 Mtetra
.667 .733 .899 r
.54347 .20323 .55047 .21247 .56362 .20754 .55666 .19826 Mtetra
.55666 .19826 .56362 .20754 .57683 .20257 .56992 .19325 Mtetra
.668 .733 .899 r
.56992 .19325 .57683 .20257 .59011 .19755 .58323 .18819 Mtetra
.669 .734 .899 r
.58323 .18819 .59011 .19755 .60344 .19249 .59661 .18309 Mtetra
.59661 .18309 .60344 .19249 .61684 .18739 .61005 .17796 Mtetra
.67 .734 .898 r
.61005 .17796 .61684 .18739 .6303 .18225 .62355 .17278 Mtetra
.67 .735 .898 r
.62355 .17278 .6303 .18225 .64382 .17707 .63712 .16756 Mtetra
.63712 .16756 .64382 .17707 .6574 .17185 .65074 .1623 Mtetra
.671 .735 .899 r
.65074 .1623 .6574 .17185 .67105 .1666 .66443 .15701 Mtetra
.671 .736 .899 r
.66443 .15701 .67105 .1666 .68476 .1613 .67819 .15168 Mtetra
.67819 .15168 .68476 .1613 .69853 .15598 .69201 .14632 Mtetra
.69201 .14632 .69853 .15598 .71237 .15062 .70589 .14093 Mtetra
.672 .737 .899 r
.70589 .14093 .71237 .15062 .72627 .14523 .71984 .1355 Mtetra
.71984 .1355 .72627 .14523 .74024 .13981 .73385 .13005 Mtetra
.73385 .13005 .74024 .13981 .75427 .13436 .74793 .12457 Mtetra
.672 .738 .9 r
.74793 .12457 .75427 .13436 .76837 .12888 .76208 .11906 Mtetra
.654 .736 .91 r
.12195 .34167 .13014 .34941 .14137 .34556 .13322 .33777 Mtetra
.654 .736 .909 r
.13322 .33777 .14137 .34556 .15266 .3417 .14453 .33387 Mtetra
.654 .735 .909 r
.14453 .33387 .15266 .3417 .164 .33781 .1559 .32994 Mtetra
.1559 .32994 .164 .33781 .1754 .33391 .16732 .326 Mtetra
.16732 .326 .1754 .33391 .18684 .33 .1788 .32204 Mtetra
.1788 .32204 .18684 .33 .19834 .32606 .19032 .31806 Mtetra
.19032 .31806 .19834 .32606 .20989 .3221 .20191 .31406 Mtetra
.654 .734 .908 r
.20191 .31406 .20989 .3221 .2215 .31812 .21354 .31003 Mtetra
.21354 .31003 .2215 .31812 .23316 .31412 .22524 .30599 Mtetra
.655 .734 .908 r
.22524 .30599 .23316 .31412 .24488 .3101 .23698 .30192 Mtetra
.23698 .30192 .24488 .3101 .25665 .30605 .24879 .29782 Mtetra
.655 .734 .907 r
.24879 .29782 .25665 .30605 .26848 .30197 .26064 .2937 Mtetra
.655 .733 .907 r
.26064 .2937 .26848 .30197 .28036 .29786 .27256 .28954 Mtetra
.656 .733 .907 r
.27256 .28954 .28036 .29786 .2923 .29373 .28453 .28536 Mtetra
.656 .733 .906 r
.28453 .28536 .2923 .29373 .3043 .28957 .29656 .28115 Mtetra
.29656 .28115 .3043 .28957 .31636 .28537 .30865 .27691 Mtetra
.657 .733 .905 r
.30865 .27691 .31636 .28537 .32847 .28114 .3208 .27263 Mtetra
.3208 .27263 .32847 .28114 .34064 .27688 .333 .26832 Mtetra
.658 .732 .905 r
.333 .26832 .34064 .27688 .35287 .27258 .34526 .26397 Mtetra
.658 .732 .904 r
.34526 .26397 .35287 .27258 .36516 .26824 .35759 .25959 Mtetra
.659 .732 .904 r
.35759 .25959 .36516 .26824 .3775 .26387 .36997 .25517 Mtetra
.36997 .25517 .3775 .26387 .38991 .25946 .38241 .25071 Mtetra
.66 .732 .903 r
.38241 .25071 .38991 .25946 .40238 .25501 .39491 .24621 Mtetra
.39491 .24621 .40238 .25501 .4149 .25052 .40747 .24167 Mtetra
.661 .732 .902 r
.40747 .24167 .4149 .25052 .42749 .24598 .42009 .23709 Mtetra
.42009 .23709 .42749 .24598 .44013 .24141 .43277 .23247 Mtetra
.662 .732 .902 r
.43277 .23247 .44013 .24141 .45284 .23679 .44551 .2278 Mtetra
.663 .732 .901 r
.44551 .2278 .45284 .23679 .4656 .23213 .45831 .22309 Mtetra
.45831 .22309 .4656 .23213 .47843 .22742 .47118 .21834 Mtetra
.664 .732 .901 r
.47118 .21834 .47843 .22742 .49131 .22267 .4841 .21355 Mtetra
.665 .732 .9 r
.4841 .21355 .49131 .22267 .50426 .21788 .49709 .20871 Mtetra
.665 .733 .9 r
.49709 .20871 .50426 .21788 .51727 .21304 .51014 .20383 Mtetra
.666 .733 .9 r
.51014 .20383 .51727 .21304 .53034 .20816 .52324 .1989 Mtetra
.52324 .1989 .53034 .20816 .54347 .20323 .53641 .19393 Mtetra
.667 .733 .899 r
.53641 .19393 .54347 .20323 .55666 .19826 .54965 .18892 Mtetra
.54965 .18892 .55666 .19826 .56992 .19325 .56294 .18386 Mtetra
.668 .734 .899 r
.56294 .18386 .56992 .19325 .58323 .18819 .5763 .17877 Mtetra
.5763 .17877 .58323 .18819 .59661 .18309 .58972 .17363 Mtetra
.669 .734 .899 r
.58972 .17363 .59661 .18309 .61005 .17796 .6032 .16845 Mtetra
.669 .735 .899 r
.6032 .16845 .61005 .17796 .62355 .17278 .61674 .16323 Mtetra
.67 .735 .899 r
.61674 .16323 .62355 .17278 .63712 .16756 .63035 .15798 Mtetra
.63035 .15798 .63712 .16756 .65074 .1623 .64402 .15269 Mtetra
.67 .736 .899 r
.64402 .15269 .65074 .1623 .66443 .15701 .65776 .14736 Mtetra
.671 .736 .899 r
.65776 .14736 .66443 .15701 .67819 .15168 .67156 .14199 Mtetra
.67156 .14199 .67819 .15168 .69201 .14632 .68543 .1366 Mtetra
.671 .737 .899 r
.68543 .1366 .69201 .14632 .70589 .14093 .69936 .13117 Mtetra
.69936 .13117 .70589 .14093 .71984 .1355 .71335 .12571 Mtetra
.672 .737 .9 r
.71335 .12571 .71984 .1355 .73385 .13005 .72741 .12022 Mtetra
.672 .738 .9 r
.72741 .12022 .73385 .13005 .74793 .12457 .74154 .1147 Mtetra
.74154 .1147 .74793 .12457 .76208 .11906 .75574 .10916 Mtetra
.654 .736 .909 r
.1137 .33385 .12195 .34167 .13322 .33777 .12499 .32992 Mtetra
.12499 .32992 .13322 .33777 .14453 .33387 .13634 .32597 Mtetra
.654 .735 .909 r
.13634 .32597 .14453 .33387 .1559 .32994 .14773 .322 Mtetra
.14773 .322 .1559 .32994 .16732 .326 .15918 .31802 Mtetra
.15918 .31802 .16732 .326 .1788 .32204 .17069 .31401 Mtetra
.17069 .31401 .1788 .32204 .19032 .31806 .18224 .30999 Mtetra
.654 .735 .908 r
.18224 .30999 .19032 .31806 .20191 .31406 .19386 .30594 Mtetra
.655 .734 .908 r
.19386 .30594 .20191 .31406 .21354 .31003 .20552 .30187 Mtetra
.20552 .30187 .21354 .31003 .22524 .30599 .21724 .29778 Mtetra
.21724 .29778 .22524 .30599 .23698 .30192 .22902 .29367 Mtetra
.655 .734 .907 r
.22902 .29367 .23698 .30192 .24879 .29782 .24086 .28952 Mtetra
.24086 .28952 .24879 .29782 .26064 .2937 .25275 .28535 Mtetra
.656 .733 .907 r
.25275 .28535 .26064 .2937 .27256 .28954 .26469 .28115 Mtetra
.656 .733 .906 r
.26469 .28115 .27256 .28954 .28453 .28536 .2767 .27693 Mtetra
.2767 .27693 .28453 .28536 .29656 .28115 .28876 .27267 Mtetra
.657 .733 .906 r
.28876 .27267 .29656 .28115 .30865 .27691 .30088 .26838 Mtetra
.657 .733 .905 r
.30088 .26838 .30865 .27691 .3208 .27263 .31306 .26405 Mtetra
.31306 .26405 .3208 .27263 .333 .26832 .3253 .25969 Mtetra
.658 .733 .905 r
.3253 .25969 .333 .26832 .34526 .26397 .33759 .2553 Mtetra
.658 .732 .904 r
.33759 .2553 .34526 .26397 .35759 .25959 .34995 .25087 Mtetra
.659 .732 .904 r
.34995 .25087 .35759 .25959 .36997 .25517 .36237 .2464 Mtetra
.36237 .2464 .36997 .25517 .38241 .25071 .37484 .24189 Mtetra
.66 .732 .903 r
.37484 .24189 .38241 .25071 .39491 .24621 .38738 .23734 Mtetra
.661 .732 .903 r
.38738 .23734 .39491 .24621 .40747 .24167 .39997 .23275 Mtetra
.661 .732 .902 r
.39997 .23275 .40747 .24167 .42009 .23709 .41263 .22813 Mtetra
.662 .732 .902 r
.41263 .22813 .42009 .23709 .43277 .23247 .42535 .22346 Mtetra
.42535 .22346 .43277 .23247 .44551 .2278 .43813 .21874 Mtetra
.663 .732 .901 r
.43813 .21874 .44551 .2278 .45831 .22309 .45097 .21399 Mtetra
.663 .733 .901 r
.45097 .21399 .45831 .22309 .47118 .21834 .46387 .20919 Mtetra
.664 .733 .901 r
.46387 .20919 .47118 .21834 .4841 .21355 .47683 .20435 Mtetra
.665 .733 .9 r
.47683 .20435 .4841 .21355 .49709 .20871 .48985 .19947 Mtetra
.48985 .19947 .49709 .20871 .51014 .20383 .50294 .19454 Mtetra
.666 .733 .9 r
.50294 .19454 .51014 .20383 .52324 .1989 .51609 .18957 Mtetra
.51609 .18957 .52324 .1989 .53641 .19393 .5293 .18456 Mtetra
.667 .733 .9 r
.5293 .18456 .53641 .19393 .54965 .18892 .54257 .17951 Mtetra
.667 .734 .899 r
.54257 .17951 .54965 .18892 .56294 .18386 .55591 .17441 Mtetra
.668 .734 .899 r
.55591 .17441 .56294 .18386 .5763 .17877 .5693 .16927 Mtetra
.5693 .16927 .5763 .17877 .58972 .17363 .58276 .16409 Mtetra
.669 .735 .899 r
.58276 .16409 .58972 .17363 .6032 .16845 .59629 .15888 Mtetra
.59629 .15888 .6032 .16845 .61674 .16323 .60988 .15362 Mtetra
.67 .735 .899 r
.60988 .15362 .61674 .16323 .63035 .15798 .62353 .14833 Mtetra
.62353 .14833 .63035 .15798 .64402 .15269 .63725 .143 Mtetra
.67 .736 .899 r
.63725 .143 .64402 .15269 .65776 .14736 .65103 .13763 Mtetra
.671 .736 .899 r
.65103 .13763 .65776 .14736 .67156 .14199 .66487 .13223 Mtetra
.66487 .13223 .67156 .14199 .68543 .1366 .67878 .1268 Mtetra
.671 .737 .9 r
.67878 .1268 .68543 .1366 .69936 .13117 .69276 .12133 Mtetra
.69276 .12133 .69936 .13117 .71335 .12571 .70681 .11583 Mtetra
.70681 .11583 .71335 .12571 .72741 .12022 .72092 .11031 Mtetra
.671 .738 .9 r
.72092 .11031 .72741 .12022 .74154 .1147 .73509 .10476 Mtetra
.73509 .10476 .74154 .1147 .75574 .10916 .74934 .09918 Mtetra
.655 .736 .909 r
.10538 .32597 .1137 .33385 .12499 .32992 .1167 .32199 Mtetra
.1167 .32199 .12499 .32992 .13634 .32597 .12807 .318 Mtetra
.655 .735 .909 r
.12807 .318 .13634 .32597 .14773 .322 .1395 .31399 Mtetra
.1395 .31399 .14773 .322 .15918 .31802 .15098 .30996 Mtetra
.15098 .30996 .15918 .31802 .17069 .31401 .16251 .30591 Mtetra
.655 .735 .908 r
.16251 .30591 .17069 .31401 .18224 .30999 .1741 .30185 Mtetra
.655 .734 .908 r
.1741 .30185 .18224 .30999 .19386 .30594 .18574 .29776 Mtetra
.18574 .29776 .19386 .30594 .20552 .30187 .19744 .29364 Mtetra
.19744 .29364 .20552 .30187 .21724 .29778 .20919 .28951 Mtetra
.655 .734 .907 r
.20919 .28951 .21724 .29778 .22902 .29367 .221 .28534 Mtetra
.221 .28534 .22902 .29367 .24086 .28952 .23286 .28115 Mtetra
.656 .734 .907 r
.23286 .28115 .24086 .28952 .25275 .28535 .24478 .27694 Mtetra
.656 .733 .907 r
.24478 .27694 .25275 .28535 .26469 .28115 .25676 .27269 Mtetra
.656 .733 .906 r
.25676 .27269 .26469 .28115 .2767 .27693 .2688 .26842 Mtetra
.657 .733 .906 r
.2688 .26842 .2767 .27693 .28876 .27267 .28089 .26411 Mtetra
.28089 .26411 .28876 .27267 .30088 .26838 .29305 .25977 Mtetra
.657 .733 .905 r
.29305 .25977 .30088 .26838 .31306 .26405 .30526 .2554 Mtetra
.658 .733 .905 r
.30526 .2554 .31306 .26405 .3253 .25969 .31753 .25099 Mtetra
.31753 .25099 .3253 .25969 .33759 .2553 .32986 .24655 Mtetra
.659 .733 .904 r
.32986 .24655 .33759 .2553 .34995 .25087 .34225 .24207 Mtetra
.34225 .24207 .34995 .25087 .36237 .2464 .3547 .23755 Mtetra
.66 .733 .903 r
.3547 .23755 .36237 .2464 .37484 .24189 .36721 .233 Mtetra
.66 .732 .903 r
.36721 .233 .37484 .24189 .38738 .23734 .37978 .2284 Mtetra
.661 .732 .903 r
.37978 .2284 .38738 .23734 .39997 .23275 .39241 .22377 Mtetra
.661 .732 .902 r
.39241 .22377 .39997 .23275 .41263 .22813 .40511 .21909 Mtetra
.662 .733 .902 r
.40511 .21909 .41263 .22813 .42535 .22346 .41786 .21438 Mtetra
.41786 .21438 .42535 .22346 .43813 .21874 .43068 .20962 Mtetra
.663 .733 .901 r
.43068 .20962 .43813 .21874 .45097 .21399 .44355 .20482 Mtetra
.664 .733 .901 r
.44355 .20482 .45097 .21399 .46387 .20919 .45649 .19997 Mtetra
.45649 .19997 .46387 .20919 .47683 .20435 .46949 .19509 Mtetra
.665 .733 .901 r
.46949 .19509 .47683 .20435 .48985 .19947 .48256 .19016 Mtetra
.665 .733 .9 r
.48256 .19016 .48985 .19947 .50294 .19454 .49568 .18519 Mtetra
.666 .733 .9 r
.49568 .18519 .50294 .19454 .51609 .18957 .50887 .18018 Mtetra
.666 .734 .9 r
.50887 .18018 .51609 .18957 .5293 .18456 .52212 .17512 Mtetra
.667 .734 .9 r
.52212 .17512 .5293 .18456 .54257 .17951 .53543 .17002 Mtetra
.53543 .17002 .54257 .17951 .55591 .17441 .54881 .16489 Mtetra
.668 .734 .9 r
.54881 .16489 .55591 .17441 .5693 .16927 .56225 .15971 Mtetra
.56225 .15971 .5693 .16927 .58276 .16409 .57575 .15449 Mtetra
.669 .735 .899 r
.57575 .15449 .58276 .16409 .59629 .15888 .58932 .14923 Mtetra
.58932 .14923 .59629 .15888 .60988 .15362 .60295 .14394 Mtetra
.60295 .14394 .60988 .15362 .62353 .14833 .61665 .1386 Mtetra
.67 .736 .899 r
.61665 .1386 .62353 .14833 .63725 .143 .63041 .13323 Mtetra
.67 .736 .9 r
.63041 .13323 .63725 .143 .65103 .13763 .64424 .12783 Mtetra
.64424 .12783 .65103 .13763 .66487 .13223 .65813 .12239 Mtetra
.67 .737 .9 r
.65813 .12239 .66487 .13223 .67878 .1268 .67209 .11692 Mtetra
.671 .737 .9 r
.67209 .11692 .67878 .1268 .69276 .12133 .68611 .11142 Mtetra
.68611 .11142 .69276 .12133 .70681 .11583 .7002 .10588 Mtetra
.671 .738 .9 r
.7002 .10588 .70681 .11583 .72092 .11031 .71436 .10032 Mtetra
.71436 .10032 .72092 .11031 .73509 .10476 .72859 .09473 Mtetra
.671 .738 .901 r
.72859 .09473 .73509 .10476 .74934 .09918 .74288 .08911 Mtetra
.655 .736 .909 r
.097 .31801 .10538 .32597 .1167 .32199 .10834 .31399 Mtetra
.655 .735 .909 r
.10834 .31399 .1167 .32199 .12807 .318 .11974 .30996 Mtetra
.11974 .30996 .12807 .318 .1395 .31399 .1312 .30591 Mtetra
.655 .735 .908 r
.1312 .30591 .1395 .31399 .15098 .30996 .14271 .30183 Mtetra
.14271 .30183 .15098 .30996 .16251 .30591 .15427 .29774 Mtetra
.15427 .29774 .16251 .30591 .1741 .30185 .16588 .29363 Mtetra
.655 .734 .908 r
.16588 .29363 .1741 .30185 .18574 .29776 .17756 .2895 Mtetra
.17756 .2895 .18574 .29776 .19744 .29364 .18928 .28534 Mtetra
.655 .734 .907 r
.18928 .28534 .19744 .29364 .20919 .28951 .20107 .28115 Mtetra
.20107 .28115 .20919 .28951 .221 .28534 .2129 .27695 Mtetra
.656 .734 .907 r
.2129 .27695 .221 .28534 .23286 .28115 .2248 .27271 Mtetra
.2248 .27271 .23286 .28115 .24478 .27694 .23675 .26845 Mtetra
.656 .733 .906 r
.23675 .26845 .24478 .27694 .25676 .27269 .24876 .26416 Mtetra
.657 .733 .906 r
.24876 .26416 .25676 .27269 .2688 .26842 .26083 .25983 Mtetra
.26083 .25983 .2688 .26842 .28089 .26411 .27296 .25548 Mtetra
.657 .733 .905 r
.27296 .25548 .28089 .26411 .29305 .25977 .28515 .25109 Mtetra
.658 .733 .905 r
.28515 .25109 .29305 .25977 .30526 .2554 .29739 .24667 Mtetra
.29739 .24667 .30526 .2554 .31753 .25099 .3097 .24222 Mtetra
.658 .733 .904 r
.3097 .24222 .31753 .25099 .32986 .24655 .32206 .23773 Mtetra
.659 .733 .904 r
.32206 .23773 .32986 .24655 .34225 .24207 .33449 .2332 Mtetra
.33449 .2332 .34225 .24207 .3547 .23755 .34697 .22864 Mtetra
.66 .733 .903 r
.34697 .22864 .3547 .23755 .36721 .233 .35952 .22403 Mtetra
.35952 .22403 .36721 .233 .37978 .2284 .37212 .21939 Mtetra
.661 .733 .903 r
.37212 .21939 .37978 .2284 .39241 .22377 .38479 .21471 Mtetra
.661 .733 .902 r
.38479 .21471 .39241 .22377 .40511 .21909 .39752 .20999 Mtetra
.662 .733 .902 r
.39752 .20999 .40511 .21909 .41786 .21438 .41031 .20522 Mtetra
.663 .733 .902 r
.41031 .20522 .41786 .21438 .43068 .20962 .42316 .20042 Mtetra
.42316 .20042 .43068 .20962 .44355 .20482 .43608 .19557 Mtetra
.664 .733 .901 r
.43608 .19557 .44355 .20482 .45649 .19997 .44905 .19068 Mtetra
.44905 .19068 .45649 .19997 .46949 .19509 .46209 .18575 Mtetra
.665 .733 .901 r
.46209 .18575 .46949 .19509 .48256 .19016 .47519 .18078 Mtetra
.47519 .18078 .48256 .19016 .49568 .18519 .48836 .17576 Mtetra
.666 .734 .9 r
.48836 .17576 .49568 .18519 .50887 .18018 .50159 .17071 Mtetra
.50159 .17071 .50887 .18018 .52212 .17512 .51488 .16561 Mtetra
.667 .734 .9 r
.51488 .16561 .52212 .17512 .53543 .17002 .52823 .16047 Mtetra
.52823 .16047 .53543 .17002 .54881 .16489 .54165 .15529 Mtetra
.668 .734 .9 r
.54165 .15529 .54881 .16489 .56225 .15971 .55513 .15007 Mtetra
.668 .735 .9 r
.55513 .15007 .56225 .15971 .57575 .15449 .56868 .14481 Mtetra
.669 .735 .9 r
.56868 .14481 .57575 .15449 .58932 .14923 .58229 .13951 Mtetra
.58229 .13951 .58932 .14923 .60295 .14394 .59596 .13417 Mtetra
.669 .736 .9 r
.59596 .13417 .60295 .14394 .61665 .1386 .6097 .1288 Mtetra
.67 .736 .9 r
.6097 .1288 .61665 .1386 .63041 .13323 .62351 .12339 Mtetra
.62351 .12339 .63041 .13323 .64424 .12783 .63738 .11795 Mtetra
.63738 .11795 .64424 .12783 .65813 .12239 .65132 .11247 Mtetra
.67 .737 .9 r
.65132 .11247 .65813 .12239 .67209 .11692 .66533 .10697 Mtetra
.66533 .10697 .67209 .11692 .68611 .11142 .6794 .10142 Mtetra
.671 .737 .9 r
.6794 .10142 .68611 .11142 .7002 .10588 .69354 .09585 Mtetra
.671 .738 .901 r
.69354 .09585 .7002 .10588 .71436 .10032 .70775 .09025 Mtetra
.70775 .09025 .71436 .10032 .72859 .09473 .72202 .08462 Mtetra
.72202 .08462 .72859 .09473 .74288 .08911 .73637 .07897 Mtetra
.655 .736 .909 r
.08854 .30998 .097 .31801 .10834 .31399 .09992 .30592 Mtetra
.655 .735 .909 r
.09992 .30592 .10834 .31399 .11974 .30996 .11135 .30185 Mtetra
.655 .735 .908 r
.11135 .30185 .11974 .30996 .1312 .30591 .12283 .29775 Mtetra
.12283 .29775 .1312 .30591 .14271 .30183 .13437 .29364 Mtetra
.13437 .29364 .14271 .30183 .15427 .29774 .14596 .2895 Mtetra
.14596 .2895 .15427 .29774 .16588 .29363 .1576 .28534 Mtetra
.655 .734 .908 r
.1576 .28534 .16588 .29363 .17756 .2895 .1693 .28116 Mtetra
.655 .734 .907 r
.1693 .28116 .17756 .2895 .18928 .28534 .18106 .27696 Mtetra
.656 .734 .907 r
.18106 .27696 .18928 .28534 .20107 .28115 .19287 .27273 Mtetra
.19287 .27273 .20107 .28115 .2129 .27695 .20474 .26847 Mtetra
.20474 .26847 .2129 .27695 .2248 .27271 .21667 .26419 Mtetra
.656 .734 .906 r
.21667 .26419 .2248 .27271 .23675 .26845 .22866 .25988 Mtetra
.656 .733 .906 r
.22866 .25988 .23675 .26845 .24876 .26416 .2407 .25554 Mtetra
.657 .733 .906 r
.2407 .25554 .24876 .26416 .26083 .25983 .2528 .25117 Mtetra
.2528 .25117 .26083 .25983 .27296 .25548 .26496 .24677 Mtetra
.657 .733 .905 r
.26496 .24677 .27296 .25548 .28515 .25109 .27718 .24234 Mtetra
.658 .733 .905 r
.27718 .24234 .28515 .25109 .29739 .24667 .28946 .23787 Mtetra
.28946 .23787 .29739 .24667 .3097 .24222 .3018 .23337 Mtetra
.659 .733 .904 r
.3018 .23337 .3097 .24222 .32206 .23773 .3142 .22883 Mtetra
.3142 .22883 .32206 .23773 .33449 .2332 .32665 .22426 Mtetra
.66 .733 .904 r
.32665 .22426 .33449 .2332 .34697 .22864 .33917 .21964 Mtetra
.66 .733 .903 r
.33917 .21964 .34697 .22864 .35952 .22403 .35175 .21499 Mtetra
.661 .733 .903 r
.35175 .21499 .35952 .22403 .37212 .21939 .3644 .2103 Mtetra
.3644 .2103 .37212 .21939 .38479 .21471 .3771 .20557 Mtetra
.662 .733 .902 r
.3771 .20557 .38479 .21471 .39752 .20999 .38987 .2008 Mtetra
.38987 .2008 .39752 .20999 .41031 .20522 .40269 .19599 Mtetra
.663 .733 .902 r
.40269 .19599 .41031 .20522 .42316 .20042 .41558 .19114 Mtetra
.41558 .19114 .42316 .20042 .43608 .19557 .42854 .18625 Mtetra
.664 .733 .901 r
.42854 .18625 .43608 .19557 .44905 .19068 .44155 .18132 Mtetra
.44155 .18132 .44905 .19068 .46209 .18575 .45463 .17634 Mtetra
.665 .733 .901 r
.45463 .17634 .46209 .18575 .47519 .18078 .46777 .17132 Mtetra
.665 .734 .901 r
.46777 .17132 .47519 .18078 .48836 .17576 .48097 .16626 Mtetra
.666 .734 .901 r
.48097 .16626 .48836 .17576 .50159 .17071 .49424 .16116 Mtetra
.666 .734 .9 r
.49424 .16116 .50159 .17071 .51488 .16561 .50757 .15602 Mtetra
.667 .734 .9 r
.50757 .15602 .51488 .16561 .52823 .16047 .52097 .15084 Mtetra
.52097 .15084 .52823 .16047 .54165 .15529 .53443 .14562 Mtetra
.668 .735 .9 r
.53443 .14562 .54165 .15529 .55513 .15007 .54795 .14035 Mtetra
.54795 .14035 .55513 .15007 .56868 .14481 .56154 .13505 Mtetra
.56154 .13505 .56868 .14481 .58229 .13951 .57519 .12971 Mtetra
.669 .735 .9 r
.57519 .12971 .58229 .13951 .59596 .13417 .58891 .12434 Mtetra
.669 .736 .9 r
.58891 .12434 .59596 .13417 .6097 .1288 .6027 .11893 Mtetra
.6027 .11893 .6097 .1288 .62351 .12339 .61655 .11348 Mtetra
.67 .736 .9 r
.61655 .11348 .62351 .12339 .63738 .11795 .63047 .10799 Mtetra
.67 .737 .9 r
.63047 .10799 .63738 .11795 .65132 .11247 .64445 .10248 Mtetra
.64445 .10248 .65132 .11247 .66533 .10697 .65851 .09693 Mtetra
.65851 .09693 .66533 .10697 .6794 .10142 .67263 .09135 Mtetra
.67 .738 .901 r
.67263 .09135 .6794 .10142 .69354 .09585 .68681 .08574 Mtetra
.68681 .08574 .69354 .09585 .70775 .09025 .70107 .0801 Mtetra
.70107 .0801 .70775 .09025 .72202 .08462 .7154 .07443 Mtetra
.7154 .07443 .72202 .08462 .73637 .07897 .72979 .06873 Mtetra
.655 .736 .908 r
.08002 .30189 .08854 .30998 .09992 .30592 .09142 .29778 Mtetra
.655 .735 .908 r
.09142 .29778 .09992 .30592 .11135 .30185 .10288 .29366 Mtetra
.10288 .29366 .11135 .30185 .12283 .29775 .11439 .28952 Mtetra
.11439 .28952 .12283 .29775 .13437 .29364 .12596 .28536 Mtetra
.12596 .28536 .13437 .29364 .14596 .2895 .13758 .28118 Mtetra
.655 .734 .908 r
.13758 .28118 .14596 .2895 .1576 .28534 .14925 .27698 Mtetra
.656 .734 .907 r
.14925 .27698 .1576 .28534 .1693 .28116 .16098 .27275 Mtetra
.16098 .27275 .1693 .28116 .18106 .27696 .17277 .2685 Mtetra
.17277 .2685 .18106 .27696 .19287 .27273 .18462 .26423 Mtetra
.18462 .26423 .19287 .27273 .20474 .26847 .19652 .25993 Mtetra
.19652 .25993 .20474 .26847 .21667 .26419 .20848 .2556 Mtetra
.656 .733 .906 r
.20848 .2556 .21667 .26419 .22866 .25988 .22049 .25124 Mtetra
.657 .733 .906 r
.22049 .25124 .22866 .25988 .2407 .25554 .23257 .24686 Mtetra
.23257 .24686 .2407 .25554 .2528 .25117 .2447 .24244 Mtetra
.657 .733 .905 r
.2447 .24244 .2528 .25117 .26496 .24677 .25689 .23799 Mtetra
.658 .733 .905 r
.25689 .23799 .26496 .24677 .27718 .24234 .26915 .23351 Mtetra
.26915 .23351 .27718 .24234 .28946 .23787 .28146 .22899 Mtetra
.28146 .22899 .28946 .23787 .3018 .23337 .29383 .22444 Mtetra
.659 .733 .904 r
.29383 .22444 .3018 .23337 .3142 .22883 .30626 .21986 Mtetra
.30626 .21986 .3142 .22883 .32665 .22426 .31876 .21523 Mtetra
.66 .733 .904 r
.31876 .21523 .32665 .22426 .33917 .21964 .33131 .21057 Mtetra
.66 .733 .903 r
.33131 .21057 .33917 .21964 .35175 .21499 .34393 .20588 Mtetra
.661 .733 .903 r
.34393 .20588 .35175 .21499 .3644 .2103 .35661 .20114 Mtetra
.35661 .20114 .3644 .2103 .3771 .20557 .36935 .19636 Mtetra
.662 .733 .902 r
.36935 .19636 .3771 .20557 .38987 .2008 .38215 .19155 Mtetra
.38215 .19155 .38987 .2008 .40269 .19599 .39501 .18669 Mtetra
.663 .733 .902 r
.39501 .18669 .40269 .19599 .41558 .19114 .40794 .18179 Mtetra
.40794 .18179 .41558 .19114 .42854 .18625 .42093 .17685 Mtetra
.664 .733 .901 r
.42093 .17685 .42854 .18625 .44155 .18132 .43398 .17187 Mtetra
.43398 .17187 .44155 .18132 .45463 .17634 .4471 .16685 Mtetra
.665 .734 .901 r
.4471 .16685 .45463 .17634 .46777 .17132 .46028 .16179 Mtetra
.46028 .16179 .46777 .17132 .48097 .16626 .47352 .15669 Mtetra
.666 .734 .901 r
.47352 .15669 .48097 .16626 .49424 .16116 .48683 .15154 Mtetra
.48683 .15154 .49424 .16116 .50757 .15602 .5002 .14636 Mtetra
.667 .734 .9 r
.5002 .14636 .50757 .15602 .52097 .15084 .51364 .14113 Mtetra
.667 .735 .9 r
.51364 .14113 .52097 .15084 .53443 .14562 .52714 .13587 Mtetra
.52714 .13587 .53443 .14562 .54795 .14035 .54071 .13056 Mtetra
.668 .735 .9 r
.54071 .13056 .54795 .14035 .56154 .13505 .55434 .12522 Mtetra
.55434 .12522 .56154 .13505 .57519 .12971 .56804 .11984 Mtetra
.669 .736 .9 r
.56804 .11984 .57519 .12971 .58891 .12434 .5818 .11442 Mtetra
.5818 .11442 .58891 .12434 .6027 .11893 .59563 .10897 Mtetra
.59563 .10897 .6027 .11893 .61655 .11348 .60953 .10348 Mtetra
.60953 .10348 .61655 .11348 .63047 .10799 .62349 .09796 Mtetra
.67 .737 .9 r
.62349 .09796 .63047 .10799 .64445 .10248 .63752 .0924 Mtetra
.67 .737 .901 r
.63752 .0924 .64445 .10248 .65851 .09693 .65162 .08681 Mtetra
.65162 .08681 .65851 .09693 .67263 .09135 .66579 .08119 Mtetra
.67 .738 .901 r
.66579 .08119 .67263 .09135 .68681 .08574 .68003 .07554 Mtetra
.68003 .07554 .68681 .08574 .70107 .0801 .69434 .06986 Mtetra
.69434 .06986 .70107 .0801 .7154 .07443 .70871 .06415 Mtetra
.70871 .06415 .7154 .07443 .72979 .06873 .72316 .05841 Mtetra
.656 .735 .908 r
.07143 .29372 .08002 .30189 .09142 .29778 .08286 .28957 Mtetra
.08286 .28957 .09142 .29778 .10288 .29366 .09434 .28541 Mtetra
.09434 .28541 .10288 .29366 .11439 .28952 .10588 .28122 Mtetra
.10588 .28122 .11439 .28952 .12596 .28536 .11748 .27702 Mtetra
.11748 .27702 .12596 .28536 .13758 .28118 .12913 .27279 Mtetra
.656 .734 .907 r
.12913 .27279 .13758 .28118 .14925 .27698 .14083 .26854 Mtetra
.14083 .26854 .14925 .27698 .16098 .27275 .1526 .26427 Mtetra
.1526 .26427 .16098 .27275 .17277 .2685 .16441 .25998 Mtetra
.16441 .25998 .17277 .2685 .18462 .26423 .17629 .25565 Mtetra
.17629 .25565 .18462 .26423 .19652 .25993 .18822 .25131 Mtetra
.656 .734 .906 r
.18822 .25131 .19652 .25993 .20848 .2556 .20021 .24693 Mtetra
.657 .733 .906 r
.20021 .24693 .20848 .2556 .22049 .25124 .21226 .24253 Mtetra
.21226 .24253 .22049 .25124 .23257 .24686 .22437 .23809 Mtetra
.22437 .23809 .23257 .24686 .2447 .24244 .23653 .23363 Mtetra
.658 .733 .905 r
.23653 .23363 .2447 .24244 .25689 .23799 .24876 .22913 Mtetra
.24876 .22913 .25689 .23799 .26915 .23351 .26104 .2246 Mtetra
.26104 .2246 .26915 .23351 .28146 .22899 .27339 .22004 Mtetra
.659 .733 .904 r
.27339 .22004 .28146 .22899 .29383 .22444 .2858 .21544 Mtetra
.2858 .21544 .29383 .22444 .30626 .21986 .29826 .21081 Mtetra
.66 .733 .904 r
.29826 .21081 .30626 .21986 .31876 .21523 .31079 .20614 Mtetra
.31079 .20614 .31876 .21523 .33131 .21057 .32338 .20143 Mtetra
.66 .733 .903 r
.32338 .20143 .33131 .21057 .34393 .20588 .33603 .19668 Mtetra
.661 .733 .903 r
.33603 .19668 .34393 .20588 .35661 .20114 .34875 .1919 Mtetra
.34875 .1919 .35661 .20114 .36935 .19636 .36152 .18707 Mtetra
.662 .733 .902 r
.36152 .18707 .36935 .19636 .38215 .19155 .37436 .18221 Mtetra
.37436 .18221 .38215 .19155 .39501 .18669 .38726 .17731 Mtetra
.663 .733 .902 r
.38726 .17731 .39501 .18669 .40794 .18179 .40023 .17236 Mtetra
.40023 .17236 .40794 .18179 .42093 .17685 .41326 .16738 Mtetra
.664 .733 .901 r
.41326 .16738 .42093 .17685 .43398 .17187 .42635 .16235 Mtetra
.664 .734 .901 r
.42635 .16235 .43398 .17187 .4471 .16685 .4395 .15729 Mtetra
.665 .734 .901 r
.4395 .15729 .4471 .16685 .46028 .16179 .45272 .15218 Mtetra
.45272 .15218 .46028 .16179 .47352 .15669 .46601 .14703 Mtetra
.666 .734 .901 r
.46601 .14703 .47352 .15669 .48683 .15154 .47936 .14184 Mtetra
.47936 .14184 .48683 .15154 .5002 .14636 .49277 .13661 Mtetra
.667 .734 .901 r
.49277 .13661 .5002 .14636 .51364 .14113 .50625 .13134 Mtetra
.667 .735 .901 r
.50625 .13134 .51364 .14113 .52714 .13587 .51979 .12604 Mtetra
.667 .735 .9 r
.51979 .12604 .52714 .13587 .54071 .13056 .5334 .12069 Mtetra
.668 .735 .9 r
.5334 .12069 .54071 .13056 .55434 .12522 .54708 .11531 Mtetra
.54708 .11531 .55434 .12522 .56804 .11984 .56082 .10988 Mtetra
.668 .736 .9 r
.56082 .10988 .56804 .11984 .5818 .11442 .57463 .10442 Mtetra
.669 .736 .9 r
.57463 .10442 .5818 .11442 .59563 .10897 .5885 .09893 Mtetra
.669 .736 .901 r
.5885 .09893 .59563 .10897 .60953 .10348 .60244 .0934 Mtetra
.669 .737 .901 r
.60244 .0934 .60953 .10348 .62349 .09796 .61645 .08784 Mtetra
.61645 .08784 .62349 .09796 .63752 .0924 .63053 .08224 Mtetra
.63053 .08224 .63752 .0924 .65162 .08681 .64468 .07661 Mtetra
.67 .737 .901 r
.64468 .07661 .65162 .08681 .66579 .08119 .6589 .07095 Mtetra
.67 .738 .901 r
.6589 .07095 .66579 .08119 .68003 .07554 .67318 .06526 Mtetra
.67318 .06526 .68003 .07554 .69434 .06986 .68754 .05953 Mtetra
.68754 .05953 .69434 .06986 .70871 .06415 .70197 .05378 Mtetra
.67 .739 .902 r
.70197 .05378 .70871 .06415 .72316 .05841 .71646 .04801 Mtetra
.656 .735 .908 r
.06276 .28548 .07143 .29372 .08286 .28957 .07422 .28129 Mtetra
.07422 .28129 .08286 .28957 .09434 .28541 .08574 .27708 Mtetra
.08574 .27708 .09434 .28541 .10588 .28122 .09731 .27285 Mtetra
.09731 .27285 .10588 .28122 .11748 .27702 .10893 .2686 Mtetra
.656 .735 .907 r
.10893 .2686 .11748 .27702 .12913 .27279 .12061 .26433 Mtetra
.656 .734 .907 r
.12061 .26433 .12913 .27279 .14083 .26854 .13235 .26003 Mtetra
.13235 .26003 .14083 .26854 .1526 .26427 .14414 .25572 Mtetra
.14414 .25572 .1526 .26427 .16441 .25998 .15599 .25137 Mtetra
.15599 .25137 .16441 .25998 .17629 .25565 .16789 .247 Mtetra
.657 .734 .906 r
.16789 .247 .17629 .25565 .18822 .25131 .17986 .24261 Mtetra
.17986 .24261 .18822 .25131 .20021 .24693 .19188 .23819 Mtetra
.657 .733 .906 r
.19188 .23819 .20021 .24693 .21226 .24253 .20396 .23373 Mtetra
.20396 .23373 .21226 .24253 .22437 .23809 .2161 .22925 Mtetra
.658 .733 .905 r
.2161 .22925 .22437 .23809 .23653 .23363 .22829 .22474 Mtetra
.22829 .22474 .23653 .23363 .24876 .22913 .24055 .2202 Mtetra
.24055 .2202 .24876 .22913 .26104 .2246 .25287 .21562 Mtetra
.659 .733 .905 r
.25287 .21562 .26104 .2246 .27339 .22004 .26525 .21101 Mtetra
.659 .733 .904 r
.26525 .21101 .27339 .22004 .2858 .21544 .27769 .20636 Mtetra
.27769 .20636 .2858 .21544 .29826 .21081 .29019 .20168 Mtetra
.66 .733 .904 r
.29019 .20168 .29826 .21081 .31079 .20614 .30276 .19696 Mtetra
.66 .733 .903 r
.30276 .19696 .31079 .20614 .32338 .20143 .31538 .1922 Mtetra
.661 .733 .903 r
.31538 .1922 .32338 .20143 .33603 .19668 .32807 .18741 Mtetra
.32807 .18741 .33603 .19668 .34875 .1919 .34082 .18258 Mtetra
.662 .733 .903 r
.34082 .18258 .34875 .1919 .36152 .18707 .35363 .17771 Mtetra
.662 .733 .902 r
.35363 .17771 .36152 .18707 .37436 .18221 .36651 .1728 Mtetra
.36651 .1728 .37436 .18221 .38726 .17731 .37945 .16785 Mtetra
.663 .733 .902 r
.37945 .16785 .38726 .17731 .40023 .17236 .39245 .16286 Mtetra
.39245 .16286 .40023 .17236 .41326 .16738 .40551 .15782 Mtetra
.664 .733 .902 r
.40551 .15782 .41326 .16738 .42635 .16235 .41865 .15275 Mtetra
.664 .734 .901 r
.41865 .15275 .42635 .16235 .4395 .15729 .43184 .14764 Mtetra
.665 .734 .901 r
.43184 .14764 .4395 .15729 .45272 .15218 .4451 .14249 Mtetra
.4451 .14249 .45272 .15218 .46601 .14703 .45842 .1373 Mtetra
.666 .734 .901 r
.45842 .1373 .46601 .14703 .47936 .14184 .47181 .13206 Mtetra
.47181 .13206 .47936 .14184 .49277 .13661 .48527 .12679 Mtetra
.667 .735 .901 r
.48527 .12679 .49277 .13661 .50625 .13134 .49879 .12148 Mtetra
.49879 .12148 .50625 .13134 .51979 .12604 .51237 .11613 Mtetra
.51237 .11613 .51979 .12604 .5334 .12069 .52603 .11074 Mtetra
.668 .735 .901 r
.52603 .11074 .5334 .12069 .54708 .11531 .53975 .10531 Mtetra
.668 .736 .901 r
.53975 .10531 .54708 .11531 .56082 .10988 .55353 .09984 Mtetra
.55353 .09984 .56082 .10988 .57463 .10442 .56739 .09434 Mtetra
.56739 .09434 .57463 .10442 .5885 .09893 .58131 .08881 Mtetra
.669 .736 .901 r
.58131 .08881 .5885 .09893 .60244 .0934 .59529 .08324 Mtetra
.669 .737 .901 r
.59529 .08324 .60244 .0934 .61645 .08784 .60935 .07763 Mtetra
.60935 .07763 .61645 .08784 .63053 .08224 .62348 .07199 Mtetra
.62348 .07199 .63053 .08224 .64468 .07661 .63767 .06632 Mtetra
.669 .738 .901 r
.63767 .06632 .64468 .07661 .6589 .07095 .65194 .06062 Mtetra
.65194 .06062 .6589 .07095 .67318 .06526 .66627 .05488 Mtetra
.67 .738 .901 r
.66627 .05488 .67318 .06526 .68754 .05953 .68068 .04912 Mtetra
.67 .738 .902 r
.68068 .04912 .68754 .05953 .70197 .05378 .69516 .04333 Mtetra
.67 .739 .902 r
.69516 .04333 .70197 .05378 .71646 .04801 .70971 .03751 Mtetra
.656 .735 .908 r
.05403 .27717 .06276 .28548 .07422 .28129 .06552 .27293 Mtetra
.06552 .27293 .07422 .28129 .08574 .27708 .07706 .26868 Mtetra
.07706 .26868 .08574 .27708 .09731 .27285 .08866 .2644 Mtetra
.656 .735 .907 r
.08866 .2644 .09731 .27285 .10893 .2686 .10031 .26011 Mtetra
.10031 .26011 .10893 .2686 .12061 .26433 .11202 .25579 Mtetra
.656 .734 .907 r
.11202 .25579 .12061 .26433 .13235 .26003 .12379 .25145 Mtetra
.12379 .25145 .13235 .26003 .14414 .25572 .13561 .24708 Mtetra
.13561 .24708 .14414 .25572 .15599 .25137 .14749 .24269 Mtetra
.657 .734 .907 r
.14749 .24269 .15599 .25137 .16789 .247 .15942 .23828 Mtetra
.657 .734 .906 r
.15942 .23828 .16789 .247 .17986 .24261 .17142 .23383 Mtetra
.17142 .23383 .17986 .24261 .19188 .23819 .18347 .22936 Mtetra
.657 .733 .906 r
.18347 .22936 .19188 .23819 .20396 .23373 .19558 .22486 Mtetra
.19558 .22486 .20396 .23373 .2161 .22925 .20776 .22033 Mtetra
.658 .733 .905 r
.20776 .22033 .2161 .22925 .22829 .22474 .21999 .21577 Mtetra
.21999 .21577 .22829 .22474 .24055 .2202 .23228 .21118 Mtetra
.23228 .21118 .24055 .2202 .25287 .21562 .24463 .20656 Mtetra
.659 .733 .904 r
.24463 .20656 .25287 .21562 .26525 .21101 .25704 .2019 Mtetra
.25704 .2019 .26525 .21101 .27769 .20636 .26952 .1972 Mtetra
.26952 .1972 .27769 .20636 .29019 .20168 .28205 .19247 Mtetra
.66 .733 .904 r
.28205 .19247 .29019 .20168 .30276 .19696 .29465 .1877 Mtetra
.66 .733 .903 r
.29465 .1877 .30276 .19696 .31538 .1922 .30731 .1829 Mtetra
.661 .733 .903 r
.30731 .1829 .31538 .1922 .32807 .18741 .32004 .17806 Mtetra
.32004 .17806 .32807 .18741 .34082 .18258 .33282 .17318 Mtetra
.662 .733 .903 r
.33282 .17318 .34082 .18258 .35363 .17771 .34567 .16826 Mtetra
.662 .733 .902 r
.34567 .16826 .35363 .17771 .36651 .1728 .35858 .1633 Mtetra
.663 .733 .902 r
.35858 .1633 .36651 .1728 .37945 .16785 .37156 .15831 Mtetra
.37156 .15831 .37945 .16785 .39245 .16286 .3846 .15327 Mtetra
.3846 .15327 .39245 .16286 .40551 .15782 .39771 .14819 Mtetra
.664 .734 .902 r
.39771 .14819 .40551 .15782 .41865 .15275 .41088 .14307 Mtetra
.664 .734 .901 r
.41088 .14307 .41865 .15275 .43184 .14764 .42411 .13792 Mtetra
.665 .734 .901 r
.42411 .13792 .43184 .14764 .4451 .14249 .43741 .13272 Mtetra
.43741 .13272 .4451 .14249 .45842 .1373 .45077 .12748 Mtetra
.666 .734 .901 r
.45077 .12748 .45842 .1373 .47181 .13206 .4642 .1222 Mtetra
.4642 .1222 .47181 .13206 .48527 .12679 .4777 .11689 Mtetra
.666 .735 .901 r
.4777 .11689 .48527 .12679 .49879 .12148 .49126 .11153 Mtetra
.667 .735 .901 r
.49126 .11153 .49879 .12148 .51237 .11613 .50489 .10613 Mtetra
.50489 .10613 .51237 .11613 .52603 .11074 .51859 .1007 Mtetra
.51859 .1007 .52603 .11074 .53975 .10531 .53235 .09523 Mtetra
.668 .736 .901 r
.53235 .09523 .53975 .10531 .55353 .09984 .54618 .08972 Mtetra
.54618 .08972 .55353 .09984 .56739 .09434 .56008 .08418 Mtetra
.56008 .08418 .56739 .09434 .58131 .08881 .57404 .0786 Mtetra
.669 .736 .901 r
.57404 .0786 .58131 .08881 .59529 .08324 .58808 .07299 Mtetra
.669 .737 .901 r
.58808 .07299 .59529 .08324 .60935 .07763 .60218 .06734 Mtetra
.60218 .06734 .60935 .07763 .62348 .07199 .61636 .06166 Mtetra
.61636 .06166 .62348 .07199 .63767 .06632 .6306 .05594 Mtetra
.669 .738 .901 r
.6306 .05594 .63767 .06632 .65194 .06062 .64491 .0502 Mtetra
.669 .738 .902 r
.64491 .0502 .65194 .06062 .66627 .05488 .6593 .04442 Mtetra
.6593 .04442 .66627 .05488 .68068 .04912 .67376 .03861 Mtetra
.67376 .03861 .68068 .04912 .69516 .04333 .68829 .03278 Mtetra
.669 .739 .902 r
.68829 .03278 .69516 .04333 .70971 .03751 .70289 .02691 Mtetra
.657 .735 .908 r
.04522 .26879 .05403 .27717 .06552 .27293 .05674 .26451 Mtetra
.656 .735 .908 r
.05674 .26451 .06552 .27293 .07706 .26868 .06831 .26021 Mtetra
.656 .735 .907 r
.06831 .26021 .07706 .26868 .08866 .2644 .07994 .25588 Mtetra
.07994 .25588 .08866 .2644 .10031 .26011 .09162 .25154 Mtetra
.09162 .25154 .10031 .26011 .11202 .25579 .10336 .24718 Mtetra
.657 .734 .907 r
.10336 .24718 .11202 .25579 .12379 .25145 .11515 .24279 Mtetra
.11515 .24279 .12379 .25145 .13561 .24708 .12701 .23838 Mtetra
.12701 .23838 .13561 .24708 .14749 .24269 .13892 .23394 Mtetra
.657 .734 .906 r
.13892 .23394 .14749 .24269 .15942 .23828 .15088 .22947 Mtetra
.15088 .22947 .15942 .23828 .17142 .23383 .16291 .22498 Mtetra
.16291 .22498 .17142 .23383 .18347 .22936 .17499 .22047 Mtetra
.17499 .22047 .18347 .22936 .19558 .22486 .18714 .21592 Mtetra
.658 .733 .905 r
.18714 .21592 .19558 .22486 .20776 .22033 .19934 .21134 Mtetra
.19934 .21134 .20776 .22033 .21999 .21577 .21161 .20673 Mtetra
.21161 .20673 .21999 .21577 .23228 .21118 .22393 .20209 Mtetra
.659 .733 .905 r
.22393 .20209 .23228 .21118 .24463 .20656 .23632 .19741 Mtetra
.659 .733 .904 r
.23632 .19741 .24463 .20656 .25704 .2019 .24877 .19271 Mtetra
.24877 .19271 .25704 .2019 .26952 .1972 .26127 .18796 Mtetra
.66 .733 .904 r
.26127 .18796 .26952 .1972 .28205 .19247 .27385 .18318 Mtetra
.27385 .18318 .28205 .19247 .29465 .1877 .28648 .17837 Mtetra
.66 .733 .903 r
.28648 .17837 .29465 .1877 .30731 .1829 .29917 .17352 Mtetra
.661 .733 .903 r
.29917 .17352 .30731 .1829 .32004 .17806 .31193 .16863 Mtetra
.31193 .16863 .32004 .17806 .33282 .17318 .32476 .1637 Mtetra
.662 .733 .903 r
.32476 .1637 .33282 .17318 .34567 .16826 .33764 .15873 Mtetra
.662 .733 .902 r
.33764 .15873 .34567 .16826 .35858 .1633 .35059 .15373 Mtetra
.663 .733 .902 r
.35059 .15373 .35858 .1633 .37156 .15831 .36361 .14868 Mtetra
.36361 .14868 .37156 .15831 .3846 .15327 .37668 .1436 Mtetra
.663 .734 .902 r
.37668 .1436 .3846 .15327 .39771 .14819 .38983 .13848 Mtetra
.664 .734 .902 r
.38983 .13848 .39771 .14819 .41088 .14307 .40304 .13331 Mtetra
.40304 .13331 .41088 .14307 .42411 .13792 .41631 .12811 Mtetra
.665 .734 .901 r
.41631 .12811 .42411 .13792 .43741 .13272 .42965 .12287 Mtetra
.42965 .12287 .43741 .13272 .45077 .12748 .44306 .11758 Mtetra
.666 .734 .901 r
.44306 .11758 .45077 .12748 .4642 .1222 .45653 .11226 Mtetra
.666 .735 .901 r
.45653 .11226 .4642 .1222 .4777 .11689 .47006 .1069 Mtetra
.47006 .1069 .4777 .11689 .49126 .11153 .48367 .1015 Mtetra
.667 .735 .901 r
.48367 .1015 .49126 .11153 .50489 .10613 .49734 .09606 Mtetra
.49734 .09606 .50489 .10613 .51859 .1007 .51108 .09058 Mtetra
.667 .736 .901 r
.51108 .09058 .51859 .1007 .53235 .09523 .52489 .08507 Mtetra
.668 .736 .901 r
.52489 .08507 .53235 .09523 .54618 .08972 .53876 .07951 Mtetra
.53876 .07951 .54618 .08972 .56008 .08418 .55271 .07393 Mtetra
.55271 .07393 .56008 .08418 .57404 .0786 .56672 .0683 Mtetra
.668 .737 .901 r
.56672 .0683 .57404 .0786 .58808 .07299 .5808 .06265 Mtetra
.5808 .06265 .58808 .07299 .60218 .06734 .59495 .05696 Mtetra
.669 .737 .901 r
.59495 .05696 .60218 .06734 .61636 .06166 .60917 .05123 Mtetra
.60917 .05123 .61636 .06166 .6306 .05594 .62346 .04547 Mtetra
.669 .738 .902 r
.62346 .04547 .6306 .05594 .64491 .0502 .63783 .03968 Mtetra
.63783 .03968 .64491 .0502 .6593 .04442 .65226 .03386 Mtetra
.65226 .03386 .6593 .04442 .67376 .03861 .66677 .02801 Mtetra
.66677 .02801 .67376 .03861 .68829 .03278 .68135 .02213 Mtetra
.669 .739 .902 r
.68135 .02213 .68829 .03278 .70289 .02691 .696 .01622 Mtetra
.657 .735 .908 r
.03634 .26033 .04522 .26879 .05674 .26451 .04788 .25601 Mtetra
.04788 .25601 .05674 .26451 .06831 .26021 .05948 .25166 Mtetra
.657 .735 .907 r
.05948 .25166 .06831 .26021 .07994 .25588 .07114 .24729 Mtetra
.07114 .24729 .07994 .25588 .09162 .25154 .08285 .2429 Mtetra
.08285 .2429 .09162 .25154 .10336 .24718 .09462 .23849 Mtetra
.657 .734 .907 r
.09462 .23849 .10336 .24718 .11515 .24279 .10645 .23405 Mtetra
.10645 .23405 .11515 .24279 .12701 .23838 .11833 .22959 Mtetra
.657 .734 .906 r
.11833 .22959 .12701 .23838 .13892 .23394 .13027 .22511 Mtetra
.13027 .22511 .13892 .23394 .15088 .22947 .14227 .2206 Mtetra
.14227 .2206 .15088 .22947 .16291 .22498 .15433 .21606 Mtetra
.15433 .21606 .16291 .22498 .17499 .22047 .16645 .21149 Mtetra
.658 .734 .906 r
.16645 .21149 .17499 .22047 .18714 .21592 .17862 .20689 Mtetra
.658 .733 .905 r
.17862 .20689 .18714 .21592 .19934 .21134 .19086 .20227 Mtetra
.19086 .20227 .19934 .21134 .21161 .20673 .20316 .19761 Mtetra
.20316 .19761 .21161 .20673 .22393 .20209 .21551 .19292 Mtetra
.659 .733 .905 r
.21551 .19292 .22393 .20209 .23632 .19741 .22793 .18819 Mtetra
.659 .733 .904 r
.22793 .18819 .23632 .19741 .24877 .19271 .24042 .18344 Mtetra
.24042 .18344 .24877 .19271 .26127 .18796 .25296 .17864 Mtetra
.66 .733 .904 r
.25296 .17864 .26127 .18796 .27385 .18318 .26556 .17382 Mtetra
.26556 .17382 .27385 .18318 .28648 .17837 .27823 .16895 Mtetra
.661 .733 .903 r
.27823 .16895 .28648 .17837 .29917 .17352 .29096 .16405 Mtetra
.29096 .16405 .29917 .17352 .31193 .16863 .30376 .15912 Mtetra
.30376 .15912 .31193 .16863 .32476 .1637 .31662 .15414 Mtetra
.662 .733 .903 r
.31662 .15414 .32476 .1637 .33764 .15873 .32954 .14913 Mtetra
.662 .733 .902 r
.32954 .14913 .33764 .15873 .35059 .15373 .34253 .14407 Mtetra
.663 .733 .902 r
.34253 .14407 .35059 .15373 .36361 .14868 .35558 .13898 Mtetra
.663 .734 .902 r
.35558 .13898 .36361 .14868 .37668 .1436 .3687 .13385 Mtetra
.3687 .13385 .37668 .1436 .38983 .13848 .38188 .12868 Mtetra
.664 .734 .902 r
.38188 .12868 .38983 .13848 .40304 .13331 .39513 .12347 Mtetra
.39513 .12347 .40304 .13331 .41631 .12811 .40844 .11822 Mtetra
.665 .734 .902 r
.40844 .11822 .41631 .12811 .42965 .12287 .42182 .11293 Mtetra
.665 .734 .901 r
.42182 .11293 .42965 .12287 .44306 .11758 .43527 .1076 Mtetra
.43527 .1076 .44306 .11758 .45653 .11226 .44878 .10223 Mtetra
.666 .735 .901 r
.44878 .10223 .45653 .11226 .47006 .1069 .46236 .09682 Mtetra
.46236 .09682 .47006 .1069 .48367 .1015 .47601 .09138 Mtetra
.667 .735 .901 r
.47601 .09138 .48367 .1015 .49734 .09606 .48972 .08589 Mtetra
.48972 .08589 .49734 .09606 .51108 .09058 .5035 .08037 Mtetra
.667 .736 .901 r
.5035 .08037 .51108 .09058 .52489 .08507 .51736 .07481 Mtetra
.51736 .07481 .52489 .08507 .53876 .07951 .53128 .06922 Mtetra
.668 .736 .901 r
.53128 .06922 .53876 .07951 .55271 .07393 .54526 .06359 Mtetra
.54526 .06359 .55271 .07393 .56672 .0683 .55932 .05792 Mtetra
.668 .737 .901 r
.55932 .05792 .56672 .0683 .5808 .06265 .57345 .05222 Mtetra
.57345 .05222 .5808 .06265 .59495 .05696 .58765 .04648 Mtetra
.668 .737 .902 r
.58765 .04648 .59495 .05696 .60917 .05123 .60192 .04071 Mtetra
.669 .737 .902 r
.60192 .04071 .60917 .05123 .62346 .04547 .61626 .03491 Mtetra
.669 .738 .902 r
.61626 .03491 .62346 .04547 .63783 .03968 .63067 .02908 Mtetra
.63067 .02908 .63783 .03968 .65226 .03386 .64516 .02321 Mtetra
.64516 .02321 .65226 .03386 .66677 .02801 .65972 .01732 Mtetra
.65972 .01732 .66677 .02801 .68135 .02213 .67435 .01139 Mtetra
.669 .739 .902 r
.67435 .01139 .68135 .02213 .696 .01622 .68905 .00544 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.54287 .9902 m
.5516 .96926 L
.55724 .9644 L
.56555 .9386 L
.56877 .9128 L
.56727 .887 L
.5609 .8612 L
.5516 .83969 L
.54888 .8354 L
.52928 .8096 L
.5258 .80608 L
.5 .78614 L
.49638 .7838 L
.4742 .77388 L
.4484 .76732 L
.4226 .76565 L
.3968 .76869 L
.371 .7768 L
.35619 .7838 L
.3452 .79092 L
.32333 .8096 L
.3194 .81384 L
.30375 .8354 L
.2936 .85591 L
.29182 .8612 L
.28541 .887 L
.28391 .9128 L
.28715 .9386 L
.2936 .96176 L
.29545 .9644 L
.30983 .9902 L
s
.70463 .0098 m
.7064 .01074 L
.7322 .02546 L
.74797 .0356 L
.758 .04256 L
.78261 .0614 L
.7838 .06239 L
.8096 .08543 L
.81142 .0872 L
.8354 .11244 L
.83589 .113 L
.85689 .1388 L
.8612 .1446 L
.87499 .1646 L
.887 .18409 L
.8906 .1904 L
.90399 .2162 L
.9128 .23574 L
.91538 .242 L
.92493 .2678 L
.93275 .2936 L
.9386 .31771 L
.93895 .3194 L
.94358 .3452 L
.94669 .371 L
.94832 .3968 L
.94849 .4226 L
.94718 .4484 L
.9444 .4742 L
.9401 .5 L
.9386 .50748 L
.93426 .5258 L
.9268 .5516 L
.91764 .5774 L
.9128 .58936 L
.90667 .6032 L
.89373 .629 L
.887 .64101 L
.87864 .6548 L
.8612 .68048 L
.86111 .6806 L
.8408 .7064 L
.8354 .71265 L
.81716 .7322 L
.8096 .73966 L
.7894 .758 L
.7838 .76271 L
.758 .78253 L
.75622 .7838 L
.7322 .79964 L
Mistroke
.71519 .8096 L
.7064 .81436 L
.6806 .82696 L
.66059 .8354 L
.6548 .83762 L
.629 .8465 L
.6032 .85368 L
.5774 .85927 L
.5668 .8612 L
.5516 .86331 L
.5258 .86585 L
.5 .86691 L
.4742 .86651 L
.4484 .86464 L
.4226 .86128 L
.42209 .8612 L
.3968 .85639 L
.371 .84994 L
.3452 .84183 L
.32778 .8354 L
.3194 .83199 L
.2936 .82028 L
.2732 .8096 L
.2678 .80654 L
.242 .79055 L
.23216 .7838 L
.2162 .772 L
.19898 .758 L
.1904 .75048 L
.17122 .7322 L
.1646 .72537 L
.14758 .7064 L
.1388 .69572 L
.12727 .6806 L
.113 .6599 L
.10975 .6548 L
.09465 .629 L
.0872 .61466 L
.08172 .6032 L
.07074 .5774 L
.06159 .5516 L
.0614 .55104 L
.05412 .5258 L
.04828 .5 L
.04399 .4742 L
.0412 .4484 L
.0399 .4226 L
.04006 .3968 L
.04169 .371 L
.0448 .3452 L
Mistroke
.04943 .3194 L
.05563 .2936 L
.0614 .27401 L
.06346 .2678 L
.073 .242 L
.08439 .2162 L
.0872 .21044 L
.09779 .1904 L
.113 .1652 L
.11339 .1646 L
.13149 .1388 L
.1388 .12937 L
.15249 .113 L
.1646 .09972 L
.17696 .0872 L
.1904 .07461 L
.20577 .0614 L
.2162 .05309 L
.24042 .0356 L
.242 .03455 L
.2678 .01856 L
.28374 .0098 L
Mfstroke
.242 .70166 m
.2678 .691 L
.2936 .68579 L
.3194 .68536 L
.3452 .68965 L
.371 .6992 L
.38441 .7064 L
.3968 .71523 L
.41496 .7322 L
.4226 .74133 L
.43336 .758 L
.44455 .7838 L
.4484 .79856 L
.45025 .8096 L
.45116 .8354 L
.4484 .85636 L
.44732 .8612 L
.4384 .887 L
.42298 .9128 L
.4226 .91331 L
.39805 .9386 L
.3968 .93958 L
.371 .95575 L
.3488 .9644 L
.3452 .9652 L
.3194 .96946 L
.2936 .96903 L
.26965 .9644 L
.2678 .96386 L
.242 .95331 L
.21963 .9386 L
.2162 .93569 L
.19477 .9128 L
.1904 .90687 L
.17943 .887 L
.17046 .8612 L
.16666 .8354 L
.16755 .8096 L
.17325 .7838 L
.1845 .758 L
.1904 .74813 L
.20286 .7322 L
.2162 .71917 L
.23355 .7064 L
.242 .70166 L
s
.9902 .76874 m
.98236 .758 L
.9644 .73634 L
.96055 .7322 L
.9386 .71114 L
.93302 .7064 L
.9128 .69099 L
.89695 .6806 L
.887 .67477 L
.8612 .66181 L
.8442 .6548 L
.8354 .65167 L
.8096 .64406 L
.7838 .63881 L
.758 .63578 L
.7322 .63492 L
.7064 .63621 L
.6806 .63966 L
.6548 .64537 L
.629 .65346 L
.62534 .6548 L
.6032 .66413 L
.5774 .6777 L
.57256 .6806 L
.5516 .69463 L
.53647 .7064 L
.5258 .71566 L
.50894 .7322 L
.5 .74207 L
.48709 .758 L
.4742 .77634 L
.46952 .7838 L
.45541 .8096 L
.4484 .82498 L
.44426 .8354 L
.43574 .8612 L
.42964 .887 L
.4258 .9128 L
.42414 .9386 L
.42463 .9644 L
.42728 .9902 L
s
0 g
.03 w
.42634 .90811 Mdot
.49419 .41255 Mdot
.30891 .82746 Mdot
.73474 .94559 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.34314 .81238 m
.36275 .80825 L
.38235 .81042 L
.39209 .81373 L
.40196 .81823 L
.42018 .83333 L
.42157 .83412 L
.43264 .85294 L
.43723 .87255 L
.43492 .89216 L
.42273 .91176 L
.42157 .91292 L
.40196 .92489 L
.38235 .92784 L
.36275 .92501 L
.34314 .91587 L
.33715 .91176 L
.32353 .89805 L
.31994 .89216 L
.31182 .87255 L
.31083 .85294 L
.31768 .83333 L
.32353 .82471 L
.33905 .81373 L
.34314 .81238 L
s
.32353 .78206 m
.34314 .77614 L
.36275 .77454 L
.38235 .77665 L
.40196 .78245 L
.42157 .79246 L
.42417 .79412 L
.44118 .80779 L
.44683 .81373 L
.46078 .83316 L
.46088 .83333 L
.46943 .85294 L
.47335 .87255 L
.47284 .89216 L
.46743 .91176 L
.46078 .92494 L
.45558 .93137 L
.44118 .94488 L
.43176 .95098 L
.42157 .95534 L
.40196 .96041 L
.38235 .96129 L
.36275 .95845 L
.34314 .95183 L
.34113 .95098 L
.32353 .941 L
.31125 .93137 L
.30392 .92424 L
.29389 .91176 L
.28431 .89529 L
.28305 .89216 L
.27702 .87255 L
.27543 .85294 L
.27841 .83333 L
.28431 .81674 L
.28689 .81373 L
.30392 .79414 L
.30395 .79412 L
.32353 .78206 L
s
.32353 .75207 m
.34314 .74812 L
.36275 .74732 L
.38235 .74942 L
.40196 .75436 L
.40368 .7549 L
.42157 .76229 L
.44118 .77373 L
.44232 .77451 L
.46078 .78961 L
.46528 .79412 L
.48039 .81263 L
.48113 .81373 L
.49215 .83333 L
.49925 .85294 L
.5 .85584 L
.50286 .87255 L
.50304 .89216 L
.5 .91023 L
.49959 .91176 L
.49195 .93137 L
.48039 .94902 L
.4787 .95098 L
.46078 .96738 L
.45615 .97059 L
.44118 .97844 L
.42157 .98505 L
.40196 .98817 L
.38235 .9882 L
.36275 .98534 L
.34314 .97963 L
.32353 .97084 L
.32304 .97059 L
.30392 .95833 L
.29486 .95098 L
.28431 .9408 L
.27621 .93137 L
.26471 .91455 L
.26316 .91176 L
.25432 .89216 L
.24911 .87255 L
.2473 .85294 L
.24896 .83333 L
.25446 .81373 L
.26471 .7942 L
.26476 .79412 L
.28204 .77451 L
.28431 .77258 L
.30392 .75976 L
.31439 .7549 L
Mistroke
.32353 .75207 L
Mfstroke
.47614 .9902 m
.48039 .98707 L
.49886 .97059 L
.5 .96933 L
.51347 .95098 L
.51961 .93964 L
.52296 .93137 L
.52861 .91176 L
.53101 .89216 L
.53045 .87255 L
.52705 .85294 L
.52076 .83333 L
.51961 .83043 L
.51136 .81373 L
.5 .79622 L
.4984 .79412 L
.48098 .77451 L
.48039 .77394 L
.46078 .75746 L
.45721 .7549 L
.44118 .74492 L
.42157 .73548 L
.42115 .73529 L
.40196 .72867 L
.38235 .72429 L
.36275 .72226 L
.34314 .72262 L
.32353 .72552 L
.30392 .73128 L
.29416 .73529 L
.28431 .74049 L
.26471 .75435 L
.26407 .7549 L
.24595 .77451 L
.2451 .77565 L
.2341 .79412 L
.22663 .81373 L
.22549 .81799 L
.22264 .83333 L
.22171 .85294 L
.22362 .87255 L
.22549 .88411 L
.22836 .89216 L
.23604 .91176 L
.2451 .92847 L
.24698 .93137 L
.26181 .95098 L
.26471 .95423 L
.28176 .97059 L
.28431 .97268 L
Mistroke
.30392 .98659 L
.30986 .9902 L
Mfstroke
.51872 .9902 m
.51961 .98921 L
.53447 .97059 L
.53922 .9631 L
.54548 .95098 L
.55289 .93137 L
.55728 .91176 L
.55882 .89663 L
.55899 .89216 L
.55882 .88072 L
.5582 .87255 L
.55496 .85294 L
.54924 .83333 L
.54092 .81373 L
.53922 .81033 L
.52973 .79412 L
.51961 .77994 L
.5152 .77451 L
.5 .7582 L
.49651 .7549 L
.48039 .74138 L
.472 .73529 L
.46078 .72806 L
.44118 .71753 L
.43725 .71569 L
.42157 .70938 L
.40196 .70338 L
.38235 .69944 L
.36275 .69749 L
.34314 .69759 L
.32353 .69983 L
.30392 .70441 L
.28431 .71166 L
.2759 .71569 L
.26471 .72216 L
.24699 .73529 L
.2451 .73696 L
.22817 .7549 L
.22549 .75836 L
.21507 .77451 L
.20603 .79412 L
.20588 .79446 L
.20023 .81373 L
.19722 .83333 L
.19676 .85294 L
.19874 .87255 L
.20312 .89216 L
.20588 .90123 L
.21001 .91176 L
.21958 .93137 L
Mistroke
.22549 .94124 L
.23219 .95098 L
.2451 .96696 L
.24843 .97059 L
.26471 .98618 L
.26944 .9902 L
Mfstroke
.55716 .9902 m
.55882 .98773 L
.56934 .97059 L
.57815 .95098 L
.57843 .95028 L
.58413 .93137 L
.58764 .91176 L
.58886 .89216 L
.5879 .87255 L
.5848 .85294 L
.57955 .83333 L
.57843 .82991 L
.57203 .81373 L
.56211 .79412 L
.55882 .78854 L
.54949 .77451 L
.53922 .76122 L
.53376 .7549 L
.51961 .74032 L
.51415 .73529 L
.5 .72354 L
.48926 .71569 L
.48039 .70982 L
.46078 .69858 L
.45583 .69608 L
.44118 .6895 L
.42157 .68235 L
.40196 .67703 L
.39991 .67647 L
.38235 .67346 L
.36275 .67164 L
.34314 .67158 L
.32353 .67337 L
.30613 .67647 L
.30392 .67714 L
.28431 .68311 L
.26471 .69159 L
.25633 .69608 L
.2451 .70311 L
.22877 .71569 L
.22549 .71862 L
.20963 .73529 L
.20588 .73998 L
.19565 .7549 L
.18627 .77259 L
.18543 .77451 L
.17821 .79412 L
.17359 .81373 L
.17129 .83333 L
.17118 .85294 L
Mistroke
.17319 .87255 L
.1773 .89216 L
.18356 .91176 L
.18627 .91868 L
.19212 .93137 L
.20317 .95098 L
.20588 .95518 L
.21706 .97059 L
.22549 .98065 L
.23435 .9902 L
Mfstroke
.59748 .9902 m
.59804 .98915 L
.60733 .97059 L
.61458 .95098 L
.61765 .94037 L
.61951 .93137 L
.62233 .91176 L
.62317 .89216 L
.6221 .87255 L
.61913 .85294 L
.61765 .84569 L
.61425 .83333 L
.6074 .81373 L
.59848 .79412 L
.59804 .79325 L
.5873 .77451 L
.57843 .76135 L
.57363 .7549 L
.55882 .7372 L
.55707 .73529 L
.53922 .71768 L
.53698 .71569 L
.51961 .70146 L
.51228 .69608 L
.5 .68782 L
.48067 .67647 L
.48039 .67632 L
.46078 .66674 L
.44118 .65887 L
.43548 .65686 L
.42157 .65262 L
.40196 .64792 L
.38235 .64473 L
.36275 .64307 L
.34314 .64296 L
.32353 .64445 L
.30392 .64765 L
.28431 .65268 L
.27191 .65686 L
.26471 .65975 L
.2451 .66918 L
.23281 .67647 L
.22549 .68143 L
.20719 .69608 L
.20588 .69727 L
.18833 .71569 L
.18627 .71818 L
.17395 .73529 L
.16667 .74764 L
.16296 .7549 L
Mistroke
.15474 .77451 L
.14888 .79412 L
.14706 .80118 L
.14518 .81373 L
.14345 .83333 L
.14362 .85294 L
.14563 .87255 L
.14706 .88191 L
.14949 .89216 L
.15524 .91176 L
.16296 .93137 L
.16667 .93933 L
.1728 .95098 L
.18494 .97059 L
.18627 .97252 L
.19973 .9902 L
Mfstroke
.64621 .9902 m
.6544 .97059 L
.65686 .96357 L
.66045 .95098 L
.66456 .93137 L
.66684 .91176 L
.66737 .89216 L
.6662 .87255 L
.66335 .85294 L
.6588 .83333 L
.65686 .82657 L
.65249 .81373 L
.64438 .79412 L
.63725 .77976 L
.63436 .77451 L
.62227 .7549 L
.61765 .74821 L
.60789 .73529 L
.59804 .72351 L
.59093 .71569 L
.57843 .70307 L
.57088 .69608 L
.55882 .68573 L
.547 .67647 L
.53922 .67081 L
.51961 .65791 L
.51788 .65686 L
.5 .64679 L
.48042 .63725 L
.48039 .63724 L
.46078 .62918 L
.44118 .6225 L
.42365 .61765 L
.42157 .61715 L
.40196 .61314 L
.38235 .61043 L
.36275 .60903 L
.34314 .60898 L
.32353 .61032 L
.30392 .61311 L
.28431 .61746 L
.28358 .61765 L
.26471 .62351 L
.2451 .63143 L
.23317 .63725 L
.22549 .64148 L
.20588 .65406 L
.20204 .65686 L
.18627 .66977 L
.17912 .67647 L
Mistroke
.16667 .68966 L
.16129 .69608 L
.14715 .71569 L
.14706 .71583 L
.13594 .73529 L
.12745 .75414 L
.12715 .7549 L
.12052 .77451 L
.1158 .79412 L
.11287 .81373 L
.11163 .83333 L
.11203 .85294 L
.11405 .87255 L
.11769 .89216 L
.12297 .91176 L
.12745 .92498 L
.12995 .93137 L
.13874 .95098 L
.14706 .96655 L
.14944 .97059 L
.16226 .9902 L
Mfstroke
.72342 .9902 m
.73058 .97059 L
.73529 .95373 L
.73591 .95098 L
.73947 .93137 L
.74138 .91176 L
.74167 .89216 L
.74039 .87255 L
.73753 .85294 L
.73529 .84183 L
.7331 .83333 L
.72705 .81373 L
.71941 .79412 L
.71569 .78579 L
.71008 .77451 L
.699 .7549 L
.69608 .75019 L
.68604 .73529 L
.67647 .72242 L
.67108 .71569 L
.65686 .69928 L
.65389 .69608 L
.63725 .67936 L
.63417 .67647 L
.61765 .66191 L
.61149 .65686 L
.59804 .64646 L
.58518 .63725 L
.57843 .6327 L
.55882 .62044 L
.55403 .61765 L
.53922 .60954 L
.51961 .59986 L
.51563 .59804 L
.5 .59139 L
.48039 .58403 L
.46313 .57843 L
.46078 .57775 L
.44118 .57258 L
.42157 .56847 L
.40196 .56542 L
.38235 .56345 L
.36275 .56259 L
.34314 .56287 L
.32353 .56432 L
.30392 .567 L
.28431 .57096 L
.26471 .57629 L
.25799 .57843 L
.2451 .58313 L
Mistroke
.22549 .59162 L
.21283 .59804 L
.20588 .60194 L
.18627 .61441 L
.18172 .61765 L
.16667 .62943 L
.15775 .63725 L
.14706 .64764 L
.13848 .65686 L
.12745 .67014 L
.12269 .67647 L
.10966 .69608 L
.10784 .69913 L
.09896 .71569 L
.09027 .73529 L
.08824 .74056 L
.0834 .7549 L
.07819 .77451 L
.07453 .79412 L
.07234 .81373 L
.07158 .83333 L
.07222 .85294 L
.07425 .87255 L
.07767 .89216 L
.08249 .91176 L
.08824 .92992 L
.08876 .93137 L
.09657 .95098 L
.10595 .97059 L
.10784 .97417 L
.11705 .9902 L
Mfstroke
.0098 .8049 m
.01061 .79412 L
.01297 .77451 L
.0165 .7549 L
.02126 .73529 L
.02729 .71569 L
.02941 .70965 L
.03466 .69608 L
.04341 .67647 L
.04902 .66537 L
.0537 .65686 L
.06567 .63725 L
.06863 .63282 L
.07954 .61765 L
.08824 .60666 L
.09557 .59804 L
.10784 .58478 L
.11416 .57843 L
.12745 .56608 L
.13587 .55882 L
.14706 .5499 L
.1616 .53922 L
.16667 .53577 L
.18627 .52343 L
.19288 .51961 L
.20588 .51266 L
.22549 .50323 L
.23284 .5 L
.2451 .49508 L
.26471 .48806 L
.28431 .48204 L
.29026 .48039 L
.30392 .47705 L
.32353 .47296 L
.34314 .46969 L
.36275 .46722 L
.38235 .46548 L
.40196 .46445 L
.42157 .46408 L
.44118 .46432 L
.46078 .46513 L
.48039 .46648 L
.5 .46831 L
.51961 .4706 L
.53922 .47331 L
.55882 .47641 L
.57843 .47991 L
.581 .48039 L
.59804 .48379 L
.61765 .48806 L
Mistroke
.63725 .49276 L
.65686 .49792 L
.66427 .5 L
.67647 .5036 L
.69608 .50988 L
.71569 .51684 L
.72295 .51961 L
.73529 .52457 L
.7549 .53316 L
.76755 .53922 L
.77451 .54273 L
.79412 .55339 L
.80335 .55882 L
.81373 .56527 L
.83322 .57843 L
.83333 .57851 L
.85294 .59331 L
.85877 .59804 L
.87255 .60989 L
.88098 .61765 L
.89216 .62858 L
.90048 .63725 L
.91176 .64982 L
.91771 .65686 L
.93137 .67431 L
.93296 .67647 L
.94647 .69608 L
.95098 .70319 L
.95841 .71569 L
.96889 .73529 L
.97059 .73874 L
.97801 .7549 L
.98586 .77451 L
.9902 .7869 L
Mfstroke
.0098 .8462 m
.01027 .85294 L
.01236 .87255 L
.01558 .89216 L
.01997 .91176 L
.02554 .93137 L
.02941 .943 L
.03233 .95098 L
.04035 .97059 L
.04902 .98899 L
.04963 .9902 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`;o00000oooool00on[_NKo0000o`00
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3o`0000;ooooo00OoZkcVoj^mi_n[_NKoZkgVo`000?oooooo0000043ooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`20ooooo`?o00000_ooool5oj^liP;o
ZkgV00?o0000ooooool00000@?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo07kooooo0_l00003ooooo`SoZkcV00GoZkgVo`000?n[_NKoooooo`00000ooooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Noooool3o`00
00;ooooo3?n[_>H01Ol0003oZkgVoooooooooooo000003kooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`1iooooo`;o00000oooool>oj^liP05o`000?n[_NKo
ZkgVooooool00000?_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo07Kooooo0ol00002oooooa7oZkcV00Ko0000oj^mi_n[_NKoZkgVooooool0000mooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0M?ooool2o`0000Co
oooo4_n[_>H00ol0003oZkgVoj^miP02oj^miP03o`000?oooooooooo03_ooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`1aooooo`?o00001?oooolDoj^liP03
o`000?n[_>KoZkgV00;oZkgV00?oooooo`000?ooool0>oooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo06kooooo0ol00005oooooaKoZkcV00?o0000oj^li_n[
_NH00on[_NH00ooooooo0000ooooo`0jooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0K?ooool2o`0000Gooooo6_n[_>H01ol0003oZkcVoj^mi_n[_NKoZkcV
ooooool00000>oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo06Wooooo0ol00005oooooacoZkcV00?o0000oj^li_n[_>H00on[_>H00ooooooo0000ooooo`0i
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Ioooool2
o`0000Gooooo00?oZ[cVoj^li_n[_>H07?n[_>H00ol0003oZkcVoj^liP04oj^liP03ooooool0003o
oooo03Sooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1T
ooooo`?o00001Oooool4ojZliQgoZkcV00?o0000oj^li_n[_>H01?n[_>H00ooooooo0000ooooo`0h
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0H_ooool2
o`0000Gooooo1_nZ_>HNoj^liP03o`000?n[_>KoZkcV00GoZkcV00?oooooo`000?ooool0=oooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo05oooooo0ol00005
ooooo`SoZ[cV7_n[_>H00ol0003oZkcVoj^liP06oj^liP03ooooool0003ooooo03Kooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Mooooo`;o00001Oooool<
ojZliQgoZkcV00?o0000oj^li_n[_>H01on[_>H00ol0003oooooooooo`0eooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0F_ooool3o`0000Gooooo3onZ_>HL
oj^liP03o`000?n[_>KoZkcV00OoZkcV00?oooooo`000?ooool0=Oooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo05Oooooo0ol00005ooooo`?oZ[_V3_nZ_>HM
oj^liP03o`000?n[_>KoZkcV00SoZkcV00?oooooo`000?ooool0=?ooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo05Gooooo0_l00006ooooo`GoZ[_V3OnZ_>HN
oj^liP03o`000?n[_>KoZkcV00OoZkcV00?o[;cVooooool00000=Oooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo05;ooooo0ol00005ooooo`WoZ[_V00?oZ[cV
ojZki_nZ^nH02_nZ_>HMoj^liP03o`000?n[_>KoZkcV00CoZkcV1On/_>H00ooooooo0000ooooo`0c
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0D?ooool2
o`0000?ooooo1OnY^nH=ojZkiPWoZ[cV7On[_>H00ol0003oZkcVoj^liP02oj^liPSo[;cV00?o0000
ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo04gooooo0ol00003ooooo`SoZK_V3?nZ^nH:ojZliQcoZkcV00?o0000oj^li_n[_>H02_n/_>H0
0ooooooo0000ooooo`0booooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0Boooool2o`0000Cooooo2onY^nH<ojZkiP;oZ[cV00?oZ[_VojZli_nZ_>H01?nZ_>HL
oj^liP04o`000?n[_>KoZkcVoj^liP[o[;cV00?oooooo`000?ooool0<Oooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo04Sooooo0ol00003ooooo`koZK_V4?nZ
^nH6ojZliQ_oZkcV00?o0000oj^li_n[_>H02on/_>H00ooooooo0000ooooo`0aooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0AOooool3o`0000Cooooo4OnY
^nH@ojZkiP;oZ[cV00?oZ[_Voj^li_n[_>H06on[_>H00ol0003oZkcVoj^liP0<ojbliP03ooooool0
003ooooo033ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`13ooooo`;o00001Oooool00onY^nOoZK_VojVkiP0AojVkiQ?oZ[_V00?oZkcVoj^ki_n[^nH06On[
_>H00ol0003oZkcVojbli@05ojbliP03ojbliOn/_>Ko[;cV00Co[;cV0_ooool00ol0003ooooooooo
o`0^ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0@?oo
ool3o`0000Cooooo1OnY^nLCojVkiQ;oZ[_V1?n[^nH00on[_>KoZk_Voj^liP0Doj^liP03ojbliOl0
003o[;cU00;o[;cU0_n/_>H4ojbli@;o[;cV00Ko[;cUojbli_n/_>Ko[;cVooooool0000`ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0?_ooool2o`0000Go
oooo2?nY^nLCojVkiQ;oZ[_V1_n[^nH<oj^liP03oj^liOn[_>KoZkcV00?oZkcV00CoZkcUojbliOn/
_>Go00003On/_>D01On/_>Ko[;cUojbliOoooooo000002oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`0kooooo`?o00001Oooool;ojVkia;oZK_V4onZ^nH6
oj^kiPSoZkcV1On[_>D00on[_>KoZkcUoj^li@03oj^li@03ojbliOl0003o[;cU013o[;cU00?ooooo
o`000?ooool0;Oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo03Wooooo0_l00005ooooo`?oZ;_W3?nY^nLBojVkiQ?oZ[_V1_n[^nH00on[_>KoZk_Voj^kiP02
oj^liP03oj^kiOn[_>GoZkcU00[oZkcU00?o[;cUo`000?n/_>D04On/_>D00ol0003oooooooooo`0/
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0=_ooool3
o`0000?ooooo2onX^nL8ojVkia?oZK_V4onZ^nH9oj^kiP?oZk_U00?oZkcUoj^kiOn[^nD02On[_>D0
0ol0003o[;cUojbli@0@ojbli@03ooooool0003ooooo02cooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`0cooooo`?o00001?ooool=ojRki`WoZK_W4onY^nHB
ojZkiP[oZk_V1_n[^nD00on[_>GoZk_Uoj^li@04oj^li@03ojbliOl0003o[;cU01;o[;cU00?o0000
ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo037ooooo0_l00004oooooa7oZ;_W2OnY^nLCojVkiQ;oZ[_V2?n[^nH:oj^ki@;oZkcU0_n[^nD0
0on/_>Go[;_Uo`00000Bojbli@03ooooool0003ooooo02_ooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`0^ooooo`?o00001?oooolDojRki`WoZK_W4_nY^nHB
ojZkiPGoZk_V4?n[^nD3ojbki@04o`000?n/^nGo[;cUojbkiA3o[;cU00?oooooo`000?ooool0:_oo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02cooooo0_l0
0005oooooaOoZ;_W00?oZK_WojRkionX^nL01_nY^nLBojVkiQ;oZ[_V0_n[^nHAoj^ki@Co[;_U00?o
0000ojbkiOn/^nD00_n/^nD2ojbli@03ojbkiOn/_>Go[;cU00_o[;cU00?o0000ooooooooool0:Ooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02Wooooo0ol0
0005oooooagoZ;_W1_nY^nLBojVkiQ?oZ[_V4_n[^nD3ojbki@03o`000?n/^nGo[;_U00Ko[;_U00?o
[;cUojbkiOn/^nD02?n/_>D00on]_>Goooooo`00000Zooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool09oooool2o`0000?ooooo8onX^nL6ojVkia;oZK_V4OnZ
^nH00onZ^nGoZk_Uoj^ki@0@oj^ki@?o[;_U00?o0000ojbkiOn/^nD02On/^nD5ojbli@Go[KcU00?o
ooooo`000?ooool0:?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo02Cooooo0ol00003ooooobGoZ;_W1_nY^nLCojVkiPgoZ[_V1OnZ^nDBoj^ki@;o[;_U00?o
0000ojbkiOn/^nD02_n/^nD2ojbli@03ojbkiOn]_>Go[KcU00Co[KcU00?oooooo`000?ooool0:?oo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02;ooooo0_l0
0004ooooobSoZ;_W00CoZK_WojRkionX^nOoZ;_W0_nY^nLFojVkiPSoZ[_V1_nZ^nDAoj^ki@?o[;_U
00?o0000ojbkiOn/^nD02On/^nD00on/^nCo[;_Uojbki@02ojbki@03ojfliOn]_>Co[KcT00?o[KcU
00?oooooo`000?ooool09oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo01oooooo0ol00004ooooobkoZ;_W0onY^nLEojVkiPWoZ[_V1_nZ^nD@oj^ki@?o[;_U
00Go0000ojbkiOn/^nGo[;_Uojbki005ojbki@Co[;_T0_n/^nD2ojfki003ojfli?n]^nCo[KcT00?o
[KcT00?oooooo`000?ooool09_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo01cooooo0ol00002ooooo`GoZ;_X00?oZ;_WojRkj?nX^nP0;?nX^nL3ojVkiaGo
ZK_V1onZ^nH8ojZki@ooZk_U0on/^nD00ol0003o[;_Uojbki003ojbki003ojbkiOn/^nCo[;_T00Oo
[;_T1On]^n@3ojfli003ooooool0003ooooo02Kooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`0Jooooo`;o00000oooool2ojRlj0WoZ;_X00?oZ;_WojRkj?nX
^nL0:?nX^nL4ojVkiaGoZK_V1_nZ^nH8ojZkiA3oZk_U00?o[;_Uojbki?l000003_n/^n@7ojfki0?o
[KcT00?oooooo`000?ooool09Oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo01Oooooo0ol00003ooooo`GoZ;cX1onX^nP01?nW^nSoZ;_XojRkj?nX^nPYojRk
i`;oZK_W0_nX^nLDojVkiPGoZ[_V1_nZ^nD01?nZ^^GoZ[_UojZkiOnZ^nD2oj^ki@03oj^jiOn[^nGo
Zk_U00?oZk_U00?oZk[Uoj^kiOn[^nD00on[^nD01?n[^nCo[;_To`000?l0000<ojbki0[o[K_T0on]
_>@00ooooooo0000ooooo`0Tooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool05_ooool2o`0000?ooooo1_nX_>P2ojNlj0CoZ;_X1?nW^nP01?nX^nSoYk_XojNk
j?nW^nP3ojRki`?oYk_W9OnX^nLEojVkiP;oZ[_V00?oZ[[VojZkiOnZ^nD00onZ^nD4ojZji@03ojZk
iOnZ^^GoZ[[U00?oZk[U00?oZk_Uoj^jiOn[^^D00on[^^D00on[^nGoZk[Uoj^ji@03o`000003ojbk
i?l0003o[;_T00co[;_T2_n]^n@01?n]_>Co[K_Tooooool0000Uooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool05_ooool00ol0003oZ;cXojRlj003ojRlj0So
YkcX3onW^nP00onW^nOoYk_XojNki`02ojNki`;oZ;_W00?oYk_WojRkionX^nL07_nX^nL2ojVkiP03
ojRki_nY^nKoZK_V00koZK_V0_nY^^H3ojZjiP03ojZkiOnZ^^GoZ[[U00WoZ[[U2?n[^^D3o`0000Co
Zk[T00?o[;_To`000?n/^n@02_n/^n@>ojfki003ooooool0003ooooo02?ooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Fooooo`04o`000?nX_>SoZ;cXojRl
j0_oYkcX4OnW^nP6ojNkib3oZ;_W0onX^nH=ojVkiPGoZK[V00?oZ[[VojVjiOnY^^D03?nZ^^D4oj^j
i@?o00001_n[^^@3ojbji004o`000?n/^nCo[;_Tojbji0Oo[;_T3_n]^n@00ooooooo0000ooooo`0S
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool05_ooool0
0ol0003oZ;cXojRlj002ojRlj0_oYkcX4_nW^nP5ojNkib3oZ;_W0onX^nH:ojVkiPSoZK[V0_nY^^D<
ojZji@05oj^jiOl0003o0000o`000?n[^^D01on[^^@5ojbji005o`000?n/^^Co[;[Tojbji?n/^n@0
0_n/^^@2ojbki13o[K_T00?oooooo`000?ooool08_ooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo01Gooooo00Go0000ooooooooooooooooojRlj00=ojNlj1Co
Yk_X00?oYk_WojNkj?nW^nP00onW^nL00onX^nOoYk_WojNki`0GojRki`CoZ;_V1OnX^^H00onY^nKo
ZK[VojVjiP0:ojVjiPCoZK[U2OnZ^^D3o`000003oj^jiOn[^^CoZk[T00WoZk[T1?n/^^@00ol0003o
[;[Tojbji004ojbji17o[K_T0_n^^n@00ooooooo0000ooooo`0Qooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool05Oooool01?l0003oooooooooooooool?ojNl
j1OoYk_X1_nW^nL00onX^nOoYk_WojRki`0DojRki`03ojRki_nX^^KoZ;[V00GoZ;[V2onY^^H7ojVj
i@GoZ[[U0ol00004ojZji@coZk[T1?n/^^@00ol0003o[;[Tojbji004ojbji0;o[K_T00?o[K[Tojfk
i?n]^n@02On]^n@4ojjki003ooooool0003ooooo027ooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo3onW_>PFojNk
j0WoYk_W00?oZ;_WojNkionW^nL04OnX^nL9ojRjiPWoZK[V2OnY^^D01?nZ^^Go0000o`000?l00006
ojZji@03ojZji?n[^^CoZk[T00[oZk[T1On/^^@00ol0003o[;[Tojbji004ojbji0?o[K[T1On]^n@0
1?n]^n?o[K_Tojfki?n]^n@6ojjki003ooooool0003ooooo023ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo4OnW
_>PCojNkj004ojNkionW^nSoYk_XojNkj0SoYk_W00?oZ;_WojNkionW^nL03_nX^nL9ojRjiP;oZK[V
00?oZ;[VojVji_nY^^H00_nY^^H6ojVji@03ojViiOnY^^Go000000;o000000?oZ[[UojZiiOnZ^^D0
1?nZ^^D01?nZ^NCoZ[[TojZji?nZ^^@2oj^ji003oj^ii?n[^^CoZk[T00OoZk[T1On/^^@00ol0003o
[;[Tojbji004ojbji004ojfji?n]^^?o[K[Sojfki0Go[K_S00?o[K_Tojjkhon^^n@01?n^^n@2ojjl
i003ooooool0003ooooo01oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo4_nW_>PFojNkj0coYk_W2_nX^nL00onX
^^OoZ;[VojRjiP0=ojRjiP03ojVji_nY^NGoZK[U00CoZK[U0_nY^ND2o`0000;oZK[U00CoZKWUojZi
iOnZ^NGoZ[WU0_nZ^^D4ojZii003ojZji?n[^NCoZkWT00?oZkWT00?oZk[Toj^ii?n[^^@01?n[^^@6
ojbji004o`000?n/^^?o[;[Tojbjh`Ko[K[S1_n]^n<3ojjkh`;o[[_T0_n^^n<01?n^_>Co[[cSoooo
ool0000Pooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
5Oooool00ol0003oooooooooo`05oooooa;oYkcX5_nW^nP<ojNki`03ojRkionW^nOoZ;_W00CoZ;_W
1?nX^^L=ojRjiP04ojRiiOnY^NGoZKWUojVii@;oZK[U00CoZKWUo`000?l0003o00001_nY^ND00onZ
^NGoZ[WTojZii006ojZii0SoZkWT0_n[^^@2oj^ii003ojbji?n/^N?o[;[S00Co[;[S00Co0000ojbj
hon/^^?o[;[S1_n]^^<6ojfkh`Ko[[_S0on^_><00ooooooo0000ooooo`0Nooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08
oooooa7oYkcX00?oYk_XojNlj?nW_>P05?nW^nP=ojNki`04ojRkionW^^OoYk[WojNji`?oZ;[W3?nX
^^H4ojRii@;oZKWU0ol00008ojVii@;oZKWT2?nZ^N@5oj^ii003oj^ihon[^NCoZkWT00?oZkWT00Go
ZkWSojbihon/^N?o[;WSojbjh`02ojbih`;o[;[S00?o0000ojbjhon]^^<01on]^^<2ojfkh`[o[[_S
0_n^_><2ooooo`03o`000?oooooooooo01cooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo5?nW_>PCojNkj0[oYk_W
1_nW^^L00onW^^KoZ;[VojRjiP02ojRjiP;oZ;WV1?nX^^H8ojRii@?o000000?oZKWUojVhi?nY^N@0
0_nY^N@00onY^NGoZKSTojVhi004ojVii003ojZhi?nZ^NCoZ[WT00?oZ[WT00CoZ[SSojZii?nZ^NCo
Z[WT0_n[^N@4oj^ih`03oj^ii?n[^N?oZkWS00?oZkWS1_n/^N<2ojbjh`03o`000?n]^^?o[K[S00Ko
[K[S0on]^n<:ojjkh`;o[[cS00?oooooo`000?ooool07Oooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02_oooolDojNlj1?o
Yk_X1onW^nL7ojNji`?oYk[V00?oZ;[VojNii_nW^NH00onX^NH00onX^^KoZ;WUojRii@04ojRii@05
ojRhiOl0003o0000o`000?nX^ND01OnY^>@00onY^NCoZKSTojVhi003ojVhi003ojVii?nY^>?oZ[ST
00;oZ[ST0_nZ^N@4ojZhh`03ojZii?n[^>?oZkWS00[oZkWS2?n/^N<00on/^^?o0000ojfjh`08ojfj
h`03ojfkhon^^n?o[[_S00So[[_S00Ko[[cSojnlhon__>?o[kcSooooool0000Mooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00ol0003ooooooooo
o`0;oooooa?oYkcX5?nW^nP3ojNki`_oYk[W00?oYk[VojNii_nW^NH00onW^NH00onX^NKoZ;WUojRi
i@03ojRii@06ojRhiOl0003o0000o`000?nX^>GoZ;WU0_nX^>@:ojVhi0CoZKSS00?oZ[STojZhhonZ
^><01?nZ^><4oj^hh`;oZkWS0_n[^><6oj^ih`So[;WS0_n]^^<00ol0003o[K[Sojfjh`06ojfjh`Wo
[[_S0on^_><3ojnlh`;ooooo00?o0000ooooooooool06_ooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool03?oooolCojNlj1;o
Yk_X1OnW^nL7ojNji`[oYkWV00?oZ;WUojRhiOnX^>D00ol000000onX^>GoZ;OTojRhi003ojRhi0Go
ZKOS0onY^>@2ojVgh`CoZKSS0_nZ]n<4ojZhh`;oZ[OS00?oZkSSoj^gh_n[^><01?n[^><01?n[^>;o
ZkSSoj^hhon[^><2oj^ih`03ojbhh_n/^N?o[;WS00Oo[;WS00?o[K[Sojfihol000002?n]^^<9ojjk
h`03ojjlhon__>?o[kcS00?o[kcS00?oooooo`000?ooool06oooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool03OoooolDojNl
j17oYk_X0onW^nL6ojNji`03ojNji_nW^NKoYkWV00SoYkWV00GoYkSUo`000?l0003o0000ojRhi@05
ojRgi003ojRhi?nX]^?oZKOS00CoZKOS00?oZKKRojVghonY]n<00_nY]n<2ojZfhP?oZ[OR00?oZ[OS
ojZfh_nZ]n800onZ]n800onZ]n?oZkORoj^ghP02oj^ghP;oZkSS00GoZkORoj^hh_n[^>;oZkSRoj^h
h`05ojbhhP03ojbihon/^>;o[;WS00Co[;WS0on]^N<00ol0003o[K[Sojfjh`04ojfjh`?o[[[S1on^
^n<8ojnlh`03ooooool0003ooooo01[ooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo4onW_>P@ojNkj0[oYk[W0_nW
^^H7ojNiiP?o000000?oYkSUojRhiOnX]n@01OnX]n@4ojRfh`;oZKOS00KoZKGRojVfh_nY]^;oZKKR
ojVghonY]N44ojZfhP03ojZgh_nZ]N7oZ[KR00;oZ[KR0_nZ]n800on[]^7oZkORoj^ghP02oj^ghP03
oj^fhOn[]n;oZkOR00;oZkOR00?oZkSRojbgh_n/^>802?n/^>800on/^N?o[;WRojbihP02ojfih`04
ojfih_n]^N?o[KWSo`0000Ko[K[S00?o[[[Sojjkhon^^n<01_n^^n<7ojnlh`03ojnli?oooooo0000
01_ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Coooo
o`03o`000?oooooooooo017ooooo4_nW_>P<ojNkj0;oY[_X1?nW^^L00onV^^OoYk[WojNji`03ojNj
i`GoYkWV0onW^>D2o`000003ojNhiOnW]^CoYkOT00;oYkOT1?nX]n@2ojRfhP?oZ;KS0onY]N42ojVe
hP03ojVfh_nY]>7oZKGQ00;oZKGQ0_nZ]^801_nZ]>3oZ[GQojZehOnZ]N7oZ[KRoj^eh0CoZkKQ00?o
ZkORoj^fhOn[]^400_n[]^42oj^ghP;o[;OQ0_n/]n800on/^>;o[;OQojbgh@02ojbhhP05ojbhhOn/
^>;o[;SRojbhh_n/^N801On]^N800on]^N?o[KWRo`000004ojfjh`;o[[[S1on^^n<00on_^n?o[kcS
ojnlh`04ojnlh`?o[kcT00?oooooo`000?ooool06Oooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04OoooolAojNlj0CoYk_X
1?nV^nP00onW^nSoY[_XojJkj005ojJkj003ojNjionV^^OoY[[W00;oY[[W0_nW^^L2ojJiiP?oYkWV
0_nW^>D3o`000003ojNhiOnW]^CoYkKT00;oYkKT00?oYkOTojNeh_nW]N800onX]N800onX]^;oZ;?Q
ojRdh@02ojRdh@;oZKGQ00CoZK?OojVdh?nY]>3oZKCP0_nY]>401?nY]N7oZ[?OojZcgonZ/ml2ojZd
h003ojZehOn[]=ooZkCO00;oZkGP0_n[]^42oj^eg`03oj^fhOn/]=oo[;KP00?o[;KP00?o[;OQojbf
h?n/]n400on/]n42ojfgh@?o[;SQ00?o[;SRojfhhOn]^N802?n]^N800ol0003o[[[RojjjhP03ojjj
h`Go[[_S1?n_^n<5ojnlh`Co[kgT00?oooooo`000?ooool06?ooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_oooolAojNl
j003ojNkj?nV^nSoY[_X00WoY[_X00?oY[[XojJjionV^^L00_nV^^L5ojJii`04ojJii_nV^>KoY[SU
ojJhi@?o00000_nW^>D5ojNfi003ojNdh_nW]N;oYkGR00;oYkGR00?oZ;GRojRch?nX/n400_nX/n40
0onX]>7oZK;OojVbg`03ojVcg`03ojVdh?nZ/MkoZ[;N00;oZ[;N0_nZ/ml01_n[/]goZk?Noj^cg_n[
/mkoZkCOojbbg@Co[;?N00?oZkGOojbcg_n/]=l00_n/]=l2ojbfh006ojfegon/]^3o[;KPojbfh?n/
]n7o[KKP1?n]]n400on/^>7o[KOQojfhh@02ojfhh@03ojfih_n]^>;o[KSR00Co[KWR00Co[[WRo`00
0?n^^^;o[[[R1?n^^^<5ojjkh`;o[k_S1on__><2ojnmi0;o/;gT00?o0000ooooooooool05oooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01?ooooo00?o0000
ooooooooool04oooool=ojNlj0CoY[cX2OnV^nP4ojJjj003ojJjionV^NOoY[WW00CoY[WW0_nV^>H3
o`0000GoY[KT00?oYkKTojJdh_nW]>801?nW]>82ojNehP;oZ;;P0_nX/n000onX/n7oZ;7NojVbg`03
ojVbg`03ojVcgonZ/=goZ[7N00;oZ[7N00?oZ[;Noj^`g?n[/=`00on[/]d00on[/mko[;7Lojbbg@02
ojbbg@;o[;?N00Ko[;;Lojbcg_n//mko[;?Nojbdgon]/md4ojfeg`03ojbfh?n]]Mko[KKP00;o[KKP
0_n]]n42ojfgh0;o[KOQ0on]^>400on]^>;o[[SQojjhh@04ojjihP04ojjjh_l0003o[[[RojjjhP;o
[[[S1On^^n<2ojnkh`Oo[kcS0_n__N@3ok2mi003ooooool0003ooooo01Oooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01Go
oooo2?nW_>P6ojJlj0[oY[_X00?oY[[XojJjionV^^L00_nV^^L2ojJii`03ojJii_nV^>KoY[SV00?o
000000?oY[SVojJfiOnV]^D01?nV]^@4ojJdhP03ojNdh_nW/^3oYk;P00?oYk;P00?oZ;;PojR`gOnX
/=h00_nX/=h2ojRagP;oZK;O00KoZJoLojZ`gOnZ/=goZ[3MojZag_n[[m/4oj^`g003oj^bgOn/[m_o
[;7L00;o[;7L00?o[;;Mojfafon]/M/00on//]`00on//mko[K;Lojfcg@02ojfcg@;o[KGO00Go[[CM
ojfeg_n]]Mko[KGNojffh002ojjfgP;o[KOP00Ko[[KOojjgh?n^]n3o[[OPojfhhOn^^>04ojjhh@03
ojjih_n^^N7o[[[R00;o[[[R00?o0000ojjjh_n^^^800_n^^n<5ojnkh`Ko[kcS0on__N@4ok2mi0;o
oooo00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo@000000C01TI6EX0
00001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo1?nW_>P2ojNlj@?o
YkcX1OnV_>P9ojJkj0;oY[[X0onV^^L3ojJii`?o000000GoYKOUojJgiOnV]nGoY[OUojJfi@02ojFd
h`?oY[CS0onV]>800onV/N3oYk;PojNbh003ojNbh006ojN_gOnX/=goZ;3MojR`gOnX/=koZ:gK1?nY
[]/2ojV_g003ojZ`gOnZ[][oZjoK00;oZjoK0_n[/=`01_n/[]Wo[:oKojb_fon/[m_o[;7Lojf_f@Co
[K7K00?o[;;Lojf`f_n]/]`00_n]/]`00on]/mgo[[;Kojjbf`03ojjdg@05ojfeg_n^]=go[[CMojjf
g_n_]Md01?n^]]l00on^]n3o[[OOojjhh002ojjhh0Co[[SQ0_n^^N43ojjjhP03o`000?n_^^;o[k_S
00Go[k_S1on__><00on__NCo/;gTok2mi003ok2mi0;o/;kT00?oooooo`000?ooool05_ooool000Wo
oooo00@00000oooooooooooooooo>@00000T01TI6E0000001?ooool00`00003oooooooooo`0Boooo
o`03o`000?oooooooooo01Oooooo00?oYkcXojNljOnW_>T00onW_>T00onW_>SoY[cYojJlj003ojJl
j0OoY[_X1?nV^^P2ojJji`;oY[WW0ol00003ojFgiP;oYKOU00?oY[OUojFdi?nU]>@00onU]><00onV
]>?oYK7QojJah004ojJah003ojNbh?nW[mgoYjoM00?oYjoM00?oZ;3MojR/f_nX[M/00_nX[M/2ojV^
f`04ojV[f?nZ[=WoZZcIojZ/f@;oZZkJ00?oZjoKoj^/f?n[[=P00on/[]T00on/[m_o[JgHojf_f@02
ojf_f@;o[K7K00Go[ZoHojf`f_n]/=[o[K3Jojfbg002ojjafP03ojjbfon_/MWo[k7I00?o[k?K00?o
[[CMojncg?n_]Md00_n_]Md2ojjfg`05ojnfg_n^]moo[[OOojjggon^^>000_n_^>02ojjhh@07ojni
h?n_^N7o[kWQojnihOn^^^;o[k[Ro`000002ojnjhPKo[k_S1On__><00on__NCo/;gTok2mi002ok2m
i0Co/;kT0_ooool00ol0003oooooooooo`0Dooooo`002Oooool01000003oooooooooooooool`0000
0003o`0000000000000003406ATI00?o0000000000000000AP000004ooooo`0300000?oooooooooo
01;ooooo00?o0000ooooooooool06Oooool3ojNlj@CoY[cY1?nV_>P7ojJkj0CoY[[X0ol00004ojFh
iP03ojFgi_nU]^GoYKGT00?oYKGT0_nU]>@00onU]>?oYK;QojFah@02ojFah@03ojJah?nU[]koYZkM
00?oYZkM0onW[md01OnW[=[oZ:cJojR/f_nX[=[oZ:gK00;oZJWG0onYZmP00onZ[=WoZjWEoj^[eP02
oj^[eP?oZjcH00?o[:kIojf[e_n][MP00_n][MP00on][mWo[ZgFojj_f003ojj_f005ojf`f_n_[mSo
[joHojjaf_n`[mL01?n_/MT00on_/m_o/;;Jojncg002ojncg003ojnegOn`]=co[kKN00?o[kKN00Go
[[OOojngg_n_]mko[kSPok2hg`04ojnih0;o[kWQ0on_^^800ol0003o[k_RojnkhP02ojnkh`Go[kcS
0_n__N<2ojnmi0Co/;gT1On`_^@2ooooo`03o`000?oooooooooo01?ooooo0009ooooo`0400000?oo
ooooooooooooobl00000>@0I6AU5000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0Jooooo`;oYkcY1_nV_>T00onV_>SoY[_XojJkj004ojJkj0CoY[[X0_l00003ojFii`?oYKSV
1?nU]^D2ojFei004ojBbhonU/^;oYK;RojFbhP;oYK;Q00?oYK7QojF^g_nU[]h00_nU[]h2ojJ^g@04
ojJZf_nVZm[oYZ_JojJ[fP;oYjcJ00?oZ:cJojRXeonYZML00onYZML00onYZmSoZZODoj^Ye@02oj^Y
e@03oj^[e_n/Ym;o[:OB00;o[:WD0on]ZmH00on][MSo[Z_Dojj]eP02ojj]eP;o[ZoH0_n_[MD00on_
[mSo/:gDok2_e`02ok2_e`;o[k7I00Ko/K3Gok2bf_n`/][o/;;Jojncg?na/mX3ok2dg0;o[kKN0_n`
]]d00on_]mko/;ONok2hg`02ok2hg`;o[kWP0_n`^N02ojnih@?o[k[R00?o0000ojnkh_n__><01_n_
_><00on__N?o/;gTok2mi004ok2mi0Go/;kT0_n`_nD00ooooooo0000ooooo`0Dooooo`002Oooool0
1000003oooooooooooooool/000004806ATI?`000004ooooo`0300000?oooooooooo01;ooooo00?o
0000ooooooooool06oooool8ojJlj@OoY[_X0ol000001?nU^^SoYKWWojFiionU^NL4ojBgiP03ojFf
iOnT]>CoY;CT00?oY;?S0_nT/^<00onU/^;oY:oOojB^g`02ojB^g`?oYJkN0_nUZ]X3ojJZfP04ojJ[
f_nVYmKoYjOFojNWeP?oZ:SG0_nYZML01_nYY]?oZZODojZWe?nZYmCoZjWEoj^Ud@Co[:OB0_n/ZM@0
0on]ZmKo[ZSBojj[e002ojj[e006ojj]e_n_Z]?o[j[CojnZdon_[MGo/J_B0on`[M@00on`[mOo/JkD
ok6`e`03ok6`e`03ok2bf_nb/MSo/K?J00;o/K?J00Ko/;CLok6dfona]=_o/KCKok2fgOnb]]`3ok2g
gP03ok2hgona^=ko/KSN00;o/;WP00Wo/KWOok2jhOn`^^7o/;[Qojnjh_n`^n;o[k_Ro`000?n_^n80
0_n__><2ok2lh`03ojnlhon`_N?o/;gT00?o/;gT1On`_^@6ok2oi@03ooooool0003ooooo01?ooooo
0009ooooo`0400000?ooooooooooooooobX00000B00I6ATk000000Cooooo00<00000ooooooooool0
4_ooool00ol0003oooooooooo`0Looooo`KoY[cY00?oY[_YojJkj?nV^nP00_nV^nP3o`0000?oYK[X
00CoYKWWojFhionU^>OoYKSW0onT]nH2ojBei@?oY;CT00?oY;?Soj>`hOnS[n400_nS[n42ojB_g`03
ojB^gonSZmcoY:[K00;oY:[K0onUZ]X00onVZ][oYJKFojJWeP02ojJWeP;oYjOF00?oZ:SGojRTd_nX
Y=800onYY]<00onZYmCoZZ?@oj^Ud@02oj^Ud@;o[:OB00?o[JC>ojfVd?n]Y]000on^Z=800on^ZmCo
[jS@ojnZd`02ojnZd`06ok6XconaZm;o/J_Bok6[d_n`[MCo/Z_B0ona[]@2ok6`e`05ok:_eOnb/MSo
/[7Hok:af?na/mX00_nb/]P2ok6df`05ok>dfOnb]]co/[KLok:fg?n`]mh00_nb]md00ona^=ko/[SN
ok6ig`03ok6ig`03ok2jhOna^^7o/;_R00;o/;_R00?o0000ok2lh_n`_>800_n`_><4ok2mh`03ok2m
i?n`_^Co/;kT00Ko/;kT1?n`_nD00on``>Goooooo`00000Dooooo`002Oooool01000003ooooooooo
oooooolV00000003o`00000I6AT06ATI04d06ATI=`000004ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool07Oooool5ojJlj@;oY[_Y0ol000001?nV^nSoYK[XojFjj?nU^^P2ojFij0;o
YKWW00?oYKSWojBgi_nT]^D00onT]^D2ojBei@03ojBdi?nS/N;oXk3Q00;oXk3Q00CoXjoQoj:/g_nS
ZmgoXj_M0onSZm`3ojBZf`03ojFZf_nTY]OoYJKF00;oYJKF00CoYZOFojJRd_nWXm;oYj?B1?nXY=80
0onYY]?oZJ7?ojZSd002ojZSd003oj^UdOn/XLco[JC>00?o[JC>0_n]Y]000on^Z=;o[jG>ojnXd002
ojnXd006ojnZdonaZ<oo/JS?ok6XconaZm;o/ZS?0onbZm800ona[]Co/jgBok>]dP03ok:_e@05ok:a
f?nc/=Ko/k3Fok:bf?nd/]L01?nc]=T01Onb]]co/kKKok>ffonb]mgo/kOL00?o/[SN0_na^Ml2ok:j
g`;o/K[Q0on`^n800ol0003o/;cSok2mh`04ok2mh`;o/;gT1on`_^@3ok2oi@Co/<3U00?oooooo`00
0?ooool04_ooool000Wooooo00@00000oooooooooooooooo9@00001D01TI6C@000001?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo0onV_>T3o`0000?oY[_X1?nU^^P00onU
^NSoY;SWojBgi`02ojBgi`;oY;OV0_nT]^D01?nS/nCoXk;Soj>bhonS/^<2oj>ahP03oj>`hOnR[Moo
XZcN00;oXZcN0_nSZmd00onSZmcoXZKHoj:Vf003oj>Ve`;oY:KG00?oYJKFojFQd_nVX]800_nVX]82
ojNSdP;oZ:CB00KoZ:3>ojVQconYXLooZJ7?ojZSd?n[Wl/3ojbQc0?o[JC>00?o[JK@ojjSc?n_YLh0
0_n_YLh00on_Z=3o/:G=ok2Uc@03ok6Xc`?o/ZS?00?o/Z_BokBZconc[M800onc[M801Onb[mGo]:kB
okB^d_nc/=Ko]K3C00?o];;G0_nc]=T2okBdf003ok>ffone]][o/kOL00;o/kOL00?o/[SNok>ig_nc
^Mh00_nb^]l01Onc^]oo/K_Qok6khOna^n7o/;_R00;o/KcR00?o0000ok2lhon`_N<00_n`_N<2ok2m
i0Go/;kT1?n`_nD5ok30i@;o/L3V00?oooooo`000?ooool04Oooool000Wooooo00@00000oooooooo
oooooooo8`00001I01TI6@0300000?l00000000002h000001?ooool00`00003oooooooooo`0Aoooo
o`03o`000?oooooooooo01oooooo0ol000000onV_>WoY[_YojJkj@03ojFkj0?oYK[X0_nT^NP2ojBh
i`03ojBgionS]^KoXkKV00?oXkCU0_nS/n@00onS/^?oXJoRoj6^h002oj6^h0;oXZgO00?oXZcNoj6W
fonQYm/00_nQY]X3oj:Vf004oj>VeonRXM?oXj7Boj>QdP?oYJ7B0_nVX]800onWXm;oYik=ojNNc@03
ojRPcP03ojVQconYWL[oZio;00;oZio;0on/XL`00on]Y<ko[Z3:ojjSc002ojjSc003ojnUc_n`Xl[o
/:G=00?o/:G=00?o/JS?ok:Vc?nbY/`00_nbZ<l3okBZc`;o/jgB00Co]Jc?okB^d_nd[];o]:kB0one
/=<00ond/]Oo][;EokBdf002okBdf005okJdeone]][o]KKJokFff_nc]m`00_nd^=`00onc^Mko];[M
ok>jg`03ok>jg`09ok6khOnb_>7o/[cQok6lh_nb_N;o/KgSo`000?na_N?o/;gS00;o/KkT1?n`_^@7
ok2oi@;o/<3U0ona`>H2ok71iP03o`000?oooooooooo013ooooo0009ooooo`0400000?oooooooooo
ooooob400000G@0I6AT_000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0L
ooooo`?o00000_ooool00onV_>WoY[_YojJkj@02ojJkj@03ojFkj?nU^^SoYK[X00;oYK[X00?oY;WX
oj>hionS^>L00onS]nL2oj>fiP03oj>diOnQ/^CoXK7S00;oXK7S0_nQ[n801?nQ[^3oWj[Noj2Xg?nP
Z=`4oj6Wf`;oXJKJ00?oXZKHoj6Qe?nRXM<00_nRXM<2oj>QdP03ojFQd_nTW<koYIg=00;oYIg=0onW
W/d00onXX<koZ9_9ojVMbP02ojVMbP;oZio;0_n/XL`01_n]W/So[Z3:ojjPb_n^X<[o[Z?<ojnPb0?o
/:?:0_n`YLd01OnbXlWo/ZK<ok:Vc?nbY/co/ZS?00;o]:O;00?o]:[?okJYc?ne[<l00one[<l01Ond
[];o]Zk@okJ^d?ne/=?o]k3B00?o][;E00Ko];CHokJdeonf]=Oo][CGokFff_nf]mT3okBhg0?o];[M
0_nc^]l2ok>kg`03ok:lhOnc_N7o/[gR00;o/[gR00Co0000ok6nhona_^?o/KkT1Ona_n@4ok2oi@Co
/<3V00?o/L3Vok71i_na`NH00ona`NH00ooooooo0000ooooo`0@ooooo`002Oooool01000003ooooo
oooooooooolO00000003o`00000I6AT06ATI05h06ATI;@000004ooooo`0300000?oooooooooo017o
oooo00?o0000ooooooooool06Oooool3o`0000Kooooo00?oY[_YojFkjOnU^nT00_nU^nT3ojFjj0?o
Y;WX0_nS^>L00onS]nOoX[GVoj:ci@02oj:ci@;oXK;T00?oXK7Soin]hOnO[=l00_nO[=l2oinZgP;o
X:SL0_nQYm/00onOX]SoX:;Foj2ReP03oj6Qe0;oXZ7C00?oXj7Boj:Lc_nTW<h00_nTW<h3ojFMc@03
ojNNcOnWV/WoZ9_900;oZ9_90_nYWLX00on[Wl_oZi_6oj^KaP03ojfNb003ojjPb_n_WLGo[j3800;o
[j3800?o/:?:ok:Pa_nbX<H00onbXlT00onbY/co]:C8okBWb`02okBWb`?o]ZW<0_ne[<l01?ngZlgo
]Zk@okJ^d?nf[]03okN`dP03okJbeOnh/]Co^;;D00;o][CG00Go^;GFokJgfOnf]mWo][OIokBhg002
okJif`03okBjgOnf^mgo][_M00;o/k_O00Go];cOok>mhOnc_N7o/kgQok:mhP02ok:nhP03o`000?nb
_nCo/KoT00Co/KoT00Co/KoUok2oiOn`_nGo/L3U1?n``>H7ok71iP?o00004?ooool000Wooooo00@0
0000oooooooooooooooo7P00001U01TI6BX000001?ooool00`00003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Kooooo0ol0000:ooooo`?oYK_Y0onU^^P3ojBij004oj>hionR]^OoX[KWoj:fi`;o
X[GV00?oX[?Uoj2ai?nO[n<00_nO[n<2oin]h@03oin/gonMYmgoWJOM00;oWJGK0_nNY=T3oinRf0;o
X:;F00CoXJ7DoinLd?nQVlooXI_?0onRW<h2ojBLcP;oYIg=00CoYIS8ojNJbOnWV/WoYi[90_nXVlT0
0onYWL[oZYW5oj^KaP03oj^KaP03ojfNb?n]V/Co[ig500;o[ig500?o[j38ok6Ma?nbX<H00onbX<H0
0onbXlWo]:75okBTb002okBTb004okBWbonfY/So]ZK8okJYc0;o^:S90ongZld01Onf[]3o^Jg>okV]
c_ng/=;o^[3@00?o^;;D00Go^[?BokRee_nh]MKo^;GFokJgf@02okRhf@05okJifonh^]_o^;[KokJk
gOng_=d01?nd_=l02Onc_N7o];kQokBnhOnb_^;o/koSok:oi?l0003o/[oTok6oi003ok6oi@Go/L3U
00Co/<3Vok71i_na`NKo/L7V0_na`^H00ona`NKo/L;Wok72i`02ok72i`03ooooool0003ooooo00oo
oooo0009ooooo`0400000?oooooooooooooooa`00000JP0I6AT00ol0000000000000000T000000Co
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o00003_ooool3ojFkj@03
ojFjj?nT^NSoXkWX00;oXkWX0_nS^>L00onR]^OoXKCVoj2ci@02oj2ci@;oX;7T00?oWjoSoif/hOnM
[>400_nMZMl3oifWg@;oWJGK0_nNY=T01?nOX]SoW9gDoijLd_nNW=83oinLd0;oXI_?00?oXYc>oj6G
bOnSUlT00_nSUlT3ojFHb0;oYi[900?oZ9_9ojRGaOnZVLD00_nZVLD2oj^KaP04ojbH`_n]V/Co[I[4
ojfJa0;o[ig50onaWL@2ok:PaP06ok>N`_ndXLGo]:75okBQaOndY<So]Z?50onfY/P4okRXb@03okN[
cOnjZl[o^Jg>00;o^Jg>0onj/=001Onh/]Co^[?BokZcd_nj/m;o^;GF00;o^[KE00?o^;SIokZif?nh
^]/00_nh^]/3okNlg@;o];cO00?o][gPokBnhOnd_^400_nd_n82ok>oh`04ok:oi?l0003o/[oTok6o
i@?o/L3U1_na`NH3ok72iPGo/L;W0_na`nL00ol0003oooooooooo`0>ooooo`002Oooool01000003o
oooooooooooooolJ000006d06ATI9P000004ooooo`0300000?oooooooooo013ooooo00?o0000oooo
ooooool04_ooool3o`00017ooooo00?oYK_YojBjjOnT^^T00_nT^NP00onS^NSoX[OXoj:fi`02oj:f
i`;oXKCV00?oX;?Uoij`i?nN/>@00onM[^<2oif/h@;oWJWO00CoWJOMoiZRfonKX=SoVj3H0_nKW]H3
oibMe0;oWYcB00CoWic@oifFc?nOU/_oWiK;0onQUlT3oj>Gb@04ojFHb?nTU<CoYYK4ojJFa0?oZ9O5
00?oZYW5ojZF`On/V<800on/V<82ojfJa003ojnMaOn`V/;o/9[200;o/Ig400Co/Z36ok>N`_ncW/;o
/ik20_ndXLD3okJSa@03okJVb?nhYLGo^:G500;o^:S900Go^ZS7okZ[b_njZl[o^Z_:okV]cP02ok^^
c003okZ`d?nl/Loo_;7?00;o^[?B00Co_KCBokZfeOnj]]Go^[KE0onj^MP01?nh^]_o^K_KokVkfong
_=d2okRmgP03okJmh?ng_n3o]koP00;o];oR00Go]L3Rok?0honc`>?o/l3So`000002ok;1i@03ok70
iOnb`NKo/L7V00Co/L7V0ona`^H5ok72i`?o/L?W00?o/L?Xo`000?ooool03oooool000Wooooo00@0
0000oooooooooooooooo6@00001`01TI6B@000001?ooool00`00003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo0ol0000Eooooo`;oY;[Y0onS^NP2oj:gj003oj:fionP]>OoX;CW00?oWk;V
0_nN/>@01?nM[^?oVj[RoiZWgonJYml2oiZUg@?oVZ;K0_nKX=P2oi^NeP04oibMe?nJV=3oViO>oi^G
cP?oWIK<0_nOU//2oj6Gb@;oXiO900CoXY?4ojBDa?nTU<CoY9C40_nVU/@00onXUlGoZ9?0ojZF`@02
ojZF`@?o[9S200?o[I[4ojjH`?n`V/800_n`V/800onaWLCo/Y_0ok>N`P03ok>N`P03okBQaOnfWl;o
]Yo200;o]Z?50onhYLD01_nhZ<Wo^ZS7okZXaonjZ<Oo^Z_:okb[b0?o^jk<0onl/Ll4okfddP04okZf
eOnl^=Go_;SEokZif0;o_;_H00Go^K_Kok^mfonk_M_o^;gNokVogP03okNoh0Co]L3R00Co/l3Sok?1
i?nc`NCo00000_nb`^D2ok;1iP04ok71i_na`^Ko/L;Vok72iP?o/L;W1_na`nL3ok73j003ooooool0
003ooooo00kooooo0009ooooo`0400000?oooooooooooooooaP00000L`0I6AT00ol0000000000000
000O000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`?o00006Ooo
ool2ojBjj@04oj>ij?nR]nSoX[OXoj:gj0;oXKKW0_nP]>L00onO/^KoW;3Uoi^]h`02oi^]h`;oVj[R
0_nJYml2oiZUg@04oiZRfonGWMSoUi_EoiNKe@;oV9WC0onJV=02oi^GcP;oWIK<00CoWiK;oifAa_nP
T/GoX9;51?nRTl@2ojBDa003ojJFa?nVT/3oZ9?000;oZ9?00onZU/400on/V<;o[IFnojjH`002ojjH
`003ok2J`_naV;ko/Y_000;o/Y_00_ncW/801OneW;oo]Yo2okJO`_nfWl;o]Z?500;o^:;200?o^:G5
okZU`onjYL<00onjZ<L3okb[b004ok^^c?nn[l_o_Zo;okbac`;o_k;>0_nm]=82oknfd@05okbheOno
^]Go_k[Eokbkf?nn_MT00onk_M/3okVogP03okNoh?ng`N7o]l7Q00;o]L3R0_nf`N<01Onc`NCo]<;U
okC2iOl0003o//?V00?o//;V00Co/L;Vok73iona`nOo/L;W0_na`nP4ok73i`03ok33j?na`nSo/L?X
00?ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5`00001e01TI
6B4000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0ol0000Noooo
o`;oXkWX00?oX[OXoj2fj?nO]>L00_nO]>L2oijbiP;oW;3U00CoVjgSoiRYh_nGY^3oUjKP0_nGXmd2
oiJPf`?oUigH0_nGVmD2oiRId`;oVYS@00CoViO>oiVAb_nKTLSoVi780onMTLH2oj2Ba@?oXY?400?o
Y9C4ojB@`?nVT/000_nVT/02ojRC`0;oZYK100CoZi>mojfE__n]UKko[IFn0_n^V<03ok6H_P;o/Y_0
1?neW;l00onfWl;o^9nookRR`P02okRR`PCo^ZG300Go^ZS7okfXaOnmZ<Go_:_8okn/a`03okj_b`?o
_k;>0ono]]401?o2^=7o_k[EoknjeOno^]D3okjmf@04ok^mfonl_mco_;oLokVogP;o^/7O00?o]l7Q
okS2h_nh`^800_nf`N<01Onf`nCo]<;UokC2iOnd`nKo000000;o//?V00Co//;Vok;3ionb`nOo/L?W
0ona`nP00onaa>So/<?Xok33j002ok33j0Kooooo00?o0000ooooooooool03Oooool000Wooooo00@0
0000oooooooooooooooo5@00000M01TI6AH00000AP0I6ATO000000Cooooo00<00000ooooooooool0
4?ooool00ol0003oooooooooo`06ooooo`?o00008Oooool3oj6hj0;oX;KX00CoWkCWoifbionK/>Ko
Vk3V0onJ[N@2oiRYhP;oUjKP0_nGXmd2oiJPf`04oiNMf?nBV=GoTiGBoi>EdP;oUI??0_nGT/d3oiVA
bP;oVi780onMTLH2oj2Ba@03oj:Ca?nQS/7oY93000;oY9300_nVT/000onXTl3oZ92loj^C_@03oj^C
_@;o[IFn00?o[YS0ojnF_?n_U[`00_naV;h00onbVl3o]9ZmokBJ_@03okFL_`?o^9no00?o^:;2okZR
`?njX/000_njYL<01?nmYL7o_JS5okfXaOnmZ<D3okn/a`04okj_boo0/<[o`;3:oknbcP;o`KC=00Go
_kKAol:hdOo2^=7o`[SAoknje@02ol6le@04okjmfOno_mWo_koIokbog0;o_L7M00Co^/7Ook_3h?nk
`n3o^<;R0_nha><00onf`nCo]/CUokK4i@03okC3iP04o`000?nba>Oo//CWok;3i`;o/LCX00?o/L?X
ok74j?naa>P00_naa>P00on``nSoooooooooo`06ooooo`03o`000?oooooooooo00gooooo0009oooo
o`0400000?oooooooooooooooa@000006`0I6AT3000001H0<c<c1`00001101TI6Ad000001?ooool0
0`00003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`03oj6hj?nP]nSo
W[CX00;oW[CX0_nM/^L2oi^`iP04oiZ]i?nFZN?oU:GQoiBUh@;oTj;N0_nBW]`2oi:Kf@?oTYSE0_nC
UM82oiFCc`;oUi;=0_nITLX2oi^Ab0;oWI7600?oW8c3oij=`OnNSL400onQS/42ojB@`003ojJB`?nV
S[coZ92l00;oZ92l0on[Tkd00on]UKko[I>kojnF_002ojnF_003ok6H__nbUk_o]9Zm00?o]9Zm00?o
]IbookNL_?ngW;`00_nhWkl3okZR`005okZU`onmYL7o_JG1okfU`OnmZ<D00_noZL<00ono[<Oo`Zg6
ol2`bP02ol2`bP?o`KC=00?oa;O=ol:hdOo2^=400_o4^m401?o1_=Go`kkFol>ne_no_mT2ol72fP04
okg1gOnna=ko_/CNok_3h0;o^lGQ00Go^<CSokS5i?nhaNCo]/CUokK5iP03okC4iP03ok;4iol0003o
//CW00;o/LCX0_naaNP00onaa>Soooooooooo`0:ooooo`03o`000?oooooooooo00gooooo0009oooo
o`0400000?oooooooooooooooa<00000600I6AT200000003o`0000000000<c<c01l0<c<c1000000o
01TI6A/000001?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`?o0000:Ooo
ool2oj2gj003oijdj?nL/nSoV[3W00;oV[3W0_nH[ND2oiJYh`;oU:GQ0_nCX]h2oi:Ng0;oTY_I0_nB
V=D2oi>EdP04oiFCconAS/coThc9oi><b@;oUXc60_nIS<@4oib<``;oWXg10_nQS/401?nTT<3oXhbl
ojJ>_?nVS[`4ojR@_003oj^C_On[T;[o[I>k00;o[I>k0_n_U[`3ok:G^`;o]9Zm00Go]YVjokNL_?ng
W;co]iblokRO_`02okZN_@;o^Z;00onmYL401?o0Y[oo_jW3oknY`onoZL<3ol:]aP04ol2`b_o3//Wo
`k;9ol6dc@;oa;O=0oo4^m401?o7_];o`kkFol>ne_o3_]H3ol72fP05ol?4fonna=ko_lKOoko6gonk
aN400_nlan<00onhaNCo^<OUokK5iP02okK5iP06okC4i_ndaNOo]<GWok;4iol0003o//GX0_naaNP>
ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooa<000005@0I6AT3
000002P0<c<c0P00000n01TI6AX000001?ooool00`00003oooooooooo`0?ooooo`Co0000;_ooool0
1?nN]NWoW;?Xoibcj?nJ/>L2oiJ]i`;oU:WU00?oTJGSohnQh?n?XN000_n>WMd2ohfIfP;oSIGF0_n>
T]<2ohn?c`?oTHk<0_nCS<T2oiJ<aP;oVHc40onLS<<2oij=`@04oj6>`OnPRkgoXhbloj><_0?oYXjl
0_nXT;`01?nYS[WoZi2joj^@^_n[T;X2ojfC^`03ojnF_?naU;Wo/YNk00;o/YNk00Co]9ZmokJI^_nf
VK[o]YVj0_ngW;`3okZN_@04okZR`?nmX[ko_J:nokfU`@?o`:Jo0_noZL<01Oo3Zl;o`Zg6ol:]a_o5
/<Go`k;900;oa[C900Coa;O=olNicOo7^Lgoa;_A0oo7_]801?o3_]KoaL;GolG2eoo1`]X2ol?4f`?o
_lKO0onlan<3okS7i@04okK5i_nfanOo]/OWokC5i`;o/lKX00?o0000ooooooooool03oooool00ol0
003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolB000001D06ATI00<0000003<c
<`0c<c<0:`0c<c<00`0000006ATI01TI6@0l01TI6AT000001?ooool00`00003oooooooooo`0?oooo
o`;o0000<?ooool3oi^dj@;oVK7X0_nF[NL2oiBYi@03oi6Uhon?XN3oSj7P00;oSYgM0_n=VMX2ohfE
eP;oSY;C0_n?Sll2oi6>c0;oThc90onFS<H2oiV<a004oib<`onJR;ooWHVnoif9_P?oX8^m0_nSS;`2
ojJ>_003ojR@_?nYS[WoZHji00?oZi2j00?o[I>kojjA^?naU;T00_naU;T2ok:G^`Co]YVj00?o]ibl
okVK^_niVkX00_njW[d3okfR_PCo`:Jo00Co_jW3ol>[`_o3Zl;o`Zg60_o5/<D3olJdb@?oakW=0oo7
_]82olW2d`04olG2eoo7aMSoalGHol?4f`;oa<OM00Co_lKOol38hOo0b>7o_<OS0_nlb>@01?nhanGo
^<SVokS8i_nfanL2okG8j004ok?6j?ooooooooooo`00017ooooo00?o0000ooooooooool03?ooool0
00Wooooo00@00000oooooooooooooooo4@00000D01TI6@800000;`0c<c<3000003`06ATI00?o0000
0000000000005@000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0;_ooool0
0onK]>WoVK;YoiJ_j002oiJ_j0;oTZ_W0_n?Y^D2ohbQhP03ohVLgon8V=coR9SL00;oQi?H0_n7Sm@0
0on8S=3oRXW=ohZ9c@02ohf8b@;oT8O60onCQl<2oiN7`@;oVXRo0onMRKh2oj2;_@;oXhbl00?oYXjl
ojJ<^OnYS[T00onYS[T2oj^@^P?o[Y6h0_naU;T00onbUk_o]9JhokBF^003okJI^P?o^I^j00Co^Yjm
okbO^onlWk_o_J:n0_o0Xk`3ol2V_`?o`j_20oo5/<D01Oo8//Goa[C9olVhbOo9^<WoakW=00;ob[g>
00?oakkBolW2doo9`]<00_o;aMD01?o7aMSob<SJolS8f_o4amd2olC:g`04ol38hOo0bn?o`<_Sokc8
i0;o^l[V00Co^<SVokS9j?nhbNSo]LSX1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00cooooo0009ooooo`0400000?oooooooooooooooa0000004`0I6AT2000003@0<c<c00<00000
o`0000000000>P0I6ATG000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0^
ooooo`;oVK;Y00CoUZoXoi6/j?n=Z>OoSJSW0_n9XnD2ohFMhP;oPYOO0_n8V=`2ohNCf0;oQhoD00?o
R8c@ohZ9cOn:RLd00_n=R<T2oi27aP?oThO30_nGQl42oiZ8_`;oWHVn00CoX8^moin8^_nSRKWoXhVi
0onVS;T3ojV>^@03oj^@^_n/SkOo[Y6h00;o[Y6h00?o/IBiok:C]ondU[P00ondU[P00onfVK[o^9Vh
okRI^002okVK^P?o_9nk1?o0Xk`01?o0Y[oo`jRnol>X__o3Zl82olJ]`@03olF`aOo8//Gob;;500?o
bKS900GocKc:olZmc_o=`LoocL7?olW2d`02ol_5e@06olg:eoo8b=[ob<SJolS8f_o9c=coa<[O0_o4
cN401?o0bn?o_lgUoko=iOnkb^H2ok_<i`03okS9j?oooooooooo00Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool>00000003o`00
000I6AT06ATI01006ATI0P00000i03<c<`030000000I6AT06ATI03P06ATI5P000004ooooo`030000
0?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool2oiJ`j@;oTJcX0_n=Z>L2ohVSi@;oQIgR
0_n2Uml00on1T]_oP8gGoh2=e`02oh29d`;oPXK>0_n:RLd2ohf8b@;oT8O60_nCQl<2oiN7`@;oVXRo
00CoWHVnoib6^onOR;[oWhRj0onSRKT3ojJ<^@03ojV>^OnYS;Oo[8ng00;o[8ng0_n^TKP3ok:C]`;o
]9Jh00Go]YJfokRI^?nhVKSo^9VhokVK^P02ok^L^0;o_9nk00Co_j2iol2S_?o0Xkco`jFk0oo3Z;h3
olJ]`@?ob;;500Coc;K5olVhbOo=_<[ocKc:0oo=`Ll00oo?a]7oblGEolg:e`02olg:e`03olS8f_o9
c=cob]3N00;oa<gQ0_o4d><01?nocNGo_loVoko?i_nkc>L:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo3P00000B01TI6@030000
000c<c<0<c<c01<0<c<c3`00000H03<c<`<00000>00I6ATE000000Cooooo00<00000ooooooooool0
5?ooool2o`0002oooooo0_nB[nX2ohfZj@03ohNUion2WnGoPYoU00;oOYSR0_mjT]h2ogR<fP;oP8gG
0_n0RM<00on2Q/koQHC;ohF4b`02ohR3a`;oS8;40_n@P/42oiB3_P;oV8Bl0_nLQ[/3oin8^P;oXhVi
0_nVS;T01?nVR[OoZHbgojV<]onYS;L2ojb?]`03ojjA^?n`T;Ko/Y>g00;o/Y>g00Co]9JhokJF]_nf
U[Ko]YJf0_nhVKP3ok^L^004okbO^onoX;Wo_j2iol2S_0?o`jFk00Co`jRnolJ[__o6ZkkoaZg10_o9
/<400oo8//Goc;K5olbfa@03olflbP05om31boo=`LooclKAolo6dOoBbm<00_o=b]L01Oo>c]WobLcL
ol[@g_o:d=kobM?Q00;oa=3S00?o`m;Uoko?i_nocnH03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo0009ooooo`0400000?ooooooooooooooo`d00000400I6AT200000003
o`00000c<c<0<c<c00d0<c<c1`00000?04a<C0L00000500c<c<00`0000006ATI01TI6@0g01TI6A<0
00001?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00GoTZoZohj]jon7
Z>[oQjSZoh6Qj002oh:Oi@;oOYSR0_mjT]h00omhS=[oMhOFogN7eP02ogR3d@;oPXK>0_n5Q</2ohR3
a`;oS8;40_n@P/42oiB3_P;oV8Bl0_nLQ[/2oin8^P03oj>9^OnSQkOoYXZg00;oYXZg0onYS;L00on/
SkOo[Hjeok2@]P02ok2@]P;o/Y>g1?nfU[H00onhVKSo^YVfokZI]P02ok^L^0?o_j2i1?o3YK/3olJ[
_P?obK3100GocKC2olbfaOo?^lKock_6olflbP02om31b`06om?6cOo?a]7od/_Com;;dooDd=Koc/kI
0_o?dm`01Oo:d=kobM?QolWChOo9e^Co`m;U017ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`002Oooool01000003oooooooooooooool=000000l06ATI00<0000003<c<`0c
<c<03@0c<c<3000001d0C4a<0`00000B03<c<`03o`00000000006ATI03L06ATI4P000004ooooo`03
00000?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool2ohj]j`;oQjSZ00CoPJ7XogZJi_mj
V^KoM9?R0_m`S=h2off5fP;oMhOF00?oN8?AogZ0cOmjP<d00_mnO/T2ohR3a`;oS8;40_n@P/42oiB3
_P;oV8Bl0_nLQ[/00onOR;[oWhFhoj>7]`02oj>7]`?oYXZg0_nYS;L2ojf>]@?o/92f00?o/Y>gokBC
]OndTkD00onfU[H3okZI]P03ok^L^?nnWKOo_Yfg00;o_j2i00Go`Z:iol>U^oo3YK_o`jFkolJX^`02
olJ[_P04olZ^__o9/<7ocKC2olfd`P?ock_600Kodl37om31booCa/godlK=omK<cooBbm<2omC@eP06
omGFfOo?dmcocmOOoloGgoo9dn7obMKT5?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00cooooo0009ooooo`0400000?ooooooooooooooo``000003`0I6AT00`000000<c<c03<c<`0<
03<c<`8000008`1<C4`300000140<c<c00<0000001TI6@0I6AT0=P0I6ATA000000Cooooo00<00000
ooooooooool06?ooool00ol0003oooooooooo`0]ooooo`;oRJ_/0_n1YN/01?miW^WoLIKVog6Fi_mY
S^<2og2<gP03off5f_m/P=GoK83E00;oN8?A0_mjP<d00omnO/WoPWg5oh9ma@02ohMm`P;oS7jo0_nA
Ok`2oiJ1^P;oVh>i0_nOQKP3oj>7]`?oYXZg00?oZHbgojZ;]On]S[D00_n]S[D2ok2@]PCo]9>e00?o
]YJfokRF]OnhU[D00_njVKH3okjM]`05oknP^Oo2X[Wo`Z:iol:R^Oo3YK/00_o6Z;/00oo6ZkkobZjn
olZ^_P03olfd`P06om6i`_o?^lKodl37om?0aooGa/WodlK=0_oFc<l01_oId];oe=3FomGFfOoEe]Wo
eM_LoloGg`;oc]_R5Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`0400000?ooooooooooooooo`/00000400I6AT00`000000<c<c03<c<`0:03<c<`800000:01<
C4`00`000000<c<c03<c<`0?03<c<`800000=P0I6ATA000000Cooooo00<00000ooooooooool06Ooo
ool2o`0002gooooo0_n3ZNd2ogZSk0;oL9[Z0_maU^H2of>6gP;oH7kJ00?oK83Eofild?m^O=000_ma
NL`2oginb@;oPWg500?oQgg2ohan_on<O[l00_nAOk`2oiJ1^P?oVh>i0_nOQKP3oj>7]`03ojJ:]onV
R;GoZX^e00;oZX^e0_n]S[D00on`T;Ko/I2dok6@]002okBC]@05okJD]?nhU[Go^9JeokRF]OnjVKH0
0_nlVkD2okjM]`?o`Z:i00CoaZFholJX^oo6Z;_oaZRk0oo:[[h01?o>/[kocKC2om6i`_oA^L83om?0
a`03omO6bOoJcLcoe/c?00;ofM;B00Kof]WFomGFfOoEfmcoeM_LomCOgoo>fn8Gooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo2P00
00000ol000006ATI01TI6@0=01TI6@030000000c<c<0<c<c00X0<c<c00?o000004a<C01<C4`0:@1<
C4`200000140<c<c0P00000e01TI6A0000001?ooool00`00003oooooooooo`0Kooooo`03o`000?oo
oooooooo02_ooooo0_n3ZNd2ogZSk0;oL9[Z00GoII7Woeb7homSQ]koHhKNof1nfP02oemie@;oKWc@
00?oLGW<ogIhb?mfN<P00_n2OLD2ohMm`P;oS7jo0_nAOk`2oiJ1^P;oVh>i0_nOQKP2oj>7]`03oj>6
]OnVR;GoYXRe00?oZX^e00?o[Hjeojj>/onaT;@00_naT;@00ondTkGo]YBdokJD]003okRF]@?o_9^e
00Co_Yfgol6P]oo1X;Oo`Z:i0oo6YKP01?o6Z;_obZbkolZ/^oo:[[h2oljb_P?odKW200Ooe[o4om?0
aooGa/WoelK9om[=c?oMe<oofM;B00;of]WF00CofmoIomGKg?oDgmooe=oO6Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooo`X00000
3`0I6AT00`000000<c<c03<c<`0903<c<`8000003`1<C4`?00000100C4a<00<0000003<c<`0c<c<0
400c<c<00`0000006ATI01TI6@0c01TI6@l000001?ooool00`00003oooooooooo`0Looooo`03o`00
0?oooooooooo02_ooooo0_mnZ>l2og:PkP03ofFGk?mHS>SoF8cX00;oG8OS00?oE7kNodmffOmONMD0
0_mQMM02og5ic003ogIhb?mkN<CoNgS400;oPWW10_n<O[l2oi5o_0;oUX6j00CoVh>ioiV1^?nNPkKo
WX>f0onSQ[D3ojJ8]@;oZX^e0on^S[<2ok6@]0Co]YBd0_nhU[D3okbK]@?o`J2g1?o6YKP3olZ/^`?o
c[:n00Kod[Room6i`_oF_lCoe[o4om[6a_oGa/T2om[=c003omgDcooOg=;of]WF00;ofmoI00?of^GM
omCOgoooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009oooo
o`0400000?ooooooooooooooo`T000003P0I6AT2000000X0<c<c0P00000=04a<C0@000003`1VIVH3
000000h0C4a<0`00000@03<c<`030000000I6AT06ATI03<06ATI00?o00000000000000002`000004
ooooo`0300000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool01?mhYo3oJIk_oeVCk?mI
Tn`2oeR<j003od^1hom1M]ko@GKN00;oCW3D00?oHGG@ofIcc?mVLl`00_mfN<P2og]ha003oh9i`On8
N[koR7Zn00;oSWbk0_nDO[T2oiV1^0?oWX>f0onSQ[D2ojJ8]@03ojZ;]On[Rk?o[Xjc00;o[Xjc00?o
/I2dok>A/oncTK<00onfU;@00onhU[Go^iRdok^H]002okbK]@04ol2M]Oo1X;Oo`J2golFS]P?oaZFh
00GobZViolZ/^oo:[;_ock2loljb_P02om:h_`06omNn`OoF_lCof/K6om[6a_oNc/Wof/g<0_oMe<l0
1?oOg=;ohN?Fom_OfOoJiMdMooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool000Wooooo00@00000oooooooooooooooo2000000>01TI6@030000000c<c<0<c<c00T0<c<c00<0
000004a<C01<C4`02@1<C4`01?l00000000000000000000F06IVIP@000003@1<C4`2000000l0<c<c
00<0000001TI6@0I6AT0<`0I6AT=000000Cooooo00<00000ooooooooool07_ooool2o`0002gooooo
0_maY_42oeVCk006odR6j?lgN>;o=gSRod5fg_m?M]WoCW3D0_mAK=000omVLlcoK7;7ofaba`02og]h
a0;oPWW100?oR7Znohil^on>O;/00_nDO[T3oiV1^0;oWX>f0onSQ[D00onVR;GoYhRdoj^;/`02oj^;
/`;o[Xjc0oncTK<3okJD]0?o^iRd00Co_9^eol2M]Oo0WKGo`J2g0oo5XkH01?o6YKSobZViolZY^Oo:
[;/2oln`_0?od[Ro00?oekk1omc6`ooJa/H00_oNc/T00ooRe/cogMC?omoLdP02on7SeP03on3ZfOoo
oooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`002Oooool0
1000003oooooooooooooool8000000h06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<
C00704a<C0<000007P1VIVH00ol0000000000000000<04a<C0030000000c<c<0<c<c00d0<c<c00?o
000001TI6@0I6AT0<`0I6AT<000000Cooooo00<00000ooooooooool08?ooool00ol0003ooooooooo
o`0[ooooo`06ofbUlomGV_7oC8o]odb?kOlfOnOo=gSR0_lYJm/2odi`e004oe5/d?mGJlcoIW?<ofab
a`;oLg?40_mkML02ohQj_P;oSWbk0_nDO[T2oiV1^0?oWX>f00CoXhJeoj>5]?nWR;CoYhRd0on[Rk<0
0on^S[?o/8jcok2>/`03ok>A/`03okJD]?nhUK?o^9Fc00;o^iRd0oo0WKD4olFS]P?obZVi0oo?/;`0
1OoC][god[RoomNn`OoG_/7og<K300?og/k900Goh]K<onCOcooUj=;ohN?Fon3Zf@0Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo
2000000=01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`01P1<C4`2000002@0IVIV
0`00000:04a<C0030000000c<c<0<c<c00d0<c<c00<0000001TI6@0I6AT0<`0I6AT;000000Cooooo
00<00000ooooooooool08Oooool00ol0003oooooooooo`0[ooooo`09ofJUm?mGV_7oEi[aocn;kOlS
N>Co86oOobU[folPH=Go>FKC00;oDFc@00CoEf_<ofabaom/L/OoLg?40_mkML02oh=g_@;oSWbk0_nD
O[T00onIPKSoV7ngoij2]P02oij2]P;oXhFd0onWR;@2oj^;/`?o/8jc0oncTK<3okRE/`03ok^H]?nn
V[Co_YZd00;o`9fe00Go`j2eolFS]_o5XkKoaJ>folVW]`02olZY^@06olj_^_o?/;codkJmom>f_OoI
_[ooekk10_oLa/<00ooQclKog/k9on;Fc002onCOc`03onGXd_oTl=Kooooo02;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool80000
00`06ATI00?o000003<c<`0c<c<0200c<c<00ol00000C4a<04a<C00604a<C0030000001VIVH0IVIV
00/0IVIV3`00000=06IVIP030000001<C4`0C4a<00P0C4a<0P00000>03<c<`030000000I6AT06ATI
03<06ATI00?o00000000000000001`000004ooooo`0300000?oooooooooo02;ooooo00?o0000oooo
ooooool0:oooool01?mRYOGoCiSbodnHl_laQn`2o`ISf@05o`eNe_lPH=Go>FKCocaRcomGJl`00_mO
K<P2og=ca003og]e`?n3MkgoPgNm00;oRgZk0_nBOKT3oiQo]`;oWX:f0onSQK@2ojN8]003oj^;/on/
Rk?o/8jc00?o/8jc00?o/i6cokFB/onhUK<00_nhUK<3okjJ]005ol2M]Oo3X;Go`j2eol>P]Oo5XkH0
0_o9YkL00oo:ZKWocZnjolj_^P03om>f_@03omVn_ooNa/7og<K300;ohLo600CoiMW9onSSc?oTgloo
iNSB0_oTl=HSooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool000Wooooo
00@00000oooooooooooooooo1`00000=01TI6@030000000c<c<0<c<c00H0<c<c0P00000804a<C003
o`00001VIVH0IVIV00P0IVIV1000000?07moO`<000002`1VIVH2000000X0C4a<0P00000=03<c<`03
00000?l000006ATI03806ATI2P000004ooooo`0300000?oooooooooo02?ooooo00?o0000oooooooo
ool0:oooool01_mOY_KoAiSbodNHl_lUQ>[o1V?Io`1>c0;o053>00Co75S@ocaRcom4H/_oGfc80_mY
KL@2og]e`0;oPgNm00?oRgZkoi9m^OnBOKT00onHOkL3oij2]P;oXhFd00?oYhRdojR8/on/Rk<00_n/
Rk<2ok2>/`04ok:@/oneT[?o]I:cokFB/`;o^9Fc0onnV[@4ol>P]@?obJNg0oo>[kX01ooD]K_odkJm
omVn_ooI_[oog/K1onC@a?oQclH00_oUfLT01?oXhlcojNg?onOedOoTl=HUooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo1`00000<
01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01P1<C4`2000000P0IVIV0`00000F
07moO`@000002@1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00`0<c<c00<00000
01TI6@0I6AT0<@0I6AT9000000Cooooo00<00000ooooooooool09?ooool2o`0002gooooo0_m2V?<0
1OlKP^So06WIo`1>c?l0D<ko04O700;o7eG<00?oCV?8oem/b?mYKL@00_mcL<42oh=g_@;oRgZk0_nB
OKT2oiQo]`?oWX:f0_nSQK@2ojR8/`?o[8^c00?o/8jcok:@/onbT;<00oneT[<00onhUK?o^iRcok^H
/`02okjJ]003ol6N]?o3X;Go`j2e00;ob:Ff0_o9YkL01_o>[KSocZnjomBe^ooD]K_ofKfmomVn_`;o
g/K100?oi=34onSKaooUfLT00_oXhl`00ooYkLooioGAooooo`0Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo1P00000<01TI6@03
0000000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP<0
00007@1oOgl3000000L0IVIV0`00000904a<C0030000000c<c<0<c<c00`0<c<c00<0000001TI6@0I
6AT0<@0I6AT8000000Cooooo00<00000ooooooooool09_ooool00ol0003oooooooooo`0[ooooo`;o
?iWc00So58;Vo`1Sd_l0?;_o03boo`17aolOELcoA6;;odiSb0;oJFg400?oLg31oged__mmM;h00_n6
N;/2oi9m^@?oV7ng00CoWX:foif2]_nSQKCoXhFd0onXR;<2ojb;/`Co/Y2c0_neT[<3ok^H/`04okjJ
]?o1W[Co`Ijdol>P]@?ob:Ff00?obJNgolj]^?o>[KP00ooD]K/00ooI_KgoglO0omk6`@02onC@a005
onSKaoo/ilWoj>?<onW]cooWmM40:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo0009ooooo`0400000?ooooooooooooooo`D00000300I6AT00ol00000<c<c03<c<`0603<c
<`030000001<C4`0C4a<00D0C4a<00<00000o`00001VIVH01@1VIVH200000140Ogmo1000000>07mo
O`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0<03<c
<`030000000I6AT06ATI03406ATI1`000004ooooo`0300000?oooooooooo02Oooooo00?o0000oooo
ooooool0:oooool2of>^n@07oa>4i_l0H<co03nco`0`]ol0@/Co7eG<odiSb002oe]Wa@;oLg3100?o
OGBnohIh^on6N;/00_n?NkT3oiMo]`;oWH:f0onSQK@2ojR8/`03ojb;/on^SK?o[Xfc00?o/Y2c00?o
]I:cokRE/onhUK<00_nkV;<3ol6N]0Cob:Ff0oo>[KP01ooC];[oe;FkomVm_OoI_KgoglO0onKB`ooT
d<@00_oXflL00oo/ilWok?7;onOjb`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool000Wooooo00@00000oooooooooooooooo1@00000<01TI6@030000000c<c<0<c<c00H0
<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00X0
Ogmo1`00000409VIV@@000002`1oOgl00ol00000000006IVIP0706IVIP03o`00001<C4`0C4a<00L0
C4a<00?o000003<c<`0c<c<02`0c<c<00ol000006ATI01TI6@0a01TI6@L000001?ooool00`00003o
ooooooooo`0Xooooo`03o`000?oooooooooo02_ooooo0_mX/OX02?m;Y_So5hWXo`1UbOl0<;Oo04;4
ocMIb?m>HlSoFfO50_mXK<<2oged_P;oQWRk0_n?NkT2oiMo]`?oWH:f0_nSQK@00onXR;?oZHZdojj=
/`02ojj=/`?o/Y2c0onhUK<00onkV;?o_i^doknK]002ol6N]006olJS]Oo8YKKob:FfolRU]_o=ZkOo
cZfh0_oC];X02_oJ_KcofKfmomo7`?oOal3oi];3on_Na_oXflOok>O9oncabooWn///ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo
1000000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00L0Ogmo1000000?09VIV@<000002P1oOgl00`000000IVIV
06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI
01TI6@0`01TI6@L000001?ooool00`00003oooooooooo`0Yooooo`;o0000;?ooool2ofnenP;oE:cj
00Co;9[`o`0Z/ol4A<Co=eW80_mKIlD00omXK<?oMG70ogEa`002ohIh^`;oSg^i0onGOkL2oif2]P04
oj>5]?nSQ[GoZHZdojV:]0Co[Xfc00?o/Y2cokBB/onhUK<00_nhUK<3oknK]005ol6N]?o6XkGoaZ>e
olJS]Oo8YKH00_o=ZkL3om>d^P03omZm_?oOal3oglO000;oi];300Cojmk6onk[aoo/m/Ooi?g3;_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?oooooo
ooooooooo`@00000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0607moO`03o`0000000000VIVI01D0VIVI0`00
000807moO`8000001`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00/0<c<c00<0
000001TI6@0I6AT0<00I6AT6000000Cooooo00<00000ooooooooool0:oooool00ol0003ooooooooo
o`0Zooooo`;oMkSj0_mO/_/01OllY?Go02Zco`A4a?lgFLSoAeo700;oJ6c300CoMG70oh5f_On1M[go
PGJm0_n?NkT2oiMo]`04oif2]_nMPkOoXhJeoj>6]@?oZHZd0_n^SK<01?n`SkCo]9:cokBB/ondT[<2
okRE/`?o_i^d1?o6XkD3olf[]`07om:c^_oC];[of[flomZm_?oPakooglO0onKB``02on_NaP03onk[
aoo/m/Ooi?g302kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Ooo
ool01000003oooooooooooooool300000003o`00000I6AT06ATI00T06ATI00<0000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0
1@1oOgl2000001/0VIVI00<00000o`00000000001`1oOgl00`000000IVIV06IVIP0506IVIP800000
201<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI03006ATI1@000004ooooo`030000
0?oooooooooo02cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`0[
]?lDBLGo54W500?oFFK500?oMG70oh5f_On1M[d00_n<N[/2oiEo^@;oWH>g0onSQ[D2ojV:]003ojj=
/on`SkCo/8nd00?o]9:c00?o^9FcokbI]?nlVK@00_noVk@00oo3XKKoaZ>eolJS]@02ol^Y]`03olf[
]ooB/k[od[>j00;of[fl0_oPakl01_oWe<?okN?5on_Na_o^jlOok?K7onCm`c3ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`002Oooool01000003oooooooooooooool4000000/06ATI00<00000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl0101oOgl2000000P0VIVI3`00000909VIV@8000001P1oOgl00ol00000000006IVIP06
06IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<02`0c<c<00ol000006ATI01TI6@0_
01TI6@D000001?ooool00`00003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01?ooool00ol0:kCo54W5obYCa`02oeUVa@;oJVg30_n1M[d00on<N[_oUGnioiEo^@03
oif3]`;oXhJe00?oZHZdoj^<]On`Sk@00on`Sk@2okBB/`?o_9Vd00Co_i^dol>Q]_o3XKKoaZ>e0oo;
ZKL3om:c^P09omVl_OoJ_Kcoh<Noon37_ooWe<?okN?5onoaa_oYnl7ofObg03;ooooo00Co0000oooo
oooooooo00002oooool000Wooooo00@00000oooooooooooooooo0`00000;01TI6@030000000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT3000000l0/k>c0`00000809VIV@8000001P1oOgl0
0`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02P0c<c<0
0`0000006ATI01TI6@0`01TI6@@000001?ooool00`00003oooooooooo`0^ooooo`;o0000:?ooool0
0ol0003oooooooooo`05ooooo`04o`0b^_lDBLGo:U?7oeUVa@;oJVg30_mjM<42ohaj^`;oUGni0_nM
PkL00onSQ[GoY8Rgoj^<]@02oj^<]@?o/8nd00?o]9:cokRF]OnhU[D00_nlVK@3ol>Q]P06olRW^?o;
ZKOobjVgol^Y]ooA/K[od[>j0_oI_;d00ooQbL3oh<NoonOD``02ongSa@03onoaa_oYnl7ooooo03?o
oooo00?o0000ooooool000002oooool000Wooooo00@00000oooooooooooooooo0`00000;01TI6@03
o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP03
o`00001oOgl0Ogmo00<0Ogmo00<00000o`00002IVIT01@2IVIT2000001D0/k>c00<00000o`000000
00001`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<
C4`01P1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI03006ATI00?o000000000000
00001?ooool00`00003oooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool01Ol0<[[o:U?7od9Nb?mII/GoJVg300;oNWC10_n7N[h2oiEo^@04oif3]onLQ;WoY8Rg
ojB8]`?oZhbe0on`Sk@3okRF]@03okbI]?o0W[Ko`9jf00;o`j6f0_o8YkP00oo;ZKOodK6jom6a^P03
omVl_@06on79`?oXelCoimC3ongSaOo_lLKojO_1=Oooool00ol0003oooooo`00000;ooooo`002Ooo
ool01000003oooooooooooooool3000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0409VIV@030000002c/k<0/k>c01P0/k>c00<0000009VIV@2IVIT01@2IVIT00ol00000Ogmo
07moO`0407moO`03o`00001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c
03<c<`0:03<c<`030000000I6AT06ATI03006ATI0`000004ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03o`10`_lZDlOo@Uk800;oJVg3
00?oNWC1ohMj__n7N[h00_nBOk/2oib4^@?oY8Rg0on[S;D00on`SkCo/i>fok>C]P02okRF]@?o`9jf
00Co`j6folRW^?o8YkSob:Nh0ooA/KX02?oH_;kofKbmon79`?oQbL3oj=O4onkXa_o]m/Coh?bi=ooo
ool00ol0003oooooo`00000:ooooo`002Oooool01000003oooooooooooooool3000000/06ATI00<0
000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00@0IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00L0/k>c2000
000;0;>c/`8000001P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI02l06ATI0`00
0004ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`04o`10`_m2G/SoFVW8oeYYb0;oNWC10_n7N[h2oi9o^`;oW8Bi0_nTR;L2oj^<]@05ojf@
^?ncTkKo/i>fok>C]_nhU[D00_nkW;P2ol2N]P?ob:Nh0_o?/K/01OoA/K[of;bnomRl__oQbl;ohLW0
00;oj=O400?ok^S6ongfa?ooool0>?ooool2o`0000[ooooo0009ooooo`0400000?oooooooooooooo
o`8000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<01P2c/k<00ol0000000000<c<c0070<c<c0@000002@2c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<
C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT0;`0I6AT2000000Cooooo00<00000oooo
ooooool0<oooool2o`0002?ooooo00?o0000ooooooooool02?ooool01?nB4`3o7U39oai@bOmJJLP2
ofmbaP;oQgZn0_nBOk/2oib4^@03ojB8]onUS;[o[I2h00?o[I2h0_ncTkH3ok^L^004ol2N]_o5Y[Wo
aJJiolRW^0?ock6k0ooH_;h01_oQbl;ojMc7onSGa?o^j<KokOK4oikOR3Sooooo0ol0000:ooooo`00
2Oooool01000003oooooooooooooool2000000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0309VIV@8000001`2c/k<00`00003o00000<c<c00=0<c<c0<000001`2c/k<00`00003o
000009VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000
C4a<04a<C00504a<C0030000000c<c<0<c<c00/0<c<c00?o000001TI6@0I6AT0;P0I6AT2000000Co
oooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wo
oooo00Go026/oai@bOloHLgoFVW8ofmbaP02oh5k``;oT8;00_nKQkd3ojF<^P?o[I2h00?o/i>fokJI
^_nkW;P00_nkW;P3olFV^@06olb`__o?/K_ock6kolna^ooG_L3of;bn0_oQbl801?oYg<OokNk8onOl
`_o<n:`eooooo`Co00003Oooool000Wooooo00@00000oooooooooooooooo0P00000;01TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`050;>c/`800000
4`3<c<`3000000H0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`03o`00
001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0;03<c<`030000
000I6AT06ATI02h06ATI0P000004ooooo`0300000?oooooooooo03Kooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0:ooooo`03o`0h_OlND<Wo?f7=00;oKg;600?oPG_3oi22`?n@P/00
0onKQkd2ojF<^P?o[I2h0onfVKX2ok^L^003ol6T_?o5Y[WoaJJi00;oc;2n00Gock6komNm`?oG_L3o
glg6on7;`P02onWLa`03ong^b?o<n:cooooo03;ooooo0ol0000Aooooo`002Oooool01@00003ooooo
ooooooooool0000000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03
0000002c/k<0/k>c00@0/k>c0P00000H0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2I
VIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<
C4`01@1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI02h06ATI00<00000oooooooo
ool00_ooool00`00003oooooooooo`0gooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool01?l0>;go?f7=oee`cOmML<d2oh5k``;oT8;00_nKQkd3ojF<^P03ojf@^?n_U[co[iJl
00;o]YVj00Co^ibhol6T_?o1Y;coaJJi0oo</;h3omNm`005omo=a_oXhLcojMc7ong^b?nWii@0<?oo
ool4o`0001Cooooo0009ooooo`0500000?ooooooooooooooo`0000002`0I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0060<c<c0P000002`3<c<`2000000D0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07mo
O`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0;03<c<`030000000I6AT06ATI02h06ATI00D00000oooooooooooooooo0000000jooooo`;o0000
7_ooool00ol0003oooooooooo`0<ooooo`;o4E;=00?oGG3=ogMlbomgO</00_n@P/000onKQkgoVXc3
ojJA_`02ojJA_`?o[iJl00?o]YVjok^Q_oo1Y;`00_o1Y;`3olb`_P;oe;g400Koekg0omo=a_oOcLKo
j>7<on[fc?oHoK`]ooooo`Co00006?ooool000Wooooo00D00000oooooooooooooooo0000000;01TI
6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<00@0c<c<0P0000080>KViP@000002@3<c<`00`000000/k>c0;>c/`020;>c
/`030000002IVIT0VIVI00@0VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0^01TI
6@0500000?ooooooooooooooo`000000??ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00gooooo00Co4E;=oci[e_mML<goMgc;0_n;QLL3oiZ<``?oYY6o0_n_U[`3ok^Q_`04ol6T_?o7
[l;oajo2olb`_P?oe;g400GogM3<omo=a_oXhLcoj_K<omSm_00Zooooo`Co00007?ooool000Wooooo
00D00000oooooooooooooooo0000000;01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3V
i^H0303Vi^H3000000L0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C003
0000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT0;@0I6AT01@00003oooooooooooooool00000
03gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`04o`0a]OlnJmKoMgc;
ogMlb`;oRhG70onJS<<2ojJA_`03ojnF_?ncW/?o/ik300;o^j6o0oo7[l82olnnbP06omBma?oMd<co
gM3<onGXdooOoLoo]oB]:?ooool3o`00023ooooo0009ooooo`0500000?ooooooooooooooo`000000
2P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0
0`2c/k<00`000000c<c<0<c<c0030<c<c08000004P3Vi^H00`00003o00000<c<c0050<c<c003o`00
002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000
001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000
000I6AT06ATI02d06ATI1?ooool00`00003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool03oooool00ol1FM?oIGgGofEme`02oh>;d`;oVXc300?oV9C>ojNJb?nWV/P0
0oncW/<01?nkXKoo`Jg7ol6]aoo7[l83olnnbP05omWEeOoMd<coiNSConGXdooOoLl09Oooool4o`00
02?ooooo0009ooooo`0500000?ooooooooooooooo`0000002P0I6AT00`000000<c<c03<c<`0403<c
<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<
c0030000003Vi^H0i^KV0180i^KV0P0000050<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VI
V@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`03o`00001VIVH0IVIV00@0IVIV00?o000004a<
C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI02d06ATI1?ooool00`00
003oooooooooo`0mooooo`;o00006Oooool00ol0003oooooooooo`0@ooooo`03o`5IdomUOMOoIGgG
00;oPh_C0onHU<h2ojNJb003ok>N`ongZlgo`Jg700;o`Jg70oo?_/X2omWEe@03omgagOoUj=?ogog?
02;ooooo1?l0000Wooooo`002Oooool01@00003oooooooooooooool0000000X06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007mo
O`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<
c03<c<`00`3<c<`00`000000i^KV0>KViP0E0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c
/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI
6@0I6AT0;@0I6AT4ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Aooooo`03o`0[WoloO>?oPh_C00;oPh_C0_nHU<h00onWV/SoZJOEokN[c@02okN[
c@04ol6]aoo8_m;ob;oBolnnbP;ofMGE0_oMlMdPooooo`Co0000:oooool000Wooooo00D00000oooo
oooooooooooo0000000:01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c
/`030;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H0203Vi^H4o`0000/0i^KV00?o
00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0
000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0/01TI6@Cooooo00<00000ooooooooool0@?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00Co06CCog6Ci?nCXMkoTj7N
0onYYmD01?ngZlgo_<3Lokc0g?o8_m82om3Jh@;ob_WY00?ogO7Mooooooooool07?ooool3o`0002oo
oooo0009ooooo`0400000?ooooooooooooooo`/06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VI
V@03o`00002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP050>KV
iPCo0000103oool4o`0000P0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c
/`030000002IVIT0VIVI00<0VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0[01TI
6@Cooooo00<00000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Kooooo00GoL`00od:Hl_nCXMkoTj7NojVWe@02ojNmj@04okc0g?nmg_7o_Mkaom3Jh@;ob_WY7?oo
ool4o`0003;ooooo0009ooooo`0400000?ooooooooooooooo`/06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo
0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV
0>KViP050>KViP03o`00003oool0oooo00X0oooo00?o00000>KViP3Vi^H01@3Vi^H00`000000c<c<
0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0;03<c<`030000000I6AT06ATI02/06ATI1?ooool00`00003oooooooooo`12ooooo`;o0000
4oooool00ol0003oooooooooo`0Hooooo`04o`1^_?n2/oGoP[?eojNmj@;oU=[n00?o_Mkaoi[bk?oo
ool06_ooool4o`0003Kooooo0009ooooo`0400000?ooooooooooooooo`/06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1o
Ogl0Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00`00
0000i^KV0>KViP040>KViP03o`00003oool0oooo00`0oooo00?o00000>KViP3Vi^H01@3Vi^H00`00
0000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`00
0000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`00`00
0000<c<c03<c<`0:03<c<`030000000I6AT06ATI02/06ATI1?ooool00`00003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00onDf_koooooooooo`0Hoooo
o`Co0000>_ooool000Wooooo00@00000oooooooooooooooo2`0I6AT00`000000<c<c03<c<`0403<c
<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207mo
O`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0
i^KV00D0i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV0>KViP050>KViP030000003<c<`0
c<c<0080c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00/0<c<c00<0000001TI6@0I6AT0:P0I6AT4ooooo`0300000?oooooooooo04Gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00@00000oooo
oooooooooooo2`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<00000
06IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c
/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool03`3o
ool2o`0000H0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`03o`00002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00ol00000IVIV06IVIP0306IVIP030000001<
C4`0C4a<00D0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0Z01TI6@Cooooo00<0
0000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol0
0012ooooo`002Oooool01000003oooooooooooooool;01TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0
000009VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0
103Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`0
0P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0
0`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0
2P0c<c<00ol000006ATI01TI6@0Z01TI6@Cooooo00<00000ooooooooool0Aoooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01@00003ooooooooo
oooooooo000000X06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0
/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP030>KViP03o`00003oool0oooo0180
oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI02X0
6ATI1?ooool00`00003oooooooooo`18ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co
0000BOooool000Wooooo00D00000ooooooooooooooooo`00000:01TI6@030000000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080
Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<00<000000>KV
iP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<000000<c<
c03<c<`00P3<c<`00ol00000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007mo
O`1oOgl00P1oOgl00`000000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<02`0c<c<00`0000006ATI01TI6@0Y01TI6@Cooooo00<00000ooooooooool0B_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`002Oooool01@00003o
oooooooooooooooo000000X06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0
000000@0/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP030>KViP03o`00003oool0
oooo01<0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0
/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0
IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT0
6ATI02T06ATI1?ooool00`00003oooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool3o`00057ooooo0009ooooo`0500000?ooooooooooooooool000002P0I6AT0
0`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH0
0`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<
c0020<c<c0030000003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04`3oool00ol00000i^KV0>KV
iP030>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT0:@0I6AT4ooooo`0300000?oo
oooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?oo
ool000Wooooo00D00000ooooooooooooooooo`00000:01TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000
0`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0
0`3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`0
0P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0
2P0c<c<00`0000006ATI01TI6@0Y01TI6@Cooooo00<00000ooooooooool0COooool2o`0000Sooooo
00?o0000ooooooooool06Oooool4o`0005Sooooo0009ooooo`0500000?ooooooooooooooool00000
2P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH0
0P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000
c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04`3oool00ol00000
i^KV0>KViP040>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0:@0I6AT4ooooo`03
00000?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co
0000G?ooool000Wooooo00D00000ooooooooooooooooo`00000:01TI6@030000000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07mo
O`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00<000000>KV
iP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<
c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00?o000007mo
O`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c
<`0c<c<02P0c<c<00`0000006ATI01TI6@0Y01TI6@Cooooo00<00000ooooooooool0D?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Pooooo`002Oooool01P00003o
ooooooooooooool00000o`0000X06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2I
VIWo000000@0/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP030>KViP03o`00003o
ool0oooo0180oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0030000002c
/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001V
IVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I
6AT06ATI02T06ATI1?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`0600000?ooooooooooooooo`00003o0000
2P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000
c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool04@3oool00ol00000
i^KV0>KViP040>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0:@0I6AT4ooooo`03
00000?oooooooooo05;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0001Wooooo`00
2Oooool01P00003oooooooooooooool00000o`0000X06ATI00<0000003<c<`0c<c<0100c<c<00`00
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@00
0000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP04
0>KViP;o00004P3oool00ol00000i^KV0>KViP040>KViP030000003<c<`0c<c<0080c<c<00<00000
0;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo0080Ogmo00<00000
06IVIP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<00000
01TI6@0I6AT0:@0I6AT4ooooo`0300000?oooooooooo05Cooooo00Co0000oooooooooooo00002?oo
ool4o`0006_ooooo0009ooooo`0600000?ooooooooooooooo`00003o00002P0I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo
07moO`1oOgoo000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003
0000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool03P3oool00ol00000i^KV0>KViP040>KViP03
0000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C003
0000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0:@0I6AT4ooooo`0300000?oooooooooo05Go
oooo00?o0000ooooool000001Oooool3o`0006oooooo0009ooooo`0600000?ooooooooooooooo`00
003o00002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IV
IP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?oo
o`3oool0303oool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<0080c<c<00<000000;>c
/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI
6@0I6AT0:@0I6AT4ooooo`0300000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002o`00
07;ooooo0009ooooo`0600000?ooooooooooooooo`00003o00002P0I6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`02
07moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c002
0<c<c0030000003Vi^H0i^KV00H0i^KV0_l0000;0?ooo`;o00001`3Vi^H00`000000c<c<0<c<c002
0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:
03<c<`030000000I6AT06ATI02T06ATI1?ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool0
00Wooooo00H00000oooooooooooooooo00000?l0000;01TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00P2IVIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<00<000000>KViP3Vi^H0
1`3Vi^H00ol00000oooo0?ooo`060?ooo`;o0000203Vi^H00`000000c<c<0<c<c0030<c<c0030000
002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000
000I6AT06ATI02T06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
ooooool200000003o`00000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00ol00000C4a<
04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0209VIV@03o`00002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV
0>KViP070>KViPSo00002P3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c00<0/k>c
00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00@0IVIV
00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI02T06ATI
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool200000003o`00
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C003o`00
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000
002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP0F0>KViP800000
1@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0
2P0c<c<00`0000006ATI01TI6@0Y01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo0P0000000ol000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo
00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<
00<000000>KViP3Vi^H0503Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c0080/k>c
00?o000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00@0IVIV
00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI02T06ATI
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool300000003o`00
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0209VIV@030000
002c/k<0/k>c0080/k>c0P0000050<c<c0<000004@3Vi^H2000000L0c<c<00<000000;>c/`2c/k<0
0`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0
:P0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`@00000
00?o000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI
00?o00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00d0i^KV
00?o00000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<00D0C4a<
00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0Z01TI6@Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo100000000ol000006ATI01TI6@0801TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000
003<c<`0c<c<00D0c<c<00?o00000000000000002@3Vi^H3000000P0c<c<00<000000;>c/`2c/k<0
102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00?o000001TI6@0I6AT0
:P0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`@00000
00?o000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI
00<000000;>c/`2c/k<00`2c/k<2000000P0c<c<2@00000:0<c<c0030000002c/k<0/k>c00@0/k>c
00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI02X06ATI
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool500000003o`00
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00304a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0309VIV@030000
002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`05`3<c<`00ol00000/k>c0;>c/`040;>c/`030000
002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000
001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0[01TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1@0000000ol000006ATI
01TI6@0901TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT2000000D0/k>c
0`00000D0<c<c08000001P2c/k<00`000000VIVI09VIV@0409VIV@03o`00001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00604a<C003o`00000c<c<0<c<c00X0<c<c
00<0000001TI6@0I6AT0:`0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooo`D0000000?o000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000
001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000
002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<3000000h0c<c<0`0000070;>c/`030000
002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP030000
001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0[01TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1P0000000ol000006ATI
01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0306IVIP03o`00001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c
0;>c/`070;>c/`030000003<c<`0c<c<00L0c<c<100000090;>c/`030000002IVIT0VIVI00@0VIVI
00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00H0C4a<
00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0/01TI6@Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo1`0000000ol000006ATI01TI6@0901TI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP03o`00
001oOgl0Ogmo00<0Ogmo0_l0000509VIV@;o0000202c/k<9000000/0/k>c00?o00000000002IVIT0
1@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI02`06ATI1?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo0009oooookKo00004Ooooonfo`0000[ooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo033ooooo00<0003oooooooooool0BOooool00ol00?l0
003o0000o`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0_0?nf`@030000o`3o]/40okK104d0okK1
00<0003o0?nf`@3o]/402`3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40
S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK102d0okK10P00
0?mA0?nf`@030000o`3o]/40okK100X0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0Z
0?nf`@<0003oE03o]/420000o`X0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0Y0?nf
`@030000o`3o]/40okK105L0okK100<0003o0?nf`@3o]/401`3o]/4Uooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK102P0okK100<0003oo`00o`3o]/40F@3o]/420000o`L0okK19Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0V0?nf`@80003oGP3o]/420000o`D0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0U0?nf`@030000o`3o]/40okK10600okK10P000?l30?nf`BGooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/408`3o]/420000ofD0okK100<0003o0?nf`@3o]/409Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`@030000o`3o]/40okK106H0okK100<0003o0?nf
`Oooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`@030000o`3o]/40okK106H0
okK100<0003o0?nf`Oooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK108d0
okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0Q0?nf`@030000
o`3o]/40okK106P0okK100<0003oooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@0O0?nf`@80003oK03o]/400`000?ooooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK101h0okK100<0003o0?nf`@3o]/40K03o]/400oooool0003oooooo`0Rooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK101d0okK100<0003o0?nf`@3o]/40K@3o]/42ooooo`03o`00o`000?oooooo
023ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/40703o]/400`000?l0okK10?nf`@1^0?nf`@?o
oooo00<0003oooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK108d0
okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0K0?nf`@030000
o`3o]/40okK106l0okK11?ooool00`000?ooooooooooo`0Nooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK101/0okK100<0003o0?nf`@3o]/40K`3o]/45ooooo`030000oooooooooooo01gooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/406P3o]/400`000?l0okK10?nf`@1`0?nf`@Kooooo00<0003o
ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0I0?nf`@030000o`3o]/40okK1
0740okK11oooool00`000?ooooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101P0
okK100<0003o0?nf`@3o]/40LP3o]/48ooooo`030000oooooooooooo01[ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/405`3o]/400`000?l0okK10?nf`@1c0?nf`@Wooooo00<0003oooooooooool0
6Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0F0?nf`@030000o`3o]/40okK107@0okK12_oo
ool00`000?ooooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o
]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101D0okK100?o003o
0?nf`@3o]/40M@3o]/4;ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/405@3o]/400`000?l0okK10?nf`@1e0?nf`@cooooo00<0003oooooooooool05_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@0D0?nf`@030000o`3o]/40okK107H0okK13?ooool00`000?oo
ooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101<0okK100<0003o0?nf`@3o]/40
M`3o]/4=ooooo`030000oooooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404`3o
]/400`000?l0okK10?nf`@1g0?nf`@gooooo00<0003oooooooooool05Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?nf`@0B0?nf`@030000o`3o]/40okK107P0okK13_ooool00`000?ooooooooooo`0D
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK10180okK100<0003o0?nf`@3o]/40N03o]/4>oooo
o`030000oooooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf
`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404@3o]/400`000?l0
okK10?nf`@1i0?nf`@oooooo00<0003oooooooooool04oooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0@0?nf`@030000o`3o]/40okK107X0okK14?ooool00`000?ooooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK10100okK100<0003o0?nf`@3o]/40NP3o]/4@ooooo`030000oooo
oooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403`3o]/400`000?l0okK10?nf`@1k
0?nf`A7ooooo00<0003oooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0?0?nf
`@030000o`3o]/40okK107/0okK14Oooool00`000?ooooooooooo`0Aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100h0okK100<0003o0?nf`@3o]/40O03o]/4Booooo`030000oooooooooooo013o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/400`000?l0okK10?nf`@0B0?nf`Ggooooo
00<0003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10280okK1
T?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0<0?nf`@03o`00o`3o
]/40okK101<0okK1O_ooool00`000?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK100`0okK100<0003o0?nf`@3o]/404`3o]/5nooooo`030000oooooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/402`3o]/400`000?l0okK10?nf`@0D0?nf`Goooooo00<0003ooooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0;0?nf`@030000o`3o]/40okK101@0
okK1Ooooool00`000?ooooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
]/408P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100/0okK1
00<0003o0?nf`@3o]/40503o]/60ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/402P3o]/400`000?l0okK10?nf`@0E0?nf`H7ooooo00<0003oooooooooool03?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@0:0?nf`@030000o`3o]/40okK101D0okK1POooool0
0`000?ooooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100X0okK100<0003o0?nf
`@3o]/405@3o]/61ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/402@3o]/400`000?l0okK10?nf`@0F0?nf`H;ooooo00<0003oooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@090?nf`@030000o`3o]/40okK101H0okK1P_ooool00`000?oooooo
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100T0okK100<0003o0?nf`@3o]/405P3o
]/62ooooo`030000oooooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf
`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/40
0ol00?l0okK10?nf`@0G0?nf`H;ooooo00<0003oooooooooool02oooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@080?nf`@030000o`3o]/40okK101L0okK1Poooool00`000?ooooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/40603o]/63ooooo`03
0000oooooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0R0?nf`I3o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK1
0?nf`@0H0?nf`HCooooo00<0003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0okK10280okK1T?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@070?nf`@030000o`3o]/40okK101P0okK1Q?ooool00`000?ooooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/40603o]/64ooooo`030000oooooooo
oooo00Wooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@0I0?nf
`HGooooo00<0003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK1
0280okK1T?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@03
0000o`3o]/40okK101T0okK1QOooool00`000?ooooooooooo`08ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK100H0okK100<0003o0?nf`@3o]/406@3o]/65ooooo`030000oooooooooooo00Sooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@0I0?nf`HGooooo00<0
003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10280okK1T?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40
okK101T0okK1QOooool00`000?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
00D0okK100<0003o0?nf`@3o]/406P3o]/66ooooo`030000oooooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/401@3o]/400`000?l0okK10?nf`@0J0?nf`HKooooo00<0003ooooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK101X0okK1
Q_ooool00`000?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40
8P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100D0okK100<0
003o0?nf`@3o]/406P3o]/66ooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/401@3o]/400`000?l0okK10?nf`@0J0?nf`HKooooo00<0003oooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK101X0okK1Q_ooool00`00
0?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100D0okK100<0003o0?nf`@3o
]/406P3o]/66ooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
1@3o]/400`000?l0okK10?nf`@0J0?nf`HKooooo00<0003oooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK101X0okK1Q_ooool00`000?oooooooooo
o`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK100@0okK100<0003o0?nf`@3o]/406`3o]/66
ooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0R
0?nf`I3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40103o]/400`00
0?l0okK10?nf`@0K0?nf`HKooooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@040?nf`@030000o`3o]/40okK101/0okK1Q_ooool00`000?ooooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK100@0okK100<0003o0?nf`@3o]/406`3o]/4cooooo`<00000
D?ooool00`000?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40
8P3o]/6@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100@0okK100<0
003o0?nf`@3o]/40C@3o]/45000003@0okK16oooool00`000?ooooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK100@0okK100<0003o0?nf`@3o]/40C@3o]/45000003@0okK17?ooool0
0`000?ooooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4U
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100@0okK100<0003o0?nf
`@3o]/40C@3o]/45000003@0okK17?ooool00`000?ooooooooooo`06ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100@0okK100<0003o0?nf`@3o]/40CP3o]/43000003D0okK17?ooool00`000?oo
ooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100@0okK100<0003o0?nf`@3o]/40
QP3o]/4Looooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@2=0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40103o
]/400`000?l0okK10?nf`@260?nf`Acooooo00<0003oooooooooool01_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK108D0okK16oooool00`000?ooooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100D0okK100<0003o0?nf`@3o]/40Q@3o]/4Koooo
o`030000oooooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@2=0?nf
`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401@3o]/400`000?l0
okK10?nf`@250?nf`A_ooooo00<0003oooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@050?nf`@030000o`3o]/40okK108D0okK16oooool00`000?ooooooooooo`07ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK100D0okK100<0003o0?nf`@3o]/40Q@3o]/4Kooooo`030000oooo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@110?nf`AH00000=P3o
]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100D0okK100<0003o
0?nf`@3o]/40Q@3o]/4Kooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?nf`@0j0?nf`@L000005P3o]/47000002l0okK19Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@050?nf`@030000o`3o]/40okK108D0okK16oooool00`00
0?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40<`3o]/470000
02@0okK11`00000X0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/401@3o]/400`000?l0okK10?nf`@250?nf`A_ooooo00<0003oooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK102l0okK11000000b0?nf`@@00000903o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100D0okK100<0003o0?nf`@3o]/40
Q@3o]/4Kooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@0/0?nf`@<00000>P3o]/47000001d0okK19Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40okK108@0okK16_ooool00`000?oooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40:P3o]/42000004@0okK10`00
000J0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/40
0`000?l0okK10?nf`@240?nf`A[ooooo00<0003oooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0okK102P0okK10P0000190?nf`@0300000?l00000okK101L0okK19Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40okK1
08@0okK16_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3o]/409@3o]/400`00003o00000000001=0?nf`@D000004`3o]/4Uooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o]/40Q03o]/4Jooooo`03
0000oooooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0S0?nf`@80
0000E@3o]/4300000100okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@060?nf`@030000o`3o]/40okK108@0okK16_ooool00`000?ooooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/408@3o]/42000005X0okK100<000000?nf`@3o]/40
3@3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100L0okK100<0
003o0?nf`@3o]/40P`3o]/4Iooooo`030000oooooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?nf`@0P0?nf`@030000003o]/40okK105/0okK11000000;0?nf`BGooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@23
0?nf`AWooooo00<0003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK101h0okK100<00000o`00003o]/40H@3o]/42000000T0okK19Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o]/40okK108<0okK16Oooool00`00
0?ooooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40703o]/420000
06H0okK10P0000070?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/401`3o]/400`000?l0okK10?nf`@230?nf`AWooooo00<0003oooooooooool02Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0okK101/0okK100<000000?nf`@3o]/40J03o]/42000000D0
okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000
o`3o]/40okK10880okK16?ooool00`000?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3o]/406P3o]/400ol00000okK10?nf`@1[0?nf`@03o`000000000000000080okK1
9Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o
]/40okK10880okK16?ooool00`000?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3o]/406@3o]/400`000000okK10?nf`@1_0?nf`@8000009Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf`@030000o`3o]/40okK10880okK16?ooool0
0`000?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/405`3o]/42
000007@0okK100?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@080?nf`@030000o`3o]/40okK10880okK16?ooool00`000?ooooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/405@3o]/42000007H0okK100?ooooo0000
000000008_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@090?nf`@03
0000o`3o]/40okK10840okK15oooool00`000?ooooooooooo`0;ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3o]/40503o]/400`000000okK10?nf`@0O0?nf`A<00000A03o]/43ooooo`80
00008?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@090?nf`@030000
o`3o]/40okK10840okK15oooool00`000?ooooooooooo`0;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3o]/40503o]/400`000000okK10?nf`@0H0?nf`@L000004`3o]/4300000440okK1
1Oooool00`00003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK100T0okK100<0003o0?nf`@3o]/40P@3o]/4Gooooo`030000oooooooooooo00_ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@0C0?nf`@030000003o]/40okK101L0okK100?o
00000000003o]/40703o]/44000003d0okK11_ooool00`00003oooooooooo`0Looooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK100X0okK100<0003o0?nf`@3o]/40P03o]/4F
ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0B
0?nf`@030000003o]/40okK101H0okK10P00000S0?nf`@0400000?l000000000000003T0okK11ooo
ool2000001cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402P3o]/40
0`000?l0okK10?nf`@200?nf`AKooooo00<0003oooooooooool03?ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0okK10100okK100<00000o`00003o]/405@3o]/43000002T0okK10`00000f
0?nf`@Wooooo00<00000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0;0?nf`@030000o`3o]/40okK107l0okK15Oooool00`000?ooooooooooo`0=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/403`3o]/400`000000okK10?nf`@0C0?nf
`@<00000;`3o]/43000003<0okK12_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100/0okK100<0003o0?nf`@3o]/40O`3o]/4Eooooo`03
0000oooooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0>0?nf`@03
0000003o]/40okK10180okK10P00000e0?nf`@030000003o]/40okK10300okK12oooool2000001So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40303o]/400`000?l0okK1
0?nf`@0C0?nf`Goooooo00<0003oooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0okK100h0okK100<000000?nf`@3o]/40403o]/42000003Sooooo00?o0000000000000000
??ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK100`0okK100<0003o0?nf`@3o]/404`3o]/5oooooo`030000oooooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@0=0?nf`@030000003o]/40okK10100okK100<0
00000?nf`Oooool04oooool?000001Wooooo0P00000kooooo`0300000?oooooooooo01Cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/403@3o]/400`000?l0okK10?nf`@0B
0?nf`Gkooooo00<0003oooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK100`0okK100<000000?nf`@3o]/40403o]/400ol00000okK10?nf`@0@ooooo`@000003oooool4
000001Oooooo00<00000ooooooooool0>?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100d0okK100<0003o0?nf`@3o]/404P3o]/5noooo
o`030000oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0;0?nf
`@030000003o]/40okK100l0okK10P0000030?nf`@gooooo0`00000Gooooo`0400000?l000000000
000001Cooooo00<00000o`0000000000>?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK100h0okK100<0003o0?nf`@3o]/404@3o]/5noooo
o`030000oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0;0?nf
`@030000003o]/40okK100h0okK100<000000?nf`@3o]/400`3o]/49ooooo`@000007_ooool30000
01Cooooo00<00000ooooooooool0=_ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100h0okK100<0003o0?nf`@3o]/404@3o]/5mooooo`03
0000oooooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0:0?nf`@03
0000003o]/40okK100h0okK100?o00000?nf`@3o]/40103o]/46ooooo`<000009Oooool3000001;o
oooo00<00000ooooooooool0=_ooool2000001;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/403P3o]/400`000?l0okK10?nf`@0A0?nf`EWooooo3ol00?lDooooo`030000
oooooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@090?nf`@03o`00
00000000okK100h0okK100<000000?nf`@3o]/401@3o]/45ooooo`03o`000?oooooooooo02Wooooo
0`00000@ooooo`0300000?l0003ooooo03Oooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0?0?nf`@030000o`3o]/40okK10100okK1E?oo
ool5o`00o`oooooo1?l00?l?ooooo`030000oooooooooooo01;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?nf`@090?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/401P3o
]/43ooooo`8000004oooool8000001Cooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0eooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/40403o]/400`000?l0okK10?nf`@0?0?nf`Doooooo1Ol00?lHooooo`Go003o2_ooool0
0`000?ooooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40203o]/40
0`000000okK10?nf`@0=0?nf`@030000003o]/40okK100L0okK100?ooooo0000000000003Oooool8
000000Sooooo1`00000>ooooo`8000004?ooool2000003Kooooo00<00000ooooooooool03_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0A0?nf`@030000o`3o]/40okK1
00h0okK1Boooool4o`00ob;ooooo1Ol00?l4ooooo`030000oooooooooooo01?ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@080?nf`@030000003o]/40okK100`0okK100<000000?nf
`@3o]/40203o]/400ol0003oooooooooo`0:ooooo`<000005oooool3000000gooooo0P00000@oooo
o`0300000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@0B0?nf`@03o`00o`3o]/40okK100d0okK1BOooool2o`00ob_o
oooo00Go003ooooooooooooooooo0000o`0Eooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3o]/401`3o]/400`000000okK10?nf`@0<0?nf`@030000003o]/40okK100P0okK10P000009oooo
o`80000000?o0000ooooooooool06oooool00`00003o00000000000<ooooo`8000003oooool00`00
003oooooooooo`0dooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/404P3o]/400`000?l0okK10?nf`@0=0?nf`DOooooo0_l00?l^ooooo`;o
003o00<0003oooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100H0
okK100?o00000?nf`@3o]/40303o]/400`000000okK10?nf`@080?nf`@030000003o]/7ooooo00Oo
oooo0P00000Sooooo`0300000?oooooooooo00_ooooo0P00000>ooooo`03o`000000003ooooo03?o
oooo00<00000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0C0?nf`@030000o`3o]/40okK100`0okK1AOooool2o`00oc7ooooo00<0003oo`00ool00?l0
5Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100H0okK100<000000?nf`@3o]/40
2`3o]/400ol00000okK10?nf`@070?nf`@8000000P3o]/46ooooo`8000009_ooool3000000cooooo
00<00000ooooooooool03Oooool00`00003oooooooooo`0booooo`0300000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404`3o]/400`000?l0okK10?nf
`@0<0?nf`DCooooo00?o003oooooooooool0<Oooool00`000?ooooooooooo`02o`00oa?ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@050?nf`@030000003o]/40okK100/0okK100<0
00000?nf`@3o]/401`3o]/400`000000okK10?nf`@020?nf`@Gooooo00?o0000ooooooooool02_oo
ool00ol0000000000000000?000000gooooo0`00000:ooooo`03o`000?oooooooooo00gooooo00<0
0000ooooooooool0<_ooool00ol000000000ooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0okK101@0okK100<0003o0?nf`@3o]/402`3o]/52ooooo`;o003o<oooool0
0`000?ooooooooooo`03ooooo`;o003o4Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK100D0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40
okK10080okK11?ooool00`00003oooooooooo`09ooooo`<000004Oooool00ol00000000000000002
000000_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0<ooooo`03o`000?oooooo
oooo03?ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0D0?nf`@030000o`3o]/40okK100/0okK13_ooool;o`00obSooooo00?o003ooooo
ooooool0<oooool00`000?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@040?nf`@030000003o]/40okK100/0okK100<000000?nf
`@3o]/401`3o]/400`000000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool01oooool30000
01Wooooo0P00000:ooooo`8000002Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo
03?ooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0E0?nf`@030000o`3o]/40okK100X0okK12oooool3o`00o`_ooooo0ol00?lTooooo`03
o`00oooooooooooo03?ooooo00<0003oooooooooool01oooool2o`00o`kooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@040?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o
]/401P3o]/400ol00000okK10?nf`@040?nf`@;ooooo00<00000ooooooooool01Oooool3000001ko
oooo0P00000:ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool03?ooool00`00003o
ooooooooo`0booooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/405P3o]/400`000?l0okK10?nf`@090?nf`@Sooooo0ol00?lAooooo`;o003o
8?ooool2o`00ocGooooo00<0003oooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3o]/400`3o]/400`000000okK10?nf`@0;0?nf`@03o`00
003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`00003o0000ooooo`05ooooo`800000
3_ooool8000000gooooo00<00000o`00000000002?ooool00`00003oooooooooo`07ooooo`800000
3Oooool00`00003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/405`3o]/400`000?l0okK10?nf`@080?nf`@Kooooo0_l0
0?lFooooo`?o003o7?ooool00ol00?ooooooooooo`0dooooo`030000oooooooooooo00cooooo00?o
003oooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100<0okK100<0
00000?nf`@3o]/402`3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100D0okK100<0
0000ooooooooool01?ooool00`00003oooooooooo`07ooooo`L000002?ooool7000000Wooooo0P00
0007ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool02oooool00ol0003ooooooooo
o`0booooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/40603o]/400`000?l0okK10?nf`@070?nf`@Cooooo0_l00?lKooooo`;o003o6?ooool2
o`00ocKooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3o]/400P3o]/400`000000okK10?nf`@0<0?nf`@030000003o]/40
okK100D0okK100<000000?nf`@3o]/401@3o]/400`00003oooooooooo`04ooooo`0300000?oooooo
oooo00Kooooo0P00000Fooooo`8000002Oooool00`00003oooooooooo`05ooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool02oooool00`00003oooooooooo`0booooo`0300000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/406@3o]/400`00
0?l0okK10?nf`@060?nf`@?ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo03Gooooo00<0003oooooooooool04?ooool2o`00o`Wooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?nf`@020?nf`@030000003o]/40okK100/0okK100<000000?nf
`@3o]/401@3o]/42000000H0okK100<000000?nf`Oooool01?ooool00`00003oooooooooo`06oooo
o`03o`000?oooooooooo01Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00Oooooo00<00000ooooooooool02oooool00`00003oooooooooo`0boooo
o`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/406P3o]/400`000?l0okK10?nf`@050?nf`@;ooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo03Gooooo00<0003oooooooooool04oooool00ol00?oo
ooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400`000000
okK10?nf`@0:0?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@04ooooo`0300000?oooooooooo00Gooooo0P00000Looooo`0300000?l00000000000Oo
oooo00<00000ooooooooool01Oooool00`00003o0000ooooo`07ooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool0<Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK101/0okK100<0003o0?nf`@3o]/40103o]/400ooooooo003o
ooooo`0Rooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0=Oooool00`000?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?nf`@020?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/401P3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100?ooooo00<00000ooooooooool01?ooool2000000Sooooo
3`00000:ooooo`0300000?oooooooooo00Gooooo00?o000000000?ooool01_ooool00`00003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00`00003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101`0okK100?o
003o0?nf`@3o]/400`3o]/400ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool0=Oooool00`000?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool03oooool01Ol0003ooooo0?nf`@3o]/40000000`0okK100<000000?nf`@3o]/40
1P3o]/400`000000okK10?nf`@040?nf`@040000003o]/40okK10?nf`@;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`05ooooo`<000003oooool4000000Oooooo0P000007ooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0;ooooo`03
00000?oooooooooo033ooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0M0?nf`@030000o`3o]/40okK10080okK100?o003oooooooooool0
8oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo03Gooooo00<0003oooooooooool0
6?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00Go0000ooooo`3o]/40
okK10000000;0?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@020?nf`@03ooooool0003ooooo00Cooooo00<00000o`000?ooool01Oooool2000001Ko
oooo0P000007ooooo`8000001_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0`ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/407P3o]/4010000?l0okK1
0?nf`Ol00?lWooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0=Oooool00`000?oo
ooooooooo`0Jooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03oooool01Ol0003o
oooo0?nf`@3o]/40000000/0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@030?nf
`@030000003o]/40okK100<0okK100<00000ooooooooool01?ooool00`00003oooooooooo`03oooo
o`8000006_ooool2000000Oooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`0300000?oooooooooo00Oooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0`oooo
o`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/407`3o]/400`000?oo003o0?nf`@0Wooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool0=?ooool00`000?ooooooooooo`0Looooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool03oooool01Ol0003ooooo0?nf`@3o]/40000000/0okK100<000000?nf`@3o]/401@3o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<00000ooooooooool00oooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00Wooooo2000000;ooooo`8000001_ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01oooool00`00
003oooooooooo`0:ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0O0?nf`@03o`00o`000?l0okK102So
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0dooooo`030000oooooooooooo01ko
oooo00Go003oooooooooooooooooo`00000Aooooo`04o`000?ooool0okK1000000/0okK100<00000
0?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<00000
ooooooooool00oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0`000008
ooooo`@0000000?o0000ooooooooool01_ooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool01?ooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00_ooooo00<00000ooooooooool0;oooool00`00003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK101h0okK100Co003o0?nf`@3o]/7o003o:Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool08?ooool0
1?l00?ooooooooooool0000Aooooo`04o`000?ooool0okK1000000/0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK100<000000?nf`Oooool0
0oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00?ooooo1000000?ooooo`<00000
1oooool2000000Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`050000
0?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooo`3o]/407P3o]/401Ol00?l0okK1
0?nf`@3o]/40003o02Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0booooo`80
003o8oooool01?l00?ooooooooooool0000Aooooo`04o`000?ooool0okK1000000/0okK100<00000
0?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK100<00000
0?nf`Oooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool05?ooool2000000Oooooo00<00000ooooooooool00oooool00`00003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo033ooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool0
0ol0003ooooo0?nf`@0M0?nf`@03o`00o`3o]/40okK10080okK100?ooooo0000ooooool07oooool>
o`00o`;ooooo00?o003oooooooooool0<_ooool00`000?ooooooooooo`0Tooooo`03o`00oooooooo
0000017ooooo00?o0000ooooo`0000002`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@03ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0Gooooo`8000001_ooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0<?ooool0
1000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?nf`@0M0?nf`@03o`00o`3o]/40
okK10080okK10_ooool20000oa_ooooo0ol00?l8ooooo`03o`00oooooooooooo00?ooooo0ol00?lc
ooooo`030000oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003ooooo0000000;
0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK100;ooooo00<00000ooooooooool00_ooool00`00003o0000ooooo`04
ooooo`0300000?oooooooooo00Oooooo2000000;ooooo`0300000?oooooooooo00Cooooo00<00000
ooooooooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02oooooo00@00000
oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3o]/407@3o]/400ol00?l0okK10?nf`@02
0?nf`@Cooooo00<0003oooooooooool05_ooool2o`00o`_ooooo00?o003oooooooooool01?ooool0
1?l00?ooooooo`00ool00?l`ooooo`030000oooooooooooo02Sooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0000000;0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100;ooooo00<00000ooooooooool00_oo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo0`000008ooooo`<000002Ooo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02_oo
ool00`00003oooooooooo`0_ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oo
ool0okK101`0okK100?o003o0?nf`@3o]/400`3o]/45ooooo`80003o5?ooool2o`00o`kooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o;?ooool20000ob_ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0000000;0?nf`@030000003o]/40okK100D0okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@060000003o]/40okK10?nf`Oooool0
00001?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool03?ooool4000000Kooooo00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`03
00000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`05ooooo`03
00000?oooooooooo00_ooooo00<00000ooooooooool0;oooool00`00003oooooo`00000:ooooo`00
2Oooool00ol0003ooooo0?nf`@0L0?nf`@03o`00o`3o]/40okK100<0okK11oooool20000oa3ooooo
0_l00?l@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Wooooo`80003o;Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000/0okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00H000000?nf`@3o]/40okK1ooooo`000004ooooo`0300000?oooooooooo00;ooooo0P000005oooo
o`8000004oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool01_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/40703o]/400ol00?l0okK10?nf`@030?nf`@Wo
oooo0P000?l=ooooo`03o`00oooooooooooo017ooooo00Co003ooooooooooooo003o2?ooool00ol0
0?ooooooooooo`0Uooooo`030000oooooooooooo02gooooo00?o0000ooooooooool03oooool00ol0
003ooooo0000000;0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400ol0
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<00000ooooooooool00_ooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool04oooool20000
00Gooooo00<00000ooooooooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo
00[ooooo00<00000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0K0?nf`@03o`00o`3o]/40okK100l0okK100<0003o0?nf`@3o]/402@3o]/400ol00?l0
okK10?nf`@0B0?nf`@03o`00o`3o]/7o003o00X0okK100?o003o0?nf`@3o]/408P3o]/420000o`/0
okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000/0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@0F0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o
]/402`3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101/0okK1
00?o003o0?nf`@3o]/40403o]/420000o`P0okK100?o003o0?nf`@3o]/404`3o]/42o`00o``0okK1
0_l00?lP0?nf`@03o`00o`000?l0okK100`0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0000000X0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@050000
003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@080?nf`@Go00002`3o]/400ol00000
okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401P3o]/400`000000
okK10?nf`@0:0?nf`@030000003o]/40okK100X0okK19Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0K0?nf`@03o`00o`3o]/40okK10180okK10P000?l50?nf`@03o`00
o`3o]/40okK101@0okK10_l00?l=0?nf`@03o`00o`3o]/40okK101`0okK10P000?l?0?nf`BGooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@0:0?nf`@030000003o]/40okK100D0okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/401P3o]/43o`0000D0okK11?l000080?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100X0okK1
00<000000?nf`@3o]/402P3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0okK101/0okK100?o003o0?nf`@3o]/40503o]/420000o`<0000000?o003o0?nf`@3o]/40503o
]/400ol00?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK101T0okK10P000?lA0?nf`BGooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?nf`@0:0?nf`@030000003o]/40okK100D0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o
00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@0:0?nf`@03o`00003o]/40okK100D0okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<0
00000?nf`@3o]/402P3o]/400`000000okK10?nf`@0:0?nf`BGooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/406`3o]/400ol00?l0okK10?nf`@0E0?nf`@D000005P3o]/42
o`00o`l0okK100?o003o0?nf`@3o]/405`3o]/400`000?l0okK10?nf`@0A0?nf`BGooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?nf`@0:0?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/401@3o]/400ol00000okK10?nf`@0<0?nf`@03o`00003o]/40okK100D0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@0000001@3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/402P3o
]/400`000000okK10?nf`@090?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/406`3o]/400ol00?l0okK10?nf`@0E0?nf`@D000005P3o]/42o`00o`l0okK100?o003o
0?nf`@3o]/40503o]/430000oa@0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
okK100X0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000@0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100d0okK100?o
00000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100T0okK19Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0K0?nf`@03o`00o`3o]/40
okK101D0okK11@0000000ol00?l0003o0000o`0B0?nf`@03o`00o`3o]/7o003o0100okK100?o003o
0?nf`@3o]/404@3o]/400ol00?l0003o0?nf`@0F0?nf`BGooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?nf`@0:0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK10000
00040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf
`@0?0?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf
`@030?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/402`3o]/400`000000okK10?nf
`@080?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/406`3o]/40
0ol00?l0okK10?nf`@0F0?nf`@<00000103o]/430000o`l0okK100?o003o0?nf`Ol00?l04@3o]/40
0ol00?l0okK10?nf`@0=0?nf`@<0003o6@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3o]/402P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@000000103o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/403`3o
]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100/0okK100?o00000?nf`@3o]/40203o
]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101/0okK100?o003o
0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@080?nf`@80003o3@3o]/400ol00?l0okK1o`00o`0A
0?nf`@03o`00o`3o]/40okK100T0okK110000?lL0?nf`BGooooo00?o0000ooooooooool03oooool0
0ol0003oooooo`00000:0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK10000
00040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf
`@0A0?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf
`@080?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40703o]/40
0ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100X0okK110000?l80?nf`@03o`00o`3o]/7o
003o0180okK100?o003o0?nf`@3o]/40103o]/450000ob00okK19Oooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0000000X0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o
]/40000000@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00003o
]/40okK101<0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@03o`00003o
]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100<0okK100?o00000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000003o
]/40okK100P0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0L
0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/403`3o]/440000o`@0okK100?o003o
0?nf`Ol00?l04`3o]/401?l00?l0okK10?nf`Ol00?l20000obD0okK19Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0000000X0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf
`@3o]/40000000@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00
003o]/40okK101<0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000
003o]/40okK100P0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@0L0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/404`3o]/440000o`03o`00o`00
0?oo003o00<0003o3@3o]/460000obP0okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0000000X0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000@0okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK101<0okK1
00?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100P0okK1
9Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0L0?nf`@03o`00o`3o
]/40okK101<0okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK1o`00o`030?nf`@d0003o0`3o
]/400ol00?l0okK10?nf`@0X0?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0000
000;0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf
`@3o]/40000000@0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@0D0?nf`@03o`00
003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100D0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@070?nf`BGooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/407@3o]/400ol00?l0okK10?nf
`@0B0?nf`@03o`00o`3o]/40okK101L0okK10_l00?lE0?nf`@03o`00o`3o]/40okK102L0okK19Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000/0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK1
0?nf`@030?nf`@03o`00003o]/40okK101@0okK100?o00000?nf`@3o]/40103o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@0:0?nf`@030000003o]/40okK100L0okK19Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0M0?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/405`3o
]/400ol00?l0okK1o`00o`0E0?nf`@03o`00o`3o]/40okK102L0okK19Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0000000/0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@030?nf`@03o`00
003o]/40okK101@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000
003o]/40okK100L0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@0N0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/405`3o]/42o`00oaL0okK100?o
003o0?nf`@3o]/409P3o]/4Uooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/400000
2P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`Ol00000103o]/400`000000
okK10?nf`@020?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/404`3o]/400ol00000
okK10?nf`@040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000
okK10?nf`@050?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/401`3o]/4Uooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK101h0okK100?o003o0?nf`@3o]/40
403o]/400ol00?l0okK10?nf`@0G0?nf`@;o003o5`3o]/400ol00?l0okK10?nf`@0V0?nf`BGooooo
00?o0000ooooooooool03oooool01?l0003ooooo0?nf`@00000:0?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080
okK100D000000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/40103o]/400ol00000okK10?nf`@0B0?nf`@03o`00003o]/40okK100@0okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100D0okK100<000000?nf
`@3o]/402P3o]/400`000000okK10?nf`@070?nf`BGooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/407`3o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK101D0
okK10`00000H0?nf`@03o`00o`3o]/40okK102H0okK19Oooool00ol0003oooooooooo`0?ooooo`04
o`000?ooool0okK1000000X0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40
000000@0okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40
okK10140okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@030?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40
okK100L0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0O0?nf
`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o]/405@3o]/45000001L0okK100?o003o0?nf
`@3o]/409P3o]/4Uooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3o]/4000002P3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/40
1@000000okK10?nf`@3o]/40000000L0okK100?o00000?nf`@3o]/40403o]/400ol00000okK10?nf
`@050?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/401`3o]/4Uooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK10200okK100?o003o0?nf`@3o]/403@3o]/40
0ol00?l0okK10?nf`@0E0?nf`@D000005`3o]/400ol00?l0okK10?nf`@0V0?nf`BGooooo00?o0000
ooooooooool03oooool01Ol0003ooooo0?nf`@3o]/40000000X0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1
000000040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@050?nf`@03o`00003o]/40okK100l0okK100?o00000?nf`@3o]/40103o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@0:0?nf`@030000003o]/40okK100L0okK19Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0P0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/405@3o
]/45000001L0okK100?o003o0?nf`@3o]/409P3o]/4Uooooo`03o`000?oooooooooo00oooooo00Go
0000ooooo`3o]/40okK10000000:0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
1@3o]/400ol00000okK10?nf`@0;0?nf`@?o00001`3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000
003o]/40okK100L0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@0Q0?nf`@03o`00o`3o]/40okK100`0okK100?o003o0?nf`@3o]/405P3o]/43000001P0okK100?o
003o0?nf`@3o]/409P3o]/4Uooooo`03o`000?oooooooooo00oooooo00Go0000ooooo`3o]/40okK1
0000000:0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@030?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@020?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/43o`0000T0okK100?o00000?nf`@3o
]/401`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100L0okK19Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`@03o`00o`3o]/40okK100/0okK1
00?o003o0?nf`@3o]/405@3o]/400ol00?l0okK1o`00o`0I0?nf`@03o`00o`3o]/40okK102H0okK1
9Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10080okK100<000000?nf`@3o]/40
203o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100L0okK11?l000020?nf`@?o0000
2@3o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100L0okK19Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0S0?nf`@03o`00o`3o]/40okK100/0okK100?o
003o0?nf`@3o]/404`3o]/401?l00?l0okK10?nf`Ol00?lH0?nf`@03o`00o`3o]/40okK102L0okK1
9Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK10080okK100<000000?nf`@3o]/40
203o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@060000003o]/40okK10?nf`Ol000000000103o]/400`00
0000okK10?nf`@030?nf`@03o`0000000000okK100X0okK10_l0000;0?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1
00<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK1
00/0okK100<000000?nf`@3o]/401`3o]/4Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK102@0okK100?o003o0?nf`@3o]/402P3o]/400ol00?l0okK10?nf`@0B0?nf`@05
o`00o`3o]/40okK10?nf`Ol00?l0603o]/400ol00?l0okK10?nf`@0K0?nf`@<000002@3o]/4Uoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400P3o]/400`000000okK10?nf`@080?nf
`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100D0okK100<000000?nf`@3o]/405@3o]/400`000000okK10?nf`@040?nf
`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf
`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0;0?nf
`@030000003o]/40okK100L0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0U0?nf`@;o003o2P3o]/400ol00?l0okK10?nf`@0@0?nf`@;o003o103o]/400ol00?l0
okK10?nf`@0F0?nf`@03o`00o`3o]/40okK101X0okK11@0000080?nf`BGooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?nf`@020?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o
]/401@3o]/42000001@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@03
0000003o]/40okK100D0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@070?nf`BGo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/409`3o]/42o`00o`P0okK1
00?o003o0?nf`@3o]/403P3o]/42o`00o`H0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK1
0?nf`@0J0?nf`@D00000203o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/40
0P3o]/400ol00000okK10?nf`@090?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40
3`3o]/42000000L0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100/0okK100<000000?nf`@3o]/40203o]/4Uooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK102T0okK10_l00?l60?nf`@03o`00o`3o]/40okK100d0okK100?o
003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK101X0okK11@00
00080?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@030?nf`@030000003o
]/40okK100T0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@03o`00003o
]/40okK100<0okK10P0000070?nf`@<00000303o]/42000000L0okK10P0000050?nf`@030000003o
]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100D0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@080?nf`BGooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40:`3o]/43o`00o`@0okK100?o003o
0?nf`@3o]/402@3o]/43o`00o`T0okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0L
0?nf`@<000002@3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o]/400`3o]/40
0`000000okK10?nf`@090?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100L0okK1100000060?nf`@800000203o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/402`3o]/40
0ol00000okK10?nf`@080?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/40;P3o]/43o`00o`030?nf`Ol00?oo003o00P0okK10_l00?l<0?nf`@03o`00o`3o]/40okK1
01D0okK100?o003o0?nf`@3o]/40:03o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3o]/400`3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100D0okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100X0okK11P0000090?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0;0?nf
`@030000003o]/40okK100P0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@0a0?nf`@co003o3@3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK102T0
okK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0okK100@0okK100<000000?nf`@3o
]/402@3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@0G0?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o
]/401@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/401P3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100T0okK19Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0d0?nf`@03o`00o`3o]/40okK101<0okK1
00?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0Y0?nf`BGooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?nf`@040?nf`@030000003o]/40okK100T0okK100?o00000000003o]/40
1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK10P0000040?nf`@800000
103o]/42000000D0okK100@00000o`00000000000000503o]/42000000H0okK100?o00000?nf`@3o
]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/401@3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100T0okK19Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0d0?nf`@03o`00o`3o]/40okK101<0okK1
00?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0Z0?nf`BGooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?nf`@040?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@030?nf`@8000001`3o]/43000000d0okK1100000070?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100D0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@090?nf`BGooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40=03o]/400ol00?l0okK10?nf
`@0C0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40:P3o]/4Uooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3o]/401@3o]/400`000000okK10?nf`@0:0?nf`@030000003o
]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@070?nf`@@000001P3o
]/43000000X0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o
]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0;0?nf`@030000003o
]/40okK100X0okK19Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0e
0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@0[
0?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo0?nf`@060?nf`@03o`00003o]/40
okK100T0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40
okK100X0okK11P00000;0?nf`@03o`0000000000okK100D0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/402`3o]/40
0`000000okK10?nf`@0:0?nf`BGooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo]_l0000AoooookKo00002_ooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PolygonalAllPlot[poly, em\  // \ Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 g
.01923 .89217 m
.02324 .90385 L
.03553 .92308 L
.03846 .92658 L
.05471 .94231 L
.05769 .94475 L
.07692 .95808 L
.08288 .96154 L
.09615 .96761 L
.11538 .97322 L
.13462 .97529 L
.15385 .97483 L
.17308 .97319 L
.19231 .97159 L
.21154 .97081 L
.23077 .97103 L
.25 .97206 L
.26923 .97354 L
.28846 .97515 L
.30769 .97667 L
.32692 .97799 L
.34615 .97906 L
.36538 .97988 L
.38462 .98045 L
.40342 .98077 L
.01923 .98077 L
F
0 g
.01923 .89217 m
.02324 .90385 L
.03553 .92308 L
.03846 .92658 L
.05471 .94231 L
.05769 .94475 L
.07692 .95808 L
.08288 .96154 L
.09615 .96761 L
.11538 .97322 L
.13462 .97529 L
.15385 .97483 L
.17308 .97319 L
.19231 .97159 L
.21154 .97081 L
.23077 .97103 L
.25 .97206 L
.26923 .97354 L
.28846 .97515 L
.30769 .97667 L
.32692 .97799 L
.34615 .97906 L
.36538 .97988 L
.38462 .98045 L
.40342 .98077 L
s
.1 g
.01923 .32724 m
.01927 .32692 L
.0216 .30769 L
.02423 .28846 L
.02709 .26923 L
.03003 .25 L
.03278 .23077 L
.03489 .21154 L
.03594 .19231 L
.03575 .17308 L
.03475 .15385 L
.03401 .13462 L
.03503 .11538 L
.03846 .09881 L
.03927 .09615 L
.04782 .07692 L
.05769 .06225 L
.06154 .05769 L
.07692 .04298 L
.08274 .03846 L
.09615 .03057 L
.11538 .02359 L
.13462 .0211 L
.15385 .02175 L
.17308 .02386 L
.19231 .02586 L
.21154 .02671 L
.23077 .02615 L
.25 .02447 L
.26923 .02218 L
.28846 .01972 L
.29239 .01923 L
.01923 .01923 L
F
0 g
.01923 .32724 m
.01927 .32692 L
.0216 .30769 L
.02423 .28846 L
.02709 .26923 L
.03003 .25 L
.03278 .23077 L
.03489 .21154 L
.03594 .19231 L
.03575 .17308 L
.03475 .15385 L
.03401 .13462 L
.03503 .11538 L
.03846 .09881 L
.03927 .09615 L
.04782 .07692 L
.05769 .06225 L
.06154 .05769 L
.07692 .04298 L
.08274 .03846 L
.09615 .03057 L
.11538 .02359 L
.13462 .0211 L
.15385 .02175 L
.17308 .02386 L
.19231 .02586 L
.21154 .02671 L
.23077 .02615 L
.25 .02447 L
.26923 .02218 L
.28846 .01972 L
.29239 .01923 L
s
.01923 .96121 m
.01962 .96154 L
.03846 .97693 L
.04342 .98077 L
.01923 .98077 L
F
.01923 .96121 m
.01962 .96154 L
.03846 .97693 L
.04342 .98077 L
s
.01923 .04228 m
.02237 .03846 L
.03846 .02072 L
.03992 .01923 L
.01923 .01923 L
F
.01923 .04228 m
.02237 .03846 L
.03846 .02072 L
.03992 .01923 L
s
.1 g
.01923 .86038 m
.02272 .84615 L
.02828 .82692 L
.03258 .80769 L
.03436 .78846 L
.03372 .76923 L
.03151 .75 L
.02862 .73077 L
.02564 .71154 L
.02283 .69231 L
.02028 .67308 L
.01923 .66451 L
F
0 g
.01923 .86038 m
.02272 .84615 L
.02828 .82692 L
.03258 .80769 L
.03436 .78846 L
.03372 .76923 L
.03151 .75 L
.02862 .73077 L
.02564 .71154 L
.02283 .69231 L
.02028 .67308 L
.01923 .66451 L
s
.3 g
.30769 .03615 m
.32692 .03342 L
.34615 .03113 L
.36538 .02927 L
.38462 .02781 L
.40385 .02673 L
.42308 .02603 L
.44231 .02568 L
.46154 .02568 L
.48077 .02603 L
.5 .02672 L
.51923 .02777 L
.53846 .02918 L
.55769 .03097 L
.57692 .03317 L
.59615 .0358 L
.61287 .03846 L
.61538 .0389 L
.63462 .04252 L
.65385 .04674 L
.67308 .05168 L
.69231 .05751 L
.69287 .05769 L
.71154 .06433 L
.73077 .07326 L
.7371 .07692 L
.75 .08217 L
.76077 .09615 L
.76811 .11538 L
.75982 .13462 L
.75 .14638 L
.73388 .15385 L
.73077 .15551 L
.71154 .16399 L
.69231 .17043 L
.68296 .17308 L
.67308 .17568 L
.65385 .18009 L
.63462 .1838 L
.61538 .18692 L
.59615 .18952 L
.57692 .19166 L
.57017 .19231 L
.55769 .19331 L
.53846 .19455 L
.51923 .19542 L
.5 .19595 L
.48077 .19614 L
.46154 .19599 L
.44231 .19551 L
.42308 .19469 L
.40385 .19354 L
.3877 .19231 L
.38462 .19202 L
.36538 .19005 L
.34615 .18769 L
.32692 .18494 L
.30769 .18188 L
.28846 .17867 L
.26923 .17572 L
.25 .17381 L
.23077 .17438 L
.21154 .18014 L
.19708 .19231 L
.19231 .1984 L
.18867 .21154 L
.18675 .23077 L
.18799 .25 L
.19066 .26923 L
.19231 .27976 L
.19377 .28846 L
.19686 .30769 L
.19984 .32692 L
.2028 .34615 L
.2061 .36538 L
.21042 .38462 L
.21154 .38865 L
.21639 .40385 L
.22753 .42308 L
.23077 .42654 L
.25 .4391 L
.26923 .44149 L
.28846 .43925 L
.30769 .4353 L
.32692 .43103 L
.34615 .42701 L
.36538 .42344 L
.36748 .42308 L
.38462 .42051 L
.40385 .41802 L
.42308 .41595 L
.44231 .41428 L
.46154 .41302 L
.48077 .41216 L
.5 .41171 L
.51923 .41167 L
.53846 .41204 L
.55769 .41284 L
.57692 .41409 L
.59615 .41582 L
.61538 .41806 L
.63462 .42087 L
.6473 .42308 L
.65385 .42437 L
.67308 .42875 L
.69231 .43419 L
.71154 .44116 L
.71424 .44231 L
.73077 .44952 L
.74638 .46154 L
.75 .46515 L
.75908 .48077 L
.75645 .5 L
.75 .5092 L
.7392 .51923 L
.73077 .52555 L
.71154 .53588 L
.70538 .53846 L
.69231 .54383 L
.67308 .55051 L
.65385 .55613 L
.64788 .55769 L
.63462 .56084 L
.61538 .56488 L
.59615 .56838 L
.57692 .57137 L
.55769 .5739 L
.53846 .57597 L
.52795 .57692 L
.51923 .57755 L
.5 .57867 L
.48077 .57941 L
.46154 .57978 L
.44231 .57975 L
.42308 .57933 L
.40385 .5785 L
.38462 .57724 L
.38062 .57692 L
.36538 .57542 L
.34615 .57309 L
.32692 .57031 L
.30769 .56725 L
.28846 .56448 L
.26923 .56339 L
.25 .56682 L
.23247 .57692 L
.23077 .57989 L
.21905 .59615 L
.21154 .61529 L
.21151 .61538 L
.20614 .63462 L
.20218 .65385 L
.1988 .67308 L
.19551 .69231 L
.19231 .7108 L
.19218 .71154 L
.18889 .73077 L
.18653 .75 L
.18689 .76923 L
.19231 .78565 L
.19397 .78846 L
.21154 .80322 L
.22799 .80769 L
.23077 .80816 L
.25 .80941 L
.26923 .80859 L
.28292 .80769 L
.28846 .80691 L
.30769 .80502 L
.32692 .80317 L
.34615 .80151 L
.36538 .8001 L
.38462 .79898 L
.40385 .79815 L
.42308 .79761 L
.44231 .79736 L
.46154 .79741 L
.48077 .79776 L
.5 .7984 L
.51923 .79936 L
.53846 .80062 L
.55769 .80221 L
.57692 .80413 L
.59615 .80641 L
.60574 .80769 L
.61538 .80919 L
.63462 .81254 L
.65385 .81646 L
.67308 .82105 L
.69231 .82653 L
.69354 .82692 L
.71154 .83297 L
.73077 .84168 L
.73822 .84615 L
.75 .85466 L
.75955 .86538 L
.76276 .88462 L
.75 .90289 L
.74891 .90385 L
.73077 .91697 L
.71605 .92308 L
.71154 .92502 L
.69231 .9322 L
.67308 .93807 L
.65689 .94231 L
.65385 .94303 L
.63462 .94724 L
.61538 .95092 L
.59615 .95415 L
.57692 .95696 L
.55769 .95939 L
.53846 .96145 L
.53759 .96154 L
.51923 .96317 L
.5 .96455 L
.48077 .96562 L
.46154 .96638 L
.44231 .96683 L
.42308 .96698 L
.40385 .96684 L
.38462 .96639 L
.36538 .96564 L
.34615 .96456 L
.32692 .96317 L
.3085 .96154 L
.30769 .96146 L
.28846 .95948 L
.26923 .95732 L
.25 .95517 L
.23077 .95331 L
.21154 .95205 L
.19231 .95159 L
.17308 .95174 L
.15385 .95181 L
.13462 .95069 L
.11538 .94708 L
.1012 .94231 L
.09615 .93983 L
.07692 .92749 L
.07191 .92308 L
.05769 .90608 L
.05649 .90385 L
.04924 .88462 L
.04808 .86538 L
.05083 .84615 L
.05487 .82692 L
.05769 .80871 L
.0578 .80769 L
.05822 .78846 L
.05769 .78101 L
.05624 .76923 L
.05279 .75 L
.04884 .73077 L
.04496 .71154 L
.04138 .69231 L
.03846 .67491 L
.03817 .67308 L
.03528 .65385 L
.03262 .63462 L
.03012 .61538 L
.02769 .59615 L
.02536 .57692 L
.02327 .55769 L
.02163 .53846 L
.02067 .51923 L
.02052 .5 L
.02116 .48077 L
.02243 .46154 L
.02409 .44231 L
.02594 .42308 L
.02786 .40385 L
.02983 .38462 L
.03194 .36538 L
.03426 .34615 L
.03687 .32692 L
.03846 .31634 L
.03984 .30769 L
.04318 .28846 L
.04687 .26923 L
.0508 .25 L
.05469 .23077 L
.05769 .21439 L
.05811 .21154 L
.06054 .19231 L
.06177 .17308 L
.06219 .15385 L
.06298 .13462 L
.06581 .11538 L
.07257 .09615 L
.07692 .08813 L
.08561 .07692 L
.09615 .06749 L
.11356 .05769 L
.11538 .05706 L
.13462 .05232 L
.15385 .05114 L
.17308 .05162 L
.19231 .05206 L
.21154 .05135 L
.23077 .04926 L
.25 .04619 L
.26923 .04272 L
.28846 .03929 L
.29332 .03846 L
F
0 g
.30769 .03615 m
.32692 .03342 L
.34615 .03113 L
.36538 .02927 L
.38462 .02781 L
.40385 .02673 L
.42308 .02603 L
.44231 .02568 L
.46154 .02568 L
.48077 .02603 L
.5 .02672 L
.51923 .02777 L
.53846 .02918 L
.55769 .03097 L
.57692 .03317 L
.59615 .0358 L
.61287 .03846 L
.61538 .0389 L
.63462 .04252 L
.65385 .04674 L
.67308 .05168 L
.69231 .05751 L
.69287 .05769 L
.71154 .06433 L
.73077 .07326 L
.7371 .07692 L
.75 .08217 L
.76077 .09615 L
.76811 .11538 L
.75982 .13462 L
.75 .14638 L
.73388 .15385 L
.73077 .15551 L
.71154 .16399 L
.69231 .17043 L
.68296 .17308 L
.67308 .17568 L
.65385 .18009 L
.63462 .1838 L
.61538 .18692 L
.59615 .18952 L
.57692 .19166 L
.57017 .19231 L
.55769 .19331 L
.53846 .19455 L
.51923 .19542 L
.5 .19595 L
.48077 .19614 L
.46154 .19599 L
.44231 .19551 L
Mistroke
.42308 .19469 L
.40385 .19354 L
.3877 .19231 L
.38462 .19202 L
.36538 .19005 L
.34615 .18769 L
.32692 .18494 L
.30769 .18188 L
.28846 .17867 L
.26923 .17572 L
.25 .17381 L
.23077 .17438 L
.21154 .18014 L
.19708 .19231 L
.19231 .1984 L
.18867 .21154 L
.18675 .23077 L
.18799 .25 L
.19066 .26923 L
.19231 .27976 L
.19377 .28846 L
.19686 .30769 L
.19984 .32692 L
.2028 .34615 L
.2061 .36538 L
.21042 .38462 L
.21154 .38865 L
.21639 .40385 L
.22753 .42308 L
.23077 .42654 L
.25 .4391 L
.26923 .44149 L
.28846 .43925 L
.30769 .4353 L
.32692 .43103 L
.34615 .42701 L
.36538 .42344 L
.36748 .42308 L
.38462 .42051 L
.40385 .41802 L
.42308 .41595 L
.44231 .41428 L
.46154 .41302 L
.48077 .41216 L
.5 .41171 L
.51923 .41167 L
.53846 .41204 L
.55769 .41284 L
.57692 .41409 L
.59615 .41582 L
Mistroke
.61538 .41806 L
.63462 .42087 L
.6473 .42308 L
.65385 .42437 L
.67308 .42875 L
.69231 .43419 L
.71154 .44116 L
.71424 .44231 L
.73077 .44952 L
.74638 .46154 L
.75 .46515 L
.75908 .48077 L
.75645 .5 L
.75 .5092 L
.7392 .51923 L
.73077 .52555 L
.71154 .53588 L
.70538 .53846 L
.69231 .54383 L
.67308 .55051 L
.65385 .55613 L
.64788 .55769 L
.63462 .56084 L
.61538 .56488 L
.59615 .56838 L
.57692 .57137 L
.55769 .5739 L
.53846 .57597 L
.52795 .57692 L
.51923 .57755 L
.5 .57867 L
.48077 .57941 L
.46154 .57978 L
.44231 .57975 L
.42308 .57933 L
.40385 .5785 L
.38462 .57724 L
.38062 .57692 L
.36538 .57542 L
.34615 .57309 L
.32692 .57031 L
.30769 .56725 L
.28846 .56448 L
.26923 .56339 L
.25 .56682 L
.23247 .57692 L
.23077 .57989 L
.21905 .59615 L
.21154 .61529 L
.21151 .61538 L
Mistroke
.20614 .63462 L
.20218 .65385 L
.1988 .67308 L
.19551 .69231 L
.19231 .7108 L
.19218 .71154 L
.18889 .73077 L
.18653 .75 L
.18689 .76923 L
.19231 .78565 L
.19397 .78846 L
.21154 .80322 L
.22799 .80769 L
.23077 .80816 L
.25 .80941 L
.26923 .80859 L
.28292 .80769 L
.28846 .80691 L
.30769 .80502 L
.32692 .80317 L
.34615 .80151 L
.36538 .8001 L
.38462 .79898 L
.40385 .79815 L
.42308 .79761 L
.44231 .79736 L
.46154 .79741 L
.48077 .79776 L
.5 .7984 L
.51923 .79936 L
.53846 .80062 L
.55769 .80221 L
.57692 .80413 L
.59615 .80641 L
.60574 .80769 L
.61538 .80919 L
.63462 .81254 L
.65385 .81646 L
.67308 .82105 L
.69231 .82653 L
.69354 .82692 L
.71154 .83297 L
.73077 .84168 L
.73822 .84615 L
.75 .85466 L
.75955 .86538 L
.76276 .88462 L
.75 .90289 L
.74891 .90385 L
.73077 .91697 L
Mistroke
.71605 .92308 L
.71154 .92502 L
.69231 .9322 L
.67308 .93807 L
.65689 .94231 L
.65385 .94303 L
.63462 .94724 L
.61538 .95092 L
.59615 .95415 L
.57692 .95696 L
.55769 .95939 L
.53846 .96145 L
.53759 .96154 L
.51923 .96317 L
.5 .96455 L
.48077 .96562 L
.46154 .96638 L
.44231 .96683 L
.42308 .96698 L
.40385 .96684 L
.38462 .96639 L
.36538 .96564 L
.34615 .96456 L
.32692 .96317 L
.3085 .96154 L
.30769 .96146 L
.28846 .95948 L
.26923 .95732 L
.25 .95517 L
.23077 .95331 L
.21154 .95205 L
.19231 .95159 L
.17308 .95174 L
.15385 .95181 L
.13462 .95069 L
.11538 .94708 L
.1012 .94231 L
.09615 .93983 L
.07692 .92749 L
.07191 .92308 L
.05769 .90608 L
.05649 .90385 L
.04924 .88462 L
.04808 .86538 L
.05083 .84615 L
.05487 .82692 L
.05769 .80871 L
.0578 .80769 L
.05822 .78846 L
.05769 .78101 L
Mistroke
.05624 .76923 L
.05279 .75 L
.04884 .73077 L
.04496 .71154 L
.04138 .69231 L
.03846 .67491 L
.03817 .67308 L
.03528 .65385 L
.03262 .63462 L
.03012 .61538 L
.02769 .59615 L
.02536 .57692 L
.02327 .55769 L
.02163 .53846 L
.02067 .51923 L
.02052 .5 L
.02116 .48077 L
.02243 .46154 L
.02409 .44231 L
.02594 .42308 L
.02786 .40385 L
.02983 .38462 L
.03194 .36538 L
.03426 .34615 L
.03687 .32692 L
.03846 .31634 L
.03984 .30769 L
.04318 .28846 L
.04687 .26923 L
.0508 .25 L
.05469 .23077 L
.05769 .21439 L
.05811 .21154 L
.06054 .19231 L
.06177 .17308 L
.06219 .15385 L
.06298 .13462 L
.06581 .11538 L
.07257 .09615 L
.07692 .08813 L
.08561 .07692 L
.09615 .06749 L
.11356 .05769 L
.11538 .05706 L
.13462 .05232 L
.15385 .05114 L
.17308 .05162 L
.19231 .05206 L
.21154 .05135 L
.23077 .04926 L
Mistroke
.25 .04619 L
.26923 .04272 L
.28846 .03929 L
.29332 .03846 L
.30769 .03615 L
Mfstroke
.4 g
.28846 .05674 m
.30769 .05249 L
.32692 .04895 L
.34615 .04605 L
.36538 .04372 L
.38462 .04191 L
.40385 .04057 L
.42308 .03969 L
.44231 .03923 L
.46154 .03919 L
.48077 .03955 L
.5 .04034 L
.51923 .04154 L
.53846 .04318 L
.55769 .04528 L
.57692 .04789 L
.59615 .05106 L
.61538 .05488 L
.62756 .05769 L
.63462 .0594 L
.65385 .06481 L
.67308 .07182 L
.68411 .07692 L
.69231 .07838 L
.71154 .09502 L
.71219 .09615 L
.72033 .11538 L
.71154 .13286 L
.70979 .13462 L
.69231 .14888 L
.67684 .15385 L
.67308 .15538 L
.65385 .16196 L
.63462 .16701 L
.61538 .17103 L
.60375 .17308 L
.59615 .17429 L
.57692 .17695 L
.55769 .17904 L
.53846 .18064 L
.51923 .18177 L
.5 .18247 L
.48077 .18275 L
.46154 .18261 L
.44231 .18207 L
.42308 .18111 L
.40385 .17973 L
.38462 .17791 L
.36538 .17562 L
.34769 .17308 L
.34615 .17283 L
.32692 .16951 L
.30769 .16561 L
.28846 .16119 L
.26923 .15645 L
.25993 .15385 L
.25 .15233 L
.23077 .14984 L
.21154 .1503 L
.19576 .15385 L
.19231 .15559 L
.17308 .17286 L
.17294 .17308 L
.16486 .19231 L
.16296 .21154 L
.16497 .23077 L
.16875 .25 L
.17302 .26923 L
.17308 .26948 L
.17745 .28846 L
.18152 .30769 L
.18519 .32692 L
.18859 .34615 L
.19202 .36538 L
.19231 .36689 L
.19585 .38462 L
.20091 .40385 L
.20838 .42308 L
.21154 .42919 L
.2189 .44231 L
.23077 .4535 L
.24466 .46154 L
.25 .46254 L
.26923 .46238 L
.27574 .46154 L
.28846 .45802 L
.30769 .45206 L
.32692 .44648 L
.34333 .44231 L
.34615 .44163 L
.36538 .43742 L
.38462 .43387 L
.40385 .43092 L
.42308 .42853 L
.44231 .42666 L
.46154 .42528 L
.48077 .42438 L
.5 .42396 L
.51923 .42403 L
.53846 .42458 L
.55769 .42565 L
.57692 .42728 L
.59615 .42951 L
.61538 .43244 L
.63462 .43622 L
.65385 .4411 L
.65791 .44231 L
.67308 .44689 L
.69231 .45556 L
.70091 .46154 L
.71154 .47104 L
.71746 .48077 L
.71555 .5 L
.71154 .50582 L
.69635 .51923 L
.69231 .5221 L
.67308 .53237 L
.65646 .53846 L
.65385 .5394 L
.63462 .54551 L
.61538 .55052 L
.59615 .55468 L
.57957 .55769 L
.57692 .55812 L
.55769 .56092 L
.53846 .56318 L
.51923 .56495 L
.5 .56624 L
.48077 .56705 L
.46154 .56739 L
.44231 .56726 L
.42308 .56663 L
.40385 .56548 L
.38462 .56377 L
.36538 .56146 L
.34615 .55847 L
.34179 .55769 L
.32692 .55483 L
.30769 .55053 L
.28846 .54588 L
.26923 .54227 L
.25 .54323 L
.23077 .55343 L
.22538 .55769 L
.21186 .57692 L
.21154 .57758 L
.2027 .59615 L
.19642 .61538 L
.19231 .63207 L
.19173 .63462 L
.18769 .65385 L
.18383 .67308 L
.17978 .69231 L
.17535 .71154 L
.17308 .72059 L
.17074 .73077 L
.16644 .75 L
.16374 .76923 L
.16575 .78846 L
.17308 .80559 L
.17761 .80769 L
.19231 .81758 L
.21154 .82335 L
.23077 .82499 L
.25 .82425 L
.26923 .82226 L
.28846 .81977 L
.30769 .81725 L
.32692 .81493 L
.34615 .81293 L
.36538 .81128 L
.38462 .80998 L
.40385 .80905 L
.42308 .80845 L
.44231 .8082 L
.46154 .80829 L
.48077 .80873 L
.5 .80951 L
.51923 .81067 L
.53846 .81221 L
.55769 .81416 L
.57692 .81656 L
.59615 .81946 L
.61538 .82295 L
.63365 .82692 L
.63462 .82714 L
.65385 .83206 L
.67308 .83843 L
.69006 .84615 L
.69231 .84732 L
.71154 .86077 L
.71564 .86538 L
.7198 .88462 L
.71154 .89746 L
.70422 .90385 L
.69231 .9125 L
.67308 .92085 L
.66577 .92308 L
.65385 .92719 L
.63462 .93276 L
.61538 .93736 L
.59615 .94123 L
.59018 .94231 L
.57692 .94447 L
.55769 .94721 L
.53846 .94952 L
.51923 .95143 L
.5 .95297 L
.48077 .95415 L
.46154 .95498 L
.44231 .95547 L
.42308 .95562 L
.40385 .95542 L
.38462 .95489 L
.36538 .954 L
.34615 .95274 L
.32692 .95112 L
.30769 .94911 L
.28846 .94675 L
.26923 .94411 L
.25684 .94231 L
.25 .94133 L
.23077 .93868 L
.21154 .93649 L
.19231 .93499 L
.17308 .93405 L
.15385 .93293 L
.13462 .93037 L
.11538 .92472 L
.1115 .92308 L
.09615 .91412 L
.08598 .90385 L
.07692 .88829 L
.07561 .88462 L
.07301 .86538 L
.07519 .84615 L
.07692 .83695 L
.07907 .82692 L
.08155 .80769 L
.08086 .78846 L
.07764 .76923 L
.07692 .76509 L
.07235 .75 L
.06668 .73077 L
.06157 .71154 L
.05769 .6949 L
.05712 .69231 L
.05319 .67308 L
.04974 .65385 L
.04664 .63462 L
.04377 .61538 L
.04105 .59615 L
.03848 .57692 L
.03846 .57677 L
.03619 .55769 L
.03441 .53846 L
.03334 .51923 L
.03315 .5 L
.0338 .48077 L
.03514 .46154 L
.03693 .44231 L
.03846 .42754 L
.03895 .42308 L
.04109 .40385 L
.04335 .38462 L
.04579 .36538 L
.04851 .34615 L
.05163 .32692 L
.05523 .30769 L
.05769 .29601 L
.05937 .28846 L
.06409 .26923 L
.06947 .25 L
.07535 .23077 L
.07692 .22593 L
.08015 .21154 L
.08459 .19231 L
.08775 .17308 L
.08957 .15385 L
.09187 .13462 L
.09615 .11754 L
.09726 .11538 L
.11053 .09615 L
.11538 .09229 L
.13462 .08287 L
.15385 .07976 L
.17308 .07889 L
.19231 .07772 L
.21051 .07692 L
.21154 .07673 L
.23077 .07204 L
.25 .06653 L
.26923 .06134 L
.28456 .05769 L
F
0 g
.28846 .05674 m
.30769 .05249 L
.32692 .04895 L
.34615 .04605 L
.36538 .04372 L
.38462 .04191 L
.40385 .04057 L
.42308 .03969 L
.44231 .03923 L
.46154 .03919 L
.48077 .03955 L
.5 .04034 L
.51923 .04154 L
.53846 .04318 L
.55769 .04528 L
.57692 .04789 L
.59615 .05106 L
.61538 .05488 L
.62756 .05769 L
.63462 .0594 L
.65385 .06481 L
.67308 .07182 L
.68411 .07692 L
.69231 .07838 L
.71154 .09502 L
.71219 .09615 L
.72033 .11538 L
.71154 .13286 L
.70979 .13462 L
.69231 .14888 L
.67684 .15385 L
.67308 .15538 L
.65385 .16196 L
.63462 .16701 L
.61538 .17103 L
.60375 .17308 L
.59615 .17429 L
.57692 .17695 L
.55769 .17904 L
.53846 .18064 L
.51923 .18177 L
.5 .18247 L
.48077 .18275 L
.46154 .18261 L
.44231 .18207 L
.42308 .18111 L
.40385 .17973 L
.38462 .17791 L
.36538 .17562 L
.34769 .17308 L
Mistroke
.34615 .17283 L
.32692 .16951 L
.30769 .16561 L
.28846 .16119 L
.26923 .15645 L
.25993 .15385 L
.25 .15233 L
.23077 .14984 L
.21154 .1503 L
.19576 .15385 L
.19231 .15559 L
.17308 .17286 L
.17294 .17308 L
.16486 .19231 L
.16296 .21154 L
.16497 .23077 L
.16875 .25 L
.17302 .26923 L
.17308 .26948 L
.17745 .28846 L
.18152 .30769 L
.18519 .32692 L
.18859 .34615 L
.19202 .36538 L
.19231 .36689 L
.19585 .38462 L
.20091 .40385 L
.20838 .42308 L
.21154 .42919 L
.2189 .44231 L
.23077 .4535 L
.24466 .46154 L
.25 .46254 L
.26923 .46238 L
.27574 .46154 L
.28846 .45802 L
.30769 .45206 L
.32692 .44648 L
.34333 .44231 L
.34615 .44163 L
.36538 .43742 L
.38462 .43387 L
.40385 .43092 L
.42308 .42853 L
.44231 .42666 L
.46154 .42528 L
.48077 .42438 L
.5 .42396 L
.51923 .42403 L
.53846 .42458 L
Mistroke
.55769 .42565 L
.57692 .42728 L
.59615 .42951 L
.61538 .43244 L
.63462 .43622 L
.65385 .4411 L
.65791 .44231 L
.67308 .44689 L
.69231 .45556 L
.70091 .46154 L
.71154 .47104 L
.71746 .48077 L
.71555 .5 L
.71154 .50582 L
.69635 .51923 L
.69231 .5221 L
.67308 .53237 L
.65646 .53846 L
.65385 .5394 L
.63462 .54551 L
.61538 .55052 L
.59615 .55468 L
.57957 .55769 L
.57692 .55812 L
.55769 .56092 L
.53846 .56318 L
.51923 .56495 L
.5 .56624 L
.48077 .56705 L
.46154 .56739 L
.44231 .56726 L
.42308 .56663 L
.40385 .56548 L
.38462 .56377 L
.36538 .56146 L
.34615 .55847 L
.34179 .55769 L
.32692 .55483 L
.30769 .55053 L
.28846 .54588 L
.26923 .54227 L
.25 .54323 L
.23077 .55343 L
.22538 .55769 L
.21186 .57692 L
.21154 .57758 L
.2027 .59615 L
.19642 .61538 L
.19231 .63207 L
.19173 .63462 L
Mistroke
.18769 .65385 L
.18383 .67308 L
.17978 .69231 L
.17535 .71154 L
.17308 .72059 L
.17074 .73077 L
.16644 .75 L
.16374 .76923 L
.16575 .78846 L
.17308 .80559 L
.17761 .80769 L
.19231 .81758 L
.21154 .82335 L
.23077 .82499 L
.25 .82425 L
.26923 .82226 L
.28846 .81977 L
.30769 .81725 L
.32692 .81493 L
.34615 .81293 L
.36538 .81128 L
.38462 .80998 L
.40385 .80905 L
.42308 .80845 L
.44231 .8082 L
.46154 .80829 L
.48077 .80873 L
.5 .80951 L
.51923 .81067 L
.53846 .81221 L
.55769 .81416 L
.57692 .81656 L
.59615 .81946 L
.61538 .82295 L
.63365 .82692 L
.63462 .82714 L
.65385 .83206 L
.67308 .83843 L
.69006 .84615 L
.69231 .84732 L
.71154 .86077 L
.71564 .86538 L
.7198 .88462 L
.71154 .89746 L
.70422 .90385 L
.69231 .9125 L
.67308 .92085 L
.66577 .92308 L
.65385 .92719 L
.63462 .93276 L
Mistroke
.61538 .93736 L
.59615 .94123 L
.59018 .94231 L
.57692 .94447 L
.55769 .94721 L
.53846 .94952 L
.51923 .95143 L
.5 .95297 L
.48077 .95415 L
.46154 .95498 L
.44231 .95547 L
.42308 .95562 L
.40385 .95542 L
.38462 .95489 L
.36538 .954 L
.34615 .95274 L
.32692 .95112 L
.30769 .94911 L
.28846 .94675 L
.26923 .94411 L
.25684 .94231 L
.25 .94133 L
.23077 .93868 L
.21154 .93649 L
.19231 .93499 L
.17308 .93405 L
.15385 .93293 L
.13462 .93037 L
.11538 .92472 L
.1115 .92308 L
.09615 .91412 L
.08598 .90385 L
.07692 .88829 L
.07561 .88462 L
.07301 .86538 L
.07519 .84615 L
.07692 .83695 L
.07907 .82692 L
.08155 .80769 L
.08086 .78846 L
.07764 .76923 L
.07692 .76509 L
.07235 .75 L
.06668 .73077 L
.06157 .71154 L
.05769 .6949 L
.05712 .69231 L
.05319 .67308 L
.04974 .65385 L
.04664 .63462 L
Mistroke
.04377 .61538 L
.04105 .59615 L
.03848 .57692 L
.03846 .57677 L
.03619 .55769 L
.03441 .53846 L
.03334 .51923 L
.03315 .5 L
.0338 .48077 L
.03514 .46154 L
.03693 .44231 L
.03846 .42754 L
.03895 .42308 L
.04109 .40385 L
.04335 .38462 L
.04579 .36538 L
.04851 .34615 L
.05163 .32692 L
.05523 .30769 L
.05769 .29601 L
.05937 .28846 L
.06409 .26923 L
.06947 .25 L
.07535 .23077 L
.07692 .22593 L
.08015 .21154 L
.08459 .19231 L
.08775 .17308 L
.08957 .15385 L
.09187 .13462 L
.09615 .11754 L
.09726 .11538 L
.11053 .09615 L
.11538 .09229 L
.13462 .08287 L
.15385 .07976 L
.17308 .07889 L
.19231 .07772 L
.21051 .07692 L
.21154 .07673 L
.23077 .07204 L
.25 .06653 L
.26923 .06134 L
.28456 .05769 L
.28846 .05674 L
Mfstroke
.5 g
.11538 .22268 m
.13462 .23064 L
.13475 .23077 L
.14606 .25 L
.15385 .26796 L
.15438 .26923 L
.16134 .28846 L
.16686 .30769 L
.17138 .32692 L
.17308 .33508 L
.1754 .34615 L
.17925 .36538 L
.18328 .38462 L
.18805 .40385 L
.19231 .4177 L
.19414 .42308 L
.20206 .44231 L
.21154 .45912 L
.21246 .46154 L
.22448 .48077 L
.23077 .4874 L
.23764 .5 L
.23113 .51923 L
.23077 .51974 L
.21633 .53846 L
.21154 .54865 L
.2059 .55769 L
.19657 .57692 L
.19231 .58784 L
.18935 .59615 L
.18352 .61538 L
.17866 .63462 L
.17415 .65385 L
.17308 .65841 L
.16968 .67308 L
.16458 .69231 L
.15827 .71154 L
.15385 .7226 L
.15045 .73077 L
.14091 .75 L
.13462 .75729 L
.12478 .76923 L
.11538 .76945 L
.11497 .76923 L
.09725 .75 L
.09615 .74824 L
.08504 .73077 L
.07827 .71154 L
.07692 .70589 L
.0725 .69231 L
.06729 .67308 L
.06299 .65385 L
.05929 .63462 L
.05769 .62557 L
.05595 .61538 L
.05284 .59615 L
.04999 .57692 L
.04749 .55769 L
.04555 .53846 L
.04439 .51923 L
.04416 .5 L
.04483 .48077 L
.04624 .46154 L
.04816 .44231 L
.05038 .42308 L
.05278 .40385 L
.05538 .38462 L
.05769 .36896 L
.05824 .36538 L
.06148 .34615 L
.06532 .32692 L
.06997 .30769 L
.07573 .28846 L
.07692 .28499 L
.08123 .26923 L
.09053 .25 L
.09615 .24234 L
.10465 .23077 L
F
0 g
.11538 .22268 m
.13462 .23064 L
.13475 .23077 L
.14606 .25 L
.15385 .26796 L
.15438 .26923 L
.16134 .28846 L
.16686 .30769 L
.17138 .32692 L
.17308 .33508 L
.1754 .34615 L
.17925 .36538 L
.18328 .38462 L
.18805 .40385 L
.19231 .4177 L
.19414 .42308 L
.20206 .44231 L
.21154 .45912 L
.21246 .46154 L
.22448 .48077 L
.23077 .4874 L
.23764 .5 L
.23113 .51923 L
.23077 .51974 L
.21633 .53846 L
.21154 .54865 L
.2059 .55769 L
.19657 .57692 L
.19231 .58784 L
.18935 .59615 L
.18352 .61538 L
.17866 .63462 L
.17415 .65385 L
.17308 .65841 L
.16968 .67308 L
.16458 .69231 L
.15827 .71154 L
.15385 .7226 L
.15045 .73077 L
.14091 .75 L
.13462 .75729 L
.12478 .76923 L
.11538 .76945 L
.11497 .76923 L
.09725 .75 L
.09615 .74824 L
.08504 .73077 L
.07827 .71154 L
.07692 .70589 L
.0725 .69231 L
Mistroke
.06729 .67308 L
.06299 .65385 L
.05929 .63462 L
.05769 .62557 L
.05595 .61538 L
.05284 .59615 L
.04999 .57692 L
.04749 .55769 L
.04555 .53846 L
.04439 .51923 L
.04416 .5 L
.04483 .48077 L
.04624 .46154 L
.04816 .44231 L
.05038 .42308 L
.05278 .40385 L
.05538 .38462 L
.05769 .36896 L
.05824 .36538 L
.06148 .34615 L
.06532 .32692 L
.06997 .30769 L
.07573 .28846 L
.07692 .28499 L
.08123 .26923 L
.09053 .25 L
.09615 .24234 L
.10465 .23077 L
.11538 .22268 L
Mfstroke
.6 g
.11538 .27202 m
.13462 .28092 L
.14006 .28846 L
.14968 .30769 L
.15385 .31874 L
.15668 .32692 L
.16227 .34615 L
.16692 .36538 L
.17125 .38462 L
.17308 .39248 L
.17603 .40385 L
.18174 .42308 L
.18862 .44231 L
.19231 .45133 L
.19624 .46154 L
.20363 .48077 L
.20809 .5 L
.2061 .51923 L
.19938 .53846 L
.19231 .55605 L
.19156 .55769 L
.18377 .57692 L
.17699 .59615 L
.17308 .60866 L
.1712 .61538 L
.16599 .63462 L
.16049 .65385 L
.15395 .67308 L
.15385 .67333 L
.14588 .69231 L
.13462 .71013 L
.13329 .71154 L
.11538 .71881 L
.10375 .71154 L
.09615 .7018 L
.08952 .69231 L
.0814 .67308 L
.07696 .65385 L
.07692 .65366 L
.07195 .63462 L
.06771 .61538 L
.064 .59615 L
.06071 .57692 L
.0579 .55769 L
.05769 .55623 L
.05573 .53846 L
.05445 .51923 L
.05417 .5 L
.05488 .48077 L
.05642 .46154 L
.05769 .44945 L
.05855 .44231 L
.06105 .42308 L
.06384 .40385 L
.06696 .38462 L
.07056 .36538 L
.0749 .34615 L
.07692 .33843 L
.07918 .32692 L
.08512 .30769 L
.09615 .28923 L
.09665 .28846 L
F
0 g
.11538 .27202 m
.13462 .28092 L
.14006 .28846 L
.14968 .30769 L
.15385 .31874 L
.15668 .32692 L
.16227 .34615 L
.16692 .36538 L
.17125 .38462 L
.17308 .39248 L
.17603 .40385 L
.18174 .42308 L
.18862 .44231 L
.19231 .45133 L
.19624 .46154 L
.20363 .48077 L
.20809 .5 L
.2061 .51923 L
.19938 .53846 L
.19231 .55605 L
.19156 .55769 L
.18377 .57692 L
.17699 .59615 L
.17308 .60866 L
.1712 .61538 L
.16599 .63462 L
.16049 .65385 L
.15395 .67308 L
.15385 .67333 L
.14588 .69231 L
.13462 .71013 L
.13329 .71154 L
.11538 .71881 L
.10375 .71154 L
.09615 .7018 L
.08952 .69231 L
.0814 .67308 L
.07696 .65385 L
.07692 .65366 L
.07195 .63462 L
.06771 .61538 L
.064 .59615 L
.06071 .57692 L
.0579 .55769 L
.05769 .55623 L
.05573 .53846 L
.05445 .51923 L
.05417 .5 L
.05488 .48077 L
.05642 .46154 L
Mistroke
.05769 .44945 L
.05855 .44231 L
.06105 .42308 L
.06384 .40385 L
.06696 .38462 L
.07056 .36538 L
.0749 .34615 L
.07692 .33843 L
.07918 .32692 L
.08512 .30769 L
.09615 .28923 L
.09665 .28846 L
.11538 .27202 L
Mfstroke
.7 g
.11538 .31362 m
.13462 .32413 L
.13651 .32692 L
.14599 .34615 L
.15272 .36538 L
.15385 .36902 L
.15864 .38462 L
.16424 .40385 L
.16996 .42308 L
.17308 .43306 L
.17626 .44231 L
.18301 .46154 L
.18895 .48077 L
.19208 .5 L
.19075 .51923 L
.18564 .53846 L
.17875 .55769 L
.17308 .5728 L
.17162 .57692 L
.16496 .59615 L
.15821 .61538 L
.15385 .62724 L
.15112 .63462 L
.14296 .65385 L
.13462 .66788 L
.12977 .67308 L
.11538 .67792 L
.10716 .67308 L
.09615 .65801 L
.09346 .65385 L
.0847 .63462 L
.07963 .61538 L
.07692 .60092 L
.07576 .59615 L
.07155 .57692 L
.06812 .55769 L
.06559 .53846 L
.0641 .51923 L
.06377 .5 L
.06455 .48077 L
.06631 .46154 L
.06882 .44231 L
.07191 .42308 L
.0755 .40385 L
.07692 .39698 L
.07881 .38462 L
.08278 .36538 L
.08941 .34615 L
.09615 .33399 L
.10025 .32692 L
F
0 g
.11538 .31362 m
.13462 .32413 L
.13651 .32692 L
.14599 .34615 L
.15272 .36538 L
.15385 .36902 L
.15864 .38462 L
.16424 .40385 L
.16996 .42308 L
.17308 .43306 L
.17626 .44231 L
.18301 .46154 L
.18895 .48077 L
.19208 .5 L
.19075 .51923 L
.18564 .53846 L
.17875 .55769 L
.17308 .5728 L
.17162 .57692 L
.16496 .59615 L
.15821 .61538 L
.15385 .62724 L
.15112 .63462 L
.14296 .65385 L
.13462 .66788 L
.12977 .67308 L
.11538 .67792 L
.10716 .67308 L
.09615 .65801 L
.09346 .65385 L
.0847 .63462 L
.07963 .61538 L
.07692 .60092 L
.07576 .59615 L
.07155 .57692 L
.06812 .55769 L
.06559 .53846 L
.0641 .51923 L
.06377 .5 L
.06455 .48077 L
.06631 .46154 L
.06882 .44231 L
.07191 .42308 L
.0755 .40385 L
.07692 .39698 L
.07881 .38462 L
.08278 .36538 L
.08941 .34615 L
.09615 .33399 L
.10025 .32692 L
Mistroke
.11538 .31362 L
Mfstroke
.8 g
.11538 .35661 m
.13215 .36538 L
.13462 .36889 L
.14255 .38462 L
.15011 .40385 L
.15385 .41407 L
.15725 .42308 L
.16428 .44231 L
.17062 .46154 L
.17308 .46862 L
.17578 .48077 L
.17841 .5 L
.17731 .51923 L
.17308 .53758 L
.17283 .53846 L
.16658 .55769 L
.15896 .57692 L
.15385 .58861 L
.15057 .59615 L
.14137 .61538 L
.13462 .62643 L
.12639 .63462 L
.11538 .63695 L
.11099 .63462 L
.09694 .61538 L
.09615 .61374 L
.0879 .59615 L
.08232 .57692 L
.07869 .55769 L
.07692 .54539 L
.07598 .53846 L
.07411 .51923 L
.07368 .5 L
.07464 .48077 L
.07683 .46154 L
.07692 .46088 L
.07931 .44231 L
.08261 .42308 L
.08739 .40385 L
.09491 .38462 L
.09615 .38218 L
.10509 .36538 L
F
0 g
.11538 .35661 m
.13215 .36538 L
.13462 .36889 L
.14255 .38462 L
.15011 .40385 L
.15385 .41407 L
.15725 .42308 L
.16428 .44231 L
.17062 .46154 L
.17308 .46862 L
.17578 .48077 L
.17841 .5 L
.17731 .51923 L
.17308 .53758 L
.17283 .53846 L
.16658 .55769 L
.15896 .57692 L
.15385 .58861 L
.15057 .59615 L
.14137 .61538 L
.13462 .62643 L
.12639 .63462 L
.11538 .63695 L
.11099 .63462 L
.09694 .61538 L
.09615 .61374 L
.0879 .59615 L
.08232 .57692 L
.07869 .55769 L
.07692 .54539 L
.07598 .53846 L
.07411 .51923 L
.07368 .5 L
.07464 .48077 L
.07683 .46154 L
.07692 .46088 L
.07931 .44231 L
.08261 .42308 L
.08739 .40385 L
.09491 .38462 L
.09615 .38218 L
.10509 .36538 L
.11538 .35661 L
s
.9 g
.11538 .40173 m
.12642 .40385 L
.13462 .41267 L
.1407 .42308 L
.14972 .44231 L
.15385 .4523 L
.15738 .46154 L
.16308 .48077 L
.16566 .5 L
.16458 .51923 L
.15989 .53846 L
.15385 .55415 L
.15221 .55769 L
.1425 .57692 L
.13462 .58866 L
.12588 .59615 L
.11538 .59724 L
.11335 .59615 L
.09901 .57692 L
.09615 .57035 L
.09117 .55769 L
.08643 .53846 L
.08408 .51923 L
.08356 .5 L
.08468 .48077 L
.08751 .46154 L
.09248 .44231 L
.09615 .43241 L
.09976 .42308 L
.11214 .40385 L
F
0 g
.11538 .40173 m
.12642 .40385 L
.13462 .41267 L
.1407 .42308 L
.14972 .44231 L
.15385 .4523 L
.15738 .46154 L
.16308 .48077 L
.16566 .5 L
.16458 .51923 L
.15989 .53846 L
.15385 .55415 L
.15221 .55769 L
.1425 .57692 L
.13462 .58866 L
.12588 .59615 L
.11538 .59724 L
.11335 .59615 L
.09901 .57692 L
.09615 .57035 L
.09117 .55769 L
.08643 .53846 L
.08408 .51923 L
.08356 .5 L
.08468 .48077 L
.08751 .46154 L
.09248 .44231 L
.09615 .43241 L
.09976 .42308 L
.11214 .40385 L
.11538 .40173 L
s
1 g
.11538 .44618 m
.13462 .45355 L
.13936 .46154 L
.14692 .48077 L
.15006 .5 L
.14869 .51923 L
.1426 .53846 L
.13462 .55235 L
.12829 .55769 L
.11538 .55821 L
.1147 .55769 L
.10314 .53846 L
.09881 .51923 L
.09787 .5 L
.09987 .48077 L
.10529 .46154 L
F
0 g
.11538 .44618 m
.13462 .45355 L
.13936 .46154 L
.14692 .48077 L
.15006 .5 L
.14869 .51923 L
.1426 .53846 L
.13462 .55235 L
.12829 .55769 L
.11538 .55821 L
.1147 .55769 L
.10314 .53846 L
.09881 .51923 L
.09787 .5 L
.09987 .48077 L
.10529 .46154 L
.11538 .44618 L
s
.5 g
.11538 .82424 m
.13462 .82012 L
.15385 .82591 L
.15704 .82692 L
.17308 .83404 L
.19231 .83935 L
.21154 .84128 L
.23077 .84043 L
.25 .83791 L
.26923 .83467 L
.28846 .83134 L
.30769 .82827 L
.31694 .82692 L
.32692 .82556 L
.34615 .82326 L
.36538 .8214 L
.38462 .81996 L
.40385 .81892 L
.42308 .81828 L
.44231 .81802 L
.46154 .81815 L
.48077 .81867 L
.5 .8196 L
.51923 .82096 L
.53846 .82277 L
.55769 .8251 L
.57026 .82692 L
.57692 .82796 L
.59615 .83145 L
.61538 .83587 L
.63462 .84171 L
.64593 .84615 L
.65385 .84967 L
.67308 .86173 L
.67683 .86538 L
.68211 .88462 L
.67308 .89726 L
.66449 .90385 L
.65385 .91089 L
.63462 .9189 L
.61873 .92308 L
.61538 .92406 L
.59615 .92905 L
.57692 .93309 L
.55769 .9364 L
.53846 .93911 L
.51923 .94131 L
.50887 .94231 L
.5 .94304 L
.48077 .94434 L
.46154 .94524 L
.44231 .94576 L
.42308 .94589 L
.40385 .94565 L
.38462 .94501 L
.36538 .94397 L
.34615 .94251 L
.34388 .94231 L
.32692 .94058 L
.30769 .93818 L
.28846 .93526 L
.26923 .93184 L
.25 .92801 L
.23077 .92404 L
.2262 .92308 L
.21154 .92129 L
.19231 .91881 L
.17308 .91648 L
.15385 .9137 L
.13462 .90856 L
.12433 .90385 L
.11538 .89751 L
.10451 .88462 L
.09995 .86538 L
.10254 .84615 L
.11348 .82692 L
F
0 g
.11538 .82424 m
.13462 .82012 L
.15385 .82591 L
.15704 .82692 L
.17308 .83404 L
.19231 .83935 L
.21154 .84128 L
.23077 .84043 L
.25 .83791 L
.26923 .83467 L
.28846 .83134 L
.30769 .82827 L
.31694 .82692 L
.32692 .82556 L
.34615 .82326 L
.36538 .8214 L
.38462 .81996 L
.40385 .81892 L
.42308 .81828 L
.44231 .81802 L
.46154 .81815 L
.48077 .81867 L
.5 .8196 L
.51923 .82096 L
.53846 .82277 L
.55769 .8251 L
.57026 .82692 L
.57692 .82796 L
.59615 .83145 L
.61538 .83587 L
.63462 .84171 L
.64593 .84615 L
.65385 .84967 L
.67308 .86173 L
.67683 .86538 L
.68211 .88462 L
.67308 .89726 L
.66449 .90385 L
.65385 .91089 L
.63462 .9189 L
.61873 .92308 L
.61538 .92406 L
.59615 .92905 L
.57692 .93309 L
.55769 .9364 L
.53846 .93911 L
.51923 .94131 L
.50887 .94231 L
.5 .94304 L
.48077 .94434 L
Mistroke
.46154 .94524 L
.44231 .94576 L
.42308 .94589 L
.40385 .94565 L
.38462 .94501 L
.36538 .94397 L
.34615 .94251 L
.34388 .94231 L
.32692 .94058 L
.30769 .93818 L
.28846 .93526 L
.26923 .93184 L
.25 .92801 L
.23077 .92404 L
.2262 .92308 L
.21154 .92129 L
.19231 .91881 L
.17308 .91648 L
.15385 .9137 L
.13462 .90856 L
.12433 .90385 L
.11538 .89751 L
.10451 .88462 L
.09995 .86538 L
.10254 .84615 L
.11348 .82692 L
.11538 .82424 L
Mfstroke
.6 g
.28846 .84329 m
.30769 .83912 L
.32692 .8357 L
.34615 .83295 L
.36538 .83079 L
.38462 .82916 L
.40385 .82802 L
.42308 .82732 L
.44231 .82707 L
.46154 .82725 L
.48077 .82787 L
.5 .82896 L
.51923 .83055 L
.53846 .83271 L
.55769 .83557 L
.57692 .83934 L
.59615 .84439 L
.60165 .84615 L
.61538 .85109 L
.63462 .86107 L
.64011 .86538 L
.64682 .88462 L
.63462 .89873 L
.62656 .90385 L
.61538 .91026 L
.59615 .91741 L
.57692 .92181 L
.56966 .92308 L
.55769 .92559 L
.53846 .92895 L
.51923 .93159 L
.5 .93364 L
.48077 .93516 L
.46154 .9362 L
.44231 .93678 L
.42308 .93691 L
.40385 .93659 L
.38462 .93581 L
.36538 .93454 L
.34615 .93273 L
.32692 .93032 L
.30769 .9272 L
.28846 .92326 L
.28766 .92308 L
.26923 .92019 L
.25 .9152 L
.23077 .90724 L
.22417 .90385 L
.21154 .89884 L
.19231 .89063 L
.17911 .88462 L
.19231 .86913 L
.20709 .86538 L
.21154 .86428 L
.23077 .85538 L
.25 .84984 L
.26923 .84683 L
.27702 .84615 L
F
0 g
.28846 .84329 m
.30769 .83912 L
.32692 .8357 L
.34615 .83295 L
.36538 .83079 L
.38462 .82916 L
.40385 .82802 L
.42308 .82732 L
.44231 .82707 L
.46154 .82725 L
.48077 .82787 L
.5 .82896 L
.51923 .83055 L
.53846 .83271 L
.55769 .83557 L
.57692 .83934 L
.59615 .84439 L
.60165 .84615 L
.61538 .85109 L
.63462 .86107 L
.64011 .86538 L
.64682 .88462 L
.63462 .89873 L
.62656 .90385 L
.61538 .91026 L
.59615 .91741 L
.57692 .92181 L
.56966 .92308 L
.55769 .92559 L
.53846 .92895 L
.51923 .93159 L
.5 .93364 L
.48077 .93516 L
.46154 .9362 L
.44231 .93678 L
.42308 .93691 L
.40385 .93659 L
.38462 .93581 L
.36538 .93454 L
.34615 .93273 L
.32692 .93032 L
.30769 .9272 L
.28846 .92326 L
.28766 .92308 L
.26923 .92019 L
.25 .9152 L
.23077 .90724 L
.22417 .90385 L
.21154 .89884 L
.19231 .89063 L
Mistroke
.17911 .88462 L
.19231 .86913 L
.20709 .86538 L
.21154 .86428 L
.23077 .85538 L
.25 .84984 L
.26923 .84683 L
.27702 .84615 L
.28846 .84329 L
Mfstroke
.1 g
.43763 .98077 m
.44231 .98071 L
.46154 .98033 L
.48077 .9797 L
.5 .97883 L
.51923 .9777 L
.53846 .97629 L
.55769 .97459 L
.57692 .97258 L
.59615 .97022 L
.61538 .96749 L
.63462 .96438 L
.65023 .96154 L
.65385 .96084 L
.67308 .95685 L
.69231 .95239 L
.71154 .94739 L
.72893 .94231 L
.73077 .94172 L
.75 .93497 L
.76923 .92678 L
.77661 .92308 L
.78846 .91722 L
.80464 .90385 L
.80769 .90061 L
.81689 .88462 L
.81457 .86538 L
.80769 .85573 L
.79701 .84615 L
.78846 .84005 L
.76923 .83014 L
.76128 .82692 L
.75 .82258 L
.73077 .81621 L
.71154 .81079 L
.69915 .80769 L
.69231 .80619 L
.67308 .80231 L
.65385 .79886 L
.63462 .79579 L
.61538 .79308 L
.59615 .79072 L
.57692 .78869 L
.57453 .78846 L
.55769 .78723 L
.53846 .78604 L
.51923 .78509 L
.5 .78436 L
.48077 .78387 L
.46154 .78363 L
.44231 .78361 L
.42308 .78384 L
.40385 .7843 L
.38462 .78498 L
.36538 .78588 L
.34615 .78697 L
.32692 .78822 L
.32335 .78846 L
.30769 .78977 L
.28846 .79123 L
.26923 .79197 L
.25 .79086 L
.23898 .78846 L
.23077 .78611 L
.21385 .76923 L
.21154 .76276 L
.20924 .75 L
.20947 .73077 L
.21154 .71157 L
.21154 .71154 L
.21399 .69231 L
.21671 .67308 L
.21991 .65385 L
.22436 .63462 L
.23077 .61737 L
.23158 .61538 L
.24585 .59615 L
.25 .59344 L
.26923 .58597 L
.28846 .58482 L
.30769 .5861 L
.32692 .58813 L
.34615 .59018 L
.36538 .59196 L
.38462 .59338 L
.40385 .59442 L
.42308 .59508 L
.44231 .59536 L
.46154 .59529 L
.48077 .59485 L
.5 .59406 L
.51923 .59292 L
.53846 .59141 L
.55769 .58955 L
.57692 .58733 L
.59615 .58475 L
.61538 .58183 L
.63462 .57858 L
.64371 .57692 L
.65385 .57475 L
.67308 .57021 L
.69231 .5651 L
.71154 .55936 L
.7167 .55769 L
.73077 .55262 L
.75 .54462 L
.76256 .53846 L
.76923 .53503 L
.78846 .522 L
.79152 .51923 L
.80708 .5 L
.80769 .49864 L
.81034 .48077 L
.80769 .4722 L
.80089 .46154 L
.78846 .4489 L
.77652 .44231 L
.76923 .43829 L
.75 .4297 L
.73111 .42308 L
.73077 .42297 L
.71154 .41752 L
.69231 .41293 L
.67308 .40904 L
.65385 .40575 L
.64097 .40385 L
.63462 .40308 L
.61538 .40104 L
.59615 .39939 L
.57692 .39811 L
.55769 .3972 L
.53846 .39665 L
.51923 .39644 L
.5 .39658 L
.48077 .39705 L
.46154 .39785 L
.44231 .39897 L
.42308 .4004 L
.40385 .40213 L
.38716 .40385 L
.38462 .40418 L
.36538 .40687 L
.34615 .40993 L
.32692 .41322 L
.30769 .41645 L
.28846 .41887 L
.26923 .41883 L
.25 .41234 L
.23921 .40385 L
.23077 .38741 L
.22962 .38462 L
.2238 .36538 L
.2202 .34615 L
.21746 .32692 L
.21502 .30769 L
.21276 .28846 L
.21154 .28067 L
.21082 .26923 L
.20996 .25 L
.21154 .23301 L
.21197 .23077 L
.22068 .21154 L
.23077 .20361 L
.25 .19775 L
.26923 .19707 L
.28846 .19846 L
.30769 .20065 L
.32692 .20301 L
.34615 .20526 L
.36538 .20725 L
.38462 .20895 L
.40385 .21034 L
.42308 .21142 L
.42542 .21154 L
.44231 .21211 L
.46154 .21252 L
.48077 .21268 L
.5 .21257 L
.51923 .21219 L
.53846 .21154 L
.53852 .21154 L
.55769 .21049 L
.57692 .2091 L
.59615 .20738 L
.61538 .20531 L
.63462 .20286 L
.65385 .20003 L
.67308 .19677 L
.69231 .19306 L
.69588 .19231 L
.71154 .18861 L
.73077 .18341 L
.75 .17731 L
.76157 .17308 L
.76923 .17006 L
.78846 .16091 L
.79974 .15385 L
.80769 .15058 L
.82027 .13462 L
.82665 .11538 L
.81999 .09615 L
.80769 .0803 L
.79992 .07692 L
.78846 .06943 L
.76923 .05981 L
.76421 .05769 L
.75 .05204 L
.73077 .04543 L
.71154 .03973 L
.70689 .03846 L
.69231 .03474 L
.67308 .03038 L
.65385 .02657 L
.63462 .02324 L
.61538 .02037 L
.60693 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.43763 .98077 m
.44231 .98071 L
.46154 .98033 L
.48077 .9797 L
.5 .97883 L
.51923 .9777 L
.53846 .97629 L
.55769 .97459 L
.57692 .97258 L
.59615 .97022 L
.61538 .96749 L
.63462 .96438 L
.65023 .96154 L
.65385 .96084 L
.67308 .95685 L
.69231 .95239 L
.71154 .94739 L
.72893 .94231 L
.73077 .94172 L
.75 .93497 L
.76923 .92678 L
.77661 .92308 L
.78846 .91722 L
.80464 .90385 L
.80769 .90061 L
.81689 .88462 L
.81457 .86538 L
.80769 .85573 L
.79701 .84615 L
.78846 .84005 L
.76923 .83014 L
.76128 .82692 L
.75 .82258 L
.73077 .81621 L
.71154 .81079 L
.69915 .80769 L
.69231 .80619 L
.67308 .80231 L
.65385 .79886 L
.63462 .79579 L
.61538 .79308 L
.59615 .79072 L
.57692 .78869 L
.57453 .78846 L
.55769 .78723 L
.53846 .78604 L
.51923 .78509 L
.5 .78436 L
.48077 .78387 L
.46154 .78363 L
Mistroke
.44231 .78361 L
.42308 .78384 L
.40385 .7843 L
.38462 .78498 L
.36538 .78588 L
.34615 .78697 L
.32692 .78822 L
.32335 .78846 L
.30769 .78977 L
.28846 .79123 L
.26923 .79197 L
.25 .79086 L
.23898 .78846 L
.23077 .78611 L
.21385 .76923 L
.21154 .76276 L
.20924 .75 L
.20947 .73077 L
.21154 .71157 L
.21154 .71154 L
.21399 .69231 L
.21671 .67308 L
.21991 .65385 L
.22436 .63462 L
.23077 .61737 L
.23158 .61538 L
.24585 .59615 L
.25 .59344 L
.26923 .58597 L
.28846 .58482 L
.30769 .5861 L
.32692 .58813 L
.34615 .59018 L
.36538 .59196 L
.38462 .59338 L
.40385 .59442 L
.42308 .59508 L
.44231 .59536 L
.46154 .59529 L
.48077 .59485 L
.5 .59406 L
.51923 .59292 L
.53846 .59141 L
.55769 .58955 L
.57692 .58733 L
.59615 .58475 L
.61538 .58183 L
.63462 .57858 L
.64371 .57692 L
.65385 .57475 L
Mistroke
.67308 .57021 L
.69231 .5651 L
.71154 .55936 L
.7167 .55769 L
.73077 .55262 L
.75 .54462 L
.76256 .53846 L
.76923 .53503 L
.78846 .522 L
.79152 .51923 L
.80708 .5 L
.80769 .49864 L
.81034 .48077 L
.80769 .4722 L
.80089 .46154 L
.78846 .4489 L
.77652 .44231 L
.76923 .43829 L
.75 .4297 L
.73111 .42308 L
.73077 .42297 L
.71154 .41752 L
.69231 .41293 L
.67308 .40904 L
.65385 .40575 L
.64097 .40385 L
.63462 .40308 L
.61538 .40104 L
.59615 .39939 L
.57692 .39811 L
.55769 .3972 L
.53846 .39665 L
.51923 .39644 L
.5 .39658 L
.48077 .39705 L
.46154 .39785 L
.44231 .39897 L
.42308 .4004 L
.40385 .40213 L
.38716 .40385 L
.38462 .40418 L
.36538 .40687 L
.34615 .40993 L
.32692 .41322 L
.30769 .41645 L
.28846 .41887 L
.26923 .41883 L
.25 .41234 L
.23921 .40385 L
.23077 .38741 L
Mistroke
.22962 .38462 L
.2238 .36538 L
.2202 .34615 L
.21746 .32692 L
.21502 .30769 L
.21276 .28846 L
.21154 .28067 L
.21082 .26923 L
.20996 .25 L
.21154 .23301 L
.21197 .23077 L
.22068 .21154 L
.23077 .20361 L
.25 .19775 L
.26923 .19707 L
.28846 .19846 L
.30769 .20065 L
.32692 .20301 L
.34615 .20526 L
.36538 .20725 L
.38462 .20895 L
.40385 .21034 L
.42308 .21142 L
.42542 .21154 L
.44231 .21211 L
.46154 .21252 L
.48077 .21268 L
.5 .21257 L
.51923 .21219 L
.53846 .21154 L
.53852 .21154 L
.55769 .21049 L
.57692 .2091 L
.59615 .20738 L
.61538 .20531 L
.63462 .20286 L
.65385 .20003 L
.67308 .19677 L
.69231 .19306 L
.69588 .19231 L
.71154 .18861 L
.73077 .18341 L
.75 .17731 L
.76157 .17308 L
.76923 .17006 L
.78846 .16091 L
.79974 .15385 L
.80769 .15058 L
.82027 .13462 L
.82665 .11538 L
Mistroke
.81999 .09615 L
.80769 .0803 L
.79992 .07692 L
.78846 .06943 L
.76923 .05981 L
.76421 .05769 L
.75 .05204 L
.73077 .04543 L
.71154 .03973 L
.70689 .03846 L
.69231 .03474 L
.67308 .03038 L
.65385 .02657 L
.63462 .02324 L
.61538 .02037 L
.60693 .01923 L
Mfstroke
.69004 .98077 m
.69231 .98039 L
.71154 .97692 L
.73077 .97293 L
.75 .9684 L
.76923 .96327 L
.77525 .96154 L
.78846 .95753 L
.80769 .95115 L
.82692 .94402 L
.83119 .94231 L
.84615 .93558 L
.86538 .92511 L
.86858 .92308 L
.88462 .91181 L
.8916 .90385 L
.90214 .88462 L
.90078 .86538 L
.88719 .84615 L
.88462 .84357 L
.86538 .82982 L
.85993 .82692 L
.84615 .81999 L
.82692 .81187 L
.81564 .80769 L
.80769 .8051 L
.78846 .79931 L
.76923 .79406 L
.75 .78932 L
.7463 .78846 L
.73077 .78555 L
.71154 .78211 L
.69231 .77887 L
.67308 .77586 L
.65385 .77311 L
.63462 .77064 L
.62245 .76923 L
.61538 .76871 L
.59615 .76736 L
.57692 .76611 L
.55769 .765 L
.53846 .76405 L
.51923 .76328 L
.5 .7627 L
.48077 .76232 L
.46154 .76215 L
.44231 .76218 L
.42308 .76241 L
.40385 .76284 L
.38462 .76347 L
.36538 .76426 L
.34615 .76517 L
.32692 .76612 L
.30769 .76688 L
.28846 .76701 L
.26923 .76533 L
.25 .75509 L
.24647 .75 L
.24008 .73077 L
.23983 .71154 L
.24148 .69231 L
.24424 .67308 L
.2487 .65385 L
.25 .6497 L
.2557 .63462 L
.26923 .6215 L
.28846 .61541 L
.28865 .61538 L
.30769 .61416 L
.32692 .6149 L
.33592 .61538 L
.34615 .61596 L
.36538 .61688 L
.38462 .61765 L
.40385 .6182 L
.42308 .61852 L
.44231 .6186 L
.46154 .61843 L
.48077 .61803 L
.5 .61741 L
.51923 .6166 L
.53846 .61563 L
.54307 .61538 L
.55769 .61406 L
.57692 .61204 L
.59615 .60971 L
.61538 .60709 L
.63462 .60422 L
.65385 .60115 L
.67308 .59797 L
.68389 .59615 L
.69231 .5943 L
.71154 .58975 L
.73077 .58484 L
.75 .57965 L
.7597 .57692 L
.76923 .57377 L
.78846 .56688 L
.80769 .55926 L
.81138 .55769 L
.82692 .55025 L
.84615 .53938 L
.84759 .53846 L
.86538 .52553 L
.8718 .51923 L
.88462 .50352 L
.88561 .5 L
.88951 .48077 L
.88462 .46381 L
.88336 .46154 L
.86607 .44231 L
.86538 .44174 L
.84615 .42877 L
.83519 .42308 L
.82692 .41925 L
.80769 .41149 L
.78846 .40488 L
.78518 .40385 L
.76923 .39953 L
.75 .39483 L
.73077 .39061 L
.71154 .38687 L
.6986 .38462 L
.69231 .3838 L
.67308 .38146 L
.65385 .37936 L
.63462 .37753 L
.61538 .37598 L
.59615 .37472 L
.57692 .37377 L
.55769 .37311 L
.53846 .37276 L
.51923 .37272 L
.5 .37297 L
.48077 .37351 L
.46154 .37434 L
.44231 .37545 L
.42308 .37682 L
.40385 .37843 L
.38462 .38024 L
.36538 .38217 L
.34615 .38412 L
.34148 .38462 L
.32692 .38651 L
.30769 .38854 L
.28846 .38847 L
.27365 .38462 L
.26923 .38267 L
.25347 .36538 L
.25 .35287 L
.24825 .34615 L
.24464 .32692 L
.24233 .30769 L
.2409 .28846 L
.24101 .26923 L
.24537 .25 L
.25 .24124 L
.26923 .23084 L
.2696 .23077 L
.28846 .22841 L
.30769 .22893 L
.32692 .23044 L
.33076 .23077 L
.34615 .23183 L
.36538 .23314 L
.38462 .23433 L
.40385 .23535 L
.42308 .23619 L
.44231 .23681 L
.46154 .23722 L
.48077 .2374 L
.5 .23736 L
.51923 .23709 L
.53846 .2366 L
.55769 .23588 L
.57692 .23494 L
.59615 .23381 L
.61538 .23248 L
.63462 .23097 L
.63701 .23077 L
.65385 .22881 L
.67308 .22629 L
.69231 .22346 L
.71154 .22032 L
.73077 .2169 L
.75 .21319 L
.7581 .21154 L
.76923 .20885 L
.78846 .20377 L
.80769 .19813 L
.82545 .19231 L
.82692 .19177 L
.84615 .18415 L
.86538 .17506 L
.86908 .17308 L
.88462 .16378 L
.8969 .15385 L
.90385 .15051 L
.91226 .13462 L
.9167 .11538 L
.91075 .09615 L
.90385 .08409 L
.89424 .07692 L
.88462 .06913 L
.86612 .05769 L
.86538 .05729 L
.84615 .04771 L
.82692 .03959 L
.82402 .03846 L
.80769 .03252 L
.78846 .02632 L
.76923 .02089 L
.76279 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.69004 .98077 m
.69231 .98039 L
.71154 .97692 L
.73077 .97293 L
.75 .9684 L
.76923 .96327 L
.77525 .96154 L
.78846 .95753 L
.80769 .95115 L
.82692 .94402 L
.83119 .94231 L
.84615 .93558 L
.86538 .92511 L
.86858 .92308 L
.88462 .91181 L
.8916 .90385 L
.90214 .88462 L
.90078 .86538 L
.88719 .84615 L
.88462 .84357 L
.86538 .82982 L
.85993 .82692 L
.84615 .81999 L
.82692 .81187 L
.81564 .80769 L
.80769 .8051 L
.78846 .79931 L
.76923 .79406 L
.75 .78932 L
.7463 .78846 L
.73077 .78555 L
.71154 .78211 L
.69231 .77887 L
.67308 .77586 L
.65385 .77311 L
.63462 .77064 L
.62245 .76923 L
.61538 .76871 L
.59615 .76736 L
.57692 .76611 L
.55769 .765 L
.53846 .76405 L
.51923 .76328 L
.5 .7627 L
.48077 .76232 L
.46154 .76215 L
.44231 .76218 L
.42308 .76241 L
.40385 .76284 L
.38462 .76347 L
Mistroke
.36538 .76426 L
.34615 .76517 L
.32692 .76612 L
.30769 .76688 L
.28846 .76701 L
.26923 .76533 L
.25 .75509 L
.24647 .75 L
.24008 .73077 L
.23983 .71154 L
.24148 .69231 L
.24424 .67308 L
.2487 .65385 L
.25 .6497 L
.2557 .63462 L
.26923 .6215 L
.28846 .61541 L
.28865 .61538 L
.30769 .61416 L
.32692 .6149 L
.33592 .61538 L
.34615 .61596 L
.36538 .61688 L
.38462 .61765 L
.40385 .6182 L
.42308 .61852 L
.44231 .6186 L
.46154 .61843 L
.48077 .61803 L
.5 .61741 L
.51923 .6166 L
.53846 .61563 L
.54307 .61538 L
.55769 .61406 L
.57692 .61204 L
.59615 .60971 L
.61538 .60709 L
.63462 .60422 L
.65385 .60115 L
.67308 .59797 L
.68389 .59615 L
.69231 .5943 L
.71154 .58975 L
.73077 .58484 L
.75 .57965 L
.7597 .57692 L
.76923 .57377 L
.78846 .56688 L
.80769 .55926 L
.81138 .55769 L
Mistroke
.82692 .55025 L
.84615 .53938 L
.84759 .53846 L
.86538 .52553 L
.8718 .51923 L
.88462 .50352 L
.88561 .5 L
.88951 .48077 L
.88462 .46381 L
.88336 .46154 L
.86607 .44231 L
.86538 .44174 L
.84615 .42877 L
.83519 .42308 L
.82692 .41925 L
.80769 .41149 L
.78846 .40488 L
.78518 .40385 L
.76923 .39953 L
.75 .39483 L
.73077 .39061 L
.71154 .38687 L
.6986 .38462 L
.69231 .3838 L
.67308 .38146 L
.65385 .37936 L
.63462 .37753 L
.61538 .37598 L
.59615 .37472 L
.57692 .37377 L
.55769 .37311 L
.53846 .37276 L
.51923 .37272 L
.5 .37297 L
.48077 .37351 L
.46154 .37434 L
.44231 .37545 L
.42308 .37682 L
.40385 .37843 L
.38462 .38024 L
.36538 .38217 L
.34615 .38412 L
.34148 .38462 L
.32692 .38651 L
.30769 .38854 L
.28846 .38847 L
.27365 .38462 L
.26923 .38267 L
.25347 .36538 L
.25 .35287 L
Mistroke
.24825 .34615 L
.24464 .32692 L
.24233 .30769 L
.2409 .28846 L
.24101 .26923 L
.24537 .25 L
.25 .24124 L
.26923 .23084 L
.2696 .23077 L
.28846 .22841 L
.30769 .22893 L
.32692 .23044 L
.33076 .23077 L
.34615 .23183 L
.36538 .23314 L
.38462 .23433 L
.40385 .23535 L
.42308 .23619 L
.44231 .23681 L
.46154 .23722 L
.48077 .2374 L
.5 .23736 L
.51923 .23709 L
.53846 .2366 L
.55769 .23588 L
.57692 .23494 L
.59615 .23381 L
.61538 .23248 L
.63462 .23097 L
.63701 .23077 L
.65385 .22881 L
.67308 .22629 L
.69231 .22346 L
.71154 .22032 L
.73077 .2169 L
.75 .21319 L
.7581 .21154 L
.76923 .20885 L
.78846 .20377 L
.80769 .19813 L
.82545 .19231 L
.82692 .19177 L
.84615 .18415 L
.86538 .17506 L
.86908 .17308 L
.88462 .16378 L
.8969 .15385 L
.90385 .15051 L
.91226 .13462 L
.9167 .11538 L
Mistroke
.91075 .09615 L
.90385 .08409 L
.89424 .07692 L
.88462 .06913 L
.86612 .05769 L
.86538 .05729 L
.84615 .04771 L
.82692 .03959 L
.82402 .03846 L
.80769 .03252 L
.78846 .02632 L
.76923 .02089 L
.76279 .01923 L
Mfstroke
.5 g
.36538 .05731 m
.38462 .05497 L
.40385 .05327 L
.42308 .05214 L
.44231 .05153 L
.46154 .05143 L
.48077 .05182 L
.5 .05271 L
.51923 .05412 L
.53846 .05607 L
.55128 .05769 L
.55769 .05857 L
.57692 .06165 L
.59615 .06559 L
.61538 .07069 L
.6332 .07692 L
.63462 .07747 L
.65385 .08192 L
.66759 .09615 L
.67308 .10264 L
.6768 .11538 L
.67308 .1247 L
.66321 .13462 L
.65385 .1422 L
.63462 .15046 L
.6192 .15385 L
.61538 .15494 L
.59615 .15961 L
.57692 .16317 L
.55769 .16588 L
.53846 .16789 L
.51923 .16932 L
.5 .1702 L
.48077 .17058 L
.46154 .17048 L
.44231 .16988 L
.42308 .16879 L
.40385 .16717 L
.38462 .16499 L
.36538 .16217 L
.34615 .15861 L
.32692 .15416 L
.32573 .15385 L
.30769 .14958 L
.28846 .14304 L
.27169 .13462 L
.26923 .13335 L
.25 .11967 L
.24722 .11538 L
.25 .09871 L
.25235 .09615 L
.26923 .08449 L
.28542 .07692 L
.28846 .07561 L
.30769 .0688 L
.32692 .06386 L
.34615 .06016 L
.36265 .05769 L
F
0 g
.36538 .05731 m
.38462 .05497 L
.40385 .05327 L
.42308 .05214 L
.44231 .05153 L
.46154 .05143 L
.48077 .05182 L
.5 .05271 L
.51923 .05412 L
.53846 .05607 L
.55128 .05769 L
.55769 .05857 L
.57692 .06165 L
.59615 .06559 L
.61538 .07069 L
.6332 .07692 L
.63462 .07747 L
.65385 .08192 L
.66759 .09615 L
.67308 .10264 L
.6768 .11538 L
.67308 .1247 L
.66321 .13462 L
.65385 .1422 L
.63462 .15046 L
.6192 .15385 L
.61538 .15494 L
.59615 .15961 L
.57692 .16317 L
.55769 .16588 L
.53846 .16789 L
.51923 .16932 L
.5 .1702 L
.48077 .17058 L
.46154 .17048 L
.44231 .16988 L
.42308 .16879 L
.40385 .16717 L
.38462 .16499 L
.36538 .16217 L
.34615 .15861 L
.32692 .15416 L
.32573 .15385 L
.30769 .14958 L
.28846 .14304 L
.27169 .13462 L
.26923 .13335 L
.25 .11967 L
.24722 .11538 L
.25 .09871 L
Mistroke
.25235 .09615 L
.26923 .08449 L
.28542 .07692 L
.28846 .07561 L
.30769 .0688 L
.32692 .06386 L
.34615 .06016 L
.36265 .05769 L
.36538 .05731 L
Mfstroke
.7 g
.34615 .8432 m
.36538 .84042 L
.38462 .83838 L
.40385 .83697 L
.42308 .83614 L
.44231 .83586 L
.46154 .83612 L
.48077 .83693 L
.5 .83836 L
.51923 .84048 L
.53846 .84348 L
.5516 .84615 L
.55769 .84754 L
.57692 .85297 L
.59615 .86105 L
.60312 .86538 L
.61186 .88462 L
.59615 .89955 L
.58775 .90385 L
.57692 .90907 L
.55769 .91537 L
.53846 .91931 L
.51923 .92191 L
.5076 .92308 L
.5 .92399 L
.48077 .92584 L
.46154 .92708 L
.44231 .92775 L
.42308 .92787 L
.40385 .92743 L
.38462 .92642 L
.36538 .92477 L
.35101 .92308 L
.34615 .92266 L
.32692 .9206 L
.30769 .91726 L
.28846 .91122 L
.27456 .90385 L
.26923 .9011 L
.25293 .88462 L
.26923 .8656 L
.26962 .86538 L
.28846 .85374 L
.30769 .84835 L
.32692 .84633 L
.33028 .84615 L
F
0 g
.34615 .8432 m
.36538 .84042 L
.38462 .83838 L
.40385 .83697 L
.42308 .83614 L
.44231 .83586 L
.46154 .83612 L
.48077 .83693 L
.5 .83836 L
.51923 .84048 L
.53846 .84348 L
.5516 .84615 L
.55769 .84754 L
.57692 .85297 L
.59615 .86105 L
.60312 .86538 L
.61186 .88462 L
.59615 .89955 L
.58775 .90385 L
.57692 .90907 L
.55769 .91537 L
.53846 .91931 L
.51923 .92191 L
.5076 .92308 L
.5 .92399 L
.48077 .92584 L
.46154 .92708 L
.44231 .92775 L
.42308 .92787 L
.40385 .92743 L
.38462 .92642 L
.36538 .92477 L
.35101 .92308 L
.34615 .92266 L
.32692 .9206 L
.30769 .91726 L
.28846 .91122 L
.27456 .90385 L
.26923 .9011 L
.25293 .88462 L
.26923 .8656 L
.26962 .86538 L
.28846 .85374 L
.30769 .84835 L
.32692 .84633 L
.33028 .84615 L
.34615 .8432 L
s
.5 g
.42308 .44007 m
.44231 .43798 L
.46154 .43647 L
.48077 .43553 L
.5 .43514 L
.51923 .43533 L
.53846 .4361 L
.55769 .43751 L
.57692 .43963 L
.59456 .44231 L
.59615 .44256 L
.61538 .44618 L
.63462 .45127 L
.65385 .45919 L
.65803 .46154 L
.67308 .47206 L
.67982 .48077 L
.67881 .5 L
.67308 .50723 L
.65711 .51923 L
.65385 .52128 L
.63462 .53053 L
.61538 .53666 L
.60823 .53846 L
.59615 .54162 L
.57692 .54582 L
.55769 .54917 L
.53846 .55181 L
.51923 .5538 L
.5 .55521 L
.48077 .55604 L
.46154 .55633 L
.44231 .55605 L
.42308 .55519 L
.40385 .5537 L
.38462 .5515 L
.36538 .54846 L
.34615 .54435 L
.32692 .53878 L
.32599 .53846 L
.30769 .53515 L
.28846 .52363 L
.28439 .51923 L
.27087 .5 L
.28846 .48192 L
.29026 .48077 L
.30769 .46856 L
.32692 .46207 L
.32962 .46154 L
.34615 .45576 L
.36538 .45039 L
.38462 .44615 L
.40385 .44279 L
.40702 .44231 L
F
0 g
.42308 .44007 m
.44231 .43798 L
.46154 .43647 L
.48077 .43553 L
.5 .43514 L
.51923 .43533 L
.53846 .4361 L
.55769 .43751 L
.57692 .43963 L
.59456 .44231 L
.59615 .44256 L
.61538 .44618 L
.63462 .45127 L
.65385 .45919 L
.65803 .46154 L
.67308 .47206 L
.67982 .48077 L
.67881 .5 L
.67308 .50723 L
.65711 .51923 L
.65385 .52128 L
.63462 .53053 L
.61538 .53666 L
.60823 .53846 L
.59615 .54162 L
.57692 .54582 L
.55769 .54917 L
.53846 .55181 L
.51923 .5538 L
.5 .55521 L
.48077 .55604 L
.46154 .55633 L
.44231 .55605 L
.42308 .55519 L
.40385 .5537 L
.38462 .5515 L
.36538 .54846 L
.34615 .54435 L
.32692 .53878 L
.32599 .53846 L
.30769 .53515 L
.28846 .52363 L
.28439 .51923 L
.27087 .5 L
.28846 .48192 L
.29026 .48077 L
.30769 .46856 L
.32692 .46207 L
.32962 .46154 L
.34615 .45576 L
Mistroke
.36538 .45039 L
.38462 .44615 L
.40385 .44279 L
.40702 .44231 L
.42308 .44007 L
Mfstroke
.8 g
.42308 .84596 m
.44231 .84565 L
.46154 .84605 L
.46489 .84615 L
.48077 .84718 L
.5 .84912 L
.51923 .85206 L
.53846 .85635 L
.55769 .86294 L
.56275 .86538 L
.5749 .88462 L
.55769 .8984 L
.54399 .90385 L
.53846 .90598 L
.51923 .91157 L
.5 .91513 L
.48077 .91738 L
.46154 .91875 L
.44231 .91944 L
.42308 .91956 L
.40385 .91912 L
.38462 .91805 L
.36538 .91609 L
.34615 .91271 L
.32692 .90681 L
.32028 .90385 L
.30769 .89821 L
.29452 .88462 L
.30769 .86818 L
.31303 .86538 L
.32692 .85712 L
.34615 .85082 L
.36538 .84791 L
.38462 .84668 L
.40385 .84624 L
.41829 .84615 L
F
0 g
.42308 .84596 m
.44231 .84565 L
.46154 .84605 L
.46489 .84615 L
.48077 .84718 L
.5 .84912 L
.51923 .85206 L
.53846 .85635 L
.55769 .86294 L
.56275 .86538 L
.5749 .88462 L
.55769 .8984 L
.54399 .90385 L
.53846 .90598 L
.51923 .91157 L
.5 .91513 L
.48077 .91738 L
.46154 .91875 L
.44231 .91944 L
.42308 .91956 L
.40385 .91912 L
.38462 .91805 L
.36538 .91609 L
.34615 .91271 L
.32692 .90681 L
.32028 .90385 L
.30769 .89821 L
.29452 .88462 L
.30769 .86818 L
.31303 .86538 L
.32692 .85712 L
.34615 .85082 L
.36538 .84791 L
.38462 .84668 L
.40385 .84624 L
.41829 .84615 L
.42308 .84596 L
s
.6 g
.34615 .07605 m
.36538 .07132 L
.38462 .06802 L
.40385 .06574 L
.42308 .06426 L
.44231 .06346 L
.46154 .06329 L
.48077 .06371 L
.5 .06475 L
.51923 .06645 L
.53846 .06892 L
.55769 .07232 L
.57686 .07692 L
.57692 .07694 L
.59615 .08289 L
.61538 .09147 L
.62271 .09615 L
.63355 .11538 L
.61538 .13444 L
.61506 .13462 L
.59615 .14435 L
.57692 .14948 L
.55769 .15244 L
.54445 .15385 L
.53846 .15463 L
.51923 .15664 L
.5 .15788 L
.48077 .15844 L
.46154 .15837 L
.44231 .15766 L
.42308 .15629 L
.40385 .15422 L
.40091 .15385 L
.38462 .15194 L
.36538 .14874 L
.34615 .1439 L
.32692 .13631 L
.32365 .13462 L
.30769 .12549 L
.29824 .11538 L
.30309 .09615 L
.30769 .09243 L
.32692 .08244 L
.34326 .07692 L
F
0 g
.34615 .07605 m
.36538 .07132 L
.38462 .06802 L
.40385 .06574 L
.42308 .06426 L
.44231 .06346 L
.46154 .06329 L
.48077 .06371 L
.5 .06475 L
.51923 .06645 L
.53846 .06892 L
.55769 .07232 L
.57686 .07692 L
.57692 .07694 L
.59615 .08289 L
.61538 .09147 L
.62271 .09615 L
.63355 .11538 L
.61538 .13444 L
.61506 .13462 L
.59615 .14435 L
.57692 .14948 L
.55769 .15244 L
.54445 .15385 L
.53846 .15463 L
.51923 .15664 L
.5 .15788 L
.48077 .15844 L
.46154 .15837 L
.44231 .15766 L
.42308 .15629 L
.40385 .15422 L
.40091 .15385 L
.38462 .15194 L
.36538 .14874 L
.34615 .1439 L
.32692 .13631 L
.32365 .13462 L
.30769 .12549 L
.29824 .11538 L
.30309 .09615 L
.30769 .09243 L
.32692 .08244 L
.34326 .07692 L
.34615 .07605 L
s
.6 g
.38462 .45902 m
.40385 .45456 L
.42308 .45121 L
.44231 .44877 L
.46154 .44708 L
.48077 .44609 L
.5 .44577 L
.51923 .4461 L
.53846 .44713 L
.55769 .44896 L
.57692 .4518 L
.59615 .45608 L
.61254 .46154 L
.61538 .46263 L
.63462 .47274 L
.6429 .48077 L
.64317 .5 L
.63462 .50898 L
.61778 .51923 L
.61538 .5205 L
.59615 .52852 L
.57692 .53382 L
.55769 .53745 L
.55095 .53846 L
.53846 .54043 L
.51923 .5428 L
.5 .54442 L
.48077 .54533 L
.46154 .54556 L
.44231 .54508 L
.42308 .54384 L
.40385 .54172 L
.38462 .53853 L
.38426 .53846 L
.36538 .53595 L
.34615 .53056 L
.33006 .51923 L
.32692 .51684 L
.31746 .5 L
.32692 .48452 L
.33162 .48077 L
.34615 .46961 L
.36538 .46296 L
.37573 .46154 L
F
0 g
.38462 .45902 m
.40385 .45456 L
.42308 .45121 L
.44231 .44877 L
.46154 .44708 L
.48077 .44609 L
.5 .44577 L
.51923 .4461 L
.53846 .44713 L
.55769 .44896 L
.57692 .4518 L
.59615 .45608 L
.61254 .46154 L
.61538 .46263 L
.63462 .47274 L
.6429 .48077 L
.64317 .5 L
.63462 .50898 L
.61778 .51923 L
.61538 .5205 L
.59615 .52852 L
.57692 .53382 L
.55769 .53745 L
.55095 .53846 L
.53846 .54043 L
.51923 .5428 L
.5 .54442 L
.48077 .54533 L
.46154 .54556 L
.44231 .54508 L
.42308 .54384 L
.40385 .54172 L
.38462 .53853 L
.38426 .53846 L
.36538 .53595 L
.34615 .53056 L
.33006 .51923 L
.32692 .51684 L
.31746 .5 L
.32692 .48452 L
.33162 .48077 L
.34615 .46961 L
.36538 .46296 L
.37573 .46154 L
.38462 .45902 L
s
.9 g
.38462 .85843 m
.40385 .85453 L
.42308 .85734 L
.44231 .85699 L
.46154 .85765 L
.48077 .85943 L
.5 .86266 L
.51076 .86538 L
.51923 .86864 L
.53139 .88462 L
.51923 .89347 L
.5 .89988 L
.48077 .90362 L
.47957 .90385 L
.46154 .90637 L
.44231 .90773 L
.42308 .90781 L
.40385 .90658 L
.38512 .90385 L
.38462 .90375 L
.36538 .89979 L
.34615 .89216 L
.33892 .88462 L
.34615 .87359 L
.36538 .86545 L
.36559 .86538 L
F
0 g
.38462 .85843 m
.40385 .85453 L
.42308 .85734 L
.44231 .85699 L
.46154 .85765 L
.48077 .85943 L
.5 .86266 L
.51076 .86538 L
.51923 .86864 L
.53139 .88462 L
.51923 .89347 L
.5 .89988 L
.48077 .90362 L
.47957 .90385 L
.46154 .90637 L
.44231 .90773 L
.42308 .90781 L
.40385 .90658 L
.38512 .90385 L
.38462 .90375 L
.36538 .89979 L
.34615 .89216 L
.33892 .88462 L
.34615 .87359 L
.36538 .86545 L
.36559 .86538 L
.38462 .85843 L
s
.7 g
.36538 .09093 m
.38462 .08488 L
.40385 .08109 L
.42308 .0787 L
.44231 .07739 L
.46154 .07701 L
.48077 .07751 L
.5 .07891 L
.51923 .08131 L
.53846 .08494 L
.55769 .09034 L
.57156 .09615 L
.57692 .09951 L
.58575 .11538 L
.57692 .12527 L
.55769 .13408 L
.55605 .13462 L
.53846 .1401 L
.51923 .14362 L
.5 .14554 L
.48077 .14637 L
.46154 .14631 L
.44231 .14539 L
.42308 .14347 L
.40385 .14025 L
.38462 .13515 L
.38299 .13462 L
.36538 .12841 L
.34695 .11538 L
.35488 .09615 L
F
0 g
.36538 .09093 m
.38462 .08488 L
.40385 .08109 L
.42308 .0787 L
.44231 .07739 L
.46154 .07701 L
.48077 .07751 L
.5 .07891 L
.51923 .08131 L
.53846 .08494 L
.55769 .09034 L
.57156 .09615 L
.57692 .09951 L
.58575 .11538 L
.57692 .12527 L
.55769 .13408 L
.55605 .13462 L
.53846 .1401 L
.51923 .14362 L
.5 .14554 L
.48077 .14637 L
.46154 .14631 L
.44231 .14539 L
.42308 .14347 L
.40385 .14025 L
.38462 .13515 L
.38299 .13462 L
.36538 .12841 L
.34695 .11538 L
.35488 .09615 L
.36538 .09093 L
s
.7 g
.44231 .46079 m
.46154 .45861 L
.48077 .45741 L
.5 .45714 L
.51923 .45783 L
.53846 .45963 L
.55138 .46154 L
.55769 .46273 L
.57692 .46751 L
.59615 .47567 L
.60316 .48077 L
.60566 .5 L
.59615 .50846 L
.57692 .51794 L
.57342 .51923 L
.55769 .52464 L
.53846 .52919 L
.51923 .53215 L
.5 .53397 L
.48077 .53491 L
.46154 .53509 L
.44231 .53454 L
.42308 .53309 L
.40385 .53021 L
.38462 .52435 L
.37499 .51923 L
.36538 .51369 L
.35597 .5 L
.36538 .48517 L
.37182 .48077 L
.38462 .47161 L
.40385 .46442 L
.42308 .46396 L
.43709 .46154 L
F
0 g
.44231 .46079 m
.46154 .45861 L
.48077 .45741 L
.5 .45714 L
.51923 .45783 L
.53846 .45963 L
.55138 .46154 L
.55769 .46273 L
.57692 .46751 L
.59615 .47567 L
.60316 .48077 L
.60566 .5 L
.59615 .50846 L
.57692 .51794 L
.57342 .51923 L
.55769 .52464 L
.53846 .52919 L
.51923 .53215 L
.5 .53397 L
.48077 .53491 L
.46154 .53509 L
.44231 .53454 L
.42308 .53309 L
.40385 .53021 L
.38462 .52435 L
.37499 .51923 L
.36538 .51369 L
.35597 .5 L
.36538 .48517 L
.37182 .48077 L
.38462 .47161 L
.40385 .46442 L
.42308 .46396 L
.43709 .46154 L
.44231 .46079 L
s
.8 g
.44231 .47579 m
.46154 .47281 L
.48077 .47139 L
.5 .47136 L
.51923 .47285 L
.53846 .47637 L
.55167 .48077 L
.55769 .48454 L
.56021 .5 L
.55769 .50218 L
.53846 .51143 L
.51923 .51626 L
.5 .51902 L
.49778 .51923 L
.48077 .52047 L
.46154 .52023 L
.45068 .51923 L
.44231 .51822 L
.42308 .51414 L
.40385 .50394 L
.40153 .5 L
.40385 .49266 L
.42308 .48094 L
.42352 .48077 L
F
0 g
.44231 .47579 m
.46154 .47281 L
.48077 .47139 L
.5 .47136 L
.51923 .47285 L
.53846 .47637 L
.55167 .48077 L
.55769 .48454 L
.56021 .5 L
.55769 .50218 L
.53846 .51143 L
.51923 .51626 L
.5 .51902 L
.49778 .51923 L
.48077 .52047 L
.46154 .52023 L
.45068 .51923 L
.44231 .51822 L
.42308 .51414 L
.40385 .50394 L
.40153 .5 L
.40385 .49266 L
.42308 .48094 L
.42352 .48077 L
.44231 .47579 L
s
.8 g
.42308 .10237 m
.44231 .09769 L
.46154 .09637 L
.48077 .09724 L
.5 .10065 L
.51624 .11538 L
.5 .12218 L
.48077 .12499 L
.46154 .12534 L
.44231 .12355 L
.42308 .11863 L
.41666 .11538 L
F
0 g
.42308 .10237 m
.44231 .09769 L
.46154 .09637 L
.48077 .09724 L
.5 .10065 L
.51624 .11538 L
.5 .12218 L
.48077 .12499 L
.46154 .12534 L
.44231 .12355 L
.42308 .11863 L
.41666 .11538 L
.42308 .10237 L
s
1 g
.44231 .87961 m
.4445 .88462 L
.44231 .88497 L
.42589 .88462 L
F
0 g
.44231 .87961 m
.4445 .88462 L
.44231 .88497 L
.42589 .88462 L
.44231 .87961 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
0 .471 .699 r
.39852 .61146 .40481 .61259 .41497 .6131 .40867 .61325 Mtetra
.378 0 0 r
.40867 .61325 .41497 .6131 .42516 .61432 .41885 .61595 Mtetra
.49 0 0 r
.41885 .61595 .42516 .61432 .43542 .6157 .4291 .61896 Mtetra
.503 0 0 r
.4291 .61896 .43542 .6157 .44575 .6165 .43944 .62135 Mtetra
.46 0 .022 r
.43944 .62135 .44575 .6165 .45618 .616 .44989 .62226 Mtetra
.391 0 .039 r
.44989 .62226 .45618 .616 .46669 .61384 .46044 .62125 Mtetra
.328 0 .047 r
.46044 .62125 .46669 .61384 .47727 .61018 .47107 .61851 Mtetra
.302 0 .068 r
.47107 .61851 .47727 .61018 .48789 .60562 .48176 .61474 Mtetra
.324 0 .109 r
.48176 .61474 .48789 .60562 .49855 .60093 .49248 .61085 Mtetra
.376 0 .165 r
.49248 .61085 .49855 .60093 .50924 .59669 .50324 .60755 Mtetra
.432 .054 .22 r
.50324 .60755 .50924 .59669 .51996 .5932 .51404 .60518 Mtetra
.474 .11 .266 r
.51404 .60518 .51996 .5932 .53072 .59045 .52489 .60369 Mtetra
.501 .149 .302 r
.52489 .60369 .53072 .59045 .54153 .58822 .53579 .60282 Mtetra
.516 .175 .328 r
.53579 .60282 .54153 .58822 .55239 .58628 .54675 .60226 Mtetra
.522 .191 .348 r
.54675 .60226 .55239 .58628 .56331 .58442 .55777 .60171 Mtetra
.523 .201 .362 r
.55777 .60171 .56331 .58442 .57427 .58248 .56886 .60098 Mtetra
.522 .206 .373 r
.56886 .60098 .57427 .58248 .58529 .58037 .57999 .59993 Mtetra
.518 .208 .381 r
.57999 .59993 .58529 .58037 .59635 .57804 .59118 .59846 Mtetra
.514 .208 .386 r
.59118 .59846 .59635 .57804 .60745 .57544 .60242 .59652 Mtetra
.508 .206 .389 r
.60242 .59652 .60745 .57544 .61859 .57256 .61369 .59406 Mtetra
.501 .201 .39 r
.61369 .59406 .61859 .57256 .62978 .56937 .625 .59105 Mtetra
.493 .195 .388 r
.625 .59105 .62978 .56937 .641 .56589 .63634 .5875 Mtetra
.484 .187 .385 r
.63634 .5875 .641 .56589 .65225 .56211 .64771 .58339 Mtetra
.474 .176 .38 r
.64771 .58339 .65225 .56211 .66353 .55804 .6591 .57876 Mtetra
.463 .164 .372 r
.6591 .57876 .66353 .55804 .67484 .5537 .6705 .57364 Mtetra
.45 .148 .361 r
.6705 .57364 .67484 .5537 .68618 .54912 .68192 .56807 Mtetra
.435 .13 .348 r
.68192 .56807 .68618 .54912 .69755 .54433 .69335 .5621 Mtetra
.418 .108 .33 r
.69335 .5621 .69755 .54433 .70894 .53935 .7048 .5558 Mtetra
.397 .081 .307 r
.7048 .5558 .70894 .53935 .72037 .53423 .71625 .54923 Mtetra
.373 .048 .279 r
.71625 .54923 .72037 .53423 .73182 .529 .72772 .54247 Mtetra
.343 .007 .242 r
.72772 .54247 .73182 .529 .7433 .5237 .73921 .53558 Mtetra
.306 0 .195 r
.73921 .53558 .7433 .5237 .75481 .51837 .75072 .52864 Mtetra
.259 0 .133 r
.75072 .52864 .75481 .51837 .76636 .51304 .76225 .5217 Mtetra
.198 0 .051 r
.76225 .5217 .76636 .51304 .77795 .50773 .77382 .51481 Mtetra
.118 0 0 r
.77382 .51481 .77795 .50773 .78958 .50248 .78541 .50803 Mtetra
.013 0 0 r
.78541 .50803 .78958 .50248 .80125 .4973 .79705 .5014 Mtetra
0 0 0 r
.79705 .5014 .80125 .4973 .81297 .49221 .80872 .49495 Mtetra
.80872 .49495 .81297 .49221 .82473 .48723 .82045 .4887 Mtetra
.418 .852 .73 r
.82045 .4887 .82473 .48723 .83654 .48235 .83222 .48266 Mtetra
.536 .925 .859 r
.83222 .48266 .83654 .48235 .84841 .47759 .84405 .47684 Mtetra
.613 .947 .933 r
.84405 .47684 .84841 .47759 .86033 .47294 .85594 .47124 Mtetra
.656 .937 .966 r
.85594 .47124 .86033 .47294 .8723 .4684 .86788 .46586 Mtetra
.676 .914 .975 r
.86788 .46586 .8723 .4684 .88433 .46396 .87989 .46068 Mtetra
.685 .886 .972 r
.87989 .46068 .88433 .46396 .89642 .45962 .89196 .4557 Mtetra
.687 .86 .965 r
.89196 .4557 .89642 .45962 .90856 .45536 .90409 .45089 Mtetra
.686 .838 .956 r
.90409 .45089 .90856 .45536 .92076 .45118 .91628 .44624 Mtetra
.684 .818 .947 r
.91628 .44624 .92076 .45118 .93302 .44707 .92854 .44173 Mtetra
.681 .802 .94 r
.92854 .44173 .93302 .44707 .94534 .44302 .94086 .43733 Mtetra
.678 .79 .933 r
.94086 .43733 .94534 .44302 .95771 .43901 .95325 .43304 Mtetra
.676 .779 .928 r
.95325 .43304 .95771 .43901 .97014 .43504 .96569 .42884 Mtetra
.438 0 0 r
.39213 .61151 .39852 .61146 .40867 .61325 .40225 .61487 Mtetra
.584 .054 0 r
.40225 .61487 .40867 .61325 .41885 .61595 .41241 .61945 Mtetra
.624 .148 .102 r
.41241 .61945 .41885 .61595 .4291 .61896 .42264 .6245 Mtetra
.611 .171 .179 r
.42264 .6245 .4291 .61896 .43944 .62135 .43297 .62892 Mtetra
.568 .153 .215 r
.43297 .62892 .43944 .62135 .44989 .62226 .44344 .63169 Mtetra
.511 .116 .228 r
.44344 .63169 .44989 .62226 .46044 .62125 .45402 .63225 Mtetra
.462 .084 .236 r
.45402 .63225 .46044 .62125 .47107 .61851 .46471 .63082 Mtetra
.441 .078 .252 r
.46471 .63082 .47107 .61851 .48176 .61474 .47546 .62824 Mtetra
.452 .102 .279 r
.47546 .62824 .48176 .61474 .49248 .61085 .48626 .62559 Mtetra
.484 .143 .313 r
.48626 .62559 .49248 .61085 .50324 .60755 .4971 .62369 Mtetra
.517 .186 .346 r
.4971 .62369 .50324 .60755 .51404 .60518 .50799 .62295 Mtetra
.542 .22 .373 r
.50799 .62295 .51404 .60518 .52489 .60369 .51893 .62327 Mtetra
.556 .244 .393 r
.51893 .62327 .52489 .60369 .53579 .60282 .52994 .62434 Mtetra
.563 .258 .409 r
.52994 .62434 .53579 .60282 .54675 .60226 .54103 .62571 Mtetra
.563 .265 .42 r
.54103 .62571 .54675 .60226 .55777 .60171 .55218 .62704 Mtetra
.561 .269 .429 r
.55218 .62704 .55777 .60171 .56886 .60098 .56341 .62804 Mtetra
.556 .269 .435 r
.56341 .62804 .56886 .60098 .57999 .59993 .57471 .62852 Mtetra
.55 .268 .44 r
.57471 .62852 .57999 .59993 .59118 .59846 .58606 .62832 Mtetra
.543 .265 .443 r
.58606 .62832 .59118 .59846 .60242 .59652 .59746 .62737 Mtetra
.536 .26 .444 r
.59746 .62737 .60242 .59652 .61369 .59406 .60891 .62558 Mtetra
.528 .255 .444 r
.60891 .62558 .61369 .59406 .625 .59105 .62038 .6229 Mtetra
.519 .248 .443 r
.62038 .6229 .625 .59105 .63634 .5875 .63188 .61933 Mtetra
.51 .24 .441 r
.63188 .61933 .63634 .5875 .64771 .58339 .6434 .61487 Mtetra
.5 .231 .437 r
.6434 .61487 .64771 .58339 .6591 .57876 .65492 .60953 Mtetra
.489 .22 .432 r
.65492 .60953 .6591 .57876 .6705 .57364 .66645 .60339 Mtetra
.477 .207 .425 r
.66645 .60339 .6705 .57364 .68192 .56807 .67797 .5965 Mtetra
.464 .193 .416 r
.67797 .5965 .68192 .56807 .69335 .5621 .68948 .58897 Mtetra
.45 .176 .405 r
.68948 .58897 .69335 .5621 .7048 .5558 .70099 .58088 Mtetra
.434 .156 .391 r
.70099 .58088 .7048 .5558 .71625 .54923 .71248 .57236 Mtetra
.415 .133 .374 r
.71248 .57236 .71625 .54923 .72772 .54247 .72398 .56351 Mtetra
.393 .105 .352 r
.72398 .56351 .72772 .54247 .73921 .53558 .73547 .55445 Mtetra
.368 .071 .324 r
.73547 .55445 .73921 .53558 .75072 .52864 .74696 .5453 Mtetra
.337 .03 .288 r
.74696 .5453 .75072 .52864 .76225 .5217 .75847 .53615 Mtetra
.299 0 .242 r
.75847 .53615 .76225 .5217 .77382 .51481 .76999 .52711 Mtetra
.25 0 .181 r
.76999 .52711 .77382 .51481 .78541 .50803 .78153 .51824 Mtetra
.186 0 .1 r
.78153 .51824 .78541 .50803 .79705 .5014 .79311 .50961 Mtetra
.102 0 0 r
.79311 .50961 .79705 .5014 .80872 .49495 .80472 .50128 Mtetra
0 0 0 r
.80472 .50128 .80872 .49495 .82045 .4887 .81638 .49329 Mtetra
.81638 .49329 .82045 .4887 .83222 .48266 .82809 .48565 Mtetra
.82809 .48565 .83222 .48266 .84405 .47684 .83986 .47838 Mtetra
.47 .877 .729 r
.83986 .47838 .84405 .47684 .85594 .47124 .85169 .47148 Mtetra
.585 .946 .862 r
.85169 .47148 .85594 .47124 .86788 .46586 .86359 .46494 Mtetra
.652 .959 .934 r
.86359 .46494 .86788 .46586 .87989 .46068 .87555 .45875 Mtetra
.685 .941 .963 r
.87555 .45875 .87989 .46068 .89196 .4557 .88758 .45288 Mtetra
.697 .912 .969 r
.88758 .45288 .89196 .4557 .90409 .45089 .89968 .44731 Mtetra
.7 .882 .965 r
.89968 .44731 .90409 .45089 .91628 .44624 .91186 .44201 Mtetra
.697 .854 .958 r
.91186 .44201 .91628 .44624 .92854 .44173 .9241 .43695 Mtetra
.693 .831 .949 r
.9241 .43695 .92854 .44173 .94086 .43733 .93641 .43209 Mtetra
.689 .812 .941 r
.93641 .43209 .94086 .43733 .95325 .43304 .9488 .42741 Mtetra
.684 .797 .934 r
.9488 .42741 .95325 .43304 .96569 .42884 .96125 .42289 Mtetra
.579 .022 0 r
.38566 .61183 .39213 .61151 .40225 .61487 .39574 .61693 Mtetra
.67 .179 .075 r
.39574 .61693 .40225 .61487 .41241 .61945 .40586 .62356 Mtetra
.686 .242 .192 r
.40586 .62356 .41241 .61945 .42264 .6245 .41606 .63085 Mtetra
.665 .251 .25 r
.41606 .63085 .42264 .6245 .43297 .62892 .42638 .63751 Mtetra
.62 .226 .276 r
.42638 .63751 .43297 .62892 .44344 .63169 .43685 .64231 Mtetra
.563 .185 .283 r
.43685 .64231 .44344 .63169 .45402 .63225 .44747 .64457 Mtetra
.513 .149 .286 r
.44747 .64457 .45402 .63225 .46471 .63082 .45821 .64455 Mtetra
.489 .137 .297 r
.45821 .64455 .46471 .63082 .47546 .62824 .46903 .64324 Mtetra
.496 .156 .319 r
.46903 .64324 .47546 .62824 .48626 .62559 .4799 .64191 Mtetra
.523 .192 .347 r
.4799 .64191 .48626 .62559 .4971 .62369 .49082 .64155 Mtetra
.552 .229 .375 r
.49082 .64155 .4971 .62369 .50799 .62295 .5018 .6426 Mtetra
.574 .259 .397 r
.5018 .6426 .50799 .62295 .51893 .62327 .51284 .64496 Mtetra
.585 .278 .415 r
.51284 .64496 .51893 .62327 .52994 .62434 .52396 .64821 Mtetra
.588 .289 .428 r
.52396 .64821 .52994 .62434 .54103 .62571 .53516 .65181 Mtetra
.586 .293 .438 r
.53516 .65181 .54103 .62571 .55218 .62704 .54646 .65531 Mtetra
.581 .294 .445 r
.54646 .65531 .55218 .62704 .56341 .62804 .55784 .65833 Mtetra
.574 .291 .45 r
.55784 .65833 .56341 .62804 .57471 .62852 .5693 .66062 Mtetra
.565 .288 .453 r
.5693 .66062 .57471 .62852 .58606 .62832 .58083 .66196 Mtetra
.556 .282 .456 r
.58083 .66196 .58606 .62832 .59746 .62737 .59242 .66222 Mtetra
.547 .276 .457 r
.59242 .66222 .59746 .62737 .60891 .62558 .60405 .6613 Mtetra
.536 .269 .456 r
.60405 .6613 .60891 .62558 .62038 .6229 .61571 .65911 Mtetra
.525 .26 .455 r
.61571 .65911 .62038 .6229 .63188 .61933 .62739 .65563 Mtetra
.514 .25 .452 r
.62739 .65563 .63188 .61933 .6434 .61487 .63907 .65085 Mtetra
.501 .239 .449 r
.63907 .65085 .6434 .61487 .65492 .60953 .65075 .64482 Mtetra
.488 .227 .444 r
.65075 .64482 .65492 .60953 .66645 .60339 .66242 .6376 Mtetra
.474 .213 .437 r
.66242 .6376 .66645 .60339 .67797 .5965 .67406 .6293 Mtetra
.459 .197 .429 r
.67406 .6293 .67797 .5965 .68948 .58897 .68567 .62005 Mtetra
.442 .179 .419 r
.68567 .62005 .68948 .58897 .70099 .58088 .69725 .61 Mtetra
.424 .159 .406 r
.69725 .61 .70099 .58088 .71248 .57236 .7088 .59931 Mtetra
.403 .136 .39 r
.7088 .59931 .71248 .57236 .72398 .56351 .72032 .58814 Mtetra
.38 .108 .37 r
.72032 .58814 .72398 .56351 .73547 .55445 .73181 .57666 Mtetra
.353 .076 .346 r
.73181 .57666 .73547 .55445 .74696 .5453 .7433 .56503 Mtetra
.322 .036 .315 r
.7433 .56503 .74696 .5453 .75847 .53615 .75477 .55341 Mtetra
.283 0 .275 r
.75477 .55341 .75847 .53615 .76999 .52711 .76625 .54193 Mtetra
.236 0 .223 r
.76625 .54193 .76999 .52711 .78153 .51824 .77774 .5307 Mtetra
.177 0 .154 r
.77774 .5307 .78153 .51824 .79311 .50961 .78925 .51983 Mtetra
.1 0 .063 r
.78925 .51983 .79311 .50961 .80472 .50128 .8008 .50938 Mtetra
0 0 0 r
.8008 .50938 .80472 .50128 .81638 .49329 .81239 .49942 Mtetra
.81239 .49942 .81638 .49329 .82809 .48565 .82403 .48997 Mtetra
.82403 .48997 .82809 .48565 .83986 .47838 .83573 .48106 Mtetra
.442 .831 .609 r
.83573 .48106 .83986 .47838 .85169 .47148 .84749 .47269 Mtetra
.575 .933 .776 r
.84749 .47269 .85169 .47148 .86359 .46494 .85933 .46484 Mtetra
.66 .972 .883 r
.85933 .46484 .86359 .46494 .87555 .45875 .87124 .4575 Mtetra
.703 .966 .937 r
.87124 .4575 .87555 .45875 .88758 .45288 .88322 .45062 Mtetra
.719 .94 .957 r
.88322 .45062 .88758 .45288 .89968 .44731 .89529 .44419 Mtetra
.72 .908 .961 r
.89529 .44419 .89968 .44731 .91186 .44201 .90743 .43814 Mtetra
.716 .877 .956 r
.90743 .43814 .91186 .44201 .9241 .43695 .91966 .43245 Mtetra
.709 .85 .95 r
.91966 .43245 .9241 .43695 .93641 .43209 .93196 .42707 Mtetra
.702 .827 .942 r
.93196 .42707 .93641 .43209 .9488 .42741 .94433 .42195 Mtetra
.695 .809 .936 r
.94433 .42195 .9488 .42741 .96125 .42289 .95679 .41706 Mtetra
.632 .076 0 r
.37916 .61104 .38566 .61183 .39574 .61693 .38921 .61773 Mtetra
.72 .227 .07 r
.38921 .61773 .39574 .61693 .40586 .62356 .39928 .62628 Mtetra
.733 .283 .184 r
.39928 .62628 .40586 .62356 .41606 .63085 .40945 .63564 Mtetra
.708 .284 .237 r
.40945 .63564 .41606 .63085 .42638 .63751 .41975 .64433 Mtetra
.658 .247 .254 r
.41975 .64433 .42638 .63751 .43685 .64231 .43022 .65086 Mtetra
.589 .187 .249 r
.43022 .65086 .43685 .64231 .44747 .64457 .44086 .65445 Mtetra
.521 .128 .237 r
.44086 .65445 .44747 .64457 .45821 .64455 .45165 .65538 Mtetra
.484 .1 .236 r
.45165 .65538 .45821 .64455 .46903 .64324 .46253 .65484 Mtetra
.491 .116 .256 r
.46253 .65484 .46903 .64324 .4799 .64191 .47348 .65431 Mtetra
.528 .162 .29 r
.47348 .65431 .4799 .64191 .49082 .64155 .48447 .65498 Mtetra
.567 .212 .326 r
.48447 .65498 .49082 .64155 .5018 .6426 .49551 .65736 Mtetra
.596 .251 .356 r
.49551 .65736 .5018 .6426 .51284 .64496 .50663 .66133 Mtetra
.61 .276 .379 r
.50663 .66133 .51284 .64496 .52396 .64821 .51783 .66638 Mtetra
.613 .288 .395 r
.51783 .66638 .52396 .64821 .53516 .65181 .52914 .67188 Mtetra
.609 .292 .407 r
.52914 .67188 .53516 .65181 .54646 .65531 .54055 .67726 Mtetra
.6 .291 .416 r
.54055 .67726 .54646 .65531 .55784 .65833 .55205 .68207 Mtetra
.589 .286 .422 r
.55205 .68207 .55784 .65833 .5693 .66062 .56365 .68599 Mtetra
.576 .279 .426 r
.56365 .68599 .5693 .66062 .58083 .66196 .57533 .68875 Mtetra
.562 .27 .428 r
.57533 .68875 .58083 .66196 .59242 .66222 .58707 .69017 Mtetra
.547 .259 .429 r
.58707 .69017 .59242 .66222 .60405 .6613 .59886 .6901 Mtetra
.531 .247 .428 r
.59886 .6901 .60405 .6613 .61571 .65911 .61069 .68846 Mtetra
.514 .233 .425 r
.61069 .68846 .61571 .65911 .62739 .65563 .62253 .68518 Mtetra
.495 .217 .421 r
.62253 .68518 .62739 .65563 .63907 .65085 .63437 .68026 Mtetra
.475 .2 .415 r
.63437 .68026 .63907 .65085 .65075 .64482 .64619 .67375 Mtetra
.454 .18 .407 r
.64619 .67375 .65075 .64482 .66242 .6376 .65798 .66573 Mtetra
.431 .158 .397 r
.65798 .66573 .66242 .6376 .67406 .6293 .66974 .65632 Mtetra
.406 .134 .385 r
.66974 .65632 .67406 .6293 .68567 .62005 .68145 .6457 Mtetra
.379 .107 .369 r
.68145 .6457 .68567 .62005 .69725 .61 .69311 .63403 Mtetra
.349 .076 .35 r
.69311 .63403 .69725 .61 .7088 .59931 .70472 .62154 Mtetra
.315 .04 .327 r
.70472 .62154 .7088 .59931 .72032 .58814 .71628 .60842 Mtetra
.277 0 .298 r
.71628 .60842 .72032 .58814 .73181 .57666 .7278 .59491 Mtetra
.232 0 .261 r
.7278 .59491 .73181 .57666 .7433 .56503 .73929 .58119 Mtetra
.18 0 .215 r
.73929 .58119 .7433 .56503 .75477 .55341 .75076 .56747 Mtetra
.118 0 .156 r
.75076 .56747 .75477 .55341 .76625 .54193 .76221 .55391 Mtetra
.043 0 .08 r
.76221 .55391 .76625 .54193 .77774 .5307 .77367 .54066 Mtetra
0 0 0 r
.77367 .54066 .77774 .5307 .78925 .51983 .78514 .52786 Mtetra
.78514 .52786 .78925 .51983 .8008 .50938 .79664 .51559 Mtetra
.79664 .51559 .8008 .50938 .81239 .49942 .80818 .50392 Mtetra
.80818 .50392 .81239 .49942 .82403 .48997 .81977 .49291 Mtetra
.562 .887 .622 r
.81977 .49291 .82403 .48997 .83573 .48106 .83142 .48257 Mtetra
.664 .962 .759 r
.83142 .48257 .83573 .48106 .84749 .47269 .84314 .47291 Mtetra
.727 .99 .853 r
.84314 .47291 .84749 .47269 .85933 .46484 .85494 .46392 Mtetra
.756 .984 .907 r
.85494 .46392 .85933 .46484 .87124 .4575 .86681 .45556 Mtetra
.763 .959 .934 r
.86681 .45556 .87124 .4575 .88322 .45062 .87876 .4478 Mtetra
.759 .928 .944 r
.87876 .4478 .88322 .45062 .89529 .44419 .8908 .4406 Mtetra
.749 .897 .945 r
.8908 .4406 .89529 .44419 .90743 .43814 .90293 .4339 Mtetra
.737 .868 .942 r
.90293 .4339 .90743 .43814 .91966 .43245 .91514 .42765 Mtetra
.725 .844 .938 r
.91514 .42765 .91966 .43245 .93196 .42707 .92743 .42179 Mtetra
.714 .823 .933 r
.92743 .42179 .93196 .42707 .94433 .42195 .93981 .41628 Mtetra
.705 .806 .928 r
.93981 .41628 .94433 .42195 .95679 .41706 .95227 .41106 Mtetra
.594 .028 0 r
.37271 .60786 .37916 .61104 .38921 .61773 .38272 .61573 Mtetra
.736 .213 0 r
.38272 .61573 .38921 .61773 .39928 .62628 .39275 .62571 Mtetra
.769 .28 .067 r
.39275 .62571 .39928 .62628 .40945 .63564 .40288 .63661 Mtetra
.749 .273 .115 r
.40288 .63661 .40945 .63564 .41975 .64433 .41316 .64667 Mtetra
.686 .204 .099 r
.41316 .64667 .41975 .64433 .43022 .65086 .42364 .65417 Mtetra
.57 .068 .022 r
.42364 .65417 .43022 .65086 .44086 .65445 .43431 .65818 Mtetra
.406 0 0 r
.43431 .65818 .44086 .65445 .45165 .65538 .44515 .65905 Mtetra
.263 0 0 r
.44515 .65905 .45165 .65538 .46253 .65484 .45609 .65817 Mtetra
.24 0 0 r
.45609 .65817 .46253 .65484 .47348 .65431 .46709 .65729 Mtetra
.34 0 0 r
.46709 .65729 .47348 .65431 .48447 .65498 .47813 .65781 Mtetra
.475 0 0 r
.47813 .65781 .48447 .65498 .49551 .65736 .48922 .66035 Mtetra
.572 .058 0 r
.48922 .66035 .49551 .65736 .50663 .66133 .50038 .66478 Mtetra
.623 .133 .067 r
.50038 .66478 .50663 .66133 .51783 .66638 .51163 .67053 Mtetra
.642 .17 .117 r
.51163 .67053 .51783 .66638 .52914 .67188 .52298 .67687 Mtetra
.641 .183 .149 r
.52298 .67687 .52914 .67188 .54055 .67726 .53445 .68316 Mtetra
.626 .18 .17 r
.53445 .68316 .54055 .67726 .55205 .68207 .54602 .68888 Mtetra
.603 .166 .183 r
.54602 .68888 .55205 .68207 .56365 .68599 .55768 .69365 Mtetra
.573 .144 .188 r
.55768 .69365 .56365 .68599 .57533 .68875 .56944 .69721 Mtetra
.536 .114 .188 r
.56944 .69721 .57533 .68875 .58707 .69017 .58127 .69931 Mtetra
.492 .078 .182 r
.58127 .69931 .58707 .69017 .59886 .6901 .59315 .69981 Mtetra
.442 .035 .169 r
.59315 .69981 .59886 .6901 .61069 .68846 .60506 .69859 Mtetra
.384 0 .151 r
.60506 .69859 .61069 .68846 .62253 .68518 .617 .69557 Mtetra
.318 0 .125 r
.617 .69557 .62253 .68518 .63437 .68026 .62894 .69075 Mtetra
.244 0 .092 r
.62894 .69075 .63437 .68026 .64619 .67375 .64085 .68417 Mtetra
.16 0 .051 r
.64085 .68417 .64619 .67375 .65798 .66573 .65274 .67592 Mtetra
.068 0 .001 r
.65274 .67592 .65798 .66573 .66974 .65632 .66458 .66612 Mtetra
0 0 0 r
.66458 .66612 .66974 .65632 .68145 .6457 .67637 .65495 Mtetra
.67637 .65495 .68145 .6457 .69311 .63403 .68811 .64262 Mtetra
.68811 .64262 .69311 .63403 .70472 .62154 .69978 .62935 Mtetra
.69978 .62935 .70472 .62154 .71628 .60842 .7114 .61536 Mtetra
.7114 .61536 .71628 .60842 .7278 .59491 .72297 .60091 Mtetra
.572 .823 .451 r
.72297 .60091 .7278 .59491 .73929 .58119 .73449 .58621 Mtetra
.66 .887 .533 r
.73449 .58621 .73929 .58119 .75076 .56747 .74599 .57148 Mtetra
.733 .937 .609 r
.74599 .57148 .75076 .56747 .76221 .55391 .75747 .55691 Mtetra
.789 .971 .676 r
.75747 .55691 .76221 .55391 .77367 .54066 .76894 .54267 Mtetra
.829 .991 .734 r
.76894 .54267 .77367 .54066 .78514 .52786 .78042 .52889 Mtetra
.853 .997 .781 r
.78042 .52889 .78514 .52786 .79664 .51559 .79193 .5157 Mtetra
.864 .993 .819 r
.79193 .5157 .79664 .51559 .80818 .50392 .80347 .50316 Mtetra
.865 .982 .848 r
.80347 .50316 .80818 .50392 .81977 .49291 .81506 .49133 Mtetra
.858 .964 .87 r
.81506 .49133 .81977 .49291 .83142 .48257 .82671 .48024 Mtetra
.845 .944 .885 r
.82671 .48024 .83142 .48257 .84314 .47291 .83843 .46989 Mtetra
.83 .922 .896 r
.83843 .46989 .84314 .47291 .85494 .46392 .85022 .46028 Mtetra
.812 .9 .904 r
.85022 .46028 .85494 .46392 .86681 .45556 .8621 .45137 Mtetra
.794 .879 .908 r
.8621 .45137 .86681 .45556 .87876 .4478 .87406 .44312 Mtetra
.777 .859 .911 r
.87406 .44312 .87876 .4478 .8908 .4406 .88611 .43549 Mtetra
.76 .84 .912 r
.88611 .43549 .8908 .4406 .90293 .4339 .89824 .42842 Mtetra
.745 .824 .913 r
.89824 .42842 .90293 .4339 .91514 .42765 .91047 .42184 Mtetra
.732 .81 .913 r
.91047 .42184 .91514 .42765 .92743 .42179 .92278 .41571 Mtetra
.72 .797 .913 r
.92278 .41571 .92743 .42179 .93981 .41628 .93518 .40996 Mtetra
.709 .787 .912 r
.93518 .40996 .93981 .41628 .95227 .41106 .94766 .40454 Mtetra
0 .105 .599 r
.36633 .6018 .37271 .60786 .38272 .61573 .37631 .61031 Mtetra
.636 .113 0 r
.37631 .61031 .38272 .61573 .39275 .62571 .38632 .62111 Mtetra
.72 .2 0 r
.38632 .62111 .39275 .62571 .40288 .63661 .39641 .63283 Mtetra
.698 .162 0 r
.39641 .63283 .40288 .63661 .41316 .64667 .40668 .64343 Mtetra
.531 0 0 r
.40668 .64343 .41316 .64667 .42364 .65417 .41717 .6509 Mtetra
0 .481 .829 r
.41717 .6509 .42364 .65417 .43431 .65818 .42789 .65419 Mtetra
.464 .757 .993 r
.42789 .65419 .43431 .65818 .44515 .65905 .43879 .65371 Mtetra
.63 .762 .942 r
.43879 .65371 .44515 .65905 .45609 .65817 .4498 .65109 Mtetra
.64 .71 .897 r
.4498 .65109 .45609 .65817 .46709 .65729 .46085 .64839 Mtetra
.592 .644 .871 r
.46085 .64839 .46709 .65729 .47813 .65781 .47193 .64726 Mtetra
.52 .575 .851 r
.47193 .64726 .47813 .65781 .48922 .66035 .48304 .64844 Mtetra
.451 .513 .831 r
.48304 .64844 .48922 .66035 .50038 .66478 .4942 .65181 Mtetra
.406 .47 .814 r
.4942 .65181 .50038 .66478 .51163 .67053 .50545 .65675 Mtetra
.39 .449 .801 r
.50545 .65675 .51163 .67053 .52298 .67687 .51679 .66248 Mtetra
.399 .446 .793 r
.51679 .66248 .52298 .67687 .53445 .68316 .52824 .66829 Mtetra
.424 .455 .789 r
.52824 .66829 .53445 .68316 .54602 .68888 .53979 .67365 Mtetra
.456 .471 .785 r
.53979 .67365 .54602 .68888 .55768 .69365 .55144 .67816 Mtetra
.492 .489 .782 r
.55144 .67816 .55768 .69365 .56944 .69721 .56319 .68153 Mtetra
.528 .509 .778 r
.56319 .68153 .56944 .69721 .58127 .69931 .575 .68356 Mtetra
.563 .528 .774 r
.575 .68356 .58127 .69931 .59315 .69981 .58688 .68408 Mtetra
.596 .547 .77 r
.58688 .68408 .59315 .69981 .60506 .69859 .5988 .68298 Mtetra
.626 .565 .766 r
.5988 .68298 .60506 .69859 .617 .69557 .61074 .68017 Mtetra
.655 .583 .762 r
.61074 .68017 .617 .69557 .62894 .69075 .62269 .67565 Mtetra
.68 .599 .758 r
.62269 .67565 .62894 .69075 .64085 .68417 .63463 .66945 Mtetra
.703 .614 .754 r
.63463 .66945 .64085 .68417 .65274 .67592 .64655 .66163 Mtetra
.724 .629 .751 r
.64655 .66163 .65274 .67592 .66458 .66612 .65843 .65232 Mtetra
.742 .642 .749 r
.65843 .65232 .66458 .66612 .67637 .65495 .67026 .64168 Mtetra
.758 .655 .747 r
.67026 .64168 .67637 .65495 .68811 .64262 .68205 .6299 Mtetra
.772 .667 .747 r
.68205 .6299 .68811 .64262 .69978 .62935 .69378 .61719 Mtetra
.784 .678 .747 r
.69378 .61719 .69978 .62935 .7114 .61536 .70546 .60376 Mtetra
.794 .689 .748 r
.70546 .60376 .7114 .61536 .72297 .60091 .71709 .58985 Mtetra
.803 .699 .751 r
.71709 .58985 .72297 .60091 .73449 .58621 .72869 .57566 Mtetra
.809 .709 .754 r
.72869 .57566 .73449 .58621 .74599 .57148 .74025 .56142 Mtetra
.814 .718 .759 r
.74025 .56142 .74599 .57148 .75747 .55691 .7518 .5473 Mtetra
.816 .726 .765 r
.7518 .5473 .75747 .55691 .76894 .54267 .76335 .53346 Mtetra
.817 .734 .773 r
.76335 .53346 .76894 .54267 .78042 .52889 .7749 .52005 Mtetra
.817 .741 .781 r
.7749 .52005 .78042 .52889 .79193 .5157 .78648 .50717 Mtetra
.814 .748 .79 r
.78648 .50717 .79193 .5157 .80347 .50316 .79809 .4949 Mtetra
.81 .753 .8 r
.79809 .4949 .80347 .50316 .81506 .49133 .80975 .4833 Mtetra
.804 .758 .811 r
.80975 .4833 .81506 .49133 .82671 .48024 .82146 .47241 Mtetra
.796 .762 .821 r
.82146 .47241 .82671 .48024 .83843 .46989 .83324 .46222 Mtetra
.788 .764 .832 r
.83324 .46222 .83843 .46989 .85022 .46028 .84509 .45274 Mtetra
.778 .766 .842 r
.84509 .45274 .85022 .46028 .8621 .45137 .85702 .44393 Mtetra
.767 .766 .852 r
.85702 .44393 .8621 .45137 .87406 .44312 .86903 .43576 Mtetra
.756 .766 .861 r
.86903 .43576 .87406 .44312 .88611 .43549 .88113 .42818 Mtetra
.745 .765 .869 r
.88113 .42818 .88611 .43549 .89824 .42842 .89332 .42114 Mtetra
.734 .764 .876 r
.89332 .42114 .89824 .42842 .91047 .42184 .90559 .41459 Mtetra
.724 .762 .882 r
.90559 .41459 .91047 .42184 .92278 .41571 .91795 .40846 Mtetra
.715 .759 .888 r
.91795 .40846 .92278 .41571 .93518 .40996 .93039 .40271 Mtetra
.706 .757 .892 r
.93039 .40271 .93518 .40996 .94766 .40454 .94292 .39728 Mtetra
0 .208 .73 r
.36001 .59347 .36633 .6018 .37631 .61031 .36998 .60219 Mtetra
0 .013 .554 r
.36998 .60219 .37631 .61031 .38632 .62111 .37996 .61333 Mtetra
0 0 .474 r
.37996 .61333 .38632 .62111 .39641 .63283 .39004 .6253 Mtetra
0 .053 .582 r
.39004 .6253 .39641 .63283 .40668 .64343 .40031 .63574 Mtetra
.021 .366 .836 r
.40031 .63574 .40668 .64343 .41717 .6509 .41083 .64235 Mtetra
.469 .597 .898 r
.41083 .64235 .41717 .6509 .42789 .65419 .4216 .64395 Mtetra
.644 .637 .829 r
.4216 .64395 .42789 .65419 .43879 .65371 .43258 .64104 Mtetra
.684 .618 .776 r
.43258 .64104 .43879 .65371 .4498 .65109 .44365 .6355 Mtetra
.673 .583 .746 r
.44365 .6355 .4498 .65109 .46085 .64839 .45477 .62976 Mtetra
.639 .541 .727 r
.45477 .62976 .46085 .64839 .47193 .64726 .46588 .6257 Mtetra
.598 .499 .713 r
.46588 .6257 .47193 .64726 .48304 .64844 .477 .62422 Mtetra
.562 .464 .7 r
.477 .62422 .48304 .64844 .4942 .65181 .48814 .62524 Mtetra
.539 .439 .689 r
.48814 .62524 .4942 .65181 .50545 .65675 .49935 .62809 Mtetra
.528 .425 .68 r
.49935 .62809 .50545 .65675 .51679 .66248 .51064 .63194 Mtetra
.528 .419 .673 r
.51064 .63194 .51679 .66248 .52824 .66829 .52203 .63606 Mtetra
.534 .418 .668 r
.52203 .63606 .52824 .66829 .53979 .67365 .53351 .63992 Mtetra
.543 .421 .664 r
.53351 .63992 .53979 .67365 .55144 .67816 .54508 .64314 Mtetra
.554 .426 .66 r
.54508 .64314 .55144 .67816 .56319 .68153 .55673 .64545 Mtetra
.565 .431 .657 r
.55673 .64545 .56319 .68153 .575 .68356 .56846 .64668 Mtetra
.576 .437 .655 r
.56846 .64668 .575 .68356 .58688 .68408 .58025 .64667 Mtetra
.587 .444 .654 r
.58025 .64667 .58688 .68408 .5988 .68298 .59209 .64532 Mtetra
.598 .451 .653 r
.59209 .64532 .5988 .68298 .61074 .68017 .60396 .64259 Mtetra
.609 .459 .653 r
.60396 .64259 .61074 .68017 .62269 .67565 .61585 .63843 Mtetra
.619 .467 .653 r
.61585 .63843 .62269 .67565 .63463 .66945 .62774 .63288 Mtetra
.63 .475 .654 r
.62774 .63288 .63463 .66945 .64655 .66163 .63962 .62598 Mtetra
.64 .483 .655 r
.63962 .62598 .64655 .66163 .65843 .65232 .65149 .61783 Mtetra
.649 .492 .657 r
.65149 .61783 .65843 .65232 .67026 .64168 .66333 .60855 Mtetra
.659 .501 .659 r
.66333 .60855 .67026 .64168 .68205 .6299 .67513 .5983 Mtetra
.668 .511 .662 r
.67513 .5983 .68205 .6299 .69378 .61719 .6869 .58724 Mtetra
.677 .52 .666 r
.6869 .58724 .69378 .61719 .70546 .60376 .69864 .57556 Mtetra
.685 .53 .67 r
.69864 .57556 .70546 .60376 .71709 .58985 .71035 .56344 Mtetra
.693 .541 .676 r
.71035 .56344 .71709 .58985 .72869 .57566 .72203 .55105 Mtetra
.7 .551 .682 r
.72203 .55105 .72869 .57566 .74025 .56142 .73369 .53857 Mtetra
.707 .563 .689 r
.73369 .53857 .74025 .56142 .7518 .5473 .74535 .52617 Mtetra
.714 .574 .697 r
.74535 .52617 .7518 .5473 .76335 .53346 .75701 .51397 Mtetra
.719 .586 .706 r
.75701 .51397 .76335 .53346 .7749 .52005 .76868 .5021 Mtetra
.724 .599 .716 r
.76868 .5021 .7749 .52005 .78648 .50717 .78038 .49064 Mtetra
.728 .611 .727 r
.78038 .49064 .78648 .50717 .79809 .4949 .79211 .47968 Mtetra
.731 .624 .739 r
.79211 .47968 .79809 .4949 .80975 .4833 .80389 .46927 Mtetra
.733 .637 .752 r
.80389 .46927 .80975 .4833 .82146 .47241 .81572 .45943 Mtetra
.734 .65 .766 r
.81572 .45943 .82146 .47241 .83324 .46222 .82761 .45018 Mtetra
.733 .663 .78 r
.82761 .45018 .83324 .46222 .84509 .45274 .83957 .44151 Mtetra
.732 .675 .795 r
.83957 .44151 .84509 .45274 .85702 .44393 .8516 .4334 Mtetra
.729 .686 .809 r
.8516 .4334 .85702 .44393 .86903 .43576 .86371 .42583 Mtetra
.725 .696 .822 r
.86371 .42583 .86903 .43576 .88113 .42818 .87589 .41875 Mtetra
.72 .705 .835 r
.87589 .41875 .88113 .42818 .89332 .42114 .88816 .41213 Mtetra
.715 .713 .847 r
.88816 .41213 .89332 .42114 .90559 .41459 .90051 .40592 Mtetra
.709 .719 .858 r
.90051 .40592 .90559 .41459 .91795 .40846 .91295 .40007 Mtetra
.703 .725 .867 r
.91295 .40007 .91795 .40846 .93039 .40271 .92546 .39454 Mtetra
.697 .729 .875 r
.92546 .39454 .93039 .40271 .94292 .39728 .93805 .38929 Mtetra
0 .237 .754 r
.3537 .58422 .36001 .59347 .36998 .60219 .36366 .59301 Mtetra
0 .054 .608 r
.36366 .59301 .36998 .60219 .37996 .61333 .37362 .60431 Mtetra
0 .004 .559 r
.37362 .60431 .37996 .61333 .39004 .6253 .38368 .61631 Mtetra
0 .158 .695 r
.38368 .61631 .39004 .6253 .40031 .63574 .39395 .62631 Mtetra
.249 .455 .865 r
.39395 .62631 .40031 .63574 .41083 .64235 .40452 .6317 Mtetra
.578 .6 .839 r
.40452 .6317 .41083 .64235 .4216 .64395 .41536 .63115 Mtetra
.689 .619 .772 r
.41536 .63115 .4216 .64395 .43258 .64104 .42642 .62525 Mtetra
.712 .601 .731 r
.42642 .62525 .43258 .64104 .44365 .6355 .43759 .6162 Mtetra
.698 .57 .708 r
.43759 .6162 .44365 .6355 .45477 .62976 .44878 .60678 Mtetra
.666 .534 .693 r
.44878 .60678 .45477 .62976 .46588 .6257 .45993 .59917 Mtetra
.629 .497 .682 r
.45993 .59917 .46588 .6257 .477 .62422 .47106 .5944 Mtetra
.596 .465 .672 r
.47106 .5944 .477 .62422 .48814 .62524 .48219 .59242 Mtetra
.574 .442 .663 r
.48219 .59242 .48814 .62524 .49935 .62809 .49335 .59255 Mtetra
.562 .428 .656 r
.49335 .59255 .49935 .62809 .51064 .63194 .50458 .5939 Mtetra
.558 .42 .65 r
.50458 .5939 .51064 .63194 .52203 .63606 .51588 .59574 Mtetra
.559 .418 .645 r
.51588 .59574 .52203 .63606 .53351 .63992 .52727 .59754 Mtetra
.563 .417 .641 r
.52727 .59754 .53351 .63992 .54508 .64314 .53873 .59893 Mtetra
.568 .418 .638 r
.53873 .59893 .54508 .64314 .55673 .64545 .55027 .59971 Mtetra
.574 .42 .636 r
.55027 .59971 .55673 .64545 .56846 .64668 .56187 .59971 Mtetra
.579 .423 .634 r
.56187 .59971 .56846 .64668 .58025 .64667 .57354 .59884 Mtetra
.585 .427 .633 r
.57354 .59884 .58025 .64667 .59209 .64532 .58526 .59701 Mtetra
.592 .43 .632 r
.58526 .59701 .59209 .64532 .60396 .64259 .59701 .59418 Mtetra
.598 .435 .632 r
.59701 .59418 .60396 .64259 .61585 .63843 .6088 .59033 Mtetra
.604 .439 .632 r
.6088 .59033 .61585 .63843 .62774 .63288 .6206 .58546 Mtetra
.61 .445 .633 r
.6206 .58546 .62774 .63288 .63962 .62598 .63241 .57961 Mtetra
.616 .45 .634 r
.63241 .57961 .63962 .62598 .65149 .61783 .64423 .57285 Mtetra
.623 .456 .636 r
.64423 .57285 .65149 .61783 .66333 .60855 .65604 .56525 Mtetra
.629 .463 .639 r
.65604 .56525 .66333 .60855 .67513 .5983 .66784 .55693 Mtetra
.635 .47 .642 r
.66784 .55693 .67513 .5983 .6869 .58724 .67963 .548 Mtetra
.641 .477 .645 r
.67963 .548 .6869 .58724 .69864 .57556 .69142 .53858 Mtetra
.647 .485 .65 r
.69142 .53858 .69864 .57556 .71035 .56344 .70319 .52881 Mtetra
.653 .493 .655 r
.70319 .52881 .71035 .56344 .72203 .55105 .71495 .51882 Mtetra
.659 .502 .661 r
.71495 .51882 .72203 .55105 .73369 .53857 .72672 .50873 Mtetra
.665 .512 .667 r
.72672 .50873 .73369 .53857 .74535 .52617 .73849 .49867 Mtetra
.67 .522 .675 r
.73849 .49867 .74535 .52617 .75701 .51397 .75028 .48873 Mtetra
.676 .534 .684 r
.75028 .48873 .75701 .51397 .76868 .5021 .76209 .479 Mtetra
.681 .546 .694 r
.76209 .479 .76868 .5021 .78038 .49064 .77392 .46955 Mtetra
.685 .558 .705 r
.77392 .46955 .78038 .49064 .79211 .47968 .7858 .46045 Mtetra
.69 .572 .717 r
.7858 .46045 .79211 .47968 .80389 .46927 .79772 .45173 Mtetra
.693 .586 .73 r
.79772 .45173 .80389 .46927 .81572 .45943 .80969 .44342 Mtetra
.696 .6 .745 r
.80969 .44342 .81572 .45943 .82761 .45018 .82172 .43553 Mtetra
.699 .615 .759 r
.82172 .43553 .82761 .45018 .83957 .44151 .83381 .42806 Mtetra
.7 .63 .775 r
.83381 .42806 .83957 .44151 .8516 .4334 .84596 .421 Mtetra
.701 .644 .79 r
.84596 .421 .8516 .4334 .86371 .42583 .85819 .41433 Mtetra
.7 .658 .805 r
.85819 .41433 .86371 .42583 .87589 .41875 .87049 .40802 Mtetra
.699 .671 .82 r
.87049 .40802 .87589 .41875 .88816 .41213 .88286 .40204 Mtetra
.696 .683 .833 r
.88286 .40204 .88816 .41213 .90051 .40592 .89531 .39637 Mtetra
.694 .694 .846 r
.89531 .39637 .90051 .40592 .91295 .40007 .90783 .39096 Mtetra
.691 .703 .857 r
.90783 .39096 .91295 .40007 .92546 .39454 .92043 .38579 Mtetra
.687 .711 .867 r
.92043 .38579 .92546 .39454 .93805 .38929 .9331 .38082 Mtetra
0 .201 .727 r
.34733 .57539 .3537 .58422 .36366 .59301 .35727 .58438 Mtetra
0 0 .544 r
.35727 .58438 .36366 .59301 .37362 .60431 .3672 .59602 Mtetra
0 0 .487 r
.3672 .59602 .37362 .60431 .38368 .61631 .37724 .60822 Mtetra
0 .133 .664 r
.37724 .60822 .38368 .61631 .39395 .62631 .38752 .61793 Mtetra
.278 .504 .895 r
.38752 .61793 .39395 .62631 .40452 .6317 .39813 .62222 Mtetra
.637 .65 .846 r
.39813 .62222 .40452 .6317 .41536 .63115 .40906 .61957 Mtetra
.738 .655 .767 r
.40906 .61957 .41536 .63115 .42642 .62525 .42022 .6107 Mtetra
.753 .631 .724 r
.42022 .6107 .42642 .62525 .43759 .6162 .4315 .59815 Mtetra
.736 .598 .703 r
.4315 .59815 .43759 .6162 .44878 .60678 .44277 .58505 Mtetra
.702 .561 .691 r
.44277 .58505 .44878 .60678 .45993 .59917 .45399 .57391 Mtetra
.662 .522 .683 r
.45399 .57391 .45993 .59917 .47106 .5944 .46514 .5659 Mtetra
.626 .488 .674 r
.46514 .5659 .47106 .5944 .48219 .59242 .47627 .56099 Mtetra
.6 .463 .666 r
.47627 .56099 .48219 .59242 .49335 .59255 .4874 .55847 Mtetra
.584 .446 .659 r
.4874 .55847 .49335 .59255 .50458 .5939 .49858 .5574 Mtetra
.577 .436 .653 r
.49858 .5574 .50458 .5939 .51588 .59574 .50981 .55703 Mtetra
.575 .431 .648 r
.50981 .55703 .51588 .59574 .52727 .59754 .52111 .5568 Mtetra
.576 .428 .643 r
.52111 .5568 .52727 .59754 .53873 .59893 .53247 .5564 Mtetra
.579 .427 .64 r
.53247 .5564 .53873 .59893 .55027 .59971 .5439 .55564 Mtetra
.582 .427 .637 r
.5439 .55564 .55027 .59971 .56187 .59971 .5554 .55441 Mtetra
.585 .428 .635 r
.5554 .55441 .56187 .59971 .57354 .59884 .56695 .55262 Mtetra
.589 .43 .634 r
.56695 .55262 .57354 .59884 .58526 .59701 .57855 .55023 Mtetra
.593 .432 .633 r
.57855 .55023 .58526 .59701 .59701 .59418 .59019 .54721 Mtetra
.597 .435 .633 r
.59019 .54721 .59701 .59418 .6088 .59033 .60187 .54354 Mtetra
.601 .438 .633 r
.60187 .54354 .6088 .59033 .6206 .58546 .61358 .53922 Mtetra
.605 .442 .634 r
.61358 .53922 .6206 .58546 .63241 .57961 .62532 .53427 Mtetra
.609 .446 .635 r
.62532 .53427 .63241 .57961 .64423 .57285 .63708 .52872 Mtetra
.614 .45 .637 r
.63708 .52872 .64423 .57285 .65604 .56525 .64886 .52264 Mtetra
.618 .456 .64 r
.64886 .52264 .65604 .56525 .66784 .55693 .66064 .51608 Mtetra
.623 .461 .643 r
.66064 .51608 .66784 .55693 .67963 .548 .67244 .50911 Mtetra
.627 .468 .646 r
.67244 .50911 .67963 .548 .69142 .53858 .68425 .50181 Mtetra
.632 .474 .651 r
.68425 .50181 .69142 .53858 .70319 .52881 .69608 .49426 Mtetra
.637 .482 .656 r
.69608 .49426 .70319 .52881 .71495 .51882 .70791 .48655 Mtetra
.642 .49 .662 r
.70791 .48655 .71495 .51882 .72672 .50873 .71977 .47876 Mtetra
.646 .499 .669 r
.71977 .47876 .72672 .50873 .73849 .49867 .73165 .47096 Mtetra
.651 .509 .677 r
.73165 .47096 .73849 .49867 .75028 .48873 .74355 .46322 Mtetra
.656 .52 .686 r
.74355 .46322 .75028 .48873 .76209 .479 .75548 .45559 Mtetra
.66 .532 .697 r
.75548 .45559 .76209 .479 .77392 .46955 .76745 .44813 Mtetra
.665 .544 .708 r
.76745 .44813 .77392 .46955 .7858 .46045 .77946 .44087 Mtetra
.669 .558 .72 r
.77946 .44087 .7858 .46045 .79772 .45173 .79151 .43385 Mtetra
.673 .572 .733 r
.79151 .43385 .79772 .45173 .80969 .44342 .80362 .42707 Mtetra
.677 .587 .748 r
.80362 .42707 .80969 .44342 .82172 .43553 .81578 .42056 Mtetra
.679 .602 .762 r
.81578 .42056 .82172 .43553 .83381 .42806 .828 .41431 Mtetra
.682 .618 .777 r
.828 .41431 .83381 .42806 .84596 .421 .84028 .40832 Mtetra
.683 .633 .793 r
.84028 .40832 .84596 .421 .85819 .41433 .85263 .40257 Mtetra
.684 .648 .808 r
.85263 .40257 .85819 .41433 .87049 .40802 .86504 .39705 Mtetra
.684 .662 .822 r
.86504 .39705 .87049 .40802 .88286 .40204 .87751 .39175 Mtetra
.683 .674 .835 r
.87751 .39175 .88286 .40204 .89531 .39637 .89006 .38663 Mtetra
.682 .686 .847 r
.89006 .38663 .89531 .39637 .90783 .39096 .90267 .38168 Mtetra
.681 .696 .858 r
.90267 .38168 .90783 .39096 .92043 .38579 .91535 .37688 Mtetra
.679 .705 .868 r
.91535 .37688 .92043 .38579 .9331 .38082 .92809 .37221 Mtetra
0 .094 .622 r
.34086 .56779 .34733 .57539 .35727 .58438 .35076 .5773 Mtetra
.628 .139 0 r
.35076 .5773 .35727 .58438 .3672 .59602 .36065 .58963 Mtetra
.69 .19 0 r
.36065 .58963 .3672 .59602 .37724 .60822 .37066 .60245 Mtetra
.536 .014 0 r
.37066 .60245 .37724 .60822 .38752 .61793 .38094 .61231 Mtetra
.152 .531 .921 r
.38094 .61231 .38752 .61793 .39813 .62222 .39158 .61589 Mtetra
.692 .749 .895 r
.39158 .61589 .39813 .62222 .40906 .61957 .4026 .61154 Mtetra
.799 .726 .784 r
.4026 .61154 .40906 .61957 .42022 .6107 .41388 .60008 Mtetra
.809 .69 .733 r
.41388 .60008 .42022 .6107 .4315 .59815 .42528 .58438 Mtetra
.788 .652 .712 r
.42528 .58438 .4315 .59815 .44277 .58505 .43666 .568 Mtetra
.751 .612 .704 r
.43666 .568 .44277 .58505 .45399 .57391 .44795 .55375 Mtetra
.706 .57 .699 r
.44795 .55375 .45399 .57391 .46514 .5659 .45915 .54296 Mtetra
.663 .531 .694 r
.45915 .54296 .46514 .5659 .47627 .56099 .4703 .53562 Mtetra
.629 .5 .687 r
.4703 .53562 .47627 .56099 .4874 .55847 .48142 .53094 Mtetra
.608 .479 .68 r
.48142 .53094 .4874 .55847 .49858 .5574 .49257 .52795 Mtetra
.596 .466 .673 r
.49257 .52795 .49858 .5574 .50981 .55703 .50376 .52582 Mtetra
.592 .458 .667 r
.50376 .52582 .50981 .55703 .52111 .5568 .515 .52401 Mtetra
.591 .453 .662 r
.515 .52401 .52111 .5568 .53247 .5564 .5263 .52219 Mtetra
.591 .451 .658 r
.5263 .52219 .53247 .5564 .5439 .55564 .53766 .52021 Mtetra
.593 .449 .655 r
.53766 .52021 .5439 .55564 .5554 .55441 .54908 .51798 Mtetra
.595 .448 .653 r
.54908 .51798 .5554 .55441 .56695 .55262 .56054 .51544 Mtetra
.597 .449 .651 r
.56054 .51544 .56695 .55262 .57855 .55023 .57206 .51256 Mtetra
.599 .449 .65 r
.57206 .51256 .57855 .55023 .59019 .54721 .58362 .50932 Mtetra
.602 .451 .649 r
.58362 .50932 .59019 .54721 .60187 .54354 .59523 .50572 Mtetra
.605 .453 .649 r
.59523 .50572 .60187 .54354 .61358 .53922 .60688 .50174 Mtetra
.608 .456 .65 r
.60688 .50174 .61358 .53922 .62532 .53427 .61856 .49741 Mtetra
.611 .459 .651 r
.61856 .49741 .62532 .53427 .63708 .52872 .63027 .49274 Mtetra
.614 .463 .654 r
.63027 .49274 .63708 .52872 .64886 .52264 .64202 .48775 Mtetra
.618 .468 .656 r
.64202 .48775 .64886 .52264 .66064 .51608 .6538 .48248 Mtetra
.621 .473 .66 r
.6538 .48248 .66064 .51608 .67244 .50911 .6656 .47697 Mtetra
.625 .479 .664 r
.6656 .47697 .67244 .50911 .68425 .50181 .67744 .47126 Mtetra
.629 .486 .669 r
.67744 .47126 .68425 .50181 .69608 .49426 .6893 .4654 Mtetra
.633 .494 .675 r
.6893 .4654 .69608 .49426 .70791 .48655 .70119 .45942 Mtetra
.637 .502 .682 r
.70119 .45942 .70791 .48655 .71977 .47876 .71311 .45339 Mtetra
.641 .511 .689 r
.71311 .45339 .71977 .47876 .73165 .47096 .72507 .44734 Mtetra
.645 .521 .698 r
.72507 .44734 .73165 .47096 .74355 .46322 .73707 .4413 Mtetra
.649 .532 .708 r
.73707 .4413 .74355 .46322 .75548 .45559 .7491 .43531 Mtetra
.654 .544 .718 r
.7491 .43531 .75548 .45559 .76745 .44813 .76117 .42941 Mtetra
.658 .557 .73 r
.76117 .42941 .76745 .44813 .77946 .44087 .77329 .42361 Mtetra
.661 .571 .742 r
.77329 .42361 .77946 .44087 .79151 .43385 .78546 .41793 Mtetra
.665 .585 .755 r
.78546 .41793 .79151 .43385 .80362 .42707 .79768 .41237 Mtetra
.668 .599 .769 r
.79768 .41237 .80362 .42707 .81578 .42056 .80996 .40696 Mtetra
.671 .614 .783 r
.80996 .40696 .81578 .42056 .828 .41431 .82228 .40169 Mtetra
.673 .629 .797 r
.82228 .40169 .828 .41431 .84028 .40832 .83467 .39656 Mtetra
.674 .643 .811 r
.83467 .39656 .84028 .40832 .85263 .40257 .84712 .39155 Mtetra
.675 .657 .824 r
.84712 .39155 .85263 .40257 .86504 .39705 .85962 .38667 Mtetra
.675 .67 .837 r
.85962 .38667 .86504 .39705 .87751 .39175 .87219 .38191 Mtetra
.675 .681 .848 r
.87219 .38191 .87751 .39175 .89006 .38663 .88482 .37724 Mtetra
.675 .692 .859 r
.88482 .37724 .89006 .38663 .90267 .38168 .89751 .37267 Mtetra
.674 .701 .868 r
.89751 .37267 .90267 .38168 .91535 .37688 .91026 .36817 Mtetra
.673 .709 .875 r
.91026 .36817 .91535 .37688 .92809 .37221 .92308 .36374 Mtetra
.57 .058 0 r
.33426 .56156 .34086 .56779 .35076 .5773 .34412 .57193 Mtetra
.768 .269 0 r
.34412 .57193 .35076 .5773 .36065 .58963 .35395 .58537 Mtetra
.8 .307 0 r
.35395 .58537 .36065 .58963 .37066 .60245 .36391 .59925 Mtetra
.715 .181 0 r
.36391 .59925 .37066 .60245 .38094 .61231 .37416 .60974 Mtetra
0 .409 .727 r
.37416 .60974 .38094 .61231 .39158 .61589 .38484 .61312 Mtetra
.729 .88 .95 r
.38484 .61312 .39158 .61589 .4026 .61154 .39594 .60754 Mtetra
.863 .816 .801 r
.39594 .60754 .4026 .61154 .41388 .60008 .40735 .59392 Mtetra
.869 .761 .742 r
.40735 .59392 .41388 .60008 .42528 .58438 .41888 .57553 Mtetra
.846 .719 .723 r
.41888 .57553 .42528 .58438 .43666 .568 .43039 .55635 Mtetra
.809 .679 .721 r
.43039 .55635 .43666 .568 .44795 .55375 .44178 .53951 Mtetra
.76 .637 .725 r
.44178 .53951 .44795 .55375 .45915 .54296 .45304 .5265 Mtetra
.71 .595 .726 r
.45304 .5265 .45915 .54296 .4703 .53562 .46422 .51732 Mtetra
.667 .559 .724 r
.46422 .51732 .4703 .53562 .48142 .53094 .47536 .51109 Mtetra
.637 .532 .718 r
.47536 .51109 .48142 .53094 .49257 .52795 .4865 .50677 Mtetra
.621 .515 .712 r
.4865 .50677 .49257 .52795 .50376 .52582 .49768 .50346 Mtetra
.613 .504 .706 r
.49768 .50346 .50376 .52582 .515 .52401 .5089 .50058 Mtetra
.61 .497 .7 r
.5089 .50058 .515 .52401 .5263 .52219 .52017 .49783 Mtetra
.609 .492 .695 r
.52017 .49783 .5263 .52219 .53766 .52021 .5315 .49503 Mtetra
.609 .489 .691 r
.5315 .49503 .53766 .52021 .54908 .51798 .54287 .49212 Mtetra
.609 .487 .688 r
.54287 .49212 .54908 .51798 .56054 .51544 .5543 .48905 Mtetra
.611 .486 .686 r
.5543 .48905 .56054 .51544 .57206 .51256 .56577 .48582 Mtetra
.612 .486 .684 r
.56577 .48582 .57206 .51256 .58362 .50932 .5773 .4824 Mtetra
.614 .486 .683 r
.5773 .4824 .58362 .50932 .59523 .50572 .58886 .47879 Mtetra
.615 .488 .683 r
.58886 .47879 .59523 .50572 .60688 .50174 .60048 .47499 Mtetra
.618 .49 .684 r
.60048 .47499 .60688 .50174 .61856 .49741 .61213 .47101 Mtetra
.62 .493 .686 r
.61213 .47101 .61856 .49741 .63027 .49274 .62383 .46685 Mtetra
.622 .496 .688 r
.62383 .46685 .63027 .49274 .64202 .48775 .63556 .46253 Mtetra
.625 .501 .691 r
.63556 .46253 .64202 .48775 .6538 .48248 .64734 .45805 Mtetra
.628 .506 .695 r
.64734 .45805 .6538 .48248 .6656 .47697 .65916 .45345 Mtetra
.631 .512 .7 r
.65916 .45345 .6656 .47697 .67744 .47126 .67101 .44873 Mtetra
.634 .519 .705 r
.67101 .44873 .67744 .47126 .6893 .4654 .68291 .44393 Mtetra
.638 .527 .712 r
.68291 .44393 .6893 .4654 .70119 .45942 .69484 .43906 Mtetra
.641 .536 .719 r
.69484 .43906 .70119 .45942 .71311 .45339 .70682 .43415 Mtetra
.645 .545 .728 r
.70682 .43415 .71311 .45339 .72507 .44734 .71884 .42922 Mtetra
.648 .556 .737 r
.71884 .42922 .72507 .44734 .73707 .4413 .7309 .42428 Mtetra
.652 .567 .747 r
.7309 .42428 .73707 .4413 .7491 .43531 .74301 .41936 Mtetra
.655 .579 .757 r
.74301 .41936 .7491 .43531 .76117 .42941 .75516 .41447 Mtetra
.658 .591 .768 r
.75516 .41447 .76117 .42941 .77329 .42361 .76737 .40962 Mtetra
.661 .604 .78 r
.76737 .40962 .77329 .42361 .78546 .41793 .77962 .40481 Mtetra
.664 .617 .792 r
.77962 .40481 .78546 .41793 .79768 .41237 .79193 .40006 Mtetra
.666 .63 .804 r
.79193 .40006 .79768 .41237 .80996 .40696 .80428 .39538 Mtetra
.668 .643 .816 r
.80428 .39538 .80996 .40696 .82228 .40169 .8167 .39075 Mtetra
.669 .655 .828 r
.8167 .39075 .82228 .40169 .83467 .39656 .82917 .38618 Mtetra
.67 .667 .839 r
.82917 .38618 .83467 .39656 .84712 .39155 .84169 .38167 Mtetra
.67 .678 .849 r
.84169 .38167 .84712 .39155 .85962 .38667 .85427 .37721 Mtetra
.67 .688 .858 r
.85427 .37721 .85962 .38667 .87219 .38191 .86692 .3728 Mtetra
.67 .697 .867 r
.86692 .3728 .87219 .38191 .88482 .37724 .87961 .36843 Mtetra
.67 .705 .874 r
.87961 .36843 .88482 .37724 .89751 .37267 .89237 .3641 Mtetra
.669 .712 .88 r
.89237 .3641 .89751 .37267 .91026 .36817 .90519 .3598 Mtetra
.668 .718 .886 r
.90519 .3598 .91026 .36817 .92308 .36374 .91807 .35553 Mtetra
.708 .189 0 r
.32755 .5564 .33426 .56156 .34412 .57193 .33735 .56792 Mtetra
.827 .351 .025 r
.33735 .56792 .34412 .57193 .35395 .58537 .3471 .58279 Mtetra
.836 .374 .104 r
.3471 .58279 .35395 .58537 .36391 .59925 .35699 .59813 Mtetra
.772 .277 .042 r
.35699 .59813 .36391 .59925 .37416 .60974 .36721 .60965 Mtetra
.418 0 0 r
.36721 .60965 .37416 .60974 .38484 .61312 .37791 .61323 Mtetra
.704 .966 .938 r
.37791 .61323 .38484 .61312 .39594 .60754 .3891 .60679 Mtetra
.91 .891 .799 r
.3891 .60679 .39594 .60754 .40735 .59392 .40063 .59139 Mtetra
.916 .821 .738 r
.40063 .59139 .40735 .59392 .41888 .57553 .41231 .57067 Mtetra
.896 .779 .724 r
.41231 .57067 .41888 .57553 .43039 .55635 .42395 .54908 Mtetra
.862 .744 .732 r
.42395 .54908 .43039 .55635 .44178 .53951 .43545 .53006 Mtetra
.816 .709 .747 r
.43545 .53006 .44178 .53951 .45304 .5265 .4468 .51528 Mtetra
.761 .67 .762 r
.4468 .51528 .45304 .5265 .46422 .51732 .45802 .50473 Mtetra
.71 .633 .769 r
.45802 .50473 .46422 .51732 .47536 .51109 .4692 .49745 Mtetra
.672 .603 .77 r
.4692 .49745 .47536 .51109 .4865 .50677 .48036 .49228 Mtetra
.649 .583 .767 r
.48036 .49228 .4865 .50677 .49768 .50346 .49154 .48826 Mtetra
.637 .57 .762 r
.49154 .48826 .49768 .50346 .5089 .50058 .50277 .48477 Mtetra
.632 .561 .757 r
.50277 .48477 .5089 .50058 .52017 .49783 .51404 .48146 Mtetra
.63 .555 .752 r
.51404 .48146 .52017 .49783 .5315 .49503 .52536 .47819 Mtetra
.629 .551 .747 r
.52536 .47819 .5315 .49503 .54287 .49212 .53673 .47488 Mtetra
.629 .548 .744 r
.53673 .47488 .54287 .49212 .5543 .48905 .54814 .4715 Mtetra
.63 .546 .741 r
.54814 .4715 .5543 .48905 .56577 .48582 .55961 .46803 Mtetra
.63 .545 .739 r
.55961 .46803 .56577 .48582 .5773 .4824 .57112 .46448 Mtetra
.631 .545 .738 r
.57112 .46448 .5773 .4824 .58886 .47879 .58268 .46085 Mtetra
.632 .545 .738 r
.58268 .46085 .58886 .47879 .60048 .47499 .59429 .45711 Mtetra
.634 .547 .739 r
.59429 .45711 .60048 .47499 .61213 .47101 .60594 .45329 Mtetra
.635 .549 .74 r
.60594 .45329 .61213 .47101 .62383 .46685 .61764 .44939 Mtetra
.637 .553 .743 r
.61764 .44939 .62383 .46685 .63556 .46253 .62939 .4454 Mtetra
.639 .557 .746 r
.62939 .4454 .63556 .46253 .64734 .45805 .64118 .44134 Mtetra
.641 .562 .75 r
.64118 .44134 .64734 .45805 .65916 .45345 .65301 .43721 Mtetra
.644 .568 .755 r
.65301 .43721 .65916 .45345 .67101 .44873 .66489 .43302 Mtetra
.646 .575 .76 r
.66489 .43302 .67101 .44873 .68291 .44393 .67682 .42878 Mtetra
.648 .582 .766 r
.67682 .42878 .68291 .44393 .69484 .43906 .68879 .4245 Mtetra
.651 .59 .774 r
.68879 .4245 .69484 .43906 .70682 .43415 .70081 .4202 Mtetra
.653 .599 .781 r
.70081 .4202 .70682 .43415 .71884 .42922 .71288 .41587 Mtetra
.656 .608 .789 r
.71288 .41587 .71884 .42922 .7309 .42428 .72499 .41153 Mtetra
.658 .618 .798 r
.72499 .41153 .7309 .42428 .74301 .41936 .73716 .40719 Mtetra
.66 .628 .807 r
.73716 .40719 .74301 .41936 .75516 .41447 .74937 .40285 Mtetra
.662 .638 .816 r
.74937 .40285 .75516 .41447 .76737 .40962 .76164 .39851 Mtetra
.663 .649 .825 r
.76164 .39851 .76737 .40962 .77962 .40481 .77395 .39419 Mtetra
.665 .659 .834 r
.77395 .39419 .77962 .40481 .79193 .40006 .78632 .38988 Mtetra
.666 .669 .843 r
.78632 .38988 .79193 .40006 .80428 .39538 .79874 .38559 Mtetra
.667 .678 .851 r
.79874 .38559 .80428 .39538 .8167 .39075 .81122 .38131 Mtetra
.667 .687 .859 r
.81122 .38131 .8167 .39075 .82917 .38618 .82375 .37705 Mtetra
.667 .695 .866 r
.82375 .37705 .82917 .38618 .84169 .38167 .83634 .37281 Mtetra
.667 .702 .873 r
.83634 .37281 .84169 .38167 .85427 .37721 .84898 .36858 Mtetra
.667 .709 .879 r
.84898 .36858 .85427 .37721 .86692 .3728 .86168 .36436 Mtetra
.667 .714 .884 r
.86168 .36436 .86692 .3728 .87961 .36843 .87444 .36015 Mtetra
.667 .719 .888 r
.87444 .36015 .87961 .36843 .89237 .3641 .88725 .35594 Mtetra
.666 .724 .892 r
.88725 .35594 .89237 .3641 .90519 .3598 .90012 .35174 Mtetra
.666 .727 .895 r
.90012 .35174 .90519 .3598 .91807 .35553 .91306 .34754 Mtetra
.779 .277 0 r
.32075 .55191 .32755 .5564 .33735 .56792 .33046 .56475 Mtetra
.852 .4 .121 r
.33046 .56475 .33735 .56792 .3471 .58279 .34012 .58129 Mtetra
.849 .413 .186 r
.34012 .58129 .3471 .58279 .35699 .59813 .34993 .59833 Mtetra
.792 .33 .144 r
.34993 .59833 .35699 .59813 .36721 .60965 .3601 .61115 Mtetra
.52 0 0 r
.3601 .61115 .36721 .60965 .37791 .61323 .37082 .61518 Mtetra
.634 .964 .856 r
.37082 .61518 .37791 .61323 .3891 .60679 .38209 .60813 Mtetra
.932 .929 .779 r
.38209 .60813 .3891 .60679 .40063 .59139 .39376 .59118 Mtetra
.943 .854 .724 r
.39376 .59118 .40063 .59139 .41231 .57067 .4056 .56836 Mtetra
.927 .815 .715 r
.4056 .56836 .41231 .57067 .42395 .54908 .41739 .54458 Mtetra
.899 .788 .73 r
.41739 .54458 .42395 .54908 .43545 .53006 .429 .52366 Mtetra
.858 .764 .757 r
.429 .52366 .43545 .53006 .4468 .51528 .44044 .5074 Mtetra
.805 .735 .787 r
.44044 .5074 .4468 .51528 .45802 .50473 .45172 .49578 Mtetra
.749 .704 .809 r
.45172 .49578 .45802 .50473 .4692 .49745 .46294 .48776 Mtetra
.704 .676 .821 r
.46294 .48776 .4692 .49745 .48036 .49228 .47413 .48206 Mtetra
.674 .656 .824 r
.47413 .48206 .48036 .49228 .49154 .48826 .48534 .47764 Mtetra
.659 .643 .823 r
.48534 .47764 .49154 .48826 .50277 .48477 .49658 .47382 Mtetra
.653 .635 .82 r
.49658 .47382 .50277 .48477 .51404 .48146 .50787 .47023 Mtetra
.65 .629 .816 r
.50787 .47023 .51404 .48146 .52536 .47819 .5192 .46671 Mtetra
.649 .625 .813 r
.5192 .46671 .52536 .47819 .53673 .47488 .53058 .46318 Mtetra
.649 .622 .81 r
.53058 .46318 .53673 .47488 .54814 .4715 .54201 .45963 Mtetra
.649 .62 .808 r
.54201 .45963 .54814 .4715 .55961 .46803 .55349 .45604 Mtetra
.649 .619 .806 r
.55349 .45604 .55961 .46803 .57112 .46448 .56501 .4524 Mtetra
.649 .618 .805 r
.56501 .4524 .57112 .46448 .58268 .46085 .57659 .44873 Mtetra
.65 .618 .805 r
.57659 .44873 .58268 .46085 .59429 .45711 .58821 .445 Mtetra
.651 .619 .805 r
.58821 .445 .59429 .45711 .60594 .45329 .59988 .44124 Mtetra
.651 .621 .806 r
.59988 .44124 .60594 .45329 .61764 .44939 .61159 .43743 Mtetra
.652 .624 .808 r
.61159 .43743 .61764 .44939 .62939 .4454 .62336 .43357 Mtetra
.654 .627 .811 r
.62336 .43357 .62939 .4454 .64118 .44134 .63517 .42968 Mtetra
.655 .631 .814 r
.63517 .42968 .64118 .44134 .65301 .43721 .64703 .42576 Mtetra
.656 .635 .817 r
.64703 .42576 .65301 .43721 .66489 .43302 .65894 .4218 Mtetra
.657 .64 .821 r
.65894 .4218 .66489 .43302 .67682 .42878 .6709 .41781 Mtetra
.658 .646 .826 r
.6709 .41781 .67682 .42878 .68879 .4245 .68291 .41379 Mtetra
.66 .652 .831 r
.68291 .41379 .68879 .4245 .70081 .4202 .69497 .40976 Mtetra
.661 .658 .836 r
.69497 .40976 .70081 .4202 .71288 .41587 .70708 .4057 Mtetra
.662 .664 .842 r
.70708 .4057 .71288 .41587 .72499 .41153 .71923 .40163 Mtetra
.663 .671 .847 r
.71923 .40163 .72499 .41153 .73716 .40719 .73144 .39755 Mtetra
.664 .678 .853 r
.73144 .39755 .73716 .40719 .74937 .40285 .7437 .39346 Mtetra
.664 .684 .859 r
.7437 .39346 .74937 .40285 .76164 .39851 .75602 .38935 Mtetra
.665 .691 .864 r
.75602 .38935 .76164 .39851 .77395 .39419 .76838 .38525 Mtetra
.665 .697 .869 r
.76838 .38525 .77395 .39419 .78632 .38988 .7808 .38114 Mtetra
.665 .702 .874 r
.7808 .38114 .78632 .38988 .79874 .38559 .79327 .37702 Mtetra
.666 .708 .879 r
.79327 .37702 .79874 .38559 .81122 .38131 .8058 .3729 Mtetra
.666 .713 .883 r
.8058 .3729 .81122 .38131 .82375 .37705 .81838 .36877 Mtetra
.666 .717 .887 r
.81838 .36877 .82375 .37705 .83634 .37281 .83102 .36464 Mtetra
.665 .721 .89 r
.83102 .36464 .83634 .37281 .84898 .36858 .84371 .3605 Mtetra
.665 .724 .893 r
.84371 .3605 .84898 .36858 .86168 .36436 .85646 .35636 Mtetra
.665 .727 .896 r
.85646 .35636 .86168 .36436 .87444 .36015 .86927 .35221 Mtetra
.665 .73 .898 r
.86927 .35221 .87444 .36015 .88725 .35594 .88213 .34805 Mtetra
.665 .732 .9 r
.88213 .34805 .88725 .35594 .90012 .35174 .89505 .34388 Mtetra
.665 .734 .902 r
.89505 .34388 .90012 .35174 .91306 .34754 .90803 .3397 Mtetra
.818 .336 .003 r
.31386 .54774 .32075 .55191 .33046 .56475 .32349 .56201 Mtetra
.866 .434 .179 r
.32349 .56201 .33046 .56475 .34012 .58129 .33304 .58033 Mtetra
.858 .441 .233 r
.33304 .58033 .34012 .58129 .34993 .59833 .34275 .59921 Mtetra
.805 .365 .198 r
.34275 .59921 .34993 .59833 .3601 .61115 .35287 .61348 Mtetra
.568 .04 0 r
.35287 .61348 .3601 .61115 .37082 .61518 .36359 .61811 Mtetra
.591 .942 .792 r
.36359 .61811 .37082 .61518 .38209 .60813 .37495 .61057 Mtetra
.943 .938 .758 r
.37495 .61057 .38209 .60813 .39376 .59118 .38676 .59218 Mtetra
.956 .864 .708 r
.38676 .59218 .39376 .59118 .4056 .56836 .39877 .56738 Mtetra
.942 .828 .703 r
.39877 .56738 .4056 .56836 .41739 .54458 .41071 .54155 Mtetra
.919 .809 .722 r
.41071 .54155 .41739 .54458 .429 .52366 .42246 .51886 Mtetra
.883 .793 .756 r
.42246 .51886 .429 .52366 .44044 .5074 .43398 .50126 Mtetra
.834 .775 .797 r
.43398 .50126 .44044 .5074 .45172 .49578 .44534 .48875 Mtetra
.776 .753 .832 r
.44534 .48875 .45172 .49578 .46294 .48776 .4566 .48016 Mtetra
.725 .729 .854 r
.4566 .48016 .46294 .48776 .47413 .48206 .46783 .47411 Mtetra
.69 .712 .865 r
.46783 .47411 .47413 .48206 .48534 .47764 .47907 .46945 Mtetra
.672 .701 .868 r
.47907 .46945 .48534 .47764 .49658 .47382 .49034 .46545 Mtetra
.664 .694 .868 r
.49034 .46545 .49658 .47382 .50787 .47023 .50165 .46173 Mtetra
.661 .69 .867 r
.50165 .46173 .50787 .47023 .5192 .46671 .51301 .45809 Mtetra
.66 .688 .865 r
.51301 .45809 .5192 .46671 .53058 .46318 .52441 .45446 Mtetra
.66 .686 .864 r
.52441 .45446 .53058 .46318 .54201 .45963 .53586 .45081 Mtetra
.66 .685 .862 r
.53586 .45081 .54201 .45963 .55349 .45604 .54736 .44715 Mtetra
.66 .684 .862 r
.54736 .44715 .55349 .45604 .56501 .4524 .55891 .44346 Mtetra
.66 .683 .861 r
.55891 .44346 .56501 .4524 .57659 .44873 .57051 .43974 Mtetra
.57051 .43974 .57659 .44873 .58821 .445 .58216 .436 Mtetra
.661 .683 .861 r
.58216 .436 .58821 .445 .59988 .44124 .59385 .43223 Mtetra
.661 .684 .861 r
.59385 .43223 .59988 .44124 .61159 .43743 .60559 .42844 Mtetra
.661 .686 .862 r
.60559 .42844 .61159 .43743 .62336 .43357 .61739 .42462 Mtetra
.662 .687 .863 r
.61739 .42462 .62336 .43357 .63517 .42968 .62923 .42078 Mtetra
.662 .689 .865 r
.62923 .42078 .63517 .42968 .64703 .42576 .64112 .41691 Mtetra
.662 .692 .867 r
.64112 .41691 .64703 .42576 .65894 .4218 .65306 .41302 Mtetra
.663 .694 .869 r
.65306 .41302 .65894 .4218 .6709 .41781 .66505 .40911 Mtetra
.663 .697 .871 r
.66505 .40911 .6709 .41781 .68291 .41379 .6771 .40518 Mtetra
.664 .7 .874 r
.6771 .40518 .68291 .41379 .69497 .40976 .68919 .40123 Mtetra
.664 .703 .876 r
.68919 .40123 .69497 .40976 .70708 .4057 .70134 .39727 Mtetra
.664 .706 .879 r
.70134 .39727 .70708 .4057 .71923 .40163 .71353 .39329 Mtetra
.664 .71 .881 r
.71353 .39329 .71923 .40163 .73144 .39755 .72578 .38929 Mtetra
.664 .713 .884 r
.72578 .38929 .73144 .39755 .7437 .39346 .73808 .38528 Mtetra
.665 .716 .887 r
.73808 .38528 .7437 .39346 .75602 .38935 .75044 .38125 Mtetra
.665 .719 .889 r
.75044 .38125 .75602 .38935 .76838 .38525 .76284 .37722 Mtetra
.665 .722 .891 r
.76284 .37722 .76838 .38525 .7808 .38114 .77531 .37317 Mtetra
.665 .724 .894 r
.77531 .37317 .7808 .38114 .79327 .37702 .78782 .3691 Mtetra
.665 .727 .896 r
.78782 .3691 .79327 .37702 .8058 .3729 .80039 .36503 Mtetra
.665 .729 .897 r
.80039 .36503 .8058 .3729 .81838 .36877 .81302 .36094 Mtetra
.664 .731 .899 r
.81302 .36094 .81838 .36877 .83102 .36464 .8257 .35683 Mtetra
.664 .733 .9 r
.8257 .35683 .83102 .36464 .84371 .3605 .83844 .35272 Mtetra
.664 .734 .902 r
.83844 .35272 .84371 .3605 .85646 .35636 .85123 .34859 Mtetra
.664 .735 .903 r
.85123 .34859 .85646 .35636 .86927 .35221 .86408 .34444 Mtetra
.664 .736 .904 r
.86408 .34444 .86927 .35221 .88213 .34805 .87699 .34028 Mtetra
.664 .737 .905 r
.87699 .34028 .88213 .34805 .89505 .34388 .88995 .33611 Mtetra
.664 .738 .905 r
.88995 .33611 .89505 .34388 .90803 .3397 .90297 .33192 Mtetra
.843 .378 .065 r
.30691 .54369 .31386 .54774 .32349 .56201 .31644 .55942 Mtetra
.877 .46 .216 r
.31644 .55942 .32349 .56201 .33304 .58033 .32588 .57956 Mtetra
.867 .463 .263 r
.32588 .57956 .33304 .58033 .34275 .59921 .33547 .60034 Mtetra
.818 .391 .23 r
.33547 .60034 .34275 .59921 .35287 .61348 .34552 .61613 Mtetra
.599 .086 .001 r
.34552 .61613 .35287 .61348 .36359 .61811 .35626 .62142 Mtetra
.591 .939 .771 r
.35626 .62142 .36359 .61811 .37495 .61057 .3677 .61347 Mtetra
.95 .934 .743 r
.3677 .61347 .37495 .61057 .38676 .59218 .37966 .59371 Mtetra
.961 .862 .695 r
.37966 .59371 .38676 .59218 .39877 .56738 .39184 .56698 Mtetra
.949 .829 .691 r
.39184 .56698 .39877 .56738 .41071 .54155 .40395 .53916 Mtetra
.929 .814 .711 r
.40395 .53916 .41071 .54155 .42246 .51886 .41583 .51478 Mtetra
.897 .805 .749 r
.41583 .51478 .42246 .51886 .43398 .50126 .42745 .49595 Mtetra
.851 .795 .796 r
.42745 .49595 .43398 .50126 .44534 .48875 .43888 .48263 Mtetra
.793 .779 .84 r
.43888 .48263 .44534 .48875 .4566 .48016 .45019 .47356 Mtetra
.738 .76 .871 r
.45019 .47356 .4566 .48016 .46783 .47411 .46146 .46724 Mtetra
.699 .745 .887 r
.46146 .46724 .46783 .47411 .47907 .46945 .47273 .46243 Mtetra
.677 .735 .894 r
.47273 .46243 .47907 .46945 .49034 .46545 .48403 .45835 Mtetra
.668 .731 .897 r
.48403 .45835 .49034 .46545 .50165 .46173 .49537 .45455 Mtetra
.664 .728 .897 r
.49537 .45455 .50165 .46173 .51301 .45809 .50676 .45085 Mtetra
.663 .727 .897 r
.50676 .45085 .51301 .45809 .52441 .45446 .51819 .44717 Mtetra
.663 .726 .897 r
.51819 .44717 .52441 .45446 .53586 .45081 .52968 .44348 Mtetra
.663 .726 .896 r
.52968 .44348 .53586 .45081 .54736 .44715 .54121 .43977 Mtetra
.54121 .43977 .54736 .44715 .55891 .44346 .55279 .43604 Mtetra
.663 .725 .895 r
.55279 .43604 .55891 .44346 .57051 .43974 .56441 .43229 Mtetra
.664 .725 .895 r
.56441 .43229 .57051 .43974 .58216 .436 .57609 .42851 Mtetra
.57609 .42851 .58216 .436 .59385 .43223 .58782 .42471 Mtetra
.58782 .42471 .59385 .43223 .60559 .42844 .59959 .4209 Mtetra
.59959 .4209 .60559 .42844 .61739 .42462 .61141 .41706 Mtetra
.664 .726 .895 r
.61141 .41706 .61739 .42462 .62923 .42078 .62329 .4132 Mtetra
.62329 .4132 .62923 .42078 .64112 .41691 .63521 .40932 Mtetra
.664 .727 .896 r
.63521 .40932 .64112 .41691 .65306 .41302 .64719 .40542 Mtetra
.64719 .40542 .65306 .41302 .66505 .40911 .65922 .40151 Mtetra
.665 .728 .897 r
.65922 .40151 .66505 .40911 .6771 .40518 .67129 .39757 Mtetra
.665 .729 .897 r
.67129 .39757 .6771 .40518 .68919 .40123 .68342 .39362 Mtetra
.665 .73 .898 r
.68342 .39362 .68919 .40123 .70134 .39727 .6956 .38966 Mtetra
.665 .731 .899 r
.6956 .38966 .70134 .39727 .71353 .39329 .70784 .38568 Mtetra
.664 .732 .9 r
.70784 .38568 .71353 .39329 .72578 .38929 .72012 .38168 Mtetra
.72012 .38168 .72578 .38929 .73808 .38528 .73246 .37767 Mtetra
.664 .733 .901 r
.73246 .37767 .73808 .38528 .75044 .38125 .74485 .37364 Mtetra
.664 .734 .902 r
.74485 .37364 .75044 .38125 .76284 .37722 .7573 .3696 Mtetra
.664 .735 .903 r
.7573 .3696 .76284 .37722 .77531 .37317 .7698 .36555 Mtetra
.664 .736 .903 r
.7698 .36555 .77531 .37317 .78782 .3691 .78236 .36147 Mtetra
.664 .737 .904 r
.78236 .36147 .78782 .3691 .80039 .36503 .79497 .35739 Mtetra
.79497 .35739 .80039 .36503 .81302 .36094 .80763 .35329 Mtetra
.664 .738 .905 r
.80763 .35329 .81302 .36094 .8257 .35683 .82036 .34917 Mtetra
.82036 .34917 .8257 .35683 .83844 .35272 .83313 .34504 Mtetra
.664 .739 .906 r
.83313 .34504 .83844 .35272 .85123 .34859 .84597 .34089 Mtetra
.84597 .34089 .85123 .34859 .86408 .34444 .85886 .33672 Mtetra
.664 .74 .906 r
.85886 .33672 .86408 .34444 .87699 .34028 .87181 .33254 Mtetra
.664 .74 .907 r
.87181 .33254 .87699 .34028 .88995 .33611 .88482 .32834 Mtetra
.88482 .32834 .88995 .33611 .90297 .33192 .89788 .32412 Mtetra
.86 .411 .111 r
.29989 .53964 .30691 .54369 .31644 .55942 .30932 .55684 Mtetra
.886 .48 .244 r
.30932 .55684 .31644 .55942 .32588 .57956 .31863 .57881 Mtetra
.875 .481 .284 r
.31863 .57881 .32588 .57956 .33547 .60034 .32811 .6015 Mtetra
.829 .413 .251 r
.32811 .6015 .33547 .60034 .34552 .61613 .33809 .61882 Mtetra
.624 .119 .029 r
.33809 .61882 .34552 .61613 .35626 .62142 .34882 .62482 Mtetra
.615 .948 .776 r
.34882 .62482 .35626 .62142 .3677 .61347 .36035 .6165 Mtetra
.956 .926 .732 r
.36035 .6165 .3677 .61347 .37966 .59371 .37246 .59542 Mtetra
.964 .855 .685 r
.37246 .59542 .37966 .59371 .39184 .56698 .38482 .56684 Mtetra
.953 .826 .681 r
.38482 .56684 .39184 .56698 .40395 .53916 .3971 .53712 Mtetra
.935 .814 .702 r
.3971 .53712 .40395 .53916 .41583 .51478 .40912 .51113 Mtetra
.906 .81 .742 r
.40912 .51113 .41583 .51478 .42745 .49595 .42085 .49113 Mtetra
.862 .806 .793 r
.42085 .49113 .42745 .49595 .43888 .48263 .43236 .47706 Mtetra
.805 .796 .844 r
.43236 .47706 .43888 .48263 .45019 .47356 .44372 .46759 Mtetra
.746 .781 .881 r
.44372 .46759 .45019 .47356 .46146 .46724 .45503 .46106 Mtetra
.703 .768 .902 r
.45503 .46106 .46146 .46724 .47273 .46243 .46634 .45617 Mtetra
.679 .76 .913 r
.46634 .45617 .47273 .46243 .48403 .45835 .47767 .45204 Mtetra
.668 .757 .917 r
.47767 .45204 .48403 .45835 .49537 .45455 .48904 .44822 Mtetra
.664 .756 .919 r
.48904 .44822 .49537 .45455 .50676 .45085 .50046 .44451 Mtetra
.663 .756 .92 r
.50046 .44451 .50676 .45085 .51819 .44717 .51193 .44081 Mtetra
.51193 .44081 .51819 .44717 .52968 .44348 .52344 .4371 Mtetra
.663 .757 .92 r
.52344 .4371 .52968 .44348 .54121 .43977 .53501 .43336 Mtetra
.53501 .43336 .54121 .43977 .55279 .43604 .54662 .42959 Mtetra
.664 .757 .919 r
.54662 .42959 .55279 .43604 .56441 .43229 .55828 .4258 Mtetra
.664 .756 .919 r
.55828 .4258 .56441 .43229 .57609 .42851 .56999 .42197 Mtetra
.665 .756 .918 r
.56999 .42197 .57609 .42851 .58782 .42471 .58175 .41813 Mtetra
.665 .755 .918 r
.58175 .41813 .58782 .42471 .59959 .4209 .59356 .41425 Mtetra
.665 .754 .917 r
.59356 .41425 .59959 .4209 .61141 .41706 .60542 .41035 Mtetra
.665 .754 .916 r
.60542 .41035 .61141 .41706 .62329 .4132 .61733 .40643 Mtetra
.666 .753 .915 r
.61733 .40643 .62329 .4132 .63521 .40932 .62929 .40249 Mtetra
.666 .752 .914 r
.62929 .40249 .63521 .40932 .64719 .40542 .6413 .39852 Mtetra
.666 .751 .914 r
.6413 .39852 .64719 .40542 .65922 .40151 .65336 .39454 Mtetra
.666 .749 .913 r
.65336 .39454 .65922 .40151 .67129 .39757 .66547 .39055 Mtetra
.666 .748 .912 r
.66547 .39055 .67129 .39757 .68342 .39362 .67764 .38653 Mtetra
.666 .747 .911 r
.67764 .38653 .68342 .39362 .6956 .38966 .68985 .38251 Mtetra
.665 .746 .911 r
.68985 .38251 .6956 .38966 .70784 .38568 .70212 .37847 Mtetra
.665 .746 .91 r
.70212 .37847 .70784 .38568 .72012 .38168 .71444 .37442 Mtetra
.665 .745 .91 r
.71444 .37442 .72012 .38168 .73246 .37767 .72682 .37035 Mtetra
.665 .744 .909 r
.72682 .37035 .73246 .37767 .74485 .37364 .73925 .36628 Mtetra
.73925 .36628 .74485 .37364 .7573 .3696 .75173 .36219 Mtetra
.665 .743 .909 r
.75173 .36219 .7573 .3696 .7698 .36555 .76427 .35809 Mtetra
.665 .743 .908 r
.76427 .35809 .7698 .36555 .78236 .36147 .77686 .35398 Mtetra
.664 .742 .908 r
.77686 .35398 .78236 .36147 .79497 .35739 .78951 .34985 Mtetra
.78951 .34985 .79497 .35739 .80763 .35329 .80222 .34571 Mtetra
.80222 .34571 .80763 .35329 .82036 .34917 .81498 .34155 Mtetra
.81498 .34155 .82036 .34917 .83313 .34504 .8278 .33738 Mtetra
.664 .741 .908 r
.8278 .33738 .83313 .34504 .84597 .34089 .84067 .3332 Mtetra
.84067 .3332 .84597 .34089 .85886 .33672 .85361 .329 Mtetra
.85361 .329 .85886 .33672 .87181 .33254 .8666 .32478 Mtetra
.8666 .32478 .87181 .33254 .88482 .32834 .87965 .32055 Mtetra
.87965 .32055 .88482 .32834 .89788 .32412 .89275 .31629 Mtetra
.873 .437 .148 r
.29281 .53558 .29989 .53964 .30932 .55684 .30213 .55421 Mtetra
.893 .497 .266 r
.30213 .55421 .30932 .55684 .31863 .57881 .31131 .57799 Mtetra
.882 .496 .301 r
.31131 .57799 .31863 .57881 .32811 .6015 .32066 .60258 Mtetra
.84 .432 .268 r
.32066 .60258 .32811 .6015 .33809 .61882 .33056 .62145 Mtetra
.647 .148 .05 r
.33056 .62145 .33809 .61882 .34882 .62482 .34129 .62819 Mtetra
.639 .959 .786 r
.34129 .62819 .34882 .62482 .36035 .6165 .3529 .61957 Mtetra
.96 .917 .723 r
.3529 .61957 .36035 .6165 .37246 .59542 .36517 .59728 Mtetra
.966 .849 .676 r
.36517 .59728 .37246 .59542 .38482 .56684 .37771 .56696 Mtetra
.956 .823 .673 r
.37771 .56696 .38482 .56684 .3971 .53712 .39016 .53546 Mtetra
.94 .815 .694 r
.39016 .53546 .3971 .53712 .40912 .51113 .40233 .50798 Mtetra
.915 .817 .735 r
.40233 .50798 .40912 .51113 .42085 .49113 .41417 .48694 Mtetra
.874 .82 .792 r
.41417 .48694 .42085 .49113 .43236 .47706 .42575 .47224 Mtetra
.817 .819 .851 r
.42575 .47224 .43236 .47706 .44372 .46759 .43717 .46245 Mtetra
.754 .81 .897 r
.43717 .46245 .44372 .46759 .45503 .46106 .44852 .45582 Mtetra
.704 .801 .925 r
.44852 .45582 .45503 .46106 .46634 .45617 .45987 .45091 Mtetra
.675 .795 .939 r
.45987 .45091 .46634 .45617 .47767 .45204 .47124 .44683 Mtetra
.662 .794 .945 r
.47124 .44683 .47767 .45204 .48904 .44822 .48265 .44306 Mtetra
.657 .796 .949 r
.48265 .44306 .48904 .44822 .50046 .44451 .4941 .43939 Mtetra
.655 .798 .951 r
.4941 .43939 .50046 .44451 .51193 .44081 .5056 .43572 Mtetra
.656 .8 .952 r
.5056 .43572 .51193 .44081 .52344 .4371 .51716 .43202 Mtetra
.657 .802 .952 r
.51716 .43202 .52344 .4371 .53501 .43336 .52876 .42827 Mtetra
.658 .803 .952 r
.52876 .42827 .53501 .43336 .54662 .42959 .54041 .42447 Mtetra
.659 .803 .952 r
.54041 .42447 .54662 .42959 .55828 .4258 .55211 .42063 Mtetra
.661 .802 .951 r
.55211 .42063 .55828 .4258 .56999 .42197 .56386 .41673 Mtetra
.662 .801 .949 r
.56386 .41673 .56999 .42197 .58175 .41813 .57566 .41279 Mtetra
.664 .799 .948 r
.57566 .41279 .58175 .41813 .59356 .41425 .58751 .40881 Mtetra
.665 .797 .945 r
.58751 .40881 .59356 .41425 .60542 .41035 .5994 .40479 Mtetra
.666 .794 .943 r
.5994 .40479 .60542 .41035 .61733 .40643 .61135 .40074 Mtetra
.667 .791 .94 r
.61135 .40074 .61733 .40643 .62929 .40249 .62335 .39665 Mtetra
.668 .787 .938 r
.62335 .39665 .62929 .40249 .6413 .39852 .63539 .39254 Mtetra
.668 .783 .935 r
.63539 .39254 .6413 .39852 .65336 .39454 .64749 .38841 Mtetra
.669 .779 .932 r
.64749 .38841 .65336 .39454 .66547 .39055 .65964 .38426 Mtetra
.669 .775 .929 r
.65964 .38426 .66547 .39055 .67764 .38653 .67183 .3801 Mtetra
.669 .771 .927 r
.67183 .3801 .67764 .38653 .68985 .38251 .68409 .37593 Mtetra
.668 .767 .924 r
.68409 .37593 .68985 .38251 .70212 .37847 .69639 .37175 Mtetra
.668 .764 .922 r
.69639 .37175 .70212 .37847 .71444 .37442 .70874 .36757 Mtetra
.668 .761 .92 r
.70874 .36757 .71444 .37442 .72682 .37035 .72115 .36339 Mtetra
.667 .758 .918 r
.72115 .36339 .72682 .37035 .73925 .36628 .73362 .3592 Mtetra
.667 .755 .916 r
.73362 .3592 .73925 .36628 .75173 .36219 .74614 .35501 Mtetra
.667 .753 .915 r
.74614 .35501 .75173 .36219 .76427 .35809 .75871 .35081 Mtetra
.666 .751 .913 r
.75871 .35081 .76427 .35809 .77686 .35398 .77134 .34661 Mtetra
.666 .749 .912 r
.77134 .34661 .77686 .35398 .78951 .34985 .78403 .34241 Mtetra
.665 .747 .911 r
.78403 .34241 .78951 .34985 .80222 .34571 .79677 .3382 Mtetra
.665 .746 .911 r
.79677 .3382 .80222 .34571 .81498 .34155 .80957 .33398 Mtetra
.665 .745 .91 r
.80957 .33398 .81498 .34155 .8278 .33738 .82243 .32975 Mtetra
.665 .744 .91 r
.82243 .32975 .8278 .33738 .84067 .3332 .83534 .32551 Mtetra
.664 .744 .909 r
.83534 .32551 .84067 .3332 .85361 .329 .84831 .32126 Mtetra
.664 .743 .909 r
.84831 .32126 .85361 .329 .8666 .32478 .86135 .31699 Mtetra
.86135 .31699 .8666 .32478 .87965 .32055 .87444 .31272 Mtetra
.664 .742 .908 r
.87444 .31272 .87965 .32055 .89275 .31629 .88758 .30842 Mtetra
.883 .459 .18 r
.28566 .53153 .29281 .53558 .30213 .55421 .29487 .55158 Mtetra
.898 .511 .285 r
.29487 .55158 .30213 .55421 .31131 .57799 .30391 .57714 Mtetra
.888 .509 .315 r
.30391 .57714 .31131 .57799 .32066 .60258 .31313 .60362 Mtetra
.849 .449 .283 r
.31313 .60362 .32066 .60258 .33056 .62145 .32293 .62406 Mtetra
.669 .178 .074 r
.32293 .62406 .33056 .62145 .34129 .62819 .33366 .63161 Mtetra
.648 .962 .788 r
.33366 .63161 .34129 .62819 .3529 .61957 .34535 .62282 Mtetra
.963 .912 .716 r
.34535 .62282 .3529 .61957 .36517 .59728 .35777 .59948 Mtetra
.968 .847 .669 r
.35777 .59948 .36517 .59728 .37771 .56696 .37049 .56764 Mtetra
.96 .825 .665 r
.37049 .56764 .37771 .56696 .39016 .53546 .38312 .53458 Mtetra
.948 .822 .687 r
.38312 .53458 .39016 .53546 .40233 .50798 .39544 .50584 Mtetra
.927 .832 .731 r
.39544 .50584 .40233 .50798 .41417 .48694 .40739 .48395 Mtetra
.891 .849 .796 r
.40739 .48395 .41417 .48694 .42575 .47224 .41904 .46882 Mtetra
.831 .863 .869 r
.41904 .46882 .42575 .47224 .43717 .46245 .43052 .4589 Mtetra
.757 .867 .929 r
.43052 .4589 .43717 .46245 .44852 .45582 .44192 .45233 Mtetra
.689 .863 .965 r
.44192 .45233 .44852 .45582 .45987 .45091 .4533 .44758 Mtetra
.644 .861 .981 r
.4533 .44758 .45987 .45091 .47124 .44683 .46471 .44368 Mtetra
.621 .863 .988 r
.46471 .44368 .47124 .44683 .48265 .44306 .47616 .44011 Mtetra
.609 .867 .991 r
.47616 .44011 .48265 .44306 .4941 .43939 .48766 .4366 Mtetra
.604 .873 .992 r
.48766 .4366 .4941 .43939 .5056 .43572 .4992 .43306 Mtetra
.603 .878 .992 r
.4992 .43306 .5056 .43572 .51716 .43202 .5108 .42944 Mtetra
.604 .882 .991 r
.5108 .42944 .51716 .43202 .52876 .42827 .52245 .42573 Mtetra
.607 .885 .991 r
.52245 .42573 .52876 .42827 .54041 .42447 .53415 .42192 Mtetra
.611 .887 .99 r
.53415 .42192 .54041 .42447 .55211 .42063 .5459 .41802 Mtetra
.618 .888 .989 r
.5459 .41802 .55211 .42063 .56386 .41673 .5577 .41401 Mtetra
.625 .887 .988 r
.5577 .41401 .56386 .41673 .57566 .41279 .56955 .40992 Mtetra
.633 .885 .987 r
.56955 .40992 .57566 .41279 .58751 .40881 .58144 .40574 Mtetra
.641 .881 .985 r
.58144 .40574 .58751 .40881 .5994 .40479 .59338 .40149 Mtetra
.648 .875 .983 r
.59338 .40149 .5994 .40479 .61135 .40074 .60537 .39717 Mtetra
.655 .868 .98 r
.60537 .39717 .61135 .40074 .62335 .39665 .61741 .39279 Mtetra
.661 .86 .975 r
.61741 .39279 .62335 .39665 .63539 .39254 .6295 .38838 Mtetra
.665 .851 .971 r
.6295 .38838 .63539 .39254 .64749 .38841 .64163 .38393 Mtetra
.669 .841 .966 r
.64163 .38393 .64749 .38841 .65964 .38426 .65381 .37946 Mtetra
.671 .831 .96 r
.65381 .37946 .65964 .38426 .67183 .3801 .66605 .37499 Mtetra
.673 .821 .954 r
.66605 .37499 .67183 .3801 .68409 .37593 .67833 .37051 Mtetra
.674 .811 .949 r
.67833 .37051 .68409 .37593 .69639 .37175 .69066 .36604 Mtetra
.674 .802 .943 r
.69066 .36604 .69639 .37175 .70874 .36757 .70305 .36159 Mtetra
.673 .793 .938 r
.70305 .36159 .70874 .36757 .72115 .36339 .71549 .35715 Mtetra
.673 .785 .934 r
.71549 .35715 .72115 .36339 .73362 .3592 .72798 .35272 Mtetra
.672 .778 .929 r
.72798 .35272 .73362 .3592 .74614 .35501 .74053 .34832 Mtetra
.671 .772 .926 r
.74053 .34832 .74614 .35501 .75871 .35081 .75314 .34393 Mtetra
.67 .766 .922 r
.75314 .34393 .75871 .35081 .77134 .34661 .7658 .33956 Mtetra
.669 .762 .92 r
.7658 .33956 .77134 .34661 .78403 .34241 .77852 .33521 Mtetra
.668 .758 .917 r
.77852 .33521 .78403 .34241 .79677 .3382 .7913 .33087 Mtetra
.667 .754 .915 r
.7913 .33087 .79677 .3382 .80957 .33398 .80413 .32653 Mtetra
.667 .752 .914 r
.80413 .32653 .80957 .33398 .82243 .32975 .81702 .3222 Mtetra
.666 .749 .912 r
.81702 .3222 .82243 .32975 .83534 .32551 .82998 .31787 Mtetra
.666 .748 .911 r
.82998 .31787 .83534 .32551 .84831 .32126 .84299 .31355 Mtetra
.665 .746 .911 r
.84299 .31355 .84831 .32126 .86135 .31699 .85606 .30921 Mtetra
.665 .745 .91 r
.85606 .30921 .86135 .31699 .87444 .31272 .86919 .30487 Mtetra
.665 .744 .909 r
.86919 .30487 .87444 .31272 .88758 .30842 .88238 .30052 Mtetra
.89 .477 .208 r
.27844 .52755 .28566 .53153 .29487 .55158 .28753 .549 Mtetra
.902 .523 .302 r
.28753 .549 .29487 .55158 .30391 .57714 .29642 .57633 Mtetra
.892 .521 .329 r
.29642 .57633 .30391 .57714 .31313 .60362 .3055 .6047 Mtetra
.856 .464 .299 r
.3055 .6047 .31313 .60362 .32293 .62406 .3152 .62676 Mtetra
.692 .211 .105 r
.3152 .62676 .32293 .62406 .33366 .63161 .32591 .63526 Mtetra
.627 .952 .773 r
.32591 .63526 .33366 .63161 .34535 .62282 .33767 .62651 Mtetra
.965 .913 .709 r
.33767 .62651 .34535 .62282 .35777 .59948 .35023 .60241 Mtetra
.972 .851 .662 r
.35023 .60241 .35777 .59948 .37049 .56764 .36313 .56937 Mtetra
.967 .833 .658 r
.36313 .56937 .37049 .56764 .38312 .53458 .37594 .5351 Mtetra
.959 .838 .681 r
.37594 .5351 .38312 .53458 .39544 .50584 .3884 .50544 Mtetra
.944 .862 .729 r
.3884 .50544 .39544 .50584 .40739 .48395 .40045 .48305 Mtetra
.91 .902 .804 r
.40045 .48305 .40739 .48395 .41904 .46882 .41219 .46781 Mtetra
.835 .943 .894 r
.41219 .46781 .41904 .46882 .43052 .4589 .42372 .45808 Mtetra
.703 .952 .953 r
.42372 .45808 .43052 .4589 .44192 .45233 .43516 .45187 Mtetra
.548 .916 .949 r
.43516 .45187 .44192 .45233 .4533 .44758 .44659 .44758 Mtetra
.422 .864 .902 r
.44659 .44758 .4533 .44758 .46471 .44368 .45804 .44416 Mtetra
.337 .818 .845 r
.45804 .44416 .46471 .44368 .47616 .44011 .46954 .44104 Mtetra
.281 .783 .792 r
.46954 .44104 .47616 .44011 .48766 .4366 .48109 .43793 Mtetra
.245 .756 .746 r
.48109 .43793 .48766 .4366 .4992 .43306 .49269 .43471 Mtetra
.222 .736 .709 r
.49269 .43471 .4992 .43306 .5108 .42944 .50435 .43134 Mtetra
.212 .726 .684 r
.50435 .43134 .5108 .42944 .52245 .42573 .51607 .42778 Mtetra
0 0 0 r
.51607 .42778 .52245 .42573 .53415 .42192 .52783 .42403 Mtetra
.226 .732 .672 r
.52783 .42403 .53415 .42192 .5459 .41802 .53965 .42007 Mtetra
.249 .749 .685 r
.53965 .42007 .5459 .41802 .5577 .41401 .55151 .41591 Mtetra
.283 .773 .71 r
.55151 .41591 .5577 .41401 .56955 .40992 .56342 .41157 Mtetra
.325 .804 .744 r
.56342 .41157 .56955 .40992 .58144 .40574 .57538 .40705 Mtetra
.373 .837 .786 r
.57538 .40705 .58144 .40574 .59338 .40149 .58738 .40238 Mtetra
.426 .87 .83 r
.58738 .40238 .59338 .40149 .60537 .39717 .59943 .39757 Mtetra
.479 .898 .874 r
.59943 .39757 .60537 .39717 .61741 .39279 .61152 .39265 Mtetra
.529 .918 .912 r
.61152 .39265 .61741 .39279 .6295 .38838 .62365 .38765 Mtetra
.573 .929 .943 r
.62365 .38765 .6295 .38838 .64163 .38393 .63582 .38259 Mtetra
.609 .931 .963 r
.63582 .38259 .64163 .38393 .65381 .37946 .64804 .37751 Mtetra
.636 .924 .975 r
.64804 .37751 .65381 .37946 .66605 .37499 .66031 .37242 Mtetra
.655 .911 .98 r
.66031 .37242 .66605 .37499 .67833 .37051 .67262 .36734 Mtetra
.667 .895 .979 r
.67262 .36734 .67833 .37051 .69066 .36604 .68499 .3623 Mtetra
.675 .877 .974 r
.68499 .3623 .69066 .36604 .70305 .36159 .6974 .35729 Mtetra
.679 .859 .968 r
.6974 .35729 .70305 .36159 .71549 .35715 .70986 .35235 Mtetra
.681 .841 .96 r
.70986 .35235 .71549 .35715 .72798 .35272 .72238 .34746 Mtetra
.681 .825 .953 r
.72238 .34746 .72798 .35272 .74053 .34832 .73495 .34264 Mtetra
.68 .811 .946 r
.73495 .34264 .74053 .34832 .75314 .34393 .74758 .33788 Mtetra
.678 .799 .939 r
.74758 .33788 .75314 .34393 .7658 .33956 .76027 .33318 Mtetra
.676 .788 .933 r
.76027 .33318 .7658 .33956 .77852 .33521 .77301 .32854 Mtetra
.675 .779 .928 r
.77301 .32854 .77852 .33521 .7913 .33087 .78582 .32395 Mtetra
.673 .771 .924 r
.78582 .32395 .7913 .33087 .80413 .32653 .79868 .3194 Mtetra
.671 .765 .921 r
.79868 .3194 .80413 .32653 .81702 .3222 .8116 .31489 Mtetra
.67 .76 .918 r
.8116 .31489 .81702 .3222 .82998 .31787 .82459 .3104 Mtetra
.669 .756 .916 r
.82459 .3104 .82998 .31787 .84299 .31355 .83763 .30594 Mtetra
.667 .752 .914 r
.83763 .30594 .84299 .31355 .85606 .30921 .85074 .3015 Mtetra
.667 .75 .912 r
.85074 .3015 .85606 .30921 .86919 .30487 .86391 .29706 Mtetra
.666 .748 .911 r
.86391 .29706 .86919 .30487 .88238 .30052 .87713 .29263 Mtetra
.896 .492 .233 r
.27114 .52368 .27844 .52755 .28753 .549 .2801 .54653 Mtetra
.905 .533 .318 r
.2801 .54653 .28753 .549 .29642 .57633 .28885 .57561 Mtetra
.895 .53 .342 r
.28885 .57561 .29642 .57633 .3055 .6047 .29777 .60589 Mtetra
.862 .477 .314 r
.29777 .60589 .3055 .6047 .3152 .62676 .30736 .62966 Mtetra
.714 .247 .14 r
.30736 .62966 .3152 .62676 .32591 .63526 .31803 .63928 Mtetra
.567 .922 .737 r
.31803 .63928 .32591 .63526 .33767 .62651 .32985 .63087 Mtetra
.967 .921 .703 r
.32985 .63087 .33767 .62651 .35023 .60241 .34254 .6064 Mtetra
.977 .86 .656 r
.34254 .6064 .35023 .60241 .36313 .56937 .3556 .57262 Mtetra
.975 .847 .651 r
.3556 .57262 .36313 .56937 .37594 .5351 .36857 .53762 Mtetra
.971 .863 .673 r
.36857 .53762 .37594 .5351 .3884 .50544 .38116 .50752 Mtetra
.959 .906 .723 r
.38116 .50752 .3884 .50544 .40045 .48305 .39332 .48511 Mtetra
.908 .973 .798 r
.39332 .48511 .40045 .48305 .41219 .46781 .40513 .47025 Mtetra
.711 .986 .828 r
.40513 .47025 .41219 .46781 .42372 .45808 .41671 .46118 Mtetra
.318 .783 .662 r
.41671 .46118 .42372 .45808 .43516 .45187 .4282 .45582 Mtetra
0 0 0 r
.4282 .45582 .43516 .45187 .44659 .44758 .43967 .45246 Mtetra
.158 0 0 r
.43967 .45246 .44659 .44758 .45804 .44416 .45117 .44996 Mtetra
.232 0 0 r
.45117 .44996 .45804 .44416 .46954 .44104 .46272 .44772 Mtetra
.268 0 0 r
.46272 .44772 .46954 .44104 .48109 .43793 .47434 .4454 Mtetra
.285 0 0 r
.47434 .4454 .48109 .43793 .49269 .43471 .48602 .44285 Mtetra
.292 0 0 r
.48602 .44285 .49269 .43471 .50435 .43134 .49776 .44001 Mtetra
.291 0 .008 r
.49776 .44001 .50435 .43134 .51607 .42778 .50956 .43682 Mtetra
.284 0 .018 r
.50956 .43682 .51607 .42778 .52783 .42403 .52142 .43325 Mtetra
.271 0 .018 r
.52142 .43325 .52783 .42403 .53965 .42007 .53333 .4293 Mtetra
.253 0 .009 r
.53333 .4293 .53965 .42007 .55151 .41591 .54529 .42497 Mtetra
.229 0 0 r
.54529 .42497 .55151 .41591 .56342 .41157 .55729 .42027 Mtetra
.198 0 0 r
.55729 .42027 .56342 .41157 .57538 .40705 .56933 .41523 Mtetra
.158 0 0 r
.56933 .41523 .57538 .40705 .58738 .40238 .58142 .40988 Mtetra
.109 0 0 r
.58142 .40988 .58738 .40238 .59943 .39757 .59354 .40427 Mtetra
.047 0 0 r
.59354 .40427 .59943 .39757 .61152 .39265 .6057 .39844 Mtetra
0 0 0 r
.6057 .39844 .61152 .39265 .62365 .38765 .61789 .39244 Mtetra
.61789 .39244 .62365 .38765 .63582 .38259 .63012 .38634 Mtetra
.63012 .38634 .63582 .38259 .64804 .37751 .64238 .38018 Mtetra
.336 .791 .653 r
.64238 .38018 .64804 .37751 .66031 .37242 .65468 .374 Mtetra
.443 .872 .77 r
.65468 .374 .66031 .37242 .67262 .36734 .66702 .36786 Mtetra
.534 .924 .862 r
.66702 .36786 .67262 .36734 .68499 .3623 .67941 .36179 Mtetra
.601 .946 .924 r
.67941 .36179 .68499 .3623 .6974 .35729 .69184 .35582 Mtetra
.645 .944 .958 r
.69184 .35582 .6974 .35729 .70986 .35235 .70432 .34997 Mtetra
.671 .927 .972 r
.70432 .34997 .70986 .35235 .72238 .34746 .71685 .34426 Mtetra
.684 .904 .974 r
.71685 .34426 .72238 .34746 .73495 .34264 .72943 .33868 Mtetra
.689 .879 .969 r
.72943 .33868 .73495 .34264 .74758 .33788 .74207 .33325 Mtetra
.69 .856 .962 r
.74207 .33325 .74758 .33788 .76027 .33318 .75477 .32796 Mtetra
.688 .835 .954 r
.75477 .32796 .76027 .33318 .77301 .32854 .76753 .32281 Mtetra
.686 .817 .946 r
.76753 .32281 .77301 .32854 .78582 .32395 .78035 .31777 Mtetra
.683 .802 .938 r
.78035 .31777 .78582 .32395 .79868 .3194 .79323 .31285 Mtetra
.68 .789 .932 r
.79323 .31285 .79868 .3194 .8116 .31489 .80618 .30801 Mtetra
.677 .779 .927 r
.80618 .30801 .8116 .31489 .82459 .3104 .81919 .30326 Mtetra
.674 .77 .923 r
.81919 .30326 .82459 .3104 .83763 .30594 .83226 .29858 Mtetra
.672 .763 .919 r
.83226 .29858 .83763 .30594 .85074 .3015 .8454 .29395 Mtetra
.67 .758 .916 r
.8454 .29395 .85074 .3015 .86391 .29706 .8586 .28936 Mtetra
.669 .754 .914 r
.8586 .28936 .86391 .29706 .87713 .29263 .87186 .2848 Mtetra
.9 .504 .253 r
.26376 .51989 .27114 .52368 .2801 .54653 .2726 .54409 Mtetra
.907 .542 .33 r
.2726 .54409 .2801 .54653 .28885 .57561 .28119 .57489 Mtetra
.898 .539 .352 r
.28119 .57489 .28885 .57561 .29777 .60589 .28995 .60707 Mtetra
.868 .49 .326 r
.28995 .60707 .29777 .60589 .30736 .62966 .29942 .63261 Mtetra
.737 .281 .169 r
.29942 .63261 .30736 .62966 .31803 .63928 .31003 .64356 Mtetra
.484 .875 .694 r
.31003 .64356 .31803 .63928 .32985 .63087 .32189 .63581 Mtetra
.966 .929 .7 r
.32189 .63581 .32985 .63087 .34254 .6064 .33468 .61142 Mtetra
.981 .871 .651 r
.33468 .61142 .34254 .6064 .3556 .57262 .34789 .57743 Mtetra
.982 .863 .644 r
.34789 .57743 .3556 .57262 .36857 .53762 .36101 .54226 Mtetra
.98 .89 .663 r
.36101 .54226 .36857 .53762 .38116 .50752 .37372 .5123 Mtetra
.955 .95 .702 r
.37372 .5123 .38116 .50752 .39332 .48511 .38596 .49044 Mtetra
.789 .979 .702 r
.38596 .49044 .39332 .48511 .40513 .47025 .39782 .47652 Mtetra
0 0 0 r
.39782 .47652 .40513 .47025 .41671 .46118 .40945 .4687 Mtetra
.185 0 0 r
.40945 .4687 .41671 .46118 .4282 .45582 .42097 .46478 Mtetra
.359 0 .054 r
.42097 .46478 .4282 .45582 .43967 .45246 .43249 .46293 Mtetra
.423 .004 .137 r
.43249 .46293 .43967 .45246 .45117 .44996 .44404 .46195 Mtetra
.447 .046 .186 r
.44404 .46195 .45117 .44996 .46272 .44772 .45566 .46115 Mtetra
.454 .068 .218 r
.45566 .46115 .46272 .44772 .47434 .4454 .46735 .46015 Mtetra
.453 .08 .24 r
.46735 .46015 .47434 .4454 .48602 .44285 .47912 .45876 Mtetra
.449 .085 .254 r
.47912 .45876 .48602 .44285 .49776 .44001 .49097 .45686 Mtetra
.441 .085 .264 r
.49097 .45686 .49776 .44001 .50956 .43682 .50288 .45438 Mtetra
.431 .081 .268 r
.50288 .45438 .50956 .43682 .52142 .43325 .51486 .45125 Mtetra
.419 .073 .268 r
.51486 .45125 .52142 .43325 .53333 .4293 .5269 .44746 Mtetra
.405 .06 .264 r
.5269 .44746 .53333 .4293 .54529 .42497 .53898 .443 Mtetra
.388 .044 .256 r
.53898 .443 .54529 .42497 .55729 .42027 .55111 .43788 Mtetra
.368 .023 .243 r
.55111 .43788 .55729 .42027 .56933 .41523 .56328 .43215 Mtetra
.345 0 .224 r
.56328 .43215 .56933 .41523 .58142 .40988 .57548 .42586 Mtetra
.317 0 .199 r
.57548 .42586 .58142 .40988 .59354 .40427 .58771 .41909 Mtetra
.284 0 .166 r
.58771 .41909 .59354 .40427 .6057 .39844 .59996 .41192 Mtetra
.244 0 .123 r
.59996 .41192 .6057 .39844 .61789 .39244 .61223 .40445 Mtetra
.195 0 .067 r
.61223 .40445 .61789 .39244 .63012 .38634 .62453 .39676 Mtetra
.132 0 0 r
.62453 .39676 .63012 .38634 .64238 .38018 .63684 .38895 Mtetra
.054 0 0 r
.63684 .38895 .64238 .38018 .65468 .374 .64919 .38112 Mtetra
0 0 0 r
.64919 .38112 .65468 .374 .66702 .36786 .66156 .37334 Mtetra
.66156 .37334 .66702 .36786 .67941 .36179 .67397 .36567 Mtetra
.67397 .36567 .67941 .36179 .69184 .35582 .68641 .35818 Mtetra
.439 .855 .699 r
.68641 .35818 .69184 .35582 .70432 .34997 .69889 .35091 Mtetra
.552 .93 .828 r
.69889 .35091 .70432 .34997 .71685 .34426 .71143 .34388 Mtetra
.629 .959 .91 r
.71143 .34388 .71685 .34426 .72943 .33868 .72401 .33712 Mtetra
.673 .953 .952 r
.72401 .33712 .72943 .33868 .74207 .33325 .73665 .33062 Mtetra
.694 .93 .967 r
.73665 .33062 .74207 .33325 .75477 .32796 .74935 .32439 Mtetra
.701 .901 .968 r
.74935 .32439 .75477 .32796 .76753 .32281 .7621 .31841 Mtetra
.701 .872 .962 r
.7621 .31841 .76753 .32281 .78035 .31777 .77493 .31267 Mtetra
.698 .847 .954 r
.77493 .31267 .78035 .31777 .79323 .31285 .78782 .30714 Mtetra
.693 .825 .946 r
.78782 .30714 .79323 .31285 .80618 .30801 .80077 .3018 Mtetra
.688 .807 .938 r
.80077 .3018 .80618 .30801 .81919 .30326 .8138 .29663 Mtetra
.684 .792 .932 r
.8138 .29663 .81919 .30326 .83226 .29858 .82689 .2916 Mtetra
.68 .78 .926 r
.82689 .2916 .83226 .29858 .8454 .29395 .84005 .28668 Mtetra
.676 .771 .922 r
.84005 .28668 .8454 .29395 .8586 .28936 .85327 .28185 Mtetra
.673 .764 .919 r
.85327 .28185 .8586 .28936 .87186 .2848 .86657 .2771 Mtetra
.905 .514 .266 r
.25633 .51596 .26376 .51989 .2726 .54409 .26504 .54141 Mtetra
.911 .55 .337 r
.26504 .54141 .2726 .54409 .28119 .57489 .27347 .5738 Mtetra
.903 .547 .357 r
.27347 .5738 .28119 .57489 .28995 .60707 .28206 .60778 Mtetra
.877 .502 .331 r
.28206 .60778 .28995 .60707 .29942 .63261 .2914 .63508 Mtetra
.76 .31 .181 r
.2914 .63508 .29942 .63261 .31003 .64356 .30195 .64744 Mtetra
.433 .852 .698 r
.30195 .64744 .31003 .64356 .32189 .63581 .31382 .6406 Mtetra
.963 .932 .706 r
.31382 .6406 .32189 .63581 .33468 .61142 .3267 .61667 Mtetra
.982 .875 .652 r
.3267 .61667 .33468 .61142 .34789 .57743 .34003 .58293 Mtetra
.984 .873 .643 r
.34003 .58293 .34789 .57743 .36101 .54226 .35327 .5481 Mtetra
.98 .908 .658 r
.35327 .5481 .36101 .54226 .37372 .5123 .36608 .5188 Mtetra
.923 .968 .674 r
.36608 .5188 .37372 .5123 .38596 .49044 .37839 .498 Mtetra
.546 .843 .521 r
.37839 .498 .38596 .49044 .39782 .47652 .3903 .48553 Mtetra
.1 0 0 r
.3903 .48553 .39782 .47652 .40945 .4687 .40195 .47947 Mtetra
.385 0 .118 r
.40195 .47947 .40945 .4687 .42097 .46478 .4135 .47751 Mtetra
.481 .087 .216 r
.4135 .47751 .42097 .46478 .43249 .46293 .42504 .47773 Mtetra
.513 .138 .267 r
.42504 .47773 .43249 .46293 .44404 .46195 .43664 .47884 Mtetra
.521 .161 .297 r
.43664 .47884 .44404 .46195 .45566 .46115 .44833 .48005 Mtetra
.519 .171 .318 r
.44833 .48005 .45566 .46115 .46735 .46015 .4601 .48093 Mtetra
.512 .174 .331 r
.4601 .48093 .46735 .46015 .47912 .45876 .47197 .48122 Mtetra
.503 .173 .341 r
.47197 .48122 .47912 .45876 .49097 .45686 .48394 .48075 Mtetra
.492 .169 .347 r
.48394 .48075 .49097 .45686 .50288 .45438 .49599 .47938 Mtetra
.48 .162 .35 r
.49599 .47938 .50288 .45438 .51486 .45125 .50811 .47704 Mtetra
.467 .153 .35 r
.50811 .47704 .51486 .45125 .5269 .44746 .5203 .47365 Mtetra
.452 .141 .347 r
.5203 .47365 .5269 .44746 .53898 .443 .53255 .46921 Mtetra
.435 .127 .342 r
.53255 .46921 .53898 .443 .55111 .43788 .54484 .46373 Mtetra
.417 .109 .333 r
.54484 .46373 .55111 .43788 .56328 .43215 .55716 .45726 Mtetra
.396 .088 .322 r
.55716 .45726 .56328 .43215 .57548 .42586 .56951 .44988 Mtetra
.374 .064 .306 r
.56951 .44988 .57548 .42586 .58771 .41909 .58187 .44171 Mtetra
.347 .035 .286 r
.58187 .44171 .58771 .41909 .59996 .41192 .59425 .43287 Mtetra
.317 0 .26 r
.59425 .43287 .59996 .41192 .61223 .40445 .60663 .4235 Mtetra
.282 0 .226 r
.60663 .4235 .61223 .40445 .62453 .39676 .61901 .41377 Mtetra
.239 0 .183 r
.61901 .41377 .62453 .39676 .63684 .38895 .6314 .40382 Mtetra
.187 0 .126 r
.6314 .40382 .63684 .38895 .64919 .38112 .6438 .3938 Mtetra
.122 0 .052 r
.6438 .3938 .64919 .38112 .66156 .37334 .65621 .38383 Mtetra
.038 0 0 r
.65621 .38383 .66156 .37334 .67397 .36567 .66864 .37403 Mtetra
0 0 0 r
.66864 .37403 .67397 .36567 .68641 .35818 .68109 .36449 Mtetra
.68109 .36449 .68641 .35818 .69889 .35091 .69358 .35529 Mtetra
.69358 .35529 .69889 .35091 .71143 .34388 .7061 .34648 Mtetra
.487 .875 .687 r
.7061 .34648 .71143 .34388 .72401 .33712 .71867 .33808 Mtetra
.6 .949 .823 r
.71867 .33808 .72401 .33712 .73665 .33062 .7313 .33012 Mtetra
.67 .971 .907 r
.7313 .33012 .73665 .33062 .74935 .32439 .74398 .32259 Mtetra
.704 .958 .948 r
.74398 .32259 .74935 .32439 .7621 .31841 .75673 .31547 Mtetra
.716 .929 .961 r
.75673 .31547 .7621 .31841 .77493 .31267 .76954 .30875 Mtetra
.716 .897 .961 r
.76954 .30875 .77493 .31267 .78782 .30714 .78243 .30238 Mtetra
.711 .866 .955 r
.78243 .30238 .78782 .30714 .80077 .3018 .79538 .29633 Mtetra
.704 .84 .948 r
.79538 .29633 .80077 .3018 .8138 .29663 .80841 .29057 Mtetra
.697 .818 .94 r
.80841 .29057 .8138 .29663 .82689 .2916 .82151 .28505 Mtetra
.691 .801 .933 r
.82151 .28505 .82689 .2916 .84005 .28668 .83468 .27972 Mtetra
.685 .787 .927 r
.83468 .27972 .84005 .28668 .85327 .28185 .84793 .27457 Mtetra
.68 .776 .923 r
.84793 .27457 .85327 .28185 .86657 .2771 .86125 .26955 Mtetra
.91 .523 .268 r
.24886 .51153 .25633 .51596 .26504 .54141 .25746 .53802 Mtetra
.917 .557 .337 r
.25746 .53802 .26504 .54141 .27347 .5738 .26573 .57173 Mtetra
.911 .557 .354 r
.26573 .57173 .27347 .5738 .28206 .60778 .27417 .60722 Mtetra
.889 .515 .324 r
.27417 .60722 .28206 .60778 .2914 .63508 .28338 .63603 Mtetra
.785 .328 .16 r
.28338 .63603 .2914 .63508 .30195 .64744 .29386 .64969 Mtetra
.491 .902 .818 r
.29386 .64969 .30195 .64744 .31382 .6406 .30574 .64379 Mtetra
.959 .915 .725 r
.30574 .64379 .31382 .6406 .3267 .61667 .31869 .62049 Mtetra
.975 .863 .663 r
.31869 .62049 .3267 .61667 .34003 .58293 .33213 .58724 Mtetra
.979 .864 .653 r
.33213 .58724 .34003 .58293 .35327 .5481 .34547 .55302 Mtetra
.977 .904 .672 r
.34547 .55302 .35327 .5481 .36608 .5188 .35836 .52462 Mtetra
.917 .975 .698 r
.35836 .52462 .36608 .5188 .37839 .498 .37072 .5051 Mtetra
0 0 0 r
.37072 .5051 .37839 .498 .3903 .48553 .38265 .49428 Mtetra
.216 0 0 r
.38265 .49428 .3903 .48553 .40195 .47947 .39432 .49018 Mtetra
.462 .043 .158 r
.39432 .49018 .40195 .47947 .4135 .47751 .40588 .4904 Mtetra
.537 .145 .246 r
.40588 .4904 .4135 .47751 .42504 .47773 .41744 .49292 Mtetra
.559 .187 .291 r
.41744 .49292 .42504 .47773 .43664 .47884 .42907 .49637 Mtetra
.561 .203 .319 r
.42907 .49637 .43664 .47884 .44833 .48005 .44081 .49989 Mtetra
.554 .209 .337 r
.44081 .49989 .44833 .48005 .4601 .48093 .45265 .50298 Mtetra
.543 .208 .35 r
.45265 .50298 .4601 .48093 .47197 .48122 .46462 .50529 Mtetra
.53 .203 .358 r
.46462 .50529 .47197 .48122 .48394 .48075 .47669 .50659 Mtetra
.516 .196 .364 r
.47669 .50659 .48394 .48075 .49599 .47938 .48888 .5067 Mtetra
.5 .186 .366 r
.48888 .5067 .49599 .47938 .50811 .47704 .50115 .50546 Mtetra
.482 .174 .366 r
.50115 .50546 .50811 .47704 .5203 .47365 .5135 .50279 Mtetra
.464 .159 .363 r
.5135 .50279 .5203 .47365 .53255 .46921 .52592 .49864 Mtetra
.444 .142 .358 r
.52592 .49864 .53255 .46921 .54484 .46373 .53839 .49301 Mtetra
.422 .123 .351 r
.53839 .49301 .54484 .46373 .55716 .45726 .55089 .48595 Mtetra
.399 .101 .34 r
.55089 .48595 .55716 .45726 .56951 .44988 .56341 .47758 Mtetra
.373 .076 .326 r
.56341 .47758 .56951 .44988 .58187 .44171 .57593 .46803 Mtetra
.344 .047 .308 r
.57593 .46803 .58187 .44171 .59425 .43287 .58845 .4575 Mtetra
.312 .013 .286 r
.58845 .4575 .59425 .43287 .60663 .4235 .60096 .44617 Mtetra
.276 0 .257 r
.60096 .44617 .60663 .4235 .61901 .41377 .61345 .43426 Mtetra
.234 0 .22 r
.61345 .43426 .61901 .41377 .6314 .40382 .62593 .422 Mtetra
.184 0 .173 r
.62593 .422 .6314 .40382 .6438 .3938 .63839 .40958 Mtetra
.123 0 .113 r
.63839 .40958 .6438 .3938 .65621 .38383 .65085 .39719 Mtetra
.049 0 .034 r
.65085 .39719 .65621 .38383 .66864 .37403 .66332 .38501 Mtetra
0 0 0 r
.66332 .38501 .66864 .37403 .68109 .36449 .67579 .37317 Mtetra
.67579 .37317 .68109 .36449 .69358 .35529 .68828 .36178 Mtetra
.68828 .36178 .69358 .35529 .7061 .34648 .7008 .35093 Mtetra
.7008 .35093 .7061 .34648 .71867 .33808 .71336 .34066 Mtetra
.567 .913 .701 r
.71336 .34066 .71867 .33808 .7313 .33012 .72597 .331 Mtetra
.662 .972 .826 r
.72597 .331 .7313 .33012 .74398 .32259 .73864 .32196 Mtetra
.716 .982 .902 r
.73864 .32196 .74398 .32259 .75673 .31547 .75137 .31352 Mtetra
.737 .963 .939 r
.75137 .31352 .75673 .31547 .76954 .30875 .76417 .30564 Mtetra
.74 .931 .952 r
.76417 .30564 .76954 .30875 .78243 .30238 .77704 .29828 Mtetra
.734 .897 .953 r
.77704 .29828 .78243 .30238 .79538 .29633 .78999 .29139 Mtetra
.724 .866 .948 r
.78999 .29139 .79538 .29633 .80841 .29057 .80301 .28492 Mtetra
.714 .84 .942 r
.80301 .28492 .80841 .29057 .82151 .28505 .81612 .27881 Mtetra
.704 .818 .936 r
.81612 .27881 .82151 .28505 .83468 .27972 .8293 .273 Mtetra
.696 .8 .93 r
.8293 .273 .83468 .27972 .84793 .27457 .84256 .26746 Mtetra
.689 .786 .925 r
.84256 .26746 .84793 .27457 .86125 .26955 .8559 .26212 Mtetra
.916 .529 .259 r
.2414 .50621 .24886 .51153 .25746 .53802 .2499 .53337 Mtetra
.924 .565 .327 r
.2499 .53337 .25746 .53802 .26573 .57173 .25805 .56795 Mtetra
.921 .566 .342 r
.25805 .56795 .26573 .57173 .27417 .60722 .26636 .60446 Mtetra
.905 .527 .302 r
.26636 .60446 .27417 .60722 .28338 .63603 .27546 .63429 Mtetra
.806 .329 .084 r
.27546 .63429 .28338 .63603 .29386 .64969 .28588 .64882 Mtetra
.637 .934 .968 r
.28588 .64882 .29386 .64969 .30574 .64379 .29777 .64359 Mtetra
.939 .863 .738 r
.29777 .64359 .30574 .64379 .31869 .62049 .31079 .62075 Mtetra
.955 .824 .676 r
.31079 .62075 .31869 .62049 .33213 .58724 .32433 .58791 Mtetra
.959 .827 .669 r
.32433 .58791 .33213 .58724 .34547 .55302 .33776 .5542 Mtetra
.96 .861 .697 r
.33776 .5542 .34547 .55302 .35836 .52462 .35073 .52654 Mtetra
.939 .939 .767 r
.35073 .52654 .35836 .52462 .37072 .5051 .36313 .50806 Mtetra
.7 .981 .812 r
.36313 .50806 .37072 .5051 .38265 .49428 .37508 .49858 Mtetra
.096 0 0 r
.37508 .49858 .38265 .49428 .39432 .49018 .38675 .49608 Mtetra
.471 0 .004 r
.38675 .49608 .39432 .49018 .40588 .4904 .39831 .4981 Mtetra
.572 .122 .144 r
.39831 .4981 .40588 .4904 .41744 .49292 .40988 .50257 Mtetra
.597 .175 .212 r
.40988 .50257 .41744 .49292 .42907 .49637 .42152 .50804 Mtetra
.597 .195 .251 r
.42152 .50804 .42907 .49637 .44081 .49989 .43328 .51361 Mtetra
.586 .2 .277 r
.43328 .51361 .44081 .49989 .45265 .50298 .44517 .51869 Mtetra
.569 .196 .295 r
.44517 .51869 .45265 .50298 .46462 .50529 .4572 .52291 Mtetra
.549 .187 .306 r
.4572 .52291 .46462 .50529 .47669 .50659 .46936 .52595 Mtetra
.527 .175 .314 r
.46936 .52595 .47669 .50659 .48888 .5067 .48165 .52758 Mtetra
.502 .159 .317 r
.48165 .52758 .48888 .5067 .50115 .50546 .49405 .52759 Mtetra
.475 .139 .317 r
.49405 .52759 .50115 .50546 .5135 .50279 .50654 .52584 Mtetra
.446 .117 .313 r
.50654 .52584 .5135 .50279 .52592 .49864 .51911 .52226 Mtetra
.415 .091 .306 r
.51911 .52226 .52592 .49864 .53839 .49301 .53173 .51682 Mtetra
.381 .063 .295 r
.53173 .51682 .53839 .49301 .55089 .48595 .54439 .50957 Mtetra
.345 .03 .281 r
.54439 .50957 .55089 .48595 .56341 .47758 .55707 .50063 Mtetra
.305 0 .262 r
.55707 .50063 .56341 .47758 .57593 .46803 .56975 .49016 Mtetra
.261 0 .238 r
.56975 .49016 .57593 .46803 .58845 .4575 .58241 .47838 Mtetra
.213 0 .207 r
.58241 .47838 .58845 .4575 .60096 .44617 .59505 .46553 Mtetra
.16 0 .17 r
.59505 .46553 .60096 .44617 .61345 .43426 .60766 .45189 Mtetra
.099 0 .122 r
.60766 .45189 .61345 .43426 .62593 .422 .62024 .43772 Mtetra
.029 0 .063 r
.62024 .43772 .62593 .422 .63839 .40958 .63278 .42328 Mtetra
0 0 0 r
.63278 .42328 .63839 .40958 .65085 .39719 .64531 .40883 Mtetra
.64531 .40883 .65085 .39719 .66332 .38501 .65782 .39458 Mtetra
.65782 .39458 .66332 .38501 .67579 .37317 .67032 .38071 Mtetra
.67032 .38071 .67579 .37317 .68828 .36178 .68284 .36737 Mtetra
.68284 .36737 .68828 .36178 .7008 .35093 .69537 .35468 Mtetra
.609 .908 .631 r
.69537 .35468 .7008 .35093 .71336 .34066 .70793 .34271 Mtetra
.696 .97 .752 r
.70793 .34271 .71336 .34066 .72597 .331 .72054 .33149 Mtetra
.75 .994 .839 r
.72054 .33149 .72597 .331 .73864 .32196 .7332 .32104 Mtetra
.775 .988 .894 r
.7332 .32104 .73864 .32196 .75137 .31352 .74593 .31135 Mtetra
.78 .964 .923 r
.74593 .31135 .75137 .31352 .76417 .30564 .75872 .30237 Mtetra
.772 .933 .936 r
.75872 .30237 .76417 .30564 .77704 .29828 .77159 .29407 Mtetra
.759 .901 .94 r
.77159 .29407 .77704 .29828 .78999 .29139 .78453 .28637 Mtetra
.745 .871 .938 r
.78453 .28637 .78999 .29139 .80301 .28492 .79756 .27921 Mtetra
.73 .845 .935 r
.79756 .27921 .80301 .28492 .81612 .27881 .81068 .27252 Mtetra
.718 .823 .93 r
.81068 .27252 .81612 .27881 .8293 .273 .82387 .26624 Mtetra
.707 .805 .926 r
.82387 .26624 .8293 .273 .84256 .26746 .83715 .2603 Mtetra
.697 .79 .922 r
.83715 .2603 .84256 .26746 .8559 .26212 .85051 .25464 Mtetra
.92 .533 .24 r
.23397 .49973 .2414 .50621 .2499 .53337 .2424 .5271 Mtetra
.932 .571 .309 r
.2424 .5271 .2499 .53337 .25805 .56795 .25047 .56198 Mtetra
.932 .575 .319 r
.25047 .56198 .25805 .56795 .26636 .60446 .25869 .59882 Mtetra
.919 .536 .261 r
.25869 .59882 .26636 .60446 .27546 .63429 .26771 .62897 Mtetra
.787 .29 0 r
.26771 .62897 .27546 .63429 .28588 .64882 .27811 .64374 Mtetra
.699 .817 .938 r
.27811 .64374 .28588 .64882 .29777 .64359 .29003 .63862 Mtetra
.898 .787 .73 r
.29003 .63862 .29777 .64359 .31079 .62075 .30313 .61581 Mtetra
.919 .767 .677 r
.30313 .61581 .31079 .62075 .32433 .58791 .31677 .58297 Mtetra
.921 .766 .672 r
.31677 .58297 .32433 .58791 .33776 .5542 .3303 .54933 Mtetra
.914 .78 .699 r
.3303 .54933 .33776 .5542 .35073 .52654 .34335 .52187 Mtetra
.888 .808 .764 r
.34335 .52187 .35073 .52654 .36313 .50806 .35581 .50375 Mtetra
.802 .848 .885 r
.35581 .50375 .36313 .50806 .37508 .49858 .36779 .49479 Mtetra
.506 .808 .999 r
.36779 .49479 .37508 .49858 .38675 .49608 .37947 .49297 Mtetra
0 .503 .818 r
.37947 .49297 .38675 .49608 .39831 .4981 .39102 .49581 Mtetra
.386 0 0 r
.39102 .49581 .39831 .4981 .40988 .50257 .40258 .50121 Mtetra
.515 0 0 r
.40258 .50121 .40988 .50257 .42152 .50804 .41422 .50772 Mtetra
.557 0 0 r
.41422 .50772 .42152 .50804 .43328 .51361 .42599 .51439 Mtetra
.561 0 0 r
.42599 .51439 .43328 .51361 .44517 .51869 .43789 .52063 Mtetra
.542 0 0 r
.43789 .52063 .44517 .51869 .4572 .52291 .44995 .52601 Mtetra
.507 0 0 r
.44995 .52601 .4572 .52291 .46936 .52595 .46214 .53021 Mtetra
.458 0 0 r
.46214 .53021 .46936 .52595 .48165 .52758 .47448 .53293 Mtetra
.396 0 0 r
.47448 .53293 .48165 .52758 .49405 .52759 .48694 .53395 Mtetra
.322 0 0 r
.48694 .53395 .49405 .52759 .50654 .52584 .49951 .53308 Mtetra
.237 0 0 r
.49951 .53308 .50654 .52584 .51911 .52226 .51216 .53021 Mtetra
.143 0 0 r
.51216 .53021 .51911 .52226 .53173 .51682 .52489 .52529 Mtetra
.042 0 0 r
.52489 .52529 .53173 .51682 .54439 .50957 .53765 .51835 Mtetra
0 0 0 r
.53765 .51835 .54439 .50957 .55707 .50063 .55044 .50951 Mtetra
.55044 .50951 .55707 .50063 .56975 .49016 .56323 .49891 Mtetra
.56323 .49891 .56975 .49016 .58241 .47838 .57601 .48679 Mtetra
.57601 .48679 .58241 .47838 .59505 .46553 .58876 .4734 Mtetra
.58876 .4734 .59505 .46553 .60766 .45189 .60147 .45904 Mtetra
.555 .825 .47 r
.60147 .45904 .60766 .45189 .62024 .43772 .61414 .44401 Mtetra
.633 .878 .53 r
.61414 .44401 .62024 .43772 .63278 .42328 .62678 .42859 Mtetra
.7 .922 .59 r
.62678 .42859 .63278 .42328 .64531 .40883 .63938 .41308 Mtetra
.756 .956 .649 r
.63938 .41308 .64531 .40883 .65782 .39458 .65195 .39771 Mtetra
.8 .981 .704 r
.65195 .39771 .65782 .39458 .67032 .38071 .66451 .3827 Mtetra
.831 .995 .754 r
.66451 .3827 .67032 .38071 .68284 .36737 .67707 .36824 Mtetra
.85 .998 .797 r
.67707 .36824 .68284 .36737 .69537 .35468 .68964 .35445 Mtetra
.857 .992 .833 r
.68964 .35445 .69537 .35468 .70793 .34271 .70224 .34143 Mtetra
.855 .979 .861 r
.70224 .34143 .70793 .34271 .72054 .33149 .71487 .32924 Mtetra
.845 .96 .883 r
.71487 .32924 .72054 .33149 .7332 .32104 .72755 .31788 Mtetra
.831 .937 .897 r
.72755 .31788 .7332 .32104 .74593 .31135 .74029 .30737 Mtetra
.813 .913 .907 r
.74029 .30737 .74593 .31135 .75872 .30237 .7531 .29766 Mtetra
.794 .889 .913 r
.7531 .29766 .75872 .30237 .77159 .29407 .76599 .2887 Mtetra
.775 .866 .916 r
.76599 .2887 .77159 .29407 .78453 .28637 .77895 .28043 Mtetra
.757 .845 .917 r
.77895 .28043 .78453 .28637 .79756 .27921 .792 .27278 Mtetra
.74 .826 .917 r
.792 .27278 .79756 .27921 .81068 .27252 .80513 .26568 Mtetra
.726 .809 .917 r
.80513 .26568 .81068 .27252 .82387 .26624 .81835 .25904 Mtetra
.713 .795 .915 r
.81835 .25904 .82387 .26624 .83715 .2603 .83166 .25281 Mtetra
.703 .784 .914 r
.83166 .25281 .83715 .2603 .85051 .25464 .84504 .2469 Mtetra
.922 .531 .212 r
.22659 .49209 .23397 .49973 .2424 .5271 .23499 .5192 Mtetra
.938 .574 .284 r
.23499 .5192 .2424 .5271 .25047 .56198 .24301 .55376 Mtetra
.94 .579 .287 r
.24301 .55376 .25047 .56198 .25869 .59882 .25118 .59023 Mtetra
.925 .536 .199 r
.25118 .59023 .25869 .59882 .26771 .62897 .26018 .61995 Mtetra
.644 .171 0 r
.26018 .61995 .26771 .62897 .27811 .64374 .27059 .63425 Mtetra
.697 .701 .85 r
.27059 .63425 .27811 .64374 .29003 .63862 .28256 .62864 Mtetra
.857 .72 .711 r
.28256 .62864 .29003 .63862 .30313 .61581 .29576 .60533 Mtetra
.882 .714 .669 r
.29576 .60533 .30313 .61581 .31677 .58297 .30952 .57201 Mtetra
.882 .71 .665 r
.30952 .57201 .31677 .58297 .3303 .54933 .32317 .53787 Mtetra
.864 .705 .684 r
.32317 .53787 .3303 .54933 .34335 .52187 .33631 .5099 Mtetra
.822 .694 .722 r
.33631 .5099 .34335 .52187 .35581 .50375 .34885 .49126 Mtetra
.74 .663 .775 r
.34885 .49126 .35581 .50375 .36779 .49479 .36087 .48178 Mtetra
.608 .599 .817 r
.36087 .48178 .36779 .49479 .37947 .49297 .37258 .47944 Mtetra
.462 .517 .828 r
.37258 .47944 .37947 .49297 .39102 .49581 .38415 .4818 Mtetra
.359 .45 .818 r
.38415 .4818 .39102 .49581 .40258 .50121 .39571 .48678 Mtetra
.314 .417 .808 r
.39571 .48678 .40258 .50121 .41422 .50772 .40735 .49294 Mtetra
.311 .411 .803 r
.40735 .49294 .41422 .50772 .42599 .51439 .4191 .49936 Mtetra
.332 .421 .803 r
.4191 .49936 .42599 .51439 .43789 .52063 .431 .50546 Mtetra
.367 .441 .805 r
.431 .50546 .43789 .52063 .44995 .52601 .44303 .51084 Mtetra
.409 .467 .808 r
.44303 .51084 .44995 .52601 .46214 .53021 .45522 .51516 Mtetra
.456 .496 .812 r
.45522 .51516 .46214 .53021 .47448 .53293 .46754 .51814 Mtetra
.505 .529 .814 r
.46754 .51814 .47448 .53293 .48694 .53395 .47999 .51954 Mtetra
.554 .561 .816 r
.47999 .51954 .48694 .53395 .49951 .53308 .49256 .51917 Mtetra
.602 .594 .816 r
.49256 .51917 .49951 .53308 .51216 .53021 .50522 .5169 Mtetra
.646 .625 .814 r
.50522 .5169 .51216 .53021 .52489 .52529 .51796 .51265 Mtetra
.687 .654 .811 r
.51796 .51265 .52489 .52529 .53765 .51835 .53076 .50644 Mtetra
.724 .68 .807 r
.53076 .50644 .53765 .51835 .55044 .50951 .54358 .49833 Mtetra
.756 .704 .803 r
.54358 .49833 .55044 .50951 .56323 .49891 .55642 .48847 Mtetra
.783 .725 .799 r
.55642 .48847 .56323 .49891 .57601 .48679 .56925 .47705 Mtetra
.806 .744 .795 r
.56925 .47705 .57601 .48679 .58876 .4734 .58206 .46432 Mtetra
.824 .76 .792 r
.58206 .46432 .58876 .4734 .60147 .45904 .59484 .45054 Mtetra
.839 .774 .79 r
.59484 .45054 .60147 .45904 .61414 .44401 .60758 .43601 Mtetra
.849 .787 .79 r
.60758 .43601 .61414 .44401 .62678 .42859 .62029 .42101 Mtetra
.857 .797 .792 r
.62029 .42101 .62678 .42859 .63938 .41308 .63297 .40582 Mtetra
.861 .806 .795 r
.63297 .40582 .63938 .41308 .65195 .39771 .64561 .39068 Mtetra
.861 .813 .8 r
.64561 .39068 .65195 .39771 .66451 .3827 .65825 .37584 Mtetra
.859 .818 .807 r
.65825 .37584 .66451 .3827 .67707 .36824 .67088 .36145 Mtetra
.855 .822 .816 r
.67088 .36145 .67707 .36824 .68964 .35445 .68351 .34768 Mtetra
.847 .824 .825 r
.68351 .34768 .68964 .35445 .70224 .34143 .69617 .33462 Mtetra
.837 .824 .835 r
.69617 .33462 .70224 .34143 .71487 .32924 .70886 .32235 Mtetra
.825 .822 .846 r
.70886 .32235 .71487 .32924 .72755 .31788 .7216 .31089 Mtetra
.812 .819 .856 r
.7216 .31089 .72755 .31788 .74029 .30737 .73439 .30024 Mtetra
.797 .814 .866 r
.73439 .30024 .74029 .30737 .7531 .29766 .74725 .29038 Mtetra
.782 .808 .874 r
.74725 .29038 .7531 .29766 .76599 .2887 .76018 .28127 Mtetra
.766 .802 .881 r
.76018 .28127 .76599 .2887 .77895 .28043 .77319 .27285 Mtetra
.751 .794 .888 r
.77319 .27285 .77895 .28043 .792 .27278 .78628 .26505 Mtetra
.737 .787 .893 r
.78628 .26505 .792 .27278 .80513 .26568 .79945 .25781 Mtetra
.725 .78 .897 r
.79945 .25781 .80513 .26568 .81835 .25904 .81271 .25104 Mtetra
.713 .774 .9 r
.81271 .25104 .81835 .25904 .83166 .25281 .82606 .24468 Mtetra
.703 .768 .902 r
.82606 .24468 .83166 .25281 .84504 .2469 .83949 .23867 Mtetra
.92 .525 .181 r
.21922 .48355 .22659 .49209 .23499 .5192 .22763 .51001 Mtetra
.94 .573 .257 r
.22763 .51001 .23499 .5192 .24301 .55376 .23564 .54374 Mtetra
.943 .578 .252 r
.23564 .54374 .24301 .55376 .25118 .59023 .24381 .57924 Mtetra
.914 .522 .123 r
.24381 .57924 .25118 .59023 .26018 .61995 .25283 .60792 Mtetra
0 0 .565 r
.25283 .60792 .26018 .61995 .27059 .63425 .26328 .6212 Mtetra
.693 .64 .792 r
.26328 .6212 .27059 .63425 .28256 .62864 .27534 .61464 Mtetra
.831 .679 .694 r
.27534 .61464 .28256 .62864 .29576 .60533 .28865 .59048 Mtetra
.857 .68 .661 r
.28865 .59048 .29576 .60533 .30952 .57201 .30253 .55632 Mtetra
.856 .674 .656 r
.30253 .55632 .30952 .57201 .32317 .53787 .31631 .52129 Mtetra
.834 .662 .669 r
.31631 .52129 .32317 .53787 .33631 .5099 .32957 .49229 Mtetra
.789 .636 .693 r
.32957 .49229 .33631 .5099 .34885 .49126 .3422 .47243 Mtetra
.714 .591 .718 r
.3422 .47243 .34885 .49126 .36087 .48178 .3543 .46156 Mtetra
.62 .53 .73 r
.3543 .46156 .36087 .48178 .37258 .47944 .36606 .45769 Mtetra
.538 .47 .727 r
.36606 .45769 .37258 .47944 .38415 .4818 .37767 .45844 Mtetra
.489 .429 .716 r
.37767 .45844 .38415 .4818 .39571 .48678 .38925 .46178 Mtetra
.47 .407 .705 r
.38925 .46178 .39571 .48678 .40735 .49294 .40089 .46634 Mtetra
.469 .399 .695 r
.40089 .46634 .40735 .49294 .4191 .49936 .41264 .47126 Mtetra
.478 .398 .687 r
.41264 .47126 .4191 .49936 .431 .50546 .42451 .476 Mtetra
.491 .401 .681 r
.42451 .476 .431 .50546 .44303 .51084 .43651 .4802 Mtetra
.506 .407 .677 r
.43651 .4802 .44303 .51084 .45522 .51516 .44864 .48358 Mtetra
.523 .415 .673 r
.44864 .48358 .45522 .51516 .46754 .51814 .46091 .48588 Mtetra
.54 .425 .671 r
.46091 .48588 .46754 .51814 .47999 .51954 .4733 .48691 Mtetra
.558 .436 .67 r
.4733 .48691 .47999 .51954 .49256 .51917 .4858 .48647 Mtetra
.576 .448 .669 r
.4858 .48647 .49256 .51917 .50522 .5169 .4984 .48445 Mtetra
.594 .461 .67 r
.4984 .48445 .50522 .5169 .51796 .51265 .51108 .48076 Mtetra
.612 .475 .671 r
.51108 .48076 .51796 .51265 .53076 .50644 .52382 .47539 Mtetra
.629 .489 .672 r
.52382 .47539 .53076 .50644 .54358 .49833 .53661 .46838 Mtetra
.646 .503 .675 r
.53661 .46838 .54358 .49833 .55642 .48847 .54942 .45983 Mtetra
.662 .518 .678 r
.54942 .45983 .55642 .48847 .56925 .47705 .56224 .44989 Mtetra
.678 .534 .682 r
.56224 .44989 .56925 .47705 .58206 .46432 .57505 .43874 Mtetra
.692 .549 .687 r
.57505 .43874 .58206 .46432 .59484 .45054 .58785 .42663 Mtetra
.706 .565 .692 r
.58785 .42663 .59484 .45054 .60758 .43601 .60063 .41377 Mtetra
.719 .581 .699 r
.60063 .41377 .60758 .43601 .62029 .42101 .61339 .40042 Mtetra
.731 .597 .707 r
.61339 .40042 .62029 .42101 .63297 .40582 .62613 .38681 Mtetra
.741 .613 .716 r
.62613 .38681 .63297 .40582 .64561 .39068 .63885 .37318 Mtetra
.749 .629 .726 r
.63885 .37318 .64561 .39068 .65825 .37584 .65156 .35971 Mtetra
.756 .644 .737 r
.65156 .35971 .65825 .37584 .67088 .36145 .66427 .34658 Mtetra
.762 .66 .75 r
.66427 .34658 .67088 .36145 .68351 .34768 .67699 .33392 Mtetra
.765 .674 .763 r
.67699 .33392 .68351 .34768 .69617 .33462 .68973 .32184 Mtetra
.766 .688 .777 r
.68973 .32184 .69617 .33462 .70886 .32235 .70251 .3104 Mtetra
.765 .701 .792 r
.70251 .3104 .70886 .32235 .7216 .31089 .71533 .29965 Mtetra
.761 .712 .806 r
.71533 .29965 .7216 .31089 .73439 .30024 .72821 .28959 Mtetra
.756 .722 .821 r
.72821 .28959 .73439 .30024 .74725 .29038 .74114 .28021 Mtetra
.749 .73 .834 r
.74114 .28021 .74725 .29038 .76018 .28127 .75415 .27149 Mtetra
.741 .737 .847 r
.75415 .27149 .76018 .28127 .77319 .27285 .76723 .26337 Mtetra
.733 .741 .858 r
.76723 .26337 .77319 .27285 .78628 .26505 .78038 .25581 Mtetra
.723 .744 .868 r
.78038 .25581 .78628 .26505 .79945 .25781 .79362 .24874 Mtetra
.715 .746 .877 r
.79362 .24874 .79945 .25781 .81271 .25104 .80694 .24209 Mtetra
.706 .747 .884 r
.80694 .24209 .81271 .25104 .82606 .24468 .82035 .23582 Mtetra
.698 .747 .89 r
.82035 .23582 .82606 .24468 .83949 .23867 .83383 .22986 Mtetra
.915 .515 .152 r
.21185 .4745 .21922 .48355 .22763 .51001 .22028 .50003 Mtetra
.939 .567 .231 r
.22028 .50003 .22763 .51001 .23564 .54374 .22833 .53259 Mtetra
.94 .572 .218 r
.22833 .53259 .23564 .54374 .24381 .57924 .23653 .56673 Mtetra
.889 .496 .049 r
.23653 .56673 .24381 .57924 .25283 .60792 .24559 .594 Mtetra
0 .13 .677 r
.24559 .594 .25283 .60792 .26328 .6212 .25611 .60596 Mtetra
.697 .617 .763 r
.25611 .60596 .26328 .6212 .27534 .61464 .26826 .59831 Mtetra
.82 .659 .684 r
.26826 .59831 .27534 .61464 .28865 .59048 .28168 .57324 Mtetra
.847 .664 .655 r
.28168 .57324 .28865 .59048 .30253 .55632 .29568 .53825 Mtetra
.846 .659 .65 r
.29568 .53825 .30253 .55632 .31631 .52129 .30959 .50228 Mtetra
.825 .646 .661 r
.30959 .50228 .31631 .52129 .32957 .49229 .32297 .47211 Mtetra
.782 .619 .679 r
.32297 .47211 .32957 .49229 .3422 .47243 .3357 .45078 Mtetra
.715 .575 .697 r
.3357 .45078 .3422 .47243 .3543 .46156 .34789 .43814 Mtetra
.638 .521 .703 r
.34789 .43814 .3543 .46156 .36606 .45769 .35973 .43226 Mtetra
.574 .47 .698 r
.35973 .43226 .36606 .45769 .37767 .45844 .3714 .43082 Mtetra
.536 .436 .688 r
.3714 .43082 .37767 .45844 .38925 .46178 .38302 .43188 Mtetra
.519 .416 .677 r
.38302 .43188 .38925 .46178 .40089 .46634 .39469 .43415 Mtetra
.516 .406 .667 r
.39469 .43415 .40089 .46634 .41264 .47126 .40644 .43683 Mtetra
.519 .401 .659 r
.40644 .43683 .41264 .47126 .42451 .476 .41829 .43947 Mtetra
.525 .4 .652 r
.41829 .43947 .42451 .476 .43651 .4802 .43025 .44176 Mtetra
.532 .401 .647 r
.43025 .44176 .43651 .4802 .44864 .48358 .44233 .44349 Mtetra
.541 .403 .643 r
.44233 .44349 .44864 .48358 .46091 .48588 .45453 .44447 Mtetra
.55 .407 .64 r
.45453 .44447 .46091 .48588 .4733 .48691 .46683 .44452 Mtetra
.559 .412 .638 r
.46683 .44452 .4733 .48691 .4858 .48647 .47924 .44352 Mtetra
.569 .418 .637 r
.47924 .44352 .4858 .48647 .4984 .48445 .49173 .44134 Mtetra
.58 .425 .636 r
.49173 .44134 .4984 .48445 .51108 .48076 .50431 .43793 Mtetra
.59 .433 .637 r
.50431 .43793 .51108 .48076 .52382 .47539 .51696 .43325 Mtetra
.6 .442 .638 r
.51696 .43325 .52382 .47539 .53661 .46838 .52965 .42732 Mtetra
.611 .451 .641 r
.52965 .42732 .53661 .46838 .54942 .45983 .54239 .4202 Mtetra
.621 .461 .643 r
.54239 .4202 .54942 .45983 .56224 .44989 .55515 .41199 Mtetra
.632 .471 .647 r
.55515 .41199 .56224 .44989 .57505 .43874 .56792 .40281 Mtetra
.642 .483 .652 r
.56792 .40281 .57505 .43874 .58785 .42663 .58071 .39284 Mtetra
.652 .495 .658 r
.58071 .39284 .58785 .42663 .60063 .41377 .59349 .38223 Mtetra
.662 .507 .664 r
.59349 .38223 .60063 .41377 .61339 .40042 .60627 .37117 Mtetra
.671 .521 .672 r
.60627 .37117 .61339 .40042 .62613 .38681 .61904 .35985 Mtetra
.68 .535 .681 r
.61904 .35985 .62613 .38681 .63885 .37318 .63182 .34843 Mtetra
.689 .55 .691 r
.63182 .34843 .63885 .37318 .65156 .35971 .6446 .33707 Mtetra
.696 .565 .703 r
.6446 .33707 .65156 .35971 .66427 .34658 .65739 .32592 Mtetra
.703 .581 .716 r
.65739 .32592 .66427 .34658 .67699 .33392 .6702 .31508 Mtetra
.709 .598 .73 r
.6702 .31508 .67699 .33392 .68973 .32184 .68304 .30463 Mtetra
.714 .615 .745 r
.68304 .30463 .68973 .32184 .70251 .3104 .69592 .29466 Mtetra
.717 .631 .761 r
.69592 .29466 .70251 .3104 .71533 .29965 .70884 .28518 Mtetra
.719 .647 .777 r
.70884 .28518 .71533 .29965 .72821 .28959 .72181 .27622 Mtetra
.719 .663 .794 r
.72181 .27622 .72821 .28959 .74114 .28021 .73484 .26778 Mtetra
.718 .677 .81 r
.73484 .26778 .74114 .28021 .75415 .27149 .74794 .25984 Mtetra
.715 .69 .825 r
.74794 .25984 .75415 .27149 .76723 .26337 .76111 .25236 Mtetra
.711 .701 .839 r
.76111 .25236 .76723 .26337 .78038 .25581 .77435 .24532 Mtetra
.706 .711 .852 r
.77435 .24532 .78038 .25581 .79362 .24874 .78766 .23866 Mtetra
.701 .719 .863 r
.78766 .23866 .79362 .24874 .80694 .24209 .80106 .23234 Mtetra
.695 .725 .873 r
.80106 .23234 .80694 .24209 .82035 .23582 .81453 .22632 Mtetra
.69 .73 .881 r
.81453 .22632 .82035 .23582 .83383 .22986 .82808 .22054 Mtetra
.907 .502 .126 r
.20444 .46528 .21185 .4745 .22028 .50003 .21292 .48972 Mtetra
.935 .559 .208 r
.21292 .48972 .22028 .50003 .22833 .53259 .22101 .52091 Mtetra
.935 .562 .188 r
.22101 .52091 .22833 .53259 .23653 .56673 .22927 .5535 Mtetra
.859 .466 0 r
.22927 .5535 .23653 .56673 .24559 .594 .23839 .57921 Mtetra
0 .213 .727 r
.23839 .57921 .24559 .594 .25611 .60596 .24898 .58986 Mtetra
.704 .612 .751 r
.24898 .58986 .25611 .60596 .26826 .59831 .26121 .58124 Mtetra
.818 .655 .68 r
.26121 .58124 .26826 .59831 .28168 .57324 .27473 .55552 Mtetra
.846 .662 .653 r
.27473 .55552 .28168 .57324 .29568 .53825 .28884 .52002 Mtetra
.847 .659 .649 r
.28884 .52002 .29568 .53825 .30959 .50228 .30285 .48344 Mtetra
.829 .649 .659 r
.30285 .48344 .30959 .50228 .32297 .47211 .31634 .45238 Mtetra
.791 .626 .677 r
.31634 .45238 .32297 .47211 .3357 .45078 .32917 .42978 Mtetra
.732 .588 .695 r
.32917 .42978 .3357 .45078 .34789 .43814 .34146 .41551 Mtetra
.663 .54 .704 r
.34146 .41551 .34789 .43814 .35973 .43226 .35338 .4077 Mtetra
.605 .494 .701 r
.35338 .4077 .35973 .43226 .3714 .43082 .36512 .4041 Mtetra
.569 .461 .691 r
.36512 .4041 .3714 .43082 .38302 .43188 .3768 .40289 Mtetra
.551 .44 .68 r
.3768 .40289 .38302 .43188 .39469 .43415 .3885 .40282 Mtetra
.545 .428 .67 r
.3885 .40282 .39469 .43415 .40644 .43683 .40027 .4032 Mtetra
.545 .42 .661 r
.40027 .4032 .40644 .43683 .41829 .43947 .41212 .40363 Mtetra
.547 .416 .654 r
.41212 .40363 .41829 .43947 .43025 .44176 .42406 .40387 Mtetra
.55 .413 .647 r
.42406 .40387 .43025 .44176 .44233 .44349 .4361 .40377 Mtetra
.555 .413 .643 r
.4361 .40377 .44233 .44349 .45453 .44447 .44823 .4032 Mtetra
.56 .413 .639 r
.44823 .4032 .45453 .44447 .46683 .44452 .46046 .40204 Mtetra
.566 .415 .636 r
.46046 .40204 .46683 .44452 .47924 .44352 .47277 .40019 Mtetra
.572 .418 .634 r
.47277 .40019 .47924 .44352 .49173 .44134 .48517 .39758 Mtetra
.578 .422 .633 r
.48517 .39758 .49173 .44134 .50431 .43793 .49764 .39416 Mtetra
.585 .427 .634 r
.49764 .39416 .50431 .43793 .51696 .43325 .51018 .38989 Mtetra
.592 .432 .634 r
.51018 .38989 .51696 .43325 .52965 .42732 .52278 .38477 Mtetra
.599 .439 .636 r
.52278 .38477 .52965 .42732 .54239 .4202 .53543 .37883 Mtetra
.606 .446 .639 r
.53543 .37883 .54239 .4202 .55515 .41199 .54811 .37214 Mtetra
.614 .454 .642 r
.54811 .37214 .55515 .41199 .56792 .40281 .56083 .36476 Mtetra
.621 .463 .647 r
.56083 .36476 .56792 .40281 .58071 .39284 .57357 .3568 Mtetra
.629 .473 .652 r
.57357 .3568 .58071 .39284 .59349 .38223 .58634 .34837 Mtetra
.636 .484 .659 r
.58634 .34837 .59349 .38223 .60627 .37117 .59912 .33959 Mtetra
.644 .495 .666 r
.59912 .33959 .60627 .37117 .61904 .35985 .61191 .33057 Mtetra
.651 .508 .675 r
.61191 .33057 .61904 .35985 .63182 .34843 .62473 .32143 Mtetra
.659 .521 .685 r
.62473 .32143 .63182 .34843 .6446 .33707 .63757 .31229 Mtetra
.666 .536 .696 r
.63757 .31229 .6446 .33707 .65739 .32592 .65043 .30325 Mtetra
.672 .551 .709 r
.65043 .30325 .65739 .32592 .6702 .31508 .66332 .29437 Mtetra
.678 .567 .723 r
.66332 .29437 .6702 .31508 .68304 .30463 .67625 .28573 Mtetra
.683 .584 .738 r
.67625 .28573 .68304 .30463 .69592 .29466 .68922 .27738 Mtetra
.688 .601 .754 r
.68922 .27738 .69592 .29466 .70884 .28518 .70224 .26936 Mtetra
.691 .619 .77 r
.70224 .26936 .70884 .28518 .72181 .27622 .71531 .26167 Mtetra
.693 .636 .787 r
.71531 .26167 .72181 .27622 .73484 .26778 .72844 .25432 Mtetra
.694 .652 .803 r
.72844 .25432 .73484 .26778 .74794 .25984 .74163 .2473 Mtetra
.694 .667 .819 r
.74163 .2473 .74794 .25984 .76111 .25236 .75489 .24061 Mtetra
.693 .681 .834 r
.75489 .24061 .76111 .25236 .77435 .24532 .76822 .2342 Mtetra
.691 .693 .847 r
.76822 .2342 .77435 .24532 .78766 .23866 .78162 .22806 Mtetra
.688 .704 .859 r
.78162 .22806 .78766 .23866 .80106 .23234 .7951 .22215 Mtetra
.685 .712 .869 r
.7951 .22215 .80106 .23234 .81453 .22632 .80864 .21645 Mtetra
.682 .719 .878 r
.80864 .21645 .81453 .22632 .82808 .22054 .82226 .21091 Mtetra
.899 .486 .102 r
.19698 .45607 .20444 .46528 .21292 .48972 .20551 .47935 Mtetra
.93 .548 .187 r
.20551 .47935 .21292 .48972 .22101 .52091 .21367 .50907 Mtetra
.928 .55 .162 r
.21367 .50907 .22101 .52091 .22927 .5535 .22199 .54002 Mtetra
.829 .434 0 r
.22199 .54002 .22927 .5535 .23839 .57921 .23118 .56419 Mtetra
.083 .268 .754 r
.23118 .56419 .23839 .57921 .24898 .58986 .24183 .57365 Mtetra
.712 .615 .747 r
.24183 .57365 .24898 .58986 .26121 .58124 .25413 .56437 Mtetra
.821 .657 .68 r
.25413 .56437 .26121 .58124 .27473 .55552 .26771 .53845 Mtetra
.85 .666 .654 r
.26771 .53845 .27473 .55552 .28884 .52002 .28189 .50297 Mtetra
.853 .667 .65 r
.28189 .50297 .28884 .52002 .30285 .48344 .29598 .46633 Mtetra
.84 .662 .661 r
.29598 .46633 .30285 .48344 .31634 .45238 .30955 .4349 Mtetra
.809 .646 .682 r
.30955 .4349 .31634 .45238 .32917 .42978 .32248 .41154 Mtetra
.757 .618 .705 r
.32248 .41154 .32917 .42978 .34146 .41551 .33485 .39612 Mtetra
.694 .577 .72 r
.33485 .39612 .34146 .41551 .35338 .4077 .34685 .38683 Mtetra
.637 .535 .722 r
.34685 .38683 .35338 .4077 .36512 .4041 .35865 .38153 Mtetra
.6 .502 .715 r
.35865 .38153 .36512 .4041 .3768 .40289 .37039 .37847 Mtetra
.581 .48 .704 r
.37039 .37847 .3768 .40289 .3885 .40282 .38214 .3765 Mtetra
.572 .465 .694 r
.38214 .3765 .3885 .40282 .40027 .4032 .39393 .37497 Mtetra
.569 .455 .684 r
.39393 .37497 .40027 .4032 .41212 .40363 .4058 .37353 Mtetra
.569 .448 .675 r
.4058 .37353 .41212 .40363 .42406 .40387 .41774 .37203 Mtetra
.57 .443 .668 r
.41774 .37203 .42406 .40387 .4361 .40377 .42976 .37034 Mtetra
.571 .439 .662 r
.42976 .37034 .4361 .40377 .44823 .4032 .44185 .36838 Mtetra
.574 .437 .657 r
.44185 .36838 .44823 .4032 .46046 .40204 .45403 .36609 Mtetra
.577 .436 .653 r
.45403 .36609 .46046 .40204 .47277 .40019 .46628 .3634 Mtetra
.58 .437 .651 r
.46628 .3634 .47277 .40019 .48517 .39758 .47861 .36026 Mtetra
.584 .439 .649 r
.47861 .36026 .48517 .39758 .49764 .39416 .49101 .35663 Mtetra
.589 .441 .649 r
.49101 .35663 .49764 .39416 .51018 .38989 .50347 .35251 Mtetra
.594 .445 .649 r
.50347 .35251 .51018 .38989 .52278 .38477 .51599 .34787 Mtetra
.599 .45 .65 r
.51599 .34787 .52278 .38477 .53543 .37883 .52856 .34273 Mtetra
.604 .455 .653 r
.52856 .34273 .53543 .37883 .54811 .37214 .54118 .33711 Mtetra
.61 .462 .656 r
.54118 .33711 .54811 .37214 .56083 .36476 .55385 .33107 Mtetra
.615 .47 .661 r
.55385 .33107 .56083 .36476 .57357 .3568 .56655 .32465 Mtetra
.621 .478 .666 r
.56655 .32465 .57357 .3568 .58634 .34837 .57929 .31791 Mtetra
.627 .488 .672 r
.57929 .31791 .58634 .34837 .59912 .33959 .59207 .31093 Mtetra
.633 .498 .68 r
.59207 .31093 .59912 .33959 .61191 .33057 .60488 .30378 Mtetra
.64 .51 .689 r
.60488 .30378 .61191 .33057 .62473 .32143 .61773 .29652 Mtetra
.646 .523 .699 r
.61773 .29652 .62473 .32143 .63757 .31229 .63061 .28922 Mtetra
.652 .537 .711 r
.63061 .28922 .63757 .31229 .65043 .30325 .64353 .28194 Mtetra
.658 .551 .723 r
.64353 .28194 .65043 .30325 .66332 .29437 .65649 .27475 Mtetra
.663 .567 .737 r
.65649 .27475 .66332 .29437 .67625 .28573 .66949 .26767 Mtetra
.668 .583 .751 r
.66949 .26767 .67625 .28573 .68922 .27738 .68254 .26074 Mtetra
.672 .6 .766 r
.68254 .26074 .68922 .27738 .70224 .26936 .69565 .25399 Mtetra
.676 .617 .782 r
.69565 .25399 .70224 .26936 .71531 .26167 .70881 .24743 Mtetra
.678 .634 .798 r
.70881 .24743 .71531 .26167 .72844 .25432 .72203 .24107 Mtetra
.68 .649 .813 r
.72203 .24107 .72844 .25432 .74163 .2473 .73531 .2349 Mtetra
.681 .664 .827 r
.73531 .2349 .74163 .2473 .75489 .24061 .74865 .22891 Mtetra
.681 .678 .841 r
.74865 .22891 .75489 .24061 .76822 .2342 .76206 .2231 Mtetra
.68 .69 .853 r
.76206 .2231 .76822 .2342 .78162 .22806 .77554 .21744 Mtetra
.678 .701 .864 r
.77554 .21744 .78162 .22806 .7951 .22215 .78909 .21192 Mtetra
.677 .709 .873 r
.78909 .21192 .7951 .22215 .80864 .21645 .80271 .20652 Mtetra
.675 .717 .88 r
.80271 .20652 .80864 .21645 .82226 .21091 .8164 .20122 Mtetra
.888 .468 .074 r
.18946 .4469 .19698 .45607 .20551 .47935 .19806 .46896 Mtetra
.923 .535 .163 r
.19806 .46896 .20551 .47935 .21367 .50907 .20629 .49716 Mtetra
.919 .535 .133 r
.20629 .49716 .21367 .50907 .22199 .54002 .21469 .52644 Mtetra
.795 .399 0 r
.21469 .52644 .22199 .54002 .23118 .56419 .22394 .54911 Mtetra
.146 .309 .772 r
.22394 .54911 .23118 .56419 .24183 .57365 .23465 .55757 Mtetra
.716 .619 .747 r
.23465 .55757 .24183 .57365 .25413 .56437 .24698 .54796 Mtetra
.823 .661 .682 r
.24698 .54796 .25413 .56437 .26771 .53845 .2606 .52231 Mtetra
.854 .673 .656 r
.2606 .52231 .26771 .53845 .28189 .50297 .27481 .48739 Mtetra
.86 .677 .653 r
.27481 .48739 .28189 .50297 .29598 .46633 .28895 .45127 Mtetra
.852 .678 .665 r
.28895 .45127 .29598 .46633 .30955 .4349 .30257 .42007 Mtetra
.827 .671 .69 r
.30257 .42007 .30955 .4349 .32248 .41154 .31556 .39654 Mtetra
.784 .654 .72 r
.31556 .39654 .32248 .41154 .33485 .39612 .32799 .38055 Mtetra
.727 .625 .744 r
.32799 .38055 .33485 .39612 .34685 .38683 .34006 .37037 Mtetra
.671 .59 .755 r
.34006 .37037 .34685 .38683 .35865 .38153 .35192 .36396 Mtetra
.633 .559 .754 r
.35192 .36396 .35865 .38153 .37039 .37847 .36371 .35965 Mtetra
.611 .536 .746 r
.36371 .35965 .37039 .37847 .38214 .3765 .37551 .35636 Mtetra
.601 .52 .735 r
.37551 .35636 .38214 .3765 .39393 .37497 .38734 .35348 Mtetra
.596 .508 .725 r
.38734 .35348 .39393 .37497 .4058 .37353 .39923 .35073 Mtetra
.594 .498 .716 r
.39923 .35073 .4058 .37353 .41774 .37203 .41119 .34797 Mtetra
.593 .491 .707 r
.41119 .34797 .41774 .37203 .42976 .37034 .42321 .34512 Mtetra
.593 .485 .7 r
.42321 .34512 .42976 .37034 .44185 .36838 .4353 .34213 Mtetra
.593 .48 .694 r
.4353 .34213 .44185 .36838 .45403 .36609 .44746 .33897 Mtetra
.594 .477 .689 r
.44746 .33897 .45403 .36609 .46628 .3634 .45968 .33559 Mtetra
.596 .476 .686 r
.45968 .33559 .46628 .3634 .47861 .36026 .47197 .33198 Mtetra
.598 .476 .684 r
.47197 .33198 .47861 .36026 .49101 .35663 .48432 .32811 Mtetra
.601 .477 .682 r
.48432 .32811 .49101 .35663 .50347 .35251 .49674 .32396 Mtetra
.604 .479 .682 r
.49674 .32396 .50347 .35251 .51599 .34787 .50921 .31953 Mtetra
.608 .482 .683 r
.50921 .31953 .51599 .34787 .52856 .34273 .52175 .31483 Mtetra
.612 .486 .685 r
.52175 .31483 .52856 .34273 .54118 .33711 .53433 .30986 Mtetra
.616 .492 .689 r
.53433 .30986 .54118 .33711 .55385 .33107 .54697 .30464 Mtetra
.62 .499 .693 r
.54697 .30464 .55385 .33107 .56655 .32465 .55965 .2992 Mtetra
.625 .506 .698 r
.55965 .2992 .56655 .32465 .57929 .31791 .57238 .29357 Mtetra
.63 .515 .705 r
.57238 .29357 .57929 .31791 .59207 .31093 .58516 .28779 Mtetra
.635 .525 .713 r
.58516 .28779 .59207 .31093 .60488 .30378 .59799 .28189 Mtetra
.64 .536 .721 r
.59799 .28189 .60488 .30378 .61773 .29652 .61086 .27591 Mtetra
.645 .549 .731 r
.61086 .27591 .61773 .29652 .63061 .28922 .62377 .26989 Mtetra
.649 .562 .742 r
.62377 .26989 .63061 .28922 .64353 .28194 .63674 .26386 Mtetra
.654 .576 .754 r
.63674 .26386 .64353 .28194 .65649 .27475 .64975 .25786 Mtetra
.658 .59 .767 r
.64975 .25786 .65649 .27475 .66949 .26767 .66282 .25189 Mtetra
.662 .605 .78 r
.66282 .25189 .66949 .26767 .68254 .26074 .67594 .24599 Mtetra
.666 .62 .794 r
.67594 .24599 .68254 .26074 .69565 .25399 .68911 .24017 Mtetra
.668 .635 .807 r
.68911 .24017 .69565 .25399 .70881 .24743 .70235 .23444 Mtetra
.671 .65 .821 r
.70235 .23444 .70881 .24743 .72203 .24107 .71564 .2288 Mtetra
.672 .664 .833 r
.71564 .2288 .72203 .24107 .73531 .2349 .72899 .22326 Mtetra
.673 .676 .845 r
.72899 .22326 .73531 .2349 .74865 .22891 .74241 .2178 Mtetra
.673 .688 .856 r
.74241 .2178 .74865 .22891 .76206 .2231 .7559 .21243 Mtetra
.672 .698 .865 r
.7559 .21243 .76206 .2231 .77554 .21744 .76945 .20714 Mtetra
.672 .707 .874 r
.76945 .20714 .77554 .21744 .78909 .21192 .78306 .20191 Mtetra
.671 .714 .881 r
.78306 .20191 .78909 .21192 .80271 .20652 .79675 .19674 Mtetra
.67 .72 .887 r
.79675 .19674 .80271 .20652 .8164 .20122 .8105 .19161 Mtetra
.874 .446 .038 r
.18188 .43771 .18946 .4469 .19806 .46896 .19056 .45851 Mtetra
.914 .519 .133 r
.19056 .45851 .19806 .46896 .20629 .49716 .19888 .4851 Mtetra
.907 .517 .098 r
.19888 .4851 .20629 .49716 .21469 .52644 .20736 .51267 Mtetra
.752 .356 0 r
.20736 .51267 .21469 .52644 .22394 .54911 .21669 .53387 Mtetra
.199 .341 .783 r
.21669 .53387 .22394 .54911 .23465 .55757 .22744 .54147 Mtetra
.717 .619 .748 r
.22744 .54147 .23465 .55757 .24698 .54796 .23979 .53181 Mtetra
.822 .663 .685 r
.23979 .53181 .24698 .54796 .2606 .52231 .25341 .50682 Mtetra
.855 .677 .66 r
.25341 .50682 .2606 .52231 .27481 .48739 .26762 .47294 Mtetra
.865 .685 .657 r
.26762 .47294 .27481 .48739 .28895 .45127 .28176 .43786 Mtetra
.861 .691 .671 r
.28176 .43786 .28895 .45127 .30257 .42007 .29541 .40739 Mtetra
.842 .694 .698 r
.29541 .40739 .30257 .42007 .31556 .39654 .30843 .38419 Mtetra
.806 .688 .735 r
.30843 .38419 .31556 .39654 .32799 .38055 .32091 .36813 Mtetra
.754 .672 .771 r
.32091 .36813 .32799 .38055 .34006 .37037 .33303 .35758 Mtetra
.702 .648 .793 r
.33303 .35758 .34006 .37037 .35192 .36396 .34494 .35058 Mtetra
.663 .623 .799 r
.34494 .35058 .35192 .36396 .36371 .35965 .35678 .34555 Mtetra
.64 .603 .796 r
.35678 .34555 .36371 .35965 .37551 .35636 .36862 .34147 Mtetra
.629 .588 .789 r
.36862 .34147 .37551 .35636 .38734 .35348 .38049 .33779 Mtetra
.623 .576 .78 r
.38049 .33779 .38734 .35348 .39923 .35073 .39242 .33423 Mtetra
.621 .566 .771 r
.39242 .33423 .39923 .35073 .41119 .34797 .4044 .33068 Mtetra
.619 .557 .763 r
.4044 .33068 .41119 .34797 .42321 .34512 .41644 .3271 Mtetra
.618 .55 .756 r
.41644 .3271 .42321 .34512 .4353 .34213 .42854 .32345 Mtetra
.617 .544 .749 r
.42854 .32345 .4353 .34213 .44746 .33897 .4407 .31971 Mtetra
.617 .539 .744 r
.4407 .31971 .44746 .33897 .45968 .33559 .45292 .31586 Mtetra
.618 .536 .74 r
.45292 .31586 .45968 .33559 .47197 .33198 .46521 .3119 Mtetra
.619 .534 .737 r
.46521 .3119 .47197 .33198 .48432 .32811 .47755 .30781 Mtetra
.62 .534 .735 r
.47755 .30781 .48432 .32811 .49674 .32396 .48996 .30358 Mtetra
.622 .535 .735 r
.48996 .30358 .49674 .32396 .50921 .31953 .50242 .2992 Mtetra
.624 .537 .735 r
.50242 .2992 .50921 .31953 .52175 .31483 .51494 .29468 Mtetra
.627 .54 .737 r
.51494 .29468 .52175 .31483 .53433 .30986 .52751 .29003 Mtetra
.63 .544 .739 r
.52751 .29003 .53433 .30986 .54697 .30464 .54014 .28524 Mtetra
.633 .55 .743 r
.54014 .28524 .54697 .30464 .55965 .2992 .55283 .28033 Mtetra
.636 .557 .748 r
.55283 .28033 .55965 .2992 .57238 .29357 .56556 .27532 Mtetra
.64 .565 .754 r
.56556 .27532 .57238 .29357 .58516 .28779 .57836 .27022 Mtetra
.643 .573 .761 r
.57836 .27022 .58516 .28779 .59799 .28189 .5912 .26504 Mtetra
.647 .583 .769 r
.5912 .26504 .59799 .28189 .61086 .27591 .6041 .25981 Mtetra
.65 .594 .778 r
.6041 .25981 .61086 .27591 .62377 .26989 .61705 .25454 Mtetra
.654 .605 .788 r
.61705 .25454 .62377 .26989 .63674 .26386 .63005 .24925 Mtetra
.657 .617 .798 r
.63005 .24925 .63674 .26386 .64975 .25786 .64312 .24395 Mtetra
.66 .629 .808 r
.64312 .24395 .64975 .25786 .66282 .25189 .65623 .23866 Mtetra
.662 .641 .819 r
.65623 .23866 .66282 .25189 .67594 .24599 .66941 .23338 Mtetra
.664 .653 .829 r
.66941 .23338 .67594 .24599 .68911 .24017 .68264 .22813 Mtetra
.666 .665 .839 r
.68264 .22813 .68911 .24017 .70235 .23444 .69593 .22291 Mtetra
.667 .676 .849 r
.69593 .22291 .70235 .23444 .71564 .2288 .70929 .21772 Mtetra
.668 .686 .858 r
.70929 .21772 .71564 .2288 .72899 .22326 .72271 .21256 Mtetra
.668 .695 .866 r
.72271 .21256 .72899 .22326 .74241 .2178 .73619 .20743 Mtetra
.668 .703 .873 r
.73619 .20743 .74241 .2178 .7559 .21243 .74973 .20234 Mtetra
.668 .711 .88 r
.74973 .20234 .7559 .21243 .76945 .20714 .76334 .19726 Mtetra
.668 .717 .885 r
.76334 .19726 .76945 .20714 .78306 .20191 .77702 .19221 Mtetra
.667 .722 .89 r
.77702 .19221 .78306 .20191 .79675 .19674 .79077 .18718 Mtetra
.667 .726 .894 r
.79077 .18718 .79675 .19674 .8105 .19161 .80458 .18216 Mtetra
.855 .417 0 r
.17425 .42845 .18188 .43771 .19056 .45851 .18303 .4479 Mtetra
.902 .498 .095 r
.18303 .4479 .19056 .45851 .19888 .4851 .19145 .47282 Mtetra
.889 .493 .052 r
.19145 .47282 .19888 .4851 .20736 .51267 .20003 .49862 Mtetra
.691 .303 0 r
.20003 .49862 .20736 .51267 .21669 .53387 .20944 .51834 Mtetra
.248 .368 .789 r
.20944 .51834 .21669 .53387 .22744 .54147 .22023 .52516 Mtetra
.714 .616 .747 r
.22023 .52516 .22744 .54147 .23979 .53181 .23258 .51564 Mtetra
.819 .661 .688 r
.23258 .51564 .23979 .53181 .25341 .50682 .24617 .49159 Mtetra
.854 .678 .664 r
.24617 .49159 .25341 .50682 .26762 .47294 .26034 .45909 Mtetra
.866 .69 .662 r
.26034 .45909 .26762 .47294 .28176 .43786 .27447 .42541 Mtetra
.864 .7 .677 r
.27447 .42541 .28176 .43786 .29541 .40739 .28811 .39606 Mtetra
.85 .709 .707 r
.28811 .39606 .29541 .40739 .30843 .38419 .30115 .37355 Mtetra
.819 .714 .749 r
.30115 .37355 .30843 .38419 .32091 .36813 .31366 .35779 Mtetra
.773 .709 .793 r
.31366 .35779 .32091 .36813 .33303 .35758 .3258 .34722 Mtetra
.723 .696 .824 r
.3258 .34722 .33303 .35758 .34494 .35058 .33776 .34 Mtetra
.684 .679 .84 r
.33776 .34 .34494 .35058 .35678 .34555 .34964 .33463 Mtetra
.661 .665 .843 r
.34964 .33463 .35678 .34555 .36862 .34147 .36152 .33014 Mtetra
.651 .654 .84 r
.36152 .33014 .36862 .34147 .38049 .33779 .37343 .32602 Mtetra
.646 .644 .835 r
.37343 .32602 .38049 .33779 .39242 .33423 .38539 .32202 Mtetra
.643 .636 .828 r
.38539 .32202 .39242 .33423 .4044 .33068 .3974 .31805 Mtetra
.642 .629 .822 r
.3974 .31805 .4044 .33068 .41644 .3271 .40947 .31406 Mtetra
.641 .623 .816 r
.40947 .31406 .41644 .3271 .42854 .32345 .42159 .31003 Mtetra
.64 .617 .811 r
.42159 .31003 .42854 .32345 .4407 .31971 .43378 .30595 Mtetra
.64 .613 .807 r
.43378 .30595 .4407 .31971 .45292 .31586 .44602 .30183 Mtetra
.64 .609 .803 r
.44602 .30183 .45292 .31586 .46521 .3119 .45832 .29764 Mtetra
.64 .607 .8 r
.45832 .29764 .46521 .3119 .47755 .30781 .47067 .29339 Mtetra
.641 .606 .799 r
.47067 .29339 .47755 .30781 .48996 .30358 .48309 .28907 Mtetra
.642 .605 .798 r
.48309 .28907 .48996 .30358 .50242 .2992 .49556 .28467 Mtetra
.643 .606 .798 r
.49556 .28467 .50242 .2992 .51494 .29468 .50809 .28021 Mtetra
.644 .608 .799 r
.50809 .28021 .51494 .29468 .52751 .29003 .52068 .27567 Mtetra
.646 .611 .801 r
.52068 .27567 .52751 .29003 .54014 .28524 .53332 .27106 Mtetra
.648 .615 .803 r
.53332 .27106 .54014 .28524 .55283 .28033 .54602 .26639 Mtetra
.649 .62 .807 r
.54602 .26639 .55283 .28033 .56556 .27532 .55878 .26166 Mtetra
.651 .626 .811 r
.55878 .26166 .56556 .27532 .57836 .27022 .5716 .25687 Mtetra
.654 .633 .817 r
.5716 .25687 .57836 .27022 .5912 .26504 .58447 .25204 Mtetra
.656 .64 .822 r
.58447 .25204 .5912 .26504 .6041 .25981 .5974 .24718 Mtetra
.657 .647 .828 r
.5974 .24718 .6041 .25981 .61705 .25454 .61038 .24228 Mtetra
.659 .655 .835 r
.61038 .24228 .61705 .25454 .63005 .24925 .62343 .23735 Mtetra
.661 .664 .842 r
.62343 .23735 .63005 .24925 .64312 .24395 .63653 .23241 Mtetra
.662 .672 .849 r
.63653 .23241 .64312 .24395 .65623 .23866 .6497 .22746 Mtetra
.663 .68 .855 r
.6497 .22746 .65623 .23866 .66941 .23338 .66292 .2225 Mtetra
.664 .688 .862 r
.66292 .2225 .66941 .23338 .68264 .22813 .6762 .21754 Mtetra
.665 .695 .868 r
.6762 .21754 .68264 .22813 .69593 .22291 .68955 .21257 Mtetra
.666 .702 .874 r
.68955 .21257 .69593 .22291 .70929 .21772 .70296 .20761 Mtetra
.666 .708 .879 r
.70296 .20761 .70929 .21772 .72271 .21256 .71643 .20264 Mtetra
.666 .714 .884 r
.71643 .20264 .72271 .21256 .73619 .20743 .72996 .19768 Mtetra
.666 .719 .888 r
.72996 .19768 .73619 .20743 .74973 .20234 .74356 .19272 Mtetra
.666 .723 .892 r
.74356 .19272 .74973 .20234 .76334 .19726 .75723 .18775 Mtetra
.665 .727 .895 r
.75723 .18775 .76334 .19726 .77702 .19221 .77096 .18278 Mtetra
.665 .73 .898 r
.77096 .18278 .77702 .19221 .79077 .18718 .78476 .17781 Mtetra
.665 .732 .9 r
.78476 .17781 .79077 .18718 .80458 .18216 .79862 .17282 Mtetra
.827 .38 0 r
.16658 .41907 .17425 .42845 .18303 .4479 .17546 .43712 Mtetra
.883 .471 .046 r
.17546 .43712 .18303 .4479 .19145 .47282 .184 .46028 Mtetra
.863 .461 0 r
.184 .46028 .19145 .47282 .20003 .49862 .1927 .48422 Mtetra
0 0 .339 r
.1927 .48422 .20003 .49862 .20944 .51834 .20219 .50243 Mtetra
.293 .39 .791 r
.20219 .50243 .20944 .51834 .22023 .52516 .21303 .50851 Mtetra
.709 .611 .746 r
.21303 .50851 .22023 .52516 .23258 .51564 .22536 .49923 Mtetra
.813 .658 .691 r
.22536 .49923 .23258 .51564 .24617 .49159 .2389 .47631 Mtetra
.849 .677 .668 r
.2389 .47631 .24617 .49159 .26034 .45909 .25302 .44543 Mtetra
.863 .691 .667 r
.25302 .44543 .26034 .45909 .27447 .42541 .26709 .41339 Mtetra
.864 .704 .683 r
.26709 .41339 .27447 .42541 .28811 .39606 .28071 .38539 Mtetra
.851 .717 .715 r
.28071 .38539 .28811 .39606 .30115 .37355 .29374 .36382 Mtetra
.824 .729 .76 r
.29374 .36382 .30115 .37355 .31366 .35779 .30627 .34857 Mtetra
.78 .732 .808 r
.30627 .34857 .31366 .35779 .3258 .34722 .31844 .3382 Mtetra
.733 .727 .846 r
.31844 .3382 .3258 .34722 .33776 .34 .33043 .33098 Mtetra
.695 .718 .867 r
.33043 .33098 .33776 .34 .34964 .33463 .34235 .32549 Mtetra
.673 .709 .875 r
.34235 .32549 .34964 .33463 .36152 .33014 .35426 .32083 Mtetra
.662 .702 .877 r
.35426 .32083 .36152 .33014 .37343 .32602 .36621 .31651 Mtetra
.658 .697 .875 r
.36621 .31651 .37343 .32602 .38539 .32202 .3782 .3123 Mtetra
.656 .692 .872 r
.3782 .3123 .38539 .32202 .3974 .31805 .39025 .30811 Mtetra
.655 .688 .869 r
.39025 .30811 .3974 .31805 .40947 .31406 .40235 .30391 Mtetra
.655 .684 .865 r
.40235 .30391 .40947 .31406 .42159 .31003 .4145 .29969 Mtetra
.655 .681 .862 r
.4145 .29969 .42159 .31003 .43378 .30595 .42672 .29544 Mtetra
.655 .678 .86 r
.42672 .29544 .43378 .30595 .44602 .30183 .43899 .29115 Mtetra
.655 .675 .857 r
.43899 .29115 .44602 .30183 .45832 .29764 .45131 .28683 Mtetra
.655 .673 .856 r
.45131 .28683 .45832 .29764 .47067 .29339 .46369 .28248 Mtetra
.655 .672 .854 r
.46369 .28248 .47067 .29339 .48309 .28907 .47614 .27808 Mtetra
.655 .672 .853 r
.47614 .27808 .48309 .28907 .49556 .28467 .48863 .27364 Mtetra
.656 .672 .853 r
.48863 .27364 .49556 .28467 .50809 .28021 .50119 .26917 Mtetra
.657 .673 .854 r
.50119 .26917 .50809 .28021 .52068 .27567 .5138 .26465 Mtetra
.657 .674 .854 r
.5138 .26465 .52068 .27567 .53332 .27106 .52647 .26009 Mtetra
.658 .676 .856 r
.52647 .26009 .53332 .27106 .54602 .26639 .5392 .25549 Mtetra
.659 .679 .858 r
.5392 .25549 .54602 .26639 .55878 .26166 .55199 .25085 Mtetra
.66 .682 .86 r
.55199 .25085 .55878 .26166 .5716 .25687 .56484 .24618 Mtetra
.661 .686 .863 r
.56484 .24618 .5716 .25687 .58447 .25204 .57774 .24148 Mtetra
.661 .689 .866 r
.57774 .24148 .58447 .25204 .5974 .24718 .59071 .23674 Mtetra
.662 .694 .869 r
.59071 .23674 .5974 .24718 .61038 .24228 .60373 .23199 Mtetra
.663 .698 .872 r
.60373 .23199 .61038 .24228 .62343 .23735 .61682 .2272 Mtetra
.663 .702 .876 r
.61682 .2272 .62343 .23735 .63653 .23241 .62996 .2224 Mtetra
.664 .707 .879 r
.62996 .2224 .63653 .23241 .6497 .22746 .64317 .21758 Mtetra
.664 .711 .883 r
.64317 .21758 .6497 .22746 .66292 .2225 .65643 .21274 Mtetra
.664 .715 .886 r
.65643 .21274 .66292 .2225 .6762 .21754 .66976 .20789 Mtetra
.665 .719 .889 r
.66976 .20789 .6762 .21754 .68955 .21257 .68316 .20302 Mtetra
.665 .722 .892 r
.68316 .20302 .68955 .21257 .70296 .20761 .69661 .19813 Mtetra
.665 .725 .894 r
.69661 .19813 .70296 .20761 .71643 .20264 .71013 .19324 Mtetra
.665 .728 .897 r
.71013 .19324 .71643 .20264 .72996 .19768 .72372 .18833 Mtetra
.665 .73 .899 r
.72372 .18833 .72996 .19768 .74356 .19272 .73737 .1834 Mtetra
.665 .732 .9 r
.73737 .1834 .74356 .19272 .75723 .18775 .75108 .17847 Mtetra
.664 .734 .902 r
.75108 .17847 .75723 .18775 .77096 .18278 .76486 .17351 Mtetra
.664 .736 .903 r
.76486 .17351 .77096 .18278 .78476 .17781 .77871 .16854 Mtetra
.664 .737 .904 r
.77871 .16854 .78476 .17781 .79862 .17282 .79262 .16355 Mtetra
.788 .332 0 r
.15886 .40957 .16658 .41907 .17546 .43712 .16786 .42615 Mtetra
.857 .436 0 r
.16786 .42615 .17546 .43712 .184 .46028 .17654 .44749 Mtetra
.826 .419 0 r
.17654 .44749 .184 .46028 .1927 .48422 .18536 .46953 Mtetra
0 0 .425 r
.18536 .46953 .1927 .48422 .20219 .50243 .19495 .48619 Mtetra
.332 .409 .792 r
.19495 .48619 .20219 .50243 .21303 .50851 .20583 .49153 Mtetra
.703 .606 .745 r
.20583 .49153 .21303 .50851 .22536 .49923 .21815 .48257 Mtetra
.806 .654 .694 r
.21815 .48257 .22536 .49923 .2389 .47631 .23162 .46089 Mtetra
.844 .675 .673 r
.23162 .46089 .2389 .47631 .25302 .44543 .24565 .43176 Mtetra
.859 .69 .672 r
.24565 .43176 .25302 .44543 .26709 .41339 .25966 .40153 Mtetra
.86 .706 .689 r
.25966 .40153 .26709 .41339 .28071 .38539 .27323 .37504 Mtetra
.849 .722 .722 r
.27323 .37504 .28071 .38539 .29374 .36382 .28625 .35453 Mtetra
.823 .737 .769 r
.28625 .35453 .29374 .36382 .30627 .34857 .29878 .33994 Mtetra
.782 .746 .82 r
.29878 .33994 .30627 .34857 .31844 .3382 .31098 .3299 Mtetra
.735 .746 .86 r
.31098 .3299 .31844 .3382 .33043 .33098 .32299 .3228 Mtetra
.698 .741 .884 r
.32299 .3228 .33043 .33098 .34235 .32549 .33494 .31732 Mtetra
.676 .736 .895 r
.33494 .31732 .34235 .32549 .35426 .32083 .34689 .3126 Mtetra
.666 .733 .899 r
.34689 .3126 .35426 .32083 .36621 .31651 .35887 .3082 Mtetra
.663 .73 .9 r
.35887 .3082 .36621 .31651 .3782 .3123 .37089 .3039 Mtetra
.661 .728 .899 r
.37089 .3039 .3782 .3123 .39025 .30811 .38297 .29962 Mtetra
.661 .727 .898 r
.38297 .29962 .39025 .30811 .40235 .30391 .39511 .29533 Mtetra
.661 .725 .897 r
.39511 .29533 .40235 .30391 .4145 .29969 .4073 .29102 Mtetra
.661 .724 .896 r
.4073 .29102 .4145 .29969 .42672 .29544 .41955 .28668 Mtetra
.661 .723 .895 r
.41955 .28668 .42672 .29544 .43899 .29115 .43185 .28232 Mtetra
.661 .722 .894 r
.43185 .28232 .43899 .29115 .45131 .28683 .44421 .27792 Mtetra
.662 .721 .893 r
.44421 .27792 .45131 .28683 .46369 .28248 .45663 .2735 Mtetra
.662 .72 .892 r
.45663 .2735 .46369 .28248 .47614 .27808 .4691 .26904 Mtetra
.4691 .26904 .47614 .27808 .48863 .27364 .48163 .26456 Mtetra
.662 .72 .891 r
.48163 .26456 .48863 .27364 .50119 .26917 .49422 .26004 Mtetra
.663 .72 .891 r
.49422 .26004 .50119 .26917 .5138 .26465 .50687 .25549 Mtetra
.50687 .25549 .5138 .26465 .52647 .26009 .51958 .25091 Mtetra
.663 .721 .891 r
.51958 .25091 .52647 .26009 .5392 .25549 .53234 .2463 Mtetra
.664 .721 .892 r
.53234 .2463 .5392 .25549 .55199 .25085 .54516 .24165 Mtetra
.664 .722 .893 r
.54516 .24165 .55199 .25085 .56484 .24618 .55805 .23699 Mtetra
.664 .723 .893 r
.55805 .23699 .56484 .24618 .57774 .24148 .57099 .23229 Mtetra
.664 .725 .894 r
.57099 .23229 .57774 .24148 .59071 .23674 .58399 .22757 Mtetra
.664 .726 .895 r
.58399 .22757 .59071 .23674 .60373 .23199 .59706 .22282 Mtetra
.665 .728 .896 r
.59706 .22282 .60373 .23199 .61682 .2272 .61018 .21806 Mtetra
.665 .729 .897 r
.61018 .21806 .61682 .2272 .62996 .2224 .62337 .21327 Mtetra
.665 .73 .899 r
.62337 .21327 .62996 .2224 .64317 .21758 .63662 .20846 Mtetra
.665 .732 .9 r
.63662 .20846 .64317 .21758 .65643 .21274 .64993 .20363 Mtetra
.665 .733 .901 r
.64993 .20363 .65643 .21274 .66976 .20789 .6633 .19878 Mtetra
.665 .734 .902 r
.6633 .19878 .66976 .20789 .68316 .20302 .67674 .19391 Mtetra
.665 .735 .903 r
.67674 .19391 .68316 .20302 .69661 .19813 .69024 .18902 Mtetra
.665 .736 .903 r
.69024 .18902 .69661 .19813 .71013 .19324 .70381 .18412 Mtetra
.664 .737 .904 r
.70381 .18412 .71013 .19324 .72372 .18833 .71744 .1792 Mtetra
.664 .738 .905 r
.71744 .1792 .72372 .18833 .73737 .1834 .73113 .17426 Mtetra
.664 .739 .905 r
.73113 .17426 .73737 .1834 .75108 .17847 .74489 .1693 Mtetra
.664 .739 .906 r
.74489 .1693 .75108 .17847 .76486 .17351 .75872 .16432 Mtetra
.664 .74 .906 r
.75872 .16432 .76486 .17351 .77871 .16854 .77262 .15932 Mtetra
.664 .74 .907 r
.77262 .15932 .77871 .16854 .79262 .16355 .78658 .1543 Mtetra
.737 .273 0 r
.15109 .4 .15886 .40957 .16786 .42615 .16022 .41509 Mtetra
.82 .39 0 r
.16022 .41509 .16786 .42615 .17654 .44749 .16904 .43456 Mtetra
.776 .366 0 r
.16904 .43456 .17654 .44749 .18536 .46953 .17801 .45467 Mtetra
0 0 .506 r
.17801 .45467 .18536 .46953 .19495 .48619 .18771 .46977 Mtetra
.365 .427 .793 r
.18771 .46977 .19495 .48619 .20583 .49153 .19862 .47439 Mtetra
.698 .602 .746 r
.19862 .47439 .20583 .49153 .21815 .48257 .21091 .4658 Mtetra
.799 .651 .699 r
.21091 .4658 .21815 .48257 .23162 .46089 .22431 .44543 Mtetra
.838 .673 .679 r
.22431 .44543 .23162 .46089 .24565 .43176 .23825 .41815 Mtetra
.854 .69 .679 r
.23825 .41815 .24565 .43176 .25966 .40153 .25217 .38983 Mtetra
.856 .708 .697 r
.25217 .38983 .25966 .40153 .27323 .37504 .26568 .36496 Mtetra
.846 .726 .731 r
.26568 .36496 .27323 .37504 .28625 .35453 .27867 .34562 Mtetra
.821 .744 .78 r
.27867 .34562 .28625 .35453 .29878 .33994 .2912 .33177 Mtetra
.78 .757 .832 r
.2912 .33177 .29878 .33994 .31098 .3299 .30341 .32215 Mtetra
.734 .761 .874 r
.30341 .32215 .31098 .3299 .32299 .3228 .31544 .31525 Mtetra
.698 .759 .899 r
.31544 .31525 .32299 .3228 .33494 .31732 .32742 .30986 Mtetra
.676 .757 .912 r
.32742 .30986 .33494 .31732 .34689 .3126 .3394 .30518 Mtetra
.666 .756 .917 r
.3394 .30518 .34689 .3126 .35887 .3082 .35141 .30078 Mtetra
.663 .756 .92 r
.35141 .30078 .35887 .3082 .37089 .3039 .36348 .29647 Mtetra
.662 .757 .921 r
.36348 .29647 .37089 .3039 .38297 .29962 .37559 .29218 Mtetra
.37559 .29218 .38297 .29962 .39511 .29533 .38776 .28786 Mtetra
.662 .758 .921 r
.38776 .28786 .39511 .29533 .4073 .29102 .39999 .28353 Mtetra
.39999 .28353 .4073 .29102 .41955 .28668 .41227 .27916 Mtetra
.663 .758 .921 r
.41227 .27916 .41955 .28668 .43185 .28232 .42461 .27475 Mtetra
.663 .759 .921 r
.42461 .27475 .43185 .28232 .44421 .27792 .43701 .27031 Mtetra
.664 .759 .921 r
.43701 .27031 .44421 .27792 .45663 .2735 .44947 .26584 Mtetra
.664 .758 .92 r
.44947 .26584 .45663 .2735 .4691 .26904 .46198 .26133 Mtetra
.665 .758 .92 r
.46198 .26133 .4691 .26904 .48163 .26456 .47455 .25679 Mtetra
.665 .758 .919 r
.47455 .25679 .48163 .26456 .49422 .26004 .48718 .25221 Mtetra
.665 .757 .919 r
.48718 .25221 .49422 .26004 .50687 .25549 .49987 .24759 Mtetra
.666 .757 .918 r
.49987 .24759 .50687 .25549 .51958 .25091 .51262 .24294 Mtetra
.666 .756 .917 r
.51262 .24294 .51958 .25091 .53234 .2463 .52542 .23826 Mtetra
.666 .755 .917 r
.52542 .23826 .53234 .2463 .54516 .24165 .53829 .23355 Mtetra
.667 .754 .916 r
.53829 .23355 .54516 .24165 .55805 .23699 .55121 .22881 Mtetra
.667 .753 .915 r
.55121 .22881 .55805 .23699 .57099 .23229 .5642 .22404 Mtetra
.667 .753 .914 r
.5642 .22404 .57099 .23229 .58399 .22757 .57724 .21925 Mtetra
.667 .752 .914 r
.57724 .21925 .58399 .22757 .59706 .22282 .59035 .21443 Mtetra
.667 .751 .913 r
.59035 .21443 .59706 .22282 .61018 .21806 .60351 .20959 Mtetra
.667 .75 .913 r
.60351 .20959 .61018 .21806 .62337 .21327 .61674 .20474 Mtetra
.667 .749 .912 r
.61674 .20474 .62337 .21327 .63662 .20846 .63003 .19986 Mtetra
.666 .748 .911 r
.63003 .19986 .63662 .20846 .64993 .20363 .64339 .19496 Mtetra
.64339 .19496 .64993 .20363 .6633 .19878 .6568 .19004 Mtetra
.666 .747 .911 r
.6568 .19004 .6633 .19878 .67674 .19391 .67029 .18511 Mtetra
.666 .746 .91 r
.67029 .18511 .67674 .19391 .69024 .18902 .68383 .18016 Mtetra
.68383 .18016 .69024 .18902 .70381 .18412 .69744 .1752 Mtetra
.665 .745 .91 r
.69744 .1752 .70381 .18412 .71744 .1792 .71112 .17022 Mtetra
.665 .744 .909 r
.71112 .17022 .71744 .1792 .73113 .17426 .72486 .16522 Mtetra
.72486 .16522 .73113 .17426 .74489 .1693 .73867 .1602 Mtetra
.73867 .1602 .74489 .1693 .75872 .16432 .75254 .15517 Mtetra
.665 .743 .909 r
.75254 .15517 .75872 .16432 .77262 .15932 .76648 .15011 Mtetra
.664 .743 .909 r
.76648 .15011 .77262 .15932 .78658 .1543 .78049 .14504 Mtetra
.673 .204 0 r
.14326 .39044 .15109 .4 .16022 .41509 .15252 .40404 Mtetra
.773 .335 0 r
.15252 .40404 .16022 .41509 .16904 .43456 .1615 .42167 Mtetra
.715 .304 0 r
.1615 .42167 .16904 .43456 .17801 .45467 .17062 .43985 Mtetra
0 0 .575 r
.17062 .43985 .17801 .45467 .18771 .46977 .18043 .45343 Mtetra
.389 .443 .796 r
.18043 .45343 .18771 .46977 .19862 .47439 .19138 .45739 Mtetra
.693 .602 .75 r
.19138 .45739 .19862 .47439 .21091 .4658 .20364 .44921 Mtetra
.792 .65 .705 r
.20364 .44921 .21091 .4658 .22431 .44543 .21694 .43023 Mtetra
.833 .674 .686 r
.21694 .43023 .22431 .44543 .23825 .41815 .23077 .4049 Mtetra
.85 .693 .687 r
.23077 .4049 .23825 .41815 .25217 .38983 .24458 .37858 Mtetra
.854 .713 .706 r
.24458 .37858 .25217 .38983 .26568 .36496 .25803 .35542 Mtetra
.844 .735 .743 r
.25803 .35542 .26568 .36496 .27867 .34562 .27098 .33735 Mtetra
.819 .758 .795 r
.27098 .33735 .27867 .34562 .2912 .33177 .28349 .32434 Mtetra
.778 .775 .85 r
.28349 .32434 .2912 .33177 .30341 .32215 .29571 .31524 Mtetra
.732 .784 .895 r
.29571 .31524 .30341 .32215 .31544 .31525 .30776 .30865 Mtetra
.694 .787 .922 r
.30776 .30865 .31544 .31525 .32742 .30986 .31977 .30344 Mtetra
.671 .788 .937 r
.31977 .30344 .32742 .30986 .3394 .30518 .33177 .29889 Mtetra
.66 .791 .944 r
.33177 .29889 .3394 .30518 .35141 .30078 .34382 .29459 Mtetra
.656 .794 .948 r
.34382 .29459 .35141 .30078 .36348 .29647 .35592 .29036 Mtetra
.655 .797 .95 r
.35592 .29036 .36348 .29647 .37559 .29218 .36807 .28613 Mtetra
.655 .8 .952 r
.36807 .28613 .37559 .29218 .38776 .28786 .38028 .28187 Mtetra
.656 .803 .954 r
.38028 .28187 .38776 .28786 .39999 .28353 .39254 .27757 Mtetra
.656 .805 .955 r
.39254 .27757 .39999 .28353 .41227 .27916 .40487 .27322 Mtetra
.657 .807 .955 r
.40487 .27322 .41227 .27916 .42461 .27475 .41725 .26881 Mtetra
.659 .809 .955 r
.41725 .26881 .42461 .27475 .43701 .27031 .42969 .26435 Mtetra
.66 .81 .955 r
.42969 .26435 .43701 .27031 .44947 .26584 .4422 .25984 Mtetra
.661 .81 .955 r
.4422 .25984 .44947 .26584 .46198 .26133 .45476 .25527 Mtetra
.663 .81 .954 r
.45476 .25527 .46198 .26133 .47455 .25679 .46737 .25064 Mtetra
.664 .809 .952 r
.46737 .25064 .47455 .25679 .48718 .25221 .48005 .24596 Mtetra
.666 .807 .951 r
.48005 .24596 .48718 .25221 .49987 .24759 .49279 .24123 Mtetra
.667 .805 .949 r
.49279 .24123 .49987 .24759 .51262 .24294 .50558 .23645 Mtetra
.668 .802 .947 r
.50558 .23645 .51262 .24294 .52542 .23826 .51844 .23162 Mtetra
.669 .799 .945 r
.51844 .23162 .52542 .23826 .53829 .23355 .53135 .22676 Mtetra
.67 .796 .942 r
.53135 .22676 .53829 .23355 .55121 .22881 .54432 .22185 Mtetra
.67 .792 .94 r
.54432 .22185 .55121 .22881 .5642 .22404 .55735 .21692 Mtetra
.671 .789 .937 r
.55735 .21692 .5642 .22404 .57724 .21925 .57044 .21195 Mtetra
.671 .785 .934 r
.57044 .21195 .57724 .21925 .59035 .21443 .5836 .20696 Mtetra
.671 .781 .932 r
.5836 .20696 .59035 .21443 .60351 .20959 .59681 .20195 Mtetra
.671 .777 .929 r
.59681 .20195 .60351 .20959 .61674 .20474 .61008 .19693 Mtetra
.671 .773 .927 r
.61008 .19693 .61674 .20474 .63003 .19986 .62341 .19189 Mtetra
.67 .77 .925 r
.62341 .19189 .63003 .19986 .64339 .19496 .63681 .18683 Mtetra
.67 .766 .922 r
.63681 .18683 .64339 .19496 .6568 .19004 .65027 .18177 Mtetra
.669 .763 .92 r
.65027 .18177 .6568 .19004 .67029 .18511 .66379 .1767 Mtetra
.669 .76 .919 r
.66379 .1767 .67029 .18511 .68383 .18016 .67738 .17162 Mtetra
.668 .757 .917 r
.67738 .17162 .68383 .18016 .69744 .1752 .69104 .16653 Mtetra
.668 .755 .916 r
.69104 .16653 .69744 .1752 .71112 .17022 .70475 .16144 Mtetra
.667 .753 .914 r
.70475 .16144 .71112 .17022 .72486 .16522 .71854 .15633 Mtetra
.667 .751 .913 r
.71854 .15633 .72486 .16522 .73867 .1602 .73239 .15121 Mtetra
.666 .749 .912 r
.73239 .15121 .73867 .1602 .75254 .15517 .74631 .14609 Mtetra
.666 .748 .912 r
.74631 .14609 .75254 .15517 .76648 .15011 .7603 .14095 Mtetra
.666 .747 .911 r
.7603 .14095 .76648 .15011 .78049 .14504 .77436 .1358 Mtetra
.602 .128 0 r
.13534 .38105 .14326 .39044 .15252 .40404 .14475 .39321 Mtetra
.719 .272 0 r
.14475 .39321 .15252 .40404 .1615 .42167 .15389 .40906 Mtetra
.651 .238 0 r
.15389 .40906 .1615 .42167 .17062 .43985 .16315 .42541 Mtetra
0 .065 .629 r
.16315 .42541 .17062 .43985 .18043 .45343 .17307 .43756 Mtetra
.404 .46 .805 r
.17307 .43756 .18043 .45343 .19138 .45739 .18406 .44095 Mtetra
.689 .605 .758 r
.18406 .44095 .19138 .45739 .20364 .44921 .19627 .4333 Mtetra
.788 .654 .714 r
.19627 .4333 .20364 .44921 .21694 .43023 .20946 .41582 Mtetra
.83 .68 .696 r
.20946 .41582 .21694 .43023 .23077 .4049 .22316 .39253 Mtetra
.849 .702 .699 r
.22316 .39253 .23077 .4049 .24458 .37858 .23686 .36834 Mtetra
.854 .726 .721 r
.23686 .36834 .24458 .37858 .25803 .35542 .25021 .34703 Mtetra
.847 .755 .762 r
.25021 .34703 .25803 .35542 .27098 .33735 .26311 .33038 Mtetra
.822 .787 .82 r
.26311 .33038 .27098 .33735 .28349 .32434 .2756 .31837 Mtetra
.778 .815 .882 r
.2756 .31837 .28349 .32434 .29571 .31524 .28781 .30994 Mtetra
.723 .832 .932 r
.28781 .30994 .29571 .31524 .30776 .30865 .29988 .30382 Mtetra
.676 .84 .962 r
.29988 .30382 .30776 .30865 .31977 .30344 .3119 .29896 Mtetra
.645 .846 .977 r
.3119 .29896 .31977 .30344 .33177 .29889 .32394 .2947 Mtetra
.628 .852 .984 r
.32394 .2947 .33177 .29889 .34382 .29459 .33601 .29065 Mtetra
.62 .858 .988 r
.33601 .29065 .34382 .29459 .35592 .29036 .34814 .28664 Mtetra
.615 .865 .99 r
.34814 .28664 .35592 .29036 .36807 .28613 .36033 .28261 Mtetra
.612 .871 .991 r
.36033 .28261 .36807 .28613 .38028 .28187 .37258 .27851 Mtetra
.611 .877 .991 r
.37258 .27851 .38028 .28187 .39254 .27757 .3849 .27434 Mtetra
.611 .882 .991 r
.3849 .27434 .39254 .27757 .40487 .27322 .39727 .27007 Mtetra
.612 .886 .99 r
.39727 .27007 .40487 .27322 .41725 .26881 .40971 .26571 Mtetra
.614 .889 .989 r
.40971 .26571 .41725 .26881 .42969 .26435 .42221 .26125 Mtetra
.618 .891 .989 r
.42221 .26125 .42969 .26435 .4422 .25984 .43477 .25669 Mtetra
.623 .892 .988 r
.43477 .25669 .4422 .25984 .45476 .25527 .44739 .25203 Mtetra
.629 .892 .987 r
.44739 .25203 .45476 .25527 .46737 .25064 .46007 .24727 Mtetra
.635 .891 .986 r
.46007 .24727 .46737 .25064 .48005 .24596 .47281 .24241 Mtetra
.642 .889 .985 r
.47281 .24241 .48005 .24596 .49279 .24123 .4856 .23746 Mtetra
.649 .885 .983 r
.4856 .23746 .49279 .24123 .50558 .23645 .49846 .23243 Mtetra
.655 .88 .981 r
.49846 .23243 .50558 .23645 .51844 .23162 .51137 .22732 Mtetra
.661 .874 .979 r
.51137 .22732 .51844 .23162 .53135 .22676 .52435 .22215 Mtetra
.666 .867 .975 r
.52435 .22215 .53135 .22676 .54432 .22185 .53737 .21693 Mtetra
.67 .859 .972 r
.53737 .21693 .54432 .22185 .55735 .21692 .55046 .21166 Mtetra
.673 .851 .968 r
.55046 .21166 .55735 .21692 .57044 .21195 .5636 .20636 Mtetra
.675 .842 .963 r
.5636 .20636 .57044 .21195 .5836 .20696 .57681 .20103 Mtetra
.677 .832 .958 r
.57681 .20103 .5836 .20696 .59681 .20195 .59007 .19569 Mtetra
.678 .823 .953 r
.59007 .19569 .59681 .20195 .61008 .19693 .60339 .19033 Mtetra
.678 .815 .948 r
.60339 .19033 .61008 .19693 .62341 .19189 .61677 .18498 Mtetra
.678 .806 .944 r
.61677 .18498 .62341 .19189 .63681 .18683 .63021 .17963 Mtetra
.677 .798 .939 r
.63021 .17963 .63681 .18683 .65027 .18177 .64371 .17429 Mtetra
.676 .791 .935 r
.64371 .17429 .65027 .18177 .66379 .1767 .65728 .16895 Mtetra
.675 .784 .931 r
.65728 .16895 .66379 .1767 .67738 .17162 .67091 .16363 Mtetra
.674 .778 .928 r
.67091 .16363 .67738 .17162 .69104 .16653 .6846 .15832 Mtetra
.673 .772 .925 r
.6846 .15832 .69104 .16653 .70475 .16144 .69836 .15302 Mtetra
.672 .767 .922 r
.69836 .15302 .70475 .16144 .71854 .15633 .71219 .14773 Mtetra
.671 .763 .92 r
.71219 .14773 .71854 .15633 .73239 .15121 .72608 .14245 Mtetra
.67 .759 .917 r
.72608 .14245 .73239 .15121 .74631 .14609 .74005 .13718 Mtetra
.669 .756 .916 r
.74005 .13718 .74631 .14609 .7603 .14095 .75408 .1319 Mtetra
.668 .753 .914 r
.75408 .1319 .7603 .14095 .77436 .1358 .76818 .12663 Mtetra
.536 .055 0 r
.12732 .37202 .13534 .38105 .14475 .39321 .13686 .38286 Mtetra
.668 .21 0 r
.13686 .38286 .14475 .39321 .15389 .40906 .14615 .39707 Mtetra
.6 .177 0 r
.14615 .39707 .15389 .40906 .16315 .42541 .15556 .41176 Mtetra
0 .114 .667 r
.15556 .41176 .16315 .42541 .17307 .43756 .16557 .42266 Mtetra
.406 .478 .821 r
.16557 .42266 .17307 .43756 .18406 .44095 .17658 .42567 Mtetra
.684 .617 .774 r
.17658 .42567 .18406 .44095 .19627 .4333 .18873 .41872 Mtetra
.786 .665 .73 r
.18873 .41872 .19627 .4333 .20946 .41582 .2018 .40289 Mtetra
.831 .694 .712 r
.2018 .40289 .20946 .41582 .22316 .39253 .21535 .38183 Mtetra
.853 .721 .717 r
.21535 .38183 .22316 .39253 .23686 .36834 .2289 .35995 Mtetra
.861 .753 .743 r
.2289 .35995 .23686 .36834 .25021 .34703 .24214 .34069 Mtetra
.855 .796 .793 r
.24214 .34069 .25021 .34703 .26311 .33038 .25497 .3257 Mtetra
.826 .847 .863 r
.25497 .3257 .26311 .33038 .2756 .31837 .26741 .31493 Mtetra
.763 .892 .935 r
.26741 .31493 .2756 .31837 .28781 .30994 .27961 .30744 Mtetra
.669 .91 .977 r
.27961 .30744 .28781 .30994 .29988 .30382 .29168 .30206 Mtetra
.573 .903 .98 r
.29168 .30206 .29988 .30382 .3119 .29896 .30372 .29782 Mtetra
.498 .887 .96 r
.30372 .29782 .3119 .29896 .32394 .2947 .31577 .2941 Mtetra
.445 .87 .931 r
.31577 .2941 .32394 .2947 .33601 .29065 .32787 .29055 Mtetra
.406 .855 .9 r
.32787 .29055 .33601 .29065 .34814 .28664 .34004 .287 Mtetra
.376 .841 .869 r
.34004 .287 .34814 .28664 .36033 .28261 .35227 .28337 Mtetra
.353 .829 .839 r
.35227 .28337 .36033 .28261 .37258 .27851 .36457 .27961 Mtetra
.337 .818 .814 r
.36457 .27961 .37258 .27851 .3849 .27434 .37694 .2757 Mtetra
.327 .811 .794 r
.37694 .2757 .3849 .27434 .39727 .27007 .38938 .27162 Mtetra
.325 .809 .78 r
.38938 .27162 .39727 .27007 .40971 .26571 .40188 .26737 Mtetra
.33 .811 .774 r
.40188 .26737 .40971 .26571 .42221 .26125 .41446 .26293 Mtetra
.342 .818 .776 r
.41446 .26293 .42221 .26125 .43477 .25669 .4271 .2583 Mtetra
.361 .83 .785 r
.4271 .2583 .43477 .25669 .44739 .25203 .4398 .25349 Mtetra
.386 .846 .801 r
.4398 .25349 .44739 .25203 .46007 .24727 .45256 .24848 Mtetra
.417 .864 .822 r
.45256 .24848 .46007 .24727 .47281 .24241 .46539 .2433 Mtetra
.451 .883 .847 r
.46539 .2433 .47281 .24241 .4856 .23746 .47827 .23796 Mtetra
.487 .902 .873 r
.47827 .23796 .4856 .23746 .49846 .23243 .49121 .23247 Mtetra
.523 .917 .9 r
.49121 .23247 .49846 .23243 .51137 .22732 .5042 .22686 Mtetra
.558 .929 .924 r
.5042 .22686 .51137 .22732 .52435 .22215 .51725 .22114 Mtetra
.59 .935 .944 r
.51725 .22114 .52435 .22215 .53737 .21693 .53035 .21533 Mtetra
.617 .936 .959 r
.53035 .21533 .53737 .21693 .55046 .21166 .54351 .20945 Mtetra
.639 .931 .97 r
.54351 .20945 .55046 .21166 .5636 .20636 .55672 .20354 Mtetra
.656 .923 .975 r
.55672 .20354 .5636 .20636 .57681 .20103 .56998 .1976 Mtetra
.669 .911 .977 r
.56998 .1976 .57681 .20103 .59007 .19569 .5833 .19165 Mtetra
.678 .896 .976 r
.5833 .19165 .59007 .19569 .60339 .19033 .59667 .18571 Mtetra
.683 .881 .972 r
.59667 .18571 .60339 .19033 .61677 .18498 .6101 .1798 Mtetra
.686 .866 .967 r
.6101 .1798 .61677 .18498 .63021 .17963 .62359 .17392 Mtetra
.687 .85 .961 r
.62359 .17392 .63021 .17963 .64371 .17429 .63714 .16808 Mtetra
.687 .836 .955 r
.63714 .16808 .64371 .17429 .65728 .16895 .65074 .1623 Mtetra
.686 .823 .949 r
.65074 .1623 .65728 .16895 .67091 .16363 .66441 .15656 Mtetra
.684 .811 .943 r
.66441 .15656 .67091 .16363 .6846 .15832 .67815 .15087 Mtetra
.682 .8 .938 r
.67815 .15087 .6846 .15832 .69836 .15302 .69195 .14523 Mtetra
.68 .79 .933 r
.69195 .14523 .69836 .15302 .71219 .14773 .70581 .13963 Mtetra
.678 .782 .929 r
.70581 .13963 .71219 .14773 .72608 .14245 .71975 .13408 Mtetra
.676 .775 .925 r
.71975 .13408 .72608 .14245 .74005 .13718 .73375 .12857 Mtetra
.674 .769 .922 r
.73375 .12857 .74005 .13718 .75408 .1319 .74782 .12309 Mtetra
.672 .764 .919 r
.74782 .12309 .75408 .1319 .76818 .12663 .76196 .11763 Mtetra
0 .006 .512 r
.11916 .36358 .12732 .37202 .13686 .38286 .12882 .37328 Mtetra
.632 .158 0 r
.12882 .37328 .13686 .38286 .14615 .39707 .13824 .38606 Mtetra
.574 .132 0 r
.13824 .38606 .14615 .39707 .15556 .41176 .14778 .39934 Mtetra
0 .141 .686 r
.14778 .39934 .15556 .41176 .16557 .42266 .15787 .40926 Mtetra
.387 .495 .847 r
.15787 .40926 .16557 .42266 .17658 .42567 .16888 .41215 Mtetra
.678 .637 .802 r
.16888 .41215 .17658 .42567 .18873 .41872 .18094 .40616 Mtetra
.787 .688 .755 r
.18094 .40616 .18873 .41872 .2018 .40289 .19386 .39223 Mtetra
.836 .721 .737 r
.19386 .39223 .2018 .40289 .21535 .38183 .20722 .37362 Mtetra
.862 .756 .745 r
.20722 .37362 .21535 .38183 .2289 .35995 .22061 .35432 Mtetra
.874 .805 .779 r
.22061 .35432 .2289 .35995 .24214 .34069 .23371 .33742 Mtetra
.864 .873 .843 r
.23371 .33742 .24214 .34069 .25497 .3257 .24643 .32439 Mtetra
.801 .947 .918 r
.24643 .32439 .25497 .3257 .26741 .31493 .25882 .31523 Mtetra
.621 .952 .928 r
.25882 .31523 .26741 .31493 .27961 .30744 .27098 .30906 Mtetra
.359 .831 .805 r
.27098 .30906 .27961 .30744 .29168 .30206 .28303 .3048 Mtetra
0 0 0 r
.28303 .3048 .29168 .30206 .30372 .29782 .29506 .30156 Mtetra
.29506 .30156 .30372 .29782 .31577 .2941 .30713 .29877 Mtetra
.051 0 0 r
.30713 .29877 .31577 .2941 .32787 .29055 .31925 .29607 Mtetra
.095 0 0 r
.31925 .29607 .32787 .29055 .34004 .287 .33145 .29329 Mtetra
.122 0 0 r
.33145 .29329 .34004 .287 .35227 .28337 .34373 .29034 Mtetra
.139 0 0 r
.34373 .29034 .35227 .28337 .36457 .27961 .35609 .28716 Mtetra
.146 0 0 r
.35609 .28716 .36457 .27961 .37694 .2757 .36853 .28371 Mtetra
.147 0 0 r
.36853 .28371 .37694 .2757 .38938 .27162 .38105 .27996 Mtetra
.141 0 0 r
.38105 .27996 .38938 .27162 .40188 .26737 .39365 .27588 Mtetra
.129 0 0 r
.39365 .27588 .40188 .26737 .41446 .26293 .40633 .27148 Mtetra
.11 0 0 r
.40633 .27148 .41446 .26293 .4271 .2583 .41907 .26673 Mtetra
.086 0 0 r
.41907 .26673 .4271 .2583 .4398 .25349 .43189 .26165 Mtetra
.055 0 0 r
.43189 .26165 .4398 .25349 .45256 .24848 .44477 .25623 Mtetra
.016 0 0 r
.44477 .25623 .45256 .24848 .46539 .2433 .45772 .25051 Mtetra
0 0 0 r
.45772 .25051 .46539 .2433 .47827 .23796 .47072 .24451 Mtetra
.47072 .24451 .47827 .23796 .49121 .23247 .48377 .23826 Mtetra
.48377 .23826 .49121 .23247 .5042 .22686 .49688 .23179 Mtetra
.49688 .23179 .5042 .22686 .51725 .22114 .51003 .22514 Mtetra
.51003 .22514 .51725 .22114 .53035 .21533 .52323 .21836 Mtetra
.379 .822 .687 r
.52323 .21836 .53035 .21533 .54351 .20945 .53648 .21149 Mtetra
.457 .879 .768 r
.53648 .21149 .54351 .20945 .55672 .20354 .54978 .20456 Mtetra
.528 .92 .838 r
.54978 .20456 .55672 .20354 .56998 .1976 .56312 .19762 Mtetra
.586 .945 .893 r
.56312 .19762 .56998 .1976 .5833 .19165 .5765 .19069 Mtetra
.63 .953 .932 r
.5765 .19069 .5833 .19165 .59667 .18571 .58994 .18381 Mtetra
.661 .949 .955 r
.58994 .18381 .59667 .18571 .6101 .1798 .60342 .17699 Mtetra
.681 .935 .967 r
.60342 .17699 .6101 .1798 .62359 .17392 .61696 .17027 Mtetra
.692 .917 .97 r
.61696 .17027 .62359 .17392 .63714 .16808 .63055 .16364 Mtetra
.698 .897 .969 r
.63055 .16364 .63714 .16808 .65074 .1623 .6442 .15713 Mtetra
.699 .876 .964 r
.6442 .15713 .65074 .1623 .66441 .15656 .65791 .15073 Mtetra
.698 .856 .958 r
.65791 .15073 .66441 .15656 .67815 .15087 .67168 .14445 Mtetra
.696 .839 .951 r
.67168 .14445 .67815 .15087 .69195 .14523 .68552 .13829 Mtetra
.692 .823 .945 r
.68552 .13829 .69195 .14523 .70581 .13963 .69942 .13223 Mtetra
.689 .809 .939 r
.69942 .13223 .70581 .13963 .71975 .13408 .71339 .12626 Mtetra
.685 .797 .934 r
.71339 .12626 .71975 .13408 .73375 .12857 .72743 .12039 Mtetra
.682 .786 .929 r
.72743 .12039 .73375 .12857 .74782 .12309 .74153 .1146 Mtetra
.679 .778 .925 r
.74153 .1146 .74782 .12309 .76196 .11763 .75572 .10888 Mtetra
0 .05 .538 r
.11083 .35588 .11916 .36358 .12882 .37328 .12058 .36466 Mtetra
.615 .119 0 r
.12058 .36466 .12882 .37328 .13824 .38606 .13013 .37629 Mtetra
.577 .107 0 r
.13013 .37629 .13824 .38606 .14778 .39934 .13976 .38845 Mtetra
0 .142 .679 r
.13976 .38845 .14778 .39934 .15787 .40926 .1499 .39772 Mtetra
.333 .508 .881 r
.1499 .39772 .15787 .40926 .16888 .41215 .16089 .4008 Mtetra
.662 .668 .845 r
.16089 .4008 .16888 .41215 .18094 .40616 .17283 .39605 Mtetra
.787 .725 .794 r
.17283 .39605 .18094 .40616 .19386 .39223 .18556 .3843 Mtetra
.844 .765 .775 r
.18556 .3843 .19386 .39223 .20722 .37362 .19872 .36845 Mtetra
.874 .815 .788 r
.19872 .36845 .20722 .37362 .22061 .35432 .2119 .35202 Mtetra
.882 .889 .833 r
.2119 .35202 .22061 .35432 .23371 .33742 .22483 .33782 Mtetra
.824 .976 .89 r
.22483 .33782 .23371 .33742 .24643 .32439 .23742 .32716 Mtetra
.553 .93 .818 r
.23742 .32716 .24643 .32439 .25882 .31523 .24971 .32001 Mtetra
0 0 0 r
.24971 .32001 .25882 .31523 .27098 .30906 .26181 .31559 Mtetra
.142 0 0 r
.26181 .31559 .27098 .30906 .28303 .3048 .27382 .31291 Mtetra
.263 0 0 r
.27382 .31291 .28303 .3048 .29506 .30156 .28583 .31112 Mtetra
.317 0 0 r
.28583 .31112 .29506 .30156 .30713 .29877 .29789 .30968 Mtetra
.342 0 .021 r
.29789 .30968 .30713 .29877 .31925 .29607 .31003 .30823 Mtetra
.353 0 .058 r
.31003 .30823 .31925 .29607 .33145 .29329 .32226 .3066 Mtetra
.356 0 .084 r
.32226 .3066 .33145 .29329 .34373 .29034 .33459 .30465 Mtetra
.355 0 .103 r
.33459 .30465 .34373 .29034 .35609 .28716 .34702 .30231 Mtetra
.35 0 .115 r
.34702 .30231 .35609 .28716 .36853 .28371 .35955 .29952 Mtetra
.341 0 .122 r
.35955 .29952 .36853 .28371 .38105 .27996 .37218 .29623 Mtetra
.33 0 .124 r
.37218 .29623 .38105 .27996 .39365 .27588 .3849 .29241 Mtetra
.315 0 .12 r
.3849 .29241 .39365 .27588 .40633 .27148 .39771 .28802 Mtetra
.297 0 .112 r
.39771 .28802 .40633 .27148 .41907 .26673 .41061 .28307 Mtetra
.276 0 .099 r
.41061 .28307 .41907 .26673 .43189 .26165 .42358 .27756 Mtetra
.251 0 .08 r
.42358 .27756 .43189 .26165 .44477 .25623 .43662 .27151 Mtetra
.221 0 .055 r
.43662 .27151 .44477 .25623 .45772 .25051 .44972 .26496 Mtetra
.186 0 .022 r
.44972 .26496 .45772 .25051 .47072 .24451 .46288 .25796 Mtetra
.145 0 0 r
.46288 .25796 .47072 .24451 .48377 .23826 .4761 .25055 Mtetra
.096 0 0 r
.4761 .25055 .48377 .23826 .49688 .23179 .48935 .24281 Mtetra
.038 0 0 r
.48935 .24281 .49688 .23179 .51003 .22514 .50265 .2348 Mtetra
0 0 0 r
.50265 .2348 .51003 .22514 .52323 .21836 .51598 .22659 Mtetra
.51598 .22659 .52323 .21836 .53648 .21149 .52935 .21825 Mtetra
.52935 .21825 .53648 .21149 .54978 .20456 .54275 .20985 Mtetra
.54275 .20985 .54978 .20456 .56312 .19762 .55619 .20145 Mtetra
.408 .825 .64 r
.55619 .20145 .56312 .19762 .5765 .19069 .56966 .19311 Mtetra
.504 .897 .747 r
.56966 .19311 .5765 .19069 .58994 .18381 .58317 .18486 Mtetra
.583 .944 .835 r
.58317 .18486 .58994 .18381 .60342 .17699 .59672 .17676 Mtetra
.642 .965 .897 r
.59672 .17676 .60342 .17699 .61696 .17027 .61031 .16883 Mtetra
.68 .965 .935 r
.61031 .16883 .61696 .17027 .63055 .16364 .62395 .16109 Mtetra
.702 .95 .955 r
.62395 .16109 .63055 .16364 .6442 .15713 .63765 .15356 Mtetra
.712 .929 .962 r
.63765 .15356 .6442 .15713 .65791 .15073 .65139 .14624 Mtetra
.715 .904 .963 r
.65139 .14624 .65791 .15073 .67168 .14445 .6652 .13914 Mtetra
.713 .88 .959 r
.6652 .13914 .67168 .14445 .68552 .13829 .67907 .13224 Mtetra
.709 .858 .953 r
.67907 .13224 .68552 .13829 .69942 .13223 .693 .12554 Mtetra
.704 .838 .947 r
.693 .12554 .69942 .13223 .71339 .12626 .707 .11902 Mtetra
.699 .821 .94 r
.707 .11902 .71339 .12626 .72743 .12039 .72107 .11266 Mtetra
.694 .806 .935 r
.72107 .11266 .72743 .12039 .74153 .1146 .73522 .10645 Mtetra
.689 .793 .93 r
.73522 .10645 .74153 .1146 .75572 .10888 .74943 .10037 Mtetra
0 .081 .548 r
.10233 .34889 .11083 .35588 .12058 .36466 .11216 .35695 Mtetra
.606 .091 0 r
.11216 .35695 .12058 .36466 .13013 .37629 .1218 .36768 Mtetra
.591 .093 0 r
.1218 .36768 .13013 .37629 .13976 .38845 .13151 .37901 Mtetra
0 .122 .644 r
.13151 .37901 .13976 .38845 .1499 .39772 .14167 .38792 Mtetra
.235 .502 .902 r
.14167 .38792 .1499 .39772 .16089 .4008 .1526 .39148 Mtetra
.623 .7 .9 r
.1526 .39148 .16089 .4008 .17283 .39605 .1644 .38823 Mtetra
.776 .77 .847 r
.1644 .38823 .17283 .39605 .18556 .3843 .17692 .37888 Mtetra
.842 .822 .829 r
.17692 .37888 .18556 .3843 .19872 .36845 .18983 .36599 Mtetra
.87 .891 .847 r
.18983 .36599 .19872 .36845 .2119 .35202 .20278 .3527 Mtetra
.834 .977 .881 r
.20278 .3527 .2119 .35202 .22483 .33782 .21551 .34147 Mtetra
.564 .93 .784 r
.21551 .34147 .22483 .33782 .23742 .32716 .22794 .33348 Mtetra
0 0 0 r
.22794 .33348 .23742 .32716 .24971 .32001 .2401 .32871 Mtetra
.242 0 0 r
.2401 .32871 .24971 .32001 .26181 .31559 .25211 .32642 Mtetra
.367 0 .031 r
.25211 .32642 .26181 .31559 .27382 .31291 .26405 .32569 Mtetra
.418 0 .107 r
.26405 .32569 .27382 .31291 .28583 .31112 .27602 .32573 Mtetra
.438 .023 .152 r
.27602 .32573 .28583 .31112 .29789 .30968 .28807 .326 Mtetra
.444 .042 .181 r
.28807 .326 .29789 .30968 .31003 .30823 .30021 .32614 Mtetra
.443 .052 .201 r
.30021 .32614 .31003 .30823 .32226 .3066 .31247 .32594 Mtetra
.437 .055 .215 r
.31247 .32594 .32226 .3066 .33459 .30465 .32486 .32526 Mtetra
.429 .054 .224 r
.32486 .32526 .33459 .30465 .34702 .30231 .33737 .32397 Mtetra
.418 .05 .229 r
.33737 .32397 .34702 .30231 .35955 .29952 .35001 .32198 Mtetra
.405 .042 .231 r
.35001 .32198 .35955 .29952 .37218 .29623 .36276 .31923 Mtetra
.39 .03 .229 r
.36276 .31923 .37218 .29623 .3849 .29241 .37563 .31566 Mtetra
.373 .016 .224 r
.37563 .31566 .3849 .29241 .39771 .28802 .38861 .31125 Mtetra
.353 0 .215 r
.38861 .31125 .39771 .28802 .41061 .28307 .40169 .30598 Mtetra
.331 0 .202 r
.40169 .30598 .41061 .28307 .42358 .27756 .41485 .29987 Mtetra
.306 0 .186 r
.41485 .29987 .42358 .27756 .43662 .27151 .42809 .29295 Mtetra
.277 0 .165 r
.42809 .29295 .43662 .27151 .44972 .26496 .44139 .28529 Mtetra
.244 0 .138 r
.44139 .28529 .44972 .26496 .46288 .25796 .45475 .27695 Mtetra
.206 0 .104 r
.45475 .27695 .46288 .25796 .4761 .25055 .46815 .26804 Mtetra
.161 0 .063 r
.46815 .26804 .4761 .25055 .48935 .24281 .48159 .25864 Mtetra
.109 0 .012 r
.48159 .25864 .48935 .24281 .50265 .2348 .49506 .24886 Mtetra
.048 0 0 r
.49506 .24886 .50265 .2348 .51598 .22659 .50856 .23882 Mtetra
0 0 0 r
.50856 .23882 .51598 .22659 .52935 .21825 .52207 .22862 Mtetra
.52207 .22862 .52935 .21825 .54275 .20985 .5356 .21835 Mtetra
.5356 .21835 .54275 .20985 .55619 .20145 .54915 .20812 Mtetra
.54915 .20812 .55619 .20145 .56966 .19311 .56273 .198 Mtetra
.43 .817 .585 r
.56273 .198 .56966 .19311 .58317 .18486 .57633 .18806 Mtetra
.533 .9 .704 r
.57633 .18806 .58317 .18486 .59672 .17676 .58995 .17836 Mtetra
.618 .954 .803 r
.58995 .17836 .59672 .17676 .61031 .16883 .60361 .16895 Mtetra
.677 .977 .874 r
.60361 .16895 .61031 .16883 .62395 .16109 .61731 .15985 Mtetra
.713 .977 .919 r
.61731 .15985 .62395 .16109 .63765 .15356 .63105 .15108 Mtetra
.731 .96 .942 r
.63105 .15108 .63765 .15356 .65139 .14624 .64483 .14265 Mtetra
.737 .936 .952 r
.64483 .14265 .65139 .14624 .6652 .13914 .65868 .13455 Mtetra
.735 .909 .954 r
.65868 .13455 .6652 .13914 .67907 .13224 .67258 .12677 Mtetra
.73 .883 .951 r
.67258 .12677 .67907 .13224 .693 .12554 .68654 .1193 Mtetra
.722 .86 .946 r
.68654 .1193 .693 .12554 .707 .11902 .70057 .11212 Mtetra
.715 .839 .941 r
.70057 .11212 .707 .11902 .72107 .11266 .71468 .10519 Mtetra
.707 .821 .936 r
.71468 .10519 .72107 .11266 .73522 .10645 .72885 .09849 Mtetra
.7 .805 .931 r
.72885 .09849 .73522 .10645 .74943 .10037 .7431 .092 Mtetra
0 .117 .572 r
.09369 .34224 .10233 .34889 .11216 .35695 .1036 .34973 Mtetra
.584 .057 0 r
.1036 .34973 .11216 .35695 .1218 .36768 .11331 .35971 Mtetra
.584 .072 0 r
.11331 .35971 .1218 .36768 .13151 .37901 .12308 .37039 Mtetra
0 .108 .614 r
.12308 .37039 .13151 .37901 .14167 .38792 .13326 .37909 Mtetra
.126 .468 .893 r
.13326 .37909 .14167 .38792 .1526 .39148 .14411 .38325 Mtetra
.551 .705 .942 r
.14411 .38325 .1526 .39148 .1644 .38823 .15575 .38156 Mtetra
.736 .797 .901 r
.15575 .38156 .1644 .38823 .17692 .37888 .16805 .37465 Mtetra
.811 .863 .886 r
.16805 .37465 .17692 .37888 .18983 .36599 .18071 .36474 Mtetra
.821 .941 .905 r
.18071 .36474 .18983 .36599 .20278 .3527 .1934 .3546 Mtetra
.68 .977 .882 r
.1934 .3546 .20278 .3527 .21551 .34147 .20591 .34639 Mtetra
0 0 0 r
.20591 .34639 .21551 .34147 .22794 .33348 .21816 .34115 Mtetra
.203 0 0 r
.21816 .34115 .22794 .33348 .2401 .32871 .23019 .33885 Mtetra
.383 0 .018 r
.23019 .33885 .2401 .32871 .25211 .32642 .24209 .33879 Mtetra
.455 .018 .118 r
.24209 .33879 .25211 .32642 .26405 .32569 .25396 .34012 Mtetra
.482 .065 .171 r
.25396 .34012 .26405 .32569 .27602 .32573 .26587 .34209 Mtetra
.49 .087 .203 r
.26587 .34209 .27602 .32573 .28807 .326 .27789 .34416 Mtetra
.488 .096 .224 r
.27789 .34416 .28807 .326 .30021 .32614 .29003 .34598 Mtetra
.48 .098 .237 r
.29003 .34598 .30021 .32614 .31247 .32594 .30232 .34729 Mtetra
.469 .095 .246 r
.30232 .34729 .31247 .32594 .32486 .32526 .31476 .3479 Mtetra
.455 .088 .251 r
.31476 .3479 .32486 .32526 .33737 .32397 .32735 .34767 Mtetra
.44 .077 .252 r
.32735 .34767 .33737 .32397 .35001 .32198 .3401 .34648 Mtetra
.421 .064 .25 r
.3401 .34648 .35001 .32198 .36276 .31923 .35299 .34423 Mtetra
.401 .047 .245 r
.35299 .34423 .36276 .31923 .37563 .31566 .36602 .34086 Mtetra
.378 .026 .236 r
.36602 .34086 .37563 .31566 .38861 .31125 .37918 .33632 Mtetra
.352 .003 .224 r
.37918 .33632 .38861 .31125 .40169 .30598 .39245 .33062 Mtetra
.324 0 .209 r
.39245 .33062 .40169 .30598 .41485 .29987 .40582 .32377 Mtetra
.291 0 .189 r
.40582 .32377 .41485 .29987 .42809 .29295 .41928 .31584 Mtetra
.254 0 .164 r
.41928 .31584 .42809 .29295 .44139 .28529 .4328 .3069 Mtetra
.213 0 .133 r
.4328 .3069 .44139 .28529 .45475 .27695 .44638 .29707 Mtetra
.165 0 .095 r
.44638 .29707 .45475 .27695 .46815 .26804 .45999 .28648 Mtetra
.11 0 .048 r
.45999 .28648 .46815 .26804 .48159 .25864 .47363 .27526 Mtetra
.046 0 0 r
.47363 .27526 .48159 .25864 .49506 .24886 .48729 .26357 Mtetra
0 0 0 r
.48729 .26357 .49506 .24886 .50856 .23882 .50096 .25155 Mtetra
.50096 .25155 .50856 .23882 .52207 .22862 .51463 .23935 Mtetra
.51463 .23935 .52207 .22862 .5356 .21835 .52831 .2271 Mtetra
.52831 .2271 .5356 .21835 .54915 .20812 .54199 .21494 Mtetra
.54199 .21494 .54915 .20812 .56273 .198 .55567 .20296 Mtetra
.534 .873 .613 r
.55567 .20296 .56273 .198 .57633 .18806 .56936 .19126 Mtetra
.626 .94 .721 r
.56936 .19126 .57633 .18806 .58995 .17836 .58307 .17992 Mtetra
.695 .979 .806 r
.58307 .17992 .58995 .17836 .60361 .16895 .5968 .16898 Mtetra
.739 .992 .867 r
.5968 .16898 .60361 .16895 .61731 .15985 .61056 .15848 Mtetra
.763 .984 .906 r
.61056 .15848 .61731 .15985 .63105 .15108 .62435 .14845 Mtetra
.771 .964 .927 r
.62435 .14845 .63105 .15108 .64483 .14265 .63818 .13889 Mtetra
.769 .939 .937 r
.63818 .13889 .64483 .14265 .65868 .13455 .65207 .12979 Mtetra
.762 .912 .94 r
.65207 .12979 .65868 .13455 .67258 .12677 .66601 .12114 Mtetra
.752 .886 .94 r
.66601 .12114 .67258 .12677 .68654 .1193 .68 .1129 Mtetra
.741 .862 .937 r
.68 .1129 .68654 .1193 .70057 .11212 .69407 .10506 Mtetra
.73 .841 .933 r
.69407 .10506 .70057 .11212 .71468 .10519 .7082 .09756 Mtetra
.719 .823 .929 r
.7082 .09756 .71468 .10519 .72885 .09849 .72241 .09038 Mtetra
.71 .807 .925 r
.72241 .09038 .72885 .09849 .7431 .092 .7367 .08348 Mtetra
0 .179 .64 r
.08502 .33529 .09369 .34224 .1036 .34973 .09499 .3422 Mtetra
.516 0 0 r
.09499 .3422 .1036 .34973 .11331 .35971 .10478 .35143 Mtetra
.523 .017 0 r
.10478 .35143 .11331 .35971 .12308 .37039 .11463 .36142 Mtetra
0 .138 .647 r
.11463 .36142 .12308 .37039 .13326 .37909 .12482 .36984 Mtetra
.096 .439 .877 r
.12482 .36984 .13326 .37909 .14411 .38325 .13561 .37446 Mtetra
.482 .663 .942 r
.13561 .37446 .14411 .38325 .15575 .38156 .14711 .37412 Mtetra
.672 .767 .922 r
.14711 .37412 .15575 .38156 .16805 .37465 .1592 .36935 Mtetra
.749 .839 .919 r
.1592 .36935 .16805 .37465 .18071 .36474 .17162 .3621 Mtetra
.747 .915 .949 r
.17162 .3621 .18071 .36474 .1934 .3546 .18408 .35475 Mtetra
.579 .934 .934 r
.18408 .35475 .1934 .3546 .20591 .34639 .19638 .34921 Mtetra
0 0 0 r
.19638 .34921 .20591 .34639 .21816 .34115 .20847 .34638 Mtetra
.265 0 0 r
.20847 .34638 .21816 .34115 .23019 .33885 .22036 .3462 Mtetra
.427 0 0 r
.22036 .3462 .23019 .33885 .24209 .33879 .23216 .34803 Mtetra
.491 .02 .065 r
.23216 .34803 .24209 .33879 .25396 .34012 .24396 .35108 Mtetra
.512 .063 .12 r
.24396 .35108 .25396 .34012 .26587 .34209 .25583 .35464 Mtetra
.515 .08 .152 r
.25583 .35464 .26587 .34209 .27789 .34416 .26782 .35818 Mtetra
.507 .083 .171 r
.26782 .35818 .27789 .34416 .29003 .34598 .27996 .36134 Mtetra
.493 .078 .182 r
.27996 .36134 .29003 .34598 .30232 .34729 .29227 .36383 Mtetra
.474 .067 .187 r
.29227 .36383 .30232 .34729 .31476 .3479 .30476 .36544 Mtetra
.452 .051 .188 r
.30476 .36544 .31476 .3479 .32735 .34767 .31743 .36601 Mtetra
.425 .03 .183 r
.31743 .36601 .32735 .34767 .3401 .34648 .33028 .36538 Mtetra
.395 .004 .174 r
.33028 .36538 .3401 .34648 .35299 .34423 .34329 .36344 Mtetra
.36 0 .161 r
.34329 .36344 .35299 .34423 .36602 .34086 .35647 .36011 Mtetra
.32 0 .142 r
.35647 .36011 .36602 .34086 .37918 .33632 .36979 .35535 Mtetra
.275 0 .117 r
.36979 .35535 .37918 .33632 .39245 .33062 .38324 .34916 Mtetra
.223 0 .086 r
.38324 .34916 .39245 .33062 .40582 .32377 .3968 .34157 Mtetra
.163 0 .047 r
.3968 .34157 .40582 .32377 .41928 .31584 .41045 .33267 Mtetra
.095 0 0 r
.41045 .33267 .41928 .31584 .4328 .3069 .42417 .32257 Mtetra
.018 0 0 r
.42417 .32257 .4328 .3069 .44638 .29707 .43794 .31141 Mtetra
0 0 0 r
.43794 .31141 .44638 .29707 .45999 .28648 .45175 .29934 Mtetra
.45175 .29934 .45999 .28648 .47363 .27526 .46557 .28655 Mtetra
.46557 .28655 .47363 .27526 .48729 .26357 .4794 .27321 Mtetra
.4794 .27321 .48729 .26357 .50096 .25155 .49323 .25952 Mtetra
.49323 .25952 .50096 .25155 .51463 .23935 .50705 .24565 Mtetra
.586 .882 .582 r
.50705 .24565 .51463 .23935 .52831 .2271 .52086 .23177 Mtetra
.672 .941 .67 r
.52086 .23177 .52831 .2271 .54199 .21494 .53466 .21802 Mtetra
.738 .979 .744 r
.53466 .21802 .54199 .21494 .55567 .20296 .54845 .20454 Mtetra
.784 .997 .802 r
.54845 .20454 .55567 .20296 .56936 .19126 .56224 .19142 Mtetra
.811 .998 .845 r
.56224 .19142 .56936 .19126 .58307 .17992 .57603 .17876 Mtetra
.824 .988 .875 r
.57603 .17876 .58307 .17992 .5968 .16898 .58983 .16661 Mtetra
.825 .969 .894 r
.58983 .16661 .5968 .16898 .61056 .15848 .60365 .15501 Mtetra
.819 .947 .906 r
.60365 .15501 .61056 .15848 .62435 .14845 .6175 .14399 Mtetra
.808 .923 .913 r
.6175 .14399 .62435 .14845 .63818 .13889 .63139 .13355 Mtetra
.795 .9 .917 r
.63139 .13355 .63818 .13889 .65207 .12979 .64532 .12368 Mtetra
.78 .877 .918 r
.64532 .12368 .65207 .12979 .66601 .12114 .6593 .11434 Mtetra
.766 .857 .918 r
.6593 .11434 .66601 .12114 .68 .1129 .67334 .10552 Mtetra
.752 .838 .917 r
.67334 .10552 .68 .1129 .69407 .10506 .68745 .09716 Mtetra
.738 .822 .916 r
.68745 .09716 .69407 .10506 .7082 .09756 .70163 .08923 Mtetra
.727 .807 .915 r
.70163 .08923 .7082 .09756 .72241 .09038 .71587 .08168 Mtetra
.716 .795 .914 r
.71587 .08168 .72241 .09038 .7367 .08348 .7302 .07447 Mtetra
0 .278 .753 r
.07639 .32734 .08502 .33529 .09499 .3422 .08646 .33349 Mtetra
0 .12 .625 r
.08646 .33349 .09499 .3422 .10478 .35143 .09636 .34178 Mtetra
0 .095 .619 r
.09636 .34178 .10478 .35143 .11463 .36142 .1063 .35084 Mtetra
0 .223 .739 r
.1063 .35084 .11463 .36142 .12482 .36984 .11655 .35867 Mtetra
.179 .437 .868 r
.11655 .35867 .12482 .36984 .13561 .37446 .12733 .36332 Mtetra
.465 .595 .898 r
.12733 .36332 .13561 .37446 .14711 .37412 .13873 .36379 Mtetra
.618 .681 .887 r
.13873 .36379 .14711 .37412 .1592 .36935 .15066 .36054 Mtetra
.683 .737 .892 r
.15066 .36054 .1592 .36935 .17162 .3621 .16289 .35522 Mtetra
.687 .79 .928 r
.16289 .35522 .17162 .3621 .18408 .35475 .17517 .34992 Mtetra
.605 .832 .986 r
.17517 .34992 .18408 .35475 .19638 .34921 .18732 .34628 Mtetra
.349 .78 .97 r
.18732 .34628 .19638 .34921 .20847 .34638 .19928 .34507 Mtetra
0 .543 .743 r
.19928 .34507 .20847 .34638 .22036 .3462 .21109 .3462 Mtetra
.3 0 0 r
.21109 .3462 .22036 .3462 .23216 .34803 .22283 .3491 Mtetra
.418 0 0 r
.22283 .3491 .23216 .34803 .24396 .35108 .23459 .35305 Mtetra
.461 0 0 r
.23459 .35305 .24396 .35108 .25583 .35464 .24644 .35738 Mtetra
.467 0 0 r
.24644 .35738 .25583 .35464 .26782 .35818 .25843 .3616 Mtetra
.45 0 0 r
.25843 .3616 .26782 .35818 .27996 .36134 .27058 .36534 Mtetra
.418 0 0 r
.27058 .36534 .27996 .36134 .29227 .36383 .28292 .36831 Mtetra
.371 0 0 r
.28292 .36831 .29227 .36383 .30476 .36544 .29545 .37029 Mtetra
.308 0 0 r
.29545 .37029 .30476 .36544 .31743 .36601 .30818 .3711 Mtetra
.228 0 0 r
.30818 .3711 .31743 .36601 .33028 .36538 .3211 .37059 Mtetra
.128 0 0 r
.3211 .37059 .33028 .36538 .34329 .36344 .3342 .36863 Mtetra
.007 0 0 r
.3342 .36863 .34329 .36344 .35647 .36011 .34748 .36514 Mtetra
0 0 0 r
.34748 .36514 .35647 .36011 .36979 .35535 .36091 .36009 Mtetra
.36091 .36009 .36979 .35535 .38324 .34916 .37448 .35348 Mtetra
.425 .843 .678 r
.37448 .35348 .38324 .34916 .3968 .34157 .38816 .34536 Mtetra
.555 .918 .74 r
.38816 .34536 .3968 .34157 .41045 .33267 .40194 .33582 Mtetra
.662 .966 .785 r
.40194 .33582 .41045 .33267 .42417 .32257 .41579 .32499 Mtetra
.743 .991 .813 r
.41579 .32499 .42417 .32257 .43794 .31141 .4297 .31303 Mtetra
.8 1 .83 r
.4297 .31303 .43794 .31141 .45175 .29934 .44363 .30012 Mtetra
.838 .996 .839 r
.44363 .30012 .45175 .29934 .46557 .28655 .45758 .28646 Mtetra
.862 .986 .843 r
.45758 .28646 .46557 .28655 .4794 .27321 .47153 .27225 Mtetra
.876 .973 .845 r
.47153 .27225 .4794 .27321 .49323 .25952 .48547 .25768 Mtetra
.883 .958 .846 r
.48547 .25768 .49323 .25952 .50705 .24565 .4994 .24296 Mtetra
.884 .942 .847 r
.4994 .24296 .50705 .24565 .52086 .23177 .51331 .22826 Mtetra
.881 .927 .849 r
.51331 .22826 .52086 .23177 .53466 .21802 .5272 .21373 Mtetra
.874 .912 .851 r
.5272 .21373 .53466 .21802 .54845 .20454 .54108 .19952 Mtetra
.866 .897 .854 r
.54108 .19952 .54845 .20454 .56224 .19142 .55495 .18573 Mtetra
.855 .883 .858 r
.55495 .18573 .56224 .19142 .57603 .17876 .56881 .17246 Mtetra
.843 .87 .862 r
.56881 .17246 .57603 .17876 .58983 .16661 .58268 .15975 Mtetra
.83 .857 .866 r
.58268 .15975 .58983 .16661 .60365 .15501 .59657 .14766 Mtetra
.816 .845 .871 r
.59657 .14766 .60365 .15501 .6175 .14399 .61048 .1362 Mtetra
.802 .833 .875 r
.61048 .1362 .6175 .14399 .63139 .13355 .62442 .12537 Mtetra
.788 .823 .879 r
.62442 .12537 .63139 .13355 .64532 .12368 .6384 .11516 Mtetra
.774 .812 .883 r
.6384 .11516 .64532 .12368 .6593 .11434 .65244 .10553 Mtetra
.761 .803 .887 r
.65244 .10553 .6593 .11434 .67334 .10552 .66653 .09645 Mtetra
.748 .794 .89 r
.66653 .09645 .67334 .10552 .68745 .09716 .68069 .08787 Mtetra
.736 .786 .893 r
.68069 .08787 .68745 .09716 .70163 .08923 .69492 .07975 Mtetra
.725 .779 .895 r
.69492 .07975 .70163 .08923 .71587 .08168 .70921 .07204 Mtetra
.715 .772 .898 r
.70921 .07204 .71587 .08168 .7302 .07447 .72359 .06468 Mtetra
.025 .386 .847 r
.06791 .31789 .07639 .32734 .08646 .33349 .07811 .32302 Mtetra
0 .264 .769 r
.07811 .32302 .08646 .33349 .09636 .34178 .08816 .33005 Mtetra
0 .239 .755 r
.08816 .33005 .09636 .34178 .1063 .35084 .09825 .33781 Mtetra
.069 .321 .802 r
.09825 .33781 .1063 .35084 .11655 .35867 .1086 .34457 Mtetra
.304 .444 .837 r
.1086 .34457 .11655 .35867 .12733 .36332 .11943 .34866 Mtetra
.487 .536 .833 r
.11943 .34866 .12733 .36332 .13873 .36379 .13081 .34922 Mtetra
.591 .591 .821 r
.13081 .34922 .13873 .36379 .15066 .36054 .14266 .34664 Mtetra
.636 .623 .82 r
.14266 .34664 .15066 .36054 .16289 .35522 .15478 .34234 Mtetra
.638 .641 .837 r
.15478 .34234 .16289 .35522 .17517 .34992 .16695 .33809 Mtetra
.599 .645 .868 r
.16695 .33809 .17517 .34992 .18732 .34628 .17902 .33531 Mtetra
.515 .628 .901 r
.17902 .33531 .18732 .34628 .19928 .34507 .19093 .33465 Mtetra
.399 .587 .918 r
.19093 .33465 .19928 .34507 .21109 .3462 .20272 .33601 Mtetra
.291 .536 .914 r
.20272 .33601 .21109 .3462 .22283 .3491 .21447 .3389 Mtetra
.227 .5 .902 r
.21447 .3389 .22283 .3491 .23459 .35305 .22625 .34265 Mtetra
.214 .488 .897 r
.22625 .34265 .23459 .35305 .24644 .35738 .23812 .34668 Mtetra
.24 .496 .897 r
.23812 .34668 .24644 .35738 .25843 .3616 .25014 .35053 Mtetra
.29 .516 .9 r
.25014 .35053 .25843 .3616 .27058 .36534 .26233 .35387 Mtetra
.35 .541 .901 r
.26233 .35387 .27058 .36534 .28292 .36831 .2747 .35643 Mtetra
.413 .566 .897 r
.2747 .35643 .28292 .36831 .29545 .37029 .28727 .35799 Mtetra
.473 .589 .889 r
.28727 .35799 .29545 .37029 .30818 .3711 .30003 .3584 Mtetra
.528 .609 .877 r
.30003 .3584 .30818 .3711 .3211 .37059 .31298 .35749 Mtetra
.577 .625 .864 r
.31298 .35749 .3211 .37059 .3342 .36863 .32612 .35517 Mtetra
.618 .639 .849 r
.32612 .35517 .3342 .36863 .34748 .36514 .33943 .35136 Mtetra
.653 .649 .834 r
.33943 .35136 .34748 .36514 .36091 .36009 .35289 .34602 Mtetra
.683 .658 .82 r
.35289 .34602 .36091 .36009 .37448 .35348 .3665 .33918 Mtetra
.707 .665 .807 r
.3665 .33918 .37448 .35348 .38816 .34536 .38022 .33089 Mtetra
.727 .671 .796 r
.38022 .33089 .38816 .34536 .40194 .33582 .39403 .32123 Mtetra
.743 .677 .786 r
.39403 .32123 .40194 .33582 .41579 .32499 .40792 .31035 Mtetra
.757 .682 .779 r
.40792 .31035 .41579 .32499 .4297 .31303 .42186 .2984 Mtetra
.768 .686 .773 r
.42186 .2984 .4297 .31303 .44363 .30012 .43583 .28556 Mtetra
.776 .69 .769 r
.43583 .28556 .44363 .30012 .45758 .28646 .44982 .27201 Mtetra
.783 .695 .767 r
.44982 .27201 .45758 .28646 .47153 .27225 .46381 .25796 Mtetra
.788 .699 .766 r
.46381 .25796 .47153 .27225 .48547 .25768 .47779 .2436 Mtetra
.792 .703 .767 r
.47779 .2436 .48547 .25768 .4994 .24296 .49176 .22911 Mtetra
.794 .708 .77 r
.49176 .22911 .4994 .24296 .51331 .22826 .50572 .21467 Mtetra
.794 .712 .773 r
.50572 .21467 .51331 .22826 .5272 .21373 .51966 .20042 Mtetra
.794 .716 .779 r
.51966 .20042 .5272 .21373 .54108 .19952 .53359 .18649 Mtetra
.792 .721 .785 r
.53359 .18649 .54108 .19952 .55495 .18573 .54751 .17298 Mtetra
.789 .725 .792 r
.54751 .17298 .55495 .18573 .56881 .17246 .56143 .15998 Mtetra
.785 .729 .8 r
.56143 .15998 .56881 .17246 .58268 .15975 .57536 .14755 Mtetra
.779 .732 .809 r
.57536 .14755 .58268 .15975 .59657 .14766 .5893 .13571 Mtetra
.773 .736 .819 r
.5893 .13571 .59657 .14766 .61048 .1362 .60327 .12448 Mtetra
.766 .739 .828 r
.60327 .12448 .61048 .1362 .62442 .12537 .61727 .11386 Mtetra
.758 .741 .837 r
.61727 .11386 .62442 .12537 .6384 .11516 .63132 .10383 Mtetra
.749 .743 .846 r
.63132 .10383 .6384 .11516 .65244 .10553 .64541 .09437 Mtetra
.741 .744 .855 r
.64541 .09437 .65244 .10553 .66653 .09645 .65957 .08543 Mtetra
.732 .745 .863 r
.65957 .08543 .66653 .09645 .68069 .08787 .67378 .07698 Mtetra
.723 .746 .87 r
.67378 .07698 .68069 .08787 .69492 .07975 .68807 .06895 Mtetra
.715 .746 .876 r
.68807 .06895 .69492 .07975 .70921 .07204 .70243 .06131 Mtetra
.707 .746 .882 r
.70243 .06131 .70921 .07204 .72359 .06468 .71687 .05401 Mtetra
.219 .465 .88 r
.05957 .30692 .06791 .31789 .07811 .32302 .06994 .31077 Mtetra
.13 .378 .834 r
.06994 .31077 .07811 .32302 .08816 .33005 .08019 .31625 Mtetra
.144 .351 .81 r
.08019 .31625 .08816 .33005 .09825 .33781 .09047 .32235 Mtetra
.256 .389 .806 r
.09047 .32235 .09825 .33781 .1086 .34457 .10099 .3276 Mtetra
.401 .452 .798 r
.10099 .3276 .1086 .34457 .11943 .34866 .11194 .33056 Mtetra
.516 .504 .781 r
.11194 .33056 .11943 .34866 .13081 .34922 .12337 .33052 Mtetra
.585 .536 .767 r
.12337 .33052 .13081 .34922 .14266 .34664 .13522 .3278 Mtetra
.615 .552 .76 r
.13522 .3278 .14266 .34664 .15478 .34234 .14732 .32361 Mtetra
.614 .553 .762 r
.14732 .32361 .15478 .34234 .16695 .33809 .15946 .31947 Mtetra
.588 .541 .769 r
.15946 .31947 .16695 .33809 .17902 .33531 .17153 .31656 Mtetra
.546 .516 .774 r
.17153 .31656 .17902 .33531 .19093 .33465 .18347 .31544 Mtetra
.499 .485 .773 r
.18347 .31544 .19093 .33465 .20272 .33601 .19532 .31603 Mtetra
.464 .457 .765 r
.19532 .31603 .20272 .33601 .21447 .3389 .20713 .31789 Mtetra
.447 .437 .754 r
.20713 .31789 .21447 .3389 .22625 .34265 .21898 .32045 Mtetra
.447 .426 .743 r
.21898 .32045 .22625 .34265 .23812 .34668 .23093 .32321 Mtetra
.458 .423 .732 r
.23093 .32321 .23812 .34668 .25014 .35053 .24301 .32578 Mtetra
.473 .424 .721 r
.24301 .32578 .25014 .35053 .26233 .35387 .25525 .32786 Mtetra
.492 .427 .712 r
.25525 .32786 .26233 .35387 .2747 .35643 .26766 .32924 Mtetra
.511 .433 .705 r
.26766 .32924 .2747 .35643 .28727 .35799 .28026 .32974 Mtetra
.529 .44 .698 r
.28026 .32974 .28727 .35799 .30003 .3584 .29303 .32921 Mtetra
.548 .447 .692 r
.29303 .32921 .30003 .3584 .31298 .35749 .30598 .32752 Mtetra
.565 .455 .687 r
.30598 .32752 .31298 .35749 .32612 .35517 .3191 .3246 Mtetra
.582 .464 .683 r
.3191 .3246 .32612 .35517 .33943 .35136 .33238 .32039 Mtetra
.598 .472 .68 r
.33238 .32039 .33943 .35136 .35289 .34602 .3458 .31487 Mtetra
.613 .481 .678 r
.3458 .31487 .35289 .34602 .3665 .33918 .35936 .30805 Mtetra
.627 .491 .677 r
.35936 .30805 .3665 .33918 .38022 .33089 .37302 .29998 Mtetra
.639 .5 .676 r
.37302 .29998 .38022 .33089 .39403 .32123 .38677 .29076 Mtetra
.651 .509 .677 r
.38677 .29076 .39403 .32123 .40792 .31035 .4006 .2805 Mtetra
.663 .519 .678 r
.4006 .2805 .40792 .31035 .42186 .2984 .41448 .26933 Mtetra
.673 .529 .68 r
.41448 .26933 .42186 .2984 .43583 .28556 .4284 .25742 Mtetra
.682 .538 .684 r
.4284 .25742 .43583 .28556 .44982 .27201 .44234 .24492 Mtetra
.691 .549 .688 r
.44234 .24492 .44982 .27201 .46381 .25796 .4563 .232 Mtetra
.699 .559 .693 r
.4563 .232 .46381 .25796 .47779 .2436 .47025 .21883 Mtetra
.706 .569 .699 r
.47025 .21883 .47779 .2436 .49176 .22911 .48421 .20556 Mtetra
.712 .58 .706 r
.48421 .20556 .49176 .22911 .50572 .21467 .49816 .19234 Mtetra
.717 .591 .714 r
.49816 .19234 .50572 .21467 .51966 .20042 .51211 .17931 Mtetra
.721 .603 .723 r
.51211 .17931 .51966 .20042 .53359 .18649 .52605 .16655 Mtetra
.725 .614 .733 r
.52605 .16655 .53359 .18649 .54751 .17298 .53999 .15417 Mtetra
.727 .626 .744 r
.53999 .15417 .54751 .17298 .56143 .15998 .55395 .14223 Mtetra
.729 .637 .756 r
.55395 .14223 .56143 .15998 .57536 .14755 .56792 .13078 Mtetra
.729 .649 .769 r
.56792 .13078 .57536 .14755 .5893 .13571 .58191 .11984 Mtetra
.729 .66 .782 r
.58191 .11984 .5893 .13571 .60327 .12448 .59593 .10943 Mtetra
.727 .671 .795 r
.59593 .10943 .60327 .12448 .61727 .11386 .60999 .09954 Mtetra
.724 .681 .808 r
.60999 .09954 .61727 .11386 .63132 .10383 .6241 .09015 Mtetra
.721 .69 .82 r
.6241 .09015 .63132 .10383 .64541 .09437 .63826 .08125 Mtetra
.717 .699 .832 r
.63826 .08125 .64541 .09437 .65957 .08543 .65247 .07279 Mtetra
.712 .707 .843 r
.65247 .07279 .65957 .08543 .67378 .07698 .66676 .06474 Mtetra
.707 .713 .854 r
.66676 .06474 .67378 .07698 .68807 .06895 .68111 .05705 Mtetra
.702 .719 .863 r
.68111 .05705 .68807 .06895 .70243 .06131 .69554 .04969 Mtetra
.696 .724 .871 r
.69554 .04969 .70243 .06131 .71687 .05401 .71004 .04261 Mtetra
.353 .515 .879 r
.05133 .2949 .05957 .30692 .06994 .31077 .0619 .29731 Mtetra
.296 .451 .846 r
.0619 .29731 .06994 .31077 .08019 .31625 .07237 .30108 Mtetra
.304 .422 .817 r
.07237 .30108 .08019 .31625 .09047 .32235 .08288 .30533 Mtetra
.375 .435 .795 r
.08288 .30533 .09047 .32235 .10099 .3276 .09361 .3088 Mtetra
.467 .467 .774 r
.09361 .3088 .10099 .3276 .11194 .33056 .10471 .31029 Mtetra
.544 .497 .754 r
.10471 .31029 .11194 .33056 .12337 .33052 .11625 .30919 Mtetra
.592 .516 .738 r
.11625 .30919 .12337 .33052 .13522 .3278 .12816 .30578 Mtetra
.613 .523 .729 r
.12816 .30578 .13522 .3278 .14732 .32361 .1403 .30109 Mtetra
.611 .519 .726 r
.1403 .30109 .14732 .32361 .15946 .31947 .15249 .29639 Mtetra
.592 .504 .724 r
.15249 .29639 .15946 .31947 .17153 .31656 .16461 .29269 Mtetra
.563 .481 .721 r
.16461 .29269 .17153 .31656 .18347 .31544 .17664 .29047 Mtetra
.534 .457 .714 r
.17664 .29047 .18347 .31544 .19532 .31603 .18858 .28965 Mtetra
.514 .435 .704 r
.18858 .28965 .19532 .31603 .20713 .31789 .20051 .28987 Mtetra
.503 .419 .694 r
.20051 .28987 .20713 .31789 .21898 .32045 .21247 .29066 Mtetra
.501 .409 .683 r
.21247 .29066 .21898 .32045 .23093 .32321 .22452 .2916 Mtetra
.505 .404 .673 r
.22452 .2916 .23093 .32321 .24301 .32578 .23669 .29238 Mtetra
.512 .401 .665 r
.23669 .29238 .24301 .32578 .25525 .32786 .249 .29276 Mtetra
.52 .401 .658 r
.249 .29276 .25525 .32786 .26766 .32924 .26145 .29257 Mtetra
.53 .403 .652 r
.26145 .29257 .26766 .32924 .28026 .32974 .27406 .29167 Mtetra
.539 .405 .647 r
.27406 .29167 .28026 .32974 .29303 .32921 .28683 .28996 Mtetra
.549 .409 .643 r
.28683 .28996 .29303 .32921 .30598 .32752 .29975 .28735 Mtetra
.559 .414 .64 r
.29975 .28735 .30598 .32752 .3191 .3246 .31282 .28377 Mtetra
.569 .419 .638 r
.31282 .28377 .3191 .3246 .33238 .32039 .32603 .2792 Mtetra
.578 .425 .637 r
.32603 .2792 .33238 .32039 .3458 .31487 .33936 .27361 Mtetra
.588 .432 .637 r
.33936 .27361 .3458 .31487 .35936 .30805 .35281 .26702 Mtetra
.597 .439 .638 r
.35281 .26702 .35936 .30805 .37302 .29998 .36636 .25949 Mtetra
.606 .446 .639 r
.36636 .25949 .37302 .29998 .38677 .29076 .37999 .25108 Mtetra
.615 .454 .641 r
.37999 .25108 .38677 .29076 .4006 .2805 .3937 .24187 Mtetra
.623 .463 .644 r
.3937 .24187 .4006 .2805 .41448 .26933 .40746 .23198 Mtetra
.631 .472 .648 r
.40746 .23198 .41448 .26933 .4284 .25742 .42126 .22152 Mtetra
.639 .481 .653 r
.42126 .22152 .4284 .25742 .44234 .24492 .4351 .21062 Mtetra
.647 .491 .658 r
.4351 .21062 .44234 .24492 .4563 .232 .44897 .19941 Mtetra
.654 .502 .665 r
.44897 .19941 .4563 .232 .47025 .21883 .46285 .18801 Mtetra
.661 .513 .672 r
.46285 .18801 .47025 .21883 .48421 .20556 .47674 .17655 Mtetra
.667 .524 .681 r
.47674 .17655 .48421 .20556 .49816 .19234 .49065 .16513 Mtetra
.673 .537 .69 r
.49065 .16513 .49816 .19234 .51211 .17931 .50457 .15384 Mtetra
.679 .55 .701 r
.50457 .15384 .51211 .17931 .52605 .16655 .5185 .14278 Mtetra
.684 .563 .712 r
.5185 .14278 .52605 .16655 .53999 .15417 .53244 .132 Mtetra
.688 .577 .725 r
.53244 .132 .53999 .15417 .55395 .14223 .54641 .12156 Mtetra
.692 .591 .738 r
.54641 .12156 .55395 .14223 .56792 .13078 .56041 .1115 Mtetra
.695 .606 .752 r
.56041 .1115 .56792 .13078 .58191 .11984 .57444 .10182 Mtetra
.697 .62 .767 r
.57444 .10182 .58191 .11984 .59593 .10943 .58851 .09255 Mtetra
.698 .635 .782 r
.58851 .09255 .59593 .10943 .60999 .09954 .60262 .08367 Mtetra
.698 .648 .796 r
.60262 .08367 .60999 .09954 .6241 .09015 .61679 .07518 Mtetra
.698 .661 .81 r
.61679 .07518 .6241 .09015 .63826 .08125 .63101 .06704 Mtetra
.696 .674 .824 r
.63101 .06704 .63826 .08125 .65247 .07279 .64529 .05925 Mtetra
.694 .685 .836 r
.64529 .05925 .65247 .07279 .66676 .06474 .65964 .05176 Mtetra
.692 .695 .848 r
.65964 .05176 .66676 .06474 .68111 .05705 .67406 .04454 Mtetra
.689 .703 .858 r
.67406 .04454 .68111 .05705 .69554 .04969 .68856 .03756 Mtetra
.686 .711 .867 r
.68856 .03756 .69554 .04969 .71004 .04261 .70313 .03079 Mtetra
.44 .554 .875 r
.04309 .28253 .05133 .2949 .0619 .29731 .05385 .28353 Mtetra
.399 .504 .849 r
.05385 .28353 .0619 .29731 .07237 .30108 .06455 .2856 Mtetra
.403 .475 .821 r
.06455 .2856 .07237 .30108 .08288 .30533 .07529 .28802 Mtetra
.449 .475 .794 r
.07529 .28802 .08288 .30533 .09361 .3088 .08624 .28971 Mtetra
.513 .491 .769 r
.08624 .28971 .09361 .3088 .10471 .31029 .09752 .28966 Mtetra
.569 .509 .748 r
.09752 .28966 .10471 .31029 .11625 .30919 .10919 .28737 Mtetra
.606 .52 .732 r
.10919 .28737 .11625 .30919 .12816 .30578 .1212 .28308 Mtetra
.622 .524 .722 r
.1212 .28308 .12816 .30578 .1403 .30109 .1334 .27764 Mtetra
.62 .518 .717 r
.1334 .27764 .1403 .30109 .15249 .29639 .14565 .27214 Mtetra
.605 .504 .713 r
.14565 .27214 .15249 .29639 .16461 .29269 .15787 .26744 Mtetra
.582 .484 .708 r
.15787 .26744 .16461 .29269 .17664 .29047 .17 .26392 Mtetra
.56 .463 .701 r
.17 .26392 .17664 .29047 .18858 .28965 .18207 .26155 Mtetra
.544 .444 .691 r
.18207 .26155 .18858 .28965 .20051 .28987 .19412 .26002 Mtetra
.534 .429 .681 r
.19412 .26002 .20051 .28987 .21247 .29066 .20621 .25895 Mtetra
.531 .419 .671 r
.20621 .25895 .21247 .29066 .22452 .2916 .21837 .25801 Mtetra
.532 .412 .662 r
.21837 .25801 .22452 .2916 .23669 .29238 .23063 .25697 Mtetra
.535 .408 .655 r
.23063 .25697 .23669 .29238 .249 .29276 .243 .25563 Mtetra
.539 .406 .648 r
.243 .25563 .249 .29276 .26145 .29257 .2555 .25388 Mtetra
.544 .405 .643 r
.2555 .25388 .26145 .29257 .27406 .29167 .26813 .25162 Mtetra
.549 .406 .638 r
.26813 .25162 .27406 .29167 .28683 .28996 .28088 .24878 Mtetra
.555 .407 .635 r
.28088 .24878 .28683 .28996 .29975 .28735 .29377 .24531 Mtetra
.561 .409 .633 r
.29377 .24531 .29975 .28735 .31282 .28377 .30677 .24117 Mtetra
.568 .413 .631 r
.30677 .24117 .31282 .28377 .32603 .2792 .31989 .23632 Mtetra
.574 .417 .631 r
.31989 .23632 .32603 .2792 .33936 .27361 .33312 .23078 Mtetra
.58 .422 .631 r
.33312 .23078 .33936 .27361 .35281 .26702 .34644 .22454 Mtetra
.587 .427 .632 r
.34644 .22454 .35281 .26702 .36636 .25949 .35986 .21766 Mtetra
.594 .433 .634 r
.35986 .21766 .36636 .25949 .37999 .25108 .37336 .21016 Mtetra
.6 .44 .637 r
.37336 .21016 .37999 .25108 .3937 .24187 .38692 .20213 Mtetra
.607 .448 .64 r
.38692 .20213 .3937 .24187 .40746 .23198 .40055 .19362 Mtetra
.613 .456 .645 r
.40055 .19362 .40746 .23198 .42126 .22152 .41423 .18473 Mtetra
.62 .465 .65 r
.41423 .18473 .42126 .22152 .4351 .21062 .42795 .17554 Mtetra
.626 .474 .656 r
.42795 .17554 .4351 .21062 .44897 .19941 .4417 .16613 Mtetra
.633 .485 .664 r
.4417 .16613 .44897 .19941 .46285 .18801 .45549 .15659 Mtetra
.639 .496 .672 r
.45549 .15659 .46285 .18801 .47674 .17655 .46931 .14701 Mtetra
.645 .508 .681 r
.46931 .14701 .47674 .17655 .49065 .16513 .48316 .13745 Mtetra
.651 .521 .692 r
.48316 .13745 .49065 .16513 .50457 .15384 .49704 .12799 Mtetra
.657 .534 .703 r
.49704 .12799 .50457 .15384 .5185 .14278 .51095 .11868 Mtetra
.662 .548 .715 r
.51095 .11868 .5185 .14278 .53244 .132 .52489 .10956 Mtetra
.667 .563 .729 r
.52489 .10956 .53244 .132 .54641 .12156 .53886 .10066 Mtetra
.671 .578 .743 r
.53886 .10066 .54641 .12156 .56041 .1115 .55288 .09202 Mtetra
.675 .594 .757 r
.55288 .09202 .56041 .1115 .57444 .10182 .56694 .08364 Mtetra
.678 .61 .772 r
.56694 .08364 .57444 .10182 .58851 .09255 .58105 .07553 Mtetra
.68 .625 .787 r
.58105 .07553 .58851 .09255 .60262 .08367 .59521 .06768 Mtetra
.682 .64 .802 r
.59521 .06768 .60262 .08367 .61679 .07518 .60943 .06009 Mtetra
.682 .654 .816 r
.60943 .06009 .61679 .07518 .63101 .06704 .62371 .05274 Mtetra
.682 .667 .829 r
.62371 .05274 .63101 .06704 .64529 .05925 .63806 .04562 Mtetra
.682 .679 .841 r
.63806 .04562 .64529 .05925 .65964 .05176 .65248 .03869 Mtetra
.68 .69 .852 r
.65248 .03869 .65964 .05176 .67406 .04454 .66696 .03194 Mtetra
.679 .699 .862 r
.66696 .03194 .67406 .04454 .68856 .03756 .68153 .02535 Mtetra
.677 .707 .871 r
.68153 .02535 .68856 .03756 .70313 .03079 .69616 .01889 Mtetra
.498 .591 .878 r
.03473 .27047 .04309 .28253 .05385 .28353 .04568 .27021 Mtetra
.467 .55 .858 r
.04568 .27021 .05385 .28353 .06455 .2856 .05659 .27078 Mtetra
.468 .524 .832 r
.05659 .27078 .06455 .2856 .07529 .28802 .06755 .27157 Mtetra
.501 .517 .805 r
.06755 .27157 .07529 .28802 .08624 .28971 .0787 .27168 Mtetra
.549 .524 .779 r
.0787 .27168 .08624 .28971 .09752 .28966 .09015 .27028 Mtetra
.594 .534 .758 r
.09015 .27028 .09752 .28966 .10919 .28737 .10195 .26693 Mtetra
.623 .542 .742 r
.10195 .26693 .10919 .28737 .1212 .28308 .11403 .26185 Mtetra
.637 .544 .732 r
.11403 .26185 .1212 .28308 .1334 .27764 .1263 .25575 Mtetra
.636 .538 .727 r
.1263 .25575 .1334 .27764 .14565 .27214 .13863 .24956 Mtetra
.623 .526 .723 r
.13863 .24956 .14565 .27214 .15787 .26744 .15092 .24397 Mtetra
.605 .509 .719 r
.15092 .24397 .15787 .26744 .17 .26392 .16316 .23933 Mtetra
.586 .49 .713 r
.16316 .23933 .17 .26392 .18207 .26155 .17534 .23562 Mtetra
.571 .473 .705 r
.17534 .23562 .18207 .26155 .19412 .26002 .18751 .2326 Mtetra
.562 .459 .695 r
.18751 .2326 .19412 .26002 .20621 .25895 .19971 .22996 Mtetra
.557 .448 .686 r
.19971 .22996 .20621 .25895 .21837 .25801 .21197 .22745 Mtetra
.556 .44 .677 r
.21197 .22745 .21837 .25801 .23063 .25697 .22432 .22488 Mtetra
.556 .435 .669 r
.22432 .22488 .23063 .25697 .243 .25563 .23675 .22212 Mtetra
.558 .431 .663 r
.23675 .22212 .243 .25563 .2555 .25388 .24929 .21909 Mtetra
.56 .428 .657 r
.24929 .21909 .2555 .25388 .26813 .25162 .26194 .21573 Mtetra
.563 .427 .653 r
.26194 .21573 .26813 .25162 .28088 .24878 .27468 .212 Mtetra
.567 .426 .65 r
.27468 .212 .28088 .24878 .29377 .24531 .28753 .20787 Mtetra
.571 .427 .647 r
.28753 .20787 .29377 .24531 .30677 .24117 .30048 .2033 Mtetra
.575 .429 .646 r
.30048 .2033 .30677 .24117 .31989 .23632 .31353 .19829 Mtetra
.579 .432 .645 r
.31353 .19829 .31989 .23632 .33312 .23078 .32667 .19284 Mtetra
.584 .436 .646 r
.32667 .19284 .33312 .23078 .34644 .22454 .33989 .18696 Mtetra
.589 .44 .647 r
.33989 .18696 .34644 .22454 .35986 .21766 .3532 .18067 Mtetra
.594 .445 .649 r
.3532 .18067 .35986 .21766 .37336 .21016 .36658 .174 Mtetra
.599 .452 .653 r
.36658 .174 .37336 .21016 .38692 .20213 .38002 .16699 Mtetra
.604 .459 .657 r
.38002 .16699 .38692 .20213 .40055 .19362 .39353 .15969 Mtetra
.61 .466 .662 r
.39353 .15969 .40055 .19362 .41423 .18473 .4071 .15214 Mtetra
.615 .475 .668 r
.4071 .15214 .41423 .18473 .42795 .17554 .42072 .1444 Mtetra
.621 .485 .675 r
.42072 .1444 .42795 .17554 .4417 .16613 .43438 .13653 Mtetra
.627 .495 .683 r
.43438 .13653 .4417 .16613 .45549 .15659 .44809 .12857 Mtetra
.632 .507 .692 r
.44809 .12857 .45549 .15659 .46931 .14701 .46185 .12058 Mtetra
.638 .519 .702 r
.46185 .12058 .46931 .14701 .48316 .13745 .47565 .1126 Mtetra
.643 .532 .713 r
.47565 .1126 .48316 .13745 .49704 .12799 .48949 .10467 Mtetra
.648 .546 .725 r
.48949 .10467 .49704 .12799 .51095 .11868 .50338 .09683 Mtetra
.653 .56 .737 r
.50338 .09683 .51095 .11868 .52489 .10956 .51732 .08909 Mtetra
.658 .575 .751 r
.51732 .08909 .52489 .10956 .53886 .10066 .5313 .08149 Mtetra
.662 .59 .765 r
.5313 .08149 .53886 .10066 .55288 .09202 .54534 .07404 Mtetra
.665 .606 .779 r
.54534 .07404 .55288 .09202 .56694 .08364 .55943 .06674 Mtetra
.668 .621 .793 r
.55943 .06674 .56694 .08364 .58105 .07553 .57358 .05959 Mtetra
.67 .636 .806 r
.57358 .05959 .58105 .07553 .59521 .06768 .58778 .0526 Mtetra
.672 .65 .82 r
.58778 .0526 .59521 .06768 .60943 .06009 .60205 .04576 Mtetra
.673 .663 .832 r
.60205 .04576 .60943 .06009 .62371 .05274 .61639 .03906 Mtetra
.673 .675 .844 r
.61639 .03906 .62371 .05274 .63806 .04562 .6308 .03248 Mtetra
.673 .686 .854 r
.6308 .03248 .63806 .04562 .65248 .03869 .64528 .02601 Mtetra
.673 .696 .863 r
.64528 .02601 .65248 .03869 .66696 .03194 .65983 .01964 Mtetra
.672 .704 .871 r
.65983 .01964 .66696 .03194 .68153 .02535 .67445 .01336 Mtetra
.671 .712 .878 r
.67445 .01336 .68153 .02535 .69616 .01889 .68915 .00714 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.4226 .8354 m
.4484 .83515 L
.46257 .8354 L
.4742 .83552 L
.5 .83604 L
.5258 .8371 L
.5516 .83927 L
.5774 .84374 L
.6032 .85277 L
.61767 .8612 L
.629 .86724 L
.64412 .887 L
.629 .90767 L
.62002 .9128 L
.6032 .91991 L
.5774 .92766 L
.5516 .93323 L
.5258 .93733 L
.51614 .9386 L
.5 .94046 L
.4742 .94263 L
.4484 .94386 L
.4226 .94419 L
.3968 .94363 L
.371 .94212 L
.3452 .93955 L
.33766 .9386 L
.3194 .936 L
.2936 .93111 L
.2678 .92413 L
.242 .91306 L
.24156 .9128 L
.22531 .887 L
.242 .86976 L
.25963 .8612 L
.2678 .85707 L
.2936 .84754 L
.3194 .84186 L
.3452 .83859 L
.371 .83677 L
.3968 .83582 L
.4226 .8354 L
.4226 .8354 L
s
.3194 .05806 m
.3452 .0518 L
.371 .04764 L
.3968 .04497 L
.4226 .04342 L
.4484 .04279 L
.4742 .04301 L
.5 .04409 L
.5258 .0461 L
.5516 .04923 L
.5774 .05378 L
.6032 .06017 L
.60733 .0614 L
.629 .06819 L
.6548 .08 L
.66501 .0872 L
.67435 .113 L
.6548 .13165 L
.63984 .1388 L
.629 .14383 L
.6032 .15221 L
.5774 .15723 L
.5516 .16028 L
.5258 .16209 L
.5 .16306 L
.4742 .16336 L
.4484 .16301 L
.4226 .16196 L
.3968 .16006 L
.371 .15703 L
.3452 .1524 L
.3194 .14545 L
.3017 .1388 L
.2936 .1357 L
.2678 .12178 L
.25877 .113 L
.2597 .0872 L
.2678 .07981 L
.2936 .06656 L
.30892 .0614 L
.3194 .05806 L
s
.113 .26554 m
.11952 .2678 L
.1388 .29168 L
.14016 .2936 L
.15339 .3194 L
.16014 .3452 L
.16335 .371 L
.1646 .39129 L
.16536 .3968 L
.16828 .4226 L
.17023 .4484 L
.17132 .4742 L
.17159 .5 L
.17105 .5258 L
.16969 .5516 L
.16743 .5774 L
.1646 .60017 L
.16446 .6032 L
.16256 .629 L
.15842 .6548 L
.14989 .6806 L
.1388 .69963 L
.1351 .7064 L
.113 .72562 L
.0872 .70724 L
.08669 .7064 L
.07502 .6806 L
.06734 .6548 L
.06174 .629 L
.0614 .62719 L
.05722 .6032 L
.05394 .5774 L
.05169 .5516 L
.05034 .5258 L
.04981 .5 L
.05006 .4742 L
.05111 .4484 L
.05302 .4226 L
.05592 .3968 L
.06 .371 L
.0614 .36364 L
.06517 .3452 L
.07201 .3194 L
.08189 .2936 L
.0872 .28375 L
.1021 .2678 L
.113 .26554 L
s
.3968 .44777 m
.4226 .44332 L
.4484 .44027 L
.4742 .43846 L
.5 .43778 L
.5258 .43824 L
.5516 .43996 L
.5774 .4432 L
.6029 .4484 L
.6032 .44847 L
.629 .45568 L
.6548 .46796 L
.66244 .4742 L
.66668 .5 L
.6548 .51229 L
.63 .5258 L
.629 .52632 L
.6032 .53702 L
.5774 .5438 L
.5516 .54793 L
.5258 .55031 L
.5 .55154 L
.49815 .5516 L
.4742 .55259 L
.4484 .55254 L
.4272 .5516 L
.4226 .55149 L
.3968 .55061 L
.371 .54873 L
.3452 .53881 L
.3194 .52915 L
.31315 .5258 L
.29434 .5 L
.31639 .4742 L
.3194 .47158 L
.3452 .46116 L
.371 .45344 L
.39371 .4484 L
.3968 .44777 L
s
0 g
.03 w
.43434 .88944 Mdot
.46499 .10336 Mdot
.11085 .49557 Mdot
.48201 .49563 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.44118 .88705 m
.44342 .89216 L
.44118 .89252 L
.42444 .89216 L
.44118 .88705 L
s
.10784 .44512 m
.12745 .45263 L
.13229 .46078 L
.14 .48039 L
.1432 .5 L
.14181 .51961 L
.1356 .53922 L
.12745 .55338 L
.121 .55882 L
.10784 .55935 L
.10715 .55882 L
.09535 .53922 L
.09095 .51961 L
.08999 .5 L
.09202 .48039 L
.09755 .46078 L
.10784 .44512 L
s
.38235 .86546 m
.40196 .86148 L
.42157 .86434 L
.44118 .86399 L
.46078 .86466 L
.48039 .86648 L
.5 .86977 L
.51097 .87255 L
.51961 .87587 L
.532 .89216 L
.51961 .90118 L
.5 .90772 L
.48039 .91154 L
.47917 .91176 L
.46078 .91434 L
.44118 .91572 L
.42157 .91581 L
.40196 .91456 L
.38286 .91176 L
.38235 .91166 L
.36275 .90763 L
.34314 .89985 L
.33576 .89216 L
.34314 .88092 L
.36275 .87261 L
.36295 .87255 L
.38235 .86546 L
s
.10784 .3998 m
.1191 .40196 L
.12745 .41096 L
.13365 .42157 L
.14285 .44118 L
.14706 .45137 L
.15066 .46078 L
.15648 .48039 L
.1591 .5 L
.158 .51961 L
.15322 .53922 L
.14706 .55521 L
.14539 .55882 L
.13549 .57843 L
.12745 .5904 L
.11854 .59804 L
.10784 .59915 L
.10577 .59804 L
.09114 .57843 L
.08824 .57173 L
.08315 .55882 L
.07832 .53922 L
.07593 .51961 L
.07539 .5 L
.07653 .48039 L
.07942 .46078 L
.08449 .44118 L
.08824 .43109 L
.09191 .42157 L
.10453 .40196 L
.10784 .3998 L
s
.42157 .85275 m
.44118 .85242 L
.46078 .85284 L
.4642 .85294 L
.48039 .85399 L
.5 .85597 L
.51961 .85896 L
.53922 .86333 L
.55882 .87005 L
.56398 .87255 L
.57636 .89216 L
.55882 .90621 L
.54485 .91176 L
.53922 .91394 L
.51961 .91964 L
.5 .92327 L
.48039 .92557 L
.46078 .92696 L
.44118 .92766 L
.42157 .92778 L
.40196 .92734 L
.38235 .92624 L
.36275 .92425 L
.34314 .9208 L
.32353 .91478 L
.31676 .91176 L
.30392 .90602 L
.29049 .89216 L
.30392 .87539 L
.30937 .87255 L
.32353 .86412 L
.34314 .8577 L
.36275 .85473 L
.38235 .85348 L
.40196 .85303 L
.41669 .85294 L
.42157 .85275 L
s
.44118 .47532 m
.46078 .47228 L
.48039 .47083 L
.5 .4708 L
.51961 .47232 L
.53922 .4759 L
.55269 .48039 L
.55882 .48424 L
.56139 .5 L
.55882 .50223 L
.53922 .51165 L
.51961 .51657 L
.5 .51939 L
.49774 .51961 L
.48039 .52087 L
.46078 .52063 L
.44972 .51961 L
.44118 .51858 L
.42157 .51442 L
.40196 .50401 L
.3996 .5 L
.40196 .49252 L
.42157 .48057 L
.42202 .48039 L
.44118 .47532 L
s
.10784 .3538 m
.12494 .36275 L
.12745 .36632 L
.13554 .38235 L
.14325 .40196 L
.14706 .41239 L
.15053 .42157 L
.15769 .44118 L
.16417 .46078 L
.16667 .468 L
.16942 .48039 L
.17211 .5 L
.17098 .51961 L
.16667 .53832 L
.16642 .53922 L
.16004 .55882 L
.15228 .57843 L
.14706 .59034 L
.14372 .59804 L
.13433 .61765 L
.12745 .62891 L
.11906 .63725 L
.10784 .63963 L
.10336 .63725 L
.08904 .61765 L
.08824 .61597 L
.07982 .59804 L
.07413 .57843 L
.07042 .55882 L
.06863 .54628 L
.06766 .53922 L
.06576 .51961 L
.06532 .5 L
.0663 .48039 L
.06853 .46078 L
.06863 .46011 L
.07106 .44118 L
.07443 .42157 L
.0793 .40196 L
.08697 .38235 L
.08824 .37987 L
.09734 .36275 L
.10784 .3538 L
s
.42157 .09457 m
.44118 .0898 L
.46078 .08846 L
.48039 .08934 L
.5 .09282 L
.51656 .10784 L
.5 .11478 L
.48039 .11764 L
.46078 .11799 L
.44118 .11617 L
.42157 .11115 L
.41502 .10784 L
.42157 .09457 L
s
.34314 .84993 m
.36275 .84709 L
.38235 .84501 L
.40196 .84358 L
.42157 .84274 L
.44118 .84245 L
.46078 .84271 L
.48039 .84354 L
.5 .84499 L
.51961 .84716 L
.53922 .85021 L
.55261 .85294 L
.55882 .85436 L
.57843 .85989 L
.59804 .86813 L
.60515 .87255 L
.61405 .89216 L
.59804 .90738 L
.58947 .91176 L
.57843 .91709 L
.55882 .92351 L
.53922 .92753 L
.51961 .93018 L
.50775 .93137 L
.5 .9323 L
.48039 .93419 L
.46078 .93545 L
.44118 .93613 L
.42157 .93626 L
.40196 .93581 L
.38235 .93478 L
.36275 .9331 L
.34809 .93137 L
.34314 .93095 L
.32353 .92885 L
.30392 .92544 L
.28431 .91929 L
.27014 .91176 L
.26471 .90897 L
.24808 .89216 L
.26471 .87277 L
.26511 .87255 L
.28431 .86067 L
.30392 .85518 L
.32353 .85312 L
.32695 .85294 L
.34314 .84993 L
s
.44118 .46002 m
.46078 .4578 L
.48039 .45657 L
.5 .4563 L
.51961 .45701 L
.53922 .45883 L
.55238 .46078 L
.55882 .462 L
.57843 .46687 L
.59804 .4752 L
.60519 .48039 L
.60773 .5 L
.59804 .50862 L
.57843 .51829 L
.57486 .51961 L
.55882 .52512 L
.53922 .52976 L
.51961 .53278 L
.5 .53464 L
.48039 .5356 L
.46078 .53578 L
.44118 .53521 L
.42157 .53374 L
.40196 .5308 L
.38235 .52483 L
.37254 .51961 L
.36275 .51396 L
.35315 .5 L
.36275 .48488 L
.36931 .48039 L
.38235 .47105 L
.40196 .46372 L
.42157 .46325 L
.43585 .46078 L
.44118 .46002 L
s
.10784 .30997 m
.12745 .32068 L
.12938 .32353 L
.13905 .34314 L
.14591 .36275 L
.14706 .36645 L
.15195 .38235 L
.15766 .40196 L
.16349 .42157 L
.16667 .43175 L
.16991 .44118 L
.17679 .46078 L
.18285 .48039 L
.18604 .5 L
.18469 .51961 L
.17948 .53922 L
.17245 .55882 L
.16667 .57422 L
.16519 .57843 L
.15839 .59804 L
.15151 .61765 L
.14706 .62974 L
.14428 .63725 L
.13596 .65686 L
.12745 .67117 L
.12251 .67647 L
.10784 .68141 L
.09946 .67647 L
.08824 .6611 L
.08549 .65686 L
.07656 .63725 L
.07138 .61765 L
.06863 .60289 L
.06745 .59804 L
.06315 .57843 L
.05965 .55882 L
.05707 .53922 L
.05555 .51961 L
.05521 .5 L
.05602 .48039 L
.05781 .46078 L
.06037 .44118 L
.06351 .42157 L
.06718 .40196 L
.06863 .39496 L
.07055 .38235 L
.07459 .36275 L
.08136 .34314 L
.08824 .33073 L
.09241 .32353 L
Mistroke
.10784 .30997 L
Mfstroke
.36275 .08291 m
.38235 .07675 L
.40196 .07287 L
.42157 .07043 L
.44118 .0691 L
.46078 .06871 L
.48039 .06923 L
.5 .07066 L
.51961 .0731 L
.53922 .07681 L
.55882 .0823 L
.57296 .08824 L
.57843 .09166 L
.58743 .10784 L
.57843 .11792 L
.55882 .12691 L
.55715 .12745 L
.53922 .13304 L
.51961 .13663 L
.5 .13859 L
.48039 .13944 L
.46078 .13938 L
.44118 .13844 L
.42157 .13648 L
.40196 .13319 L
.38235 .128 L
.3807 .12745 L
.36275 .12112 L
.34395 .10784 L
.35203 .08824 L
.36275 .08291 L
s
.28431 .85003 m
.30392 .84577 L
.32353 .84228 L
.34314 .83948 L
.36275 .83728 L
.38235 .83562 L
.40196 .83445 L
.42157 .83374 L
.44118 .83348 L
.46078 .83366 L
.48039 .8343 L
.5 .83541 L
.51961 .83703 L
.53922 .83924 L
.55882 .84215 L
.57843 .84599 L
.59804 .85114 L
.60365 .85294 L
.61765 .85798 L
.63725 .86815 L
.64286 .87255 L
.6497 .89216 L
.63725 .90655 L
.62904 .91176 L
.61765 .9183 L
.59804 .92559 L
.57843 .93008 L
.57103 .93137 L
.55882 .93394 L
.53922 .93736 L
.51961 .94006 L
.5 .94214 L
.48039 .9437 L
.46078 .94475 L
.44118 .94534 L
.42157 .94547 L
.40196 .94515 L
.38235 .94435 L
.36275 .94306 L
.34314 .94122 L
.32353 .93876 L
.30392 .93558 L
.28431 .93156 L
.2835 .93137 L
.26471 .92843 L
.2451 .92334 L
.22549 .91523 L
.21876 .91176 L
.20588 .90666 L
.18627 .89829 L
Mistroke
.17282 .89216 L
.18627 .87636 L
.20135 .87255 L
.20588 .87142 L
.22549 .86235 L
.2451 .8567 L
.26471 .85363 L
.27265 .85294 L
.28431 .85003 L
Mfstroke
.38235 .45821 m
.40196 .45367 L
.42157 .45026 L
.44118 .44776 L
.46078 .44605 L
.48039 .44504 L
.5 .4447 L
.51961 .44504 L
.53922 .4461 L
.55882 .44796 L
.57843 .45085 L
.59804 .45522 L
.61475 .46078 L
.61765 .46189 L
.63725 .47221 L
.6457 .48039 L
.64598 .5 L
.63725 .50916 L
.62009 .51961 L
.61765 .5209 L
.59804 .52908 L
.57843 .53448 L
.55882 .53819 L
.55195 .53922 L
.53922 .54123 L
.51961 .54364 L
.5 .54529 L
.48039 .54622 L
.46078 .54645 L
.44118 .54596 L
.42157 .5447 L
.40196 .54254 L
.38235 .53929 L
.38199 .53922 L
.36275 .53666 L
.34314 .53116 L
.32673 .51961 L
.32353 .51717 L
.31388 .5 L
.32353 .48422 L
.32831 .48039 L
.34314 .46901 L
.36275 .46223 L
.3733 .46078 L
.38235 .45821 L
s
.10784 .26755 m
.12745 .27663 L
.13301 .28431 L
.14281 .30392 L
.14706 .31519 L
.14995 .32353 L
.15565 .34314 L
.16039 .36275 L
.16481 .38235 L
.16667 .39038 L
.16967 .40196 L
.1755 .42157 L
.18251 .44118 L
.18627 .45037 L
.19028 .46078 L
.19782 .48039 L
.20237 .5 L
.20034 .51961 L
.19349 .53922 L
.18627 .55715 L
.18551 .55882 L
.17757 .57843 L
.17066 .59804 L
.16667 .61079 L
.16476 .61765 L
.15944 .63725 L
.15383 .65686 L
.14716 .67647 L
.14706 .67673 L
.13894 .69608 L
.12745 .71425 L
.1261 .71569 L
.10784 .7231 L
.09598 .71569 L
.08824 .70575 L
.08147 .69608 L
.07319 .67647 L
.06866 .65686 L
.06863 .65667 L
.06356 .63725 L
.05924 .61765 L
.05545 .59804 L
.05209 .57843 L
.04923 .55882 L
.04902 .55733 L
.04702 .53922 L
.04571 .51961 L
.04543 .5 L
.04615 .48039 L
.04772 .46078 L
Mistroke
.04902 .44845 L
.0499 .44118 L
.05245 .42157 L
.05529 .40196 L
.05847 .38235 L
.06214 .36275 L
.06656 .34314 L
.06863 .33526 L
.07093 .32353 L
.07699 .30392 L
.08824 .2851 L
.08874 .28431 L
.10784 .26755 L
Mfstroke
.34314 .06774 m
.36275 .06292 L
.38235 .05955 L
.40196 .05723 L
.42157 .05572 L
.44118 .05491 L
.46078 .05472 L
.48039 .05515 L
.5 .05621 L
.51961 .05795 L
.53922 .06047 L
.55882 .06394 L
.57836 .06863 L
.57843 .06865 L
.59804 .07471 L
.61765 .08346 L
.62511 .08824 L
.63617 .10784 L
.61765 .12727 L
.61732 .12745 L
.59804 .13738 L
.57843 .14261 L
.55882 .14562 L
.54532 .14706 L
.53922 .14786 L
.51961 .1499 L
.5 .15117 L
.48039 .15174 L
.46078 .15167 L
.44118 .15094 L
.42157 .14956 L
.40196 .14744 L
.39896 .14706 L
.38235 .14511 L
.36275 .14185 L
.34314 .13692 L
.32353 .12917 L
.32019 .12745 L
.30392 .11814 L
.29428 .10784 L
.29923 .08824 L
.30392 .08444 L
.32353 .07425 L
.34019 .06863 L
.34314 .06774 L
s
.10784 .8306 m
.12745 .8264 L
.14706 .8323 L
.15031 .83333 L
.16667 .84059 L
.18627 .846 L
.20588 .84797 L
.22549 .84711 L
.2451 .84453 L
.26471 .84123 L
.28431 .83784 L
.30392 .8347 L
.31335 .83333 L
.32353 .83194 L
.34314 .8296 L
.36275 .8277 L
.38235 .82623 L
.40196 .82517 L
.42157 .82452 L
.44118 .82426 L
.46078 .82439 L
.48039 .82492 L
.5 .82587 L
.51961 .82725 L
.53922 .8291 L
.55882 .83147 L
.57164 .83333 L
.57843 .8344 L
.59804 .83795 L
.61765 .84245 L
.63725 .84841 L
.64879 .85294 L
.65686 .85653 L
.67647 .86882 L
.6803 .87255 L
.68568 .89216 L
.67647 .90505 L
.66772 .91176 L
.65686 .91895 L
.63725 .92711 L
.62106 .93137 L
.61765 .93238 L
.59804 .93746 L
.57843 .94158 L
.55882 .94496 L
.53922 .94772 L
.51961 .94996 L
.50905 .95098 L
.5 .95173 L
.48039 .95305 L
Mistroke
.46078 .95397 L
.44118 .9545 L
.42157 .95464 L
.40196 .95439 L
.38235 .95374 L
.36275 .95268 L
.34314 .95118 L
.34082 .95098 L
.32353 .94922 L
.30392 .94677 L
.28431 .94379 L
.26471 .9403 L
.2451 .9364 L
.22549 .93235 L
.22083 .93137 L
.20588 .92955 L
.18627 .92702 L
.16667 .92465 L
.14706 .92181 L
.12745 .91657 L
.11696 .91176 L
.10784 .9053 L
.09676 .89216 L
.09211 .87255 L
.09475 .85294 L
.1059 .83333 L
.10784 .8306 L
Mfstroke
.42157 .4389 m
.44118 .43676 L
.46078 .43522 L
.48039 .43426 L
.5 .43387 L
.51961 .43406 L
.53922 .43485 L
.55882 .43628 L
.57843 .43845 L
.59642 .44118 L
.59804 .44144 L
.61765 .44513 L
.63725 .45032 L
.65686 .45839 L
.66112 .46078 L
.67647 .47151 L
.68335 .48039 L
.68232 .5 L
.67647 .50737 L
.66019 .51961 L
.65686 .52169 L
.63725 .53113 L
.61765 .53738 L
.61035 .53922 L
.59804 .54244 L
.57843 .54672 L
.55882 .55014 L
.53922 .55282 L
.51961 .55486 L
.5 .55629 L
.48039 .55714 L
.46078 .55743 L
.44118 .55715 L
.42157 .55627 L
.40196 .55475 L
.38235 .55251 L
.36275 .54941 L
.34314 .54522 L
.32353 .53954 L
.32258 .53922 L
.30392 .53584 L
.28431 .52409 L
.28016 .51961 L
.26638 .5 L
.28431 .48157 L
.28615 .48039 L
.30392 .46795 L
.32353 .46132 L
.32628 .46078 L
.34314 .45489 L
Mistroke
.36275 .44942 L
.38235 .4451 L
.40196 .44167 L
.4052 .44118 L
.42157 .4389 L
Mfstroke
.10784 .21724 m
.12745 .22536 L
.12759 .22549 L
.13912 .2451 L
.14706 .26341 L
.1476 .26471 L
.1547 .28431 L
.16033 .30392 L
.16493 .32353 L
.16667 .33185 L
.16903 .34314 L
.17296 .36275 L
.17707 .38235 L
.18193 .40196 L
.18627 .41609 L
.18814 .42157 L
.19622 .44118 L
.20588 .45832 L
.20683 .46078 L
.21907 .48039 L
.22549 .48716 L
.2325 .5 L
.22586 .51961 L
.22549 .52013 L
.21076 .53922 L
.20588 .54961 L
.20013 .55882 L
.19062 .57843 L
.18627 .58957 L
.18326 .59804 L
.17731 .61765 L
.17236 .63725 L
.16777 .65686 L
.16667 .66152 L
.1632 .67647 L
.158 .69608 L
.15157 .71569 L
.14706 .72696 L
.1436 .73529 L
.13386 .7549 L
.12745 .76234 L
.11742 .77451 L
.10784 .77473 L
.10743 .77451 L
.08936 .7549 L
.08824 .75311 L
.07691 .73529 L
.07 .71569 L
.06863 .70992 L
.06411 .69608 L
Mistroke
.0588 .67647 L
.05442 .65686 L
.05065 .63725 L
.04902 .62803 L
.04724 .61765 L
.04408 .59804 L
.04116 .57843 L
.03861 .55882 L
.03664 .53922 L
.03546 .51961 L
.03522 .5 L
.0359 .48039 L
.03734 .46078 L
.0393 .44118 L
.04156 .42157 L
.04401 .40196 L
.04666 .38235 L
.04902 .36639 L
.04958 .36275 L
.05289 .34314 L
.05679 .32353 L
.06154 .30392 L
.06741 .28431 L
.06863 .28077 L
.07302 .26471 L
.0825 .2451 L
.08824 .23729 L
.0969 .22549 L
.10784 .21724 L
Mfstroke
.36275 .04863 m
.38235 .04624 L
.40196 .04451 L
.42157 .04336 L
.44118 .04274 L
.46078 .04264 L
.48039 .04304 L
.5 .04394 L
.51961 .04537 L
.53922 .04736 L
.55228 .04902 L
.55882 .04991 L
.57843 .05306 L
.59804 .05707 L
.61765 .06227 L
.63581 .06863 L
.63725 .06919 L
.65686 .07372 L
.67088 .08824 L
.67647 .09485 L
.68027 .10784 L
.67647 .11734 L
.66641 .12745 L
.65686 .13518 L
.63725 .14361 L
.62153 .14706 L
.61765 .14817 L
.59804 .15294 L
.57843 .15656 L
.55882 .15932 L
.53922 .16138 L
.51961 .16283 L
.5 .16374 L
.48039 .16412 L
.46078 .16401 L
.44118 .16341 L
.42157 .16229 L
.40196 .16065 L
.38235 .15842 L
.36275 .15555 L
.34314 .15192 L
.32353 .14737 L
.32232 .14706 L
.30392 .14271 L
.28431 .13604 L
.26721 .12745 L
.26471 .12616 L
.2451 .11221 L
.24227 .10784 L
.2451 .09084 L
Mistroke
.24749 .08824 L
.26471 .07634 L
.28121 .06863 L
.28431 .06729 L
.30392 .06034 L
.32353 .0553 L
.34314 .05154 L
.35996 .04902 L
.36275 .04863 L
Mfstroke
.28431 .04805 m
.30392 .04372 L
.32353 .04011 L
.34314 .03714 L
.36275 .03477 L
.38235 .03292 L
.40196 .03157 L
.42157 .03066 L
.44118 .0302 L
.46078 .03015 L
.48039 .03053 L
.5 .03132 L
.51961 .03255 L
.53922 .03422 L
.55882 .03637 L
.57843 .03903 L
.59804 .04226 L
.61765 .04615 L
.63006 .04902 L
.63725 .05076 L
.65686 .05628 L
.67647 .06342 L
.68772 .06863 L
.69608 .07011 L
.71569 .08708 L
.71635 .08824 L
.72465 .10784 L
.71569 .12566 L
.71391 .12745 L
.69608 .14199 L
.68031 .14706 L
.67647 .14862 L
.65686 .15533 L
.63725 .16049 L
.61765 .16458 L
.60578 .16667 L
.59804 .16791 L
.57843 .17061 L
.55882 .17275 L
.53922 .17438 L
.51961 .17553 L
.5 .17624 L
.48039 .17653 L
.46078 .17639 L
.44118 .17583 L
.42157 .17486 L
.40196 .17345 L
.38235 .1716 L
.36275 .16926 L
.34471 .16667 L
Mistroke
.34314 .16642 L
.32353 .16303 L
.30392 .15906 L
.28431 .15455 L
.26471 .14971 L
.25522 .14706 L
.2451 .14551 L
.22549 .14297 L
.20588 .14344 L
.18979 .14706 L
.18627 .14884 L
.16667 .16645 L
.16653 .16667 L
.15828 .18627 L
.15635 .20588 L
.1584 .22549 L
.16226 .2451 L
.16661 .26471 L
.16667 .26496 L
.17112 .28431 L
.17527 .30392 L
.17901 .32353 L
.18249 .34314 L
.18598 .36275 L
.18627 .36428 L
.18989 .38235 L
.19505 .40196 L
.20266 .42157 L
.20588 .4278 L
.21339 .44118 L
.22549 .45259 L
.23965 .46078 L
.2451 .46181 L
.26471 .46165 L
.27134 .46078 L
.28431 .45719 L
.30392 .45112 L
.32353 .44543 L
.34026 .44118 L
.34314 .44048 L
.36275 .43619 L
.38235 .43257 L
.40196 .42957 L
.42157 .42713 L
.44118 .42522 L
.46078 .42381 L
.48039 .4229 L
.5 .42247 L
.51961 .42254 L
.53922 .4231 L
Mistroke
.55882 .42419 L
.57843 .42585 L
.59804 .42813 L
.61765 .43112 L
.63725 .43497 L
.65686 .43995 L
.66101 .44118 L
.67647 .44585 L
.69608 .45469 L
.70485 .46078 L
.71569 .47047 L
.72173 .48039 L
.71978 .5 L
.71569 .50593 L
.7002 .51961 L
.69608 .52253 L
.67647 .533 L
.65953 .53922 L
.65686 .54017 L
.63725 .5464 L
.61765 .55151 L
.59804 .55575 L
.58113 .55882 L
.57843 .55926 L
.55882 .56211 L
.53922 .56442 L
.51961 .56622 L
.5 .56754 L
.48039 .56837 L
.46078 .56871 L
.44118 .56857 L
.42157 .56793 L
.40196 .56676 L
.38235 .56502 L
.36275 .56266 L
.34314 .55962 L
.33868 .55882 L
.32353 .5559 L
.30392 .55152 L
.28431 .54678 L
.26471 .5431 L
.2451 .54408 L
.22549 .55448 L
.21999 .55882 L
.20621 .57843 L
.20588 .5791 L
.19687 .59804 L
.19047 .61765 L
.18627 .63466 L
.18568 .63725 L
Mistroke
.18156 .65686 L
.17763 .67647 L
.1735 .69608 L
.16898 .71569 L
.16667 .72491 L
.16429 .73529 L
.1599 .7549 L
.15715 .77451 L
.1592 .79412 L
.16667 .81158 L
.17129 .81373 L
.18627 .82381 L
.20588 .82969 L
.22549 .83136 L
.2451 .83061 L
.26471 .82858 L
.28431 .82604 L
.30392 .82347 L
.32353 .82111 L
.34314 .81906 L
.36275 .81738 L
.38235 .81606 L
.40196 .81511 L
.42157 .8145 L
.44118 .81424 L
.46078 .81434 L
.48039 .81478 L
.5 .81558 L
.51961 .81676 L
.53922 .81833 L
.55882 .82032 L
.57843 .82277 L
.59804 .82573 L
.61765 .82928 L
.63627 .83333 L
.63725 .83356 L
.65686 .83857 L
.67647 .84506 L
.69379 .85294 L
.69608 .85413 L
.71569 .86784 L
.71986 .87255 L
.72411 .89216 L
.71569 .90525 L
.70823 .91176 L
.69608 .92059 L
.67647 .9291 L
.66902 .93137 L
.65686 .93557 L
.63725 .94125 L
Mistroke
.61765 .94594 L
.59804 .94988 L
.59195 .95098 L
.57843 .95319 L
.55882 .95598 L
.53922 .95833 L
.51961 .96028 L
.5 .96185 L
.48039 .96305 L
.46078 .9639 L
.44118 .9644 L
.42157 .96455 L
.40196 .96435 L
.38235 .96381 L
.36275 .9629 L
.34314 .96162 L
.32353 .95996 L
.30392 .95792 L
.28431 .95551 L
.26471 .95282 L
.25207 .95098 L
.2451 .94998 L
.22549 .94728 L
.20588 .94505 L
.18627 .94352 L
.16667 .94256 L
.14706 .94142 L
.12745 .93881 L
.10784 .93304 L
.10388 .93137 L
.08824 .92224 L
.07786 .91176 L
.06863 .8959 L
.06729 .89216 L
.06464 .87255 L
.06686 .85294 L
.06863 .84355 L
.07081 .83333 L
.07335 .81373 L
.07264 .79412 L
.06936 .77451 L
.06863 .77029 L
.06397 .7549 L
.05818 .73529 L
.05297 .71569 L
.04902 .69873 L
.04843 .69608 L
.04443 .67647 L
.04091 .65686 L
.03776 .63725 L
Mistroke
.03483 .61765 L
.03205 .59804 L
.02943 .57843 L
.02941 .57827 L
.0271 .55882 L
.02528 .53922 L
.02419 .51961 L
.02399 .5 L
.02466 .48039 L
.02602 .46078 L
.02785 .44118 L
.02941 .42612 L
.02991 .42157 L
.03209 .40196 L
.03439 .38235 L
.03688 .36275 L
.03966 .34314 L
.04284 .32353 L
.04651 .30392 L
.04902 .29201 L
.05073 .28431 L
.05554 .26471 L
.06103 .2451 L
.06702 .22549 L
.06863 .22055 L
.07191 .20588 L
.07644 .18627 L
.07967 .16667 L
.08152 .14706 L
.08387 .12745 L
.08824 .11004 L
.08937 .10784 L
.1029 .08824 L
.10784 .0843 L
.12745 .0747 L
.14706 .07152 L
.16667 .07063 L
.18627 .06944 L
.20484 .06863 L
.20588 .06843 L
.22549 .06364 L
.2451 .05803 L
.26471 .05274 L
.28034 .04902 L
.28431 .04805 L
Mfstroke
.30392 .02706 m
.32353 .02428 L
.34314 .02194 L
.36275 .02004 L
.38235 .01855 L
.40196 .01745 L
.42157 .01674 L
.44118 .01638 L
.46078 .01638 L
.48039 .01673 L
.5 .01744 L
.51961 .01851 L
.53922 .01995 L
.55882 .02177 L
.57843 .02401 L
.59804 .02669 L
.61508 .02941 L
.61765 .02986 L
.63725 .03355 L
.65686 .03786 L
.67647 .04289 L
.69608 .04883 L
.69665 .04902 L
.71569 .05579 L
.73529 .06489 L
.74174 .06863 L
.7549 .07397 L
.76588 .08824 L
.77337 .10784 L
.76492 .12745 L
.7549 .13944 L
.73846 .14706 L
.73529 .14875 L
.71569 .1574 L
.69608 .16396 L
.68655 .16667 L
.67647 .16932 L
.65686 .17382 L
.63725 .1776 L
.61765 .18078 L
.59804 .18343 L
.57843 .18561 L
.57155 .18627 L
.55882 .18729 L
.53922 .18856 L
.51961 .18945 L
.5 .18999 L
.48039 .19018 L
.46078 .19003 L
.44118 .18954 L
Mistroke
.42157 .18871 L
.40196 .18753 L
.3855 .18627 L
.38235 .18599 L
.36275 .18397 L
.34314 .18156 L
.32353 .17876 L
.30392 .17564 L
.28431 .17237 L
.26471 .16936 L
.2451 .16742 L
.22549 .168 L
.20588 .17387 L
.19114 .18627 L
.18627 .19248 L
.18257 .20588 L
.1806 .22549 L
.18187 .2451 L
.18459 .26471 L
.18627 .27545 L
.18776 .28431 L
.19091 .30392 L
.19395 .32353 L
.19698 .34314 L
.20034 .36275 L
.20474 .38235 L
.20588 .38646 L
.21083 .40196 L
.22219 .42157 L
.22549 .4251 L
.2451 .4379 L
.26471 .44034 L
.28431 .43806 L
.30392 .43404 L
.32353 .42968 L
.34314 .42558 L
.36275 .42194 L
.36488 .42157 L
.38235 .41895 L
.40196 .41642 L
.42157 .4143 L
.44118 .4126 L
.46078 .41132 L
.48039 .41044 L
.5 .40998 L
.51961 .40993 L
.53922 .41031 L
.55882 .41113 L
.57843 .41241 L
.59804 .41417 L
Mistroke
.61765 .41646 L
.63725 .41932 L
.65019 .42157 L
.65686 .42289 L
.67647 .42736 L
.69608 .4329 L
.71569 .44001 L
.71844 .44118 L
.73529 .44853 L
.75121 .46078 L
.7549 .46447 L
.76416 .48039 L
.76148 .5 L
.7549 .50938 L
.74389 .51961 L
.73529 .52606 L
.71569 .53659 L
.7094 .53922 L
.69608 .54469 L
.67647 .5515 L
.65686 .55723 L
.65078 .55882 L
.63725 .56203 L
.61765 .56615 L
.59804 .56972 L
.57843 .57277 L
.55882 .57535 L
.53922 .57746 L
.5285 .57843 L
.51961 .57907 L
.5 .58021 L
.48039 .58097 L
.46078 .58134 L
.44118 .58132 L
.42157 .58089 L
.40196 .58004 L
.38235 .57875 L
.37828 .57843 L
.36275 .5769 L
.34314 .57453 L
.32353 .57169 L
.30392 .56857 L
.28431 .56575 L
.26471 .56463 L
.2451 .56813 L
.22723 .57843 L
.22549 .58146 L
.21354 .59804 L
.20588 .61755 L
.20585 .61765 L
Mistroke
.20038 .63725 L
.19635 .65686 L
.19289 .67647 L
.18954 .69608 L
.18627 .71493 L
.18614 .71569 L
.18279 .73529 L
.18038 .7549 L
.18075 .77451 L
.18627 .79125 L
.18797 .79412 L
.20588 .80917 L
.22266 .81373 L
.22549 .81421 L
.2451 .81548 L
.26471 .81464 L
.27866 .81373 L
.28431 .81292 L
.30392 .811 L
.32353 .80911 L
.34314 .80742 L
.36275 .80599 L
.38235 .80484 L
.40196 .80399 L
.42157 .80344 L
.44118 .80319 L
.46078 .80324 L
.48039 .8036 L
.5 .80426 L
.51961 .80523 L
.53922 .80652 L
.55882 .80814 L
.57843 .8101 L
.59804 .81242 L
.60782 .81373 L
.61765 .81525 L
.63725 .81867 L
.65686 .82266 L
.67647 .82735 L
.69608 .83294 L
.69734 .83333 L
.71569 .8395 L
.73529 .84838 L
.74289 .85294 L
.7549 .86162 L
.76464 .87255 L
.76792 .89216 L
.7549 .91079 L
.75379 .91176 L
.73529 .92515 L
Mistroke
.72029 .93137 L
.71569 .93335 L
.69608 .94067 L
.67647 .94666 L
.65997 .95098 L
.65686 .95172 L
.63725 .95601 L
.61765 .95976 L
.59804 .96305 L
.57843 .96592 L
.55882 .9684 L
.53922 .9705 L
.53832 .97059 L
.51961 .97225 L
.5 .97366 L
.48039 .97475 L
.46078 .97552 L
.44118 .97598 L
.42157 .97614 L
.40196 .97599 L
.38235 .97554 L
.36275 .97477 L
.34314 .97367 L
.32353 .97225 L
.30474 .97059 L
.30392 .97051 L
.28431 .96849 L
.26471 .96629 L
.2451 .96409 L
.22549 .96219 L
.20588 .96091 L
.18627 .96044 L
.16667 .96059 L
.14706 .96067 L
.12745 .95952 L
.10784 .95585 L
.09338 .95098 L
.08824 .94845 L
.06863 .93587 L
.06351 .93137 L
.04902 .91404 L
.0478 .91176 L
.0404 .89216 L
.03921 .87255 L
.04202 .85294 L
.04615 .83333 L
.04902 .81477 L
.04912 .81373 L
.04956 .79412 L
.04902 .78652 L
Mistroke
.04754 .77451 L
.04402 .7549 L
.03999 .73529 L
.03603 .71569 L
.03239 .69608 L
.02941 .67834 L
.02911 .67647 L
.02617 .65686 L
.02346 .63725 L
.0209 .61765 L
.01843 .59804 L
.01605 .57843 L
.01392 .55882 L
.01225 .53922 L
.01127 .51961 L
.01111 .5 L
.01177 .48039 L
.01306 .46078 L
.01476 .44118 L
.01664 .42157 L
.0186 .40196 L
.02062 .38235 L
.02276 .36275 L
.02513 .34314 L
.02779 .32353 L
.02941 .31274 L
.03082 .30392 L
.03423 .28431 L
.03799 .26471 L
.04199 .2451 L
.04596 .22549 L
.04902 .20879 L
.04945 .20588 L
.05192 .18627 L
.05317 .16667 L
.0536 .14706 L
.05441 .12745 L
.0573 .10784 L
.06419 .08824 L
.06863 .08005 L
.07748 .06863 L
.08824 .05901 L
.10599 .04902 L
.10784 .04837 L
.12745 .04354 L
.14706 .04234 L
.16667 .04283 L
.18627 .04327 L
.20588 .04256 L
.22549 .04043 L
Mistroke
.2451 .03729 L
.26471 .03375 L
.28431 .03025 L
.28927 .02941 L
.30392 .02706 L
Mfstroke
.0098 .86745 m
.01336 .85294 L
.01903 .83333 L
.02341 .81373 L
.02523 .79412 L
.02458 .77451 L
.02233 .7549 L
.01938 .73529 L
.01634 .71569 L
.01347 .69608 L
.01088 .67647 L
.0098 .66774 L
s
.0098 .89986 m
.01389 .91176 L
.02642 .93137 L
.02941 .93494 L
.04598 .95098 L
.04902 .95347 L
.06863 .96706 L
.0747 .97059 L
.08824 .97678 L
.10784 .9825 L
.12745 .98461 L
.14706 .98414 L
.16667 .98247 L
.18627 .98084 L
.20588 .98004 L
.22549 .98027 L
.2451 .98132 L
.26471 .98283 L
.28431 .98447 L
.30392 .98602 L
.32353 .98736 L
.34314 .98846 L
.36275 .98929 L
.38235 .98987 L
.40153 .9902 L
s
.43641 .9902 m
.44118 .99014 L
.46078 .98975 L
.48039 .98911 L
.5 .98822 L
.51961 .98707 L
.53922 .98563 L
.55882 .9839 L
.57843 .98184 L
.59804 .97944 L
.61765 .97666 L
.63725 .97348 L
.65317 .97059 L
.65686 .96988 L
.67647 .96581 L
.69608 .96126 L
.71569 .95616 L
.73342 .95098 L
.73529 .95038 L
.7549 .9435 L
.77451 .93515 L
.78203 .93137 L
.79412 .9254 L
.81061 .91176 L
.81373 .90847 L
.82311 .89216 L
.82074 .87255 L
.81373 .8627 L
.80283 .85294 L
.79412 .84672 L
.77451 .83662 L
.7664 .83333 L
.7549 .82891 L
.73529 .82241 L
.71569 .81688 L
.70306 .81373 L
.69608 .8122 L
.67647 .80824 L
.65686 .80472 L
.63725 .80159 L
.61765 .79882 L
.59804 .79642 L
.57843 .79435 L
.57599 .79412 L
.55882 .79286 L
.53922 .79165 L
.51961 .79068 L
.5 .78994 L
.48039 .78944 L
.46078 .78919 L
Mistroke
.44118 .78917 L
.42157 .7894 L
.40196 .78987 L
.38235 .79057 L
.36275 .79149 L
.34314 .7926 L
.32353 .79387 L
.31988 .79412 L
.30392 .79545 L
.28431 .79694 L
.26471 .79769 L
.2451 .79656 L
.23386 .79412 L
.22549 .79172 L
.20824 .77451 L
.20588 .76791 L
.20354 .7549 L
.20378 .73529 L
.20588 .71572 L
.20589 .71569 L
.20838 .69608 L
.21116 .67647 L
.21442 .65686 L
.21896 .63725 L
.22549 .61967 L
.22632 .61765 L
.24087 .59804 L
.2451 .59528 L
.26471 .58766 L
.28431 .58648 L
.30392 .58779 L
.32353 .58985 L
.34314 .59194 L
.36275 .59376 L
.38235 .59521 L
.40196 .59627 L
.42157 .59694 L
.44118 .59723 L
.46078 .59716 L
.48039 .59671 L
.5 .59591 L
.51961 .59474 L
.53922 .5932 L
.55882 .5913 L
.57843 .58904 L
.59804 .58641 L
.61765 .58344 L
.63725 .58012 L
.64653 .57843 L
.65686 .57621 L
Mistroke
.67647 .57158 L
.69608 .56638 L
.71569 .56052 L
.72094 .55882 L
.73529 .55366 L
.7549 .54549 L
.76771 .53922 L
.77451 .53572 L
.79412 .52243 L
.79724 .51961 L
.81311 .5 L
.81373 .49862 L
.81642 .48039 L
.81373 .47165 L
.80678 .46078 L
.79412 .44789 L
.78194 .44118 L
.77451 .43708 L
.7549 .42832 L
.73564 .42157 L
.73529 .42146 L
.71569 .4159 L
.69608 .41123 L
.67647 .40726 L
.65686 .4039 L
.64373 .40196 L
.63725 .40118 L
.61765 .3991 L
.59804 .39742 L
.57843 .39612 L
.55882 .39519 L
.53922 .39462 L
.51961 .39441 L
.5 .39455 L
.48039 .39503 L
.46078 .39585 L
.44118 .39699 L
.42157 .39845 L
.40196 .40021 L
.38495 .40196 L
.38235 .4023 L
.36275 .40505 L
.34314 .40816 L
.32353 .41152 L
.30392 .41481 L
.28431 .41728 L
.26471 .41723 L
.2451 .41063 L
.2341 .40196 L
.22549 .3852 L
Mistroke
.22432 .38235 L
.21838 .36275 L
.21471 .34314 L
.21192 .32353 L
.20944 .30392 L
.20712 .28431 L
.20588 .27637 L
.20515 .26471 L
.20428 .2451 L
.20588 .22778 L
.20632 .22549 L
.2152 .20588 L
.22549 .1978 L
.2451 .19182 L
.26471 .19113 L
.28431 .19254 L
.30392 .19478 L
.32353 .19719 L
.34314 .19948 L
.36275 .20151 L
.38235 .20324 L
.40196 .20466 L
.42157 .20576 L
.42396 .20588 L
.44118 .20646 L
.46078 .20689 L
.48039 .20704 L
.5 .20693 L
.51961 .20654 L
.53922 .20588 L
.53927 .20588 L
.55882 .20481 L
.57843 .2034 L
.59804 .20164 L
.61765 .19953 L
.63725 .19703 L
.65686 .19414 L
.67647 .19083 L
.69608 .18704 L
.69972 .18627 L
.71569 .1825 L
.73529 .1772 L
.7549 .17099 L
.7667 .16667 L
.77451 .16359 L
.79412 .15426 L
.80562 .14706 L
.81373 .14372 L
.82655 .12745 L
.83305 .10784 L
Mistroke
.82627 .08824 L
.81373 .07207 L
.8058 .06863 L
.79412 .06099 L
.77451 .05118 L
.76939 .04902 L
.7549 .04326 L
.73529 .03652 L
.71569 .0307 L
.71095 .02941 L
.69608 .02562 L
.67647 .02117 L
.65686 .01728 L
.63725 .0139 L
.61765 .01096 L
.60902 .0098 L
Mfstroke
.0098 .32385 m
.00984 .32353 L
.01222 .30392 L
.0149 .28431 L
.01781 .26471 L
.02082 .2451 L
.02362 .22549 L
.02577 .20588 L
.02684 .18627 L
.02665 .16667 L
.02562 .14706 L
.02487 .12745 L
.02591 .10784 L
.02941 .09094 L
.03024 .08824 L
.03895 .06863 L
.04902 .05367 L
.05295 .04902 L
.06863 .03402 L
.07456 .02941 L
.08824 .02136 L
.10784 .01425 L
.12745 .01171 L
.14706 .01237 L
.16667 .01453 L
.18627 .01656 L
.20588 .01743 L
.22549 .01686 L
.2451 .01514 L
.26471 .01281 L
.28431 .0103 L
.28832 .0098 L
s
.0098 .97025 m
.0102 .97059 L
.02941 .98628 L
.03447 .9902 L
s
.69376 .9902 m
.69608 .98981 L
.71569 .98627 L
.73529 .98221 L
.7549 .97758 L
.77451 .97235 L
.78065 .97059 L
.79412 .9665 L
.81373 .96 L
.83333 .95273 L
.83768 .95098 L
.85294 .94412 L
.87255 .93345 L
.8758 .93137 L
.89216 .91988 L
.89927 .91176 L
.91002 .89216 L
.90864 .87255 L
.89479 .85294 L
.89216 .85031 L
.87255 .83628 L
.86699 .83333 L
.85294 .82627 L
.83333 .81798 L
.82183 .81373 L
.81373 .81108 L
.79412 .80518 L
.77451 .79983 L
.7549 .79499 L
.75113 .79412 L
.73529 .79115 L
.71569 .78764 L
.69608 .78433 L
.67647 .78127 L
.65686 .77847 L
.63725 .77595 L
.62485 .77451 L
.61765 .77398 L
.59804 .7726 L
.57843 .77133 L
.55882 .7702 L
.53922 .76923 L
.51961 .76845 L
.5 .76785 L
.48039 .76747 L
.46078 .76729 L
.44118 .76732 L
.42157 .76756 L
.40196 .768 L
.38235 .76863 L
Mistroke
.36275 .76944 L
.34314 .77037 L
.32353 .77134 L
.30392 .77211 L
.28431 .77225 L
.26471 .77053 L
.2451 .76009 L
.2415 .7549 L
.23499 .73529 L
.23472 .71569 L
.23642 .69608 L
.23922 .67647 L
.24378 .65686 L
.2451 .65264 L
.25091 .63725 L
.26471 .62388 L
.28431 .61767 L
.2845 .61765 L
.30392 .6164 L
.32353 .61715 L
.3327 .61765 L
.34314 .61823 L
.36275 .61917 L
.38235 .61996 L
.40196 .62052 L
.42157 .62085 L
.44118 .62092 L
.46078 .62075 L
.48039 .62034 L
.5 .61971 L
.51961 .61889 L
.53922 .6179 L
.54391 .61765 L
.55882 .6163 L
.57843 .61424 L
.59804 .61186 L
.61765 .60919 L
.63725 .60626 L
.65686 .60314 L
.67647 .59989 L
.6875 .59804 L
.69608 .59615 L
.71569 .59151 L
.73529 .58651 L
.7549 .58121 L
.76479 .57843 L
.77451 .57521 L
.79412 .56819 L
.81373 .56042 L
.81748 .55882 L
Mistroke
.83333 .55123 L
.85294 .54015 L
.85441 .53922 L
.87255 .52603 L
.87909 .51961 L
.89216 .50359 L
.89317 .5 L
.89715 .48039 L
.89216 .4631 L
.89088 .46078 L
.87324 .44118 L
.87255 .44059 L
.85294 .42738 L
.84176 .42157 L
.83333 .41767 L
.81373 .40975 L
.79412 .40301 L
.79078 .40196 L
.77451 .39756 L
.7549 .39276 L
.73529 .38846 L
.71569 .38465 L
.7025 .38235 L
.69608 .38152 L
.67647 .37914 L
.65686 .377 L
.63725 .37513 L
.61765 .37355 L
.59804 .37227 L
.57843 .37129 L
.55882 .37063 L
.53922 .37027 L
.51961 .37022 L
.5 .37048 L
.48039 .37103 L
.46078 .37188 L
.44118 .37301 L
.42157 .37441 L
.40196 .37605 L
.38235 .37789 L
.36275 .37986 L
.34314 .38185 L
.33837 .38235 L
.32353 .38429 L
.30392 .38635 L
.28431 .38629 L
.26921 .38235 L
.26471 .38037 L
.24864 .36275 L
.2451 .34999 L
Mistroke
.24331 .34314 L
.23963 .32353 L
.23728 .30392 L
.23582 .28431 L
.23593 .26471 L
.24038 .2451 L
.2451 .23616 L
.26471 .22556 L
.26509 .22549 L
.28431 .22308 L
.30392 .22361 L
.32353 .22515 L
.32744 .22549 L
.34314 .22658 L
.36275 .2279 L
.38235 .22912 L
.40196 .23016 L
.42157 .23101 L
.44118 .23165 L
.46078 .23207 L
.48039 .23225 L
.5 .23221 L
.51961 .23194 L
.53922 .23143 L
.55882 .2307 L
.57843 .22975 L
.59804 .22859 L
.61765 .22723 L
.63725 .22569 L
.6397 .22549 L
.65686 .2235 L
.67647 .22092 L
.69608 .21803 L
.71569 .21484 L
.73529 .21135 L
.7549 .20757 L
.76316 .20588 L
.77451 .20314 L
.79412 .19797 L
.81373 .19221 L
.83183 .18627 L
.83333 .18573 L
.85294 .17796 L
.87255 .16869 L
.87631 .16667 L
.89216 .15719 L
.90469 .14706 L
.91176 .14366 L
.92035 .12745 L
.92487 .10784 L
Mistroke
.91881 .08824 L
.91176 .07594 L
.90197 .06863 L
.89216 .06068 L
.87329 .04902 L
.87255 .04861 L
.85294 .03884 L
.83333 .03056 L
.83038 .02941 L
.81373 .02335 L
.79412 .01703 L
.77451 .0115 L
.76795 .0098 L
Mfstroke
.0098 .03331 m
.01301 .02941 L
.02941 .01132 L
.03089 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool>o`0000gooooo1ol0000hooooo`;o00001P00000Dooooo`;o00000P00
000Wooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`80000000?o
000001TI6@0I6AT02P0I6AT00ol00000<c<c03<c<`0<03<c<`go00004P0c<c<S00000180<c<c0`00
000E01TI6B<000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01P00003ooooooooooooo
ool00000o`0000/06ATI0_l0000W03<c<`L000008`1<C4`7000000h0<c<c1`00000B01TI6Al00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01@00003ooooooooooooooooo000000X06ATI
0_l0000R03<c<`0300000?l00000000000@000003P1<C4`E000000h0C4a<1`00000>03<c<`040000
0?l000000000000001406ATI00<00000o`00000000006@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0500000?ooooooooooooooool000002@0I6AT00ol00000<c<c03<c<`0N03<c<`@0
00002P1<C4`;000001D0IVIV2`00000:04a<C0@000003P0c<c<2000001806ATI6@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`T06ATI00?o000003<c<`0c
<c<02P0c<c<8000000<0<c<c2P00000;04a<C0<000004P1VIVH800000140IVIV1`00000704a<C0H0
00002P0c<c<2000001406ATI60000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooo`P06ATI00?o000003<c<`0c<c<01P0c<c<5000000P0C4a<0`00000?04a<C003
o`0000000000000000<000002P1VIVH;000000P0Ogmo3@00000;06IVIP<000002P1<C4`00`000000
<c<c03<c<`0903<c<`8000004@0I6ATF000000Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo1`0I6AT00ol00000<c<c03<c<`0603<c<`0300000?l00000C4a<01P0
C4a<1@0000000ol00000IVIV06IVIP0606IVIPD0000000?o00000000001oOgl07`1oOgl00ol00000
000000000004000000L0IVIV00Co000000000000000000001`1<C4`3000000X0<c<c00<00000o`00
000000003`0I6AT00`00003o00000000000B000000Cooooo00<00000ooooooooool0coooool000Wo
oooo00@00000oooooooooooooooo1`0I6AT00ol00000<c<c03<c<`0403<c<`800000601<C4`30000
00/0IVIV0`00000707moOad000002P1oOgl4000000L0IVIV0`00000704a<C0@000002@0c<c<20000
01006ATI4P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
o`H06ATI00?o000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00D04a<C0@000002P1VIVH40000
00L0Ogmo0`00000M09VIV@L000001`1oOgl3000000L0IVIV0`00000804a<C003o`00000c<c<0<c<c
00P0<c<c0P00000?01TI6A4000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool501TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`02`1<C4`:0000
00/0IVIV0`00000707moO`0400000?l0003o0000000000X0VIVI4_l0000;09VIV@<000001`1oOgl4
000000H0IVIV00?o00000000000000001P1<C4`3000000T0<c<c00<0000001TI6@0I6AT03P0I6AT?
000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1@0I6AT0
0ol00000<c<c03<c<`0303<c<`030000001<C4`0C4a<00D0C4a<1`00000C06IVIP8000001`1oOgl3
000000P0VIVI1_l0000B0;>c/`Co00002P2IVIT3000000P0Ogmo00<0000006IVIP1VIVH01P1VIVH0
0`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00?o000001TI6@0I6AT03P0I6AT0
0ol0000000000000000;000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
oooooooooooo100I6AT00ol00000<c<c03<c<`0303<c<`030000001<C4`0C4a<00D0C4a<00<00000
06IVIP1VIVH05`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00L0VIVI0_l0000L
0;>c/`Go0000202IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00h06ATI3P000004
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`@06ATI00?o0000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV01L0IVIV00<00000
07moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@;o00008`2c/k<00ol00000VIVI09VIV@06
09VIV@8000001`1oOgl00`000000IVIV06IVIP0606IVIP03o`00001<C4`0C4a<00D0C4a<00<00000
03<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0>01TI6@d000001?ooool00`00003oooooooooo`2;
ooooo`;o0000@_ooool000Wooooo00@00000oooooooooooooooo0`0I6AT00ol00000<c<c03<c<`03
03<c<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH05P1VIVH00ol00000000007moO`07
07moO`03o`00002IVIT0VIVI00H0VIVI00?o00000;>c/`2c/k<0302c/k<<o`0000`0/k>c0_l00008
09VIV@030000001oOgl0Ogmo00D0Ogmo00?o000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C006
04a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03P0I6AT<000000Cooooo00<00000
ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooooooo
ooooo`<06ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV01H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0609VIV@03o`00002c/k<0
/k>c00X0/k>c0_l0000<0<c<c003o`00002c/k<0/k>c00X0/k>c00?o000009VIV@2IVIT01P2IVIT0
0`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`0
0`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00h06ATI30000004ooooo`0300000?oooooo
oooo08Kooooo0_l00003ooooo`03oj^fh?l0003o0000047ooooo0009ooooo`0400000?oooooooooo
ooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV01L0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@03o`00002c/k<0
/k>c00X0/k>c00?o00000<c<c03<c<`03@3<c<`00ol00000/k>c0;>c/`0:0;>c/`03o`00002IVIT0
VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0
C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0>01TI6@/000001?ooool0
0`00003oooooooooo`23ooooo`?o00001?ooool2oj^fh003o`000?oooooo0000043ooooo0009oooo
o`0400000?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV01P0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@06
09VIV@;o00002P2c/k<2o`0000l0c<c<0_l0000<0;>c/`03o`00002IVIT0VIVI00D0VIVI0P000006
07moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`07
03<c<`030000000I6AT06ATI00h06ATI2`000004ooooo`0300000?oooooooooo083ooooo0ol00005
ooooo`07ojbdg_n[]^3oZkKPoj^fh?l0003oooooo`000010ooooo`002Oooool01000003ooooooooo
ooooool201TI6@03o`00000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0H06IVIP03o`0000000000Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2IVIT00ol00000/k>c
0;>c/`090;>c/`Ko00001P3<c<`3o`0000d0/k>c00?o000009VIV@2IVIT01@2IVIT00`000000Ogmo
07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c
03<c<`0703<c<`030000000I6AT06ATI00h06ATI2`000004ooooo`0300000?oooooooooo07kooooo
0_l00005ooooo`;o[;;L0on/]=h2oj^fh004o`000?ooooooooooo`0003oooooo0009ooooo`040000
0?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C003
0000001VIVH0IVIV01/0IVIV0P00000707moO`<000001`2IVIT3o`0000h0/k>c1_l0000>0;>c/`;o
00001`2IVIT00`000000Ogmo07moO`0607moO`8000001P1VIVH00`000000C4a<04a<C00604a<C003
0000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03P0I6AT<000000Cooooo00<00000oooooooo
ool0Noooool3o`0000Gooooo00?o[:oJojbbg?n//]`00_n//]`01_n/]=ko[K;Lojfbg?n]]=ko0000
ojfdgP;ooooo00?o0000ooooooooool0??ooool000Wooooo00@00000oooooooooooooooo0P0I6AT0
0ol00000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH07@1VIVH2
000000P0Ogmo00<0000009VIV@2IVIT01`2IVIT00ol00000/k>c0;>c/`0K0;>c/`Co00001`2IVIT2
000000P0Ogmo00<0000006IVIP1VIVH01@1VIVH00`00003o000004a<C00604a<C0030000000c<c<0
<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6AT<000000Cooooo00<00000ooooooooool0NOooool2
o`0000Gooooo00?o[:cHojb_f_n/[mX00_n/[mX2ojbbg003ojj`f_n]/]co[K;L00;o[K;L00Go0000
ojnfgOooooooooooo`00000nooooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c
<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0O06IVIP030000001o
Ogl0Ogmo00D0Ogmo00?o0000000000000000202IVIT6o`0001@0/k>c0ol0000:09VIV@030000001o
Ogl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C0030000000c
<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6AT<000000Cooooo00<00000ooooooooool0M_oo
ool3o`0000Gooooo00Co[:WDojb/f?n/[=So[:cH0_n/[mX00on^[MOo[[3Jojj`fP02ojj`fP;o[K;L
00Co/;?Ko`000?n_]]go[kKM0_ooool00ol0003oooooooooo`0kooooo`002Oooool01000003ooooo
ooooooooool201TI6@03o`00000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`00`000000
IVIV06IVIP0P06IVIP<000001`1oOgl4000000X0VIVI1ol000060;>c/`Oo00002P2IVIT3000000P0
Ogmo0P00000706IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00`000000
6ATI01TI6@0>01TI6@d000001?ooool00`00003oooooooooo`1dooooo`;o00001Oooool00on/Y]7o
[:WDojbYe002ojbYe0;o[:cH1?n^[ML2ojj`fP06ok6afOn`/m_o/;?Kok2cfol0003o[kKM0_nb^Mh0
0ooooooo0000ooooo`0looooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0
<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0B06IVIPP000002P1VIVH4
000000L0Ogmo0`00000>09VIV@Ko00003P2IVIT3000000P0Ogmo0`00000706IVIP8000002@1<C4`2
000000T0<c<c00<0000001TI6@0I6AT03P0I6AT>000000Cooooo00<00000ooooooooool0LOooool3
o`0000Kooooo0on/Y]43ojbYe003ojb/f?n^Z]Co[Z[D00?o[ZgG1?na/MT2ok2cf`03o`000?nb^Mko
/[WN00;o/[WN00?oooooo`000?ooool0>oooool000Wooooo00@00000oooooooooooooooo0P0I6AT0
0ol00000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH03`1VIVH3
000000P0C4a<1`00000706IVIP<000001`1oOgl;000000`0VIVI2`00000707moO`80000000?o0000
0000001VIVH01@1VIVH4000000L0C4a<0P0000000ol00000000003<c<`0803<c<`0300000?l00000
6ATI00l06ATI00?o000000000000000030000004ooooo`0300000?oooooooooo06kooooo0ol00007
ooooo`;oZj;>0on/Y]42ojbYe003ojjWd?n^Z]Co[Z[D00;o[Z[D00?o[ZgGok6_e_na[mH00ona/MT2
ok>hg005o`000?nc^=co/[WNok:ig_nd_^400_ooool00ol0003oooooooooo`0iooooo`002Oooool0
1000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0>06IVIP030000001<C4`0C4a<0100C4a<0`00000706IVIPL000002`1o
Ogl<000000h0Ogmo1000000706IVIP<000002P1<C4`00`000000<c<c03<c<`0903<c<`8000004@0I
6AT@000000Cooooo00<00000ooooooooool0K?ooool2o`0000Sooooo00?oZik;oj^Rc_n[X/h00_n[
X/h00on/Y]7o[Z?=ojjWd003ojjWd0;o[Z[D00?o/ZcBok6_e_na[mH00_na[mH00ona/MWo];KJokBf
fP02ok>hg003o`000?nd_^7o];kQ00;o];kQ00?oooooo`000?ooool0>_ooool000Wooooo00@00000
oooooooooooooooo0`0I6AT01Ol00000<c<c03<c<`0c<c<0000000@0C4a<00<0000006IVIP1VIVH0
3@1VIVH00`000000C4a<04a<C00D04a<C0@000002P1VIVH7000001@0Ogmo2P00000706IVIP@00000
2P1<C4`3000000X0<c<c0P00000A01TI6A8000001?ooool00`00003oooooooooo`1Yooooo`?o0000
2?ooool4oj^Nb`;oZj;>00Co[Yo9ojjScOn^Xlgo[Z?=0on^Ym04ok:/dP;o/JoF00So][CGokBff_nd
]][o];KJok>hg?ng_^3o0000okNnh0;o];kQ00Co]lGUoooooooooooo0000>_ooool000Wooooo00@0
0000oooooooooooooooo0`0I6AT01Ol00000<c<c03<c<`0c<c<0000000@0C4a<00<0000006IVIP1V
IVH0301VIVH00`00003o000004a<C00I04a<C0L000002P1VIVHD000000d0IVIV00Co000000000000
000000002P1<C4`200000003o`0000000000<c<c00T0<c<c00<00000o`00000000004@0I6ATD0000
00Cooooo00<00000ooooooooool0Ioooool2o`0000[ooooo0_nZVlL3oj^Nb`04oj^Rc_n^WlWo[Yo9
ojjOb@?o[Z?=00?o[ZO@ok:YconbZLl00_nb[=800ong/]Co][CGokJde`02okJde`07okBff_ni_]ko
^KkNokNnh?l0003o]kkPokW7i@03okO5i@;ooooo00?o0000ooooooooool0=oooool000Wooooo00@0
0000oooooooooooooooo0`0I6AT01Ol00000<c<c03<c<`0c<c<0000000@0C4a<00<0000006IVIP1V
IVH0301VIVH00`000000C4a<04a<C00604a<C0l000002`1<C4`7000001h0IVIV1P00000;04a<C0<0
00002`0c<c<3000001806ATI00<00000o`00000000004`000004ooooo`0300000?oooooooooo06Co
oooo0ol0000:ooooo`03ojVG`onZVlOoZY_700;oZY_700?oZik;ojfLaOn^WlT00on^WlT2ojjSc@05
ok:UbonbZLoo/ZW?ok:Yconb[=800ong/]@2okJde`03ok^ng?ni_]ko^KkN00;o^KkN00Go0000okW7
iOnianGo^LOUokO5i@02okO;j@03ooooool0003ooooo03Sooooo0009ooooo`0400000?oooooooooo
ooooo`<06ATI00Go000003<c<`0c<c<0<c<c0000000404a<C0030000001VIVH0IVIV00`0IVIV00<0
000004a<C01<C4`0101<C4`2000000l0<c<c1000000>04a<C1h000002P1<C4`7000000/0<c<c0`00
000B01TI6AT000001?ooool00`00003oooooooooo`1Rooooo`;o00002_ooool00onXTl3oZIO3ojVG
``02ojVG``;oZY_700Co[9S1ojfLaOn]W<Go[Ic50_n^WlT00onbX/So/ZG;ok:Ub`02ok:Ub`03ok:Y
conh/=7o^;3A00?o]k;D00Co][CGok^ng?nk_]co^kkL0_ni_]h01?nlbNCo0000okW7iOnianD2ok[>
jP05okO;jOnec^coooooooooool00000>?ooool000Wooooo00@00000oooooooooooooooo0`0I6AT0
1Ol00000<c<c03<c<`0c<c<0000000<0C4a<00<0000006IVIP1VIVH0301VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c01<0<c<c2P00000U04a<C0L000003`0c<c<3000001@06ATI6P00
0004ooooo`0300000?oooooooooo05oooooo0ol0000:ooooo`04ojN?_?nXTl3oZ9?0ojRC`0?oZIO3
00?oZY_7ojbH`On/V<400on]W<D01?n^WlWo/Z;8ok:Rb?nbX/P2ok:Ub`03okV^c_nh/=7o^;3A00;o
^;3A00?o]k;Dokfnf_nm_]X00onk_]`3okc9i005o`000?njc^[o^/kZok[>j_nhd^d00onec^`2oooo
o`03o`000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00Go000003<c
<`0c<c<0<c<c0000000304a<C0030000001VIVH0IVIV00`0IVIV00<0000004a<C01<C4`00`1<C4`0
0ol00000<c<c03<c<`0N03<c<`h000002@1<C4`<00000003o`0000000000<c<c0140<c<c00@00000
o`00000000000000500I6AT00`00003o00000000000J000000Cooooo00<00000ooooooooool0GOoo
ool2o`0000cooooo0_nWSk`4ojRC`003ojVG`on[Tkko[9S100?o[9S10_n]W<D4ok:Rb004ok:Uboni
[/ko^Jk>okV^cP;o^;3A00?o_kkHokfnf_nm_]X00_nm_]X02?nk_]co_l_Soko;honlbNCo_=;Zo`00
0?nld^[o^/kZ0onhd^d01Onec^co/lk^ok?>k_ncc^ko000003Oooooo0009ooooo`0400000?oooooo
ooooooooo`<06ATI00Go000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVH0IVIV00`0IVIV
00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0603<c<`l00000600c<c<9000001T0<c<c
1`00000E01TI6B0000001?ooool00`00003oooooooooo`1Jooooo`?o00003?ooool00onURkWoYhnl
ojN?_002ojN?_0;oZ9?000CoZY2joj^C__n[TkkoZi>n0on/V<400on]W<Go/Yk4ok:Na003ok:Rb0Co
^Jk>00Co^;3Aoknnf?no_]So_kkH0_nm_]X2ol;=h`05oko;hoo0e^[o`=KZol3Fj_l000000_njenh2
okSBk@;o]=;_0_ncc^h00on`bnkoooooo`00000fooooo`002Oooool01000003oooooooooooooool2
01TI6@03o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000>06IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<3000000l06ATI1`00000/03<c<`L00000600I
6ATT000000Cooooo00<00000ooooooooool0Eoooool3o`0000gooooo00?oY8RfojF;^OnURkT01?nW
Sk`00onXTl3oZY2jojZ@^P03oj^C_P;o[9S100?o/I_0ok:Na?nbW/@00_nbW/@00onbX/So^Z_;okZ[
b`03okV^cP04ol:me_no_]So_kkHoknnf0?o`/gS00Soa=_[ol3Fj_o0e^[o`=KZokgLkol0003o^]O^
okOFl0?o]=;_00?o/Lk_ok3;k_n`bnh00_n`bnh00ooooooo0000ooooo`0dooooo`002Oooool01000
003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000
000>06IVIP050000001<C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0G01TI6A400000
2@0c<c<B000001/06ATI:0000004ooooo`0300000?oooooooooo05Gooooo0_l0000>ooooo`?oY8Rf
0onURkT2ojN?_003ojV<]onZT;[oZY2j00;oZY2j0_n[Tkh4ok6K`0;o/Yk400?o^ZS8okZ[bonjZl/0
0_njZl/01Oni[/ko`[gFol:me_o2_MKo_kkH00;oa/oR00Go`/gSolCKjoo4fn_oa=_[ol3FjP02okgL
k`05o`000?nge_3o]mK`okOFl?ndd^l00onac^l2ok3;kP;o[LO/00?o0000ooooooooool0<oooool0
00Wooooo00@00000oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`0203<c<`05o`00001<C4`0
C4a<04a<C00000003P1VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT0
:00I6AT9000002L06ATI1@0000000ol0000000000000000V000000Cooooo00<00000ooooooooool0
D_ooool3o`0000oooooo00?oXhBcojB8]_nTR;H00_nTR;H2ojF;^@03ojN?_?nYS;OoZHbg00CoZY2j
00?oZi>nok6G_?naUk`00onaVl001?nbW/Co^ZS8okZXb?njZ<P2okZ[b`04olBmdoo2_MKo`[gFol:m
eP;obM;Q00Goa/oRolOPjoo7h>_oan3[olCKj`02ol3Rl005okgLkonhg?;o0000okSLl_nge_000onb
d_000onac^oo[/W]ojk9k@02ojg7k003ojc3jooooooo000003Cooooo0009ooooo`0400000?oooooo
ooooooooo`806ATI00?o000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000606IVIP800000
1`1VIVH01@000000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI6@0I6AT0E@0I6ATb000000Co
oooo00<00000ooooooooool0D?ooool2o`00013ooooo00CoXH6aoj>4/onSQ;?oXhBc0onTR;H00onU
RkWoZ8RcojV<]`03ojV<]`;oZY2j00Co/9>iok6G_?naUkco/INl0onaVl04okZXb005okZ[boo4_M?o
a;gColBmdoo2_MH00_o9d^401?o;i^[oan3[olOPjoo7h>/2ol?Yl005ol3Rl?njh_?o^^;cokSLl_l0
00000_nde_82ok;Bl0;o[lc_00?o[/W]ojc4k?n/`n/00on/`n/00ol0003oooooooooo`0booooo`00
2Oooool01000003oooooooooooooool201TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`00`00
0000IVIV06IVIP0306IVIP040000001oOgl0Ogmo000000H0IVIV00D0000004a<C01<C4`0C4a<0000
000403<c<`030000000I6AT06ATI00T06ATI1000000n01TI6C`000001?ooool00`00003ooooooooo
o`1=ooooo`?o00004?ooool3oj61/@?oXhBc0_nTR;H01?nVQK7oZ8RcojR8/onXR;<3ojV<]`03ojZ@
^_n`TkWo/9>i00Co/INl00?o/I_0okZVa?njY/@00onjZ<P3olBmd`;ocMGO00GobM;Qol_Vj_o;i^[o
bnKZolOPj`02ol?Yl0;o_>Sd00Go^^;cokGKlonefo?o0000okCFlP02ok3?l0;o[lc_00Co[LK/ojc4
k?n/a>co[<C/0_n/`n/00on[`>Woooooo`00000cooooo`002Oooool01000003oooooooooooooool2
01TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`00ol00000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo0080Ogmo00<00000o`00001VIVH00`1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c
00<0000001TI6@0I6AT01`0I6AT;00000003o`0000000000000000/000008@0I6AU7000000Cooooo
00<00000ooooooooool0Boooool2o`0001;ooooo00?oX7j^oj61/OnQPK400_nQPK42oj>4/`03ojB8
]_nVQK7oYXFa00?oZ8Rc0onYS;L4ok2C^@;o/INl00?o^Z?1okZVa?njY/@00_njY/@01?njZ<SoaKcA
olFldOo4_M<3olgEg`03olk/jOo;i^[obnKZ00;oa?3_00?o_>ocokcXm?nlj?@00_nfhOD2okGKl`04
o`000?nad_7o/<o`ojg8k@Co[LK/00?o[<C/oj_1j_n[`NX00on[`>T00ooooooo0000ooooo`0aoooo
o`002Oooool01000003oooooooooooooool201TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`0
0`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH0
1@000000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT01@0I6AV3000000Cooooo00<0
0000ooooooooool0B?ooool3o`0001;ooooo00CoWWb/oj1n[_nPOZkoX7j^0onQPK42oj>4/`CoYXFa
0onXR;<00onYS;Oo[i2fojn@]P03ok2C^@04ok6G_?njXl7o^Z?1okZS`@;o^ZK400Coak_?olFldOo5
_=7oaKcA0_o@f=h00oo=eMooc^cYolk/j@02olGfk@03olC`konlko?o_>oc00;o]nOf00Ko]^7eok;F
lonbe_?o/M;ao`000?n^b^h3ojg8k@;o[LK/00?oZl;Zoj_1j_n[`NX00_n[`NX01?n[`>WoZ[oYojZo
jOl0000booooo`002Oooool01000003oooooooooooooool201TI6@04o`00000c<c<0<c<c000000<0
C4a<00@0000006IVIP1VIVH0IVIV0P00000707moO`030000001VIVH0IVIV0080IVIV00@0000004a<
C01<C4`000000`0c<c<00`0000006ATI01TI6@0401TI6H@000001?ooool00`00003oooooooooo`15
ooooo`?o00004oooool3oiil[0?oX7j^0onQPK400onSQ;?oYH:^ojF2[P03ojJ5/@;oZ8Rc00Co[Hbc
ojn@]_n_T;Ko[i2f0on`TkT4okZS`@05okZVa?o7^looak_?olNkcoo5_=400_o@f=h2om7bi`03olk/
jOo5m^goaOK]00;o^oGa00?o_>ocokOWm_ngioH00_nbfoD01?nbe_?o[/c`ojk:k_l00002ojk:kP04
ojg8kOn[`n_oZl?[oj_3j`;oZl;Z0_n[`NX3ojZoj@03ojVnj?oooooo0000037ooooo0009ooooo`04
00000?ooooooooooooooo`806ATI00Co000003<c<`0c<c<000000`1<C4`010000000IVIV06IVIP00
000:07moO`050000001VIVH0IVIV06IVIP0000000P1<C4`01@000000<c<c03<c<`0c<c<0000000D0
6ATI00?o0000000000000000PP000004ooooo`0300000?oooooooooo04?ooooo0_l0000Eooooo`03
oieiZonNO:coWWb/00;oWWb/0_nPOZh2oj61/@04oj=n[?nUPZkoYH:^ojF2[P?oYXFa00?oZ8Rcojf<
/on]S;<01?n_T;H00on`TkWo^Z2nokZP_P03okZS`@?oak_?0_oDfmd00oo@f=kodO;Wom7bi`02ol?k
i`03okKjjonkmO7o^oGa00;o]^gf00Co/^3fok;KmOnbfoGo[loa0on^c?001?l0003o[/[^ojc4k?n/
a>`2oj_3j`03oj[0jOnZ_nWoZ[oY00?oZ[oY00KoZ[kXojVnj?nY_^SoZKkXooooool0000`ooooo`00
2Oooool01000003oooooooooooooool201TI6@04o`00000c<c<0<c<c000000<0C4a<00@0000006IV
IP1VIVH000002P1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c
0000000501TI6HD000001?ooool00`00003oooooooooo`10ooooo`?o00005Oooool00onLMjWoWGV[
oieiZ`04oiil[0;oX7j^0onSOZ`3ojF2[P?oYXFa1?n]S;<2ojn@]P03okVM^onjX;ko^Z2n00;o^Z2n
00Co^Z?1olRjc?o8^/coak_?0ooDfmd01OoCn>CodO;Wol?kioo3nnOo]_[[00?o/o?d00?o]^gfok;P
m_n_d_801?n_co401On^c?3o[<G/o`000?n/aNco[<C/00GoZ/3Y00?oZ[oYojZnj?nZ_^P00onZ_^P0
1?nY_^SoZKgXooooool0000`ooooo`002Oooool01000003oooooooooooooool201TI6@04o`00000c
<c<0<c<c000000<0C4a<00@0000006IVIP1VIVH000002P1oOgl01@000000IVIV06IVIP1VIVH00000
0080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6HD000001?ooool00`00003oooooooooo`0n
ooooo`;o00005Oooool01?nJMJSoW7NYoiagZOnLMjT3oieiZ`?oWWb/00?oX7j^oj9lZOnRO:T00onS
OZ`3ojF2[P03ojJ5/On/RK3o[8V`00?o[Hbc00Co[i2fokVM^oniWK_o^Ifk0_njX;h01?o9^L[ob;[<
olRjc?o8^/`2omONg005omCKgOoCn>CodoSTokgmgOn]n]l00_n^mnl2ok?cm003ok;Un?n_e_Co[m;b
00;o[m;b0_n_co42ojc7k@03ojc5k?l0003oZl7Z00GoZ/3Y1_nZ_^P01_nY_NOoZKgXojVmj?nY_NSo
ooooo`0002oooooo0009ooooo`0600000?ooooooooooooooo`0I6AWo00000`0c<c<010000000C4a<
04a<C000000206IVIP030000001oOgl0Ogmo00X0Ogmo00@0000006IVIP1VIVH000000`1<C4`01000
0000<c<c03<c<`00000501TI6HD000001?ooool00`00003oooooooooo`0kooooo`?o00005Oooool0
0onILjOoVWFXoiYeZ003oiagZ@?oWGV[0_nNO:`01?nPNJOoXWbYoj9lZOnRO:T3oj=n[0;oYH:^00Co
ZXJ^ojb9/?n/RK3o[8V`0on]S;<4okVM^`05okZP__o9^L[obKW:olVib_o8^/`00_oGg]`2om;lg`03
om?hi?nmoMgo[O[O00;o[_O_0_naj_P01OnbiOSo[mKdojoFm?n_e_Co[m;b00?o[<S^00Co[<O]oj_1
j_n[`N[o00000_n[`NX00onZ`>WoZ[kXojZnj004ojZnj0GoZKgW00GoZKgXojVlionY_>OoZKcWo`00
000^ooooo`002Oooool01P00003oooooooooooooool06ATIo`0000<0<c<c00@0000004a<C01<C4`0
00000P1VIVH00`000000Ogmo07moO`0307moO`8000001@1oOgl010000000IVIV06IVIP00000304a<
C0040000000c<c<0<c<c000000D06ATIQ@000004ooooo`0300000?oooooooooo03Wooooo0_l0000G
ooooo`;oVG>W0_nJMJP4oiagZ@;oWGV[00?oWWb/oj1iYonPNJL00onRO:T3oj=n[003ojF2[_nZQZko
ZXJ^00?o[8V`0on]S;<01?nhV[Wo^IfkokVM^oniWK/4olVibP03om[RfooGg]cod_cO00;od_cO00?o
W_C=ojCgiOnTmnD00_n^koL00onaj_So[mWfojoImP02ojoFm0;o[L[_0_n/b>h01_n[`^_oZl7Zoj_1
j_n[`N[o0000oj_1jPKoZ[kX1_nY_NL4ojVli`03ojZki_l0003ooooo02gooooo0009ooooo`060000
0?ooooooooooooooo`0I6AWo00000`0c<c<010000000C4a<04a<C000000206IVIP030000001oOgl0
Ogmo0080Ogmo00@0000009VIV@2IVIT00000101oOgl010000000IVIV06IVIP00000304a<C0040000
000c<c<0<c<c000000D06ATIQ@000004ooooo`0300000?oooooooooo03Kooooo0ol0000Gooooo`04
oiQaY_nILjOoVG>WoiUcY`?oVWFX0onLMjT2oieiZ`?oX7VW1?nRO:T2oj=n[0CoZXJ^0on/RK000on]
S;?o^9ZiokRJ^@03okVM^`03olZhb?o9^L[obKW:00;of^;K0_o?omP01?oBo=ooR>JdojWbm?nYl_@2
ojk_m`;o[mgg00Ko[mWfojg<l?n]c?3o[Lc`ojg:kon[`n/4oj_2j`03oj_1j_nZ_^So000000CoZ[kX
0_nY_>L2ojVmi`04ojZki_nY^nKoZK_VojVkiP;oZKcW00?oZ[[UojZki_nZ^nH00_nZ^nH00ol0003o
ooooooooo`0[ooooo`002Oooool01P00003oooooooooooooool06ATIo`000080<c<c00@0000004a<
C01<C4`000000P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00?o0000
07moO`1oOgl00P1oOgl010000000IVIV06IVIP00000204a<C004o`00000c<c<0<c<c000000D06ATI
Q@000004ooooo`0300000?oooooooooo03?ooooo0ol0000Hooooo`04oiI`YOnHLJKoV76VoiQaYP?o
VG>W0_nJMJP3oiagZ@03oieiZonNMjKoWWNV00?oX7VW0onRO:T00onSOZcoZH>/ojV3[003ojZ6[P;o
[8V`00?o]iNfokRJ^OnhV[T00_nhV[T01?niWK_ob[S8olZhb?o9^LX3om[Rf`05oloof?n8i[CoR>Jd
oj7ck_nYl_@00on^hOP00on_gOOo[Lkaojg>l@02ojg<l004oj_4k?n[`n_oZl?[oj_3j`;oZl;[0onZ
_^P00ol0003oZKcWojVli`03ojVli`;oZ[[V0onZ^nH00onY^nKoZ[[UojZji@03ojZji@;oZ[_V00?o
Z[WTo`000?ooool0;?ooool000Wooooo00H00000oooooooooooooooo01TI6Ol0000203<c<`040000
001<C4`0C4a<00000080IVIV00D0000007moO`1oOgl0Ogmo0000000609VIV@050000001oOgl0Ogmo
07moO`0000000P1VIVH010000000C4a<04a<C000000303<c<`03o`00000I6AT06ATI00806ATIQ@00
0004ooooo`0300000?oooooooooo037ooooo0_l0000Iooooo`03oiE_YOnFL:GoUW2U00?oV76V0onI
LjL2oiYeZ0;oW7NY00CoW7BUoiigY_nNMjKoWWNV0onPNJL2oj9lZ@04ojN0Z_nYPjcoZH>/ojV3[0?o
ZXJ^00Co[8V`okNG]_ngUkKo]iNf0_nhV[T01?o;]lOob[S8olZhb?o:^<P2omgUfP03om[Rfoo?omSo
K]6E00;oXO?^0_n]iOT2ojkQn0;o[M3b00?o[Lkaoj_5k?n[aN`00on[a>`00on[`n_oZ[oYojZoj@02
ojZnj0?oZ[cW00Co0000ojVlionY_>OoZ[[U1?nZ^^H00onZ^nKoZ[WTojZji@04ojZji@03ojZhhonZ
^NCoZ[WT00;oZ[WT00?o0000ooooooooool0:_ooool000Wooooo00H00000oooooooooooooooo01TI
6Ol0000203<c<`040000001<C4`0C4a<00000080IVIV00D0000007moO`1oOgl0Ogmo0000000609VI
V@050000001oOgl0Ogmo07moO`0000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I
6AT06ATI00806ATIQ@000004ooooo`0300000?oooooooooo02kooooo0ol0000Hooooo`04oiA^YOnE
KjGoUFnUoiE_Y@;oUW2U0onHLJH3oiUcY`;oVWFX0onLM:D3oiigYP?oX7VW00?oXWbYojN0Z_nWP:X0
0onYPj`3ojZ6[PCo]iNf00Go^9Ziol^gaoo;]lOobkO7olZhb002omgUfP;ob?o=0_nFlN@2oj_YnP03
ojgUnOn]d_?o[M;c00;o[M3b0_n[aNd00on[aNcoZ[oYojZoj@04ojZoj@;oZ[_V1?nZ_>L00ol0003o
Z[WTojZji@02ojZji@;oZ[[V00CoZ[SSojZii?nZ^NCoZ[WT0_nZ^^D01?n[]n;oZ[SSojZhhonZ^><2
ojZii003oj^hhooooooo000002_ooooo0009ooooo`0600000?ooooooooooooooo`0I6AWo00000P0c
<c<010000000C4a<04a<C000000206IVIP040000001oOgl0Ogmo000000P0VIVI00@0000007moO`1o
Ogl000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00806ATIQ@000004
ooooo`0300000?oooooooooo02cooooo0_l0000Iooooo`03oi=]YOnDKZGoU6jU00?oUFnU0onFL:D3
oiQaYP;oVG>W00?oVWFXoi]bXonLM:D00_nLM:D4oiigYP;oX7VW0onWP:X4ojV3[003ojZ6[_nfU;Co
]YBd00?o]iNf1?o;]lL01OoOjMWogNGJolSocOo8olgoYnci00;o[=Of0on]e?D01On]d_?oZlK]oj_6
kOn[a^goZlG]00KoZ[oY1OnZ^nH01?nZ_>OoZ[STojZii?l00002ojZii003ojZjiOnZ]^;oZ[SS00?o
Z[SS00?oZ[WToj^fhOn[]n800on[]n800onZ^>?oZkKQoj^fh@03oj^hh`03o`000?oooooooooo02Wo
oooo0009ooooo`0500000?ooooooooooooooool000000P0c<c<01`000000C4a<04a<C01<C4`00000
06IVIP0000000`1oOgl00`000000VIVI09VIV@0609VIV@050000001oOgl0Ogmo07moO`0000000P1V
IVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00806ATIQ@000004ooooo`030000
0?oooooooooo02Wooooo0ol0000Hooooo`04oi9]YOnCKJGoTffUoi=]Y@;oU6jU1?nEKjD2oiI`Y@?o
V76V00?oVG>WoiU`XonKLZ<00_nKLZ<3oiadY@?oWWNV00?oX7VWojEmZ?nUOJP00onWP:X3ojV3[0?o
]YBd0ongUkH00oo;]/GobkO7ol^ga`02omoYf@04okcj__nSk_So[=WgojcIm`?o[=Of00?o[MCeoj_7
k_n[anh00_n[a^d6ojZoj@KoZ[_V00OoZ[SSojZhi?nZ^>CoZ[STo`000?nZ^NCoZ[GQ00?oZ[KR0_nZ
^><01?n[/mooZkKQoj^fhOn[]^42oj^ghP;o[;CO00?oZkKQojfegon/]n400on/]n400ol0003ooooo
ooooo`0Xooooo`002Oooool01@00003ooooooooooooooooo00000080<c<c00@0000004a<C01<C4`0
00000P1VIVH010000000Ogmo07moO`00000:09VIV@040000001oOgl0Ogmo00000080IVIV00@00000
04a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6HD000001?ooool00`00003ooooooooo
o`0Wooooo`;o00005oooool00on@KJOoTFfVoi5]YP02oi9]Y@?oTffU0onDKZD3oiE_Y@;oUW2U0_nH
LJH00onHKZ;oVG2SoiU`X`03oi]bX`?oW7BU0_nNMjH01?nSNjOoYGfXojEmZ?nUOJP3ojN0ZP;oZH>/
00?o]96bokJD]?nfU;@00_nfU;@01?ngUkKobkK5ol^faOo;]lL3omoYf@;oZm_h00?o[=Wgoj_9kon[
b>l00on[b>l00on[ankoZ/3YojZoj@04ojZoj@;oZ[[V1?nZ^nH2ojVghP?oZ[SS00?oZ[STojZcgol0
00000onZ]N400onZ]^;oZk7Moj^cg`03oj^cg`03oj^fhOn//]go[;;M00;o[;CO00Co[K?Mojfegon]
]Moo[KGO0_n/]n400on^^>3oooooo`00000Yooooo`002Oooool01@00003ooooooooooooooooo0000
0080<c<c00Co000004a<C01<C4`000000P1VIVH010000000Ogmo07moO`00000309VIV@<00000102I
VIT010000000Ogmo07moO`00000206IVIP040000001<C4`0C4a<00000080<c<c00<0000001TI6@0I
6AT00P0I6AV5000000Cooooo00<00000ooooooooool09?ooool3o`0001Kooooo00CoSffXoi1]Yon@
KJOoT6fW0_nAKJH3oi9]Y@?oTffU0_nDKZD3oiE_Y@;oUW2U0onHKZ82oiU`X`?oVg:S0onLM:D00onN
MjKoXg^Woj=kY`03ojEmZ0?oYh2Z00CoZH>/okBA/_ndTK;o]96b0onfU;@3ol^fa@;ohNgI00CognWI
oj_Kn?n[foSoZl[`0on[bNl2oj_8k`CoZ/3Y0_nZ_nT2ojZji@03ojZji_nY]>7oZKCQ00?oZKKR00?o
ZKORojV`g?nY/=`00onZ/Mh01OnZ/moo0000ojZehOnZ]N7oZjoK00?oZk7M0_n[/ml2ojb`f`03ojbb
gOn^/=[o[K?M00?o[K?M00?o[KGOojnfg_n^^>000on^^>000ol0003oooooooooo`0Wooooo`002Ooo
ool01@00003ooooooooooooooooo00000080<c<c00<0000004a<C00000000P1VIVH010000000Ogmo
07moO`00000309VIV@050000002c/k<0/k>c0;>c/`000000102IVIT01?l00000Ogmo07moO`000002
06IVIP030000001<C4`000000080<c<c00<0000001TI6@0I6AT00P0I6AV5000000Cooooo00<00000
ooooooooool08_ooool2o`0001Gooooo00?oSVn[ohi^ZOn>KZT00_n?KJP3oi1]Y`;oTFfV0onBKJD3
oi=]Y@;oU6jU0onEKjD00onFL:GoUVfQoiQ^XP02oiQ^XP?oVG2S0onKLZ<2oiadY@?oXg^W1?nUOJP2
ojN0ZPCo]96b0_nfU;@2ol^ea@04ol^faOoQkMWohNgIojc`Z`;oZl_a0on[b_000on[bNooZ/3Yoj[0
j@02oj[0j@03ojViiOnZ^^GoZ[[U00?oZ[[U00?oZK?PojVdhOnY]>400_nY]>400onY]^;oZJkJojV`
g003ojV`g004ojZag_nZZ]KoZZgIo`0000CoZjoK00?oZk7Mojb]f?n//=/00_n//=/01?n^[MOo[[3J
ojj`f_n^/=X2ojfcg@04ok2dfon_]]ko[kKNojnfgP;o[[SP00?o/;[Qooooool00000:?ooool000Wo
oooo00D00000ooooooooooooooooo`00000203<c<`030000001<C4`000000080IVIV00<0000007mo
O`0000000`2IVIT00`000000/k>c0;>c/`030;>c/`05o`0000000000VIVI09VIV@0000000P1oOgl0
1P000000IVIV06IVIP000000C4a<00000080<c<c00<0000001TI6@0I6AT00P0I6AV5000000Cooooo
00<00000ooooooooool07oooool3o`0001;ooooo00CoSW:_ohi`[On>L:goSW2]0_n>Kj/2ohi^Z@?o
SffX0on@KJL2oi5]YP;oTVfU0onCKJD2oiA^Y@;oUFnU00?oU6bQoiI]XOnFKJ400onHKZ83oiU`X`?o
Vg:S00?oW7BUoj5hYOnSNjL00onSNjL3ojEmZ003ojN0Z_nbSk7o]96b00?o]96b00Ko]YBdol^eaOo;
]LGobkG5on;af?oQkMT2oj_<l@?oZl_a00?oZl[`oj[0j_nZ`>X00_nZ`>T01?nY^NCoZKWUojViiOnY
^ND2ojZji@04ojVbgonY/n3oZK?PojVch0;oZKCQ00CoZJcIojV^f_nY[][oZJkJ0_nY/=`01_nYYmCo
ZZ[FojZZe_nZZ]Ko0000ojZ]f@;oZjoK00Go[:WEojb]f?n/[MSo[:gHojb`f`03ojj]e`03ojj`f_n`
/MSo/;7H00?o/;CK00?o[kKNok6igon`^^400on`^^400ooooooo0000ooooo`0Vooooo`002Oooool0
1000003oooooooooooooool303<c<`030000001<C4`000000080IVIV00<0000007moO`0000000`2I
VIT00`000000/k>c0;>c/`040;>c/`040000002IVIT0VIVI00000080Ogmo00H0000006IVIP1VIVH0
000004a<C000000203<c<`030000000I6AT06ATI00806ATIQ@000004ooooo`0300000?oooooooooo
01cooooo0ol0000Aooooo`03oi9i]?n?MK7oSgFa00?oSW:_0_n>L:d2ohi_Z`;oSVjY0on?KJP3oi1]
Y`;oTFfV0onBKJD2oi=]Y@03oiA^YOnBJZ7oU6bQ00;oU6bQ0_nFKJ44oiQ^XP;oVG2S0_nKLZ<01?nO
MZCoXGRUoj5hYOnQN:D3oj=kY`;oYGfX00Co/8b`ok:?/OnbSk7o/Xna0_ndTK801?o:/lCobkG5ol^e
aOo;]LD2on;af003oj_=l_n[c?7oZ/7Z00CoZ/7Z00?oZ/3ZojVii?nY^N@00onY^N@00onY^NGoZK7N
ojVbg`03ojVbg`03ojVch?nYZMOoZJcI00?oZJcI00?oZJkJojVTdOnYYm@00onYYm@2ojZZeP03o`00
0?n[Y];oZjKB00?o[:WE00?o[:gHojjYdon^ZM<00on^[ML4ok2af003ok2dfonc^=co/KWO00;o/KWO
0_n`^^42ok:oh`03o`000?oooooooooo02Gooooo0009ooooo`0400000?ooooooooooooooo`<0<c<c
00<0000004a<C00000000P1VIVH00`000000Ogmo0000000309VIV@030000002c/k<0/k>c00D0/k>c
00<0000009VIV@0000000P1oOgl01P000000IVIV06IVIP000000C4a<00000080<c<c00<0000001TI
6@0I6AT00P0I6AV5000000Cooooo00<00000ooooooooool06_ooool2o`00013ooooo00?oVX:hoiIm
]_nFOKH00_nBNK@2ohme/@?oSW:_0_n>L:d3ohi_Z`;oSVjY0_n?KJP3oi1]Y`;oTFfV0onBKJD01?nC
KJGoTFVQoi9ZXOnBJZ43oiA/X@?oUVfQ0onHKZ82oiU`X`03oi]bXonOMZCoWgJT00?oXGRU0onSNjL0
0onUOJSo/8b`ok2</003ok:?/@05okBA/_o:/lCob[?4olZca?o;]LD00ooRlMP6oj[1jP03ojVhi?nY
^NCoZKWT00?oZKWT00CoZK3MojVag_nY/MkoZK7N0_nY/]l01?nXYmGoZJWGojVYeonYZML2ojV/f@04
ojRQc_nYY=7oZJCAojVTd@?oZJOD00?oZZ[Foj^Rc_l000000on[Y]800on/ZMGo[ZK@ojjYd`03ojjY
d`03ojj]eona[]Go/JkE00;o/;7H00Go];KJok>hg?nc^=co/kSLok6ig`02okBohP;o/[oS00?o/lCV
ooooool000009_ooool000Wooooo00@00000oooooooooooooooo0P0c<c<01P000000C4a<04a<C000
0000IVIV00000080Ogmo00@0000009VIV@2IVIT00000202c/k<01P000000VIVI09VIV@000000Ogmo
00000080IVIV00@0000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6H@000001?oo
ool00`00003oooooooooo`0Gooooo`?o00003oooool01?nOQ[WoVX:hoiZ2^?nJP[P2oiIm]P?oTWVd
0_n?MK42ohib[`?oSW2]0_n>Kj/2ohi^Z@?oSffX0_n@KJL2oi5]YP;oTVfU00?oSfRRoi5YXOnAJJ40
0_nBJZ44oiA/X@;oUVfQ0onHKZ82oiU`X`?oWgJT0onQN:D3oj=kY`Co/8b`0_nbSk44olZca0;oh_GH
00?oh_7Hoj[1j_nZ`NX00onZ`NX4ojVhi0;oZKWT00GoZJoLojV`gOnY/=goZK3MojVagP02ojRUd`?o
Z:OE00?oZJWGojRMc?nXXLh00onXXLh2ojVTd@;oZJOD00CoZYk;oj^Rc_l0003o00000_n[Y]801?n]
X/co[ZK@ojjVd?n^Y]02ojjYd`05ok6ZdOna[]Go/JkEok6^eOn`/MP00ond]]X00onc^=co]kkPokBo
hP02okBohPCo/lCV00?oooooo`000?ooool09?ooool000Wooooo00@00000oooooooooooooooo0P0c
<c<01P000000C4a<04a<C0000000IVIV00000080Ogmo00<0000009VIV@0000002P2c/k<00`000000
VIVI0000000207moO`030000001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6AV40000
00Cooooo00<00000ooooooooool05_ooool2o`0000oooooo00CoXXVjoin6^OnOQ[WoWhJi0onJP[P2
oiIm]P;oTWVd0_n?MK43ohib[`;oSW2]0_n>Kj/2ohi^Z@?oSffX00CoT6fWohaWXon>J:;oSVRR0on?
J:82oi5YX@;oTVZQ1?nDK:42oiI]X@?oV6jR00?oVG2SoiedY?nOMZ@00onOMZ@3oj5hY@;oXg^W1?n`
S;02ok:?/@06olVba?o:/lCob[?4olZca?oRmMSo00000_nZ`N/00onZ`N[oZKSTojVhi004ojVhi003
ojR^g?nY[mcoZJoL00;oZJoL00?oZK3MojNSd_nXYM<00onXYM<00onXYmGoYi[9ojRMc002ojRMc0?o
Z:7>00?oZJCAojVJaonZW//00ol000000on[X/ko0000ojfRc003ojfRc003ojjVd?naY/go/J[A00?o
/J[A00?o/JkEokJce_nf/mH00_nd]]X01Oni_]ko]kkPokNnh?ng_^3o];oR00;o]/KV0_nca>H2ok?8
j@03o`000?oooooooooo02?ooooo0009ooooo`0400000?ooooooooooooooo`80<c<c00H0000004a<
C01<C4`0000006IVIP00000207moO`030000002IVIT0000000X0/k>c00<0000009VIV@0000000P1o
Ogl00`000000IVIV0000000204a<C0040000000c<c<0<c<c000000@06ATI00?o0000000000000000
P@000004ooooo`0300000?oooooooooo01Kooooo00?o0000ooooool000003?ooool00onSRk_oXXVj
oj:9^P03oin6^@?oVX:h0_nFOKH2oi9i]0;oSgFa0on>LZl2ohi`[@04ohi_Zon8J:OoRFNUohUWY@?o
RfNT0_n<Ij<2ohiXXP?oSfRR0_nAJJ43oi9ZX@?oU6bQ0_nFKJ42oiQ^XP03oi]bXonMM:CoWGBT00Co
WgJT0onQN:D00onSNjOo[XV_ojj9[`03ok2</007ok:?/Oo9//CobK;4olVba?o:/lCoh_GHoj[1j`06
ojVhi0CoZ:gK0_nX[]`2ojV_g004ojNRdOnWXm;oYj?BojNSdP;oZ:GC00CoYYS7ojNJbOnWV/WoYi[9
0onXWL`00onXXLkoZ9O4o`000002o`0000;oZYk;00Co[9W4ojfMb?n]WLSo00000_n]X/`01?naX/Wo
/JK=ok6VcOnaY/d2ok6Zd@04okN`donf/mKo][?FokJcePCo^KkN00Co]kkPokW7iOnianGo]/KV0_nf
bnX2ok?8j@03ok;:k?oooooo000002Cooooo0009ooooo`0400000?ooooooooooooooo`80<c<c00<0
000004a<C00000000P1VIVH01@000000Ogmo0000002IVIT0000000@0/k>c1?l000040;>c/`030000
002IVIT000000080Ogmo00D0000006IVIP000000C4a<0000000303<c<`040000000I6AT06ATI01TI
6H@000001?ooool00`00003oooooooooo`0Fooooo`04o`000?ooooooooooo`0000Wooooo00?oWhZm
oj>;^onSRk/00onRRKX2oin6^@?oVX:h00CoUWffohmf/on;LK3oRg6`0_n8KJh3ohM[Z`;oR6VY0_n8
J:L2ohUWY@?oRfNT0_n<Ij<2ohiXXPCoSfRR0_nAJJ42oi9ZX@?oU6bQ00?oUVfQoiQ`XonKLZ<00_nK
LZ<3oiedY0?oWgJT0_nQN:D01?n/Qjko[XV_ojj9[on^RJl2ok2</004olRaa?o9//CobK;4olVba0;o
h?WH1OnY^>@00onX[=[oZ:gKojR]f`03ojR]f`04ojJNc_nVX<ooYZ3?ojJPc`?oYj;A00?oYj?BojFE
a?nVV<L00onVV<L2ojNJb@;oZ9g<0ol000000onXUlCoZI[7ojVJa`04ojbIa0;o[Ig800Co0000ok6R
bOnaX/Wo/J;90_naY/d4okN`d`03okJce_nk_M_o^kgK00;o^KkN0_nlbN@01OnianGo^LoZokW?j_nf
bn[o]<k]00Co//[/00?o0000ooooooooool08_ooool000Wooooo00@00000oooooooooooooooo0P0c
<c<00`000000C4a<0000000206IVIP050000001oOgl0000009VIV@0000000`2c/k<00ol00000c<c<
0<c<c0020<c<c007o`00002c/k<0/k>c0;>c/ol00000VIVI0000000207moO`050000001VIVH00000
04a<C00000000`0c<c<00`0000006ATI01TI6@0201TI6H<000001?ooool00`00003oooooooooo`0F
ooooo`05o`000?ooooooooooooooool000001Oooool01?nHR<;oWhZmoin:_OnOR[d3oj>;^`;oXXVj
0onOQ[T01?nJP[SoU7^eohmf/on?M[<2oh]a/0;oR6f^0on7Jj/2ohQYZ@;oR6RW0_n9IjD3oh]WY0;o
S6NS0on>J:83ohmXXP;oTFVQ0_nBJZ42oiA/X@03oiI^XonHL:?oV72S00?oVg:S0onMM:@3oimfY003
oj5hYOn/Qjko[8N^00?o[XV_00Go/8b`olRaa?o8/LCob;74olVba003on3if0?oZKST1?nX[=X2ojR]
f`04ojFMcOnVW/koYYk>ojJNcP?oYZ3?00?oYj;AojBB`_nUUL@00_nUUL@3ojJHa`04ojNJbOl0003o
0000o`0000;oYi?10_nXUl@00onYV/OoZiG0oj^E`003ojbIa004ojfMb?n`W/Go/9k5o`0000;o/J;9
00?o/JK=okN]cong[Ll00_ng/=<2okflf003ok^mfoo0bn?o`<_S00;o_<WT0_nmdnX00onicn[o]m;^
okC>k@02okC>k@;o//[/0_n`bN`00ol0003oooooooooo`0Qooooo`002Oooool01000003ooooooooo
ooooool203<c<`030000001<C4`000000080IVIV00Go000007moO`000000VIVI000000030;>c/`03
o`00003<c<`0c<c<0080c<c<00Oo00000;>c/`2c/k<0/k>c0000002IVIT000000080Ogmo00D00000
06IVIP000000C4a<0000000303<c<`030000000I6AT06ATI00<06ATIPP000004ooooo`0300000?oo
oooooooo01Gooooo00Co0000ognGh?moUn3oMhcK0_mgQ]@2oh24cP;oS8K70onHR<83oin:_@;oXh^k
00?oXXVjoij4]onJPKH00_nJPKH2oiAk]@;oSgJc0_n;LK02ohQ][P?oQf^[0_n8JJT3ohQXY`;oRFNU
0on;Ij@2ohaWX`;oSVRR0on?J:82oi5YX@;oTVZQ00?oU6bQoiI^XonFKZ<00_nHL:<4oi]bX`;oWGBT
0_nOMZ@00onYQ:go[8N^ojb7[P02ojb7[P;o[XV_1?o8/L@2omcle`04on3if?nY^>CoZKSTojN/fPCo
Z:cJ00?oYIc=ojFMcOnUWLd00_nUWLd2ojJNcP;oYZ3?00CoXi31ojBB`_nTT/;oY9;20onUUL@3o`00
00;oYXnm0onWTl400onXUlCoZI6loj^E`003oj^E`003ojbIa?n`VL7o/9k500;o/9k500?o0000ok6R
bOnhZL/00ong[Ll01?no^]Go_KcHokflf?nm_=P3ol3;h`?o_M?Z00Go^]S_okOBk_ngd^ko]m;^okC>
k@02ok;<kP;o/<W/0_n^a^`00ol0003oooooooooo`0Pooooo`002Oooool01000003ooooooooooooo
ool203<c<`030000001<C4`000000080IVIV00D0000007moO`000000VIVI000000020;>c/`03o`00
003<c<`0c<c<00<0c<c<00Oo00000;>c/`2c/k<0/k>c0000002IVIT000000080Ogmo00D0000006IV
IP000000C4a<0000000303<c<`030000000I6AT06ATI00@06ATIP@000004ooooo`0300000?oooooo
oooo01Gooooo00Go0000oooooomoUn3oOiOPogN<f`02ogN6e0;oP8C>0_n<Q/L2oiR8`P?oWhZm00?o
Xh^koin6^?nNQ;L00_nNQ;L2oiZ1]P?oU7^e0_n?M[<2oh]a/0;oR6f^0on7Jj/2ohQYZ@;oR6RW0_n9
IjD3oh]WY0;oS6NS0_n>J:83ohmXXP;oTFVQ00?oTVZQoi=/XonFKZ<00_nFKZ<3oiQ`X`?oVg:S0_nM
M:@00onOMZCoZHB]ojV4[@04ojb7[P;o[XV_00Goa[34olRaa?o8/LCob;74omcle`06ojN/fP03ojR/
f_nTVlcoYIc=00;oYIc=0onUWLd00onVW/koXXjooj>@`@03oj>@`@;oY9;20ol00003ojF<^`;oYXnm
0_nWTl401?nXSKWoZI6lojVA_?nYTK`2oj^E`004ojjE_?n`VL7o/9W1ok2I`@;o/9k500Go^:G6o`00
0?nhZL_o^:W;okN]c`03oknje@04okflf?o4cN7oa<gQol3;h`;o`MSZ00Go_M?Zok[Hkonjf>oo^]S_
okOBkP02okCAk`03ok;<k_n_bNgo[lW]00;o[/K/00?o[<?[o`000?ooool08Oooool000Wooooo00@0
0000oooooooooooooooo0P0c<c<02@000000C4a<0000001VIVH0000007moO`000000VIVI00000003
0;>c/`03o`00003<c<`0c<c<00@0c<c<00Wo00000;>c/`2c/k<0/k>c0000002IVIT0000007moO`00
00000P1VIVH00`000000C4a<0000000303<c<`030000000I6AT06ATI00@06ATI6P00000[01TI6C/0
00001?ooool00`00003oooooooooo`0Eooooo`04o`000?ooooooL8gOog2=g`;oIX7I0_mgQ]@00on0
Q<koS8K7ohb6a`03oiR8`P04oin:_OnKQK_oWhJhoin6^0?oWXBg0onJPKH2oiAk]@;oSgJc0_n;LK02
ohQ][P?oQf^[0_n8JJT2ohQXY`;oRFNU0on;Ij@2ohaWX`;oSVRR0_n?J:800on?JJ?oTF^Soi5[X`02
oi=/X`?oUVjS0onHL:<3oi]bX`;oWGBT1?nYQ:d3ojb7[P06ojj9[oo6/<Coa[34olJ`a?o8/LCog?cG
1_nW[=X4ojBKc0?oYIc=00?oYIg=oj:<__nRS[l00_nRS[l2oj>@`@?o00000onSRKP3ojF<^`03ojJ?
_OnVRKKoZ8fi00?oZ8fi0_nYTK`01?n[UL3o[YFlojjE_?n^UK`2ok2I`@06ok2NaOnhYLKo^:G6okRU
a_l0003o^:W;0ono^]D2olS>g`04olC=hOo6gN[oa]gZol7HjP;o_]k`0_njf>l2okKGl@04okCAkon`
cNko/<g^ojo9k@;o[LG/0on/`n/00ol0003oooooooooo`0Oooooo`002Oooool01000003ooooooooo
ooooool203<c<`090000001<C4`0000006IVIP000000Ogmo0000002IVIT000000080/k>c00?o0000
0<c<c03<c<`01P3<c<`02?l00000/k>c0;>c/`000000VIVIo`00001oOgl000000P1VIVH00`000000
C4a<0000000303<c<`030000000I6AT06ATI00D06ATI00?o00000000000000002P0000000ol00000
000001TI6@0k01TI6@0300000?l000000000034000001?ooool00`00003oooooooooo`0Eooooo`03
o`000?oooooooooo00;oL8gO00?oIX7IofMid_mWNM800_mbNL/2ohb6a`04oiR8`_nAP[ooVhFkoi^5
^`?oWhJh0_nNQ;L3oiZ1]P;oU7^e0_n?M[<2oh]a/0;oR6f^0on7Jj/2ohQYZ@;oR6RW0_n9IjD3oh]W
Y0;oS6NS00?oSVRRohaXY?n?JJ<00_n?JJ<2oi5[X`?oTfbS0onFKZ<2oiQ`X`?oVg:S00?oWGBTojJ2
[OnVPZd00onYQ:d2ojb7[P04olB_aOo6/<Coa[34olJ`a0;oe_kF00?oYjcKojN/f_nTVl`00onTV/`5
ojBKc0;oYIc=00GoXH^moj:<__nRS;koXXbnoj:>_`03o`000003oj63]?nRQ[KoXXJf00CoXhVh0_nU
S;/3ojJ9]P?oZ8fi00?oZI6lojfA^On^UK`00on^UK`00on`VL7o]j72okRUaP03okRUaP04okRYbol0
003o`KSBoknje@;ob<kO0_o;hnT01?o6gN[o`^K`ol;Vl?nng_02okWMlP;o]]Oa0_nbdO001On`cNko
[/O]ojk7kOn]aNcoZl;Z00CoZl7Y00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooo
oooooooo0P0c<c<02@000000C4a<0000001VIVH0000007moO`000000VIVI000000020;>c/`03o`00
003<c<`0c<c<00H0c<c<00So00000;>c/`2c/k<0000009VIV@000000Ogmo00000080IVIV00<00000
04a<C00000000`0c<c<00`0000006ATI01TI6@1G01TI6Bd000001?ooool00`00003oooooooooo`0E
ooooo`03o`000?oooooooooo00;oFX?Q0_mVPMT2ofMidP03og9ibon3OLCoPgg400;oTH:o0onKQK/2
oin6^0?oWXBg00CoVX6foiN1^On@NkSoT7^h0_n8M;H2oh=_]0;oP6^a0on0J:h2oh5W[0;oPfJZ0_n5
IZP3ohMWYP;oRFNU0_n<J:@3ohmYX`;oTF^S0onCK:<3oiI^X`;oV72S0_nKLZ<01?nSOjgoYX:]ojJ2
[OnVPZd3ojV4[@05ojb7[_o4[lGoa:o5olB_aOo6/<@00_oFo]H00onW[=_oXi_<ojBKc002ojBKc0?o
Y9[<00CoY9_<oin9_?nPR[coX8Zl1?nQRkd01OnRS;ko0000o`000?nRS[ooWh6b00;oXH>d0onRQ[H3
oj>9^003ojF<^onUQK;oYXVf00;oYXVf0onXSKT3ojfA^@?o[YFl0ongXL82okRUaP;o`[K>00Co0000
olc@gOo<d=gob<kO0_o;hnT2olG^k`04ol;Vl?nkiO?o^nGcokWMlP;o]=Ob0_nbdO02ojo:kP03ojk7
kOn/`n_oZl;Z00;oZl;Z0_n[`NT00onZ_nWo0000ooooo`0Oooooo`002Oooool01P00003ooooooooo
ooooool0<c<c00000080C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c/ol000002P3<
c<`00ol00000/k>c0;>c/`0200000080Ogmo00<0000006IVIP0000000P1<C4`01@000000<c<c03<c
<`0c<c<0000002<06ATI8000000L01TI6BH000001?ooool00`00003oooooooooo`0Eooooo`04o`00
0?ooooooooooooooo`;oFX?Q00?oBg?HofMid_mWNM800_mbNL/2oh=ma0;oTH:o0_nKQK/2oin6^0;o
WXBg00?oW8BioiN1^OnGPKT00_n@NkP2ohQd]P;oPfnd0on0Jk42oh1X[P;oPFN/0_n3IZX2ohEVZ0?o
QfNV0_n9IjD2ohaXY0?oSfVS0onAJj<2oi=/X`?oUVjS0_nHL:<3oj=o[@?oYX:]0onYQ:d4olB_a@03
olcoe?nW[=_oXi_=00?oXi_<0onTVl`01?nTV/coWhRloin9_?nORK`3oj2:_005oj6;_Ol0003o0000
o`000?nNOk400onOPK83oj63]0;oXXJf0_nSRKP01?nSP[3oYHFbojF5/_nUQK83ojJ9]P03ojR=^On/
SKGo[I6i00?o[I6i00?o[YFlokJM__nfWKh00_ngXL802Oo3/l[o`[K>ol:fc_o2]/koc=3Mo`000?o<
d=god>WXol_Sj@02olG^k`;o_Nkc00Co^nGcokKMm?nfgOCo]=Ob0_n`c_02ojo:kP;o[<G/0_n/`n/0
0on[`^[oZ[oYojZoj@02ojZoj@03ojZnj?l0003ooooo01kooooo0009ooooo`0600000?oooooooooo
ooooo`0c<c<000000P1<C4`02@000000IVIV0000001oOgl0000009VIVOl00000/k>co`0000030<c<
c0Co00000`3<c<`02_l00000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C005
0000000c<c<0<c<c03<c<`000000600I6AT;00000200<c<c1@0000000ol000000000000000020000
01D06ATI00<00000o`000000000080000004ooooo`0300000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool2oeZ3h@04od]cf?m=K=7oGfo;oem_b`;oPgg40_nAP[l01?nKQK_oUhBloib5^_nL
QKX3oib4^@?oUh6i0_n@NkP2ohQd]P;oPfnd0_n0Jk42oh1X[P;oPFN/0_n3IZX2ohEVZ0?oQfNV0_n9
IjD3ohaXY0?oSfVS0_nAJj<3oi=/X`;oUVjS00?oV72Soj1m[OnPOJd00onSOjd3ojJ2[@03ojV4[Oo1
[/Oo`Jk700?oa:o500CoXic>oj>KcOnSVlgoXi_=0_nSVl`2ojBKc003oij8_?nOR;coWhRl00?oWhVl
0ol000000onQRkgoWGf`oiio/@02oiio/@?oWh6b0_nQPk@00onRQ[KoXWn^oj>2/002oj>2/0?oYHFb
0_nVRKH01?nZRK;o[8feojb=]On/SKD2ojfA^@05okFI^_nfWKko]YfnokJM__ngXL800oo3/lX01Oo2
]/kocm7KoloAfoo<d=go000000;oaoK/00?o_?K`okg^lonmk_<00_ngiOH01?nfgOCo/M?bok7Cl_n`
c_02ojg7k@;o[<G/00GoZl7Zoj[0jOnZ`>WoZ/3YojZoj@05ojZnj003o`000?oooooooooo01cooooo
0009ooooo`0600000?ooooooooooooooo`0c<c<000000P1<C4`02@000000IVIV0000001oOgl00000
09VIV@000000/k>co`0000030<c<c004o`00003Vi^H0i^KVo`0000<0c<c<00[o00000;>c/`2c/k<0
000009VIV@000000Ogmo0000001VIVH000000P1<C4`00`000000<c<c03<c<`0203<c<`030000000I
6AT06ATI00h06ATI1`00000e03<c<`@00000500I6ATP000000Cooooo00<00000ooooooooool05?oo
ool00ol0003oooooooooo`03ooooo`;o>7OQ0_lQH=D01?m=K=7oGfo;ogMga_mgMlH2oh]o`@;oUhBl
0onLQKX3oib4^@;oUh6i0_n@NkP2ohQd]P;oPfnd0_n0Jk43oh1X[P;oPFN/0_n3IZX2ohEVZ0?oQfNV
0_n9IjD2ohaXY0?oSfVS0_nAJj<3oi=/X`03oiI^XonLNjgoX7f]00;oX7f]0onSOjd2ojJ2[@03okj]
bOo1[/Oo`Jk700;o`Jk700Coa:o5oj>Lc_nSW<koXic>0_nSVld00onSVlcoWXRloij8_002oij8_0;o
WhRl0ol00002oj2:_003oial[onMOK3oWGf`00?oWWna0onOPK82oj63]0?oXWn^0onSP[02ojF5/P03
ojJ9]_nZRK;oZXVb00?o[8fe00Co[I6iokFI^_neVK[o]IVj0_nfWKh3ol>cbP08om?Bf?o?dM_ocm7K
oloAfooDknGoa_cTo`000?nlm_02okO]mP;o]nGf0_nbf?@01Onado;o[/W^ojk9k_n]angoZl;[00Co
Zl7Z00?oZ/3YojZnjOnZ_^T01?nZ_^P00onY_NSo0000ooooo`0Mooooo`002Oooool01P00003ooooo
ooooooooool0<c<c00000080C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c/ol00000
0P3<c<`00ol00000i^KV0>KViP020>KViP09o`00003<c<`0c<c<0<c<c?l00000/k>c0000002IVIT0
00000080Ogmo00<0000006IVIP0000000P1<C4`00`000000<c<c03<c<`0203<c<`<000001P0I6AT7
000000h0<c<c9000000>03<c<`<000004P0I6ATO000000Cooooo00<00000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`;o>7OQ00Go8F3EobAIcomOKl_oGfo;ogMgaP02oh]o`@?oUhBl0_nL
QKX3oib4^@04oiN1^OnFR/CoRhC6oh^4aP;oOgc50_mfM<<3oh1[/@;oP6R^0_n1Ij`2oh=VZP;oQFJX
0on7IjH2ohUWY@;oS6RT0on?JJ<2oi5[X`;oTfbS00?oVGR^oiak[OnLNjd00onPOJd3oj=o[@04ojJ2
[Onn[LWo_Zg9okj]b@;o`Jk700Go__g@oj>MconSWLooXic>oif9_P02oij9_@CoWXRl0ol000000onO
R;coWhVloi]k[P03oial[`?oWGf`0_nNOk43oin1/P03oj63]?nPO:coXWn^00;oXWn^0onSP[000onU
QK;oZ8F_ojZ9/P03ojZ9/P;o[8fe1?neVKX01?nfWKkoa;36olB`a_o3/lX3om?Bf007oloAfooDknGo
a_cTokOki_l0003o]?GbokO]mP02ok?OmP;o/]Sd0_n^cO000on^bNkoZl?[oj_3j`02oj_2j`;oZl7Z
00?oZ[oYojZnjOnZ_^T01?nY_^P3ojVmj003o`000?oooooooooo01_ooooo0009ooooo`0@00000?oo
ooooooooooooo`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`0000<0
c<c<00?o00000>KViP3Vi^H00`3Vi^H01?l00000c<c<0<c<c?l000020;>c/`070000002IVIT00000
07moOol00000IVIV0000000204a<C0030000000c<c<0<c<c00D0<c<c1P00000?03<c<`H00000901<
C4`6000000/0<c<c1000000A01TI6A`000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Kooooo0_lQH=D2od5ScP;oMgO60_n;Ol42oiN4_0?oW8Fj00CoW8Bioif=`onFR/CoUX[4
0on;Q<H2ogmla@04ogId`ombKl7oLVo1og9_`@;oLVfn0_n1Ij`2oh=VZP;oQFJX0on7IjH2ohUWY@;o
S6RT0on?JJ<00onAJj?oU7J^oiUh[P02oiUh[P?oW7^]0onPOJd2oj=o[@Co_Zg900Go`Jk7ojBOd?nT
Wm3oXig?oif;_`02oif9_P?oWXVm0ol00002oij8_003oin8_?nJNZkoVg^^00;oVg^^0onLO:l2oiem
/0?oWWna00CoWh6boiijZ_nPO:coX7b/0onROjh3oj>2/0?oZ8F_0onZRK800on/SKGo/iBgokFI^P03
okFI^P?oa;360ooCd]P00ooHmN;o_okFojWhd`02oj_hj004okCel_l0003o/nKgok?OmP;o[m7b0_n^
cO001?n/aNcoZl?[oj_3jonZ`>T4ojZoj@KoZKkX1?nY_NP00ooooooo0000ooooo`0Kooooo`002Ooo
ool04000003oooooooooooooool0<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIT00000
0;>c/ol000020<c<c003o`00003Vi^H0i^KV00D0i^KV00[o00000<c<c03<c<co00000;>c/ol00000
VIVI0000001oOgl000000P1VIVH01?l00000C4a<04a<C?l0000200000140<c<c1@0000000ol00000
00000000000:04a<C1`000002P1<C4`01?l00000000000000000000;03<c<`<00000400I6AT00ol0
000000000000000G000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`;o04O000Co95W?od5Sc_mVLlcoIW?<0_n;Ol400onGQ;coUHW4oif=`P02oif=`P?oWHg30_nFR/@2
oh^4aP;oOgc50_mfM<<2og9_`@;oLVfn0_meK;/2ogU/^0;oOFff0on7IjH2ohUWY@03ohaXY?n<L[7o
T7B_00;oT7B_0_nDMZh3oiUh[P?oW7^]0onPOJd00onSOjgo^Z_;okZ[b`03okj]b@?oWXc10onMRkl0
1?nMRKko0000o`000?l00002oij8_003oiUi[onINZkoVGZ^00;oVWZ^0onKNjh3oial[`;oWGf`0_nN
Ok400onMN:WoWWZZoiijZP03oj1l[0?oXWn^00?oXh:`ojJ2[?nXQJl00_nXQJl3ojZ9/P?o/iBg0_ne
VKX2ol>/``;oa;3600Goe];Eom?Bf?oHmN;o_okFojWhd`02oj_hj006ok7^mon`foKo/=_fo`000?n`
eOCo[m7b0_n/and00on/aNcoZ/7Zoj[0j@03oj[0j@03ojZojOnZ_^SoZ[kX00CoZKkX1onY_NP00ol0
003oooooooooo`0Jooooo`002Oooool04000003oooooooooooooool0<c<c0000001<C4`0000006IV
IP000000Ogmo0000002IVIT000000;>c/ol000020<c<c003o`00003Vi^H0i^KV00D0i^KV00[o0000
0<c<c03<c<co00000;>c/`000000VIVI0000001oOgl000000P1VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00/0<c<c0`00000;04a<C0L00000701VIVH7000000L0C4a<1000000:03<c
<`@000003P0I6ATH000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`07oooo
o`05o`17`?l0?L7o03g1od5Sc_mVLl`00_n4PLL3oiF9a0?oWHg20_nMSL<2oiJ:a0?oRhC60_moO<D2
ogId``;oLVo100?oLVfnogE/^omeK;/00_miK;P2oge]]P?oPVjd0_n7L;83ohab/@;oT7B_0_nDMZh4
oiUh[P;oW7^]0_nPOJd00ondZ/ko^Z_;okZ[b`02okZ[b`03okj]bOnNS/?oWXk300?oWXc10ol00000
0onMRKkoWXVmoiQi[`03oiUi[`;oVGZ^0onJNZh2oi]k[P?oW7b_00?oWGf`oiafYonMN:T00_nMN:T3
oiijZP;oX7b/0_nROjh01?nTOZ[oYX:/ojJ2[?nVPZ`3ojR5[`03ojZ9/_nbT;?o/iBg00;o/iBg00Go
]IVjol>/`oo3[<?o`jc3olB`aP02omKBe@04om[jg?nbn<3oVO;Bojccl`;o/>7h0_n`foH01On]c?3o
0000ojg9k_n]bNko[<O]00;oZl;Z0_nZ`NX2oj[0j@?oZ[kX1_nY_NP00onY_NOoZKgXojVmj002ojVm
j003ojVliooooooo000001_ooooo0009ooooo`0500000?ooooooooooooooo`0000000P1<C4`02000
0000IVIV0000001oOgl0000009VIV@00003o00000`3<c<`00ol00000i^KV0>KViP060>KViP05o`00
003<c<`0c<c<o`00000000000P2IVIT00`000000Ogmo0000000206IVIP030000001<C4`0C4a<00<0
C4a<0`00000603<c<`@000001`1<C4`7000000L0IVIV6@00000:06IVIP@000001`1<C4`3000000/0
<c<c00<0000001TI6@0I6AT03@0I6ATF000000Cooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`0:ooooo`04o`0m`OlAD/go4E;=ofIcc0;oQ8770_nERL@3oif=`P03oif=`onSY=KoXjCF
00;oVJGN0_n3X>H2ofJFj`;oBXWY0_ljOnH2og9]_P;oMFbk0_miK;P2oge]]P;oPVjd0_n7L;83ohab
/@?oT7B_0_nDMZh3oiUh[P;oW7^]1?ndZ/h2okZ[b`04ohk[_OnNT<GoWXk3oij>``?o000000CoWH^o
oiMj/OnHN[3oV7Z`0onHNJl2oiUi[`?oVGZ^0_nJNZh3oi]k[P04oial[onJM:OoW7JWoiafY`?oWGRY
0onNNZX2oj1l[003oj9o[_nTOZ[oY7jZ00?oYX:/0_nXQJl01?n`S;3o/Y2cok:@/onbT;<2ok>D]`09
ol>X_oo3[<?o`jc3ol>/`ooHd]?oe];Eom[jg?nbn<3oXOGX00;o[nOi00?o/>7hojk?l_n^co800on]
c?001Ol0003oZl?[oj_3jon[`^[oZ[oY00?oZ[kY0_nZ_^P5ojVmj0GoZKgW00?oZKgXojVlionY_>L0
0_nY_>L00ol0003oooooooooo`0Iooooo`002Oooool01@00003oooooooooooooool000000080C4a<
00P0000006IVIP000000Ogmo0000002IVIT00000o`000080c<c<00?o00000>KViP3Vi^H01`3Vi^H0
2?l00000c<c<0<c<c?l00000/k>c0000002IVIT000000P1oOgl010000000IVIV06IVIP00000704a<
C0H000001`1<C4`01000003o000000000000000706IVIP0300000?l00000000000@000006@1oOgl7
000000L0IVIV00Co000000000000000000001P1<C4`4000000P0<c<c00?o00000000000000003@0I
6AT00`00003o00000000000B000000Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`04o`0m`OlAD/goCG7FodeaeP;oQ8770_nERL@00onMSL;oXYoAoj>TeP03oj>TeP;oVJGN
0_n3X>H2ofJFj`;oBXWY00?o>WoVocIliOlfO>D00_meK;/2ogU/^0;oOFff0on2K[@2ohM`/P;oS7:a
0on@M:l2oiAf[P?oVGR^00?oW7^]ojjXdOn^Z=400ondZ/h01?njZl_oWi?7oij@aOnNT<D2o`000003
oij>`onNS<7oUgbc00;oUgZa0_nHN[03oiQi[`?oVGV_0_nINZh2oiYj[P;oVg^^00?oVG>VoiYdYonJ
M:L00_nLMZL4oiehZ@;oWWZZ00?oX7b/oj9kZ?nTOZX00onTOZX2ojJ2[003ojR5[on`S;3o/8b`00?o
/Y2c00Go/iBgol>X_oo3Z;oo`jRool>/``02omSBd`05om_meOnKj:7oZnghoj_]n?n_ioT00_n^do<0
0on^co;oZlG]oj_4k003oj_4k003o`000?nZ_nWoZ[oY00;oZ[oY00?oZ[kYojVmj?nY_NP01?nY_NP3
ojVmi`KoZKcW1?nZ^nH00ol0003oooooooooo`0Hooooo`002Oooool01@00003oooooooooooooool0
00000080C4a<00P0000006IVIP000000Ogmoo`00002IVIT00000o`000080c<c<00Co00000>KViP3V
i^H0i^KV0ol000030>KViP08o`00003<c<`0c<c<o`00002c/k<0000009VIV@00000207moO`050000
001VIVH0IVIV06IVIP000000401<C4`3000000L0IVIV1000000707moOaWo00001`1oOgl3000000P0
IVIV0`00000704a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02`0I6ATD000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`;o4E;=00?oCG7Fogb9eOml
RMD00_nGUm83oj:Od@;oXjCF0_n_b^d2oi[Do004oiC_kon^n^7o[_[QomGjh@;ohN?E00Coglk7ocIl
iOlfO>Go?GkU0_miK;P2oge]]P?oPVjd0_n7L;83ohab/@;oT7B_0_nDMZh2oiUh[P03ojNVeOn^Z=7o
[ZSA00;o[ZSA00?o]:[>oj6FbOnOTlL00ol00003oiMm]0;oUgbc0onGN[42oiQj/0;oV7V_0onINJl2
oiUj[P03oiYj[_nHLJKoVG>V00;oVG>V0_nJM:L3oiafY`?oWGRY0_nNNZX3oj9kZ0?oY7jZ0_nVPZ`4
ok2</0;o/Y2c1?o3Z;l01?oJd]3of=;Com_meOnKj:42oj_]n0;o[]Oe00?o[]?cojc7kOn/and00_n[
aNd2oj_4k0;oZ/3Y00?o0000ojVmj?nY_NP00onY_NP5ojVli`03ojVmionY^nKoZKcW00CoZKcW00?o
Z[[UojZki_nZ^nH00_nZ^nH2ojZji@03o`000?oooooooooo01Oooooo0009ooooo`0500000?oooooo
ooooooooo`0000000P1<C4`020000000IVIV0000001oOgl0000009VIV@00003o00000P3<c<`01Ol0
0000i^KV0>KViP3Vi^Ko00000080oooo00Wo00000>KViP3Vi^H0i^KVo`00003<c<co00000;>c/`00
00000P2IVIT010000000Ogmo07moO`00000306IVIP030000001<C4`0C4a<00T0C4a<1000000706IV
IP<00000101oOgl7o`0001T0VIVI0ol0000707moO`@000001`1VIVH00`000000C4a<04a<C00504a<
C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6ATC000000Cooooo00<00000oooo
ooooool04oooool00ol0003oooooooooo`0=ooooo`03o`0i_Om=LMKoCG7F00;oO8WE0_nGUm800onR
Wm7o[[cTojjli003ojo:k@;o_n[b00?od_3WomkTf?oNi=P00_oOd<T00ooL`Kkoglk7omc0_P02omc0
_P03oceniOm:Q>KoBXCV00;oFH[V0_n2K[@2ohM`/P?oS7:a00?oT7B_oi>OgOnNXmT00_nNXmT3ojNV
e@;o[ZSA00GoXi[;o`000?l0003o0000oiR2^@03oiQo]`;oUgfd0onGO;<2oiMj/@;oV7Z`0onHNJl2
oiUi[`04oiUj[_nFL:KoV76VoiQaYP?oVG>V0onJM:L2oiafY`?oWGRY00?oWWZZoj5iY_nRNjP00_nR
NjP3ojAnZP03ojJ2[?n^R:ko[XR^00?o/8b`00?o/Y2col6T_?o1Y;`00_o3Z;l2om[Bd004omWoc?l0
003o[M_gojgKm`;o[]Oe0_n/b>l00on/angoZ/7Zoj[0jP02oj[0jP;oZ/3Y00?oZ[kXo`000?nY_NP0
0_nY_NP6ojVli`CoZK_V00?oZKcWojZjiOnZ^^D00onZ^^D01_nZ^nKoZ[WTojZii?nZ^^GoZkORo`00
01Wooooo0009ooooo`0A00000?ooooooooooooooo`000000C4a<0000001VIVH0000007moO`000000
VIVI0000002c/k?o00000<c<c?l000000`3Vi^H01Ol00000oooo0?ooo`3ooooo000000<0i^KV00So
00000<c<c03<c<co00000;>c/`000000VIVI00000080Ogmo00?o000006IVIP1VIVH00P1VIVH00`00
0000C4a<04a<C00504a<C0<00000201VIVH3000000@0Ogmo0ol0000809VIVACo00001`2IVIT4o`00
00L0Ogmo00?o000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c
00L0<c<c00<0000001TI6@0I6AT0300I6ATB000000Cooooo00<00000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`05o`0i_Ol]KmkoO8WEogb9eOnGUm800_nN[^<3ojjli004ojo:kOnoj_;o
_n[bom;`i`?og^CH0_oOd<T01?oL`Kkof[Rgomc0__oL`;h3omZi^0;oBXCV00?oFH[VofV@iOmYT>D0
0omiU^<2ohNKh0?oTioM0onNXmT00onWY]GoZIo<o`000002o`0000;oVHFl0_nHP[T3oiQo]`?oUgfd
0_nGO;<2oiMj/@;oV7Z`0_nHNJl00onDKjKoUG2VoiE`YP02oiI`YP?oV76V0onILjH2oiYdY`;oW7JW
0_nMN:T00onNMZGoXGVVoj5iYP03oj9kZ0?oY7jZ0on^R:h3ok2</0?o`JBl00Oo`jRoom[Bd?oJd]3o
f];@omWoc?n/h?Wo[M_g00;o[<_`0_n/b>l2oj[2j`;oZ/7Z00?oZ/3ZojZnj?nZ_^P00onZ_^P01Ol0
003oZKcWojVlionY_>OoZ[[U00GoZK_V00KoZ[SSojZii?nZ^NCoZ[WTojZjiOnZ]^83ojZhh`;oZ[WT
00GoZkKQoj^gh_n[]n;oZkORo`00000Hooooo`002Oooool04@00003oooooooooooooool0000004a<
C0000000IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co00000080i^KV00?o00000?oo
o`3oool00`3oool02Ol00000i^KV0>KViP3Vi^Ko00000<c<c?l00000/k>c0000000209VIV@040000
001oOgl0Ogmo000000@0IVIV00?o00000000000000000P0000000ol00000000006IVIP0606IVIP04
00000?l000000000000000<0Ogmo1?l0000309VIV@So0000502c/k<4o`0000L0VIVI0_l0000607mo
O`<000001@1VIVH2000000H0C4a<00?o00000000000c<c<01`0c<c<00`0000006ATI01TI6@0<01TI
6A4000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00Co02>Uobe_
g_mgV>GoMiSU0onN[^<00on^_>Co_mK[okoFj`02oloLhP;oem;D00?og^CHomo@bOoOd<T00_oL`Kh2
omZh]`03omc0__oJ^KSof[Vh00;of[Jd0ooH^K/2ofV@i@?oNIKS0_n7Vn02oi>Og@;oWZ?I0ol00000
1?nRSl7oW8Vnoib9__nLRKh2oiV5_0;oV8:i0onHOkL2oiMm]0;oUgbc00CoUgZaoi9_Z?nCKjOoTfnW
0onDKjH2oiE`YP;oUW2V0onHLJH3oiUcYP;oVWBW00?oW7JWoiedY?nNMZD00_nNMZD3oj5iYP?oXW^X
00?oY7jZoj^5[?n^R:h00_n^R:h3ok2</003oknQ^Oo1Y;co`JBl00;ofm7>00?of];@omWoc?n/co80
0_n/cO401On/bo3oZl;[oj_2jon[`^_oZ/;[00GoZ[kX1OnY_>L00ol0003oZ[[UojZji@02ojZji@03
ojVki_nZ]n?oZ[SS00?oZ[SS00?oZ[WTojZehOnZ]^800_nZ]^800onZ^>?oZkCOoj^fh@03oj^fh@04
oj^gh_n/]Moo[;GOo`0001Oooooo0009ooooo`0A00000?ooooooooooooooo`000000C4a<0000001V
IVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`03
0?ooo`09o`00003Vi^H0i^KV0>KVi_l00000c<c<o`00002c/k<000000080VIVI00@0000007moO`1o
Ogl000003`1VIVH3000000@0Ogmo0ol0000409VIV@?o00003P2c/k<7o`0000/0/k>c0ol0000609VI
V@;o00001`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<01`0c<c<00ol000006ATI01TI6@0;01TI6A4000001?ooool00`00003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo0_lHL>02ogNHi@04oij^hon/a>co[<C/okoFj`?ocmcR0_oGd]@0
1?oH`lKogm39omc1__oL`Kh3omZh]`;of[Vh0ooJ][@00ooK]K;of;VkomVh^002omVh^003omVg]ooB
^/;odKJo00;odKJo00Co`Jc5o`000?l0003o00000on[Ul42oj:?`@;oW8Vn0_nIQK`2oiR2^@;oV7ng
00?oTG:/oi5aZonALJ/00_nBL:T2oi9_Z0;oTfnW0onDKjH2oiE`YP?oUW2V0_nHLJH3oiUcYP;oVWBW
0_nMM:@3oiifY@?oXGVV0_nRNjP01?nYPJWoZhF/oj^5[?n[QJ`3ojj8[P04ok2</?noXKWo_j6iol6T
_0;ofm7>00Coe?k1ojcBm?n/co;oZlC/0on[`n`2oj_2j`GoZ[kX0_nY^nH4ojVli`;oZ[WT00?o0000
ojZjiOnZ^^D00_nZ]^82ojZgh`;oZ[SS0_nZ/ml2ojZeh@03ojZfh_n[/]goZk;M00;oZkCO0_n[]^42
ojbcgP03ojbegon]]=ko000001Oooooo0009ooooo`0>00000?ooooooooooooooo`000000C4a<0000
001VIVH0000007moO`000000VIVI0000002c/k<2o`000080i^KV00?o00000?ooo`3oool01@3oool0
1?l00000i^KV0>KViP3Vi^H2o`000080/k>c00@0000009VIV@2IVIT000000P1oOgl00`000000IVIV
06IVIP0;06IVIP030000001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT0102IVIT00ol00000/k>c
0;>c/`080;>c/`Oo00001`3<c<`7o`0000L0/k>c0_l0000609VIV@03o`00001oOgl0Ogmo00@0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT0300I6AT@000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`;o673P0_mkZO401On/a>co_<cVokc<i_nlc>KocmcR00?oem;D00Cof<?6omJh_?oF
^;cog<6n0ooJ^;L01?oI/k;of[VhomZf]?oJ][@2om^e/P03ombd/?oI^;SofKRh00;ofKNg00?ofKFd
om6f_ol000000_l000001?o1[<Go^YnnokZO__njWkh2oj^G`@;oXXo100CoW8VnoiAj]?nBMk7oTWNa
0_nAM:l3oi5b[0;oTG6[0_nBL:T2oi9_Z0?oTfnW0onDKjH2oiE`YP;oUW2V0onHLJH2oiUcYP03oiYd
YonKLZ?oWGBT00;oWGBT0onNMZD2oj5iYP03oj9kZ?nYPJWoZH6Y00?oZhF/0_n^R:h02?nmW;Oo_j6i
oknQ^OnoXKWog=3<om_Ac_oDo/7o[=;d0_n[aNd2oj_4k003oj_3k?nZ_^SoZ[kX00;oZ[kX1OnY^nH0
1?nZ^>?oZ[STojZhi?nZ^>@2ojZii006ojZcgol0003oZ[GQojZehOnZ]^;oZZoK0onZ/Md2ojZcg`06
oj^]fOn[/=_oZk3Koj^`fon[/]go[:kI0on//M/2ojbcgP05ojjbfon]]=ko[KCNojfdg_l000005_oo
ool000Wooooo00h00000oooooooooooooooo0000001<C4`0000006IVIP000000Ogmo0000002IVIT0
00000;>c/`;o00000P3Vi^H00ol00000oooo0?ooo`060?ooo`08o`00003Vi^H0i^KVo`00003<c<co
00000;>c/`00000209VIV@050000001oOgl0Ogmo07moOol000002P1VIVH00ol00000000007moO`05
07moO`03o`00002IVIT0VIVI00@0VIVI00?o00000;>c/`2c/k<01P2c/k<3o`0001D0c<c<00?o0000
0;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0409VIV@03o`00001oOgl0Ogmo00@0Ogmo00<00000
06IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<00000
01TI6@0I6AT02`0I6AT@000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`0OY?lPMnCoSKCa00;oSKCa00Go_<cVolK5f?o6aMSoa/GHomOBe002omS3aP;oe[Rl0ooJ
^;L2omVc/P03omVa[ooJ][Cof[Jd00;ofkFb0_oL];000ooI^;SofKNgo`000002o`000003om6f_oo>
/;coc[2l00Co^Ynn00CoZiO1oj>8^?nIP;OoVH2g0_nDN[@2oi9g/@?oTGB_0_nALZ`2oi5aZ`;oTW2Y
0onBKjP2oi=_Y`?oU6nV0_nEL:H2oiI`YP?oV76V00CoVG>VoiU`X_nKLZ?oVg:S0onMM:@3oiifY@;o
XGVV0onYPJT3oj^5[004ojj8[_nmW;Oo_IbgokfL]`;o_j6i00Kog=3<olck]?n[a^goZlK]oj_5kOnZ
_nT3ojZnj@03ojZnj?nY^nKoZK_V00CoZK_V00KoZ[OSojZhhonZ^>?oZ[SSojZhi?nZ/]h4ojZcg`03
o`000?nZ[MWoZZoK00;oZZoK00?oZ[7Moj^Ze_n[[MT00on[[MT00on[/=_o[:_Fojb^f@02ojb^f@03
ojbafon^[mSo[[;K00?o[[;K00Co[KCNojnfgOoooooo00005Oooool000Wooooo00h00000oooooooo
oooooooo0000001<C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/`;o00000P3Vi^H00ol0
0000oooo0?ooo`060?ooo`08o`00003Vi^H0i^KVo`00003<c<co00000;>c/`00000209VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`03o`00
002IVIT0VIVI00@0VIVI00?o00000;>c/`2c/k<01@2c/k<2o`0001T0c<c<00?o00000;>c/`2c/k<0
1@2c/k<00ol00000VIVI09VIV@0409VIV@03o`00001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0
2`0I6AT@000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`05oi8Q
0?llP>Ko?83VohfdlOnO/nH00oo6aMP2olVib`06omS3a_oF^;coe[RlomJh_?oD/KKof[Rg0ooI/k82
omVa[`03omZf]?oK]K;og;B`00;og;B`0_l00003omVe]0?oc[2l00Cob:NhokZO__njWkko^Ynn0_nS
R;P2oiV0]`?oU7Zd0_nBMk42oi5d[`?oTG:/0_nALJ/2oi9`Z@;oTVnX0_nCKjL3oiA_YP;oUG2V0_nF
L:H2oiQaYP03oiM^X_nIL:;oVG2R00;oVg:S0onMM:@3oiifY@03oj5iY_nVOZSoYWjX00?oZH6Y0_n[
QJ`4okfL]`05oknQ^OoLd<cog=3<olck]?n[a^d01?nZ_nT00onZ_^WoZ[_VojZkiP04ojVkiP;oZKKR
0_nZ]n<00onZ^>?oZ[3MojZ`g@02ojZbgP;oZ[?O00KoZZ_GojZ]fOl0003oZZgIojZ_fon[Ym<3oj^Z
eP;oZjgI00Ko[:SBojb[e_n/ZmKo[:_Fojb^fOn^[=D3ojj_f0;o[[;K00Go/;?KojnfgOn_]]go[kKM
o`00000Eooooo`002Oooool04000003oooooooooooooool0000004a<C0000000IVIV0000001oOgl0
000009VIV@00003o00000<c<c?l000020>KViP03o`00003oool0oooo00H0oooo00Ko00000>KViP3V
i^Ko00000<c<c?l000020;>c/`040000002IVIT0VIVI000000<0Ogmo00<0000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0507moO`03o`00002IVIT0VIVI00@0VIVI00?o00000;>c/`2c/k<01@2c
/k<00ol00000c<c<0<c<c00I0<c<c003o`00002c/k<0/k>c00H0/k>c00?o000009VIV@2IVIT00`2I
VIT00ol00000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<
C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI4@000004ooooo`0300000?oo
oooooooo01;ooooo00?o0000ooooooooool05?ooool00onB8@3o?83VoinciP02oinciP05olK5f?o9
^L_obKW;olViboo9/<400_oF^;`2omBa]P03omB^/_oI/k;ofK>b00?ofK6_0_oK]K83o`000003omfd
[_oI]kOofKFd00;ofKFd00?oek6bolj`_?o8YkP00_o8YkP00onjWkko/I>hoj>8^002oj>8^0;oVH2g
0_nDN[@2oi9g/@;oTGB_0onALZ`2oi5aZ`;oTW2Y0_nBKjP3oi=_Y`;oU6nV00CoUG2Voi=/X_nEKJ;o
UFfR0onGKZ82oiU`XP?oVg:S0onMM:@2oiifY@?oYWjX0onYPJT2oj^5[007ok^H]?nmW;Oo_IbgokfL
]ooLc/_og=3<olck]003ojZoj@CoZ[[U00?oZ[_VojVdhOnY]N400_nY]N42ojVfhP06ojV]f_nY[m_o
ZJoKojV_fonZ/=goZJKC0_nZZ=D4ojZ[e`03ojZ]fOl0003oZjOC00;oZjOC00?oZj[FojbTcon/Z=80
0on/Z=800on/ZmKo[jWBojj/e@02ojj/e@03ojj_f?na/MSo/;?K00;o/;?K0_n_]]d2ok:jg`03o`00
0?oooooooooo01;ooooo0009ooooo`0@00000?ooooooooooooooo`000000C4a<0000001VIVH00000
07moO`000000VIVI00000?l00000c<c<o`000080i^KV00?o00000?ooo`3oool01P3oool01_l00000
i^KV0>KVi_l00000c<c<o`000080/k>c00@0000009VIV@2IVIT00000101oOgl00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo00D0Ogmo00?o000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c
/`060;>c/`03o`00003<c<`0c<c<01T0c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VI
V@0309VIV@03o`00001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00504a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6ATA000000Cooooo00<0
0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`04oi8Q0?l09:ooEH;QoinciP;oZJ_H
0oo9^L/2olV``@03omJh_?oD/KKoe;6f00;oe:jb00?ofK>bomVa[ooI/Jl00ol00002ombd/0;ogKB^
0ooI]K@2omNa/PCob:Nh0onaTkP2oj>8^0;oVH2g0_nDN[@2oi9g/@?oTGB_0_nALZ`2oi5aZ`;oTW2Y
0_nBKjP3oi=_Y`04oiA_Y_nBJj;oTfbRoi=/XP;oUFfR0onGKZ83oiU`XP;oVg:S0onMM:@00onNMZGo
Y7^VojInZ002ojInZ0?oZH6Y00?oZhF/ok^H]?nkV;@00onmW;L00ooLc/_o`OBVojZoj@06ojZji@06
ojVch?nY]>7oZKCQojVdhOnY]N7oZJ_H1?nY[MX00onY[m_oZJ?@ojVVd`02ojVVd`;oZZSE0_nZZmL0
1_nZXLgoZjC@o`000?n[Y=3oZjOCojbQc0?o[:C?0_n/Z=801_n_YLko[jWBojnYd_n_ZM;o[ZcEok:^
e@?o/K7H00?o/;?Kok>igOnc^Md00_nb^]l00ond`NCo0000ooooo`0Cooooo`002Oooool04000003o
ooooooooooooool0000004a<C0000000IVIV0000001oOgl0000009VIV@00003o00000<c<c?l00002
0>KViP03o`00003oool0oooo00H0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l000020;>c/`040000
002IVIT0VIVI000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0507moO`03
o`00002IVIT0VIVI00@0VIVI00?o00000;>c/`2c/k<01P2c/k<2o`0001T0c<c<0_l000070;>c/`03
o`00002IVIT0VIVI00@0VIVI00?o000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP03
0000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@03
o`0000000000000000h000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Go
oooo00?oTR40o`0T[omEP^400onYZmP01?o9^L_obK31olV``Oo9/<42omBa]P?oe:jb0ol00002omZ`
[@;og;B`0ooM]:h00ooM/jgofKFdomNa/P02omNa/P03om>[/?o8YkSob:Nh00;o`Ijd0_naTkP01?nS
R;SoVWjcoi5f/?nAM[02ohe`[P;oRff[0on;JjT2ohaZY`;oS6VU0_n>JJ@2ohmYX`?oT6ZR0_nBJj82
oi=/XP?oUFfR0onGKZ82oiU`XP;oVg:S0_nMM:@00onQN:GoY7^VojAkYP04ojInZ0;oZH6Y1?nkV;@0
0onmW;Oog<k;omc>b`02ojVji@;oZ[[U00CoZK;NojVcgonY/mooZK?O0_nY/n000onY]>7oZJWGojV[
f002ojV[f0;oZJgJ00KoZ:3>ojVSd?nYXm3oZJ?@ojVVdonYV/L2ojVMbPCoZZ7=00?oZjC@o`000?n/
XL`00_n/XL`00on/Y<oo[Z;;ojnUcP03ojnUcP03ojnYd_nbZm7o/ZkE00;o/ZkE00Co/K7HokFhfone
^=_o/kWM0_ng`^<01?nd`NCo]LWYokG9jOl0000Cooooo`002Oooool04000003oooooooooooooool0
000004a<C0000000IVIV0000001oOgl0000009VIV@00003o00000<c<c?l000020>KViP03o`00003o
ool0oooo00H0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l000020;>c/`040000002IVIT0VIVI0000
00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`03o`00002IVIT0VIVI
00@0VIVI00?o00000;>c/`2c/k<01`2c/k<2o`0001D0c<c<0_l000070;>c/`;o00001@2IVIT2o`00
00D0Ogmo0P00000506IVIP8000001P1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI
00`06ATI4@000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05oooool01Ol0
9:ooHgkHof=nf?nYZmSo[J?=00?obK310_o9Z[X01_oD/KKo0000o`000?l0003oeJb_omVa[`?of[2]
00Cofk2/ombd/?oM]:kogKB^0_oM/jd00ooL/:_oek6bomNa/P02om>[/006olRW^?o1W[Co`Ijdol6N
]?naTkSoZHZd0_nJO[<2oi5f/0;oSG2^0on;KJ/2oh][Z@;oS6ZW0_n<JJD2ohiYY0;oSfVS0on@JZ82
oi9[XP;oTfbR0onEKJ83oiM^XP;oVG2R0_nKLZ<00onMM:CoXGRUoj5hY@03ojAkYP?oYWjX00?oZH6Y
okRD/_nhU;800_nkV;@2om_<bP04omc>bonY^^GoZK[UojVagPCoZK;N00?oZK?OojRVe?nYZ=H00_nY
Z=H2ojVYe`03ojV[f?nXW/coZ:3>00?oZ:3>00?oZJ?@ojRGa?nYV/L00_nYV/L2ojVMbP;oZZ7=00Ko
ZiW4oj^Mb?n[WLSo0000ojbQc?n^W/H3ojjRb`;o[jG>00Go/jS>ok:[dOnbZm7o/Z_Aok:^e@02okNf
f004okFhfoni`n7o^L?QokO2h`;o^<cY00Co]LWYokC>kOoooooo00004_ooool000Wooooo00h00000
oooooooooooooooo0000001<C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/`;o00000P3V
i^H00ol00000oooo0?ooo`060?ooo`06o`00003Vi^H0i^KVo`00003<c<co00000P2c/k<00`000000
VIVI0000000407moO`030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0101oOgl00ol00000
VIVI09VIV@0509VIV@;o00002@2c/k<3o`0000`0c<c<1_l000070;>c/`;o00001P2IVIT00ol00000
Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000
<c<c03<c<`0603<c<`030000000I6AT06ATI00`06ATI4P000004ooooo`0300000?oooooooooo017o
oooo00?o0000ooooooooool06?ooool00ol09:ooHgkHojfSc@02ojfSc@03olV``Oo9Z[[o000000;o
00000_oD[[82omF/[`03omVa[ooJ/:gof[2]00;ofk2/00?og;2Zomfd[_oM]:h00_oM/jd2omb`Z`03
omNa/_oCZk3odj^`00Co`Ijd0_nYR[@3oiYn/`;oTGJ`00CoSG2^oh]]Zon;KJ_oRff[0_n;JjT2ohaZ
Y`;oS6VU0_n>JJ@2ohmYX`?oT6ZR0_nBJj83oi=/XP;oUFfR0onGKZ82oiU`XP03oi]bXonNMZCoXGRU
00;oXGRU0onTNjH2ojInZ005okB@/OnhU;;o^9BbokRD/_nkV;@00ooKc<X00onY^^GoZK7MojVag@02
ojVagP;oZK;N00KoZ:GCojRVe?nXY]CoZ:KDojVXe_nWVLL2ojNKb@?oZ9k<0_nXX<h01?nWU<7oZ9O4
ojRGa?nXUl@2ojVJa`03ojVMb_nZUL7oZiW400?oZiW400?oZig8ojfJ`ol000000_n^W/H00on^X/_o
/jC:ok>XcP02ok>XcP;o/Z_A0_nh]=D01?ng]]So^l?Pok_3h?ni`n42ok_?j@03okS<jOnfd^ko]];^
00;o]<k]00?o0000ooooooooool04?ooool000Wooooo00h00000oooooooooooooooo0000001<C4`0
000006IVIP000000Ogmo0000002IVIT000000;>c/`;o00000P3Vi^H00ol00000oooo0?ooo`060?oo
o`06o`00003Vi^H0i^KVo`00003<c<co00000P2c/k<00`000000VIVI0000000407moO`030000001V
IVH0IVIV00L0IVIV00<0000007moO`1oOgl0101oOgl3o`0000H0VIVI0_l0000:0;>c/`co00002`2c
/k<2o`0000D0VIVI0ol0000407moO`80000000?o000006IVIP1VIVH00P1VIVH200000003o`00001<
C4`0C4a<00@0C4a<0P00000703<c<`8000003@0I6ATD000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Hooooo`04ojHl0?mSO]SoHgkHojfSc@?o00000_o9Z[X00oo9YkKoe:jb
omF/[`02omF/[`;of[2]0ooK/:`2omb`ZP03omfd[_oM/jgog;2[00;og;2[0ooCZk001?o?YJko`Ijd
ol6N]?o1W[@3ojV:]0;oVWjc0_nAM[02ohe`[P;oRff[0on;JjT2ohaZY`;oS6VU00?oSVVTohmYXon?
JJ<01?n@JZ82oi9[XP;oTfbR0_nEKJ83oiM^XP04oiU`X_nLLjCoWWJToiifY0CoXGRU0_nTNjH00onV
OZSo]92aokB@/@03okRD/P?oflc:0_nY/=d01?nY/MgoYj;AojRSd_nXXm84ojRUd`03ojRVe?nVUlKo
YiW700;oYiW70_nWVlT00onXW/coYY6oojND`@03ojND`@;oZ9O400?oZI[7ojVB_OnZUL400_nZUL42
oj^Ia004ojfF_on]V/?o[I[3o`0000;o[Yk60oncY<X00oncZ<ko^K;BokRde@02okRde@06okk3g_nk
`n3o^l?Pok_3h?nnd^Wo^loY0_nif?000onfd^ko/m?aok?Cl@02ok7?k`03o`000?oooooooooo00oo
oooo0009ooooo`0>00000?ooooooooooooooo`000000C4a<0000001VIVH0000007moO`000000VIVI
0000002c/k<2o`000080i^KV00?o00000?ooo`3oool01P3oool01_l00000i^KV0>KVi_l00000c<c<
o`000080/k>c00<0000009VIV@0000000`1oOgl00`000000IVIV06IVIP0806IVIP03o`0000000000
Ogmo00L0Ogmo00?o000009VIV@2IVIT01@2IVIT3o`0001X0/k>c1?l0000609VIV@03o`00001oOgl0
Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0800000200c<c<0
0`0000006ATI01TI6@0;01TI6AH000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Wooooo0ol00002ojnMaP;obJZj0_o9YkH01_oD[[;oeJb_omF/[ooE[:ooeZb]omZ`[@;ofk2/
0ooL/:X2omfc[@?og;2[00?ofZfZom>[/?o?YJh00_o?YJh00oo1W[Co^iJaok^F/@02ojV:]0;oVWjc
0_nAM[02ohe`[P?oRff[0_n;JjT2ohaZY`;oS6VU0_n>JJ@2ohmYX`?oT6ZR0_nBJj82oi=/XP?oUFfR
0_nGKZ82oiacY0?oWWJT0onQN:D2ojAkYPCo]92a0_nhU;801OoIbL[oflc:ojV_g?nY/=goYj7@00?o
Yj;A0_nXXm82ojRUd`04ojFDa?nVUlKoYYO6ojJGaP;oYiW700?oYi_9ojF>_?nVTKl00_nVTKl3ojND
`@03ojRGa?nXS[[oZI:m00;oZI:m0_nZUL44ojfF_`;o[I[300?o0000ok>Qa_ncXLH00_ncY<X3okVb
dP07okRdeOnn`mko_/?Nokk3g_nk`n3o_];YokcNl@02okWHl004okGIloncdo7o/m?aok3?l0?o[lc_
00?o0000ooooooooool03_ooool000Wooooo01400000oooooooooooooooo0000001<C4`0000006IV
IP000000Ogmo0000002IVIT000000;>c/ol00000c<c<o`0000020>KViP03o`00003oool0oooo00@0
oooo00Ko00000>KViP3Vi^Ko00000<c<c?l000020;>c/`030000002IVIT0000000<0Ogmo00<00000
06IVIP1VIVH02`1VIVH2000000L0Ogmo0ol0000709VIV@Oo0000302c/k<7o`0000L0VIVI0ol00004
07moO`<000001@1VIVH2000000L0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0;
01TI6AL000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo0ol00000
0onV?03oIg[BofMjdP03ojnMaP03olVZ^_o9YkKobJNf00?oeJb_0_oF[:d3om^`[0?og;2Z00CogK2Y
omfc[OoL/:_og;2[0_oJ[JX01?oCZk3ocjF^olnU[_o?YJh3ok^F/@04ojV:]?nSQK?oTWRboi9h/P;o
RFn`0_n4JZd3oh]]Z`;oRf^Y0_n<JZL2ohaYY@;oSVVT0_n?JJ<3oi1ZXP;oTV^R0_nCK:83oiE]XP04
oiM^X_nILJ?oW7>ToiacY0?oWWJT0onQN:D00onTNjKo/Hb_ok6<[`03okB@/@05okRD/_oIbL[ofLW:
ojV_g?nWX<l00onWXM000onWX]7oY971ojFC`P02ojFC`P?oYIC40_nVUlH00onWVLOoYH^jojF>_002
ojF>_0?oYY6o00?oYiC1ojN;]onXS[X00_nXS[X2ojVB_@03ojZE`On/T[_o[9:k00?o[IJo00Ko[I[3
ok:M`_ncXLKo0000ok>Qa_ncY<X2okZ_c`03okVbd_o1a=co`LCL00;o_/?N00?o`]OYokkBjOnlg_40
0_ngh?@01OnefO?o/MCbok7Dl_n`co3o[L[^00?o[LO]00?o0000ooooooooool03_ooool000Wooooo
01400000oooooooooooooooo0000001<C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/ol0
0000c<c<o`0000020>KViP03o`00003oool0oooo00@0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l0
00020;>c/`030000002IVIT000000080Ogmo00<0000006IVIP1VIVH03P1VIVH4000000H0Ogmo1ol0
000709VIV@co00001`2IVIT7o`0000<0Ogmo0P0000000ol00000000006IVIP0506IVIP03o`000000
0000C4a<00D0C4a<0P0000000ol00000<c<c03<c<`0603<c<`03o`00000000006ATI00`06ATI6000
0004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05?ooool2o`0000Cooooo0_mW
MLh2ojnMaP05ok2J`_o9YkKobJNfolVW]_o:Y[@00_oE[:l2omJ/[@03omR/[?oK/:cofk2/00;og;2Z
0_oM/:T3omb`Z`;ofZfZ1?o?YJh3ok^F/@;oXhFc0_nBN;82ohU_/0;oQ6Z]0on4IjX2ohAVZ0;oS6ZW
0_n<JJD2ohiYY0;oSfVS0on@JZ82oi9[XP03oi=/X_nDK:;oUfjS00;oUfjS0_nILJ<3oiacY0;oWWJT
0onQN:D3ok6<[`?o]92a00?oe/K:omW9b_nVWlh00onWX<l00onWXM3oY8noojBA`@02ojBA`@?oYI?2
0_nUU<@00onVUlKoY8VhojF;^P02ojF;^P;oYHjl0_nVTKl01?nVR;GoYh^gojN;]onWRkL2ojR>^P03
ojVB_On[S[So[9:k00?o[9:k00?o[IJook:I__nbWL800_nbWL801?ncXLKo0000ok^/bonj[ll2olC4
fP05ol74g?o6fnWoa]_Yol;GjOnoiO400_nhj?H01?ngh?Co/][eok;JmOnae?82ojk=l0;o[L[^0_n]
and00ol0003oooooooooo`0>ooooo`002Oooool04@00003oooooooooooooool0000004a<C0000000
IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co00000080i^KV00?o00000?ooo`3oool0
103oool01_l00000i^KV0>KVi_l00000c<c<o`000080/k>c00<0000009VIV@0000000P1oOgl00`00
0000IVIV06IVIP0206IVIPP000001`1VIVH00ol0000000000000000;07moO`Oo0000302IVIT7o`00
00L0Ogmo0`00000806IVIP8000001@1<C4`3000000X0<c<c00<0000001TI6@0I6AT0300I6AT00`00
003o00000000000F000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0Boooo
o`?o00001_ooool00ol009?oIgG>ok2J`P03ok2J`P06olVW]_o:Y[CobZJdolZV]?oE[:ooeZb]0ooH
[:`3omb`ZP;ogK2Y00?ogJnXomb`ZooJ[JX00_oJ[JX00ooGZJWocjF^olnU[P02olZP[@;o^iJa0onS
QK<2oi9h/P04ohU_/?n4JZgoQ6Z]ohAZ[@;oQ6NZ0_n4IZP2ohIVYP;oR6JU0_n:Ij@2ohmYX`;oT6ZR
00?oSfVSoi5[XonAJj<00_nDK:83oiM^X`;oVG6S0onLLj@3oiifY0;oXGRU0onaS:l3okB@/@06omK6
b_n>dgSoYYo>ojJOc_nWX<ooXhjn0onTSkl2ojBA`@;oYI?200?oXXBdoj>6]_nSQ[H00onTRKP2ojF;
^P03ojF>_?nUQK;oYXRe00;oYXRe0onWRkL00onXS[[oZX^eoj^>^002oj^>^0;o[9:k00Co/IJjok:I
__nbVKko/YVn0_nbWL800onk[<_o0000ok^/b`03olC4fP06ol_Qj?o6fnWo`^gaol;]lOnhl?Co^>Sf
0_nchOL01?nbf_Go[m7bojoAl_n^cO05ooooo`03o`000?oooooooooo00kooooo0009ooooo`0A0000
0?ooooooooooooooo`000000C4a<0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<
c?l000000`3Vi^H00ol00000oooo0?ooo`020?ooo`04o`00003Vi^H0i^KVo`000080c<c<00?o0000
0;>c/`0000000P2IVIT00`000000Ogmo0000000406IVIP030000001<C4`0C4a<00H0C4a<0`000007
06IVIPL000002`1oOgl<o`0000L0Ogmo1`00000706IVIP@000001P1<C4`00`000000<c<c03<c<`08
03<c<`<000003P0I6ATJ000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`?o00002_ooool00ol009?oIgG>ok2J`P02ok2J`PCobZJd0_oF[:d3omR/[0;og;2Z0_oM/:T2
omf_Z003omb`ZooJ[J[ofZfZ00;oejVY00GocjF^olZP[Oo:X:gobZ2]ok^F/@02okNC/P;oXhFc0_nB
N;82ohU_/0;oQ6Z]0_n4IjX2ohAVZ0;oQVJV0_n8IZD2ohYWY0;oS6RS0on?JJ<2oi5[X`;oU6bR0onG
KZ<3oiUaX`;oW7>T0onNMZ@00onQN:Go[HR^ojf8[P03ok6<[`04okB@/OoFa/[oe/K:oj:<_@;oXhfn
0onSS[h2ojB?_`03ojBA`OnQPk?oXXBd00;oXXBd0onSQ[H2ojB9^003ojF;^_nTP[3oYHFb00;oYHFb
0onVR;D2ojN;]`?oZX^e0_n[S[P01?n/T[_o/IJjok6F^_naU[X2ok:I_P07ok:M`_nkZLOo^jW7ok^/
bol0003oalCGolC4fP02ol_Qj003ol?ekoo2kO7o^?3d00;o/^Wh00Co/n7gojoFm?n_e_Co[m7b2?oo
ool00ol0003oooooooooo`0=ooooo`002Oooool01@00003oooooooooooooool000000080C4a<00@0
000006IVIP000000Ogmo0P0000001@2c/k?o00000<c<c03<c<co00000080i^KV00Go00000?ooo`3o
ool0ooooo`0000030>KViP03o`00003<c<co00000080/k>c00<0000009VIV@0000000P1oOgl01@00
0000IVIV06IVIP1VIVKo000000`0C4a<1`00000706IVIP/000002@1oOgl:000000P0IVIV1P000007
04a<C0<00000200c<c<3000000l06ATI70000004ooooo`0300000?oooooooooo013ooooo00?o0000
ooooooooool03?ooool3o`0000gooooo00Co002Cof=abomSLL_o/9[20_naV[l2olZV]0;oc:Jb00Ko
eZb]omR/[?oH[:cof:b/omV]ZooL/:X2omf`Z@;ogJnX00?og:fWomZ]Z_oJ[JX00_oGZJT4olZP[@?o
]i>b0_nSQK<2oi9h/P;oRFn`0_n4JZd3ohAWZP03ohAVZ?n6IZKoQVJV00;oR6JU0_n:Ij@2ohaXX`?o
SfVS0_nAJj<2oiA/XPCoUfjS0_nILJ<2oiacY0;oWWJT00CoZHB]ojf8[_n]R:ko[HR^0_naS:l2om;2
bP03omK6b_nRS;goXXbm00?oXhfn0_nSS[h00onTSkooX86aoj63/`02oj63/`?oXXBd0_nSQ[H01?nT
RKSoXh2^ojB2/?nTP[03ojF5/P?oYXRe00?oYh^gojR8/_nZRkD00_nZRkD00on[S[So/9:gok6F^P03
ok6F^P03ok:I__nkY/Co^jW700;o^jW700SobL?DolO4eol0003ocnKWol_Qj?o3mNoo/oO_ojo`mP;o
/^Wh00?o[mcgojoFm?n_e_@02_ooool00ol0003oooooooooo`0=ooooo`002Oooool01@00003ooooo
ooooooooool000000080C4a<00@0000006IVIP000000Ogmo0P0000001@2c/k?o00000<c<c03<c<co
000000<0i^KV0ol000040>KViP05o`00003<c<co00000;>c/`0000000P2IVIT00`000000Ogmo0000
000306IVIP030000001<C4`0C4a<0180C4a<00@00000o`000000000000003P1VIVH9000000h0IVIV
0P0000000ol00000000004a<C00504a<C0D0000000?o00000000000c<c<01P0c<c<200000003o`00
000000006ATI00d06ATI00<00000o`00000000007@000004ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool02Oooool3o`00017ooooo00?o002Cof=abonaV[l00_naV[l01?o:Y[Coc:Jb
olbV/_o<Y[83omR/[0;ofJf[0_oM/:T3omf_Z0;og:fW00?ofZfZomNYZOoGZJT01?o:X:d3okNC/P04
oj>5/onNQk[oRGRjohUh^P;oOFfg0on4JZd2ohAWZP;oQ6JX0_n6IZH00on8IZGoRVNTohYWY003ohaX
X`;oSfVS0_nAJj<3oiA/XP?oUfjS0_nILJ<2oiacY0?oZHB]0on]R:h01?naS:ood/;:om;2b_oB`/X4
oj:<_@;oXhfn00CoXhjnoin0/?nPPK7oX86a0onQPk<3oj:4]004oj>6]_nROZcoXh2^oj>0[P?oY8:`
0onUQK800onVR;GoYhF_ojR8/P02ojR8/P;oZX^e0on`T[L2ok6F^P05ok^S`?nkY/Co^jK4ok^Va?nk
ZLL00_o9`m@01?oDk>Go0000ol7kj?nVmNl2ojgYn@03ojoRn?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool000Wooooo00D00000oooooooooooooooo0000000204a<C0040000001VIVH00000
07moO`80000000D0/k>co`00003<c<`0c<c<o`00000:0>KViP05o`00003<c<co00000;>c/`000000
0P2IVIT00`000000Ogmo0000000206IVIP030000001<C4`0C4a<00@0C4a<2000000;04a<C0X00000
3@1VIVH>000000L0C4a<0`00000;03<c<`<000004@0I6ATQ000000Cooooo00<00000ooooooooool0
4?ooool00ol0003oooooooooo`06ooooo`?o00005Oooool2of=ab`;o/IZo1?o<Y[82omR/[0?ofJf[
00CofZfYomf`ZOoM[jSogJnX0ooL[JL2omNYZ@;oe:JX0_o:X:d2olRN[@;o]i>b0_nNQkX3ohUh^P04
oge]]omhJ;CoN6RdogQX]0;oN6Ja0_n4IZP2ohIVYP;oR6JU0_n:Ij@2ohaXX`?oSfVS0_nAJj<2oiA/
XP?oUfjS0_nILJ<00onLLjCoYH2/ojF0[003ojV4[@;o[HR^00Coc[k;om;2b_oB`/[od/;:1?nRS;d0
1?nSSKkoWgj`oin0/?nOP;03oj21/@?oXH>c00CoXXBdoj5lZonROZcoXWj/0onSP:h2ojB2/0;oYHFb
00?oYX:]ojN5[onWQJl00onXR;800onZRkGo[hjdok2B]`02ok2B]`04ok6F^_nkXl3o^j?0ok^S`0;o
^jK400Sobl?BolW3e?oDk>Goe>cUoiGbg?l0003oYnogojgYnA7ooooo00?o0000ooooooooool03Ooo
ool000Wooooo01000000oooooooooooooooo03<c<`000000C4a<0000001VIVH0000007moO`000000
VIVI0000002c/k?o00000P3<c<`00ol00000i^KV0>KViP060>KViP05o`00003<c<co00000;>c/`00
00000P2IVIT00`000000Ogmo0000000206IVIP030000001<C4`0C4a<0080C4a<0`00000803<c<`L0
00003P1<C4`=000000h0C4a<1`00000:03<c<`@000004@0I6ATT000000Cooooo00<00000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`?o00006?ooool2oee]b`03ok6J_onbV[ko/YZn00;o
c:Jb0_o>Yk400ooH[:cofJf[omV]Z`02omZ]Z@03omf`ZOoM[jSogJnX00?og:fW0_oGZJT2omBVZ005
olZP[Oo8WZgob9j]olRN[OngTk800_nfUkL2oij7^P;oRGRj0_mmKKL2ogQX]0;oN6Ja0_mjIJl2ohIV
YP;oR6JU0_n:Ij@2ohaXX`?oSfVS0_nAJj<2oiA/XP?oUfjS00?oVG6Soj5m[?nUP:`00_nUP:`3ojV4
[@08ojf8[_o>_/_oc[k;oljnbooB`/[oXH^loj:<_OnNOJl2oiin[`;oWgj`0onOP;02oj21/@;oXH>c
00?oWgZYoj5lZonQO:/00onROZ`2oj>0[P;oY8:`0onVPZd3ojN5[`;oZ8Rb0on_S[@2ok2B]`Co^j?0
00Go^jK4ol_3d_o;`m;of?7RomC/i@02oicbkP03ojO_mol0003ooooo017ooooo00?o0000oooooooo
ool03Oooool000Wooooo01000000oooooooooooooooo03<c<`000000C4a<0000001VIVH0000007mo
O`000000VIVI0000002c/k?o00000P3<c<`00ol00000i^KV0>KViP050>KViP08o`00003<c<`0c<c<
o`00002c/k<0000009VIV@00000207moO`030000001VIVKo000000<0C4a<00?o00000000000c<c<0
4@0c<c<800000003o`0000000000000001H0C4a<0P0000000ol00000000000000003000000d0<c<c
1000000A01TI6BP000001?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`?o
00006oooool00ooCJ`3oGFg;ok:J_P02ok:J_P04olbV/_o>Yk7ocZNaoljW/@?ofJf[0_oJ[JT00ooJ
[JSogJnXomf_Z002omb]Y`;ofZZV00?oejVYomBVZ?oDYZP01?o8WZd3okJG]`;oWXNj0on9N;X01Omm
KKOoN6RdogQX]?mhJ;CoN6Ja00;oNVF_0_mmIZh2ohQVY@;oRVNT0on<J:<2ohmYX`;oTF^S0_nDK:82
oiM^X`03oiaiZonQOJcoXGf/00?oYH2/0onYQ:d3oljnb`;oXH^l00?oWGb^oiim[onNOJl00_nNOZl3
oimn/0;oWh2`00?oX86aoiiiZ?nONZT00_nONZT2oj5lZ`?oXWj/0_nSP:h00onTP[3oYGn[ojEoZ`03
ojJ2[@;oYhF_00?oZ8Rbojj;/On_S[@00_n_S[@00on`T[Oo^inmok^O_@03ok^S`006olg2coo;`m;o
f?7Rog7DVon9k=_oW?;^0oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
0009ooooo`0@00000?ooooooooooooooo`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VI
V@000000/k>co`000080c<c<00?o00000>KViP3Vi^H01@3Vi^H02?l00000c<c<0<c<c?l00000/k>c
0000002IVIT000000P1oOgl00`000000IVIV0000000304a<C0030000000c<c<0<c<c01`0<c<c5P00
000?03<c<`D0000000?o000001TI6@0I6AT0400I6AT200000003o`0000000000000002H000001?oo
ool00`00003oooooooooo`0?ooooo`Co00007oooool2oee]b`;o/YZn1?o>Yk400oo@Z;3ofJf[omV]
Z`02omZ]Z@;ofZfX0ooL[JL2omZZYP?oe:JX00GodjFYolRN[Oo8WZgob9j]olVR/@02okJG]`?oViWA
0_mfQ=<2oe]cd@;oN6Rd0_mhI[400omjIJooOFJ^ogeV[P02oh5X[@;oRVNT0on<J:<2ohmYX`;oTF^S
00?oU6bRoiQfZonLNJ/00_nLNJ/3oj5m[0?oYH2/00CoZHB]olRic?o8^Lcoc[k;1?nMO:h3oiim[`;o
WWj_0_nOO[000onOP;3oWWNWoiiiZ002oiiiZ0;oWgZY0onQO:/2oj9n[003oj>0[_nTOJWoYGn[00;o
YGn[0onVPZd2ojN5[`?o[X^a0_n_S[@4ok^O_@04ok^S`?o=`/oofoKNohoSW`Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool04000003oooooooooooooool0<c<c
0000001<C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/ol000030<c<c003o`00003Vi^H0
i^KV00<0i^KV00Co00000<c<c03<c<co00000P2c/k<01@000000VIVI0000001oOgl000000080IVIV
00D0000004a<C01<C4`0C4a<0000000403<c<`l00000:@0c<c<7000001D06ATI;P000004ooooo`03
00000?oooooooooo00oooooo0_l0000Qooooo`;oE6S:00?o/YZnok>K__ncVkh00_o>Yk43om2X/0;o
fZfY0ooJ[JP2omb]Y`?ofZZV0_oDYZP3om>UZ@04olRN[Oo9X[7obJ:aokJG]`;o_JW60onKVM42ogJ4
d`03oe]cdOm@J/koD6[>00;oN6Ja00?oNVF_ogeV[_mmIZh00_n1J:d2ohEZ[0?oRVb[0_n>Kj/2oi=b
Z`?oV7J[0_nLNJ/3oj5m[0;oYH2/00Go`KC=olRic?o8^Lcob;W<oial[`05oiel[P;oWWf_0_nNOZl0
0onOO[3oWGJWoiigY`02oiigY`;oWWVX0onONZT2oj5lZ`;oXWj/0_nTOJT3ojEoZ`?oYX:]00?oYhF_
ojf8[on^Rk400_n^Rk400on_S[Co^YbjokZL^P02ok^O_@04olo0c?o=`/oofoKNohoSW`Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`002Oooool01P00003ooooooooooooo
ool0<c<c00000080C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c/ol000000`3<c<`0
1Ol00000i^KV0>KViP3Vi^Ko000000<0c<c<00Go00000;>c/`000000VIVI0000000207moO`030000
001VIVH0000000<0C4a<00@0000003<c<`0c<c<0<c<c0P00000?01TI6@/00000400c<c<>000001P0
6ATI<P000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool07oooool00omDJ<[o
/i^nok>K_P02ok>K_P04oljW/Oo@Z;3od:R`om2X/0;ofZfY0ooJ[JP00ooJ[:Oog:fWomZZYP02omZZ
YP03omRXY_oDYZSodjFY00;odjFY0oo9X[44okfYaP04oi^IdOn1c_ooPLkoo`20d@;oFg?A00?oD6[>
odmYcOm?JLd00_mjIJl00ommIZkoPFR]oh5X[@03ohEZ[0;oRVb[0_n>Kj/2oi=bZ`?oV7J[0onLNJ/2
oj5m[005ojF0[?o1]<go`KC=ol6dcOo8^L`00_nLO:l5oiel[P;oWWf_00CoWWj_oiaeY_nMMZOoWGJW
0onNMjL2oiiiZ0?oWgZY0_nQO:/00onROZcoXg^WojAmZ@02ojAmZ@?oYGn[00?oYX:]oj^5[?n]R:l0
0_n]R:l2ojj;/@?o^Ybj00Co^inmolo0c?o?`<cogO_I3?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00cooooo0009ooooo`0600000?ooooooooooooooo`0c<c<000000P1<C4`02@00
0000IVIV0000001oOgl0000009VIV@000000/k>co`0000040<c<c0?o00000`3<c<`02?l00000/k>c
0;>c/`000000VIVI0000001oOgl000000P1VIVH010000000C4a<04a<C000000403<c<`03o`00000I
6AT06ATI01T06ATI4000000O01TI6@@0000000?o0000000000000000<P000004ooooo`0300000?oo
oooooooo01;ooooo00?o0000ooooooooool07_ooool00ol005KoE6S:ok>K_P02ok>K_PCod:R`00Co
dJV`omZ]ZOoJ[JSofZfX0_oJ[:L00ooL[JOofZZVomZZYP02omRXYP05omBVZ?oCYJWodjFYom>UZOoE
ZJ/00_o9X[400ooB/KSo_JW6okfYaP02olgIhP03ok?kcoo/mjcomNNi00;olMbj0_m@J/h00om?JLgo
E6_=ogYU[`02ogeV[P;oPFR]0_n5JZ`2ohY/Z`;oSVn[0_nCLZ/3oiQfZ`?oW7V[0_nQOJ`01?ni[/ko
`KC=ol6dcOo1]<d3oial[`GoWGb^00CoWWf_oi]dY_nLMJKoW7FV0_nMMZL3oiigY`?oWWVX0_nONZT0
1?nQO:_oXGVVoj=kYonSNjL3ojAmZ@;oYGn[00?oZX>Zoj^5[?n[QJ`00on]R:l00on^Rk7o^IVgokVI
]`02okZL^P03om2ob_o?`<cogO_I00kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`002Oooool01P00003oooooooooooooool0<c<c00000080C4a<00T0000006IVIP000000
Ogmo0000002IVIWo00000;>c/ol000002P3<c<`02?l00000/k>c0;>c/`000000VIVI0000001oOgl0
00000P1VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI04806ATI@0000004oooo
o`0300000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool2od]SbP03ok>K__neW;ko]Ibn
00;od:R`0_oAZK03omZ]Z0;ofZbW0ooJZZH2omRXYP?odjFY0_oEZJ/00oo9X[7od[6hom:a^002on?>
``05olgIh_ncnlook?N/ooCc/ooeikT00_oag;X01Oo]e;_oj]6lodmYcOm?JLgoE6_=00;oOFJ^0_n1
J:d2ohEZ[0?oRVb[0_n>Kj/2oi=bZ`?oV7J[0_nLNJ/01OnQOJco^Jk>okV^c_ni[/ko`KC=00GoW7b_
0onMO:h00onJLjKoVgBVoi]dYP02oiaeYP?oWGJW0onNMjL2oiiiZ004oimjZOnPMjGoXGVVoj5iYP?o
Xg^W0_nTOJT00onUOj_oZX>ZojZ3ZP03oj^5[0;o[HR_0oniVKL01?njW;[od;o:om2ob_oMo]4?oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooo
oooooooo0P0c<c<02@000000C4a<0000001VIVH0000007moO`000000VIVI000000020;>c/`03o`00
003<c<`0c<c<00H0c<c<00So00000;>c/`2c/k<0000009VIVOl00000Ogmo00000080IVIV00@00000
04a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0l01TI6DL000001?ooool00`00003ooooooooo
o`0Dooooo`;o00007_ooool00ol005KoBf?:okFL_P02okFL_P04om2X/?oAZK3odJV`om6Y/0;ofZfX
0ooJ[:L00ooIZZOofZZVomRXYP03omRXYP04om>UZOoEZJ_oeJV[omFYZ`?od[6h0_oSc/<01?o`l<Co
k?N/oncg[?ohg:`2ooGF[P06oo;B[oo`d;7oj]6lonO?_OoUc[ooE6_=0_mML<h2oh5X[@?oQFZ/0_n:
K:/2ohi_Z`;oTg:[0onHMZ/00onLNJ_o[jO?okV^cP02okV^cP;oVgb`1?nLO:l00onILZKoVW>VoiYc
YP02oiYcYP;oVgBV0onLMJH2oiefY`?oWWNW00CoWWVXoimfY?nPMjGoX7NU0_nQNJH3oj=kY`;oY7fY
1?nZPjX2oj^5[003ojf8[onhU[Co^9Jd00;o^IVg00?odKg7om2ob_oMo]404Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?ooooooooooooooo`80<c<c
00L0000004a<C0000000IVIV0000001oOgl000000080VIVI00@000000;>c/`2c/k?o00001`3<c<`0
2?l00000/k>c0;>c/`000000VIVI0000001oOgl000000P1VIVH010000000C4a<00000?l0000203<c
<`030000000I6AT06ATI00H06ATI3`00000N01TI6@0300000?l00000000004h000001?ooool00`00
003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo0_m;HlX2okFL_PCodJV`00CodZV_omZ]
Z?oJ[:OofZbW0_oIZZL00ooJZZKof:RVomRXYP02omRXYP06om>UZOoEZJ_oeJV[omFYZooM]:ood[6h
0_oSc/<2oo3`a003oo[XZ?ojhjWon=b/00;omMJ^00Gol]:_oo3@/Oo_d;?okM2fonG>_`02on;;`@03
oee`c_mXMlkoJ7O>00?oM7k?0_n:K:/2ohi_Z`;oTg:[0_nHMZ/02?nUWm3o[jO?ojnWcon_Yloo^Jk>
oi]m/?nKO;3oV7:W0onHLZH2oiUbYPCoVW>V0onKM:H2oiaeYP;oWGJW0_nNMjL00onNM:?oWgJToimf
Y002oj1gY@?oXGVV0_nSNjL00onTOJWoZ82YojR0Z@03ojZ3ZP;oZhF/0onhU[@01?niVKOodKg7om6m
aooJolLCooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool000Wooooo00@0
0000oooooooooooooooo0P0c<c<01`000000C4a<0000001VIVH0000007moO`0000000P2IVIT01000
0000/k>c0;>c/ol000060<c<c009o`00002c/k<0/k>c0;>c/`000000VIVI0000001oOgl000000080
IVIV00<0000004a<C00000000`0c<c<00ol000006ATI01TI6@0401TI6H0000001?ooool00`00003o
ooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo0_loG/T00oneW;ko]YfookJM_`02om6Y/0;o
dZV_00?ofZfXomZ/YooJ[:L00_oIZZL5omRXYP?oeJV[0_oM]:l01?oB/KSohlk3oo3`a?o`l<@2oo[X
Z004ooSL[?oeeZkomMJ^oo;B[`;ol=2a00Gokm2cong@]_o[ckSojlnhon;;`@02om_3`@;oJ7O>0_md
O/l2oh67d0;oSHo@0onJV=03ojFOd004ojnWconGLjSoUg:WoiMbY`;oV7:W0onHLZH2oiUbYPGoVW>V
0_nKM:H2oiaeYP;oWGJW00?oWWNWoiidXonNM:<00_nOMZ@3oj1gY@;oXGVV0_nSNjL3ojR0Z@?oZX>Z
00?oZhF/okJB/_nhU[@00_nhU[@3om6ma`03om[oaooooooooooo01;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool203<c<`030000
001<C4`000000080IVIV0P00000209VIV@050000002c/k<0/k>c0;>c/ol00000103<c<`01Ol00000
/k>c0;>c/`2c/k<000000080VIVI00D0000007moO`000000IVIV0000000204a<C0050000000c<c<0
<c<c03<c<`0000001@0I6AV1000000Cooooo00<00000ooooooooool06?ooool00ol0003ooooooooo
o`0Kooooo`05ocmNbOnfWKoo]YfookJM_ooAZK000ooBZJl2omZ/Y`?ofJZW00?of:VWomRXY_oHZ:H0
0_oHZ:H00ooK[:OoeJV[omfd[`02omfd[`08onW7/_oeg;;omMbboo[W[?ojj:Son^>YooSL[?oeeZh2
oo;B[`04oo3@/Oo_d;?okM2fong@]P;ojlnh00Coi/Vjom_3`Oo@]Kood;Fo0_neV;T2ogAnc`;oPHO@
0_n=Sm03oiZHd004ojFOd?nGLjWoUg>XoiMcZ0;oUg:W0onHLZL2oiQbYP?oVG:V1?nJLjH2oi]dYP;o
W7FV00?oWGJWoiecXonNM:<00_nNM:<3oimfY0;oX7NU0_nQNJH00onSNjOoYgjWojMnY`02ojR0Z@?o
ZX>Z0onfT[82okRF]003om6kaOoA_LOof_o701Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`002Oooool01000003oooooooooooooool203<c<`0:0000001<C4`0C4a<0000
001VIVH0000007moO`000000VIVI000000<0/k>c00?o00000<c<c03<c<`00P3<c<`02Ol00000/k>c
0;>c/`2c/k<0000009VIV@000000Ogmo0000000206IVIP03o`00001<C4`0000000<0<c<c00<00000
01TI6@0I6AT00`0I6AV2000000Cooooo00<00000ooooooooool06Oooool2o`0001_ooooo0_loG/T2
okJM_`CodZV_00?odZV^omZ/YooIZZL00_oIZZL00ooHZJOof:RVomRXYP02omRXYP03om^/YooEZJ_o
gKB_00;ogKB_00CojLNbooGL/_oeg;;on^RX0_ojhjT01oohg:comMJ^oo;B[oobdZool=2aono@/oo]
d;H00oo[ckP01OoVbK[od;Foom2e_oo@]Koo`Z>i00;o]IRi00?oZXnioh67d?n1Qm000_n=Sm02oiZH
d003oiMeZ_nGLjWoUg>Y00;oUg>X0_nGLZL3oiQbY`?oV7:V0_nILZH4oiYcYP;oVgBV00CoW7FVoi]b
X_nMLj?oWG>S0onNM:<3oimfY0;oX7NU0_nQNJH3ojMnY`?oZ82Y0_nZPjX3okJB/P04okRF]?oA^lGo
dK_5omCm^aOooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`002Oooool0
1000003oooooooooooooool203<c<`0:0000001<C4`0C4a<0000001VIVH0000007moO`000000VIVI
000000@0/k>c1?l000030;>c/`060000002IVIT0VIVI0000001oOgl000000P1VIVH00`000000C4a<
0000000303<c<`030000000I6AT06ATI00806ATIP`000004ooooo`0300000?oooooooooo01_ooooo
00?o0000ooooooooool06Oooool01?lbElSo]YfookNN_ongW[l2om:Y[`;odZV^00?ofZbWomVZYooI
ZZL00ooHZJL2omRXYP;ofjbW0ooM]:l02?oYak;omMbbooGL/_ojijcon^RXoo_LY?oif:KommFX0_oe
djX01?oddZcolm>^ono@/oo]d;H2on_?^0;oi/Vj00Kog;jkom2e_oo2XkWo`Z>iokFH^OnYQk42oj5o
[`;oVgZ^0_nHMj`2oiMeZP;oUg>Y0onGLjP2oiMbY`;oV7:W0onHLZH2oiUbYPCoVW>V00CoVgBVoiYa
X_nKLZ;oVg:R0onMLj<3oiidX`;oWgJT0_nPMjD00onQNJKoYGbVojElYP02ojMnY`?oZ82Y00?oZX>Z
okB@/?ndT;000_nfT[800oo@^L?odK_5omCm^`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool000Wooooo00@00000oooooooooooooooo0P0c<c<02P000000C4a<04a<C000
0000IVIV0000001oOgl0000009VIV@00000;0;>c/`060000002IVIT0VIVI0000001oOgl000000P1V
IVH00`000000C4a<0000000303<c<`030000000I6AT06ATI00806ATIP`000004ooooo`0300000?oo
oooooooo01cooooo00?o0000ooooooooool06?ooool00oo;IP3o]ijookNN_`02okNN_`03om:Y[ooB
ZJkodZV^00?ofJZW0ooHZJL2omRXYP;ofjbW00CohKFZomfd[ooM]:oojLNb0_oeg;801OojijconmbT
oo_LY?oif:KommFX00;omM>Z00?om=:/oo?C[_obe;000_oadk<01?o[ckSoi/Vjombn^ooL_[/3ol:S
^@;oZHNa0onQOjl2oi]j[P;oV7N/0_nGMJX2oiMcZ@;oUg>X0_nGLZL3oiQbY`;oV7:V0_nILZH01?nJ
LjKoV6nRoiU`X_nIL:82oiYaXP?oVg:R0_nMLj<3oiidX`;oWgJT00?oX7NUojAjYOnUO:H00_nUO:H3
ojMnY`;oZ82Y0ondT;001?nfT[;od;W3om2i`oo9n:dKooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo0`0c<c<00`000000C4a<0000
000206IVIP050000001oOgl0000009VIV@0000002@2c/k<010000000VIVI09VIV@00000207moO`03
0000001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6AV4000000Cooooo00<00000oooo
ooooool07Oooool00ol0003oooooooooo`0Hooooo`04oc9Gb?ngW[oo]ijookNN_`?odZV^00?odZR^
omVZYooIZZL01?oHZJL00ooHZ:KofjbWom^/Y`02on6eZP08omfd[ooYak;omMbbooGL/_okgjConmbT
ooWHY_ogeJP2ooGCZP04ooCB[?ocdjkolm>^oo;D/0;olM>c00OokM2gombn^ooL_[_og;jkoln]^?o2
XkWo]96b00?oZHNa0_nQOjl2oi]j[P;oV7N/0_nGMJX2oiMcZ@;oUg>X0_nGLZL3oiQbY`;oV7:V00Co
VG:VoiM^X_nHKj;oV6nR0_nIL:82oiYaXP?oVg:R0_nMLj<3oiidX`;oWgJT0_nTNZD3ojElYP?oYgjW
00?oZ82Yok>=[_ndT;000_ndT;03om2i`acooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`002Oooool01000003oooooooooooooool303<c<`030000001<C4`000000080IVIV
00<0000007moO`0000000P2IVIT00`000000/k>c0;>c/`060;>c/`040000002IVIT0VIVI00000080
Ogmo00?o000006IVIP0000000P1<C4`010000000<c<c03<c<`00000401TI6H@000001?ooool00`00
003oooooooooo`0Nooooo`;o00006?ooool00oo;IP3o]ijookNN_`02okNN_`04om:Y[_oBZ:kodZR^
om:X[PGof:VW0_oK[:L3on6eZP08on_4[?oedj_omM>[oo[MYookgjConmbTooWHY_ogeJP2ooGCZP03
ooCB[?ocdjkol]B`00?olM>c00?okM2gonG7^OoL_[/00_o?[KP3okBA/P;oZHNa0_nQOjl2oi]j[P;o
V7N/0_nGMJX2oiMcZ@;oUg>X00?oUg:WoiA]XonEKJ800_nEKJ82oiI^XP;oUfjR0_nHKj82oiU`XP;o
VW6R0onKLZ83oiecX`;oWWBS00CoWgJToj9hY?nTNZGoY7ZU1?nUO:H2ojMnY`?o/hf^0_ndT;000oo@
]l;od;W3ooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool000Wo
oooo00@00000oooooooooooooooo0`0c<c<00`000000C4a<0000000206IVIP030000001oOgl00000
00<0VIVI00?o00000;>c/`2c/k<01@2c/k<01P000000VIVI09VIV@000000Ogmo00000080IVIV00@0
000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6H@000001?ooool00`00003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01Kooooo1?ngW[l01?oBZJkodZR^om:X[_oBZ:h5omRYY`;o
fjbW0ooQ]JX01Oo[a:comM>[ooGCZoojgJOonmbT00;onMRV00KommFXooGCZ_oddZcom=:/oo?C[_ob
e;02oo7C/`03ong@]ooUakWoiLNi00?ocjfh0ondTK82ojV7/@04oj5o[onIMZ[oUG:XoiEbZ0;oTfnW
0_nCKZD2oi=]Y0CoU6fS0onEKJ82oiI^XP;oUfjR0_nHKj82oiU`XP?oVW6R0_nKLZ83oiecX`04oiid
XonQMZ?oXWRToj9hY0?oY7ZU0onUO:H00onWOZOo/HZ]ok>=[P02ok>=[P04okB@/?o@]l;od;O2ok__
Vaoooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool01@00003o
oooooooooooooooo00000080<c<c00<0000004a<C00000000P1VIVH00`000000Ogmo0000000309VI
V@030000002c/k<0/k>c00@0/k>c00L0000009VIV@2IVIT0VIVI0000001oOgl000000080IVIV00@0
000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6H@000001?ooool00`00003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01Gooooo00Co5DC1okNN_ongW[oo]ijo1?oBZ:h00ooAYjko
f:VWomRYY`02omRYY`05om^^ZOoK[:OohKFZon6eZ_o[a:`00_oedj/01OojgJOonmnToo_LY?oif:Ko
mmFX00;omM>Z00Gom=:/oo?C[_ocdjkol]B`oo7C/`02ong@]`;oiLNi00Cof;Rioln]^?o0W;Co`9bd
0_ndTK801?nYQk7oX7b/oiUfZ_nIMZX2oiEbZ0;oTfnW0_nCKZD2oi=]Y0GoU6fS0_nEKJ82oiI^XP;o
UfjR0onHKj82oiU`XP;oVW6R0onKLZ82oiecX`;oXGJS0onRN:@2ojAjY@;oYGbV00Co[hN[ok6:[Ona
RZgo/HZ]0_ncSJh3om2g`R7ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`002Oooool01@00003ooooooooooooooooo00000080<c<c00H0000004a<C01<C4`0000006IVIP00
000207moO`050000002IVIT0VIVI09VIV@000000102c/k<01Ol00000VIVI09VIV@2IVIT000000080
Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000401TI6HD000001?ooool00`00
003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?oe6l0oaE4`OngW[l00_nfWKl2om:X
[P;odJN^0ooHZJL2om^^Z@?ohKFZ00WojlB/ooGCZooedj_on]fWoo_OY?okg:Con]bWooSIZOogf:/0
0_ogfJd00ooffZoom]baooCM]@02oo7J^@04on[B_?oUakWof;RiomRh^@?o`9bd00Co]96bojV5[_nP
O:coX7b/0_nIMZX2oiEbZ0;oTfnW0_nCKZD2oi=]Y0GoU6fS0_nEKJ82oiI^XP?oUfjR0_nHKj82oiU`
XP;oVW6R0onKLZ801?nMLj?oWgBRoj5fXonQMZ<3oj9hY0;oY7ZU00?oYGbVojn7Zon_Qj/00onaRZd0
1?ncSJkockG1olne`Oo@]l8Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_oo
ool000Wooooo00D00000ooooooooooooooooo`00000203<c<`060000001<C4`0C4a<0000001VIVH0
00000P1oOgl010000000VIVI09VIV@2IVIT200000080/k>c0P00000309VIV@060000001oOgl0Ogmo
0000001VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6HD000001?ooool00`00003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01Cooooo00Go5DC1okJM_onfWKoo]Yfoom:X[P03om6W[P?o
f:VW0_oK[ZT2on6eZP;ojlB/00ComM>[oo[MYoojgJOonmbT0_ojg:L01oohfJWommR[ooOI[OogfJgo
m]Z_ooKL/OodgKD00_oaf[T01OoZd[cof;RiomRh^OoH^;WobJJf00;o`9bd0_nYQJh3oj1l[0;oVGJZ
0_nELZP2oi=_Y`;oTfjU0_nCKJ@4oiA]X`?oUFfR0_nFKZ82oiM^XP;oV6nR0_nIL:82oiYaXP;oVg:R
00?oWG>RoimdX_nOM:800onQMZ<2oj9hY0;oY7ZU1?n_Qj/2ok6:[@?ockG19?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0500000?ooooooooooooooool00000
0P0c<c<01P000000C4a<04a<C0000000IVIV00000080Ogmo00<0000009VIV@2IVIT00`2IVIT20000
00D0VIVI00H0000007moO`1oOgl0000006IVIP00000204a<C0040000000c<c<0<c<c000000@06ATI
Q@000004ooooo`0300000?oooooooooo02Cooooo0_l0000Dooooo`04o`0f^_lEA<7o]YfookJM_`Co
dJN^00?odJR_omRYYooK[ZT00_oK[ZT00ooQ]Z_ohKFZon_4[002ooGCZ`06oo[MYookgjConmjVoo[L
YoohfJWommR[0_ogfJd00ooffZoom]baooCM]@02oo7J^@;oj]:l00Kog/:momRh^Oo9Y[KobJJfol2L
]?ncSk03ojV5[P;oX7b/0_nIMZX2oiEbZ0;oTfnW0_nCKZD2oi=]Y0CoU6fS0onEKJ82oiI^XP;oUfjR
0_nHKj82oiU`XP03oiYaX_nLLJ;oWG>R00;oWG>R0_nOM:83oj5fX`;oXWRT00?oY7ZUojf5Z_n]QJX0
0on_Qj/2ok6:[@03olfb`?o?]L7ooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`002Oooool01@00003ooooooooooooooooo000000<0<c<c00<0000004a<C0000000
0P1VIVH010000000Ogmo07moO`00000:09VIV@040000001oOgl0Ogmo00000080IVIV00<0000004a<
C00000000`0c<c<00`0000006ATI01TI6@0201TI6HD000001?ooool00`00003oooooooooo`0Voooo
o`03o`000?oooooooooo01;ooooo00Co03JjokJM_ondW<3o]9c00_oAYjh2om6X[`03omRYYooK[ZWo
fjjY00;ohKJ[0_o[a:d01?oddZgonMbYooWLZOokgjH2oo[LY`03ooSIZOogf:_ommV]00;om]Z_00?o
m]baooCM]Ooaf[T00_oZd[`2omk2_@?obJJf0oncSk02ojV5[P;oX7b/0_nIMZX2oiEbZ0;oTfnW0_nC
KZD2oi=]Y0CoU6fS0onEKJ82oiI^XP;oUfjR0_nHKj801?nIL:;oVW2QoiaaX_nLLJ83oiecXP?oWgBR
0_nQMZ<2oj9hY0?o[HFZ0on_Qj/01?naRZgocK;0olfb`?nBdW<Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool000Wooooo00D00000ooooooooooooooooo`00000303<c<`03
0000001<C4`000000080IVIV00@0000007moO`1oOgl000002@2IVIT01@000000Ogmo07moO`1oOgl0
00000080IVIV00<0000004a<C00000000`0c<c<00`0000006ATI01TI6@0201TI6HD000001?ooool0
0`00003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o03JjokBL`?ndW<000_ndW<00
0ooAYjkodJR_om6X[`03om^^Z@;ohKJ[0_o[a:d01OoddZgonMbYooWLZOokgZKon]bW00;on=VY00Ko
mmR[ooOI[OoffZoom]Z_oo7``_o^kLL2onSTc006on[B_?oN`[gog/:moln`^oo9Y[Ko_9Vc0oncSk02
ojV5[P04oj1l[?nHMjcoTW6Yoi9aZ@;oSffW0_nCKjL2oi=^Y@;oTffT1OnDKJ<2oiE]XP;oUVjR0_nG
KZ801?nHKj;oVFnQoiY`XOnJL:43oiaaXP;oWG>R0onOM:82oj5fX`03oj9hY?n[PZWoZh:Y00;o[HFZ
0on_Qj/3olfb`2Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Ooo
ool01@00003ooooooooooooooooo000000<0<c<c00H0000004a<C01<C4co000006IVIP00000307mo
O`030000002IVIT0VIVI00H0VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP030000001<C4`0
000000<0<c<c00<0000001TI6@0I6AT00P0I6AV5000000Cooooo00<00000ooooooooool0:?ooool0
0ol0003oooooooooo`0Aooooo`04o`0f^_ndW<3o]9c0ok:M``?odJR_00Coe:faom^^ZOoK[ZWohKJ[
0_o[a:d02OoddZgonMbYooWLZOokgjKonmjVoo[LYoohfJWommR[ooGZ^@02ooC]^`03oo?___oal<;o
k^g700;oj>C<00Cog=3=omk2_Oo?/;_ock2k0onlVK<2ok>?/004ojV5[_nQOjkoV7N/oiQg[0;oTW6Y
0_n?KJL2ohi[YP;oSf^U0_n@JZ@3oi5[X`;oU6fS00CoUFfRoiA/X_nEKJ;oUFfR0_nGKZ42oiU_X@?o
VW2Q0_nLLJ83oiecXP;oWgBR0_nQMZ<3oj^2Z@?o[HFZ00Co[hN[ol^`_oo;/;oocK;0:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0500000?oooooooooooooo
ool000000`0c<c<010000000C4a<04a<C000000206IVIP050000001oOgl0Ogmo07moO`0000001P2I
VIT00`000000Ogmo07moO`0207moO`060000001VIVH0IVIV0000001<C4`000000`0c<c<00`000000
6ATI01TI6@0201TI6HD000001?ooool00`00003oooooooooo`0Yooooo`;o00004_ooool01OndW<3o
/Yg3ok:M`onbWL?odJR_00?oe:fa0_oQ]Z/2on_4[@05ooCB[Ooig:WonMbYoo_OY_ojg:L00_ogjKD0
1_ofjKOomNZiooC]^oodkK_olO32onk]a`;oj>C<0_oLd<d3oln`^`?o_9Vc00Co/hn`ojZ8/OnQOjko
XGn^0_nHMj`2oi9aZ@;oSffW0_n>JjH2ohm[Y@;oT6ZT0onAJj<2oi9[XP;oU6bR0_nEKJ82oiM^X@;o
VFnQ0onJL:42oiaaXP?oWG>R0_nOM:800onQMZ?oZ82Xoj^2Z@02oj^2Z@?o[HFZ0oo;/;l/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00H00000oooooooooooo
oooo01TI6Ol0000203<c<`040000001<C4`0C4a<00000080IVIV00D0000007moO`1oOgl0Ogmo0000
000509VIV@03o`00001oOgl0Ogmo0080Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000<c<c
03<c<`00003o000000<06ATIQP000004ooooo`0300000?oooooooooo02_ooooo00?o0000oooooooo
ool03oooool4ok:M``04om6X[ooD[K7oe:faomB]/@;ohKJ[00OojlB]ooCB[OoddZgonMbYoo_OY_ok
gZKomn^c00;omnVe00ComNZiooC]^oodkK_olnnn0_ndmo02ok[Ql`04omc@cOo<^LSoc;W8oln`^`;o
`:6i0_nlVK<2ojZ8/@?oXGn^0_nHMj`2oi9aZ@03ohm]Yon>JjKoSV^V00?oSf^U0_n@JZ@2oi5[X`;o
TV^R0_nDK:82oiE]XP;oUfjQ0_nIKj43oiY`X@;oW76R0onMLj82oimdXP;oZ82X1?n[PZT2ojf5ZP03
olR]_oo;/;oooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00
2Oooool01P00003oooooooooooooool06ATIo`000080<c<c00@0000004a<C01<C4`000000P1VIVH0
0ol00000Ogmo07moO`0207moO`8000000P2IVIT2000000@0Ogmo00@0000006IVIP1VIVKo00000P1<
C4`010000000<c<c03<c<`00000401TI6HH000001?ooool00`00003oooooooooo`0/ooooo`03o`00
0?oooooooooo00oooooo0onbWL<4omB]/@04om^h]_o[a:gojlB]ooCB[@;onMbY00Oom^jdooO]/oog
jKGomnVeooKY]ooej[WoUo3500;ooooo00?o02:YobJ7jonjhO<00_na_nD00oo<^LSo_:O4ol2Q^@02
ol2Q^@03okbI/onbTKGoZXRa00;oZXRa0_nQOjh2oiQg[0;oTW6Y0_n?KJL2ohi[YP;oSf^U0_n@JZ@2
oi5[X`;oTV^R0_nDK:82oiE]XP;oUfjQ0onIKj42oiY`X@?oW76R0_nMLj800onOM:;oYWfXojR0Z002
ojR0Z0?oZh:Y00Co[HFZolR]_oo8[Koo0000;_ooool01Ol0003ooooooooooooooooo000000_ooooo
0009ooooo`0600000?ooooooooooooooo`0I6AWo00000P0c<c<010000000C4a<04a<C000000206IV
IP030000001oOgl0Ogmo00@0Ogmo0P00000607moO`030000001VIVH0000000<0C4a<00@0000003<c
<`0c<c<00000100I6AV6000000Cooooo00<00000ooooooooool0;Oooool00ol0003oooooooooo`0>
ooooo`04o`00T?nbWL?o/J?:ok6SbP;oe:fa0_oK^;H01?oUbK[ol=bloo3L_?oej[T2ooK^]004ooO[
/oogjKGoYOK9oigbaPGooooo00Co001iodN1iOna_nGoXjKH0onlYl@00oo0XKWo]YVkok:A]@02ok:A
]@;oZXRa0_nQOjh2oiQg[0;oTW6Y0_n?KJL2ohi[YP;oSf^U0_n@JZ@2oi5[X`;oTV^R0onDK:82oiE]
XP;oUfjQ0_nIKj42oiY`X@?oW76R00CoWG>Roj=kYonVOJSoYWfX0onXP:P2oj^2Z@04olFZ_oo8[Koo
b:foolR]_c3ooooo00Co0000oooooooooooo00002oooool000Wooooo00H00000oooooooooooooooo
01TI6Ol0000303<c<`040000001<C4`0C4a<00000080IVIV00<0000007moO`1oOgl02P1oOgl01?l0
0000IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6AV5000000Cooooo00<0
0000ooooooooool0;_ooool2o`0000oooooo0onaXlX01OoD[K7ofkRfom^h]_oK^;KoiLVj00;ol=bl
00?omNZiooK^]?ogkK<00_nUm/T8ooooo`;o?gCM0_nSY]P00onlYlCo/9k5okJI^`02okJI^`;o/Y6e
00CoZXRaoj>:^_nIOkKoVGnf0_n?M[<2ohU`/0;oSffW0_n>JjH2ohm[Y@;oT6ZT0onAJj<2oi9[XP;o
U6bR0_nEKJ82oiM^X@;oVFnQ0onJL:42oiaaXP;oXg^W0onVOJP2ojR0Z005oj^2ZOo5Z[ooaJZoolFZ
_oo8[Kl0<_ooool00ol0003oooooo`00000;ooooo`002Oooool01P00003oooooooooooooool06ATI
o`0000<0<c<c00@0000004a<C01<C4`000000P1VIVH00`000000Ogmo07moO`0907moO`050000001V
IVH0IVIV06IVIP0000000P1<C4`01@000000<c<c03<c<`0c<c<0000000D06ATIQ@000004ooooo`03
00000?oooooooooo033ooooo00?o0000ooooooooool03?ooool00onT:`3o/J?:ok:cf@03om^h]P06
onG9^_o`g;col=blooGZ^Oofk[CoNmna3?ooool00oloM=goTiWFoi>IeP03ok2Na@;o]YVk00Co/Y6e
ojbE__nSR[[oXhZj0_nIOkH2ohmf/`;oRG2`0_n7K:h2ohM[[0?oSf^U0_n@JZ@2oi5[X`;oTV^R0_nD
K:82oiE]XP;oUfjQ0_nIKj43oiY`X@04oiaaX_nQNJOoXg^Woj=kY`?oYWfX0_nXP:P01?o2YkooaJZo
olFZ_oo5Z[lcooooo`03o`000?oooooo000000_ooooo0009ooooo`0600000?ooooooooooooooo`0I
6AWo00000`0c<c<010000000C4a<04a<C000000306IVIP030000001oOgl0Ogmo00P0Ogmo00D00000
06IVIP1VIVH0IVIV0000000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6AV5000000Cooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`?o/[?I00CofkRfonG9^_oUbK[o
l=bl0_oej[T00omkgk7oooooooooo`0<ooooo`03o`EMe_nCVMKoTiWF00;o/9k500?o]YVkojnNa_n/
UKh00_n/UKh2oj>:^P;oVGnf0_n?M[<01On9L;3oQfb^ohM/[_n7K:koQf^/00?oR6^[0_n@JZ@2oi5[
X`;oTV^R0_nDK:82oiE]XP;oUfjQ0_nIKj42oiY`X@03oiigYonQNJOoXGVW00?oXg^W0_nVOJP01OnX
P:So`ZNool:W_oo2YkooaJZo03Gooooo00?o0000ooooool000002_ooool000Wooooo00H00000oooo
oooooooooooo01TI6Ol0000303<c<`040000001<C4`0C4a<000000@0IVIV00<0000007moO`1oOgl0
1`1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI
6HD000001?ooool00`00003oooooooooo`0booooo`03o`000?oooooooooo00cooooo00Oo/[?Iok;A
l?nbdO3o/]7`onG9^_o`g;coK]Zb013ooooo00Go0000ogRHiOmhV>Go/9k5ojBSe003ojnNaP;o[9Fn
0_nSR[X2oiUo]P;oSgJc0_n9L;02ohM/[P;oQf^/0_n8Jj/2oh][Z@;oSFfX0_nBJj82oiA/XP;oUFfR
00CoUfjQoiUcYonKMJOoVgFW0onNMjL3oj5iY`;oXg^W0_nVOJP4ol:W_cOooooo0_l0000:ooooo`00
2Oooool01000003oooooooooooooool201TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`00`00
0000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00D0Ogmo00D0000006IVIP1VIVH0IVIV00000003
04a<C0050000000c<c<0<c<c03<c<`0000001P0I6AV4000000Cooooo00<00000ooooooooool0<ooo
ool2o`0000kooooo00?o/]7`oj?_moooool04_ooool01?l0003oooooogRHiOmhV>D2ojBSe0;o[ik6
00?o[9Fnoj>eiOnS]ND00_nGY=h00on5TmWoLh?Dog>3e002ohU`/0;oQfb^0_n7Jj`2ohQ[Z`;oRf^Y
0_n=KJP2oi1^Z0;oTfnW0_nFLJL2oiUcY`?oVgFW0_nNMjL3oj5iY`;oXg^W00?oYWfXokfT_onmY;l0
0_o2Yklgooooo`?o00002_ooool000Wooooo00@00000oooooooooooooooo0P0I6AT01Ol00000<c<c
03<c<`0c<c<000000080C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0407moO`80
00000`1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT0100I6AV40000
00Cooooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo0_mf`Oh2oj73l@;oXkGU0_nGY=h01?n5TmWoLh?Dog>3e?mWN=03ohM/[P03ohM[[?n8Jj_o
R6^[00;oRf^Y0_n=KJP2oi1^Z0;oTfnW0_nFLJL3oiUcY`;oVgFW0onNMjL2oj5iY`;oXg^W0onmY;l0
0oo2Ykooooooooooo`0booooo`Co00003Oooool000Wooooo00@00000oooooooooooooooo0P0I6AT0
1Ol00000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0207moO`030000001VIVH0IVIV00<0IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`030000
000I6AT06ATI00@06ATI00?o0000000000000000P@000004ooooo`0300000?oooooooooo03Kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`;oLh?D00?oIgS@of=bcOmSL/d0
0_n7Jj`2ohQ[Z`;oRf^Y00?oSFfXoi1^Z?n@KZP00_nCKjL2oiIaY`?oVG>W0_nKMJL3oiigY`;oXGVW
00?oXg^WokVQ`?niXL000_nmY;lbooooo`?o00004Oooool000Wooooo00@00000oooooooooooooooo
0P0I6AT01Ol00000<c<c03<c<`0c<c<0000000<0C4a<00<0000006IVIP1VIVH00`1VIVH01@000000
Ogmo07moO`1oOgl0000000D0IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`030000000I6AT0
6ATI00L06ATIP@000004ooooo`0300000?oooooooooo03Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Aooooo`03of=bcOmVL/_oIW;;00;oR6^[0_n;JjT2ohe]Z0;oT6jX0_nCKjL2
oiIaY`;oVG>W0onKMJL2oiigY`03oj5iYoncWL7o^J7000;o^J7000?o_JBoooooooooool0;Oooool4
o`0001Cooooo0009ooooo`0400000?ooooooooooooooo`806ATI00Go000003<c<`0c<c<0<c<c0000
000304a<C003o`00001VIVH0IVIV00@0IVIV0`00000606IVIP050000001<C4`0C4a<04a<C0000000
100c<c<00ol000006ATI01TI6@0:01TI6@T00000:`0I6AU9000000Cooooo00<00000ooooooooool0
>?ooool2o`0001kooooo00?o0000ooooooooool04_ooool01?mSL/goIW;;ofadbOm/M<T2oh][Z@;o
SFfX0_n@KZP2oi=_Y`;oUW6W0onILjL2oi]eY`03oiigYon^VL;o/ig100;o/ig100?o^J70oooooooo
ool0:oooool4o`0001Sooooo0009ooooo`0400000?ooooooooooooooo`806ATI00Go000003<c<`0c
<c<0<c<c0000000304a<C0030000001VIVH0IVIV00d0IVIV00D0000004a<C01<C4`0C4a<00000005
03<c<`030000000I6AT06ATI04/06ATI>`000004ooooo`0300000?oooooooooo03[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Cooooo`;oIW;;00?oK7C9ogAhb?mdN<P00_n=KJP2
oi1^Z0;oTfnW0_nFLJL3oiUcY`03oi]eYonWUL?o[YW200;o[YW20_ncWL4Zooooo`Co00007?ooool0
00Wooooo00@00000oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`0203<c<`040000001<C4`0
C4a<000000l0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I
6AT06ATI05406ATI=0000004ooooo`0300000?oooooooooo03_ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Eooooo`;oK7C900?oM7S8ogemb?mmOLP00_n7P/L2oi=_Y`;oUW6W0_nI
LjL01?nPT<CoYiG3ojNE`onWUL<2ojjI`P03ok>M`Ooooooooooo02Kooooo0ol0000Pooooo`002Ooo
ool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0
C4a<0000000>06IVIP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0@01TI6B/00000700I6AT]000000Cooooo00<00000ooooooooool0??ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo0_mdN<P2ogemb003ohN2aon@QlKoT8O600;o
V8c51?nPT<@2ojNE``03ojjI`_oooooooooo02Cooooo1?l0000Sooooo`002Oooool01000003ooooo
ooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000>06IV
IP030000001<C4`0C4a<0080C4a<0P00000603<c<`03o`0000000000000000l00000:`0c<c<:0000
01D06ATI00<00000o`00000000009`000004ooooo`0300000?oooooooooo03gooooo0_l0000Ioooo
o`03o`000?oooooooooo01Wooooo0_mmOLP2ohN2a`;oT8O60_nHS<D3oj2@a003ojNE`ooooooooooo
02;ooooo1?l0000Wooooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c
0080<c<c00D0000004a<C01<C4`0C4a<0000000>06IVIP030000001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<0800c<c<E000001D0<c<c1`00000B01TI6BH000001?ooool00`00003oooooooooo`0o
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool2oi27aP;oV8c50_nPT<@R
ooooo`Co0000:oooool000Wooooo00@00000oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`02
03<c<`050000001<C4`0C4a<04a<C00000003`1VIVH00`000000C4a<04a<C00404a<C0<000004@0c
<c<>000001D0C4a<3P00000>03<c<`@000004@0I6ATS000000Cooooo00<00000ooooooooool0@?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo0ol0000_ooooo`002Oooool0
1000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<
0000000?06IVIP03o`0000000000000000L0C4a<00?o00000000000000001`0000000ol000000000
00000004000000h0C4a<5@00000>04a<C0<0000000Co000000000000000000002`0c<c<01000003o
000000000000000A01TI6Al000001?ooool00`00003oooooooooo`11ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0?oooool4o`0003;ooooo0009ooooo`0400000?oooooooooooooo
o`806ATI00?o000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000180IVIV00<00000
04a<C01<C4`05@1<C4`>000001D0IVIV2`00000:04a<C0@000002`0c<c<3000001806ATI6`000004
ooooo`0300000?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000f
ooooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c0080<c<c00D00000
04a<C01<C4`0C4a<0000000706IVIP@00000201VIVH3000000d0C4a<1`00000:06IVIQd000001`1V
IVH7000000L0C4a<0`00000;03<c<`<000004P0I6ATH000000Cooooo00<00000ooooooooool0A?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0000jooooo`002Oooool0
1P00003oooooooooooooool06ATIo`0000@0<c<c00D0000004a<C01<C4`0C4a<0000000606IVIP03
o`0000000000Ogmo00<0Ogmo00<00000o`00001VIVH0201VIVH=000000L0IVIV2P00000M07moO`H0
0000201VIVH3000000L0C4a<100000000ol00000<c<c03<c<`0703<c<`<000004@0I6ATF000000Co
oooo00<00000ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?o
oooo1?l0000nooooo`002Oooool01P00003oooooooooooooool06ATIo`0000@0<c<c00D0000004a<
C01<C4`0C4a<0000000606IVIP03o`00001oOgl0Ogmo00D0Ogmo0P00000D06IVIPD0000000?o0000
0000001oOgl01P1oOglP000000H0Ogmo00?o00000000000000001@00000306IVIPH000001@1<C4`3
000000X0<c<c00<00000o`00000000003`0I6ATE000000Cooooo00<00000ooooooooool0A_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol00012ooooo`002Oooool01P00
003oooooooooooooool06ATIo`0000@0<c<c00D0000004a<C01<C4`0C4a<o`00000606IVIP030000
001oOgl0Ogmo00L0Ogmo0`00000=06IVIP@000001`1oOgl7000000L0VIVI4_l0000709VIV@L00000
1`1oOgl3000000H0IVIV0P00000604a<C0@000002@0c<c<2000000l06ATI4`000004ooooo`030000
0?oooooooooo04Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000
AOooool000Wooooo00D00000ooooooooooooooooo`00000403<c<`030000001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0;07moO`d000001`1oOgl4000000L0VIVI
1ol0000B0;>c/`Oo00001`2IVIT3000000L0Ogmo0`00000506IVIP<000001`1<C4`2000000T0<c<c
00<0000001TI6@0I6AT03@0I6ATB000000Cooooo00<00000ooooooooool0B?ooool2o`0000gooooo
00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0500000?ooooooooooooooool00000
100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl0
6@1oOgl200000003o`00000000000000008000009?l000070;>c/`Oo00000`2IVIT01000003o0000
00000000000607moO`03o`00001VIVH0IVIV00D0IVIV0P00000704a<C0030000000c<c<0<c<c00L0
<c<c00?o000001TI6@0I6AT03@0I6ATA000000Cooooo00<00000ooooooooool0B_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`002Oooool01@00003ooooo
oooooooooooo000000@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo01H0Ogmo0`00000509VIV@;o00001`2c/k<4o`0001T0c<c<1ol000070;>c/`;o
00001@2IVIT2000000D0Ogmo0P00000706IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c
<c<01`0c<c<00`0000006ATI01TI6@0<01TI6A4000001?ooool00`00003oooooooooo`1;ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0009ooooo`050000
0?ooooooooooooooool00000100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080
IVIV00<0000007moO`1oOgl04P1oOgl4000000L0VIVI00?o00000;>c/`2c/k<01@2c/k<2o`0000P0
c<c<5@0000070<c<c0?o00001P2c/k<2o`0000D0VIVI0P00000507moO`8000001P1VIVH00`000000
C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT@000000Co
oooo00<00000ooooooooool0C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01go
oooo1?l0001Dooooo`002Oooool01@00003ooooooooooooooooo000000@0<c<c00D0000004a<C01<
C4`0C4a<0000000406IVIP030000001oOgl0Ogmo0140Ogmo0P00000:09VIV@03o`00002c/k<0/k>c
00D0/k>c00?o00000<c<c03<c<`01@3<c<`3000001D0i^KV0P0000080<c<c0;o00001P2c/k<00ol0
0000VIVI09VIV@0409VIV@03o`00001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH0101VIVH00ol0
0000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03@0I6AT?0000
00Cooooo00<00000ooooooooool0COooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`00
05Sooooo0009ooooo`0400000?ooooooooooooooo`D0<c<c00D0000004a<C01<C4`0C4a<00000004
06IVIP030000001oOgl0Ogmo00h0Ogmo0`0000000ol00000VIVI09VIV@0809VIV@03o`00002c/k<0
/k>c00@0/k>c0_l000070<c<c08000006@3Vi^H3000000L0c<c<00?o00000;>c/`2c/k<0102c/k<0
0ol00000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03@0I6AT>
000000Cooooo00<00000ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Gooooo1?l0001Looooo`002Oooool01000003oooooooooooooool503<c<`050000001<C4`0
C4a<04a<C0000000101VIVH00`000000Ogmo07moO`0=07moO`030000002IVIT0VIVI00/0VIVI00?o
00000;>c/`2c/k<0102c/k<00ol00000c<c<0<c<c0050<c<c08000007@3Vi^H00`000000c<c<0<c<
c0050<c<c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0703<c<`030000000I6AT06ATI00d06ATI3P000004ooooo`0300000?oooooooooo053ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@00000
oooooooooooooooo1@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0;09VIV@03o`00002c/k<0/k>c00@0/k>c00?o
00000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP0>0>KViP;o00003P3Vi^H00`000000c<c<0<c<
c0050<c<c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0703<c<`030000000I6AT06ATI00`06ATI3P000004ooooo`0300000?oooooooooo057ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000Hoooool000Wooooo00@00000
oooooooooooooooo1@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl02P1oOgl3000000/0VIVI00?o00000;>c/`2c/k<0102c/k<2o`0000H0c<c<0P00
000>0>KViPCo00003`3Vi^H00`000000c<c<0<c<c0040<c<c0;o00001P2c/k<00ol00000VIVI09VI
V@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<
C00504a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT>000000Cooooo00<0
0000ooooooooool0D_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo0009
ooooo`0500000?ooooooooooooooool00000100c<c<00`000000C4a<04a<C00204a<C003o`00001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl0301oOgl2000000X0VIVI00?o00000;>c/`2c/k<01@2c
/k<00ol00000c<c<0<c<c0050<c<c08000007P3Vi^H00`000000c<c<0<c<c0040<c<c003o`00002c
/k<0/k>c00D0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001V
IVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`030000000I
6AT06ATI00`06ATI3P000004ooooo`0300000?oooooooooo05Cooooo00Co0000oooooooooooo0000
2?ooool4o`0006_ooooo0009ooooo`0500000?ooooooooooooooool000001@0c<c<00`000000C4a<
04a<C00204a<C0030000001VIVH0IVIV00<0IVIV0P00000>07moO`030000002IVIT0VIVI00P0VIVI
00?o00000;>c/`2c/k<01@2c/k<2o`0000L0c<c<00<000000>KViP3Vi^H0603Vi^H3000000D0c<c<
0_l000070;>c/`03o`00002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1oOgl2000000D0IVIV
0P00000704a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT?000000Cooooo
00<00000ooooooooool0EOooool00ol0003oooooo`000005ooooo`?o0000Koooool000Wooooo00D0
0000ooooooooooooooooo`00000503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
101VIVH00`000000Ogmo07moO`0<07moO`@000001`2IVIT2o`0000L0/k>c00?o00000<c<c03<c<`0
1@3<c<`7000000d0i^KV1P0000060<c<c0;o00001@2c/k<4o`0000@0VIVI0`00000407moO`030000
001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`00003o000003<c<`0803<c<`030000
000I6AT06ATI00`06ATI40000004ooooo`0300000?oooooooooo05Kooooo0_l000000ooooooo0000
o`000002o`0007;ooooo0009ooooo`0500000?ooooooooooooooool000001P0c<c<00ol00000C4a<
04a<C00304a<C0030000001VIVH0IVIV00@0IVIV00?o00000000000000003`1oOgl00ol000000000
09VIV@0609VIV@03o`00002c/k<0/k>c00D0/k>c0ol0000;0<c<c0d000002P3<c<`2o`0000D0/k>c
0_l0000709VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<
04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03@0I6AT@000000Cooooo
00<00000ooooooooool0Eoooool2o`0007Kooooo0009ooooo`0600000?ooooooooooooooo`0I6AWo
00001@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00H0IVIV1000000=07moO`03
0000002IVIT0VIVI00D0VIVI0ol000070;>c/`Co00006P3<c<`4o`0000H0/k>c00?o000009VIV@2I
VIT01@2IVIT2000000D0Ogmo0P00000506IVIP8000001`1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00`06ATI4P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooo`806ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00T0IVIV1`00000707moO`L000000`2IVIT7o`0000@0/k>c6_l000040;>c/`Ko
0000102IVIT4000000@0Ogmo0`00000606IVIP030000001<C4`0C4a<00D0C4a<0P00000903<c<`80
00003P0I6ATC000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo0`0I6AT00ol00000<c<c03<c<`0303<c<`030000001<C4`0C4a<00@0C4a<00@00000o`000000
000000003P1VIVH400000003o`0000000000000000L0Ogmo0`00000709VIV@Oo00004@2c/k<:o`00
00<0VIVI1@0000000ol00000000007moO`0307moO`80000000?o00000000001VIVH0101VIVH40000
00D0C4a<0P0000000ol00000<c<c03<c<`0703<c<`8000003@0I6AT00`00003o00000000000C0000
00Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0`0I6AT2o`00
00D0<c<c00?o00000000001<C4`01`1<C4`300000180IVIV0`00000707moO`L000001`2IVITAo`00
00H0VIVI1`00000707moO`@000001`1VIVH2000000L0C4a<0P00000:03<c<`0300000?l000006ATI
00d06ATI5`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
o`D06ATI00?o000003<c<`0c<c<0100c<c<2000000T0C4a<3P00000706IVIPL000001`1oOglN0000
00L0Ogmo1`00000706IVIP@000001`1<C4`2000000P0<c<c1000000>01TI6AT000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool601TI6@03o`00000c<c<0<c<c
00D0<c<c0`00000D04a<C0P000001P1VIVH800000003o`0000000000000001T0Ogmo2000000706IV
IP80000000?o00000000000000000P00000604a<C003o`00000000000000008000001`0c<c<30000
01006ATI6`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
o`L06ATI0_l0000803<c<`<000006@1<C4`6000000/0IVIV6@00000806IVIPL000001`1<C4`60000
00P0<c<c1000000A01TI6@80000000?o000000000000000060000004ooooo`0300000?oooooooooo
0<oooooo0009ooooo`0400000?ooooooooooooooo`T06ATI00?o000003<c<`0c<c<0200c<c<E0000
00X0C4a<2`00000G06IVIPX000002`1<C4`3000000/0<c<c0`00000B01TI6B0000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool:01TI6@03o`00000c<c<0<c<c
01`0<c<c1`00000>04a<C1L000003P1<C4`7000000X0<c<c1000000B01TI6B<000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01@00003ooooooooooooooooo000000X06ATI0ol0000R03<c
<`h000005`1<C4`>000000X0<c<c1`00000B01TI6@0300000?l00000000002@000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01P00003oooooooooooooool00000o`0000`06ATI0ol0000]
03<c<aL000004@0c<c<7000001D06ATI:`000004ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?ooooooooooooooo`80000000?o000001TI6@0I6AT0300I6ATRo`0002`0<c<c1`00000I
01TI6Bh000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool3
000000;o0000;P0I6ATCo`0000D0<c<c00?o00000000000000004@00000J01TI6C@000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo0009oooookKo00004Ooooonf000000[ooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`02ooooo`;o00003oooool8000001Cooooo00<00000o`000?l00000>Ooo
ool5000001Sooooo0_l00002000002Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/40S@3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/40
0`000000okK10?nf`@0:0?nf`@@00000203o]/4D000001D0okK15P00000F0?nf`@L000005@3o]/44
000002;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40S@3o]/4Uoooo
o`03o`000?oooooooooo00oooooo00D00000ooooo`3o]/40okK10000000;0?nf`@800000:`3o]/4:
000001H0okK12`00000B0?nf`@<000004`3o]/43ooooo`8000008?ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool03oooool01000
003ooooo0?nf`@00000;0?nf`@030000003o]/40okK102@0okK11`00000[0?nf`@L000003P3o]/44
000000l0okK11Oooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool00000
00X0okK100?o00000000003o]/407P3o]/4500000003o`0000000000000000X0okK19@00000:0?nf
`@03o`0000000000000000@000002`3o]/43000000`0okK11_ooool01000003o000000000000000K
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0
003oooooooooo`0?ooooo`0300000?ooool0okK100T0okK100<000000?nf`@3o]/40603o]/470000
00/0okK11`00000U0?nf`@L000002P3o]/44000000X0okK1100000080?nf`@[ooooo0P00000Ioooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK104<0okK160000?lb0?nf`BGo
oooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@080?nf`@030000003o]/40okK100P0
okK14@00000>0?nf`@@000003P3o]/4J000000/0okK10`00000;0?nf`@<000002`3o]/43000000D0
okK13?ooool2000001Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
?P3o]/450000oaP0okK12@000?lY0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo
0?nf`@070?nf`@030000003o]/40okK100D0okK100@00000o`00000000000000703o]/400`00003o
0000000000080?nf`@@000000_l00004000001X0okK10`0000001?l0000000000000000000070?nf
`@<0000000Co000000000000000000001`3o]/44000000X0okK100<00000o`00000000000P3o]/4>
ooooo`8000005Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0j0?nf
`@@0003o9P3o]/450000ob@0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK1
00H0okK100?o00000?nf`@3o]/401@3o]/400`000000okK10?nf`@0J0?nf`@@000001`3o]/440000
00h0okK14P00000;0?nf`@L000001`3o]/43000000P0okK10P00000;0?nf`@8000004?ooool00`00
003oooooooooo`0Booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103@0
okK11P000?l_0?nf`@040000ool00?l0003o0000ob00okK19Oooool00ol0003oooooooooo`0?oooo
o`0300000?ooool0okK100H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@0H0?nf
`@<000001`3o]/44000000/0okK11`00000B0?nf`@P000002P3o]/43000000L0okK100<000000?nf
`@3o]/401`3o]/42000000/0okK100<00000ooooooooool03_ooool00`00003oooooooooo`0Aoooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10340okK10`000?li0?nf`@80
003o7P3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/401@3o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK101D0okK1100000080?nf`@8000002@3o]/400ol00000
00000000000300000240okK10`0000000`3o]/4000000?nf`@070?nf`@030000003o]/40okK100D0
okK10P0000090?nf`@03o`00003o]/40okK100P0okK100?ooooo00000?ooool03oooool00`00003o
ooooooooo`0@ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10300okK1
00<0003o0?nf`@3o]/40?03o]/420000oa`0okK19Oooool00ol0003oooooooooo`0?ooooo`030000
0?ooool0okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@080?nf`@h00000
2`3o]/400`00003o00000?nf`@080?nf`@0300000?l00000okK100L0okK16_l000070?nf`@@00000
1`3o]/43000000H0okK10`0000070?nf`@<000001`3o]/42ooooo`0300000?l0003ooooo00kooooo
0P00000@ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK102l0okK100<0
003o0?nf`@3o]/40?`3o]/420000oaX0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?oo
ool0okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@050?nf`@<000005P3o
]/43000000L0okK1100000070?nf`@?o00006P3o]/44o`0000L0okK10`0000070?nf`@8000001`3o
]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100@0okK10oooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/40;@3o]/420000od@0okK10P000?lH0?nf`BGooooo00?o0000ooooooooool03oooool0
0`00003ooooo0?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/42
000001P0okK100<000000?nf`@3o]/401P3o]/42000000P0okK10ol0000Q0?nf`@?o00001`3o]/40
0`00003o00000?nf`@060?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401`3o]/40
0`000000okK10?nf`@030?nf`@Cooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0=
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK102`0okK100<0003o0?nf
`@3o]/40AP3o]/400`000?l0okK10?nf`@0E0?nf`BGooooo00?o0000ooooooooool03oooool00`00
003ooooo0?nf`@030?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/40103o]/400ol0
0000okK10?nf`@0G0?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401`3o]/400ol0
0000okK10?nf`@0;0?nf`@co00003P3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK1
00D0okK100?o00000?nf`@3o]/401@3o]/400ol0000000000?nf`@070?nf`@030000003o]/40okK1
0080okK11Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/40;03o]/400`000?l0okK10?nf`@0Q0?nf`@?o
00008P3o]/400`000?l0okK10?nf`@0E0?nf`BGooooo00?o0000ooooooooool03oooool00`00003o
oooo0?nf`@020?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@0F0?nf`@03o`00003o]/40okK100L0okK100<000000?nf`@3o]/401`3o]/400ol00000
okK10?nf`@090?nf`@;o0000303o]/400ol00000okK10?nf`@0<0?nf`@03o`00003o]/40okK100D0
okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100H0
okK100<000000?nf`@3o]/400P3o]/45ooooo`0300000?oooooooooo00kooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0/0?nf`@030000
o`3o]/40okK10200okK11Ol0000R0?nf`@030000o`3o]/40okK101@0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`0300000?ooool0okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK101L0okK100<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@060?nf`@03o`00003o]/40okK100X0okK100?o00000?nf`@3o]/40303o]/400ol00000okK1
0?nf`@0;0?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@050?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/400P3o]/46ooooo`030000
0?oooooooooo00gooooo00<00000ooooooooool03?ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0/0?nf`@030000o`3o]/40okK10200okK11Ol0000R0?nf`@030000o`3o
]/40okK101@0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK101P0okK100<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@070?nf`@03o`00003o]/40okK100T0okK100?o
00000?nf`@3o]/403P3o]/400ol00000okK10?nf`@0;0?nf`@03o`00003o]/40okK100D0okK100<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100H0okK100@0
00000?nf`@3o]/40okK11_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40;03o]/400`000?l0okK10?nf
`@0P0?nf`@Go00008P3o]/400`000?l0okK10?nf`@0D0?nf`BGooooo00?o0000ooooooooool03ooo
ool00`00003ooooo0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@0I0?nf`@8000001`3o]/400`000000okK10?nf`@060?nf`@;o00002`3o
]/44o`0000d0okK10_l0000<0?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/401@3o
]/400ol00000okK10?nf`@050?nf`@030000003o]/40okK100H0okK100@000000?nf`@3o]/40okK1
1oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/40;03o]/420000ob80okK10ol0000S0?nf`@80003o5@3o
]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/406`3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100L0okK10_l0000=0?nf`@Co00000P3o]/47o`0000`0okK10_l0
00080?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@060?nf`@040000003o]/40okK10?nf`@Oooooo00<00000ooooooooool03Oooool00`00003ooooo
ooooo`0;ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK102h0okK10P00
0?m50?nf`@030000o`3o]/40okK101D0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?oo
ool0okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK101d0okK100<000000?nf`@3o]/401@3o]/43000000P0okK10ol0000>0?nf`@;o00004@3o
]/42o`0000T0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/400P3o]/46ooooo`0300000?oooooooooo00gooooo00<0
0000ooooooooool03?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0`
0?nf`@030000o`3o]/40okK10440okK100<0003o0?nf`@3o]/405P3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/407P3o]/42000000P0okK100<000000?nf`@3o]/40203o]/43
o`0001`0okK10_l000090?nf`@800000203o]/400`000000okK10?nf`@050?nf`@030000003o]/40
okK100H0okK100<000000?nf`@3o]/400`3o]/45ooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool03?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0a0?nf
`@030000o`3o]/40okK103h0okK10P000?lI0?nf`BGooooo00?o0000ooooooooool03oooool00`00
003ooooo0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@0P0?nf`@030000003o]/40okK100H0okK100?o00000000000000002P3o]/44o`00
01@0okK11?l000090?nf`@8000002@3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK1
00L0okK100<000000?nf`@3o]/400`3o]/45ooooo`0300000?oooooooooo00kooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0b0?nf`@D0
003o>@3o]/420000oa/0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080
okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10240
okK10`0000080?nf`@<000002`3o]/4Do`0000/0okK10P0000080?nf`@<000001`3o]/400`000000
okK10?nf`@060?nf`@8000001P3o]/44ooooo`0300000?oooooooooo00kooooo00<00000oooooooo
ool03Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0g0?nf`@80003o
=@3o]/420000oad0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10180okK1
2P0000080?nf`@@000001`3o]/47000001`0okK11`0000070?nf`@<00000203o]/42000000P0okK1
00<000000?nf`@3o]/401P3o]/43ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
3Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0i0?nf`@<0003o;`3o
]/430000oal0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100l0okK10`00
000:0?nf`@D000001`3o]/401000003o000000000000000:0?nf`@0300000?l00000000000P00000
2@3o]/4700000003o`00003o]/40okK100P0okK1100000070?nf`@80000000?o00000000003o]/40
1P3o]/4200000003o`00003o]/40okK100L0okK100?ooooo00000?l000004?ooool00`00003o0000
ooooo`0?ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103`0okK10`00
0?lY0?nf`@<0003o8P3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/403P3o
]/400`000000okK10?nf`@0@0?nf`@<00000203o]/47000000h0okK12@00000;0?nf`@L000001`3o
]/44000000T0okK10P00000;0?nf`@8000004Oooool00`00003oooooooooo`0@ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK103l0okK13P000?l=0?nf`@h0003o9@3o]/4U
ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK10?nf`@02
0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/403@3o]/400`000000okK10?nf`@0D
0?nf`@@000002`3o]/47000001@0okK11`00000;0?nf`@<000002`3o]/42000000/0okK10P000000
0`3o]/7oooooooooo`0>ooooo`8000004oooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@1=0?nf`@d0003o<`3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000oooo
o`3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/40303o]/400`000000okK10?nf`@0:0?nf`@@000002`3o]/47000000/0okK15000000=0?nf
`@D000002@3o]/45000000X0okK100<00000o`00000000000`3o]/4>ooooo`8000005Oooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000oooooooo
ool03oooool00`00003ooooo0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@0<0?nf`@030000003o]/40okK100H0okK1100000040?nf`@L0
00002`3o]/47000001`0okK12@00000<0?nf`@800000303o]/43000000H0okK13?ooool200000003
o`000?oooooooooo01Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
S@3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK1
0?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40303o]/400`000000okK1
0?nf`@040?nf`@8000003`3o]/48000000X0okK17000000>0?nf`@L000002P3o]/44000000T0okK1
2Oooool3000001Wooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40S@3o
]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000003P3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK101L0okK11`00000V0?nf`@L000003P3o]/43000000d0okK12?ooool00`00003ooooo
ooooo`0Jooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK108d0okK19Ooo
ool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<000000?nf`@3o]/400P3o
]/401@000000okK10?nf`@3o]/40000000h0okK100<000000?nf`@3o]/400`3o]/400ol00000okK1
0?nf`@0O0?nf`@0300000?l00000000000/000002@3o]/4?00000140okK10P0000000ol000000000
0?nf`@0?0?nf`@Gooooo00<00000o`00000000007Oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf
`@020?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK10000000>0?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/401P3o]/4?000001T0okK12@00000I0?nf`@L00000
503o]/42ooooo`<000008?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@2=0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@050000003o
]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@0<0?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/43000000l0okK11`00000]0?nf`@L000006@3o]/44000002?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40S@3o]/4Uooooo`03o`000?oo
oooooooo00oooooo00<00000ooooo`3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK1
00<000000?nf`@3o]/40303o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/405`3o]/4;00000003o`0000000000000000@000003@3o]/4>000001`0okK1
100000020?nf`BGooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o
]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/401@000000okK10?nf
`@3o]/7o000000<0okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf`@020?nf`@040000
003o]/40okK10?nf`@;ooooo00<00000ooooooooool0:Oooool=000002?ooooo1P0000000ol0003o
ooooooooo`0Yooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1
T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100D000000?nf`@3o]/40
okK1000000030?nf`@030000003o]/40okK100@0okK10P0000060?nf`@030000003o]/40okK10080
okK100H000000?nf`@3o]/40okK1ooooo`00001Iooooo`<00000<_ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool01@00
003ooooo0?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@03
0?nf`@040000003o]/40okK1000000H0okK100D000000?nf`@3o]/40okK1000000030?nf`@03oooo
o`00003ooooo00[ooooo10000013ooooo`L00000=Oooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf
`@3o]/40000000<0okK100D000000?nf`@3o]/40okK1o`0000050?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000<0okK100<00000oooo
ooooool01oooool3000000Cooooo3`00000Vooooo`P0000000?o00000000000000000`00000loooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003o
ooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40
000000@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@050000003o]/40
okK10?nf`@0000000`3o]/400`00003oooooooooo`05ooooo`8000005_oooolV000004[ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooo
oooo00oooooo00D00000ooooo`3o]/40okK1000000030?nf`@040000003o]/40okK1000000@0okK1
00<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@00
00000`3o]/400`00003oooooooooo`04ooooo`0300000?oooooooooo08Kooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo
00D00000ooooo`3o]/40okK1000000030?nf`@040000003o]/40okK1000000<0okK100?o00000?nf
`@3o]/401`3o]/401@000000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK10000
0006ooooo`03o`000?oooooooooo08Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo00D00000ooooo`3o]/40okK10000
00030?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/401`3o]/401@000000okK1
0?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK100000006ooooo`0300000?oooooooooo
08Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03
o`000?oooooooooo00oooooo00D00000ooooo`3o]/40okK1000000030?nf`@040000003o]/40okK1
00000080okK100<000000?nf`@3o]/402@3o]/4010000000okK10?nf`@0000030?nf`@050000003o
]/40okK10?nf`@0000001_ooool00`00003oooooooooo`26ooooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`0400000?oo
ool0okK1000000<0okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@090?nf`@05
0000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000Gooooo00<00000
ooooooooool0Qoooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0A0?nf
`@80003o3`3o]/6@ooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000`3o]/40
10000000okK10?nf`@0000020?nf`@030000003o]/40okK100/0okK100@000000?nf`@3o]/400000
0P3o]/401@000000okK10?nf`@3o]/40000000Gooooo00<00000ooooooooool0Qoooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0?0?nf`@80003o0P3o]/400`000?l0okK1
0?nf`@0<0?nf`I3ooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000030?nf`@04
0000003o]/40okK100000080okK100<000000?nf`@3o]/400`3o]/44000000@0okK100@000000?nf
`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000Gooooo00<00000ooooooooool0Qooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0>0?nf`@030000o`3o]/40
okK10080okK100<0003o0?nf`@3o]/40303o]/6@ooooo`03o`000?oooooooooo00oooooo00@00000
ooooo`3o]/4000000`3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o
]/40okK1000000020?nf`@0300000?oooooooooo00?ooooo00<00000ooooooooool0Qoooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0=0?nf`@030000o`3o]/40okK100@0
okK100<0003o0?nf`@3o]/402`3o]/6@ooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o
]/4000000P3o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf`@0000001@3o
]/400`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/40
00001Oooool00`00003oooooooooo`27ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK100d0okK100<0003o0?nf`@3o]/401@3o]/400`000?l0okK10?nf`@0:0?nf`I3ooooo
00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK10000
0080okK100Go00000?nf`@3o]/40okK1000000070?nf`@050000003o]/40okK10?nf`@0000000P3o
]/4010000000okK10?nf`@0000020?nf`@03ooooo`00003ooooo00?ooooo00<00000ooooooooool0
Qoooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0<0?nf`@030000o`3o
]/40okK100L0okK100<0003o0?nf`@3o]/402@3o]/6@ooooo`03o`000?oooooooooo00oooooo00@0
0000ooooo`3o]/4000000P3o]/4010000000okK10?nf`Ol000020?nf`@050000003o]/40okK10?nf
`@0000001`3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000P3o
]/400oooool00000ooooo`03ooooo`0300000?oooooooooo08Oooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/40303o]/400`000?l0okK10?nf`@070?nf`@030000o`3o]/40
okK100T0okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0000000<0okK100H00000
0?nf`@3o]/4000000?nf`@0000030?nf`@030000003o]/40okK100L0okK100D000000?nf`@3o]/40
okK1000000020?nf`@070000003o]/40okK10000003o]/7ooooo00000004ooooo`0300000?oooooo
oooo08Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402`3o]/400`00
0?l0okK10?nf`@090?nf`@030000o`3o]/40okK100P0okK1T?ooool00ol0003oooooooooo`0?oooo
o`0300000?ooool0000000<0okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o
]/40okK100T0okK100@000000?nf`@3o]/4000000P3o]/401`000000okK10?nf`@000000okK1oooo
o`0000001?ooool00`00003oooooooooo`27ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100/0okK100<0003o0?nf`@3o]/402P3o]/400`000?l0okK10?nf`@070?nf`I3o
oooo00?o0000ooooooooool03oooool00`00003ooooo000000030?nf`@060000003o]/40okK10000
003o]/4000000P3o]/400`000000okK10?nf`@030?nf`@800000103o]/4010000000okK10?nf`@00
00020?nf`@070000003o]/40okK10000003o]/7ooooo00000004ooooo`0300000?oooooooooo08Oo
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/402`3o]/400`000?l0okK1
0?nf`@0:0?nf`@030000o`3o]/40okK100L0okK1T?ooool00ol0003oooooooooo`0?ooooo`030000
0?ooool000000080okK100L000000?nf`@3o]/40okK10000003o]/4000000080okK100<000000?nf
`@3o]/400P3o]/4010000000okK10?nf`@0000040?nf`@030000003o]/4000000080okK100L00000
0?nf`@3o]/4000000?nf`Oooool0000000Cooooo00<00000ooooooooool0Qoooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0:0?nf`@030000o`3o]/40okK100`0okK100<0
003o0?nf`@3o]/401P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`0000000P3o
]/401P000000okK10?nf`@000000okK100000080okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/400`000000okK1000000020?nf
`@040000003o]/7ooooo000000Cooooo00<00000ooooooooool0Qoooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0:0?nf`@030000o`3o]/40okK100`0okK100<0003o0?nf
`@3o]/401P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`0000000P3o]/401P00
0000okK10?nf`@000000okK100000080okK100D000000?nf`@3o]/40okK1000000060?nf`@040000
003o]/40okK100000080okK100?o00000?nf`@0000000P3o]/4010000000okK1ooooo`000004oooo
o`0300000?oooooooooo08Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
]/402P3o]/400`000?l0okK10?nf`@0<0?nf`@030000o`3o]/40okK100H0okK1T?ooool00ol0003o
ooooooooo`0?ooooo`0300000?ooool0okK10080okK100H000000?nf`@3o]/4000000?nf`@000002
0?nf`@040000003o]/40okK1o`0000L0okK100@000000?nf`@3o]/4000000P3o]/400`000000okK1
000000020?nf`@040000003o]/7ooooo000000Cooooo00<00000ooooooooool0Qoooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@090?nf`@030000o`3o]/40okK100h0okK1
00<0003o0?nf`@3o]/401@3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/40
0P3o]/400`000000okK1000000020?nf`@040000003o]/40okK100000080okK100<000000?nf`@3o
]/401P3o]/401P000000okK10?nf`@000000okK100000080okK100@000000?nf`@3o]/4000000_oo
ool00`00003oooooooooo`02ooooo`0300000?oooooooooo08Kooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/402@3o]/400`000?l0okK10?nf`@0>0?nf`@030000o`3o]/40
okK100D0okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<00000
0?nf`@0000000P3o]/400`000000okK1o`0000020?nf`@030000003o]/40okK100L0okK100@00000
0?nf`@3o]/4000000P3o]/400`000000okK1000000020?nf`@0400000?oooooooooo000000Cooooo
00<00000ooooooooool0Q_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@090?nf`@030000o`3o]/40okK100h0okK100<0003o0?nf`@3o]/401@3o]/6@ooooo`03o`000?oo
oooooooo00oooooo00<00000ooooo`3o]/400P3o]/400`000000okK1000000020?nf`@030000003o
]/4000000080okK100<000000?nf`@3o]/401`3o]/4010000000okK10?nf`@0000020?nf`@030000
003o]/4000000080okK100@00000ooooooooool000001?ooool00ol0003oooooooooo`26ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100T0okK100<0003o0?nf`@3o]/40
3P3o]/400`000?l0okK10?nf`@050?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo
0?nf`@020?nf`@030000003o]/4000000080okK100<000000?nf`@0000000P3o]/400`000000okK1
0?nf`@020?nf`@;o00000`3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/4000000080
okK100@00000ooooooooool000001?ooool00`00003oooooooooo`26ooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100P0okK100<0003o0?nf`@3o]/403`3o]/400`000?l0
okK10?nf`@050?nf`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/400000
0080okK100D000000?nf`@000000okK1000000020?nf`@030000003o]/40okK10080okK100Co0000
0?nf`@3o]/7o00000`3o]/401P000000okK10?nf`@000000okK100000080okK100<000000?nf`@00
00000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo08Gooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf`@0@0?nf`@030000
o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@00
00000P3o]/401@000000okK10000003o]/4000000080okK100D000000?nf`@3o]/40okK1o`000004
0?nf`@09o`00003o]/40okK1o`0000000000okK10000003o]/4000000080okK100<000000?nf`@00
00000oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo08Gooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400ol00?l0okK10?nf`@0@0?nf`@030000
o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@00
00000P3o]/401@000000okK10000003o]/4000000080okK100D000000?nf`@3o]/40okK1o`000004
0?nf`@09o`00003o]/40okK10?nf`@000000okK10000003o]/4000000080okK100<000000?nf`@00
00000oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo027ooooo7@000016ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100P0okK100<0003o0?nf`@3o]/40
403o]/400`000?l0okK10?nf`@040?nf`I3ooooo00?o0000ooooooooool03oooool01`00003ooooo
0?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10000003o]/40000000<0okK100?o0000
0?nf`@3o]/40103o]/402ol00000okK10?nf`@3o]/4000000?nf`@000000okK10000003o]/400000
0080okK100D00000oooooooooooooooo00000005ooooo`0300000?oooooooooo01;ooooo3P00000M
ooooo`/00000>oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@080?nf
`@030000o`3o]/40okK10100okK100<0003o0?nf`@3o]/40103o]/6@ooooo`03o`000?oooooooooo
00oooooo00L00000ooooo`3o]/40okK10000003o]/4000000080okK100D000000?nf`@000000okK1
000000020?nf`@03o`00003o]/40okK100H0okK100[o00000?nf`@3o]/4000000?nf`@000000okK1
0000003o]/4000000P3o]/401Ol0003oooooooooooooool0000000Kooooo00<00000o`0000000000
2Oooool200000003o`0000000000000000<00000=_ooool500000003o`000000003ooooo03?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf
`@0A0?nf`@030000o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0700000?oo
ool0okK10?nf`@000000okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/400ol0
0000okK10?nf`@060?nf`@0:o`00003o]/40okK10000003o]/4000000?nf`@000000okK100000080
okK100D00000ooooooooooooooooo`000009ooooo`T00000AOooool7000002gooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0A0?nf`@03
o`00o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0700000?ooool0okK10?nf
`@000000okK1000000020?nf`@070000003o]/4000000?nf`@000000okK1o`0000090?nf`@0:o`00
003o]/40okK10000003o]/4000000?nf`@000000okK100000080okK100D00000oooooooooooooooo
0000000_ooooo``000008oooool4000002Wooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0A0?nf`@030000o`3o]/40okK100@0okK1T?oo
ool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK100000080okK100D000000?nf`@000000
okK1000000020?nf`@030000003o]/7o000000@0okK10_l000040?nf`@03o`00003o]/40okK10080
00000P3o]/401P000000okK10000003o]/7ooooo000000?ooooo00<00000ooooooooool06ooooolA
000000cooooo3P00000Iooooo`<000009_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@070?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/40103o]/6@oooo
o`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o]/402@000000okK10000003o
]/4000000?nf`Ol00000okK1o`0000040?nf`@04o`00003o]/40okK1o`0000<0okK100go00000?nf
`@3o]/4000000?nf`@000000okK10000003o]/4000000?nf`Oooool0000000?ooooo0P00000Doooo
o`H0000000?o000000000?ooool0:_ooool00`00003o000000000004000001Gooooo00@00000o`00
0000000000008_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@070?nf
`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/40K`3o]/4Uooooo`03o`000?oooooooooo
00oooooo00@00000ooooo`3o]/4000000P3o]/402@000000okK10000003o]/4000000?nf`@000000
okK1o`0000040?nf`@05o`00003o]/40okK10?nf`Ol000000P3o]/402_l00000okK10?nf`@000000
okK10000003o]/4000000?nf`@0000020?nf`@030000003o]/40okK100<0okK10P00000?0?nf`@<0
00005@3o]/4C00000180okK11`00000?0?nf`@?ooooo0P00000Pooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/404P3o]/400`000?l0okK1
0?nf`@1^0?nf`BGooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@09
0000003o]/4000000?nf`@000000okK10000003o]/7o000000<0okK100?o00000?nf`@3o]/400P3o
]/401Ol00000okK10?nf`@3o]/7o00000080okK100L000000?nf`@000000okK1o`00003o]/400000
0080okK100<000000?nf`@3o]/40103o]/42000000D0okK12000000:0?nf`@h000004`3o]/4;0000
00h0okK10`00000<0?nf`@Gooooo0P00000Nooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100L0okK100<0003o0?nf`@3o]/404P3o]/400`000?l0okK10?nf`@1^0?nf`BGo
oooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@090000003o]/400000
0?nf`@000000okK10000003o]/7o00000080okK100?o00000?nf`@3o]/40103o]/401?l00000okK1
0?nf`Ol000020?nf`@050000003o]/4000000?nf`@0000000P3o]/401?l00000okK10?nf`Ol00007
0?nf`@D000002`3o]/47000002`0okK10`0000000ol00000okK10?nf`@0;0?nf`@<000002@3o]/47
ooooo`0300000?l00000000001_ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/401`3o]/400`000?l0okK10?nf`@0B0?nf`@030000o`3o]/40okK106h0okK19Oooool00ol0
003oooooooooo`0?ooooo`0600000?ooool0okK10000003o]/7o00000P3o]/401`000000okK10000
003o]/4000000?nf`Ol000000P3o]/400ol00000okK10?nf`@040?nf`@04o`00003o]/40okK1o`00
0080okK100D000000?nf`@000000okK1000000020?nf`@040000003o]/40okK10?nf`@8000004P3o
]/43000000/0okK18@00000;0?nf`@H000002P3o]/42000000L0okK12_ooool2000001Wooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0B
0?nf`@030000o`3o]/40okK106h0okK19Oooool00ol0003oooooooooo`0?ooooo`0600000?ooool0
okK10000003o]/4000000P3o]/402@000000okK10000003o]/4000000?nf`Ol00000okK1o`000008
0?nf`@08o`00003o]/40okK1o`00003o]/4000000?nf`@0000020?nf`@030000003o]/40000000D0
okK100<000000?nf`@3o]/402`3o]/44000000L0okK11`00000Q0?nf`@L000002P3o]/43000000T0
okK10`0000040?nf`@cooooo00<00000ooooooooool05_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o]/40okK10180okK100<0003o0?nf`@3o]/40
<P3o]/4?0000obd0okK19Oooool00ol0003oooooooooo`0?ooooo`0>00000?ooool0okK10000003o
]/4000000?nf`@000000okK10000003o]/4000000?nf`Ol000020?nf`@03o`00003o]/40okK100H0
okK100Ko00000?nf`@3o]/7o00000?nf`@0000020?nf`@030000003o]/4000000080okK100<00000
0?nf`@3o]/400`3o]/43000000<0okK11`0000070?nf`@@000001`3o]/4Q000000L0okK10`00000:
0?nf`@030000003o]/40okK100T0okK100@000000?nf`@3o]/40okK13Oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o
0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0X0?nf`@X0003o3`3o]/490000ob@0okK19Oooool0
0ol0003oooooooooo`0?ooooo`0@00000?ooool0okK10000003o]/4000000?nf`@000000okK10000
003o]/4000000?nf`Ol00000okK1o`0000X0okK100So00000?nf`@3o]/7o00000?nf`@000000okK1
00000080okK100@000000?nf`@3o]/4000001`3o]/43000000/0okK10`0000070?nf`@@000008@3o
]/43000000L0okK100@00000o`000000000000001`3o]/401?l0000000000000000000080?nf`@03
o`0000000000000000kooooo00<00000ooooooooool05?ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/40
8`3o]/420000o`;o003o00<0003o0?nf`@3o]/40803o]/430000ob40okK19Oooool00ol0003ooooo
ooooo`0?ooooo`0@00000?ooool0okK10000003o]/4000000?nf`@000000okK1o`00003o]/400000
0?nf`Ol00000okK1o`0000@0okK10ol000030?nf`@08o`00003o]/40okK1o`00003o]/4000000?nf
`@0000020?nf`@050000003o]/40okK10?nf`@000000403o]/44000000<0okK11`0000070?nf`A[o
00001`3o]/44000000L0okK10`0000080?nf`@8000002@3o]/400`00003oooooooooo`0<ooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
1P3o]/400`000?l0okK10?nf`@0C0?nf`@030000o`3o]/40okK10200okK10`000?lZ0?nf`@<0003o
7P3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`0000000P3o]/4020000000okK1
0000003o]/4000000?nf`@000000okK10_l000040?nf`@05o`00003o]/40okK10?nf`Ol000000`3o
]/402?l00000okK10?nf`Ol00000okK10000003o]/7o00000P3o]/4010000000okK10?nf`@3o]/42
000000X0okK1100000040?nf`@<000001`3o]/47o`0001X0okK11ol000040?nf`@<000001`3o]/40
0`00003o00000?nf`@070?nf`@030000003o]/40okK100H0okK100?ooooo00000?ooool03Oooool0
0`00003oooooooooo`0Booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
00H0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0N0?nf`@80003o<03o]/420000
oa`0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool000000080okK100P000000?nf
`@000000okK10000003o]/4000000?nf`@;o00000`3o]/400ol00000okK10?nf`@030?nf`@04o`00
003o]/40okK1o`000080okK100?o00000?nf`@0000000P3o]/400`000000okK1000000050?nf`@03
o`00003o]/40okK100<0okK1100000060?nf`@8000001P3o]/44o`0000L0okK15ol0000:0?nf`@03
o`00003o]/40okK100@0okK100<00000o`00000000001P3o]/400`000000okK10?nf`@060?nf`@03
o`00003o]/40okK100D0okK10_ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo017o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK1
0?nf`@0C0?nf`@030000o`3o]/40okK101/0okK10`000?ld0?nf`@80003o6P3o]/4Uooooo`03o`00
0?oooooooooo00oooooo00<00000ooooo`0000000P3o]/4020000000okK10000003o]/4000000?nf
`@000000okK10_l000030?nf`@03o`00003o]/40okK100<0okK100Co00000?nf`@3o]/7o00000P3o
]/400ol00000okK1000000020?nf`@030000003o]/40000000H0okK1100000000ol00000okK10?nf
`@060?nf`@80000000?o00000?nf`@3o]/400P3o]/43o`0000@0okK11ol0000G0?nf`@?o0000203o
]/42o`0000L0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@030000003o
]/40okK100@0okK10_ooool00`00003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@0C
0?nf`@030000o`3o]/40okK101P0okK10`000?li0?nf`@80003o603o]/4Uooooo`03o`000?oooooo
oooo00oooooo00<00000ooooo`0000000P3o]/4020000000okK10000003o]/4000000?nf`@000000
okK10_l000030?nf`@03o`00003o]/40okK100<0okK100Co00000?nf`@3o]/7o00000P3o]/400ol0
0000okK1000000020?nf`@040000003o]/40okK1000000l0okK10`0000040?nf`@?o00001@3o]/42
o`0000h0okK12?l0000;0?nf`@Co00001P3o]/400ol00000okK10?nf`@050?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@?ooooo00<00000
ooooooooool02oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0G0?nf
`@03o`00o`3o]/40okK103`0okK100<0003o0?nf`@3o]/405@3o]/4Uooooo`03o`000?oooooooooo
00oooooo00<00000ooooo`0000000P3o]/402P000000okK1000000000000okK10000003o]/7o0000
0?nf`Ol000020?nf`@03o`00003o]/40okK100D0okK100Ko00000?nf`@3o]/7o00000?nf`Ol00002
0?nf`@040000003o]/40okK100000080okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf
`@040?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/401`3o]/47o`0000P0okK11ol0
00080?nf`@03o`00003o]/40okK100@0okK10_l000060?nf`@030000003o]/40okK100@0okK100<0
00000?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK100H0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0G0?nf`@030000o`3o]/40
okK103`0okK100<0003o0?nf`@3o]/405@3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000
ooooo`0000000P3o]/402P000000okK1000000000000okK10000003o]/7o00000?nf`Ol000020?nf
`@03o`00003o]/40okK100D0okK100Co00000?nf`@3o]/7o00000P3o]/400ol00000okK100000002
0?nf`@050000003o]/40okK10?nf`Ol000002P3o]/400ol0000000000?nf`@050?nf`@03o`00003o
]/40okK100D0okK100?o00000?nf`@3o]/401@3o]/43o`0001H0okK100?o00000?nf`@3o]/401P3o
]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK11?ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/401P3o]/400`000?l0okK10?nf`@070?nf`@?o00002@3o]/400`000?l0okK10?nf`@0F
0?nf`@030000o`3o]/40okK101/0okK10ol0000O0?nf`@030000o`3o]/40okK101D0okK19Oooool0
0ol0003oooooooooo`0?ooooo`0300000?ooool000000080okK100X000000?nf`@00000000000?nf
`@000000okK1o`00003o]/7o00000P3o]/400ol00000okK10?nf`@050?nf`@04o`00003o]/40okK1
o`000080okK100?o00000?nf`@0000000P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100L0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40
okK100D0okK100?o00000?nf`@3o]/40603o]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40
okK100D0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400`3o]/44ooooo`0300000?oooooooooo00_ooooo00<00000
ooooooooool04?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf
`@030000o`3o]/40okK100H0okK11Ol000080?nf`@030000o`3o]/40okK101D0okK100<0003o0?nf
`@3o]/406`3o]/45o`0001l0okK100<0003o0?nf`@3o]/40503o]/4Uooooo`03o`000?oooooooooo
00oooooo00<00000ooooo`0000000P3o]/402P000000okK1000000000000okK10000003o]/7o0000
0?nf`Ol000020?nf`@03o`00003o]/40okK100D0okK100Co00000?nf`@3o]/7o00000P3o]/400ol0
0000okK1000000020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/401P3o]/400`00
0000okK10?nf`@060?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400ol0
0000okK10?nf`@0I0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/401@3o]/400ol0
0000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0@oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o
]/401P3o]/45o`0000P0okK100<0003o0?nf`@3o]/40503o]/400`000?l0okK10?nf`@0L0?nf`@Go
00007`3o]/400`000?l0okK10?nf`@0D0?nf`BGooooo00?o0000ooooooooool03oooool04@00003o
oooo0000003o]/4000000?nf`@000000okK10000003o]/4000000?nf`Ol00000okK1o`00003o]/7o
000000T0okK100Ko00000?nf`@3o]/7o00000?nf`Ol000020?nf`@040000003o]/40okK1000000@0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100@0
okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@0J0?nf`@03o`00003o]/40okK100D0
okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@030?nf`@?ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK100H0okK100<0003o0?nf`@3o]/401P3o]/45o`0000P0okK100<0003o0?nf`@3o]/40
4`3o]/400`000?l0okK10?nf`@0M0?nf`@Go00007P3o]/420000oaH0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`0A00000?ooool000000?nf`@000000okK10000003o]/4000000?nf`@000000okK1
o`00003o]/7o00000?nf`Ol000002@3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100@0
00000?nf`@3o]/400000103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100H0okK1
00?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@050?nf`@?o00006@3o]/43o`0000H0okK1
0_l000050?nf`@;o00001@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100D0okK1
00?o00000?nf`@3o]/400`3o]/43ooooo`03o`000?oooooooooo00_ooooo00?o000000000?ooool0
4Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o
]/40okK100L0okK10ol000090?nf`@030000o`3o]/40okK101@0okK100<0003o0?nf`@3o]/407@3o
]/43o`0001h0okK100<0003o0?nf`@3o]/405P3o]/4Uooooo`03o`000?oooooooooo00oooooo0140
0000ooooo`000000okK10000003o]/4000000?nf`@000000okK10000003o]/7o00000?nf`Ol00000
okK1o`0000090?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o]/4010000000okK10?nf`@00
00040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf
`@050?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o]/405@3o]/400ol00000okK10?nf
`@050?nf`@;o00001@3o]/42o`0000D0okK10P0000060?nf`@030000003o]/40okK100D0okK100<0
00000?nf`@3o]/40103o]/42ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool04Ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40
okK101<0okK100<0003o0?nf`@3o]/405@3o]/400`000?l0okK10?nf`@0k0?nf`@80003o6@3o]/4U
ooooo`03o`000?oooooooooo00oooooo00D00000ooooo`000000okK1000000020?nf`@80000000H0
okK10000003o]/7o00000?nf`Ol000020?nf`@03o`00003o]/40okK100H0okK100So00000?nf`@3o
]/7o00000?nf`Ol00000okK100000080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@060?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf
`@070?nf`@?o00004@3o]/43o`0000L0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf
`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@050?nf`@03ooooo`00003ooooo00gooooo00<00000ooooooooool04_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40okK101<0okK100<0003o
0?nf`@3o]/405P3o]/400`000?l0okK10?nf`@0h0?nf`@80003o6`3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00D00000ooooo`000000okK1000000020?nf`@80000000H0okK10000003o]/7o0000
0?nf`Ol000020?nf`@03o`00003o]/40okK100H0okK100So00000?nf`@3o]/7o00000?nf`Ol00000
okK100000080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@070?nf`@030000003o
]/40okK100D0okK10_l000060?nf`@;o00002P3o]/4Ao`0000L0okK10ol000050?nf`@;o00001@3o
]/42000000L0okK100?o00000?nf`@3o]/40103o]/42000000P0okK100<00000ooooooooool03?oo
ool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK100H0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0okK10?nf`@0G0?nf`@030000o`3o]/40
okK103D0okK10P000?lM0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0000003o
]/4000000080okK10P0000001P3o]/4000000?nf`Ol00000okK1o`000080okK100?o00000?nf`@3o
]/401P3o]/402?l00000okK10?nf`Ol00000okK1o`00003o]/4000000P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100L0okK100?o00000000003o]/401`3o]/400ol00000okK10?nf
`@050?nf`@?o0000703o]/43o`0000H0okK10_l000050?nf`@8000001P3o]/43000000D0okK10P00
00090?nf`@0300000?l0003ooooo00cooooo00?o0000ooooooooool05?ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000o`3o]/40okK101<0okK100<0003o
0?nf`@3o]/40603o]/400ol00?l0003o0?nf`@0a0?nf`@<0003o7`3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00D00000ooooo`000000okK1000000020?nf`@80000000H0okK10000003o]/7o0000
0?nf`Ol000020?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/400_l000020?nf`@04
0000003o]/40okK1000000<0okK100<000000?nf`@3o]/402P3o]/42000000L0okK10ol000070?nf
`@Co0000403o]/48o`0000L0okK10_l000050?nf`@8000001@3o]/43000000H0okK10P0000090?nf
`@80000000<0okK1ooooooooool02oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0
okK10?nf`@0J0?nf`@<0003o;03o]/430000ob80okK19Oooool00ol0003oooooooooo`0?ooooo`03
00000?ooool000000080okK100@000000?nf`@000000okK10P000000103o]/7o00000?nf`Ol00002
0?nf`@03o`00003o]/40okK100D0okK100Ko00000?nf`@3o]/7o00000?nf`Ol000020?nf`@030000
003o]/40000000<0okK100<000000?nf`@3o]/403@3o]/43000000L0okK11?l000070?nf`A3o0000
2@3o]/46o`0000@0okK10`0000060?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/40
203o]/4010000000okK10?nf`@3o]/4<ooooo`0300000?oooooooooo01Kooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@0C0?nf`@030000
o`3o]/40okK101d0okK10`000?lT0?nf`@D0003o9@3o]/4Uooooo`03o`000?oooooooooo00oooooo
00<00000ooooo`0000000P3o]/4010000000okK10000003o]/42000000040?nf`Ol00000okK1o`00
0080okK100?o00000?nf`@3o]/401@3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100<0
00000?nf`@0000000P3o]/400ol00000okK10?nf`@020?nf`@P000001`3o]/401000003o00000000
000000070?nf`@Oo0000403o]/49o`0000H0okK1100000060?nf`@<000001`3o]/42000000T0okK1
00<00000o`00003o]/400`3o]/49ooooo`0300000?l00000000001Wooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/401P3o]/400`000?l0okK10?nf`@0C0?nf`@030000o`3o
]/40okK10200okK11@000?lK0?nf`@@0003o:P3o]/4Uooooo`03o`000?oooooooooo00oooooo00<0
0000ooooo`0000000P3o]/4010000000okK10000003o]/4200000080okK10_l000020?nf`@03o`00
003o]/40okK100@0okK100Oo00000?nf`@3o]/40okK1o`00003o]/7o00000080okK100D000000?nf
`@000000okK1000000040?nf`@030000003o]/40okK100H0okK10`0000080?nf`@L000001`3o]/4@
o`0000/0okK1100000070?nf`@<000001`3o]/43000000P0okK10`0000060?nf`@Sooooo00<00000
ooooooooool06_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf
`@030000o`3o]/40okK101<0okK100<0003o0?nf`@3o]/409@3o]/460000o`03o`00o`000?l0003o
0180003o;P3o]/4Uooooo`03o`000?oooooooooo00oooooo01000000ooooo`3o]/4000000?nf`@00
0000okK10000003o]/4000000?nf`@000000okK1o`00003o]/7o00000P3o]/400ol00000okK10?nf
`@020?nf`@07o`00003o]/40okK10?nf`Ol00000okK1o`0000020?nf`@030000003o]/4000000080
okK100D000000?nf`@3o]/40okK1o`00000<0?nf`@@000002`3o]/4700000100okK12`0000070?nf
`@@000001`3o]/43000000P0okK10`0000090?nf`@Kooooo0P00000Mooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK100H0okK100<0003o0?nf`@3o]/404`3o]/400`000?l0
okK10?nf`@1^0?nf`BGooooo00?o0000ooooooooool03oooool04000003ooooo0?nf`@000000okK1
0000003o]/4000000?nf`@000000okK10000003o]/7o00000?nf`Ol000030?nf`@Co00000`3o]/42
o`0000040?nf`Ol00000okK100000080okK100<000000?nf`@0000000`3o]/400`000000okK10?nf
`@0?0?nf`@@0000000?o00000000000000002`3o]/4@000000/0okK11`0000070?nf`@80000000?o
00000000003o]/401P3o]/401000003o000000000000000<0?nf`@;ooooo00@00000o`0000000000
00007oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@060?nf`@030000
o`3o]/40okK101<0okK100<0003o0?nf`@3o]/40KP3o]/4Uooooo`03o`000?oooooooooo00oooooo
01000000ooooo`3o]/4000000?nf`@000000okK10000003o]/4000000?nf`@000000okK1o`00003o
]/7o00002P3o]/401_l00000okK10?nf`Ol00000okK100000080okK100<000000?nf`@0000000`3o
]/400`000000okK10?nf`@030?nf`@P000002`3o]/47000001@0okK12`0000070?nf`@L000002P3o
]/400`000000okK10?nf`@0>0?nf`@03ooooo`00003ooooo02;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0A0?nf`@030000o`3o]/40
okK106l0okK19Oooool00ol0003oooooooooo`0?ooooo`0>00000?ooool0okK10000003o]/400000
0?nf`@000000okK10000003o]/4000000?nf`Ol000020?nf`@03o`00003o]/40okK100L0okK100Go
00000?nf`@3o]/7o0000000000020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o
]/40okK10`0000080?nf`@P000002P3o]/4D000000l0okK10`00000;0?nf`@H000003`3o]/430000
02Cooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0
okK10?nf`@0A0?nf`@030000o`3o]/40okK106l0okK19Oooool00ol0003oooooooooo`0?ooooo`06
00000?ooool0okK10000003o]/4000000P3o]/402@000000okK10000003o]/4000000?nf`Ol00000
okK1o`0000080?nf`@06o`00003o]/40okK1o`00003o]/7o00000P3o]/400`000000okK100000002
0?nf`@050000003o]/40okK10?nf`@0000004`3o]/4600000200okK11`00000;0?nf`@<000004P3o
]/4300000080okK19Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@07
0?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o]/40K`3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00H00000ooooo`3o]/4000000?nf`@0000020?nf`@070000003o]/4000000?nf`@00
0000okK1o`0000020?nf`@03o`00003o]/40okK100D0okK100So00000?nf`@3o]/7o00000?nf`@00
0000okK100000080okK100<000000?nf`@0000000`3o]/400`000000okK10?nf`@0H0?nf`@030000
0?l00000000001d000003P3o]/4400000140okK10P0000000ol0000000000?nf`@040?nf`BGooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf
`@0A0?nf`@030000o`3o]/40okK106l0okK19Oooool00ol0003oooooooooo`0?ooooo`0600000?oo
ool0okK10000003o]/4000000P3o]/401`000000okK10000003o]/4000000?nf`Ol000000P3o]/40
0ol00000okK10?nf`@040?nf`@09o`00003o]/40okK10?nf`Ol00000okK10000003o]/4000000080
okK100<000000?nf`@0000000`3o]/400`000000okK10?nf`@030?nf`@/00000<@3o]/4700000140
okK1100000090?nf`BGooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
1`3o]/400`000?l0okK10?nf`@0A0?nf`@030000o`3o]/40okK106l0okK19Oooool00ol0003ooooo
ooooo`0?ooooo`0400000?ooool0okK100000080okK100L000000?nf`@000000okK10000003o]/40
00000080okK100Co00000?nf`@3o]/7o0000103o]/402Ol00000okK10?nf`@3o]/7o00000?nf`@00
0000okK1000000020?nf`@03o`00003o]/40000000<0okK100<000000?nf`@3o]/400P3o]/420000
00/0okK12`00000K0?nf`@/000005@3o]/43000000d0okK19Oooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o
]/40K`3o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o]/401`00
0000okK10000003o]/4000000?nf`@0000000P3o]/401?l00000okK10?nf`@3o]/44o`0000<0okK1
00So00000?nf`@3o]/4000000?nf`@000000okK100000080okK100@000000?nf`@3o]/400000103o
]/400`000000okK10?nf`@0F0?nf`A/000006`3o]/4500000100okK19Oooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?nf`@070?nf`@030000o`3o]/40okK10140okK100<0003o
0?nf`@3o]/40103o]/6@ooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000000P3o
]/401@000000okK10000003o]/4000000080okK100?o00000?nf`Ol000002P3o]/402?l00000okK1
0?nf`@000000okK10000003o]/4000000P3o]/401000003oooooooooo`000004ooooo`0300000?oo
oooooooo04Kooooo1P00000jooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK100L0okK100<0003o0?nf`@3o]/404@3o]/400`000?l0okK10?nf`@040?nf`I3ooooo00?o0000
ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@050000003o]/4000000?nf`@000000
0P3o]/4010000000okK10?nf`Ol000080?nf`@04o`00003o]/40okK10?nf`@8000000P3o]/401P00
0000okK10?nf`@00003ooooo000000Cooooo00<00000ooooooooool0@?ooool70000043ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/401`3o]/400`000?l0okK10?nf`@0A
0?nf`@030000o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0700000?ooool0
okK10?nf`@000000okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/400ol00000
okK10?nf`@060?nf`@08o`00003o]/40okK10000003o]/7o00000?nf`@0000020?nf`@040000003o
]/7ooooo000000?ooooo00<00000ooooooooool0>_ooool7000004Oooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK10?nf`@0@0?nf`@030000o`3o
]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`0700000?ooool0okK10?nf`@000000
okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/400ol00000okK10?nf`@050?nf
`@09o`00003o]/40okK10?nf`@000000okK10000003o]/4000000080okK100@000000?nf`@00003o
00000_ooool00`00003oooooooooo`06ooooo`0300000?l00000000000H0000000?o000000000000
0000:@00001>ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100P0okK1
00<0003o0?nf`@3o]/40403o]/400`000?l0okK10?nf`@040?nf`I3ooooo00?o0000ooooooooool0
3oooool01`00003ooooo0?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10000003o]/40
000000<0okK100?o00000?nf`@3o]/40103o]/402Ol00000okK10?nf`@3o]/4000000?nf`@000000
okK1000000020?nf`@030000003o]/40000000?ooooo00<00000ooooooooool00oooool3000008?o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40203o]/400`000?l0okK1
0?nf`@0@0?nf`@030000o`3o]/40okK100@0okK1T?ooool00ol0003oooooooooo`0?ooooo`050000
0?ooool0okK10?nf`@0000000P3o]/400`000000okK1000000020?nf`@030000003o]/40000000<0
okK100?o00000?nf`@3o]/400P3o]/402Ol00000okK10?nf`@3o]/7o00000?nf`@000000okK10000
00020?nf`@030000003o]/40000000?ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`24ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100P0okK100<0003o
0?nf`@3o]/40403o]/400`000?l0okK10?nf`@040?nf`I3ooooo00?o0000ooooooooool03oooool0
1@00003ooooo0?nf`@3o]/4000000080okK100<000000?nf`Ol000000P3o]/400`000000okK10000
00040?nf`@04o`00003o]/7o0000o`0000<0okK100H000000?nf`@3o]/4000000?nf`@0000020?nf
`@030000003o]/40000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`25oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100P0okK100<0003o0?nf`@3o
]/40403o]/400`000?l0okK10?nf`@040?nf`I3ooooo00?o0000ooooooooool03oooool01@00003o
oooo0?nf`@3o]/4000000080okK100<000000?nf`@0000000P3o]/400`000000okK1000000050?nf
`@03o`00003o]/40okK100<0okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o
]/40000000?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`25ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0okK100T0okK100<0003o0?nf`@3o]/403P3o]/40
0`000?l0okK10?nf`@050?nf`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o
]/4000000080okK100<000000?nf`@0000000P3o]/4010000000okK10?nf`@00000:0?nf`@060000
003o]/40okK10000003o]/4000000P3o]/400`000000okK100000003ooooo`0500000?oooooooooo
ooooo`000000R?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@090?nf
`@030000o`3o]/40okK100h0okK100<0003o0?nf`@3o]/401@3o]/6@ooooo`03o`000?oooooooooo
00oooooo00<00000ooooo`3o]/400P3o]/401P000000okK10?nf`@000000okK100000080okK100<0
00000?nf`@0000002@3o]/401P000000okK10?nf`@000000okK100000080okK100@000000?nf`@3o
]/4000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo08Kooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3o]/402@3o]/400`000?l0okK10?nf`@0>0?nf`@03
0000o`3o]/40okK100D0okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080
okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@040000003o]/40okK1000000P0okK100H0
00000?nf`@3o]/4000000?nf`Ol000020?nf`@040000003o]/40okK1000000;ooooo00<00000oooo
ooooool00_ooool00ol0003oooooooooo`26ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK100X0okK100<0003o0?nf`@3o]/40303o]/400`000?l0okK10?nf`@060?nf`I3o
oooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@060000003o]/40okK10000
003o]/4000000P3o]/4010000000okK10?nf`Ol000070?nf`@070000003o]/40okK10?nf`@000000
okK1000000020?nf`@040000003o]/40okK1000000;ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`26ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100X0
okK100<0003o0?nf`@3o]/40303o]/400`000?l0okK10?nf`@060?nf`I3ooooo00?o0000oooooooo
ool03oooool00`00003oooooo`0000020?nf`@040000003o]/40okK100000080okK100<000000?nf
`@0000000`3o]/400`000000okK10?nf`@030?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/40
0`000000okK1000000020?nf`@040000003o]/7ooooo000000Cooooo00<00000ooooooooool0Qooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0:0?nf`@030000o`3o]/40
okK100`0okK100<0003o0?nf`@3o]/401P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000
ooooool000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40000000@0okK10P00
00000`3o]/400000000000040?nf`@060000003o]/40okK10000003o]/4000000P3o]/4010000000
okK1ooooo`000004ooooo`0300000?oooooooooo08Oooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/402`3o]/400`000?l0okK10?nf`@0:0?nf`@030000o`3o]/40okK100L0
okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool000000080okK100Co00000?nf`@3o
]/4000000P3o]/400`000000okK1000000060?nf`@030000003o]/40okK100@0okK100H000000?nf
`@3o]/4000000?nf`@0000020?nf`@040000003o]/7ooooo000000Cooooo00<00000ooooooooool0
Qoooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0;0?nf`@030000o`3o
]/40okK100X0okK100<0003o0?nf`@3o]/401`3o]/6@ooooo`03o`000?oooooooooo00oooooo00<0
0000ooooo`0000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000/0
okK100L000000?nf`@3o]/40okK10000003o]/4000000080okK100@000000?nf`Oooool000001?oo
ool00`00003oooooooooo`27ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
okK100`0okK100<0003o0?nf`@3o]/40203o]/400`000?l0okK10?nf`@080?nf`I3ooooo00?o0000
ooooooooool03oooool01000003ooooo0?nf`@0000020?nf`@040000003o]/40okK100000080okK1
00<000000?nf`@0000002`3o]/401P000000okK10?nf`@000000okK100000080okK100D000000?nf
`@3o]/7ooooo00000004ooooo`0300000?oooooooooo08Oooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/40303o]/400`000?l0okK10?nf`@080?nf`@030000o`3o]/40okK1
00P0okK1T?ooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK100000080okK100@00000
0?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000090?nf`@070000003o]/40okK10?nf`@00
0000okK1000000020?nf`@050000003o]/40okK1ooooo`0000001?ooool00`00003oooooooooo`27
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK100`0okK100<0003o0?nf
`@3o]/401`3o]/400ol00?l0okK10?nf`@090?nf`I3ooooo00?o0000ooooooooool03oooool01000
003ooooo0?nf`@0000020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/400000
2@3o]/401`000000okK10?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10?nf`Oooool0
000000Cooooo00<00000ooooooooool0Qoooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0=0?nf`@80003o1P3o]/420000o`/0okK1T?ooool00ol0003oooooooooo`0?oooo
o`0400000?ooool0okK100000080okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf
`@0000070?nf`@030000003o]/40okK10080okK100<000000?nf`@0000000P3o]/401@000000okK1
0?nf`Oooool0000000Cooooo00<00000ooooooooool0Qoooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?nf`@0?0?nf`@80003o0`3o]/400`000?l0okK10?nf`@0;0?nf`I3ooooo
00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000030?nf`@040000003o]/40okK10000
0080okK100@000000?nf`@3o]/4000001P3o]/400ol00000okK10?nf`@020?nf`@040000003o]/40
okK100000080okK100?o00000?nf`@3o]/400P000004ooooo`0300000?oooooooooo08Oooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/404@3o]/400`000?l0okK10000o`0>
0?nf`I3ooooo00?o0000ooooooooool03oooool01000003ooooo0?nf`@0000030?nf`@040000003o
]/40okK100000080okK100@000000?nf`@3o]/40okK10`0000020?nf`@800000103o]/4010000000
okK10?nf`Ol000020?nf`@040000003o]/40okK1000000Gooooo00<00000ooooooooool0Qoooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0B0?nf`@030000o`3o]/40okK1
00d0okK1T?ooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK1000000<0okK100@00000
0?nf`@3o]/4000000P3o]/400`000000okK10?nf`@040?nf`@8000001P3o]/400`000000okK10000
00030?nf`@040000003o]/40okK1000000Gooooo00<00000ooooooooool0Qoooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03ooo
ool01@00003ooooo0?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1000000020?nf`@03
0000003o]/40okK100X0okK100Co00000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40
000000Gooooo00<00000ooooooooool0Qoooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/40
00000080okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100T0okK100D0
00000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000001Oooool00`00003o
ooooooooo`27ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280okK1
T?ooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@0000000P3o]/401@000000
okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/402@3o]/401@000000okK10?nf`@3o]/40
00000080okK100D000000?nf`@3o]/40okK100000005ooooo`0300000?oooooooooo08Oooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooo
oooo00oooooo00D00000ooooo`3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@000000
0`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/40
00000`3o]/400`00003oooooooooo`03ooooo`0300000?oooooooooo08Oooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo
00D00000ooooo`3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`00
0000okK10?nf`@060?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o
]/40000000Kooooo00<00000ooooooooool0Q_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o
]/40000000<0okK100D000000?nf`@3o]/40okK1000000030?nf`@03o`0000000000okK100D0okK1
00?o00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK100<00000oooooooo
ool01?ooool00`00003oooooooooo`26ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`0500000?ooool0okK10?nf`@00
00000`3o]/401@000000okK10?nf`@3o]/40000000D0okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`00003oooooooooo`04
ooooo`03o`0000000000000008Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3o]/408P3o]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/401@00
0000okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/400`3o]/4010000000okK10?nf`@00
00060?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`00003oooooooooo`07ooooo`@00000
2_ooool[000004gooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/408P3o
]/6@ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/400P3o]/401@000000okK10?nf
`@3o]/40000000<0okK100?o00000?nf`@3o]/40103o]/400`00003o00000?nf`@060?nf`@050000
003o]/40okK10?nf`@0000000`3o]/400ooooooo0000ooooo`0;ooooo`X00000:oooool900000003
o`0000000000000000800000?oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0R0?nf`I3ooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf`@050000
003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@0=0?nf`@050000003o]/40okK10?nf
`@0000000`3o]/42ooooo`0300000?oooooooooo04cooooo1`00000hooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0okK10280okK1T?ooool00ol0003oooooooooo`0?ooooo`03
00000?ooool0okK10080okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK1
00d0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@03ooooo`0300000?oooooooooo
05;ooooo1000000dooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK10280
okK1T?ooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100D000000?nf`@3o
]/40okK1000000030?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/400P3o]/400ol0
0000okK10?nf`@04ooooo`0300000?oooooooooo017ooooo:`00000Iooooo`L00000;Oooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0R0?nf`I3ooooo00?o0000oooooooo
ool03oooool00`00003ooooo0?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`00
0000okK10?nf`@0=0?nf`@030000003o]/40okK10080okK10P0000000`3o]/7oooooooooo`03oooo
o`03o`0000000000000000h0000000?o000000000?ooool0:_ooool00`00003o0000000000040000
01Wooooo00@00000o`00000000000000:Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@020?nf
`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK10?nf`@0=0?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/40803o]/4C000001D0okK11`00000F0?nf`@<0000000<0okK1
ooooooooool08oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf
`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/40000000@0okK100D00000
0?nf`@3o]/40okK10000000@0?nf`@030000003o]/40okK100@0okK10`00000A0?nf`@h000004`3o
]/4>000000h0okK11`00000B0?nf`@@000008_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o
]/40000000@0okK100D000000?nf`@3o]/40okK10000000@0?nf`@03o`0000000000000000L0okK1
00Co000000000000000000000P3o]/4400000003o`0000000000000000@000003P3o]/4C000000h0
okK12`00000:0?nf`@80000000?o00000000003o]/403P3o]/43ooooo`@000007_ooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool0
3oooool01@00003ooooo0?nf`@3o]/40000000@0okK100D000000?nf`@3o]/40okK10000000C0?nf
`@030000003o]/40okK100P0okK10P00000?0?nf`@X000004`3o]/4>000000/0okK10`00000;0?nf
`@<00000303o]/47ooooo`<000006oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/400000
00@0okK100D000000?nf`@3o]/40okK10000000D0?nf`@<000003@3o]/4;000000L0okK16@00000;
0?nf`@L000001`3o]/44000000X0okK1100000080?nf`@[ooooo0P00000Iooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`0?oooo
o`0500000?ooool0okK10?nf`@0000000`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100@0okK100?o00000000000000000`00000;0?nf`@d000002`3o]/47000001T0okK12P000008
0?nf`@@000001`3o]/43000000/0okK10`0000050?nf`@cooooo00<00000ooooooooool05_ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0n0?nf`@/0003o00?o003o0000
o`000?l050000?l]0?nf`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/40
000000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40
okK100@0okK11000000G0?nf`@P000000`3o]/4Q000000H0okK11@0000070?nf`@<000001`3o]/44
000000X0okK100<00000o`00000000000P3o]/4=ooooo`0300000?l0003ooooo01Gooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40=@3o]/490000ob80okK110000?lY0?nf
`BGooooo00?o0000ooooooooool03oooool01@00003ooooo0?nf`@3o]/40000000<0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100P0okK10`00000=
0?nf`@L00000103o]/47000000/0okK12ol0000;0?nf`@L00000103o]/47000000<0okK110000007
0?nf`@<000002P3o]/42000000oooooo00<00000ooooooooool04oooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@0a0?nf`@@0003o;`3o]/450000ob@0okK19Oooool00ol0
003oooooooooo`0?ooooo`0400000?ooool0okK1000000@0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100`0okK13@0000070?nf`@@000001`3o]/4;
o`0000/0okK12ol000070?nf`@@000001`3o]/42000000D0okK10`0000070?nf`@0300000?l00000
okK100T0okK100<00000ooooooooool03Oooool00`00003oooooooooo`0Booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0okK102l0okK10P000?lh0?nf`@<0003o8@3o]/4Uoooo
o`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/400000103o]/401@000000okK10?nf`@3o
]/7o000000@0okK100<000000?nf`@3o]/406P3o]/4200000003o`0000000000000000800000103o
]/47o`0000@0okK15_l000070?nf`@Co00001`3o]/401?l0000000000000000000050?nf`@800000
1P3o]/400ol00000okK10?nf`@060?nf`@800000203o]/400ooooooo0000ooooo`0>ooooo`030000
0?l0003ooooo017ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40;@3o
]/420000ocd0okK100<0003o0?nf`@3o]/407P3o]/4Uooooo`03o`000?oooooooooo00oooooo00@0
0000ooooo`3o]/400000103o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o
]/405`3o]/43000000L0okK11?l000040?nf`@Oo00005P3o]/47o`0000@0okK10ol000080?nf`@80
00001@3o]/42000000D0okK10P0000080?nf`@030000003o]/40okK100D0okK10_ooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/40:`3o]/420000od00okK10P000?lN0?nf`BGooooo00?o0000ooooooooool0
3oooool00`00003ooooo000000050?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000
okK10?nf`@0D0?nf`@<000001`3o]/43o`0000D0okK10ol0000:0?nf`@oo00002`3o]/44o`0000<0
okK11?l000060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@060?nf`@030000003o]/40okK100@0okK10oooool00`00003oooooooooo`0=ooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40
:@3o]/420000od@0okK100<0003o0?nf`@3o]/406`3o]/4Uooooo`03o`000?oooooooooo00oooooo
00<00000ooooo`000000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/404P3o]/42000000T0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK1
0?nf`@080?nf`@?o00003`3o]/46o`0000T0okK100?o00000?nf`@3o]/40103o]/400ol00000okK1
0?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400ol00000okK1
0?nf`@050?nf`@030000003o]/40okK100@0okK10oooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40:03o
]/400`000?l0okK10?nf`@150?nf`@030000o`3o]/40okK101X0okK19Oooool00ol0003ooooooooo
o`0?ooooo`0300000?ooool0okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK10100okK10P00000:0?nf`@03o`00003o]/40okK100@0okK10_l0
00070?nf`@Co0000603o]/43o`0000L0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf
`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100<0okK11?ooool00`00003oooooooooo`0=ooooo`0300000?oo
oooooooo00kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/409`3o]/40
0`000?l0okK10?nf`@0P0?nf`@?o0000903o]/400`000?l0okK10?nf`@0I0?nf`BGooooo00?o0000
ooooooooool03oooool00`00003ooooo0?nf`@040?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@0=0?nf`@<000002`3o]/400ol00000okK10?nf`@05
0?nf`@03o`00003o]/40okK100@0okK10_l0000N0?nf`@03o`00003o]/40okK100D0okK100?o0000
0?nf`@3o]/40103o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/40103o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100<0okK11?ooool0
0`00003oooooooooo`0=ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3o]/409P3o]/400`000?l0okK10?nf`@0P0?nf`@Go0000903o]/400`00
0?l0okK10?nf`@0H0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@040?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0;0?nf
`@030000003o]/40okK100/0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@050?nf
`@03o`00003o]/40okK100h0okK10_l0000>0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf
`@3o]/40103o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK10080okK11Oooool00`00
003oooooooooo`0=ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3o]/409P3o]/400`000?l0okK10?nf`@0P0?nf`@Go0000903o]/400`000?l0
okK10?nf`@0H0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@040?nf`@03
0000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0:0?nf`@<0
00002`3o]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o
]/403@3o]/44o`0000l0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@03
o`00003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK100D0okK100<000000?nf`@3o]/400P3o]/45ooooo`0300000?oooooooooo00go
oooo00<00000ooooooooool03Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?nf`@0W0?nf`@030000o`3o]/40okK101l0okK11Ol0000S0?nf`@030000o`3o]/40okK101T0okK1
9Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK100@0okK100<000000?nf`@3o]/40
0`3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100d0okK10P00000:0?nf`@03o`00
003o]/40okK100@0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@0O0?nf`@03o`00
003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@040?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@050?nf`@030000
003o]/40okK10080okK11Oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo00gooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40:03o]/400`000?l0okK10?nf
`@0O0?nf`@?o00008`3o]/400`000?l0okK10?nf`@0J0?nf`BGooooo00?o0000ooooooooool03ooo
ool00`00003ooooo000000050?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK100P0okK100?o00000?nf`@3o]/40103o
]/400ol00000okK10?nf`@050?nf`@?o00006`3o]/43o`0000L0okK100?o00000?nf`@3o]/40103o
]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100<0okK11?ooool00`00003ooooooooo
o`0=ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3o]/40:03o]/400`000?l0okK10?nf`@130?nf`@80003o7@3o]/4Uooooo`03o`000?oooooo
oooo00oooooo00<00000ooooo`0000001@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/403P3o]/43000000P0okK100?o00000?nf`@3o]/40103o]/42
o`0000P0okK11?l0000D0?nf`@?o0000203o]/42o`0000H0okK100?o00000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/401P3o]/40
0`000000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0>
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK102T0okK10P000?m10?nf
`@80003o7`3o]/4Uooooo`03o`000?oooooooooo00oooooo00@00000ooooo`3o]/4000001@3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100?o00000000003o]/40403o]/40
0`000000okK10?nf`@060?nf`@;o00001P3o]/44o`0000P0okK11ol000060?nf`@Oo00001`3o]/44
o`0000H0okK10_l000050?nf`@8000001@3o]/42000000H0okK100<000000?nf`@3o]/40103o]/42
00000003o`00003o]/40okK100@0okK10_ooool00`00003o0000ooooo`0=ooooo`8000004Oooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0[0?nf`@<0003o>`3o]/430000
ob40okK19Oooool00ol0003oooooooooo`0?ooooo`0400000?ooool0okK1000000H0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@050?nf`@<000003`3o]/400ol00000000000000007
0?nf`@?o00001`3o]/400ol00000okK10?nf`@0<0?nf`@Ko00002P3o]/44o`0000L0okK10ol00004
0?nf`@<000001@3o]/42000000L0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@07
0?nf`@03ooooo`00003ooooo00gooooo0P00000Cooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0okK102h0okK10`000?le0?nf`@<0003o903o]/4Uooooo`03o`000?oooooooooo
00oooooo00D00000ooooo`3o]/40okK1000000060?nf`@030000003o]/40okK10080okK10`000007
0?nf`@L000002`3o]/43000000L0okK11?l000040?nf`@Oo0000403o]/47o`0000P0okK10ol00004
0?nf`@<000001P3o]/42000000H0okK10`0000050?nf`@8000002@3o]/42000000kooooo00<00000
ooooooooool04oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0a0?nf
`@D0003o;@3o]/430000obL0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK1
0080okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00/0okK1200000060?nf`@D000001P3o]/48o`0000<0okK14?l000060?nf`@Wo00000P3o]/450000
00D0okK100Co00000000000000000000103o]/4200000003o`0000000000okK100D0okK100?o0000
0000003o]/40203o]/42000000030?nf`Ooooooooooo00cooooo00<00000ooooooooool05?ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@0f0?nf`@@0003o9@3o]/440000
obX0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100<000000?nf
`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@03o`000000000000000180okK100?o00000000
000000000`0000040?nf`@03o`0000000000000000@00000203o]/4Io`0000T0okK10P0000080?nf
`@<00000103o]/43000000P0okK10P0000090?nf`@0300000?l00000okK10080okK13Oooool00`00
003o0000ooooo`0Eooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK103X0
okK12P000?lA0?nf`@X0003o;P3o]/4Uooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o
]/400`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100H0okK12P00000>0?nf`@@0
00001`3o]/47000001P0okK12`0000030?nf`@L00000103o]/43000000L0okK11000000:0?nf`@03
0000003o]/40okK100<0okK12oooool2000001Sooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3o]/40A03o]/4A0000ocP0okK19Oooool00ol0003oooooooooo`0?ooooo`030000
0?ooool0okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0?0?nf`@/00000
1`3o]/47000000L0okK1600000070?nf`@L000001`3o]/44000000L0okK10`00000;0?nf`@<00000
1P3o]/49ooooo`8000006_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf
`@2=0?nf`BGooooo00?o0000ooooooooool03oooool00`00003ooooo0?nf`@050?nf`@03o`000000
0000000000D0okK100@00000o`00000000000000603o]/47000000L0okK12`00000@0?nf`@/00000
1`3o]/4500000003o`0000000000okK100H0okK11000000:0?nf`@@000002@3o]/46ooooo`<00000
7?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o
0000ooooooooool03oooool00`00003ooooo0?nf`@080?nf`@030000003o]/40okK100H0okK10`00
000L0?nf`@L000002`3o]/4@000000/0okK11`00000;0?nf`@<000002`3o]/43000000d0okK11?oo
ool2000001oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o]/40S@3o]/4U
ooooo`03o`000?oooooooooo00oooooo00<00000ooooo`3o]/402@3o]/400`000000okK10?nf`@08
0?nf`AP000002`3o]/4V000000/0okK11`00000:0?nf`@@00000403o]/42ooooo`8000008Oooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000oooo
ooooool03oooool00`00003oooooo`00000:0?nf`@03o`00003o]/40okK101l0okK11`00000^0?nf
`@L00000303o]/45000001<0okK10`00000Sooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0okK108d0okK19Oooool00ol0003oooooooooo`0?ooooo`0400000?ooool000000000
00X0okK10P00000V0?nf`A8000002P3o]/4@00000003o`0000000000okK100d0okK1100000000ol0
0000okK10?nf`@0B0?nf`@0500000?l0000000000000003o]/409Oooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000ooooooooool03oooool01@00
003ooooo0?nf`@3o]/40000000/0okK10`00000=0?nf`@l000006@3o]/4:000001T0okK11`00000E
0?nf`@@000001@3o]/4Uooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0okK1
08d0okK19Oooool00ol0003oooooooooo`0?ooooo`0300000?ooool0okK10080okK100?o00000?nf
`@3o]/402`3o]/4=000000l0okK12`00000V0?nf`@/000005@3o]/47000000T0okK19Oooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?nf`@2=0?nf`BGooooo00?o0000oooooooo
ool03oooool00`00003ooooo0?nf`@030?nf`@03o`00003o]/40okK10340okK1400000050?nf`@03
o`0000000000000000h000007@3o]/400ol0000000000000000@0?nf`BGooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo]_l0000AoooookH000002_oo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0501253 0.457898 0.000460518 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.14912 -0.0125 -9 -9 ]
[.14912 -0.0125 9 0 ]
[.27444 -0.0125 -3 -9 ]
[.27444 -0.0125 3 0 ]
[.39975 -0.0125 -9 -9 ]
[.39975 -0.0125 9 0 ]
[.52506 -0.0125 -6 -9 ]
[.52506 -0.0125 6 0 ]
[.65038 -0.0125 -12 -9 ]
[.65038 -0.0125 12 0 ]
[.77569 -0.0125 -6 -9 ]
[.77569 -0.0125 6 0 ]
[.901 -0.0125 -12 -9 ]
[.901 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08948 -24 -4.5 ]
[-0.0125 .08948 0 4.5 ]
[-0.0125 .18159 -24 -4.5 ]
[-0.0125 .18159 0 4.5 ]
[-0.0125 .27369 -24 -4.5 ]
[-0.0125 .27369 0 4.5 ]
[-0.0125 .36579 -24 -4.5 ]
[-0.0125 .36579 0 4.5 ]
[-0.0125 .4579 -6 -4.5 ]
[-0.0125 .4579 0 4.5 ]
[-0.0125 .55 -18 -4.5 ]
[-0.0125 .55 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.14912 0 m
.14912 .61803 L
s
.27444 0 m
.27444 .61803 L
s
.39975 0 m
.39975 .61803 L
s
.52506 0 m
.52506 .61803 L
s
.65038 0 m
.65038 .61803 L
s
.77569 0 m
.77569 .61803 L
s
.901 0 m
.901 .61803 L
s
0 .08948 m
1 .08948 L
s
0 .18159 m
1 .18159 L
s
0 .27369 m
1 .27369 L
s
0 .36579 m
1 .36579 L
s
0 .4579 m
1 .4579 L
s
0 .55 m
1 .55 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.14912 0 m
.14912 .00625 L
s
[(2.5)] .14912 -0.0125 0 1 Mshowa
.27444 0 m
.27444 .00625 L
s
[(5)] .27444 -0.0125 0 1 Mshowa
.39975 0 m
.39975 .00625 L
s
[(7.5)] .39975 -0.0125 0 1 Mshowa
.52506 0 m
.52506 .00625 L
s
[(10)] .52506 -0.0125 0 1 Mshowa
.65038 0 m
.65038 .00625 L
s
[(12.5)] .65038 -0.0125 0 1 Mshowa
.77569 0 m
.77569 .00625 L
s
[(15)] .77569 -0.0125 0 1 Mshowa
.901 0 m
.901 .00625 L
s
[(17.5)] .901 -0.0125 0 1 Mshowa
.125 Mabswid
.04887 0 m
.04887 .00375 L
s
.07393 0 m
.07393 .00375 L
s
.099 0 m
.099 .00375 L
s
.12406 0 m
.12406 .00375 L
s
.17419 0 m
.17419 .00375 L
s
.19925 0 m
.19925 .00375 L
s
.22431 0 m
.22431 .00375 L
s
.24937 0 m
.24937 .00375 L
s
.2995 0 m
.2995 .00375 L
s
.32456 0 m
.32456 .00375 L
s
.34962 0 m
.34962 .00375 L
s
.37469 0 m
.37469 .00375 L
s
.42481 0 m
.42481 .00375 L
s
.44987 0 m
.44987 .00375 L
s
.47494 0 m
.47494 .00375 L
s
.5 0 m
.5 .00375 L
s
.55013 0 m
.55013 .00375 L
s
.57519 0 m
.57519 .00375 L
s
.60025 0 m
.60025 .00375 L
s
.62531 0 m
.62531 .00375 L
s
.67544 0 m
.67544 .00375 L
s
.7005 0 m
.7005 .00375 L
s
.72556 0 m
.72556 .00375 L
s
.75063 0 m
.75063 .00375 L
s
.80075 0 m
.80075 .00375 L
s
.82581 0 m
.82581 .00375 L
s
.85088 0 m
.85088 .00375 L
s
.87594 0 m
.87594 .00375 L
s
.92607 0 m
.92607 .00375 L
s
.95113 0 m
.95113 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08948 m
.00625 .08948 L
s
[(-800)] -0.0125 .08948 1 0 Mshowa
0 .18159 m
.00625 .18159 L
s
[(-600)] -0.0125 .18159 1 0 Mshowa
0 .27369 m
.00625 .27369 L
s
[(-400)] -0.0125 .27369 1 0 Mshowa
0 .36579 m
.00625 .36579 L
s
[(-200)] -0.0125 .36579 1 0 Mshowa
0 .4579 m
.00625 .4579 L
s
[(0)] -0.0125 .4579 1 0 Mshowa
0 .55 m
.00625 .55 L
s
[(200)] -0.0125 .55 1 0 Mshowa
.125 Mabswid
0 .02041 m
.00375 .02041 L
s
0 .04343 m
.00375 .04343 L
s
0 .06646 m
.00375 .06646 L
s
0 .11251 m
.00375 .11251 L
s
0 .13554 m
.00375 .13554 L
s
0 .15856 m
.00375 .15856 L
s
0 .20461 m
.00375 .20461 L
s
0 .22764 m
.00375 .22764 L
s
0 .25067 m
.00375 .25067 L
s
0 .29672 m
.00375 .29672 L
s
0 .31974 m
.00375 .31974 L
s
0 .34277 m
.00375 .34277 L
s
0 .38882 m
.00375 .38882 L
s
0 .41185 m
.00375 .41185 L
s
0 .43487 m
.00375 .43487 L
s
0 .48092 m
.00375 .48092 L
s
0 .50395 m
.00375 .50395 L
s
0 .52698 m
.00375 .52698 L
s
0 .57303 m
.00375 .57303 L
s
0 .59605 m
.00375 .59605 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.14912 .61178 m
.14912 .61803 L
s
.27444 .61178 m
.27444 .61803 L
s
.39975 .61178 m
.39975 .61803 L
s
.52506 .61178 m
.52506 .61803 L
s
.65038 .61178 m
.65038 .61803 L
s
.77569 .61178 m
.77569 .61803 L
s
.901 .61178 m
.901 .61803 L
s
.125 Mabswid
.04887 .61428 m
.04887 .61803 L
s
.07393 .61428 m
.07393 .61803 L
s
.099 .61428 m
.099 .61803 L
s
.12406 .61428 m
.12406 .61803 L
s
.17419 .61428 m
.17419 .61803 L
s
.19925 .61428 m
.19925 .61803 L
s
.22431 .61428 m
.22431 .61803 L
s
.24937 .61428 m
.24937 .61803 L
s
.2995 .61428 m
.2995 .61803 L
s
.32456 .61428 m
.32456 .61803 L
s
.34962 .61428 m
.34962 .61803 L
s
.37469 .61428 m
.37469 .61803 L
s
.42481 .61428 m
.42481 .61803 L
s
.44987 .61428 m
.44987 .61803 L
s
.47494 .61428 m
.47494 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55013 .61428 m
.55013 .61803 L
s
.57519 .61428 m
.57519 .61803 L
s
.60025 .61428 m
.60025 .61803 L
s
.62531 .61428 m
.62531 .61803 L
s
.67544 .61428 m
.67544 .61803 L
s
.7005 .61428 m
.7005 .61803 L
s
.72556 .61428 m
.72556 .61803 L
s
.75063 .61428 m
.75063 .61803 L
s
.80075 .61428 m
.80075 .61803 L
s
.82581 .61428 m
.82581 .61803 L
s
.85088 .61428 m
.85088 .61803 L
s
.87594 .61428 m
.87594 .61803 L
s
.92607 .61428 m
.92607 .61803 L
s
.95113 .61428 m
.95113 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08948 m
1 .08948 L
s
.99375 .18159 m
1 .18159 L
s
.99375 .27369 m
1 .27369 L
s
.99375 .36579 m
1 .36579 L
s
.99375 .4579 m
1 .4579 L
s
.99375 .55 m
1 .55 L
s
.125 Mabswid
.99625 .02041 m
1 .02041 L
s
.99625 .04343 m
1 .04343 L
s
.99625 .06646 m
1 .06646 L
s
.99625 .11251 m
1 .11251 L
s
.99625 .13554 m
1 .13554 L
s
.99625 .15856 m
1 .15856 L
s
.99625 .20461 m
1 .20461 L
s
.99625 .22764 m
1 .22764 L
s
.99625 .25067 m
1 .25067 L
s
.99625 .29672 m
1 .29672 L
s
.99625 .31974 m
1 .31974 L
s
.99625 .34277 m
1 .34277 L
s
.99625 .38882 m
1 .38882 L
s
.99625 .41185 m
1 .41185 L
s
.99625 .43487 m
1 .43487 L
s
.99625 .48092 m
1 .48092 L
s
.99625 .50395 m
1 .50395 L
s
.99625 .52698 m
1 .52698 L
s
.99625 .57303 m
1 .57303 L
s
.99625 .59605 m
1 .59605 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.07393 .38863 L
.12406 .41747 L
.17419 .44377 L
.22431 .45915 L
.27444 .4705 L
.32456 .47977 L
.37469 .48869 L
.42481 .50189 L
.47494 .52163 L
.52506 .53202 L
.57519 .54225 L
.62531 .55549 L
.67544 .57416 L
.72556 .59431 L
.77569 .60149 L
.82581 .60282 L
.87594 .60315 L
.92607 .60327 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.07393 .38863 Mdot
.12406 .41747 Mdot
.17419 .44377 Mdot
.22431 .45915 Mdot
.27444 .4705 Mdot
.32456 .47977 Mdot
.37469 .48869 Mdot
.42481 .50189 Mdot
.47494 .52163 Mdot
.52506 .53202 Mdot
.57519 .54225 Mdot
.62531 .55549 Mdot
.67544 .57416 Mdot
.72556 .59431 Mdot
.77569 .60149 Mdot
.82581 .60282 Mdot
.87594 .60315 Mdot
.92607 .60327 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0001Kooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Hooooo`?o00006Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Dooooo`?o00001?ooool2o`0001;ooooo0ol00002ooooo`Go0000
0oooool00ol0003oooooooooo`02ooooo`?o00004Oooool3o`0000?ooooo0ol0000Booooo`?o0000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Aooooo`007ooo
ool01?l0003oooooooooool0000Fooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Fooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000@ooooo`007oooool01?l0003oooooooooool0000Gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`007ooo
ool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0>ooooo`007oooool01?l0003oooooooooool0000Eooooo`05
o`000?ooooooooooooooool000001oooool4o`0001Oooooo1?l0000Kooooo`03o`000?oooooooooo
00Gooooo1?l0000Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool4o`0001;ooooo00Co
0000oooooooooooooooo1?l0000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool4o`00017ooooo000Oooooo`04o`000?ooooooooooo`0001Gooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool05Oooool2o`0000Cooooo00Co0000oooo
oooooooo00004Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`0Booooo`008?ooool2o`0001Oooooo0ol0
0008ooooo`Go00005_ooool5o`0001Kooooo1Ol00007ooooo`Go00005?ooool00ol0003ooooooooo
o`03ooooo`;o00004oooool00ol0003oooooooooo`02ooooo`?o00002?ooool5o`00017ooooo00Co
0000oooooooooooooooo1Ol0000Booooo`04o`000?ooooooooooooooo`Go00001oooool5o`00013o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Kooooool0
00001@000001ooooo`006oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00<00000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool00_ooool3ool001kooooo00?o0000ooooooooool07_ooool00`00003ooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00<00000ooooooooool07_ooool00ol0003ooooooooo
o`0Mooooo`0300000?oooooooooo01kooooo00?o0000ooooooooool05_ooool10000007ooooo000K
ooooo`0400000?ooooooooooooooo`Goo`007Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00@00000oooooooooooooooo1Ooo000Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`006oooool01000003o0000ooooooooool5ool001gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05Ooo
ool1o`00004000000Oooool001_ooooo00<00000ooooooooool00_ooool3ool001kooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
6oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01cooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool07?oo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool01?ooool0
0`00003oooooooooo`0Looooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Koooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Looooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo01cooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Kooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`05ooooo`0300000?oooooooooo
01_ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
6oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool06ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2
o`0000Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Kooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool06oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Go000000?o
ooooo`000?ooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00`00003o00000000O`050000O`030000000007l0001o0?L0
001o0Ol000010000007ooooo0007ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0Joooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Moooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00Kooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo01[o
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01go
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool05_ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool06_ooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`0Jooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`06
ooooo`0300000?oooooooooo01[ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0M
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05Oooool1o`00004000000Oooool0
01_ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01Wo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01go
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool06Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`006oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01Wooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool05_ooool10000007ooooo000Kooooo`0300000?l0003ooooo00Oooooo00<00000oooo
ooooool06Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007o
oooo000Kooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool06Oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0Iooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0M
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Koooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001_ooooo00<00000o`000?ooool02?ooool00`00003oooooooooo`0Hooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool06?ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`0Hooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01Sooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool05_ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo01Oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo0005o`000003ooooool0003o
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00<00000o`00000007l02@0007l00`000000001o0000O`3c0000O`7o0000
0@000001ooooo`001_ooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool05oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool000Kooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`0Gooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0`00003oooooooooo`09ooooo`0300000?oooooooooo01Oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool1
0000007ooooo0008ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo
00Wooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_o
oooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`006oooool00`00003o0000ooooo`0:ooooo`0300000?oooooooooo01Kooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool02_oo
ool00`00003oooooooooo`0Fooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0:ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool05_ooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`0Fooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo
000Kooooo`0300000?l0003ooooo00[ooooo00<00000ooooooooool05_ooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo01Kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo
00_ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01Gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<0
0000ooooooooool05Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000
o`000?ooool02oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Gooooo0Ol00001
0000007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool05Oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`0Eooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`002?ooool3o`0000?ooooo
0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01Cooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool05_ooool10000007ooooo0009ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
1Ol000000ooooooo0000o`000003o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool05?ooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool000Kooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l03000
07l00`000000001o0000O`3`0000O`7o00000@000001ooooo`001oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo
0008ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`002Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`006oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01Cooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo00gooooo00<00000
ooooooooool04oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`00
0?ooool03Oooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Gooooo0Ol000010000
007ooooo000Kooooo`0300000?oooooooooo00gooooo00<00000ooooooooool04oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool03Oooool00`00003ooooo
ooooo`0Cooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0=ooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001_ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Coooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Moooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0>ooooo`03
00000?oooooooooo01;ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool03_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`006oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01;ooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool04_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooo
ooooool03_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`006oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01;ooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?l0003ooooo00kooooo00<00000ooooooooool0
4_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`0>ooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo017ooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool05_ooool10000007ooooo0005o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?l00000001o00l0001o00<000000000O`0007l0k@0007l1o`000040
00000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo017ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool05_ooool10000007ooooo0006ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooooooo
o`0@ooooo`0300000?oooooooooo013ooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?oooooooooo00oooooo0ooo000Aooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`006oooool00`00003oooooooooo`0>ooooo`Goo`004?ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001_ooooo00<00000o`000?ooool03_ooool5ool0013ooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool05Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool03_ooool5ool000030000
0?oooooooooo00gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oo
oooooooo00oooooo0ooo0002ooooo`8000003Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool05_ooool2000000_ooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool02?ooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool06Oooool200000004
oooooooo003oo`00ool000Cooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Moooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`03
00000?l0003ooooo01_ooooo1Ooo0003ooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Gooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo01_ooooo1Ooo0003ooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Kooooo`Goo`0000@00000ooooooooool0001o
8?ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?oooooooooo01cooooo0ooo0002ooooo`80000000<0
001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo0P00000O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08oooool00`0007oooooo0000000Noooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001_ooooo00<00000o`000?ooool08oooool00`0007ooooooooooo`0200000004
oooooooo003oo`00ool001Sooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Moooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02?o
oooo00<0001oooooooooool00_ooool5ool001Oooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Sooooo`030000Oooooooooooo00;ooooo1Ooo000Gooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Cooooo0_l0
0005ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool00_ooool5ool000<000005?oo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_oo
ool10000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool08ooo
ool00`0007ooooooooooo`03ooooo`?oo`001?ooool3000000?ooooo0ooo000;ooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Sooooo`030000Oooo
oooooooo00gooooo0P000005ool000[ooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`0300000?l00000001o03D0001o1Ooo00350000O`7o00000@000001ooooo`004oooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool03ooo
ool5ool000D000001?ooool3ool001oooooo00<0001oooooooooool07Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`0Sooooo`030000Oooooooooooo013ooooo0ooo0006ooooo`<000001Ooo000Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Dooooo`;o00001Oooool0
0`00003oooooooooo`0Sooooo`030000Oooooooooooo01cooooo1Ooo00000`00003oooooooooo`0K
ooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0M
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Koooo
o`0300000?oooooooooo02?ooooo00<0001oooooooooool07?ooool5ool00003ooooo`0000000000
00D0000000Coooooool00?oo003oo`004_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo
01gooooo0ooo0009ooooo`Goo`004Oooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Sooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool02?ooool5ool000D000001?ooool3ool000Gooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0Sooooo`030000Oooooooooooo01kooooo00<0001oooooooooool02?ooool5ool000Gooooo
0`000005ool000Cooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001_ooooo00<00000ooooooooool08oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo00Wooooo0ooo0009ooooo`Goo`001?ooool00`0007ooooooooooo`0Mooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool05Oooool5ool000D000001?ooool3ool001Sooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Fooooo`?oo`001Oooool0100007l00000000000000005
ool001Oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo
02?ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`040000Oooooooooooo
ooooo`Goo`005oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`00
0?ooool08oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00@0001ooooo
oooooooooooo1Ooo0002000001Gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0M
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05Oooool1o`00004000000Oooool0
01_ooooo00<00000ooooooooool08oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool00_ooool3ool000?ooooo0`00000Booooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0;ooooo`8000000_ooool3ool000_o
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo00gooooo
00<00000ool00?oo00000ooo000:ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Sooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0>ooooo`Goo`002_ooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool08oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool03_ooool5ool000D000001?ooool3ool001oooooo00<0001o
ooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`006oooool00`00003o0000ooooo`0Sooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0?ooooo`?oo`001_ooool3000000Goo`007_ooool00`00
07ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05Oooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool08oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool06oooool5ool001kooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Kooooo`Goo`001@000004ooooo`?oo`004_ooool00`0007oooooo
ooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo
0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo02?ooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01cooooo0ooo
0006ooooo`<000001Ooo000Aooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool08oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07Oooool00`0007ooooooooooo`08ooooo`Goo`004Oooool00`0007ooooooooooo`0Mooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo02?ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool02?ooool5ool000D000001?ooool3ool0
00Gooooo00<0001oooooooooool07Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o0940001o0ooo0006
0000O`<000001Ooo001M0000O`7o00000@000001ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo02?ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01gooooo00<0001oooooooooool05Oooool5ool000Cooooo00<0001oooooooooool0
7Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool05Oooool5ool0
008000000_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool05_ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03
00000?oooooooooo02?ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01gooooo00<0001oooooooooool05_ooool3ool000?ooooo0`00000Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`030000
0?oooooooooo02?ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007l0000000000002ooooo`?oo`00
6?ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Sooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00@0001oooooooooool00000
1Ooo000Gooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo
000Kooooo`0300000?l0003ooooo02?ooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool0100007oooooooooo
ooooool5ool001Oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Eooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01kooooo00@0
001ooooooooooooooooo1Ooo0002000001Gooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool08oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo00;ooooo0ooo0003ooooo`<000004_ooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0S
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0M
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool02oooool2000000;ooooo0ooo000;
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool05_ooool10000007ooooo000Koooo
o`0300000?oooooooooo02?ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01gooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0=oooo
o`0300000?oo003oo`0000?oo`002_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Mooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool03_ooool5ool0000300000?oooooooooo00Kooooo0ooo000:ooooo`?o
o`004_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0
8oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo00kooooo1Ooo00000oooool00000
00000005000000Goo`002?ooool5ool000Wooooo0ooo0005ooooo`030000Oooooooooooo00;ooooo
0ooo000:ooooo`?oo`000oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool08ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo00oooooo0ooo0009ooooo`Goo`002000
0005ool000D000000oooool5ool000Cooooo00@0001ooooooooooooooooo1Ooo0008ooooo`Goo`00
0oooool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Kooooo`Goo`002?ooool5ool000Gooooo0`000005ool000P000001Ooo
0008000000Goo`000oooool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Looooo`?oo`002_ooool3ool000Wooooo1Ooo0004
ooooo`040000Ooooooooooooooooo`Goo`002?ooool5ool000?ooooo0@000001ooooo`006oooool0
0`00003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ooo0005ooooo`03o`000?oooooo
oooo00;ooooo0ooo0005ooooo`03o`000?oooooooooo00;ooooo0ooo0004ooooo`4000000Oooool0
01_oooooo`0000050000007ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.56866, -1114.44, \
0.076841, 8.3638}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(full1\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #3: blue class, scalar covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 9;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes scalar covariances", "Subsubsection"],

Cell[BoxData[
    \(\(initScalar\  = \ EMInitializationScalar[data2, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data2, initScalar, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.2699999999999818`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AntiPolygonalAllPlot[poly, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.01923 .35211 m
.02137 .36538 L
.02524 .38462 L
.03007 .40385 L
.03584 .42308 L
.03846 .43092 L
.04254 .44231 L
.05018 .46154 L
.05769 .47851 L
.05876 .48077 L
.06839 .5 L
.07692 .51548 L
.0791 .51923 L
.09104 .53846 L
.09615 .54609 L
.10436 .55769 L
.11538 .57206 L
.11933 .57692 L
.13462 .59429 L
.13637 .59615 L
.15385 .6133 L
.15614 .61538 L
.17308 .62952 L
.1798 .63462 L
.19231 .64331 L
.20939 .65385 L
.21154 .65507 L
.23077 .66514 L
.24767 .67308 L
.25 .67413 L
.26923 .6827 L
.28846 .69199 L
.28906 .69231 L
.30769 .70376 L
.31753 .71154 L
.32692 .72083 L
.33545 .73077 L
.34615 .74599 L
.34882 .75 L
.36088 .76923 L
.36538 .77676 L
.37286 .78846 L
.38462 .80634 L
.38558 .80769 L
.39992 .82692 L
.40385 .83191 L
.4162 .84615 L
.42308 .85361 L
.43503 .86538 L
.44231 .8721 L
.45726 .88462 L
.46154 .88796 L
.48077 .90161 L
.48421 .90385 L
.5 .91334 L
.51845 .92308 L
.51923 .92345 L
.53846 .93202 L
.55769 .93934 L
.56654 .94231 L
.57692 .94541 L
.59615 .95037 L
.61538 .95435 L
.63462 .95741 L
.65385 .95962 L
.67308 .96104 L
.68495 .96154 L
.69231 .96172 L
.71154 .96171 L
.7191 .96154 L
.73077 .96109 L
.75 .95989 L
.76923 .95816 L
.78846 .95595 L
.80769 .9533 L
.82692 .95023 L
.84615 .94676 L
.86538 .94289 L
.86812 .94231 L
.88462 .93859 L
.90385 .93384 L
.92308 .92858 L
.94115 .92308 L
.94231 .9227 L
.96154 .91607 L
.98077 .90851 L
.98077 .98077 L
.01923 .98077 L
F
.01923 .35211 m
.02137 .36538 L
.02524 .38462 L
.03007 .40385 L
.03584 .42308 L
.03846 .43092 L
.04254 .44231 L
.05018 .46154 L
.05769 .47851 L
.05876 .48077 L
.06839 .5 L
.07692 .51548 L
.0791 .51923 L
.09104 .53846 L
.09615 .54609 L
.10436 .55769 L
.11538 .57206 L
.11933 .57692 L
.13462 .59429 L
.13637 .59615 L
.15385 .6133 L
.15614 .61538 L
.17308 .62952 L
.1798 .63462 L
.19231 .64331 L
.20939 .65385 L
.21154 .65507 L
.23077 .66514 L
.24767 .67308 L
.25 .67413 L
.26923 .6827 L
.28846 .69199 L
.28906 .69231 L
.30769 .70376 L
.31753 .71154 L
.32692 .72083 L
.33545 .73077 L
.34615 .74599 L
.34882 .75 L
.36088 .76923 L
.36538 .77676 L
.37286 .78846 L
.38462 .80634 L
.38558 .80769 L
.39992 .82692 L
.40385 .83191 L
.4162 .84615 L
.42308 .85361 L
.43503 .86538 L
.44231 .8721 L
Mistroke
.45726 .88462 L
.46154 .88796 L
.48077 .90161 L
.48421 .90385 L
.5 .91334 L
.51845 .92308 L
.51923 .92345 L
.53846 .93202 L
.55769 .93934 L
.56654 .94231 L
.57692 .94541 L
.59615 .95037 L
.61538 .95435 L
.63462 .95741 L
.65385 .95962 L
.67308 .96104 L
.68495 .96154 L
.69231 .96172 L
.71154 .96171 L
.7191 .96154 L
.73077 .96109 L
.75 .95989 L
.76923 .95816 L
.78846 .95595 L
.80769 .9533 L
.82692 .95023 L
.84615 .94676 L
.86538 .94289 L
.86812 .94231 L
.88462 .93859 L
.90385 .93384 L
.92308 .92858 L
.94115 .92308 L
.94231 .9227 L
.96154 .91607 L
.98077 .90851 L
Mfstroke
.01923 .24653 m
.02206 .23077 L
.02663 .21154 L
.03256 .19231 L
.03846 .17663 L
.03995 .17308 L
.04892 .15385 L
.05769 .13785 L
.05964 .13462 L
.07245 .11538 L
.07692 .10936 L
.08768 .09615 L
.09615 .08675 L
.10588 .07692 L
.11538 .06816 L
.12792 .05769 L
.13462 .05258 L
.15385 .03938 L
.15531 .03846 L
.17308 .02816 L
.19113 .01923 L
.01923 .01923 L
F
.01923 .24653 m
.02206 .23077 L
.02663 .21154 L
.03256 .19231 L
.03846 .17663 L
.03995 .17308 L
.04892 .15385 L
.05769 .13785 L
.05964 .13462 L
.07245 .11538 L
.07692 .10936 L
.08768 .09615 L
.09615 .08675 L
.10588 .07692 L
.11538 .06816 L
.12792 .05769 L
.13462 .05258 L
.15385 .03938 L
.15531 .03846 L
.17308 .02816 L
.19113 .01923 L
s
.2 g
.98077 .75575 m
.97342 .76923 L
.96154 .78686 L
.96032 .78846 L
.94379 .80769 L
.94231 .80923 L
.92323 .82692 L
.92308 .82706 L
.90385 .84191 L
.8977 .84615 L
.88462 .85455 L
.86548 .86538 L
.86538 .86544 L
.84615 .87482 L
.82692 .88294 L
.82256 .88462 L
.80769 .88986 L
.78846 .8957 L
.76923 .90053 L
.75299 .90385 L
.75 .90437 L
.73077 .90718 L
.71154 .90902 L
.69231 .90985 L
.67308 .90964 L
.65385 .90832 L
.63462 .90584 L
.62331 .90385 L
.61538 .90208 L
.59615 .89689 L
.57692 .89017 L
.56382 .88462 L
.55769 .88169 L
.53846 .87111 L
.5295 .86538 L
.51923 .85805 L
.50476 .84615 L
.5 .84178 L
.48572 .82692 L
.48077 .82109 L
.47071 .80769 L
.46154 .7934 L
.45876 .78846 L
.44935 .76923 L
.44231 .75103 L
.44197 .75 L
.43643 .73077 L
.43227 .71154 L
.42917 .69231 L
.42668 .67308 L
.42411 .65385 L
.42308 .64772 L
.42028 .63462 L
.41228 .61538 L
.40385 .60524 L
.39023 .59615 L
.38462 .59359 L
.36538 .58735 L
.34615 .58289 L
.32692 .5788 L
.3185 .57692 L
.30769 .57432 L
.28846 .56898 L
.26923 .56248 L
.25716 .55769 L
.25 .55452 L
.23077 .54481 L
.21985 .53846 L
.21154 .53313 L
.19242 .51923 L
.19231 .51914 L
.17308 .50241 L
.17056 .5 L
.15385 .48238 L
.15245 .48077 L
.13715 .46154 L
.13462 .45803 L
.12413 .44231 L
.11538 .42745 L
.11303 .42308 L
.10364 .40385 L
.09615 .38555 L
.09581 .38462 L
.08948 .36538 L
.08454 .34615 L
.08097 .32692 L
.07877 .30769 L
.07797 .28846 L
.07858 .26923 L
.08066 .25 L
.0843 .23077 L
.08959 .21154 L
.09615 .19357 L
.09669 .19231 L
.10586 .17308 L
.11538 .15686 L
.11737 .15385 L
.13173 .13462 L
.13462 .13121 L
.14967 .11538 L
.15385 .11149 L
.17249 .09615 L
.17308 .09572 L
.19231 .08293 L
.20285 .07692 L
.21154 .07247 L
.23077 .06397 L
.24825 .05769 L
.25 .05714 L
.26923 .05179 L
.28846 .04775 L
.30769 .04491 L
.32692 .04317 L
.34615 .04247 L
.36538 .04278 L
.38462 .04405 L
.40385 .0463 L
.42308 .04952 L
.44231 .05372 L
.45735 .05769 L
.46154 .05892 L
.48077 .0651 L
.5 .07212 L
.51229 .07692 L
.51923 .07967 L
.53846 .08715 L
.55769 .09351 L
.56878 .09615 L
.57692 .09743 L
.59615 .09772 L
.60653 .09615 L
.61538 .09392 L
.63462 .08661 L
.65385 .07699 L
.65398 .07692 L
.67308 .06636 L
.68858 .05769 L
.69231 .05562 L
.71154 .04544 L
.72575 .03846 L
.73077 .03612 L
.75 .02795 L
.76923 .02113 L
.77536 .01923 L
.98077 .01923 L
F
0 g
.98077 .75575 m
.97342 .76923 L
.96154 .78686 L
.96032 .78846 L
.94379 .80769 L
.94231 .80923 L
.92323 .82692 L
.92308 .82706 L
.90385 .84191 L
.8977 .84615 L
.88462 .85455 L
.86548 .86538 L
.86538 .86544 L
.84615 .87482 L
.82692 .88294 L
.82256 .88462 L
.80769 .88986 L
.78846 .8957 L
.76923 .90053 L
.75299 .90385 L
.75 .90437 L
.73077 .90718 L
.71154 .90902 L
.69231 .90985 L
.67308 .90964 L
.65385 .90832 L
.63462 .90584 L
.62331 .90385 L
.61538 .90208 L
.59615 .89689 L
.57692 .89017 L
.56382 .88462 L
.55769 .88169 L
.53846 .87111 L
.5295 .86538 L
.51923 .85805 L
.50476 .84615 L
.5 .84178 L
.48572 .82692 L
.48077 .82109 L
.47071 .80769 L
.46154 .7934 L
.45876 .78846 L
.44935 .76923 L
.44231 .75103 L
.44197 .75 L
.43643 .73077 L
.43227 .71154 L
.42917 .69231 L
.42668 .67308 L
Mistroke
.42411 .65385 L
.42308 .64772 L
.42028 .63462 L
.41228 .61538 L
.40385 .60524 L
.39023 .59615 L
.38462 .59359 L
.36538 .58735 L
.34615 .58289 L
.32692 .5788 L
.3185 .57692 L
.30769 .57432 L
.28846 .56898 L
.26923 .56248 L
.25716 .55769 L
.25 .55452 L
.23077 .54481 L
.21985 .53846 L
.21154 .53313 L
.19242 .51923 L
.19231 .51914 L
.17308 .50241 L
.17056 .5 L
.15385 .48238 L
.15245 .48077 L
.13715 .46154 L
.13462 .45803 L
.12413 .44231 L
.11538 .42745 L
.11303 .42308 L
.10364 .40385 L
.09615 .38555 L
.09581 .38462 L
.08948 .36538 L
.08454 .34615 L
.08097 .32692 L
.07877 .30769 L
.07797 .28846 L
.07858 .26923 L
.08066 .25 L
.0843 .23077 L
.08959 .21154 L
.09615 .19357 L
.09669 .19231 L
.10586 .17308 L
.11538 .15686 L
.11737 .15385 L
.13173 .13462 L
.13462 .13121 L
.14967 .11538 L
Mistroke
.15385 .11149 L
.17249 .09615 L
.17308 .09572 L
.19231 .08293 L
.20285 .07692 L
.21154 .07247 L
.23077 .06397 L
.24825 .05769 L
.25 .05714 L
.26923 .05179 L
.28846 .04775 L
.30769 .04491 L
.32692 .04317 L
.34615 .04247 L
.36538 .04278 L
.38462 .04405 L
.40385 .0463 L
.42308 .04952 L
.44231 .05372 L
.45735 .05769 L
.46154 .05892 L
.48077 .0651 L
.5 .07212 L
.51229 .07692 L
.51923 .07967 L
.53846 .08715 L
.55769 .09351 L
.56878 .09615 L
.57692 .09743 L
.59615 .09772 L
.60653 .09615 L
.61538 .09392 L
.63462 .08661 L
.65385 .07699 L
.65398 .07692 L
.67308 .06636 L
.68858 .05769 L
.69231 .05562 L
.71154 .04544 L
.72575 .03846 L
.73077 .03612 L
.75 .02795 L
.76923 .02113 L
.77536 .01923 L
Mfstroke
.3 g
.98077 .28723 m
.98 .28846 L
.96646 .30769 L
.96154 .31369 L
.94943 .32692 L
.94231 .3338 L
.92796 .34615 L
.92308 .34989 L
.90385 .36302 L
.89998 .36538 L
.88462 .37364 L
.86538 .38236 L
.85977 .38462 L
.84615 .38897 L
.82692 .39387 L
.80769 .39708 L
.78846 .39842 L
.76923 .39776 L
.75 .3951 L
.73077 .39071 L
.71154 .3853 L
.70923 .38462 L
.69231 .37857 L
.67308 .37185 L
.65385 .36663 L
.64621 .36538 L
.63462 .36486 L
.62948 .36538 L
.61538 .36973 L
.59626 .38462 L
.59615 .38475 L
.58114 .40385 L
.57692 .41008 L
.56924 .42308 L
.55869 .44231 L
.55769 .44423 L
.54892 .46154 L
.54029 .48077 L
.53846 .48598 L
.53758 .5 L
.53846 .50087 L
.55769 .50321 L
.57692 .50038 L
.58101 .5 L
.59615 .49817 L
.61538 .49571 L
.63462 .49348 L
.65385 .49165 L
.67308 .49038 L
.69231 .48986 L
.71154 .49032 L
.73077 .492 L
.75 .49509 L
.76923 .49949 L
.77123 .5 L
.78846 .50615 L
.80769 .5146 L
.81703 .51923 L
.82692 .52491 L
.84615 .53743 L
.84761 .53846 L
.86538 .55263 L
.87102 .55769 L
.88462 .57142 L
.88943 .57692 L
.90384 .59615 L
.90385 .59616 L
.91483 .61538 L
.92284 .63462 L
.92308 .63517 L
.92806 .65385 L
.93068 .67308 L
.93077 .69231 L
.92831 .71154 L
.92324 .73077 L
.92308 .73127 L
.91535 .75 L
.90446 .76923 L
.90385 .77017 L
.89005 .78846 L
.88462 .79462 L
.87146 .80769 L
.86538 .81305 L
.84739 .82692 L
.84615 .82778 L
.82692 .83983 L
.81514 .84615 L
.80769 .84977 L
.78846 .85794 L
.76923 .86456 L
.76654 .86538 L
.75 .86975 L
.73077 .87359 L
.71154 .87615 L
.69231 .87741 L
.67308 .87735 L
.65385 .8759 L
.63462 .87298 L
.61538 .86846 L
.60519 .86538 L
.59615 .86213 L
.57692 .8537 L
.56311 .84615 L
.55769 .84278 L
.53846 .82865 L
.53643 .82692 L
.51923 .81007 L
.51715 .80769 L
.50268 .78846 L
.5 .78426 L
.4918 .76923 L
.48377 .75 L
.48077 .74107 L
.47818 .73077 L
.47471 .71154 L
.47312 .69231 L
.47321 .67308 L
.47482 .65385 L
.4778 .63462 L
.48077 .62043 L
.48198 .61538 L
.48726 .59615 L
.49338 .57692 L
.5 .55775 L
.50001 .55769 L
.50667 .53846 L
.5 .52022 L
.48077 .52046 L
.46154 .52314 L
.44231 .52555 L
.42308 .52758 L
.40385 .52906 L
.38462 .52981 L
.36538 .52968 L
.34615 .52849 L
.32692 .52608 L
.30769 .52227 L
.29596 .51923 L
.28846 .51688 L
.26923 .5097 L
.25 .50055 L
.24898 .5 L
.23077 .48909 L
.21895 .48077 L
.21154 .47497 L
.19632 .46154 L
.19231 .45761 L
.17825 .44231 L
.17308 .436 L
.16347 .42308 L
.15385 .4082 L
.1513 .40385 L
.14135 .38462 L
.13462 .36874 L
.13337 .36538 L
.12721 .34615 L
.12276 .32692 L
.12 .30769 L
.11892 .28846 L
.11955 .26923 L
.12198 .25 L
.12631 .23077 L
.13274 .21154 L
.13462 .20688 L
.14154 .19231 L
.15315 .17308 L
.15385 .17207 L
.16825 .15385 L
.17308 .14863 L
.18803 .13462 L
.19231 .1311 L
.21154 .11749 L
.21497 .11538 L
.23077 .1068 L
.25 .09844 L
.25618 .09615 L
.26923 .09203 L
.28846 .08731 L
.30769 .0841 L
.32692 .08226 L
.34615 .08171 L
.36538 .08239 L
.38462 .08427 L
.40385 .08736 L
.42308 .09168 L
.43887 .09615 L
.44231 .09726 L
.46154 .10415 L
.48077 .11234 L
.48727 .11538 L
.5 .1217 L
.51923 .13185 L
.52425 .13462 L
.53846 .14195 L
.55769 .15047 L
.56889 .15385 L
.57692 .15521 L
.59615 .15402 L
.59688 .15385 L
.61538 .14627 L
.63365 .13462 L
.63462 .1337 L
.65385 .11887 L
.65836 .11538 L
.67308 .10384 L
.68336 .09615 L
.69231 .08967 L
.71144 .07692 L
.71154 .07686 L
.73077 .06567 L
.74652 .05769 L
.75 .0561 L
.76923 .04824 L
.78846 .04204 L
.80279 .03846 L
.80769 .03754 L
.82692 .03479 L
.84615 .03387 L
.86538 .03485 L
.88462 .0379 L
.8873 .03846 L
.90385 .04324 L
.92308 .05119 L
.93509 .05769 L
.94231 .06234 L
.96062 .07692 L
.96154 .07778 L
.97805 .09615 L
.98077 .09981 L
F
0 g
.98077 .28723 m
.98 .28846 L
.96646 .30769 L
.96154 .31369 L
.94943 .32692 L
.94231 .3338 L
.92796 .34615 L
.92308 .34989 L
.90385 .36302 L
.89998 .36538 L
.88462 .37364 L
.86538 .38236 L
.85977 .38462 L
.84615 .38897 L
.82692 .39387 L
.80769 .39708 L
.78846 .39842 L
.76923 .39776 L
.75 .3951 L
.73077 .39071 L
.71154 .3853 L
.70923 .38462 L
.69231 .37857 L
.67308 .37185 L
.65385 .36663 L
.64621 .36538 L
.63462 .36486 L
.62948 .36538 L
.61538 .36973 L
.59626 .38462 L
.59615 .38475 L
.58114 .40385 L
.57692 .41008 L
.56924 .42308 L
.55869 .44231 L
.55769 .44423 L
.54892 .46154 L
.54029 .48077 L
.53846 .48598 L
.53758 .5 L
.53846 .50087 L
.55769 .50321 L
.57692 .50038 L
.58101 .5 L
.59615 .49817 L
.61538 .49571 L
.63462 .49348 L
.65385 .49165 L
.67308 .49038 L
.69231 .48986 L
Mistroke
.71154 .49032 L
.73077 .492 L
.75 .49509 L
.76923 .49949 L
.77123 .5 L
.78846 .50615 L
.80769 .5146 L
.81703 .51923 L
.82692 .52491 L
.84615 .53743 L
.84761 .53846 L
.86538 .55263 L
.87102 .55769 L
.88462 .57142 L
.88943 .57692 L
.90384 .59615 L
.90385 .59616 L
.91483 .61538 L
.92284 .63462 L
.92308 .63517 L
.92806 .65385 L
.93068 .67308 L
.93077 .69231 L
.92831 .71154 L
.92324 .73077 L
.92308 .73127 L
.91535 .75 L
.90446 .76923 L
.90385 .77017 L
.89005 .78846 L
.88462 .79462 L
.87146 .80769 L
.86538 .81305 L
.84739 .82692 L
.84615 .82778 L
.82692 .83983 L
.81514 .84615 L
.80769 .84977 L
.78846 .85794 L
.76923 .86456 L
.76654 .86538 L
.75 .86975 L
.73077 .87359 L
.71154 .87615 L
.69231 .87741 L
.67308 .87735 L
.65385 .8759 L
.63462 .87298 L
.61538 .86846 L
.60519 .86538 L
Mistroke
.59615 .86213 L
.57692 .8537 L
.56311 .84615 L
.55769 .84278 L
.53846 .82865 L
.53643 .82692 L
.51923 .81007 L
.51715 .80769 L
.50268 .78846 L
.5 .78426 L
.4918 .76923 L
.48377 .75 L
.48077 .74107 L
.47818 .73077 L
.47471 .71154 L
.47312 .69231 L
.47321 .67308 L
.47482 .65385 L
.4778 .63462 L
.48077 .62043 L
.48198 .61538 L
.48726 .59615 L
.49338 .57692 L
.5 .55775 L
.50001 .55769 L
.50667 .53846 L
.5 .52022 L
.48077 .52046 L
.46154 .52314 L
.44231 .52555 L
.42308 .52758 L
.40385 .52906 L
.38462 .52981 L
.36538 .52968 L
.34615 .52849 L
.32692 .52608 L
.30769 .52227 L
.29596 .51923 L
.28846 .51688 L
.26923 .5097 L
.25 .50055 L
.24898 .5 L
.23077 .48909 L
.21895 .48077 L
.21154 .47497 L
.19632 .46154 L
.19231 .45761 L
.17825 .44231 L
.17308 .436 L
.16347 .42308 L
Mistroke
.15385 .4082 L
.1513 .40385 L
.14135 .38462 L
.13462 .36874 L
.13337 .36538 L
.12721 .34615 L
.12276 .32692 L
.12 .30769 L
.11892 .28846 L
.11955 .26923 L
.12198 .25 L
.12631 .23077 L
.13274 .21154 L
.13462 .20688 L
.14154 .19231 L
.15315 .17308 L
.15385 .17207 L
.16825 .15385 L
.17308 .14863 L
.18803 .13462 L
.19231 .1311 L
.21154 .11749 L
.21497 .11538 L
.23077 .1068 L
.25 .09844 L
.25618 .09615 L
.26923 .09203 L
.28846 .08731 L
.30769 .0841 L
.32692 .08226 L
.34615 .08171 L
.36538 .08239 L
.38462 .08427 L
.40385 .08736 L
.42308 .09168 L
.43887 .09615 L
.44231 .09726 L
.46154 .10415 L
.48077 .11234 L
.48727 .11538 L
.5 .1217 L
.51923 .13185 L
.52425 .13462 L
.53846 .14195 L
.55769 .15047 L
.56889 .15385 L
.57692 .15521 L
.59615 .15402 L
.59688 .15385 L
.61538 .14627 L
Mistroke
.63365 .13462 L
.63462 .1337 L
.65385 .11887 L
.65836 .11538 L
.67308 .10384 L
.68336 .09615 L
.69231 .08967 L
.71144 .07692 L
.71154 .07686 L
.73077 .06567 L
.74652 .05769 L
.75 .0561 L
.76923 .04824 L
.78846 .04204 L
.80279 .03846 L
.80769 .03754 L
.82692 .03479 L
.84615 .03387 L
.86538 .03485 L
.88462 .0379 L
.8873 .03846 L
.90385 .04324 L
.92308 .05119 L
.93509 .05769 L
.94231 .06234 L
.96062 .07692 L
.96154 .07778 L
.97805 .09615 L
.98077 .09981 L
Mfstroke
.4 g
.98077 .23586 m
.97563 .25 L
.96628 .26923 L
.96154 .27716 L
.95374 .28846 L
.94231 .30241 L
.93737 .30769 L
.92308 .32103 L
.91581 .32692 L
.90385 .33544 L
.88583 .34615 L
.88462 .34677 L
.86538 .35545 L
.84615 .36192 L
.83243 .36538 L
.82692 .36625 L
.80769 .36846 L
.78846 .36865 L
.76923 .36681 L
.75995 .36538 L
.75 .36286 L
.73077 .35676 L
.71154 .34864 L
.70647 .34615 L
.69231 .33847 L
.67397 .32692 L
.67308 .32633 L
.65385 .31235 L
.64983 .30769 L
.63462 .29689 L
.62493 .28846 L
.61538 .28302 L
.59615 .27112 L
.58363 .28846 L
.57692 .30444 L
.5738 .30769 L
.56454 .32692 L
.55769 .34178 L
.55542 .34615 L
.54542 .36538 L
.53846 .37796 L
.53451 .38462 L
.52211 .40385 L
.51923 .40792 L
.50746 .42308 L
.5 .4315 L
.48914 .44231 L
.48077 .44953 L
.46409 .46154 L
.46154 .46311 L
.44231 .47321 L
.42308 .48062 L
.42265 .48077 L
.40385 .48579 L
.38462 .48905 L
.36538 .49051 L
.34615 .49023 L
.32692 .48816 L
.30769 .48422 L
.29555 .48077 L
.28846 .47824 L
.26923 .47002 L
.25365 .46154 L
.25 .45927 L
.23077 .44549 L
.22691 .44231 L
.21154 .42793 L
.20698 .42308 L
.19231 .40509 L
.19141 .40385 L
.17907 .38462 L
.17308 .37334 L
.16939 .36538 L
.16202 .34615 L
.15678 .32692 L
.15385 .31089 L
.15357 .30769 L
.15237 .28846 L
.15321 .26923 L
.15385 .26365 L
.1562 .25 L
.16154 .23077 L
.16954 .21154 L
.17308 .20472 L
.18072 .19231 L
.19231 .17719 L
.19599 .17308 L
.21154 .1583 L
.21709 .15385 L
.23077 .14435 L
.24842 .13462 L
.25 .13387 L
.26923 .12605 L
.28846 .12042 L
.30769 .11668 L
.31805 .11538 L
.32692 .11464 L
.34615 .11418 L
.36538 .1152 L
.36786 .11538 L
.38462 .11771 L
.40385 .12171 L
.42308 .12728 L
.44231 .13451 L
.44256 .13462 L
.46154 .14356 L
.4796 .15385 L
.48077 .15457 L
.5 .16766 L
.50711 .17308 L
.51923 .18282 L
.52996 .19231 L
.53846 .19982 L
.55004 .21154 L
.55769 .21794 L
.57075 .23077 L
.57692 .2365 L
.59615 .24565 L
.60782 .23077 L
.61538 .21822 L
.62016 .21154 L
.63214 .19231 L
.63462 .18742 L
.64507 .17308 L
.65385 .16104 L
.65985 .15385 L
.67308 .13867 L
.67698 .13462 L
.69231 .1197 L
.69721 .11538 L
.71154 .10369 L
.7219 .09615 L
.73077 .09026 L
.75 .07916 L
.75437 .07692 L
.76923 .07022 L
.78846 .06333 L
.80769 .05842 L
.81148 .05769 L
.82692 .05554 L
.84615 .05471 L
.86538 .05605 L
.87815 .05769 L
.88462 .05976 L
.90385 .06621 L
.92308 .07593 L
.9247 .07692 L
.94231 .09003 L
.94881 .09615 L
.96154 .11099 L
.96462 .11538 L
.97537 .13462 L
.98077 .14816 L
F
0 g
.98077 .23586 m
.97563 .25 L
.96628 .26923 L
.96154 .27716 L
.95374 .28846 L
.94231 .30241 L
.93737 .30769 L
.92308 .32103 L
.91581 .32692 L
.90385 .33544 L
.88583 .34615 L
.88462 .34677 L
.86538 .35545 L
.84615 .36192 L
.83243 .36538 L
.82692 .36625 L
.80769 .36846 L
.78846 .36865 L
.76923 .36681 L
.75995 .36538 L
.75 .36286 L
.73077 .35676 L
.71154 .34864 L
.70647 .34615 L
.69231 .33847 L
.67397 .32692 L
.67308 .32633 L
.65385 .31235 L
.64983 .30769 L
.63462 .29689 L
.62493 .28846 L
.61538 .28302 L
.59615 .27112 L
.58363 .28846 L
.57692 .30444 L
.5738 .30769 L
.56454 .32692 L
.55769 .34178 L
.55542 .34615 L
.54542 .36538 L
.53846 .37796 L
.53451 .38462 L
.52211 .40385 L
.51923 .40792 L
.50746 .42308 L
.5 .4315 L
.48914 .44231 L
.48077 .44953 L
.46409 .46154 L
.46154 .46311 L
Mistroke
.44231 .47321 L
.42308 .48062 L
.42265 .48077 L
.40385 .48579 L
.38462 .48905 L
.36538 .49051 L
.34615 .49023 L
.32692 .48816 L
.30769 .48422 L
.29555 .48077 L
.28846 .47824 L
.26923 .47002 L
.25365 .46154 L
.25 .45927 L
.23077 .44549 L
.22691 .44231 L
.21154 .42793 L
.20698 .42308 L
.19231 .40509 L
.19141 .40385 L
.17907 .38462 L
.17308 .37334 L
.16939 .36538 L
.16202 .34615 L
.15678 .32692 L
.15385 .31089 L
.15357 .30769 L
.15237 .28846 L
.15321 .26923 L
.15385 .26365 L
.1562 .25 L
.16154 .23077 L
.16954 .21154 L
.17308 .20472 L
.18072 .19231 L
.19231 .17719 L
.19599 .17308 L
.21154 .1583 L
.21709 .15385 L
.23077 .14435 L
.24842 .13462 L
.25 .13387 L
.26923 .12605 L
.28846 .12042 L
.30769 .11668 L
.31805 .11538 L
.32692 .11464 L
.34615 .11418 L
.36538 .1152 L
.36786 .11538 L
Mistroke
.38462 .11771 L
.40385 .12171 L
.42308 .12728 L
.44231 .13451 L
.44256 .13462 L
.46154 .14356 L
.4796 .15385 L
.48077 .15457 L
.5 .16766 L
.50711 .17308 L
.51923 .18282 L
.52996 .19231 L
.53846 .19982 L
.55004 .21154 L
.55769 .21794 L
.57075 .23077 L
.57692 .2365 L
.59615 .24565 L
.60782 .23077 L
.61538 .21822 L
.62016 .21154 L
.63214 .19231 L
.63462 .18742 L
.64507 .17308 L
.65385 .16104 L
.65985 .15385 L
.67308 .13867 L
.67698 .13462 L
.69231 .1197 L
.69721 .11538 L
.71154 .10369 L
.7219 .09615 L
.73077 .09026 L
.75 .07916 L
.75437 .07692 L
.76923 .07022 L
.78846 .06333 L
.80769 .05842 L
.81148 .05769 L
.82692 .05554 L
.84615 .05471 L
.86538 .05605 L
.87815 .05769 L
.88462 .05976 L
.90385 .06621 L
.92308 .07593 L
.9247 .07692 L
.94231 .09003 L
.94881 .09615 L
.96154 .11099 L
Mistroke
.96462 .11538 L
.97537 .13462 L
.98077 .14816 L
Mfstroke
.5 g
.28846 .15115 m
.30769 .14664 L
.32692 .14427 L
.34615 .14382 L
.36538 .14522 L
.38462 .14845 L
.40385 .15359 L
.40466 .15385 L
.42308 .16079 L
.44231 .17036 L
.44696 .17308 L
.46154 .18277 L
.47349 .19231 L
.48077 .19892 L
.49257 .21154 L
.5 .22088 L
.50646 .23077 L
.51603 .25 L
.51923 .25663 L
.52155 .26923 L
.52342 .28846 L
.52211 .30769 L
.51923 .32242 L
.51805 .32692 L
.51149 .34615 L
.50251 .36538 L
.5 .36998 L
.49078 .38462 L
.48077 .39783 L
.47552 .40385 L
.46154 .41757 L
.45492 .42308 L
.44231 .43205 L
.42377 .44231 L
.42308 .44263 L
.40385 .4501 L
.38462 .45493 L
.36538 .45739 L
.34615 .4576 L
.32692 .45557 L
.30769 .45122 L
.28846 .44436 L
.28378 .44231 L
.26923 .43467 L
.25191 .42308 L
.25 .42159 L
.23077 .40413 L
.2305 .40385 L
.21466 .38462 L
.21154 .38012 L
.20272 .36538 L
.19388 .34615 L
.19231 .34223 L
.18773 .32692 L
.18405 .30769 L
.1828 .28846 L
.184 .26923 L
.18784 .25 L
.19231 .23603 L
.19465 .23077 L
.20502 .21154 L
.21154 .2023 L
.22008 .19231 L
.23077 .18206 L
.24232 .17308 L
.25 .16807 L
.26923 .1581 L
.27989 .15385 L
F
0 g
.28846 .15115 m
.30769 .14664 L
.32692 .14427 L
.34615 .14382 L
.36538 .14522 L
.38462 .14845 L
.40385 .15359 L
.40466 .15385 L
.42308 .16079 L
.44231 .17036 L
.44696 .17308 L
.46154 .18277 L
.47349 .19231 L
.48077 .19892 L
.49257 .21154 L
.5 .22088 L
.50646 .23077 L
.51603 .25 L
.51923 .25663 L
.52155 .26923 L
.52342 .28846 L
.52211 .30769 L
.51923 .32242 L
.51805 .32692 L
.51149 .34615 L
.50251 .36538 L
.5 .36998 L
.49078 .38462 L
.48077 .39783 L
.47552 .40385 L
.46154 .41757 L
.45492 .42308 L
.44231 .43205 L
.42377 .44231 L
.42308 .44263 L
.40385 .4501 L
.38462 .45493 L
.36538 .45739 L
.34615 .4576 L
.32692 .45557 L
.30769 .45122 L
.28846 .44436 L
.28378 .44231 L
.26923 .43467 L
.25191 .42308 L
.25 .42159 L
.23077 .40413 L
.2305 .40385 L
.21466 .38462 L
.21154 .38012 L
Mistroke
.20272 .36538 L
.19388 .34615 L
.19231 .34223 L
.18773 .32692 L
.18405 .30769 L
.1828 .28846 L
.184 .26923 L
.18784 .25 L
.19231 .23603 L
.19465 .23077 L
.20502 .21154 L
.21154 .2023 L
.22008 .19231 L
.23077 .18206 L
.24232 .17308 L
.25 .16807 L
.26923 .1581 L
.27989 .15385 L
.28846 .15115 L
Mfstroke
.6 g
.34615 .17306 m
.34662 .17308 L
.36538 .17491 L
.38462 .17912 L
.40385 .18591 L
.41715 .19231 L
.42308 .19573 L
.44231 .20953 L
.4446 .21154 L
.46154 .22967 L
.46236 .23077 L
.4741 .25 L
.48077 .26729 L
.48121 .26923 L
.4844 .28846 L
.4841 .30769 L
.48077 .32601 L
.48053 .32692 L
.47368 .34615 L
.46321 .36538 L
.46154 .36791 L
.44811 .38462 L
.44231 .39044 L
.4256 .40385 L
.42308 .40551 L
.40385 .41581 L
.38462 .42243 L
.38199 .42308 L
.36538 .42594 L
.34615 .42659 L
.32692 .42445 L
.31879 .42308 L
.30769 .41942 L
.28846 .41117 L
.27595 .40385 L
.26923 .39906 L
.25273 .38462 L
.25 .38175 L
.23691 .36538 L
.23077 .35575 L
.22581 .34615 L
.21836 .32692 L
.21409 .30769 L
.21283 .28846 L
.21465 .26923 L
.21984 .25 L
.22911 .23077 L
.23077 .22808 L
.24385 .21154 L
.25 .20556 L
.26791 .19231 L
.26923 .19153 L
.28846 .18227 L
.30769 .17651 L
.32692 .17355 L
.33444 .17308 L
F
0 g
.34615 .17306 m
.34662 .17308 L
.36538 .17491 L
.38462 .17912 L
.40385 .18591 L
.41715 .19231 L
.42308 .19573 L
.44231 .20953 L
.4446 .21154 L
.46154 .22967 L
.46236 .23077 L
.4741 .25 L
.48077 .26729 L
.48121 .26923 L
.4844 .28846 L
.4841 .30769 L
.48077 .32601 L
.48053 .32692 L
.47368 .34615 L
.46321 .36538 L
.46154 .36791 L
.44811 .38462 L
.44231 .39044 L
.4256 .40385 L
.42308 .40551 L
.40385 .41581 L
.38462 .42243 L
.38199 .42308 L
.36538 .42594 L
.34615 .42659 L
.32692 .42445 L
.31879 .42308 L
.30769 .41942 L
.28846 .41117 L
.27595 .40385 L
.26923 .39906 L
.25273 .38462 L
.25 .38175 L
.23691 .36538 L
.23077 .35575 L
.22581 .34615 L
.21836 .32692 L
.21409 .30769 L
.21283 .28846 L
.21465 .26923 L
.21984 .25 L
.22911 .23077 L
.23077 .22808 L
.24385 .21154 L
.25 .20556 L
Mistroke
.26791 .19231 L
.26923 .19153 L
.28846 .18227 L
.30769 .17651 L
.32692 .17355 L
.33444 .17308 L
.34615 .17306 L
Mfstroke
.7 g
.30769 .20943 m
.32692 .20524 L
.34615 .20455 L
.36538 .20711 L
.38174 .21154 L
.38462 .21306 L
.40385 .22305 L
.41423 .23077 L
.42308 .23905 L
.43175 .25 L
.4418 .26923 L
.44231 .27062 L
.44656 .28846 L
.4468 .30769 L
.4427 .32692 L
.44231 .32832 L
.43393 .34615 L
.42308 .36102 L
.41885 .36538 L
.40385 .37759 L
.39164 .38462 L
.38462 .38742 L
.36538 .39265 L
.34615 .39394 L
.32692 .39152 L
.30769 .38514 L
.30646 .38462 L
.28846 .37414 L
.27783 .36538 L
.26923 .35632 L
.26176 .34615 L
.25189 .32692 L
.25 .32154 L
.24659 .30769 L
.24538 .28846 L
.24839 .26923 L
.25 .26261 L
.25627 .25 L
.26923 .23272 L
.27124 .23077 L
.28846 .21783 L
.30114 .21154 L
F
0 g
.30769 .20943 m
.32692 .20524 L
.34615 .20455 L
.36538 .20711 L
.38174 .21154 L
.38462 .21306 L
.40385 .22305 L
.41423 .23077 L
.42308 .23905 L
.43175 .25 L
.4418 .26923 L
.44231 .27062 L
.44656 .28846 L
.4468 .30769 L
.4427 .32692 L
.44231 .32832 L
.43393 .34615 L
.42308 .36102 L
.41885 .36538 L
.40385 .37759 L
.39164 .38462 L
.38462 .38742 L
.36538 .39265 L
.34615 .39394 L
.32692 .39152 L
.30769 .38514 L
.30646 .38462 L
.28846 .37414 L
.27783 .36538 L
.26923 .35632 L
.26176 .34615 L
.25189 .32692 L
.25 .32154 L
.24659 .30769 L
.24538 .28846 L
.24839 .26923 L
.25 .26261 L
.25627 .25 L
.26923 .23272 L
.27124 .23077 L
.28846 .21783 L
.30114 .21154 L
.30769 .20943 L
s
.8 g
.32692 .24675 m
.34615 .24513 L
.36538 .24975 L
.36615 .25 L
.38462 .26118 L
.39135 .26923 L
.40035 .28846 L
.40109 .30769 L
.39409 .32692 L
.38462 .3391 L
.37596 .34615 L
.36538 .3494 L
.34615 .35262 L
.32692 .34911 L
.32023 .34615 L
.30769 .33876 L
.29727 .32692 L
.28897 .30769 L
.28846 .30501 L
.28801 .28846 L
.28846 .28587 L
.29443 .26923 L
.30769 .25466 L
.31774 .25 L
F
0 g
.32692 .24675 m
.34615 .24513 L
.36538 .24975 L
.36615 .25 L
.38462 .26118 L
.39135 .26923 L
.40035 .28846 L
.40109 .30769 L
.39409 .32692 L
.38462 .3391 L
.37596 .34615 L
.36538 .3494 L
.34615 .35262 L
.32692 .34911 L
.32023 .34615 L
.30769 .33876 L
.29727 .32692 L
.28897 .30769 L
.28846 .30501 L
.28801 .28846 L
.28846 .28587 L
.29443 .26923 L
.30769 .25466 L
.31774 .25 L
.32692 .24675 L
s
.4 g
.61538 .53748 m
.63462 .53178 L
.65385 .52769 L
.67308 .52506 L
.69231 .52385 L
.71154 .5241 L
.73077 .52589 L
.75 .52935 L
.76923 .53465 L
.78004 .53846 L
.78846 .54201 L
.80769 .55182 L
.81724 .55769 L
.82692 .56452 L
.84173 .57692 L
.84615 .58118 L
.85944 .59615 L
.86538 .60416 L
.87238 .61538 L
.88153 .63462 L
.88462 .64245 L
.88741 .65385 L
.89031 .67308 L
.89038 .69231 L
.88764 .71154 L
.88462 .72416 L
.88198 .73077 L
.87316 .75 L
.86538 .76281 L
.86075 .76923 L
.84615 .78629 L
.84399 .78846 L
.82692 .80353 L
.82143 .80769 L
.80769 .81693 L
.78972 .82692 L
.78846 .82754 L
.76923 .83592 L
.75 .8424 L
.73562 .84615 L
.73077 .84716 L
.71154 .8503 L
.69231 .85187 L
.67308 .85186 L
.65385 .8502 L
.63462 .84676 L
.63194 .84615 L
.61538 .84133 L
.59615 .8336 L
.58326 .82692 L
.57692 .82309 L
.55769 .80889 L
.55631 .80769 L
.53846 .78922 L
.53785 .78846 L
.52464 .76923 L
.51923 .75914 L
.51529 .75 L
.50905 .73077 L
.50549 .71154 L
.50435 .69231 L
.5055 .67308 L
.5089 .65385 L
.51464 .63462 L
.51923 .62316 L
.52299 .61538 L
.53456 .59615 L
.53846 .59085 L
.55061 .57692 L
.55769 .57026 L
.57398 .55769 L
.57692 .5558 L
.59615 .5453 L
.61258 .53846 L
F
0 g
.61538 .53748 m
.63462 .53178 L
.65385 .52769 L
.67308 .52506 L
.69231 .52385 L
.71154 .5241 L
.73077 .52589 L
.75 .52935 L
.76923 .53465 L
.78004 .53846 L
.78846 .54201 L
.80769 .55182 L
.81724 .55769 L
.82692 .56452 L
.84173 .57692 L
.84615 .58118 L
.85944 .59615 L
.86538 .60416 L
.87238 .61538 L
.88153 .63462 L
.88462 .64245 L
.88741 .65385 L
.89031 .67308 L
.89038 .69231 L
.88764 .71154 L
.88462 .72416 L
.88198 .73077 L
.87316 .75 L
.86538 .76281 L
.86075 .76923 L
.84615 .78629 L
.84399 .78846 L
.82692 .80353 L
.82143 .80769 L
.80769 .81693 L
.78972 .82692 L
.78846 .82754 L
.76923 .83592 L
.75 .8424 L
.73562 .84615 L
.73077 .84716 L
.71154 .8503 L
.69231 .85187 L
.67308 .85186 L
.65385 .8502 L
.63462 .84676 L
.63194 .84615 L
.61538 .84133 L
.59615 .8336 L
.58326 .82692 L
Mistroke
.57692 .82309 L
.55769 .80889 L
.55631 .80769 L
.53846 .78922 L
.53785 .78846 L
.52464 .76923 L
.51923 .75914 L
.51529 .75 L
.50905 .73077 L
.50549 .71154 L
.50435 .69231 L
.5055 .67308 L
.5089 .65385 L
.51464 .63462 L
.51923 .62316 L
.52299 .61538 L
.53456 .59615 L
.53846 .59085 L
.55061 .57692 L
.55769 .57026 L
.57398 .55769 L
.57692 .5558 L
.59615 .5453 L
.61258 .53846 L
.61538 .53748 L
Mfstroke
.5 g
.65385 .55437 m
.67308 .55096 L
.69231 .54938 L
.71154 .54961 L
.73077 .55172 L
.75 .55586 L
.75648 .55769 L
.76923 .5623 L
.78846 .57147 L
.79753 .57692 L
.80769 .58412 L
.82145 .59615 L
.82692 .60185 L
.83761 .61538 L
.84615 .62945 L
.8486 .63462 L
.85552 .65385 L
.85894 .67308 L
.8591 .69231 L
.85606 .71154 L
.84967 .73077 L
.84615 .73858 L
.83955 .75 L
.82692 .76706 L
.82499 .76923 L
.80769 .78589 L
.80451 .78846 L
.78846 .79976 L
.7745 .80769 L
.76923 .81028 L
.75 .81821 L
.73077 .82394 L
.71714 .82692 L
.71154 .82769 L
.69231 .82955 L
.67308 .82953 L
.65385 .82754 L
.64955 .82692 L
.63462 .82341 L
.61538 .81683 L
.59692 .80769 L
.59615 .80724 L
.57692 .79365 L
.5711 .78846 L
.55769 .7738 L
.5543 .76923 L
.54295 .75 L
.53846 .73994 L
.53565 .73077 L
.53168 .71154 L
.53068 .69231 L
.53251 .67308 L
.53721 .65385 L
.53846 .64998 L
.54506 .63462 L
.55667 .61538 L
.55769 .61398 L
.57334 .59615 L
.57692 .59281 L
.59615 .57813 L
.59804 .57692 L
.61538 .56751 L
.63462 .55977 L
.64093 .55769 L
F
0 g
.65385 .55437 m
.67308 .55096 L
.69231 .54938 L
.71154 .54961 L
.73077 .55172 L
.75 .55586 L
.75648 .55769 L
.76923 .5623 L
.78846 .57147 L
.79753 .57692 L
.80769 .58412 L
.82145 .59615 L
.82692 .60185 L
.83761 .61538 L
.84615 .62945 L
.8486 .63462 L
.85552 .65385 L
.85894 .67308 L
.8591 .69231 L
.85606 .71154 L
.84967 .73077 L
.84615 .73858 L
.83955 .75 L
.82692 .76706 L
.82499 .76923 L
.80769 .78589 L
.80451 .78846 L
.78846 .79976 L
.7745 .80769 L
.76923 .81028 L
.75 .81821 L
.73077 .82394 L
.71714 .82692 L
.71154 .82769 L
.69231 .82955 L
.67308 .82953 L
.65385 .82754 L
.64955 .82692 L
.63462 .82341 L
.61538 .81683 L
.59692 .80769 L
.59615 .80724 L
.57692 .79365 L
.5711 .78846 L
.55769 .7738 L
.5543 .76923 L
.54295 .75 L
.53846 .73994 L
.53565 .73077 L
.53168 .71154 L
Mistroke
.53068 .69231 L
.53251 .67308 L
.53721 .65385 L
.53846 .64998 L
.54506 .63462 L
.55667 .61538 L
.55769 .61398 L
.57334 .59615 L
.57692 .59281 L
.59615 .57813 L
.59804 .57692 L
.61538 .56751 L
.63462 .55977 L
.64093 .55769 L
.65385 .55437 L
Mfstroke
.66119 .01923 m
.65385 .02142 L
.63462 .02638 L
.61538 .02911 L
.59615 .02915 L
.57692 .02658 L
.55769 .02203 L
.54771 .01923 L
F
.66119 .01923 m
.65385 .02142 L
.63462 .02638 L
.61538 .02911 L
.59615 .02915 L
.57692 .02658 L
.55769 .02203 L
.54771 .01923 L
s
.6 g
.67308 .5738 m
.69231 .57193 L
.71154 .57227 L
.73077 .57491 L
.74028 .57692 L
.75 .58008 L
.76923 .58828 L
.78251 .59615 L
.78846 .60044 L
.80469 .61538 L
.80769 .61877 L
.81863 .63462 L
.82692 .65313 L
.82713 .65385 L
.83132 .67308 L
.83166 .69231 L
.82826 .71154 L
.82692 .71679 L
.82089 .73077 L
.80894 .75 L
.80769 .75164 L
.79103 .76923 L
.78846 .77145 L
.76923 .78518 L
.76356 .78846 L
.75 .79505 L
.73077 .802 L
.71154 .80645 L
.70296 .80769 L
.69231 .80862 L
.67308 .80853 L
.66412 .80769 L
.65385 .80609 L
.63462 .80101 L
.61538 .79274 L
.60786 .78846 L
.59615 .78023 L
.5842 .76923 L
.57692 .76083 L
.56967 .75 L
.56073 .73077 L
.55769 .72026 L
.55603 .71154 L
.55497 .69231 L
.55738 .67308 L
.55769 .67124 L
.56337 .65385 L
.57347 .63462 L
.57692 .62951 L
.58888 .61538 L
.59615 .6085 L
.61268 .59615 L
.61538 .59448 L
.63462 .58467 L
.65385 .57796 L
.65676 .57692 L
F
0 g
.67308 .5738 m
.69231 .57193 L
.71154 .57227 L
.73077 .57491 L
.74028 .57692 L
.75 .58008 L
.76923 .58828 L
.78251 .59615 L
.78846 .60044 L
.80469 .61538 L
.80769 .61877 L
.81863 .63462 L
.82692 .65313 L
.82713 .65385 L
.83132 .67308 L
.83166 .69231 L
.82826 .71154 L
.82692 .71679 L
.82089 .73077 L
.80894 .75 L
.80769 .75164 L
.79103 .76923 L
.78846 .77145 L
.76923 .78518 L
.76356 .78846 L
.75 .79505 L
.73077 .802 L
.71154 .80645 L
.70296 .80769 L
.69231 .80862 L
.67308 .80853 L
.66412 .80769 L
.65385 .80609 L
.63462 .80101 L
.61538 .79274 L
.60786 .78846 L
.59615 .78023 L
.5842 .76923 L
.57692 .76083 L
.56967 .75 L
.56073 .73077 L
.55769 .72026 L
.55603 .71154 L
.55497 .69231 L
.55738 .67308 L
.55769 .67124 L
.56337 .65385 L
.57347 .63462 L
.57692 .62951 L
.58888 .61538 L
Mistroke
.59615 .6085 L
.61268 .59615 L
.61538 .59448 L
.63462 .58467 L
.65385 .57796 L
.65676 .57692 L
.67308 .5738 L
Mfstroke
.7 g
.67308 .59595 m
.69231 .59377 L
.71154 .59436 L
.72341 .59615 L
.73077 .59784 L
.75 .60467 L
.76832 .61538 L
.76923 .61606 L
.78814 .63462 L
.78846 .63498 L
.79933 .65385 L
.80473 .67308 L
.80538 .69231 L
.80149 .71154 L
.79268 .73077 L
.78846 .73744 L
.77776 .75 L
.76923 .75793 L
.75311 .76923 L
.75 .771 L
.73077 .77978 L
.71154 .7852 L
.69231 .78774 L
.67308 .78751 L
.65385 .78436 L
.63462 .77777 L
.61909 .76923 L
.61538 .76659 L
.59807 .75 L
.59615 .74777 L
.58629 .73077 L
.58035 .71154 L
.57905 .69231 L
.58205 .67308 L
.58964 .65385 L
.59615 .64291 L
.60286 .63462 L
.61538 .62235 L
.62471 .61538 L
.63462 .60943 L
.65385 .60099 L
.6717 .59615 L
F
0 g
.67308 .59595 m
.69231 .59377 L
.71154 .59436 L
.72341 .59615 L
.73077 .59784 L
.75 .60467 L
.76832 .61538 L
.76923 .61606 L
.78814 .63462 L
.78846 .63498 L
.79933 .65385 L
.80473 .67308 L
.80538 .69231 L
.80149 .71154 L
.79268 .73077 L
.78846 .73744 L
.77776 .75 L
.76923 .75793 L
.75311 .76923 L
.75 .771 L
.73077 .77978 L
.71154 .7852 L
.69231 .78774 L
.67308 .78751 L
.65385 .78436 L
.63462 .77777 L
.61909 .76923 L
.61538 .76659 L
.59807 .75 L
.59615 .74777 L
.58629 .73077 L
.58035 .71154 L
.57905 .69231 L
.58205 .67308 L
.58964 .65385 L
.59615 .64291 L
.60286 .63462 L
.61538 .62235 L
.62471 .61538 L
.63462 .60943 L
.65385 .60099 L
.6717 .59615 L
.67308 .59595 L
s
.8 g
.65385 .62591 m
.67308 .6194 L
.69231 .61685 L
.71154 .61791 L
.73077 .62293 L
.75 .63348 L
.75151 .63462 L
.76885 .65385 L
.76923 .6545 L
.77666 .67308 L
.7779 .69231 L
.77318 .71154 L
.76923 .72132 L
.76176 .73077 L
.75 .74285 L
.73998 .75 L
.73077 .75504 L
.71154 .76219 L
.69231 .76532 L
.67308 .7648 L
.65385 .76033 L
.63462 .75046 L
.63395 .75 L
.61538 .73089 L
.61531 .73077 L
.60679 .71154 L
.60488 .69231 L
.60873 .67308 L
.61538 .65735 L
.61894 .65385 L
.63462 .63756 L
.63856 .63462 L
F
0 g
.65385 .62591 m
.67308 .6194 L
.69231 .61685 L
.71154 .61791 L
.73077 .62293 L
.75 .63348 L
.75151 .63462 L
.76885 .65385 L
.76923 .6545 L
.77666 .67308 L
.7779 .69231 L
.77318 .71154 L
.76923 .72132 L
.76176 .73077 L
.75 .74285 L
.73998 .75 L
.73077 .75504 L
.71154 .76219 L
.69231 .76532 L
.67308 .7648 L
.65385 .76033 L
.63462 .75046 L
.63395 .75 L
.61538 .73089 L
.61531 .73077 L
.60679 .71154 L
.60488 .69231 L
.60873 .67308 L
.61538 .65735 L
.61894 .65385 L
.63462 .63756 L
.63856 .63462 L
.65385 .62591 L
s
.9 g
.67308 .64858 m
.69231 .64486 L
.71154 .64742 L
.72463 .65385 L
.73077 .65852 L
.74177 .67308 L
.74463 .69231 L
.73774 .71154 L
.73077 .72197 L
.71654 .73077 L
.71154 .73269 L
.69231 .7376 L
.67308 .73614 L
.65991 .73077 L
.65385 .72685 L
.64056 .71154 L
.63695 .69231 L
.6425 .67308 L
.65385 .6573 L
.65928 .65385 L
F
0 g
.67308 .64858 m
.69231 .64486 L
.71154 .64742 L
.72463 .65385 L
.73077 .65852 L
.74177 .67308 L
.74463 .69231 L
.73774 .71154 L
.73077 .72197 L
.71654 .73077 L
.71154 .73269 L
.69231 .7376 L
.67308 .73614 L
.65991 .73077 L
.65385 .72685 L
.64056 .71154 L
.63695 .69231 L
.6425 .67308 L
.65385 .6573 L
.65928 .65385 L
.67308 .64858 L
s
.5 g
.80769 .07678 m
.82692 .07374 L
.84615 .07303 L
.86538 .07481 L
.87788 .07692 L
.88462 .07935 L
.90385 .0872 L
.91879 .09615 L
.92308 .09935 L
.94 .11538 L
.94231 .11811 L
.95343 .13462 L
.96154 .15262 L
.96193 .15385 L
.96667 .17308 L
.96821 .19231 L
.96678 .21154 L
.96244 .23077 L
.96154 .23382 L
.95507 .25 L
.94436 .26923 L
.94231 .27231 L
.92963 .28846 L
.92308 .29543 L
.90952 .30769 L
.90385 .3121 L
.88462 .32464 L
.88051 .32692 L
.86538 .33398 L
.84615 .34066 L
.82692 .34491 L
.81721 .34615 L
.80769 .3468 L
.78846 .34639 L
.78588 .34615 L
.76923 .34358 L
.75 .33827 L
.73077 .33022 L
.72446 .32692 L
.71154 .31896 L
.69701 .30769 L
.69231 .30346 L
.6789 .28846 L
.67308 .28056 L
.6672 .26923 L
.66073 .25 L
.65901 .23077 L
.66151 .21154 L
.66763 .19231 L
.67308 .17983 L
.67705 .17308 L
.68985 .15385 L
.69231 .15062 L
.70639 .13462 L
.71154 .12945 L
.72771 .11538 L
.73077 .11301 L
.75 .09999 L
.75664 .09615 L
.76923 .08981 L
.78846 .08212 L
.80695 .07692 L
F
0 g
.80769 .07678 m
.82692 .07374 L
.84615 .07303 L
.86538 .07481 L
.87788 .07692 L
.88462 .07935 L
.90385 .0872 L
.91879 .09615 L
.92308 .09935 L
.94 .11538 L
.94231 .11811 L
.95343 .13462 L
.96154 .15262 L
.96193 .15385 L
.96667 .17308 L
.96821 .19231 L
.96678 .21154 L
.96244 .23077 L
.96154 .23382 L
.95507 .25 L
.94436 .26923 L
.94231 .27231 L
.92963 .28846 L
.92308 .29543 L
.90952 .30769 L
.90385 .3121 L
.88462 .32464 L
.88051 .32692 L
.86538 .33398 L
.84615 .34066 L
.82692 .34491 L
.81721 .34615 L
.80769 .3468 L
.78846 .34639 L
.78588 .34615 L
.76923 .34358 L
.75 .33827 L
.73077 .33022 L
.72446 .32692 L
.71154 .31896 L
.69701 .30769 L
.69231 .30346 L
.6789 .28846 L
.67308 .28056 L
.6672 .26923 L
.66073 .25 L
.65901 .23077 L
.66151 .21154 L
.66763 .19231 L
.67308 .17983 L
Mistroke
.67705 .17308 L
.68985 .15385 L
.69231 .15062 L
.70639 .13462 L
.71154 .12945 L
.72771 .11538 L
.73077 .11301 L
.75 .09999 L
.75664 .09615 L
.76923 .08981 L
.78846 .08212 L
.80695 .07692 L
.80769 .07678 L
Mfstroke
.6 g
.80769 .09388 m
.82692 .09066 L
.84615 .09013 L
.86538 .09246 L
.88048 .09615 L
.88462 .0981 L
.90385 .10791 L
.91406 .11538 L
.92308 .12389 L
.93176 .13462 L
.94231 .15375 L
.94235 .15385 L
.94818 .17308 L
.95018 .19231 L
.94876 .21154 L
.94398 .23077 L
.94231 .23576 L
.93567 .25 L
.92325 .26923 L
.92308 .26946 L
.9055 .28846 L
.90385 .28994 L
.88462 .30436 L
.87921 .30769 L
.86538 .31472 L
.84615 .32187 L
.82692 .3262 L
.82153 .32692 L
.80769 .32785 L
.78911 .32692 L
.78846 .32685 L
.76923 .32303 L
.75 .31606 L
.7345 .30769 L
.73077 .30522 L
.71154 .28866 L
.71136 .28846 L
.69736 .26923 L
.69231 .26023 L
.68943 .25 L
.68638 .23077 L
.68756 .21154 L
.69231 .19316 L
.69261 .19231 L
.70152 .17308 L
.71154 .15752 L
.71444 .15385 L
.73077 .13598 L
.73224 .13462 L
.75 .12021 L
.75717 .11538 L
.76923 .1084 L
.78846 .09974 L
.79845 .09615 L
F
0 g
.80769 .09388 m
.82692 .09066 L
.84615 .09013 L
.86538 .09246 L
.88048 .09615 L
.88462 .0981 L
.90385 .10791 L
.91406 .11538 L
.92308 .12389 L
.93176 .13462 L
.94231 .15375 L
.94235 .15385 L
.94818 .17308 L
.95018 .19231 L
.94876 .21154 L
.94398 .23077 L
.94231 .23576 L
.93567 .25 L
.92325 .26923 L
.92308 .26946 L
.9055 .28846 L
.90385 .28994 L
.88462 .30436 L
.87921 .30769 L
.86538 .31472 L
.84615 .32187 L
.82692 .3262 L
.82153 .32692 L
.80769 .32785 L
.78911 .32692 L
.78846 .32685 L
.76923 .32303 L
.75 .31606 L
.7345 .30769 L
.73077 .30522 L
.71154 .28866 L
.71136 .28846 L
.69736 .26923 L
.69231 .26023 L
.68943 .25 L
.68638 .23077 L
.68756 .21154 L
.69231 .19316 L
.69261 .19231 L
.70152 .17308 L
.71154 .15752 L
.71444 .15385 L
.73077 .13598 L
.73224 .13462 L
.75 .12021 L
Mistroke
.75717 .11538 L
.76923 .1084 L
.78846 .09974 L
.79845 .09615 L
.80769 .09388 L
Mfstroke
.7 g
.80769 .11059 m
.82692 .10717 L
.84615 .10687 L
.86538 .10998 L
.88153 .11538 L
.88462 .1172 L
.90385 .13021 L
.90843 .13462 L
.92241 .15385 L
.92308 .15461 L
.92984 .17308 L
.93252 .19231 L
.93115 .21154 L
.92584 .23077 L
.92308 .23784 L
.9163 .25 L
.90385 .26668 L
.90148 .26923 L
.88462 .28425 L
.87871 .28846 L
.86538 .29614 L
.84615 .30401 L
.83175 .30769 L
.82692 .30854 L
.80769 .30996 L
.78846 .30825 L
.78427 .30769 L
.76923 .3031 L
.75 .29367 L
.74247 .28846 L
.73077 .27794 L
.7238 .26923 L
.71362 .25 L
.71154 .24338 L
.70924 .23077 L
.70962 .21154 L
.71154 .20158 L
.71435 .19231 L
.72346 .17308 L
.73077 .16192 L
.73751 .15385 L
.75 .14134 L
.75828 .13462 L
.76923 .12712 L
.78846 .11715 L
.79218 .11538 L
F
0 g
.80769 .11059 m
.82692 .10717 L
.84615 .10687 L
.86538 .10998 L
.88153 .11538 L
.88462 .1172 L
.90385 .13021 L
.90843 .13462 L
.92241 .15385 L
.92308 .15461 L
.92984 .17308 L
.93252 .19231 L
.93115 .21154 L
.92584 .23077 L
.92308 .23784 L
.9163 .25 L
.90385 .26668 L
.90148 .26923 L
.88462 .28425 L
.87871 .28846 L
.86538 .29614 L
.84615 .30401 L
.83175 .30769 L
.82692 .30854 L
.80769 .30996 L
.78846 .30825 L
.78427 .30769 L
.76923 .3031 L
.75 .29367 L
.74247 .28846 L
.73077 .27794 L
.7238 .26923 L
.71362 .25 L
.71154 .24338 L
.70924 .23077 L
.70962 .21154 L
.71154 .20158 L
.71435 .19231 L
.72346 .17308 L
.73077 .16192 L
.73751 .15385 L
.75 .14134 L
.75828 .13462 L
.76923 .12712 L
.78846 .11715 L
.79218 .11538 L
.80769 .11059 L
s
.8 g
.80769 .12777 m
.82692 .12407 L
.84615 .12414 L
.86538 .12844 L
.87949 .13462 L
.88462 .13828 L
.90049 .15385 L
.90385 .15763 L
.91055 .17308 L
.91431 .19231 L
.91306 .21154 L
.90703 .23077 L
.90385 .2378 L
.89567 .25 L
.88462 .26243 L
.87673 .26923 L
.86538 .27692 L
.84615 .28595 L
.83801 .28846 L
.82692 .29083 L
.80769 .29197 L
.78846 .28924 L
.78479 .28846 L
.76923 .28203 L
.75146 .26923 L
.75 .26791 L
.7372 .25 L
.73102 .23077 L
.73077 .2291 L
.73057 .21154 L
.73077 .20997 L
.73523 .19231 L
.74518 .17308 L
.75 .16624 L
.76166 .15385 L
.76923 .14741 L
.78846 .13535 L
.78964 .13462 L
F
0 g
.80769 .12777 m
.82692 .12407 L
.84615 .12414 L
.86538 .12844 L
.87949 .13462 L
.88462 .13828 L
.90049 .15385 L
.90385 .15763 L
.91055 .17308 L
.91431 .19231 L
.91306 .21154 L
.90703 .23077 L
.90385 .2378 L
.89567 .25 L
.88462 .26243 L
.87673 .26923 L
.86538 .27692 L
.84615 .28595 L
.83801 .28846 L
.82692 .29083 L
.80769 .29197 L
.78846 .28924 L
.78479 .28846 L
.76923 .28203 L
.75146 .26923 L
.75 .26791 L
.7372 .25 L
.73102 .23077 L
.73077 .2291 L
.73057 .21154 L
.73077 .20997 L
.73523 .19231 L
.74518 .17308 L
.75 .16624 L
.76166 .15385 L
.76923 .14741 L
.78846 .13535 L
.78964 .13462 L
.80769 .12777 L
s
.9 g
.80769 .14669 m
.82692 .14252 L
.84615 .14324 L
.86538 .14992 L
.87206 .15385 L
.88462 .16606 L
.88832 .17308 L
.89419 .19231 L
.89322 .21154 L
.88594 .23077 L
.88462 .23334 L
.87109 .25 L
.86538 .25489 L
.84615 .26625 L
.83756 .26923 L
.82692 .27173 L
.80769 .27243 L
.79232 .26923 L
.78846 .26795 L
.76923 .25617 L
.76376 .25 L
.75401 .23077 L
.7524 .21154 L
.75724 .19231 L
.76923 .17308 L
.76923 .17308 L
.78846 .156 L
.79121 .15385 L
F
0 g
.80769 .14669 m
.82692 .14252 L
.84615 .14324 L
.86538 .14992 L
.87206 .15385 L
.88462 .16606 L
.88832 .17308 L
.89419 .19231 L
.89322 .21154 L
.88594 .23077 L
.88462 .23334 L
.87109 .25 L
.86538 .25489 L
.84615 .26625 L
.83756 .26923 L
.82692 .27173 L
.80769 .27243 L
.79232 .26923 L
.78846 .26795 L
.76923 .25617 L
.76376 .25 L
.75401 .23077 L
.7524 .21154 L
.75724 .19231 L
.76923 .17308 L
.76923 .17308 L
.78846 .156 L
.79121 .15385 L
.80769 .14669 L
s
1 g
.80769 .171 m
.82692 .1653 L
.84615 .16799 L
.85468 .17308 L
.86538 .18533 L
.8683 .19231 L
.86822 .21154 L
.86538 .21901 L
.85929 .23077 L
.84615 .2419 L
.82692 .2487 L
.80769 .24872 L
.78846 .23986 L
.78329 .23077 L
.77842 .21154 L
.78445 .19231 L
.78846 .18407 L
.80287 .17308 L
F
0 g
.80769 .171 m
.82692 .1653 L
.84615 .16799 L
.85468 .17308 L
.86538 .18533 L
.8683 .19231 L
.86822 .21154 L
.86538 .21901 L
.85929 .23077 L
.84615 .2419 L
.82692 .2487 L
.80769 .24872 L
.78846 .23986 L
.78329 .23077 L
.77842 .21154 L
.78445 .19231 L
.78846 .18407 L
.80287 .17308 L
.80769 .171 L
s
.1 g
.98077 .61421 m
.97102 .59615 L
.96154 .58177 L
.95797 .57692 L
.94231 .55787 L
.94215 .55769 L
.92357 .53846 L
.92308 .53799 L
.90385 .5203 L
.90266 .51923 L
.88462 .5036 L
.8807 .5 L
.86538 .48695 L
.86075 .48077 L
.84904 .46154 L
.85445 .44231 L
.86538 .43177 L
.87702 .42308 L
.88462 .41716 L
.90385 .40443 L
.9049 .40385 L
.92308 .39029 L
.93071 .38462 L
.94231 .3748 L
.95291 .36538 L
.96154 .35688 L
.97174 .34615 L
.98077 .33553 L
F
0 g
.98077 .61421 m
.97102 .59615 L
.96154 .58177 L
.95797 .57692 L
.94231 .55787 L
.94215 .55769 L
.92357 .53846 L
.92308 .53799 L
.90385 .5203 L
.90266 .51923 L
.88462 .5036 L
.8807 .5 L
.86538 .48695 L
.86075 .48077 L
.84904 .46154 L
.85445 .44231 L
.86538 .43177 L
.87702 .42308 L
.88462 .41716 L
.90385 .40443 L
.9049 .40385 L
.92308 .39029 L
.93071 .38462 L
.94231 .3748 L
.95291 .36538 L
.96154 .35688 L
.97174 .34615 L
.98077 .33553 L
s
.1 g
.98077 .05863 m
.97976 .05769 L
.96154 .04287 L
.95506 .03846 L
.94231 .03092 L
.92308 .02199 L
.91575 .01923 L
.98077 .01923 L
F
0 g
.98077 .05863 m
.97976 .05769 L
.96154 .04287 L
.95506 .03846 L
.94231 .03092 L
.92308 .02199 L
.91575 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.652 .752 .923 r
.39897 .59933 .40509 .60464 .41533 .60181 .40923 .59651 Mtetra
.653 .753 .923 r
.40923 .59651 .41533 .60181 .42561 .59897 .41954 .59366 Mtetra
.41954 .59366 .42561 .59897 .43593 .59611 .42988 .5908 Mtetra
.653 .754 .924 r
.42988 .5908 .43593 .59611 .44629 .59322 .44027 .58791 Mtetra
.654 .755 .924 r
.44027 .58791 .44629 .59322 .45669 .5903 .4507 .58499 Mtetra
.655 .756 .924 r
.4507 .58499 .45669 .5903 .46714 .58735 .46117 .58203 Mtetra
.656 .757 .924 r
.46117 .58203 .46714 .58735 .47763 .58438 .47169 .57905 Mtetra
.47169 .57905 .47763 .58438 .48815 .58136 .48224 .57602 Mtetra
.657 .758 .924 r
.48224 .57602 .48815 .58136 .49872 .57831 .49284 .57296 Mtetra
.658 .759 .924 r
.49284 .57296 .49872 .57831 .50934 .57523 .50348 .56987 Mtetra
.659 .759 .924 r
.50348 .56987 .50934 .57523 .51999 .57211 .51416 .56673 Mtetra
.66 .76 .924 r
.51416 .56673 .51999 .57211 .53069 .56895 .52489 .56356 Mtetra
.661 .76 .924 r
.52489 .56356 .53069 .56895 .54142 .56576 .53565 .56035 Mtetra
.661 .761 .924 r
.53565 .56035 .54142 .56576 .5522 .56254 .54646 .55712 Mtetra
.662 .761 .924 r
.54646 .55712 .5522 .56254 .56302 .5593 .55731 .55387 Mtetra
.55731 .55387 .56302 .5593 .57389 .55603 .56821 .5506 Mtetra
.661 .762 .925 r
.56821 .5506 .57389 .55603 .5848 .55276 .57915 .54734 Mtetra
.66 .763 .926 r
.57915 .54734 .5848 .55276 .59575 .54949 .59013 .5441 Mtetra
.657 .764 .928 r
.59013 .5441 .59575 .54949 .60674 .54625 .60116 .5409 Mtetra
.654 .766 .931 r
.60116 .5409 .60674 .54625 .61778 .54303 .61223 .53775 Mtetra
.65 .768 .935 r
.61223 .53775 .61778 .54303 .62886 .53986 .62335 .53469 Mtetra
.645 .771 .94 r
.62335 .53469 .62886 .53986 .64 .53675 .63452 .53172 Mtetra
.638 .776 .946 r
.63452 .53172 .64 .53675 .65118 .53371 .64574 .52887 Mtetra
.63 .781 .954 r
.64574 .52887 .65118 .53371 .66241 .53075 .65702 .52613 Mtetra
.621 .788 .962 r
.65702 .52613 .66241 .53075 .67369 .52785 .66835 .5235 Mtetra
.611 .797 .971 r
.66835 .5235 .67369 .52785 .68503 .52503 .67974 .52097 Mtetra
.6 .807 .979 r
.67974 .52097 .68503 .52503 .69642 .52225 .69118 .51851 Mtetra
.588 .817 .987 r
.69118 .51851 .69642 .52225 .70786 .51949 .70268 .51607 Mtetra
.578 .829 .992 r
.70268 .51607 .70786 .51949 .71935 .51672 .71423 .51362 Mtetra
.568 .84 .996 r
.71423 .51362 .71935 .51672 .73089 .51392 .72583 .5111 Mtetra
.561 .85 .997 r
.72583 .5111 .73089 .51392 .74247 .51104 .73748 .50848 Mtetra
.557 .86 .997 r
.73748 .50848 .74247 .51104 .75411 .50807 .74917 .5057 Mtetra
.558 .869 .995 r
.74917 .5057 .75411 .50807 .76578 .50499 .76091 .50274 Mtetra
.563 .877 .993 r
.76091 .50274 .76578 .50499 .7775 .50179 .77268 .49958 Mtetra
.572 .883 .992 r
.77268 .49958 .7775 .50179 .78926 .49846 .78449 .49623 Mtetra
.584 .887 .991 r
.78449 .49623 .78926 .49846 .80106 .49501 .79633 .49269 Mtetra
.597 .89 .99 r
.79633 .49269 .80106 .49501 .8129 .49146 .80821 .48898 Mtetra
.611 .889 .989 r
.80821 .48898 .8129 .49146 .82478 .48781 .82013 .48514 Mtetra
.623 .886 .988 r
.82013 .48514 .82478 .48781 .83671 .4841 .83208 .48119 Mtetra
.634 .881 .987 r
.83208 .48119 .83671 .4841 .84868 .48034 .84408 .47716 Mtetra
.643 .874 .984 r
.84408 .47716 .84868 .48034 .86069 .47654 .85612 .4731 Mtetra
.65 .865 .981 r
.85612 .4731 .86069 .47654 .87276 .47272 .86821 .46901 Mtetra
.655 .857 .977 r
.86821 .46901 .87276 .47272 .88487 .46887 .88034 .46491 Mtetra
.658 .848 .973 r
.88034 .46491 .88487 .46887 .89703 .46501 .89253 .46081 Mtetra
.661 .84 .969 r
.89253 .46081 .89703 .46501 .90924 .46113 .90476 .45671 Mtetra
.664 .832 .964 r
.90476 .45671 .90924 .46113 .92149 .45721 .91705 .4526 Mtetra
.666 .826 .961 r
.91705 .4526 .92149 .45721 .93379 .45327 .92938 .44848 Mtetra
.668 .821 .957 r
.92938 .44848 .93379 .45327 .94614 .44928 .94176 .44433 Mtetra
.67 .816 .954 r
.94176 .44433 .94614 .44928 .95854 .44523 .95418 .44014 Mtetra
.672 .812 .95 r
.95418 .44014 .95854 .44523 .97097 .44112 .96665 .4359 Mtetra
.651 .752 .923 r
.39281 .59399 .39897 .59933 .40923 .59651 .40309 .59117 Mtetra
.652 .753 .924 r
.40309 .59117 .40923 .59651 .41954 .59366 .41342 .58833 Mtetra
.41342 .58833 .41954 .59366 .42988 .5908 .4238 .58546 Mtetra
.653 .754 .924 r
.4238 .58546 .42988 .5908 .44027 .58791 .43421 .58256 Mtetra
.653 .755 .924 r
.43421 .58256 .44027 .58791 .4507 .58499 .44466 .57964 Mtetra
.654 .756 .925 r
.44466 .57964 .4507 .58499 .46117 .58203 .45516 .57668 Mtetra
.655 .757 .925 r
.45516 .57668 .46117 .58203 .47169 .57905 .4657 .57369 Mtetra
.656 .758 .925 r
.4657 .57369 .47169 .57905 .48224 .57602 .47629 .57066 Mtetra
.657 .758 .925 r
.47629 .57066 .48224 .57602 .49284 .57296 .48691 .56759 Mtetra
.658 .759 .924 r
.48691 .56759 .49284 .57296 .50348 .56987 .49758 .56447 Mtetra
.659 .76 .924 r
.49758 .56447 .50348 .56987 .51416 .56673 .50829 .56133 Mtetra
.66 .76 .924 r
.50829 .56133 .51416 .56673 .52489 .56356 .51904 .55814 Mtetra
.66 .761 .924 r
.51904 .55814 .52489 .56356 .53565 .56035 .52984 .55492 Mtetra
.661 .761 .924 r
.52984 .55492 .53565 .56035 .54646 .55712 .54068 .55168 Mtetra
.661 .762 .925 r
.54068 .55168 .54646 .55712 .55731 .55387 .55156 .54842 Mtetra
.66 .762 .925 r
.55156 .54842 .55731 .55387 .56821 .5506 .56249 .54517 Mtetra
.659 .763 .927 r
.56249 .54517 .56821 .5506 .57915 .54734 .57346 .54193 Mtetra
.657 .764 .929 r
.57346 .54193 .57915 .54734 .59013 .5441 .58447 .53873 Mtetra
.653 .765 .932 r
.58447 .53873 .59013 .5441 .60116 .5409 .59553 .5356 Mtetra
.648 .768 .936 r
.59553 .5356 .60116 .5409 .61223 .53775 .60664 .53257 Mtetra
.642 .771 .941 r
.60664 .53257 .61223 .53775 .62335 .53469 .6178 .52966 Mtetra
.633 .775 .948 r
.6178 .52966 .62335 .53469 .63452 .53172 .62901 .5269 Mtetra
.622 .78 .957 r
.62901 .5269 .63452 .53172 .64574 .52887 .64028 .52431 Mtetra
.609 .788 .967 r
.64028 .52431 .64574 .52887 .65702 .52613 .6516 .5219 Mtetra
.593 .796 .977 r
.6516 .5219 .65702 .52613 .66835 .5235 .66299 .51964 Mtetra
.574 .806 .987 r
.66299 .51964 .66835 .5235 .67974 .52097 .67443 .51753 Mtetra
.551 .817 .995 r
.67443 .51753 .67974 .52097 .69118 .51851 .68594 .51551 Mtetra
.527 .827 .999 r
.68594 .51551 .69118 .51851 .70268 .51607 .6975 .51352 Mtetra
.501 .836 .998 r
.6975 .51352 .70268 .51607 .71423 .51362 .70912 .51152 Mtetra
.477 .844 .991 r
.70912 .51152 .71423 .51362 .72583 .5111 .7208 .5094 Mtetra
.457 .849 .978 r
.7208 .5094 .72583 .5111 .73748 .50848 .73252 .50712 Mtetra
.445 .854 .964 r
.73252 .50712 .73748 .50848 .74917 .5057 .74428 .50461 Mtetra
.442 .86 .951 r
.74428 .50461 .74917 .5057 .76091 .50274 .75608 .50182 Mtetra
.449 .869 .943 r
.75608 .50182 .76091 .50274 .77268 .49958 .76791 .49874 Mtetra
.467 .879 .941 r
.76791 .49874 .77268 .49958 .78449 .49623 .77977 .49535 Mtetra
.492 .891 .945 r
.77977 .49535 .78449 .49623 .79633 .49269 .79166 .49167 Mtetra
.522 .903 .953 r
.79166 .49167 .79633 .49269 .80821 .48898 .80358 .48774 Mtetra
.553 .911 .963 r
.80358 .48774 .80821 .48898 .82013 .48514 .81553 .48361 Mtetra
.582 .915 .972 r
.81553 .48361 .82013 .48514 .83208 .48119 .82751 .47932 Mtetra
.608 .914 .979 r
.82751 .47932 .83208 .48119 .84408 .47716 .83953 .47492 Mtetra
.628 .908 .983 r
.83953 .47492 .84408 .47716 .85612 .4731 .85159 .47047 Mtetra
.642 .899 .984 r
.85159 .47047 .85612 .4731 .86821 .46901 .8637 .466 Mtetra
.653 .888 .982 r
.8637 .466 .86821 .46901 .88034 .46491 .87585 .46153 Mtetra
.66 .876 .979 r
.87585 .46153 .88034 .46491 .89253 .46081 .88805 .4571 Mtetra
.664 .864 .975 r
.88805 .4571 .89253 .46081 .90476 .45671 .9003 .45269 Mtetra
.667 .853 .971 r
.9003 .45269 .90476 .45671 .91705 .4526 .9126 .44831 Mtetra
.67 .843 .966 r
.9126 .44831 .91705 .4526 .92938 .44848 .92496 .44395 Mtetra
.672 .835 .962 r
.92496 .44395 .92938 .44848 .94176 .44433 .93736 .43959 Mtetra
.674 .828 .957 r
.93736 .43959 .94176 .44433 .95418 .44014 .94981 .43522 Mtetra
.676 .822 .954 r
.94981 .43522 .95418 .44014 .96665 .4359 .96231 .43081 Mtetra
.651 .752 .924 r
.3866 .58862 .39281 .59399 .40309 .59117 .39691 .5858 Mtetra
.651 .753 .924 r
.39691 .5858 .40309 .59117 .41342 .58833 .40726 .58296 Mtetra
.40726 .58296 .41342 .58833 .4238 .58546 .41766 .58009 Mtetra
.652 .754 .925 r
.41766 .58009 .4238 .58546 .43421 .58256 .4281 .57719 Mtetra
.653 .755 .925 r
.4281 .57719 .43421 .58256 .44466 .57964 .43858 .57426 Mtetra
.653 .756 .925 r
.43858 .57426 .44466 .57964 .45516 .57668 .44911 .5713 Mtetra
.654 .757 .925 r
.44911 .5713 .45516 .57668 .4657 .57369 .45967 .5683 Mtetra
.655 .758 .925 r
.45967 .5683 .4657 .57369 .47629 .57066 .47028 .56525 Mtetra
.656 .758 .925 r
.47028 .56525 .47629 .57066 .48691 .56759 .48094 .56217 Mtetra
.657 .759 .925 r
.48094 .56217 .48691 .56759 .49758 .56447 .49163 .55905 Mtetra
.658 .76 .925 r
.49163 .55905 .49758 .56447 .50829 .56133 .50237 .55589 Mtetra
.659 .76 .925 r
.50237 .55589 .50829 .56133 .51904 .55814 .51316 .55269 Mtetra
.66 .761 .925 r
.51316 .55269 .51904 .55814 .52984 .55492 .52398 .54946 Mtetra
.52398 .54946 .52984 .55492 .54068 .55168 .53485 .54622 Mtetra
.66 .762 .925 r
.53485 .54622 .54068 .55168 .55156 .54842 .54576 .54296 Mtetra
.659 .763 .927 r
.54576 .54296 .55156 .54842 .56249 .54517 .55672 .53973 Mtetra
.656 .764 .928 r
.55672 .53973 .56249 .54517 .57346 .54193 .56772 .53653 Mtetra
.653 .765 .931 r
.56772 .53653 .57346 .54193 .58447 .53873 .57877 .5334 Mtetra
.648 .767 .936 r
.57877 .5334 .58447 .53873 .59553 .5356 .58986 .53038 Mtetra
.64 .769 .941 r
.58986 .53038 .59553 .5356 .60664 .53257 .60101 .5275 Mtetra
.63 .773 .949 r
.60101 .5275 .60664 .53257 .6178 .52966 .61221 .52481 Mtetra
.617 .778 .958 r
.61221 .52481 .6178 .52966 .62901 .5269 .62346 .52234 Mtetra
.599 .784 .969 r
.62346 .52234 .62901 .5269 .64028 .52431 .63478 .52011 Mtetra
.576 .792 .981 r
.63478 .52011 .64028 .52431 .6516 .5219 .64615 .51812 Mtetra
.547 .801 .992 r
.64615 .51812 .6516 .5219 .66299 .51964 .6576 .51637 Mtetra
.509 .808 .999 r
.6576 .51637 .66299 .51964 .67443 .51753 .66911 .51481 Mtetra
.464 .813 .998 r
.66911 .51481 .67443 .51753 .68594 .51551 .68069 .5134 Mtetra
.411 .811 .983 r
.68069 .5134 .68594 .51551 .6975 .51352 .69233 .51203 Mtetra
.354 .801 .953 r
.69233 .51203 .6975 .51352 .70912 .51152 .70403 .51062 Mtetra
.3 .784 .908 r
.70403 .51062 .70912 .51152 .7208 .5094 .71579 .50905 Mtetra
.257 .765 .857 r
.71579 .50905 .7208 .5094 .73252 .50712 .72759 .50724 Mtetra
.231 .75 .81 r
.72759 .50724 .73252 .50712 .74428 .50461 .73943 .50509 Mtetra
.224 .745 .775 r
.73943 .50509 .74428 .50461 .75608 .50182 .75131 .50254 Mtetra
.237 .752 .758 r
.75131 .50254 .75608 .50182 .76791 .49874 .76321 .49955 Mtetra
.268 .772 .76 r
.76321 .49955 .76791 .49874 .77977 .49535 .77513 .49611 Mtetra
.314 .802 .779 r
.77513 .49611 .77977 .49535 .79166 .49167 .78707 .49226 Mtetra
.371 .838 .811 r
.78707 .49226 .79166 .49167 .80358 .48774 .79903 .48803 Mtetra
.433 .874 .85 r
.79903 .48803 .80358 .48774 .81553 .48361 .81101 .4835 Mtetra
.494 .904 .89 r
.81101 .4835 .81553 .48361 .82751 .47932 .82301 .47874 Mtetra
.548 .924 .925 r
.82301 .47874 .82751 .47932 .83953 .47492 .83505 .47383 Mtetra
.592 .932 .951 r
.83505 .47383 .83953 .47492 .85159 .47047 .84712 .46884 Mtetra
.624 .93 .968 r
.84712 .46884 .85159 .47047 .8637 .466 .85923 .46384 Mtetra
.646 .921 .977 r
.85923 .46384 .8637 .466 .87585 .46153 .87138 .45887 Mtetra
.66 .907 .98 r
.87138 .45887 .87585 .46153 .88805 .4571 .88359 .45396 Mtetra
.668 .891 .978 r
.88359 .45396 .88805 .4571 .9003 .45269 .89585 .44914 Mtetra
.673 .876 .975 r
.89585 .44914 .9003 .45269 .9126 .44831 .90817 .44439 Mtetra
.676 .862 .97 r
.90817 .44439 .9126 .44831 .92496 .44395 .92054 .43971 Mtetra
.677 .85 .965 r
.92054 .43971 .92496 .44395 .93736 .43959 .93296 .43507 Mtetra
.679 .84 .961 r
.93296 .43507 .93736 .43959 .94981 .43522 .94543 .43045 Mtetra
.68 .832 .956 r
.94543 .43045 .94981 .43522 .96231 .43081 .95796 .42584 Mtetra
.65 .752 .924 r
.38034 .58321 .3866 .58862 .39691 .5858 .39068 .58039 Mtetra
.39068 .58039 .39691 .5858 .40726 .58296 .40106 .57755 Mtetra
.65 .753 .925 r
.40106 .57755 .40726 .58296 .41766 .58009 .41148 .57468 Mtetra
.651 .754 .925 r
.41148 .57468 .41766 .58009 .4281 .57719 .42195 .57178 Mtetra
.652 .755 .925 r
.42195 .57178 .4281 .57719 .43858 .57426 .43245 .56884 Mtetra
.653 .756 .925 r
.43245 .56884 .43858 .57426 .44911 .5713 .443 .56587 Mtetra
.654 .757 .925 r
.443 .56587 .44911 .5713 .45967 .5683 .4536 .56287 Mtetra
.655 .758 .925 r
.4536 .56287 .45967 .5683 .47028 .56525 .46424 .55982 Mtetra
.656 .758 .925 r
.46424 .55982 .47028 .56525 .48094 .56217 .47492 .55672 Mtetra
.657 .759 .925 r
.47492 .55672 .48094 .56217 .49163 .55905 .48564 .55359 Mtetra
.658 .76 .925 r
.48564 .55359 .49163 .55905 .50237 .55589 .49641 .55042 Mtetra
.659 .76 .925 r
.49641 .55042 .50237 .55589 .51316 .55269 .50722 .54721 Mtetra
.659 .761 .925 r
.50722 .54721 .51316 .55269 .52398 .54946 .51808 .54398 Mtetra
.659 .762 .926 r
.51808 .54398 .52398 .54946 .53485 .54622 .52898 .54073 Mtetra
.658 .762 .926 r
.52898 .54073 .53485 .54622 .54576 .54296 .53992 .53749 Mtetra
.657 .763 .928 r
.53992 .53749 .54576 .54296 .55672 .53973 .55091 .53428 Mtetra
.653 .764 .931 r
.55091 .53428 .55672 .53973 .56772 .53653 .56194 .53114 Mtetra
.648 .765 .935 r
.56194 .53114 .56772 .53653 .57877 .5334 .57302 .52811 Mtetra
.64 .767 .94 r
.57302 .52811 .57877 .5334 .58986 .53038 .58415 .52523 Mtetra
.629 .77 .948 r
.58415 .52523 .58986 .53038 .60101 .5275 .59534 .52256 Mtetra
.614 .774 .957 r
.59534 .52256 .60101 .5275 .61221 .52481 .60657 .52016 Mtetra
.593 .78 .969 r
.60657 .52016 .61221 .52481 .62346 .52234 .61787 .51806 Mtetra
.564 .786 .982 r
.61787 .51806 .62346 .52234 .63478 .52011 .62924 .51629 Mtetra
.525 .791 .994 r
.62924 .51629 .63478 .52011 .64615 .51812 .64068 .51487 Mtetra
.471 .793 .999 r
.64068 .51487 .64615 .51812 .6576 .51637 .65218 .51377 Mtetra
.401 .787 .99 r
.65218 .51377 .6576 .51637 .66911 .51481 .66377 .51294 Mtetra
.312 .765 .955 r
.66377 .51294 .66911 .51481 .68069 .5134 .67543 .5123 Mtetra
.211 .723 .887 r
.67543 .5123 .68069 .5134 .69233 .51203 .68716 .51173 Mtetra
.114 .665 .791 r
.68716 .51173 .69233 .51203 .70403 .51062 .69895 .5111 Mtetra
0 0 0 r
.69895 .5111 .70403 .51062 .71579 .50905 .7108 .51026 Mtetra
.019 0 0 r
.7108 .51026 .71579 .50905 .72759 .50724 .72271 .50907 Mtetra
.044 0 0 r
.72271 .50907 .72759 .50724 .73943 .50509 .73464 .5074 Mtetra
.73464 .5074 .73943 .50509 .75131 .50254 .74661 .50516 Mtetra
.021 0 0 r
.74661 .50516 .75131 .50254 .76321 .49955 .75859 .5023 Mtetra
0 0 0 r
.75859 .5023 .76321 .49955 .77513 .49611 .77058 .49882 Mtetra
.77058 .49882 .77513 .49611 .78707 .49226 .78257 .49473 Mtetra
.78257 .49473 .78707 .49226 .79903 .48803 .79457 .49011 Mtetra
.79457 .49011 .79903 .48803 .81101 .4835 .80658 .48505 Mtetra
.345 .808 .706 r
.80658 .48505 .81101 .4835 .82301 .47874 .8186 .47967 Mtetra
.439 .872 .789 r
.8186 .47967 .82301 .47874 .83505 .47383 .83064 .47408 Mtetra
.521 .918 .86 r
.83064 .47408 .83505 .47383 .84712 .46884 .84271 .46838 Mtetra
.585 .942 .914 r
.84271 .46838 .84712 .46884 .85923 .46384 .85481 .46267 Mtetra
.63 .946 .948 r
.85481 .46267 .85923 .46384 .87138 .45887 .86696 .45703 Mtetra
.657 .937 .966 r
.86696 .45703 .87138 .45887 .88359 .45396 .87916 .4515 Mtetra
.673 .921 .974 r
.87916 .4515 .88359 .45396 .89585 .44914 .89142 .44612 Mtetra
.681 .903 .975 r
.89142 .44612 .89585 .44914 .90817 .44439 .90374 .44088 Mtetra
.684 .884 .972 r
.90374 .44088 .90817 .44439 .92054 .43971 .91611 .43577 Mtetra
.686 .868 .968 r
.91611 .43577 .92054 .43971 .93296 .43507 .92855 .43078 Mtetra
.686 .855 .963 r
.92855 .43078 .93296 .43507 .94543 .43045 .94104 .42586 Mtetra
.687 .843 .958 r
.94104 .42586 .94543 .43045 .95796 .42584 .95359 .42099 Mtetra
.649 .751 .924 r
.37404 .57776 .38034 .58321 .39068 .58039 .3844 .57494 Mtetra
.649 .752 .925 r
.3844 .57494 .39068 .58039 .40106 .57755 .39481 .5721 Mtetra
.65 .753 .925 r
.39481 .5721 .40106 .57755 .41148 .57468 .40525 .56922 Mtetra
.65 .754 .925 r
.40525 .56922 .41148 .57468 .42195 .57178 .41575 .56632 Mtetra
.651 .755 .925 r
.41575 .56632 .42195 .57178 .43245 .56884 .42628 .56338 Mtetra
.652 .756 .926 r
.42628 .56338 .43245 .56884 .443 .56587 .43686 .56041 Mtetra
.653 .757 .926 r
.43686 .56041 .443 .56587 .4536 .56287 .44748 .55739 Mtetra
.654 .757 .925 r
.44748 .55739 .4536 .56287 .46424 .55982 .45815 .55434 Mtetra
.655 .758 .925 r
.45815 .55434 .46424 .55982 .47492 .55672 .46886 .55123 Mtetra
.657 .759 .925 r
.46886 .55123 .47492 .55672 .48564 .55359 .47961 .54809 Mtetra
.658 .76 .925 r
.47961 .54809 .48564 .55359 .49641 .55042 .49041 .54491 Mtetra
.49041 .54491 .49641 .55042 .50722 .54721 .50125 .54169 Mtetra
.658 .761 .926 r
.50125 .54169 .50722 .54721 .51808 .54398 .51213 .53845 Mtetra
.658 .762 .926 r
.51213 .53845 .51808 .54398 .52898 .54073 .52306 .53521 Mtetra
.657 .762 .927 r
.52306 .53521 .52898 .54073 .53992 .53749 .53403 .53199 Mtetra
.654 .763 .93 r
.53403 .53199 .53992 .53749 .55091 .53428 .54505 .52883 Mtetra
.649 .764 .933 r
.54505 .52883 .55091 .53428 .56194 .53114 .55612 .52576 Mtetra
.642 .765 .938 r
.55612 .52576 .56194 .53114 .57302 .52811 .56723 .52285 Mtetra
.631 .768 .945 r
.56723 .52285 .57302 .52811 .58415 .52523 .5784 .52016 Mtetra
.615 .77 .955 r
.5784 .52016 .58415 .52523 .59534 .52256 .58962 .51776 Mtetra
.592 .774 .967 r
.58962 .51776 .59534 .52256 .60657 .52016 .6009 .51571 Mtetra
.56 .778 .98 r
.6009 .51571 .60657 .52016 .61787 .51806 .61225 .51407 Mtetra
.514 .78 .993 r
.61225 .51407 .61787 .51806 .62924 .51629 .62367 .51289 Mtetra
.447 .777 .998 r
.62367 .51289 .62924 .51629 .64068 .51487 .63517 .51217 Mtetra
.354 .759 .983 r
.63517 .51217 .64068 .51487 .65218 .51377 .64675 .51188 Mtetra
.23 .715 .929 r
.64675 .51188 .65218 .51377 .66377 .51294 .65841 .51197 Mtetra
.087 .637 .823 r
.65841 .51197 .66377 .51294 .67543 .5123 .67016 .5123 Mtetra
.051 0 0 r
.67016 .5123 .67543 .5123 .68716 .51173 .68199 .51274 Mtetra
.157 0 0 r
.68199 .51274 .68716 .51173 .69895 .5111 .69389 .51309 Mtetra
.224 0 0 r
.69389 .51309 .69895 .5111 .7108 .51026 .70585 .51316 Mtetra
.256 0 0 r
.70585 .51316 .7108 .51026 .72271 .50907 .71787 .51275 Mtetra
.261 0 0 r
.71787 .51275 .72271 .50907 .73464 .5074 .72991 .5117 Mtetra
.246 0 0 r
.72991 .5117 .73464 .5074 .74661 .50516 .74198 .50988 Mtetra
.215 0 0 r
.74198 .50988 .74661 .50516 .75859 .5023 .75405 .5072 Mtetra
.168 0 0 r
.75405 .5072 .75859 .5023 .77058 .49882 .76611 .50366 Mtetra
.106 0 0 r
.76611 .50366 .77058 .49882 .78257 .49473 .77817 .49929 Mtetra
.028 0 0 r
.77817 .49929 .78257 .49473 .79457 .49011 .79021 .49418 Mtetra
0 0 0 r
.79021 .49418 .79457 .49011 .80658 .48505 .80224 .48846 Mtetra
.80224 .48846 .80658 .48505 .8186 .47967 .81427 .48229 Mtetra
.81427 .48229 .8186 .47967 .83064 .47408 .82631 .47582 Mtetra
.417 .845 .702 r
.82631 .47582 .83064 .47408 .84271 .46838 .83837 .46922 Mtetra
.521 .914 .806 r
.83837 .46922 .84271 .46838 .85481 .46267 .85046 .46261 Mtetra
.599 .951 .883 r
.85046 .46261 .85481 .46267 .86696 .45703 .86259 .4561 Mtetra
.649 .959 .932 r
.86259 .4561 .86696 .45703 .87916 .4515 .87477 .44977 Mtetra
.678 .949 .957 r
.87477 .44977 .87916 .4515 .89142 .44612 .88701 .44367 Mtetra
.691 .929 .968 r
.88701 .44367 .89142 .44612 .90374 .44088 .89932 .4378 Mtetra
.696 .908 .97 r
.89932 .4378 .90374 .44088 .91611 .43577 .91169 .43217 Mtetra
.697 .887 .967 r
.91169 .43217 .91611 .43577 .92855 .43078 .92413 .42672 Mtetra
.697 .869 .963 r
.92413 .42672 .92855 .43078 .94104 .42586 .93663 .42143 Mtetra
.696 .855 .959 r
.93663 .42143 .94104 .42586 .95359 .42099 .94919 .41624 Mtetra
.648 .751 .925 r
.3677 .57226 .37404 .57776 .3844 .57494 .37808 .56944 Mtetra
.648 .752 .925 r
.37808 .56944 .3844 .57494 .39481 .5721 .38851 .5666 Mtetra
.649 .753 .925 r
.38851 .5666 .39481 .5721 .40525 .56922 .39898 .56373 Mtetra
.65 .754 .925 r
.39898 .56373 .40525 .56922 .41575 .56632 .4095 .56082 Mtetra
.65 .754 .926 r
.4095 .56082 .41575 .56632 .42628 .56338 .42006 .55788 Mtetra
.651 .755 .926 r
.42006 .55788 .42628 .56338 .43686 .56041 .43066 .5549 Mtetra
.653 .756 .926 r
.43066 .5549 .43686 .56041 .44748 .55739 .44131 .55188 Mtetra
.654 .757 .926 r
.44131 .55188 .44748 .55739 .45815 .55434 .45201 .54881 Mtetra
.655 .758 .925 r
.45201 .54881 .45815 .55434 .46886 .55123 .46274 .5457 Mtetra
.656 .759 .925 r
.46274 .5457 .46886 .55123 .47961 .54809 .47353 .54255 Mtetra
.657 .759 .925 r
.47353 .54255 .47961 .54809 .49041 .54491 .48435 .53935 Mtetra
.658 .76 .925 r
.48435 .53935 .49041 .54491 .50125 .54169 .49522 .53613 Mtetra
.658 .761 .926 r
.49522 .53613 .50125 .54169 .51213 .53845 .50614 .53289 Mtetra
.657 .761 .927 r
.50614 .53289 .51213 .53845 .52306 .53521 .5171 .52966 Mtetra
.655 .762 .929 r
.5171 .52966 .52306 .53521 .53403 .53199 .5281 .52647 Mtetra
.651 .763 .931 r
.5281 .52647 .53403 .53199 .54505 .52883 .53915 .52336 Mtetra
.644 .764 .936 r
.53915 .52336 .54505 .52883 .55612 .52576 .55025 .5204 Mtetra
.634 .765 .942 r
.55025 .5204 .55612 .52576 .56723 .52285 .5614 .51764 Mtetra
.619 .767 .951 r
.5614 .51764 .56723 .52285 .5784 .52016 .5726 .51517 Mtetra
.597 .769 .962 r
.5726 .51517 .5784 .52016 .58962 .51776 .58386 .51308 Mtetra
.564 .771 .976 r
.58386 .51308 .58962 .51776 .6009 .51571 .59518 .51146 Mtetra
.515 .77 .989 r
.59518 .51146 .6009 .51571 .61225 .51407 .60658 .51038 Mtetra
.443 .763 .996 r
.60658 .51038 .61225 .51407 .62367 .51289 .61806 .50989 Mtetra
.337 .739 .982 r
.61806 .50989 .62367 .51289 .63517 .51217 .62962 .51001 Mtetra
.189 .68 .922 r
.62962 .51001 .63517 .51217 .64675 .51188 .64128 .5107 Mtetra
.01 .576 .793 r
.64128 .5107 .64675 .51188 .65841 .51197 .65303 .51188 Mtetra
.16 0 0 r
.65303 .51188 .65841 .51197 .67016 .5123 .66488 .51339 Mtetra
.286 0 0 r
.66488 .51339 .67016 .5123 .68199 .51274 .67682 .51504 Mtetra
.361 0 0 r
.67682 .51504 .68199 .51274 .69389 .51309 .68884 .51659 Mtetra
.396 0 0 r
.68884 .51659 .69389 .51309 .70585 .51316 .70093 .51777 Mtetra
.403 0 0 r
.70093 .51777 .70585 .51316 .71787 .51275 .71306 .51833 Mtetra
.392 0 0 r
.71306 .51833 .71787 .51275 .72991 .5117 .72523 .51805 Mtetra
.367 0 .004 r
.72523 .51805 .72991 .5117 .74198 .50988 .73741 .51674 Mtetra
.33 0 .01 r
.73741 .51674 .74198 .50988 .75405 .5072 .74958 .51431 Mtetra
.282 0 0 r
.74958 .51431 .75405 .5072 .76611 .50366 .76173 .51072 Mtetra
.222 0 0 r
.76173 .51072 .76611 .50366 .77817 .49929 .77385 .50602 Mtetra
.148 0 0 r
.77385 .50602 .77817 .49929 .79021 .49418 .78594 .50033 Mtetra
.059 0 0 r
.78594 .50033 .79021 .49418 .80224 .48846 .798 .49381 Mtetra
0 0 0 r
.798 .49381 .80224 .48846 .81427 .48229 .81004 .48668 Mtetra
.81004 .48668 .81427 .48229 .82631 .47582 .82207 .47914 Mtetra
.82207 .47914 .82631 .47582 .83837 .46922 .8341 .47142 Mtetra
.445 .848 .662 r
.8341 .47142 .83837 .46922 .85046 .46261 .84616 .46369 Mtetra
.558 .927 .785 r
.84616 .46369 .85046 .46261 .86259 .4561 .85826 .45611 Mtetra
.637 .965 .873 r
.85826 .45611 .86259 .4561 .87477 .44977 .87041 .4488 Mtetra
.683 .969 .925 r
.87041 .4488 .87477 .44977 .88701 .44367 .88262 .44181 Mtetra
.704 .954 .952 r
.88262 .44181 .88701 .44367 .89932 .4378 .89491 .43517 Mtetra
.712 .93 .962 r
.89491 .43517 .89932 .4378 .91169 .43217 .90727 .42888 Mtetra
.712 .906 .964 r
.90727 .42888 .91169 .43217 .92413 .42672 .9197 .42288 Mtetra
.71 .884 .961 r
.9197 .42288 .92413 .42672 .93663 .42143 .9322 .41713 Mtetra
.707 .866 .957 r
.9322 .41713 .93663 .42143 .94919 .41624 .94477 .41157 Mtetra
.647 .75 .925 r
.3613 .56672 .3677 .57226 .37808 .56944 .37171 .5639 Mtetra
.648 .751 .925 r
.37171 .5639 .37808 .56944 .38851 .5666 .38217 .56105 Mtetra
.648 .752 .925 r
.38217 .56105 .38851 .5666 .39898 .56373 .39266 .55818 Mtetra
.649 .753 .926 r
.39266 .55818 .39898 .56373 .4095 .56082 .40321 .55527 Mtetra
.65 .754 .926 r
.40321 .55527 .4095 .56082 .42006 .55788 .41379 .55232 Mtetra
.651 .755 .926 r
.41379 .55232 .42006 .55788 .43066 .5549 .42442 .54934 Mtetra
.652 .756 .926 r
.42442 .54934 .43066 .5549 .44131 .55188 .4351 .54631 Mtetra
.653 .757 .926 r
.4351 .54631 .44131 .55188 .45201 .54881 .44582 .54323 Mtetra
.654 .758 .926 r
.44582 .54323 .45201 .54881 .46274 .5457 .45659 .54011 Mtetra
.655 .758 .925 r
.45659 .54011 .46274 .5457 .47353 .54255 .4674 .53695 Mtetra
.656 .759 .925 r
.4674 .53695 .47353 .54255 .48435 .53935 .47825 .53375 Mtetra
.657 .76 .926 r
.47825 .53375 .48435 .53935 .49522 .53613 .48915 .53053 Mtetra
.48915 .53053 .49522 .53613 .50614 .53289 .5001 .52729 Mtetra
.655 .761 .927 r
.5001 .52729 .50614 .53289 .5171 .52966 .51109 .52408 Mtetra
.652 .762 .93 r
.51109 .52408 .5171 .52966 .5281 .52647 .52212 .52092 Mtetra
.647 .762 .933 r
.52212 .52092 .5281 .52647 .53915 .52336 .5332 .51788 Mtetra
.638 .763 .938 r
.5332 .51788 .53915 .52336 .55025 .5204 .54433 .51503 Mtetra
.625 .764 .946 r
.54433 .51503 .55025 .5204 .5614 .51764 .55551 .51245 Mtetra
.605 .765 .956 r
.55551 .51245 .5614 .51764 .5726 .51517 .56675 .51024 Mtetra
.574 .765 .969 r
.56675 .51024 .5726 .51517 .58386 .51308 .57805 .50851 Mtetra
.529 .763 .983 r
.57805 .50851 .58386 .51308 .59518 .51146 .58942 .50738 Mtetra
.459 .754 .993 r
.58942 .50738 .59518 .51146 .60658 .51038 .60086 .50693 Mtetra
.353 .729 .987 r
.60086 .50693 .60658 .51038 .61806 .50989 .6124 .50724 Mtetra
.196 .669 .936 r
.6124 .50724 .61806 .50989 .62962 .51001 .62403 .50832 Mtetra
0 .554 .809 r
.62403 .50832 .62962 .51001 .64128 .5107 .63577 .51013 Mtetra
.206 0 0 r
.63577 .51013 .64128 .5107 .65303 .51188 .64761 .51257 Mtetra
.357 0 0 r
.64761 .51257 .65303 .51188 .66488 .51339 .65957 .51544 Mtetra
.446 0 0 r
.65957 .51544 .66488 .51339 .67682 .51504 .67163 .5185 Mtetra
.487 0 0 r
.67163 .5185 .67682 .51504 .68884 .51659 .68378 .52145 Mtetra
.498 0 .005 r
.68378 .52145 .68884 .51659 .70093 .51777 .696 .52394 Mtetra
.49 .019 .064 r
.696 .52394 .70093 .51777 .71306 .51833 .70828 .52566 Mtetra
.468 .019 .1 r
.70828 .52566 .71306 .51833 .72523 .51805 .72058 .5263 Mtetra
.437 .004 .118 r
.72058 .5263 .72523 .51805 .73741 .51674 .73289 .52563 Mtetra
.396 0 .121 r
.73289 .52563 .73741 .51674 .74958 .51431 .74518 .52351 Mtetra
.346 0 .109 r
.74518 .52351 .74958 .51431 .76173 .51072 .75742 .51989 Mtetra
.286 0 .082 r
.75742 .51989 .76173 .51072 .77385 .50602 .76962 .51483 Mtetra
.214 0 .039 r
.76962 .51483 .77385 .50602 .78594 .50033 .78175 .50847 Mtetra
.128 0 0 r
.78175 .50847 .78594 .50033 .798 .49381 .79384 .50103 Mtetra
.025 0 0 r
.79384 .50103 .798 .49381 .81004 .48668 .80588 .49277 Mtetra
0 0 0 r
.80588 .49277 .81004 .48668 .82207 .47914 .81789 .48398 Mtetra
.81789 .48398 .82207 .47914 .8341 .47142 .8299 .47493 Mtetra
.8299 .47493 .8341 .47142 .84616 .46369 .84191 .46588 Mtetra
.523 .888 .677 r
.84191 .46588 .84616 .46369 .85826 .45611 .85397 .45703 Mtetra
.627 .957 .8 r
.85397 .45703 .85826 .45611 .87041 .4488 .86608 .44854 Mtetra
.691 .98 .882 r
.86608 .44854 .87041 .4488 .88262 .44181 .87825 .4405 Mtetra
.722 .973 .928 r
.87825 .4405 .88262 .44181 .89491 .43517 .8905 .43294 Mtetra
.732 .95 .949 r
.8905 .43294 .89491 .43517 .90727 .42888 .90284 .42586 Mtetra
.731 .923 .956 r
.90284 .42586 .90727 .42888 .9197 .42288 .91525 .41922 Mtetra
.725 .897 .957 r
.91525 .41922 .9197 .42288 .9322 .41713 .92775 .41294 Mtetra
.72 .876 .954 r
.92775 .41294 .9322 .41713 .94477 .41157 .94032 .40695 Mtetra
.646 .75 .925 r
.35486 .56112 .3613 .56672 .37171 .5639 .36529 .55829 Mtetra
.647 .751 .925 r
.36529 .55829 .37171 .5639 .38217 .56105 .37577 .55545 Mtetra
.37577 .55545 .38217 .56105 .39266 .55818 .3863 .55257 Mtetra
.648 .752 .925 r
.3863 .55257 .39266 .55818 .40321 .55527 .39686 .54966 Mtetra
.649 .753 .926 r
.39686 .54966 .40321 .55527 .41379 .55232 .40748 .54671 Mtetra
.65 .754 .926 r
.40748 .54671 .41379 .55232 .42442 .54934 .41814 .54372 Mtetra
.651 .755 .926 r
.41814 .54372 .42442 .54934 .4351 .54631 .42884 .54069 Mtetra
.653 .756 .926 r
.42884 .54069 .4351 .54631 .44582 .54323 .43959 .5376 Mtetra
.654 .757 .925 r
.43959 .5376 .44582 .54323 .45659 .54011 .45038 .53448 Mtetra
.655 .758 .925 r
.45038 .53448 .45659 .54011 .4674 .53695 .46122 .53131 Mtetra
.656 .759 .926 r
.46122 .53131 .4674 .53695 .47825 .53375 .47211 .5281 Mtetra
.47211 .5281 .47825 .53375 .48915 .53053 .48304 .52488 Mtetra
.655 .76 .927 r
.48304 .52488 .48915 .53053 .5001 .52729 .49401 .52165 Mtetra
.653 .761 .928 r
.49401 .52165 .5001 .52729 .51109 .52408 .50503 .51846 Mtetra
.65 .761 .931 r
.50503 .51846 .51109 .52408 .52212 .52092 .51609 .51534 Mtetra
.643 .761 .935 r
.51609 .51534 .52212 .52092 .5332 .51788 .52721 .51238 Mtetra
.632 .762 .941 r
.52721 .51238 .5332 .51788 .54433 .51503 .53837 .50965 Mtetra
.615 .762 .949 r
.53837 .50965 .54433 .51503 .55551 .51245 .54958 .50726 Mtetra
.589 .761 .961 r
.54958 .50726 .55551 .51245 .56675 .51024 .56085 .50533 Mtetra
.549 .758 .974 r
.56085 .50533 .56675 .51024 .57805 .50851 .57219 .504 Mtetra
.488 .75 .987 r
.57219 .504 .57805 .50851 .58942 .50738 .5836 .5034 Mtetra
.393 .729 .99 r
.5836 .5034 .58942 .50738 .60086 .50693 .5951 .50364 Mtetra
.246 .677 .961 r
.5951 .50364 .60086 .50693 .6124 .50724 .60669 .50482 Mtetra
.042 .571 .862 r
.60669 .50482 .6124 .50724 .62403 .50832 .61839 .50695 Mtetra
.187 0 0 r
.61839 .50695 .62403 .50832 .63577 .51013 .63021 .51 Mtetra
.374 0 0 r
.63021 .51 .63577 .51013 .64761 .51257 .64215 .51383 Mtetra
.489 0 0 r
.64215 .51383 .64761 .51257 .65957 .51544 .65422 .51821 Mtetra
.545 .009 0 r
.65422 .51821 .65957 .51544 .67163 .5185 .6664 .52285 Mtetra
.565 .064 .024 r
.6664 .52285 .67163 .5185 .68378 .52145 .67869 .52736 Mtetra
.562 .091 .095 r
.67869 .52736 .68378 .52145 .696 .52394 .69106 .53134 Mtetra
.544 .098 .142 r
.69106 .53134 .696 .52394 .70828 .52566 .70348 .53437 Mtetra
.516 .09 .17 r
.70348 .53437 .70828 .52566 .72058 .5263 .71594 .53608 Mtetra
.479 .069 .183 r
.71594 .53608 .72058 .5263 .73289 .52563 .72838 .53616 Mtetra
.434 .036 .183 r
.72838 .53616 .73289 .52563 .74518 .52351 .74079 .53443 Mtetra
.381 0 .171 r
.74079 .53443 .74518 .52351 .75742 .51989 .75315 .53082 Mtetra
.318 0 .146 r
.75315 .53082 .75742 .51989 .76962 .51483 .76542 .52539 Mtetra
.244 0 .106 r
.76542 .52539 .76962 .51483 .78175 .50847 .77761 .5183 Mtetra
.156 0 .049 r
.77761 .5183 .78175 .50847 .79384 .50103 .78972 .50983 Mtetra
.053 0 0 r
.78972 .50983 .79384 .50103 .80588 .49277 .80177 .50031 Mtetra
0 0 0 r
.80177 .50031 .80588 .49277 .81789 .48398 .81376 .4901 Mtetra
.81376 .4901 .81789 .48398 .8299 .47493 .82573 .47956 Mtetra
.82573 .47956 .8299 .47493 .84191 .46588 .8377 .469 Mtetra
.514 .857 .59 r
.8377 .469 .84191 .46588 .85397 .45703 .8497 .45871 Mtetra
.633 .946 .733 r
.8497 .45871 .85397 .45703 .86608 .44854 .86175 .44887 Mtetra
.709 .986 .837 r
.86175 .44887 .86608 .44854 .87825 .4405 .87387 .43962 Mtetra
.746 .986 .9 r
.87387 .43962 .87825 .4405 .8905 .43294 .88608 .43102 Mtetra
.756 .965 .932 r
.88608 .43102 .8905 .43294 .90284 .42586 .89838 .42305 Mtetra
.753 .936 .946 r
.89838 .42305 .90284 .42586 .91525 .41922 .91078 .41567 Mtetra
.744 .908 .95 r
.91078 .41567 .91525 .41922 .92775 .41294 .92326 .40879 Mtetra
.734 .883 .949 r
.92326 .40879 .92775 .41294 .94032 .40695 .93584 .40232 Mtetra
.645 .749 .925 r
.34837 .55546 .35486 .56112 .36529 .55829 .35883 .55263 Mtetra
.646 .75 .925 r
.35883 .55263 .36529 .55829 .37577 .55545 .36933 .54978 Mtetra
.647 .751 .925 r
.36933 .54978 .37577 .55545 .3863 .55257 .37988 .54691 Mtetra
.647 .752 .925 r
.37988 .54691 .3863 .55257 .39686 .54966 .39048 .54399 Mtetra
.648 .753 .925 r
.39048 .54399 .39686 .54966 .40748 .54671 .40112 .54104 Mtetra
.649 .754 .926 r
.40112 .54104 .40748 .54671 .41814 .54372 .4118 .53805 Mtetra
.651 .755 .926 r
.4118 .53805 .41814 .54372 .42884 .54069 .42253 .53501 Mtetra
.652 .755 .926 r
.42253 .53501 .42884 .54069 .43959 .5376 .43331 .53192 Mtetra
.653 .756 .925 r
.43331 .53192 .43959 .5376 .45038 .53448 .44413 .52879 Mtetra
.654 .757 .926 r
.44413 .52879 .45038 .53448 .46122 .53131 .455 .52562 Mtetra
.655 .758 .926 r
.455 .52562 .46122 .53131 .47211 .5281 .46591 .52241 Mtetra
.655 .759 .926 r
.46591 .52241 .47211 .5281 .48304 .52488 .47687 .51918 Mtetra
.654 .76 .927 r
.47687 .51918 .48304 .52488 .49401 .52165 .48787 .51597 Mtetra
.652 .76 .929 r
.48787 .51597 .49401 .52165 .50503 .51846 .49892 .5128 Mtetra
.647 .76 .932 r
.49892 .5128 .50503 .51846 .51609 .51534 .51002 .50973 Mtetra
.639 .76 .936 r
.51002 .50973 .51609 .51534 .52721 .51238 .52116 .50684 Mtetra
.625 .76 .943 r
.52116 .50684 .52721 .51238 .53837 .50965 .53235 .50424 Mtetra
.604 .759 .953 r
.53235 .50424 .53837 .50965 .54958 .50726 .5436 .50205 Mtetra
.572 .756 .965 r
.5436 .50205 .54958 .50726 .56085 .50533 .55491 .50041 Mtetra
.522 .749 .978 r
.55491 .50041 .56085 .50533 .57219 .504 .56628 .49949 Mtetra
.444 .732 .988 r
.56628 .49949 .57219 .504 .5836 .5034 .57774 .49944 Mtetra
.322 .694 .98 r
.57774 .49944 .5836 .5034 .5951 .50364 .58928 .5004 Mtetra
.138 .611 .922 r
.58928 .5004 .5951 .50364 .60669 .50482 .60093 .50248 Mtetra
0 .465 .777 r
.60093 .50248 .60669 .50482 .61839 .50695 .6127 .50571 Mtetra
.326 0 0 r
.6127 .50571 .61839 .50695 .63021 .51 .6246 .51004 Mtetra
.487 0 0 r
.6246 .51004 .63021 .51 .64215 .51383 .63663 .51533 Mtetra
.573 .018 0 r
.63663 .51533 .64215 .51383 .65422 .51821 .64881 .52131 Mtetra
.61 .093 0 r
.64881 .52131 .65422 .51821 .6664 .52285 .66111 .52762 Mtetra
.618 .134 .083 r
.66111 .52762 .6664 .52285 .67869 .52736 .67354 .53381 Mtetra
.607 .15 .143 r
.67354 .53381 .67869 .52736 .69106 .53134 .68606 .5394 Mtetra
.583 .149 .182 r
.68606 .5394 .69106 .53134 .70348 .53437 .69864 .54386 Mtetra
.55 .134 .204 r
.69864 .54386 .70348 .53437 .71594 .53608 .71124 .54675 Mtetra
.508 .106 .214 r
.71124 .54675 .71594 .53608 .72838 .53616 .72384 .54769 Mtetra
.457 .068 .213 r
.72384 .54769 .72838 .53616 .74079 .53443 .73638 .54644 Mtetra
.398 .019 .199 r
.73638 .54644 .74079 .53443 .75315 .53082 .74885 .54288 Mtetra
.328 0 .174 r
.74885 .54288 .75315 .53082 .76542 .52539 .76121 .53709 Mtetra
.246 0 .134 r
.76121 .53709 .76542 .52539 .77761 .5183 .77346 .52925 Mtetra
.151 0 .077 r
.77346 .52925 .77761 .5183 .78972 .50983 .78561 .5197 Mtetra
.04 0 0 r
.78561 .5197 .78972 .50983 .80177 .50031 .79765 .50884 Mtetra
0 0 0 r
.79765 .50884 .80177 .50031 .81376 .4901 .80963 .4971 Mtetra
.80963 .4971 .81376 .4901 .82573 .47956 .82156 .48494 Mtetra
.82156 .48494 .82573 .47956 .8377 .469 .83347 .47275 Mtetra
.544 .853 .546 r
.83347 .47275 .8377 .469 .8497 .45871 .84541 .46087 Mtetra
.665 .946 .692 r
.84541 .46087 .8497 .45871 .86175 .44887 .8574 .44957 Mtetra
.742 .99 .803 r
.8574 .44957 .86175 .44887 .87387 .43962 .86947 .43901 Mtetra
.777 .994 .874 r
.86947 .43901 .87387 .43962 .88608 .43102 .88163 .42925 Mtetra
.785 .974 .913 r
.88163 .42925 .88608 .43102 .89838 .42305 .89389 .42032 Mtetra
.777 .944 .932 r
.89389 .42032 .89838 .42305 .91078 .41567 .90626 .41213 Mtetra
.764 .914 .94 r
.90626 .41213 .91078 .41567 .92326 .40879 .91873 .4046 Mtetra
.75 .887 .941 r
.91873 .4046 .92326 .40879 .93584 .40232 .9313 .39761 Mtetra
.645 .748 .924 r
.34184 .54974 .34837 .55546 .35883 .55263 .35232 .54691 Mtetra
.645 .749 .925 r
.35232 .54691 .35883 .55263 .36933 .54978 .36285 .54406 Mtetra
.646 .75 .925 r
.36285 .54406 .36933 .54978 .37988 .54691 .37342 .54118 Mtetra
.647 .751 .925 r
.37342 .54118 .37988 .54691 .39048 .54399 .38404 .53826 Mtetra
.648 .752 .925 r
.38404 .53826 .39048 .54399 .40112 .54104 .39471 .53531 Mtetra
.649 .753 .925 r
.39471 .53531 .40112 .54104 .4118 .53805 .40542 .53231 Mtetra
.65 .754 .925 r
.40542 .53231 .4118 .53805 .42253 .53501 .41618 .52927 Mtetra
.651 .755 .926 r
.41618 .52927 .42253 .53501 .43331 .53192 .42698 .52618 Mtetra
.652 .756 .926 r
.42698 .52618 .43331 .53192 .44413 .52879 .43783 .52305 Mtetra
.653 .757 .926 r
.43783 .52305 .44413 .52879 .455 .52562 .44873 .51988 Mtetra
.654 .758 .926 r
.44873 .51988 .455 .52562 .46591 .52241 .45967 .51667 Mtetra
.654 .759 .927 r
.45967 .51667 .46591 .52241 .47687 .51918 .47066 .51345 Mtetra
.653 .759 .928 r
.47066 .51345 .47687 .51918 .48787 .51597 .48169 .51025 Mtetra
.65 .76 .93 r
.48169 .51025 .48787 .51597 .49892 .5128 .49277 .5071 Mtetra
.644 .76 .933 r
.49277 .5071 .49892 .5128 .51002 .50973 .5039 .50408 Mtetra
.634 .76 .938 r
.5039 .50408 .51002 .50973 .52116 .50684 .51507 .50128 Mtetra
.619 .758 .945 r
.51507 .50128 .52116 .50684 .53235 .50424 .52629 .4988 Mtetra
.594 .756 .955 r
.52629 .4988 .53235 .50424 .5436 .50205 .53757 .4968 Mtetra
.556 .75 .968 r
.53757 .4968 .5436 .50205 .55491 .50041 .54891 .49544 Mtetra
.496 .737 .98 r
.54891 .49544 .55491 .50041 .56628 .49949 .56032 .49491 Mtetra
.402 .711 .985 r
.56032 .49491 .56628 .49949 .57774 .49944 .57182 .49539 Mtetra
.256 .654 .965 r
.57182 .49539 .57774 .49944 .58928 .5004 .58341 .49705 Mtetra
.046 .544 .882 r
.58341 .49705 .58928 .5004 .60093 .50248 .59511 .50001 Mtetra
0 .372 .708 r
.59511 .50001 .60093 .50248 .6127 .50571 .60694 .50431 Mtetra
.419 0 0 r
.60694 .50431 .6127 .50571 .6246 .51004 .61891 .50992 Mtetra
.558 0 0 r
.61891 .50992 .6246 .51004 .63663 .51533 .63103 .51666 Mtetra
.628 .085 0 r
.63103 .51666 .63663 .51533 .64881 .52131 .64331 .52423 Mtetra
.656 .147 .025 r
.64331 .52423 .64881 .52131 .66111 .52762 .65574 .53223 Mtetra
.657 .179 .104 r
.65574 .53223 .66111 .52762 .67354 .53381 .6683 .54013 Mtetra
.642 .188 .158 r
.6683 .54013 .67354 .53381 .68606 .5394 .68096 .54736 Mtetra
.615 .18 .192 r
.68096 .54736 .68606 .5394 .69864 .54386 .6937 .55332 Mtetra
.577 .158 .212 r
.6937 .55332 .69864 .54386 .71124 .54675 .70646 .55746 Mtetra
.528 .124 .219 r
.70646 .55746 .71124 .54675 .72384 .54769 .7192 .55933 Mtetra
.47 .079 .215 r
.7192 .55933 .72384 .54769 .73638 .54644 .73188 .55861 Mtetra
.4 .021 .199 r
.73188 .55861 .73638 .54644 .74885 .54288 .74447 .55517 Mtetra
.318 0 .17 r
.74447 .55517 .74885 .54288 .76121 .53709 .75693 .54906 Mtetra
.223 0 .126 r
.75693 .54906 .76121 .53709 .77346 .52925 .76925 .54051 Mtetra
.111 0 .064 r
.76925 .54051 .77346 .52925 .78561 .5197 .78143 .52988 Mtetra
0 0 0 r
.78143 .52988 .78561 .5197 .79765 .50884 .79348 .51766 Mtetra
.79348 .51766 .79765 .50884 .80963 .4971 .80544 .50436 Mtetra
.80544 .50436 .80963 .4971 .82156 .48494 .81733 .49054 Mtetra
.81733 .49054 .82156 .48494 .83347 .47275 .8292 .47666 Mtetra
.618 .881 .551 r
.8292 .47666 .83347 .47275 .84541 .46087 .84108 .46315 Mtetra
.725 .961 .684 r
.84108 .46315 .84541 .46087 .8574 .44957 .85301 .45033 Mtetra
.79 .996 .787 r
.85301 .45033 .8574 .44957 .86947 .43901 .86502 .43839 Mtetra
.816 .996 .855 r
.86502 .43839 .86947 .43901 .88163 .42925 .87712 .42744 Mtetra
.816 .975 .896 r
.87712 .42744 .88163 .42925 .89389 .42032 .88935 .41749 Mtetra
.802 .945 .918 r
.88935 .41749 .89389 .42032 .90626 .41213 .90169 .40847 Mtetra
.784 .914 .928 r
.90169 .40847 .90626 .41213 .91873 .4046 .91414 .40027 Mtetra
.766 .887 .931 r
.91414 .40027 .91873 .4046 .9313 .39761 .9267 .39273 Mtetra
.644 .747 .924 r
.33525 .54395 .34184 .54974 .35232 .54691 .34576 .54112 Mtetra
.644 .748 .924 r
.34576 .54112 .35232 .54691 .36285 .54406 .35631 .53827 Mtetra
.645 .749 .925 r
.35631 .53827 .36285 .54406 .37342 .54118 .36691 .53539 Mtetra
.646 .75 .925 r
.36691 .53539 .37342 .54118 .38404 .53826 .37756 .53247 Mtetra
.647 .751 .925 r
.37756 .53247 .38404 .53826 .39471 .53531 .38825 .52952 Mtetra
.648 .752 .925 r
.38825 .52952 .39471 .53531 .40542 .53231 .39899 .52652 Mtetra
.649 .753 .926 r
.39899 .52652 .40542 .53231 .41618 .52927 .40977 .52348 Mtetra
.65 .754 .926 r
.40977 .52348 .41618 .52927 .42698 .52618 .4206 .5204 Mtetra
.651 .755 .926 r
.4206 .5204 .42698 .52618 .43783 .52305 .43148 .51727 Mtetra
.652 .757 .926 r
.43148 .51727 .43783 .52305 .44873 .51988 .44241 .5141 Mtetra
.653 .758 .927 r
.44241 .5141 .44873 .51988 .45967 .51667 .45338 .5109 Mtetra
.652 .759 .927 r
.45338 .5109 .45967 .51667 .47066 .51345 .46439 .50769 Mtetra
.651 .76 .929 r
.46439 .50769 .47066 .51345 .48169 .51025 .47546 .5045 Mtetra
.648 .76 .931 r
.47546 .5045 .48169 .51025 .49277 .5071 .48657 .50138 Mtetra
.641 .76 .935 r
.48657 .50138 .49277 .5071 .5039 .50408 .49772 .49841 Mtetra
.63 .759 .94 r
.49772 .49841 .5039 .50408 .51507 .50128 .50893 .49567 Mtetra
.612 .757 .947 r
.50893 .49567 .51507 .50128 .52629 .4988 .52018 .49331 Mtetra
.584 .752 .958 r
.52018 .49331 .52629 .4988 .53757 .4968 .53149 .49148 Mtetra
.541 .743 .969 r
.53149 .49148 .53757 .4968 .54891 .49544 .54286 .49037 Mtetra
.473 .725 .98 r
.54286 .49037 .54891 .49544 .56032 .49491 .55431 .49019 Mtetra
.366 .689 .981 r
.55431 .49019 .56032 .49491 .57182 .49539 .56584 .49115 Mtetra
.205 .617 .949 r
.56584 .49115 .57182 .49539 .58341 .49705 .57747 .49343 Mtetra
0 .488 .852 r
.57747 .49343 .58341 .49705 .59511 .50001 .58922 .49719 Mtetra
0 .307 .669 r
.58922 .49719 .59511 .50001 .60694 .50431 .60111 .50248 Mtetra
.471 0 0 r
.60111 .50248 .60694 .50431 .61891 .50992 .61314 .50925 Mtetra
.598 .027 0 r
.61314 .50925 .61891 .50992 .63103 .51666 .62535 .51733 Mtetra
.664 .123 0 r
.62535 .51733 .63103 .51666 .64331 .52423 .63772 .52639 Mtetra
.689 .178 .017 r
.63772 .52639 .64331 .52423 .65574 .53223 .65025 .53598 Mtetra
.689 .204 .091 r
.65025 .53598 .65574 .53223 .6683 .54013 .66293 .54551 Mtetra
.673 .208 .141 r
.66293 .54551 .6683 .54013 .68096 .54736 .67573 .55433 Mtetra
.642 .195 .173 r
.67573 .55433 .68096 .54736 .6937 .55332 .68861 .56175 Mtetra
.599 .167 .191 r
.68861 .56175 .6937 .55332 .70646 .55746 .70152 .56713 Mtetra
.543 .124 .195 r
.70152 .56713 .70646 .55746 .7192 .55933 .71441 .56995 Mtetra
.473 .066 .186 r
.71441 .56995 .7192 .55933 .73188 .55861 .72722 .56981 Mtetra
.387 0 .164 r
.72722 .56981 .73188 .55861 .74447 .55517 .73993 .56655 Mtetra
.283 0 .127 r
.73993 .56655 .74447 .55517 .75693 .54906 .75249 .56021 Mtetra
.162 0 .072 r
.75249 .56021 .75693 .54906 .76925 .54051 .76488 .55101 Mtetra
.021 0 0 r
.76488 .55101 .76925 .54051 .78143 .52988 .7771 .53939 Mtetra
0 0 0 r
.7771 .53939 .78143 .52988 .79348 .51766 .78918 .52589 Mtetra
.78918 .52589 .79348 .51766 .80544 .50436 .80113 .51111 Mtetra
.80113 .51111 .80544 .50436 .81733 .49054 .81299 .49567 Mtetra
.61 .846 .473 r
.81299 .49567 .81733 .49054 .8292 .47666 .82482 .48016 Mtetra
.726 .932 .599 r
.82482 .48016 .8292 .47666 .84108 .46315 .83665 .46505 Mtetra
.804 .982 .705 r
.83665 .46505 .84108 .46315 .85301 .45033 .84852 .45073 Mtetra
.844 .998 .787 r
.84852 .45073 .85301 .45033 .86502 .43839 .86048 .43745 Mtetra
.854 .99 .844 r
.86048 .43745 .86502 .43839 .87712 .42744 .87254 .42533 Mtetra
.844 .967 .881 r
.87254 .42533 .87712 .42744 .88935 .41749 .88472 .41438 Mtetra
.824 .937 .902 r
.88472 .41438 .88935 .41749 .90169 .40847 .89704 .40453 Mtetra
.801 .908 .914 r
.89704 .40453 .90169 .40847 .91414 .40027 .90948 .39566 Mtetra
.78 .881 .92 r
.90948 .39566 .91414 .40027 .9267 .39273 .92204 .38759 Mtetra
.643 .746 .924 r
.32862 .5381 .33525 .54395 .34576 .54112 .33915 .53527 Mtetra
.644 .747 .924 r
.33915 .53527 .34576 .54112 .35631 .53827 .34973 .53242 Mtetra
.644 .748 .925 r
.34973 .53242 .35631 .53827 .36691 .53539 .36035 .52954 Mtetra
.645 .749 .925 r
.36035 .52954 .36691 .53539 .37756 .53247 .37102 .52662 Mtetra
.646 .75 .925 r
.37102 .52662 .37756 .53247 .38825 .52952 .38174 .52367 Mtetra
.647 .751 .925 r
.38174 .52367 .38825 .52952 .39899 .52652 .39251 .52068 Mtetra
.648 .752 .926 r
.39251 .52068 .39899 .52652 .40977 .52348 .40332 .51765 Mtetra
.649 .754 .926 r
.40332 .51765 .40977 .52348 .4206 .5204 .41418 .51457 Mtetra
.65 .755 .927 r
.41418 .51457 .4206 .5204 .43148 .51727 .42508 .51146 Mtetra
.651 .757 .927 r
.42508 .51146 .43148 .51727 .44241 .5141 .43603 .5083 Mtetra
.651 .758 .928 r
.43603 .5083 .44241 .5141 .45338 .5109 .44703 .50511 Mtetra
.651 .759 .929 r
.44703 .50511 .45338 .5109 .46439 .50769 .45808 .50192 Mtetra
.649 .76 .93 r
.45808 .50192 .46439 .50769 .47546 .5045 .46917 .49875 Mtetra
.645 .761 .933 r
.46917 .49875 .47546 .5045 .48657 .50138 .48031 .49566 Mtetra
.638 .76 .937 r
.48031 .49566 .48657 .50138 .49772 .49841 .4915 .49272 Mtetra
.626 .759 .942 r
.4915 .49272 .49772 .49841 .50893 .49567 .50273 .49005 Mtetra
.607 .756 .95 r
.50273 .49005 .50893 .49567 .52018 .49331 .51402 .48778 Mtetra
.576 .749 .959 r
.51402 .48778 .52018 .49331 .53149 .49148 .52536 .48608 Mtetra
.529 .737 .97 r
.52536 .48608 .53149 .49148 .54286 .49037 .53676 .48517 Mtetra
.455 .714 .979 r
.53676 .48517 .54286 .49037 .55431 .49019 .54824 .48527 Mtetra
.342 .669 .975 r
.54824 .48527 .55431 .49019 .56584 .49115 .55981 .48661 Mtetra
.174 .587 .939 r
.55981 .48661 .56584 .49115 .57747 .49343 .57147 .4894 Mtetra
0 .453 .839 r
.57147 .4894 .57747 .49343 .58922 .49719 .58326 .49381 Mtetra
0 .275 .667 r
.58326 .49381 .58922 .49719 .60111 .50248 .59519 .49991 Mtetra
.484 0 0 r
.59519 .49991 .60111 .50248 .61314 .50925 .60729 .50765 Mtetra
.61 .042 0 r
.60729 .50765 .61314 .50925 .62535 .51733 .61955 .51686 Mtetra
.679 .134 0 r
.61955 .51686 .62535 .51733 .63772 .52639 .632 .52719 Mtetra
.709 .187 0 r
.632 .52719 .63772 .52639 .65025 .53598 .64463 .53815 Mtetra
.714 .211 .039 r
.64463 .53815 .65025 .53598 .66293 .54551 .65741 .5491 Mtetra
.699 .212 .087 r
.65741 .5491 .66293 .54551 .67573 .55433 .67032 .55933 Mtetra
.667 .193 .115 r
.67032 .55933 .67573 .55433 .68861 .56175 .68333 .56807 Mtetra
.619 .155 .128 r
.68333 .56807 .68861 .56175 .70152 .56713 .69637 .57461 Mtetra
.551 .097 .126 r
.69637 .57461 .70152 .56713 .71441 .56995 .70939 .57833 Mtetra
.461 .018 .108 r
.70939 .57833 .71441 .56995 .72722 .56981 .72234 .57879 Mtetra
.345 0 .072 r
.72234 .57879 .72722 .56981 .73993 .56655 .73516 .57578 Mtetra
.2 0 .016 r
.73516 .57578 .73993 .56655 .75249 .56021 .74781 .56929 Mtetra
.03 0 0 r
.74781 .56929 .75249 .56021 .76488 .55101 .76028 .5596 Mtetra
0 0 0 r
.76028 .5596 .76488 .55101 .7771 .53939 .77256 .54714 Mtetra
.77256 .54714 .7771 .53939 .78918 .52589 .78466 .53253 Mtetra
.78466 .53253 .78918 .52589 .80113 .51111 .79662 .51643 Mtetra
.664 .868 .486 r
.79662 .51643 .80113 .51111 .81299 .49567 .80847 .49956 Mtetra
.77 .935 .584 r
.80847 .49956 .81299 .49567 .82482 .48016 .82027 .48257 Mtetra
.841 .975 .668 r
.82027 .48257 .82482 .48016 .83665 .46505 .83206 .46602 Mtetra
.879 .99 .738 r
.83206 .46602 .83665 .46505 .84852 .45073 .84389 .45034 Mtetra
.891 .987 .794 r
.84389 .45034 .84852 .45073 .86048 .43745 .85581 .43582 Mtetra
.885 .971 .836 r
.85581 .43582 .86048 .43745 .87254 .42533 .86784 .42261 Mtetra
.866 .948 .866 r
.86784 .42261 .87254 .42533 .88472 .41438 .87999 .41074 Mtetra
.841 .921 .886 r
.87999 .41074 .88472 .41438 .89704 .40453 .89229 .40013 Mtetra
.815 .894 .899 r
.89229 .40013 .89704 .40453 .90948 .39566 .90472 .39064 Mtetra
.79 .87 .907 r
.90472 .39064 .90948 .39566 .92204 .38759 .91728 .38208 Mtetra
.642 .745 .924 r
.32194 .53218 .32862 .5381 .33915 .53527 .3325 .52935 Mtetra
.643 .746 .924 r
.3325 .52935 .33915 .53527 .34973 .53242 .3431 .5265 Mtetra
.643 .747 .924 r
.3431 .5265 .34973 .53242 .36035 .52954 .35375 .52362 Mtetra
.644 .748 .925 r
.35375 .52362 .36035 .52954 .37102 .52662 .36444 .52071 Mtetra
.644 .749 .925 r
.36444 .52071 .37102 .52662 .38174 .52367 .37518 .51777 Mtetra
.645 .751 .926 r
.37518 .51777 .38174 .52367 .39251 .52068 .38597 .5148 Mtetra
.646 .752 .926 r
.38597 .5148 .39251 .52068 .40332 .51765 .39681 .51178 Mtetra
.647 .754 .927 r
.39681 .51178 .40332 .51765 .41418 .51457 .4077 .50872 Mtetra
.648 .755 .928 r
.4077 .50872 .41418 .51457 .42508 .51146 .41863 .50563 Mtetra
.649 .757 .929 r
.41863 .50563 .42508 .51146 .43603 .5083 .42961 .50249 Mtetra
.649 .759 .93 r
.42961 .50249 .43603 .5083 .44703 .50511 .44064 .49933 Mtetra
.649 .761 .931 r
.44064 .49933 .44703 .50511 .45808 .50192 .45172 .49616 Mtetra
.647 .762 .933 r
.45172 .49616 .45808 .50192 .46917 .49875 .46284 .49302 Mtetra
.643 .762 .936 r
.46284 .49302 .46917 .49875 .48031 .49566 .47401 .48996 Mtetra
.635 .762 .939 r
.47401 .48996 .48031 .49566 .4915 .49272 .48523 .48706 Mtetra
.623 .76 .945 r
.48523 .48706 .4915 .49272 .50273 .49005 .49649 .48443 Mtetra
.602 .756 .952 r
.49649 .48443 .50273 .49005 .51402 .48778 .50781 .48222 Mtetra
.57 .748 .961 r
.50781 .48222 .51402 .48778 .52536 .48608 .51918 .48061 Mtetra
.521 .733 .971 r
.51918 .48061 .52536 .48608 .53676 .48517 .53061 .47983 Mtetra
.445 .705 .977 r
.53061 .47983 .53676 .48517 .54824 .48527 .54212 .48011 Mtetra
.331 .655 .971 r
.54212 .48011 .54824 .48527 .55981 .48661 .55371 .4817 Mtetra
.168 .57 .934 r
.55371 .4817 .55981 .48661 .57147 .4894 .56541 .48483 Mtetra
0 .439 .844 r
.56541 .48483 .57147 .4894 .58326 .49381 .57723 .48968 Mtetra
0 .273 .696 r
.57723 .48968 .58326 .49381 .59519 .49991 .5892 .49634 Mtetra
.455 0 0 r
.5892 .49634 .59519 .49991 .60729 .50765 .60134 .50477 Mtetra
.587 .024 0 r
.60134 .50477 .60729 .50765 .61955 .51686 .61365 .5148 Mtetra
.666 .115 0 r
.61365 .5148 .61955 .51686 .632 .52719 .62616 .52606 Mtetra
.706 .168 0 r
.62616 .52606 .632 .52719 .64463 .53815 .63885 .53806 Mtetra
.719 .191 0 r
.63885 .53806 .64463 .53815 .65741 .5491 .65171 .55011 Mtetra
.71 .189 0 r
.65171 .55011 .65741 .5491 .67032 .55933 .66471 .56145 Mtetra
.68 .161 0 r
.66471 .56145 .67032 .55933 .68333 .56807 .67782 .57126 Mtetra
.625 .106 0 r
.67782 .57126 .68333 .56807 .69637 .57461 .69097 .57877 Mtetra
.539 .019 0 r
.69097 .57877 .69637 .57461 .70939 .57833 .7041 .58328 Mtetra
.409 0 0 r
.7041 .58328 .70939 .57833 .72234 .57879 .71716 .58431 Mtetra
.226 0 0 r
.71716 .58431 .72234 .57879 .73516 .57578 .73008 .58158 Mtetra
0 0 0 r
.73008 .58158 .73516 .57578 .74781 .56929 .74283 .57509 Mtetra
.74283 .57509 .74781 .56929 .76028 .5596 .75538 .56508 Mtetra
.75538 .56508 .76028 .5596 .77256 .54714 .76772 .55202 Mtetra
.661 .889 .536 r
.76772 .55202 .77256 .54714 .78466 .53253 .77987 .53656 Mtetra
.779 .942 .596 r
.77987 .53656 .78466 .53253 .79662 .51643 .79185 .51943 Mtetra
.854 .968 .645 r
.79185 .51943 .79662 .51643 .80847 .49956 .80371 .50142 Mtetra
.898 .978 .688 r
.80371 .50142 .80847 .49956 .82027 .48257 .8155 .48322 Mtetra
.92 .977 .728 r
.8155 .48322 .82027 .48257 .83206 .46602 .82728 .46548 Mtetra
.925 .97 .764 r
.82728 .46548 .83206 .46602 .84389 .45034 .83909 .44867 Mtetra
.918 .957 .798 r
.83909 .44867 .84389 .45034 .85581 .43582 .85098 .43312 Mtetra
.9 .939 .827 r
.85098 .43312 .85581 .43582 .86784 .42261 .86299 .419 Mtetra
.876 .918 .851 r
.86299 .419 .86784 .42261 .87999 .41074 .87514 .40636 Mtetra
.849 .896 .87 r
.87514 .40636 .87999 .41074 .89229 .40013 .88743 .3951 Mtetra
.822 .874 .884 r
.88743 .3951 .89229 .40013 .90472 .39064 .89987 .38508 Mtetra
.796 .854 .893 r
.89987 .38508 .90472 .39064 .91728 .38208 .91244 .37611 Mtetra
.642 .744 .923 r
.31521 .52619 .32194 .53218 .3325 .52935 .32579 .52336 Mtetra
.642 .745 .924 r
.32579 .52336 .3325 .52935 .3431 .5265 .33642 .52051 Mtetra
.642 .746 .924 r
.33642 .52051 .3431 .5265 .35375 .52362 .34709 .51764 Mtetra
.642 .747 .925 r
.34709 .51764 .35375 .52362 .36444 .52071 .35781 .51475 Mtetra
.643 .749 .926 r
.35781 .51475 .36444 .52071 .37518 .51777 .36858 .51183 Mtetra
.643 .75 .927 r
.36858 .51183 .37518 .51777 .38597 .5148 .37939 .50888 Mtetra
.644 .752 .928 r
.37939 .50888 .38597 .5148 .39681 .51178 .39026 .50589 Mtetra
.645 .754 .929 r
.39026 .50589 .39681 .51178 .4077 .50872 .40117 .50287 Mtetra
.645 .756 .93 r
.40117 .50287 .4077 .50872 .41863 .50563 .41213 .49981 Mtetra
.646 .758 .931 r
.41213 .49981 .41863 .50563 .42961 .50249 .42314 .49672 Mtetra
.646 .761 .933 r
.42314 .49672 .42961 .50249 .44064 .49933 .43419 .4936 Mtetra
.645 .763 .934 r
.43419 .4936 .44064 .49933 .45172 .49616 .4453 .49047 Mtetra
.644 .765 .937 r
.4453 .49047 .45172 .49616 .46284 .49302 .45645 .48737 Mtetra
.64 .766 .939 r
.45645 .48737 .46284 .49302 .47401 .48996 .46765 .48434 Mtetra
.632 .766 .943 r
.46765 .48434 .47401 .48996 .48523 .48706 .4789 .48147 Mtetra
.619 .764 .948 r
.4789 .48147 .48523 .48706 .49649 .48443 .49019 .47887 Mtetra
.598 .759 .955 r
.49019 .47887 .49649 .48443 .50781 .48222 .50154 .47669 Mtetra
.566 .749 .963 r
.50154 .47669 .50781 .48222 .51918 .48061 .51294 .47511 Mtetra
.517 .731 .971 r
.51294 .47511 .51918 .48061 .53061 .47983 .52441 .47436 Mtetra
.443 .701 .976 r
.52441 .47436 .53061 .47983 .54212 .48011 .53594 .4747 Mtetra
.334 .649 .968 r
.53594 .4747 .54212 .48011 .55371 .4817 .54757 .47639 Mtetra
.184 .566 .936 r
.54757 .47639 .55371 .4817 .56541 .48483 .55929 .47965 Mtetra
0 .445 .862 r
.55929 .47965 .56541 .48483 .57723 .48968 .57114 .48469 Mtetra
0 .298 .746 r
.57114 .48469 .57723 .48968 .5892 .49634 .58313 .49161 Mtetra
0 .151 .606 r
.58313 .49161 .5892 .49634 .60134 .50477 .59529 .50038 Mtetra
.514 0 0 r
.59529 .50038 .60134 .50477 .61365 .5148 .60764 .51083 Mtetra
.601 .058 0 r
.60764 .51083 .61365 .5148 .62616 .52606 .62018 .52261 Mtetra
.651 .109 0 r
.62018 .52261 .62616 .52606 .63885 .53806 .63291 .53519 Mtetra
.671 .128 0 r
.63291 .53519 .63885 .53806 .65171 .55011 .64582 .54791 Mtetra
.666 .116 0 r
.64582 .54791 .65171 .55011 .66471 .56145 .65888 .55996 Mtetra
.632 .069 0 r
.65888 .55996 .66471 .56145 .67782 .57126 .67205 .5705 Mtetra
.558 0 0 r
.67205 .5705 .67782 .57126 .69097 .57877 .68528 .57869 Mtetra
.423 0 0 r
.68528 .57869 .69097 .57877 .7041 .58328 .6985 .58381 Mtetra
.194 0 0 r
.6985 .58381 .7041 .58328 .71716 .58431 .71164 .58532 Mtetra
.131 .675 .697 r
.71164 .58532 .71716 .58431 .73008 .58158 .72466 .5829 Mtetra
.462 .884 .788 r
.72466 .5829 .73008 .58158 .74283 .57509 .73749 .57652 Mtetra
.694 .978 .801 r
.73749 .57652 .74283 .57509 .75538 .56508 .75012 .5664 Mtetra
.823 .998 .78 r
.75012 .5664 .75538 .56508 .76772 .55202 .76253 .55303 Mtetra
.89 .99 .758 r
.76253 .55303 .76772 .55202 .77987 .53656 .77473 .53707 Mtetra
.925 .974 .744 r
.77473 .53707 .77987 .53656 .79185 .51943 .78676 .51929 Mtetra
.941 .959 .74 r
.78676 .51929 .79185 .51943 .80371 .50142 .79865 .50051 Mtetra
.947 .946 .745 r
.79865 .50051 .80371 .50142 .8155 .48322 .81046 .4815 Mtetra
.944 .934 .757 r
.81046 .4815 .8155 .48322 .82728 .46548 .82225 .46293 Mtetra
.935 .922 .774 r
.82225 .46293 .82728 .46548 .83909 .44867 .83407 .44531 Mtetra
.92 .91 .794 r
.83407 .44531 .83909 .44867 .85098 .43312 .84597 .42902 Mtetra
.9 .897 .816 r
.84597 .42902 .85098 .43312 .86299 .419 .85798 .41424 Mtetra
.875 .882 .836 r
.85798 .41424 .86299 .419 .87514 .40636 .87014 .40102 Mtetra
.849 .866 .854 r
.87014 .40102 .87514 .40636 .88743 .3951 .88244 .38928 Mtetra
.822 .849 .868 r
.88244 .38928 .88743 .3951 .89987 .38508 .89489 .37887 Mtetra
.798 .834 .879 r
.89489 .37887 .89987 .38508 .91244 .37611 .90748 .36957 Mtetra
.64 .743 .923 r
.30843 .52013 .31521 .52619 .32579 .52336 .31904 .51731 Mtetra
.64 .744 .924 r
.31904 .51731 .32579 .52336 .33642 .52051 .32969 .51447 Mtetra
.64 .745 .925 r
.32969 .51447 .33642 .52051 .34709 .51764 .34038 .51162 Mtetra
.64 .747 .926 r
.34038 .51162 .34709 .51764 .35781 .51475 .35113 .50875 Mtetra
.64 .748 .927 r
.35113 .50875 .35781 .51475 .36858 .51183 .36192 .50586 Mtetra
.641 .75 .928 r
.36192 .50586 .36858 .51183 .37939 .50888 .37276 .50295 Mtetra
.641 .752 .93 r
.37276 .50295 .37939 .50888 .39026 .50589 .38364 .50001 Mtetra
.641 .755 .931 r
.38364 .50001 .39026 .50589 .40117 .50287 .39458 .49705 Mtetra
.641 .758 .933 r
.39458 .49705 .40117 .50287 .41213 .49981 .40557 .49405 Mtetra
.642 .761 .935 r
.40557 .49405 .41213 .49981 .42314 .49672 .4166 .49102 Mtetra
.642 .764 .937 r
.4166 .49102 .42314 .49672 .43419 .4936 .42769 .48797 Mtetra
.641 .767 .939 r
.42769 .48797 .43419 .4936 .4453 .49047 .43882 .4849 Mtetra
.639 .769 .942 r
.43882 .4849 .4453 .49047 .45645 .48737 .45001 .48185 Mtetra
.635 .771 .945 r
.45001 .48185 .45645 .48737 .46765 .48434 .46124 .47887 Mtetra
.628 .771 .949 r
.46124 .47887 .46765 .48434 .4789 .48147 .47252 .47603 Mtetra
.616 .769 .954 r
.47252 .47603 .4789 .48147 .49019 .47887 .48384 .47344 Mtetra
.595 .764 .96 r
.48384 .47344 .49019 .47887 .50154 .47669 .49522 .47124 Mtetra
.564 .753 .966 r
.49522 .47124 .50154 .47669 .51294 .47511 .50666 .46963 Mtetra
.517 .734 .973 r
.50666 .46963 .51294 .47511 .52441 .47436 .51815 .46884 Mtetra
.447 .702 .975 r
.51815 .46884 .52441 .47436 .53594 .4747 .52971 .4691 Mtetra
.348 .651 .968 r
.52971 .4691 .53594 .4747 .54757 .47639 .54136 .4707 Mtetra
.217 .573 .941 r
.54136 .4707 .54757 .47639 .55929 .47965 .55311 .47387 Mtetra
.057 .467 .885 r
.55311 .47387 .55929 .47965 .57114 .48469 .56498 .47882 Mtetra
0 .342 .801 r
.56498 .47882 .57114 .48469 .58313 .49161 .57699 .48565 Mtetra
0 .217 .702 r
.57699 .48565 .58313 .49161 .59529 .50038 .58917 .49436 Mtetra
0 .113 .608 r
.58917 .49436 .59529 .50038 .60764 .51083 .60152 .50479 Mtetra
0 .039 .537 r
.60152 .50479 .60764 .51083 .62018 .52261 .61407 .5166 Mtetra
.504 .001 0 r
.61407 .5166 .62018 .52261 .63291 .53519 .62682 .52928 Mtetra
.51 .005 0 r
.62682 .52928 .63291 .53519 .64582 .54791 .63975 .54215 Mtetra
0 .029 .521 r
.63975 .54215 .64582 .54791 .65888 .55996 .65283 .55443 Mtetra
0 .11 .593 r
.65283 .55443 .65888 .55996 .67205 .5705 .66604 .56525 Mtetra
0 .248 .709 r
.66604 .56525 .67205 .5705 .68528 .57869 .6793 .57378 Mtetra
0 .442 .852 r
.6793 .57378 .68528 .57869 .6985 .58381 .69257 .57926 Mtetra
.261 .653 .966 r
.69257 .57926 .6985 .58381 .71164 .58532 .70578 .58111 Mtetra
.53 .809 .997 r
.70578 .58111 .71164 .58532 .72466 .5829 .71886 .57899 Mtetra
.715 .883 .959 r
.71886 .57899 .72466 .5829 .73749 .57652 .73177 .57283 Mtetra
.821 .905 .898 r
.73177 .57283 .73749 .57652 .75012 .5664 .74447 .56284 Mtetra
.879 .904 .844 r
.74447 .56284 .75012 .5664 .76253 .55303 .75696 .54947 Mtetra
.909 .895 .803 r
.75696 .54947 .76253 .55303 .77473 .53707 .76923 .5334 Mtetra
.925 .886 .776 r
.76923 .5334 .77473 .53707 .78676 .51929 .78131 .51541 Mtetra
.931 .878 .761 r
.78131 .51541 .78676 .51929 .79865 .50051 .79326 .49632 Mtetra
.932 .872 .756 r
.79326 .49632 .79865 .50051 .81046 .4815 .80512 .47694 Mtetra
.927 .866 .76 r
.80512 .47694 .81046 .4815 .82225 .46293 .81695 .45797 Mtetra
.918 .861 .77 r
.81695 .45797 .82225 .46293 .83407 .44531 .82881 .43995 Mtetra
.904 .856 .784 r
.82881 .43995 .83407 .44531 .84597 .42902 .84075 .42326 Mtetra
.886 .85 .802 r
.84075 .42326 .84597 .42902 .85798 .41424 .85279 .40811 Mtetra
.865 .842 .821 r
.85279 .40811 .85798 .41424 .87014 .40102 .86498 .39456 Mtetra
.841 .833 .838 r
.86498 .39456 .87014 .40102 .88244 .38928 .87731 .38255 Mtetra
.817 .822 .854 r
.87731 .38255 .88244 .38928 .89489 .37887 .88979 .3719 Mtetra
.794 .812 .866 r
.88979 .3719 .89489 .37887 .90748 .36957 .90242 .36241 Mtetra
.639 .742 .923 r
.3016 .51401 .30843 .52013 .31904 .51731 .31223 .51119 Mtetra
.639 .743 .924 r
.31223 .51119 .31904 .51731 .32969 .51447 .3229 .50838 Mtetra
.638 .744 .925 r
.3229 .50838 .32969 .51447 .34038 .51162 .33362 .50555 Mtetra
.638 .746 .927 r
.33362 .50555 .34038 .51162 .35113 .50875 .34439 .50272 Mtetra
.637 .748 .929 r
.34439 .50272 .35113 .50875 .36192 .50586 .3552 .49989 Mtetra
.637 .75 .93 r
.3552 .49989 .36192 .50586 .37276 .50295 .36607 .49704 Mtetra
.636 .753 .933 r
.36607 .49704 .37276 .50295 .38364 .50001 .37698 .49417 Mtetra
.636 .756 .935 r
.37698 .49417 .38364 .50001 .39458 .49705 .38794 .49129 Mtetra
.636 .76 .938 r
.38794 .49129 .39458 .49705 .40557 .49405 .39895 .48839 Mtetra
.636 .764 .94 r
.39895 .48839 .40557 .49405 .4166 .49102 .41001 .48545 Mtetra
.636 .768 .943 r
.41001 .48545 .4166 .49102 .42769 .48797 .42113 .4825 Mtetra
.635 .772 .946 r
.42113 .4825 .42769 .48797 .43882 .4849 .43229 .47952 Mtetra
.633 .776 .949 r
.43229 .47952 .43882 .4849 .45001 .48185 .4435 .47655 Mtetra
.629 .779 .953 r
.4435 .47655 .45001 .48185 .46124 .47887 .45476 .47363 Mtetra
.623 .78 .956 r
.45476 .47363 .46124 .47887 .47252 .47603 .46607 .47082 Mtetra
.611 .778 .961 r
.46607 .47082 .47252 .47603 .48384 .47344 .47744 .46823 Mtetra
.592 .773 .966 r
.47744 .46823 .48384 .47344 .49522 .47124 .48885 .46599 Mtetra
.563 .762 .971 r
.48885 .46599 .49522 .47124 .50666 .46963 .50031 .46429 Mtetra
.52 .742 .976 r
.50031 .46429 .50666 .46963 .51815 .46884 .51184 .46335 Mtetra
.457 .71 .977 r
.51184 .46335 .51815 .46884 .52971 .4691 .52343 .46341 Mtetra
.371 .661 .969 r
.52343 .46341 .52971 .4691 .54136 .4707 .53511 .46474 Mtetra
.261 .59 .948 r
.53511 .46474 .54136 .4707 .55311 .47387 .54687 .46758 Mtetra
.132 .499 .907 r
.54687 .46758 .55311 .47387 .56498 .47882 .55876 .47214 Mtetra
0 .395 .848 r
.55876 .47214 .56498 .47882 .57699 .48565 .57078 .47854 Mtetra
0 .294 .782 r
.57078 .47854 .57699 .48565 .58917 .49436 .58296 .48679 Mtetra
0 .211 .723 r
.58296 .48679 .58917 .49436 .60152 .50479 .59531 .49673 Mtetra
0 .155 .683 r
.59531 .49673 .60152 .50479 .61407 .5166 .60785 .50806 Mtetra
0 .132 .668 r
.60785 .50806 .61407 .5166 .62682 .52928 .62059 .5203 Mtetra
0 .144 .681 r
.62059 .5203 .62682 .52928 .63975 .54215 .63351 .53279 Mtetra
0 .19 .72 r
.63351 .53279 .63975 .54215 .65283 .55443 .64658 .54478 Mtetra
0 .27 .777 r
.64658 .54478 .65283 .55443 .66604 .56525 .65978 .55542 Mtetra
.106 .375 .836 r
.65978 .55542 .66604 .56525 .6793 .57378 .67306 .56389 Mtetra
.285 .488 .88 r
.67306 .56389 .6793 .57378 .69257 .57926 .68634 .56942 Mtetra
.455 .588 .896 r
.68634 .56942 .69257 .57926 .70578 .58111 .69958 .57144 Mtetra
.596 .663 .885 r
.69958 .57144 .70578 .58111 .71886 .57899 .7127 .56957 Mtetra
.7 .713 .859 r
.7127 .56957 .71886 .57899 .73177 .57283 .72567 .56372 Mtetra
.772 .744 .828 r
.72567 .56372 .73177 .57283 .74447 .56284 .73844 .55405 Mtetra
.82 .764 .799 r
.73844 .55405 .74447 .56284 .75696 .54947 .75099 .54101 Mtetra
.853 .776 .776 r
.75099 .54101 .75696 .54947 .76923 .5334 .76334 .52522 Mtetra
.873 .784 .76 r
.76334 .52522 .76923 .5334 .78131 .51541 .77551 .50747 Mtetra
.885 .79 .75 r
.77551 .50747 .78131 .51541 .79326 .49632 .78754 .48856 Mtetra
.891 .795 .747 r
.78754 .48856 .79326 .49632 .80512 .47694 .79948 .4693 Mtetra
.891 .798 .75 r
.79948 .4693 .80512 .47694 .81695 .45797 .81138 .45039 Mtetra
.887 .801 .759 r
.81138 .45039 .81695 .45797 .82881 .43995 .82331 .43239 Mtetra
.878 .803 .772 r
.82331 .43239 .82881 .43995 .84075 .42326 .8353 .41569 Mtetra
.865 .804 .789 r
.8353 .41569 .84075 .42326 .85279 .40811 .84741 .4005 Mtetra
.848 .802 .806 r
.84741 .4005 .85279 .40811 .86498 .39456 .85965 .38691 Mtetra
.828 .799 .824 r
.85965 .38691 .86498 .39456 .87731 .38255 .87203 .37483 Mtetra
.808 .795 .84 r
.87203 .37483 .87731 .38255 .88979 .3719 .88456 .36413 Mtetra
.787 .789 .854 r
.88456 .36413 .88979 .3719 .90242 .36241 .89724 .35458 Mtetra
.637 .741 .924 r
.29473 .50782 .3016 .51401 .31223 .51119 .30537 .50503 Mtetra
.636 .742 .925 r
.30537 .50503 .31223 .51119 .3229 .50838 .31607 .50224 Mtetra
.635 .744 .927 r
.31607 .50224 .3229 .50838 .33362 .50555 .32681 .49946 Mtetra
.634 .746 .929 r
.32681 .49946 .33362 .50555 .34439 .50272 .3376 .49669 Mtetra
.633 .748 .931 r
.3376 .49669 .34439 .50272 .3552 .49989 .34843 .49393 Mtetra
.632 .751 .934 r
.34843 .49393 .3552 .49989 .36607 .49704 .35932 .49117 Mtetra
.63 .755 .937 r
.35932 .49117 .36607 .49704 .37698 .49417 .37025 .48842 Mtetra
.629 .759 .94 r
.37025 .48842 .37698 .49417 .38794 .49129 .38124 .48566 Mtetra
.628 .764 .944 r
.38124 .48566 .38794 .49129 .39895 .48839 .39227 .48288 Mtetra
.627 .769 .948 r
.39227 .48288 .39895 .48839 .41001 .48545 .40336 .48009 Mtetra
.626 .774 .952 r
.40336 .48009 .41001 .48545 .42113 .4825 .4145 .47727 Mtetra
.625 .78 .955 r
.4145 .47727 .42113 .4825 .43229 .47952 .42569 .47442 Mtetra
.623 .785 .959 r
.42569 .47442 .43229 .47952 .4435 .47655 .43693 .47157 Mtetra
.62 .789 .963 r
.43693 .47157 .4435 .47655 .45476 .47363 .44822 .46873 Mtetra
.614 .792 .967 r
.44822 .46873 .45476 .47363 .46607 .47082 .45957 .46597 Mtetra
.604 .791 .97 r
.45957 .46597 .46607 .47082 .47744 .46823 .47096 .46337 Mtetra
.588 .786 .974 r
.47096 .46337 .47744 .46823 .48885 .46599 .48241 .46106 Mtetra
.562 .776 .978 r
.48241 .46106 .48885 .46599 .50031 .46429 .49391 .45921 Mtetra
.524 .756 .981 r
.49391 .45921 .50031 .46429 .51184 .46335 .50547 .45803 Mtetra
.471 .725 .981 r
.50547 .45803 .51184 .46335 .52343 .46341 .5171 .45776 Mtetra
.399 .679 .974 r
.5171 .45776 .52343 .46341 .53511 .46474 .5288 .45865 Mtetra
.311 .616 .956 r
.5288 .45865 .53511 .46474 .54687 .46758 .54059 .46095 Mtetra
.211 .537 .925 r
.54059 .46095 .54687 .46758 .55876 .47214 .55248 .46484 Mtetra
.111 .451 .884 r
.55248 .46484 .55876 .47214 .57078 .47854 .56451 .47048 Mtetra
.027 .369 .838 r
.56451 .47048 .57078 .47854 .58296 .48679 .57668 .47786 Mtetra
0 .303 .798 r
.57668 .47786 .58296 .48679 .59531 .49673 .58902 .48688 Mtetra
0 .261 .77 r
.58902 .48688 .59531 .49673 .60785 .50806 .60154 .49726 Mtetra
0 .246 .759 r
.60154 .49726 .60785 .50806 .62059 .5203 .61424 .50854 Mtetra
.004 .258 .763 r
.61424 .50854 .62059 .5203 .63351 .53279 .62712 .52013 Mtetra
.082 .293 .776 r
.62712 .52013 .63351 .53279 .64658 .54478 .64016 .53132 Mtetra
.182 .345 .793 r
.64016 .53132 .64658 .54478 .65978 .55542 .65333 .54131 Mtetra
.294 .406 .806 r
.65333 .54131 .65978 .55542 .67306 .56389 .66657 .54931 Mtetra
.406 .468 .811 r
.66657 .54931 .67306 .56389 .68634 .56942 .67984 .55459 Mtetra
.508 .524 .808 r
.67984 .55459 .68634 .56942 .69958 .57144 .69308 .55657 Mtetra
.595 .573 .798 r
.69308 .55657 .69958 .57144 .7127 .56957 .70622 .55487 Mtetra
.666 .612 .784 r
.70622 .55487 .7127 .56957 .72567 .56372 .71922 .54937 Mtetra
.722 .643 .77 r
.71922 .54937 .72567 .56372 .73844 .55405 .73205 .5402 Mtetra
.765 .668 .756 r
.73205 .5402 .73844 .55405 .75099 .54101 .74468 .52775 Mtetra
.797 .688 .744 r
.74468 .52775 .75099 .54101 .76334 .52522 .75711 .51262 Mtetra
.821 .704 .737 r
.75711 .51262 .76334 .52522 .77551 .50747 .76937 .49553 Mtetra
.837 .718 .733 r
.76937 .49553 .77551 .50747 .78754 .48856 .7815 .47726 Mtetra
.848 .73 .733 r
.7815 .47726 .78754 .48856 .79948 .4693 .79354 .45859 Mtetra
.853 .74 .739 r
.79354 .45859 .79948 .4693 .81138 .45039 .80554 .4402 Mtetra
.853 .749 .748 r
.80554 .4402 .81138 .45039 .82331 .43239 .81757 .42264 Mtetra
.849 .757 .761 r
.81757 .42264 .82331 .43239 .8353 .41569 .82965 .40631 Mtetra
.84 .762 .777 r
.82965 .40631 .8353 .41569 .84741 .4005 .84184 .39141 Mtetra
.828 .766 .794 r
.84184 .39141 .84741 .4005 .85965 .38691 .85416 .37804 Mtetra
.812 .769 .812 r
.85416 .37804 .85965 .38691 .87203 .37483 .86661 .36614 Mtetra
.795 .769 .829 r
.86661 .36614 .87203 .37483 .88456 .36413 .87921 .35555 Mtetra
.778 .767 .844 r
.87921 .35555 .88456 .36413 .89724 .35458 .89195 .34609 Mtetra
.635 .74 .924 r
.28779 .50159 .29473 .50782 .30537 .50503 .29846 .49882 Mtetra
.634 .742 .926 r
.29846 .49882 .30537 .50503 .31607 .50224 .30918 .49608 Mtetra
.632 .744 .929 r
.30918 .49608 .31607 .50224 .32681 .49946 .31994 .49337 Mtetra
.629 .746 .931 r
.31994 .49337 .32681 .49946 .3376 .49669 .33075 .49068 Mtetra
.627 .749 .935 r
.33075 .49068 .3376 .49669 .34843 .49393 .3416 .48803 Mtetra
.624 .752 .939 r
.3416 .48803 .34843 .49393 .35932 .49117 .35251 .4854 Mtetra
.622 .757 .943 r
.35251 .4854 .35932 .49117 .37025 .48842 .36346 .48279 Mtetra
.619 .762 .948 r
.36346 .48279 .37025 .48842 .38124 .48566 .37447 .4802 Mtetra
.616 .768 .953 r
.37447 .4802 .38124 .48566 .39227 .48288 .38553 .47761 Mtetra
.614 .775 .958 r
.38553 .47761 .39227 .48288 .40336 .48009 .39664 .47501 Mtetra
.612 .782 .963 r
.39664 .47501 .40336 .48009 .4145 .47727 .4078 .47238 Mtetra
.61 .79 .967 r
.4078 .47238 .4145 .47727 .42569 .47442 .41902 .46972 Mtetra
.608 .797 .972 r
.41902 .46972 .42569 .47442 .43693 .47157 .43029 .46702 Mtetra
.606 .803 .975 r
.43029 .46702 .43693 .47157 .44822 .46873 .44161 .4643 Mtetra
.601 .807 .979 r
.44161 .4643 .44822 .46873 .45957 .46597 .45299 .4616 Mtetra
.593 .808 .982 r
.45299 .4616 .45957 .46597 .47096 .46337 .46443 .459 Mtetra
.58 .804 .985 r
.46443 .459 .47096 .46337 .48241 .46106 .47591 .4566 Mtetra
.56 .795 .987 r
.47591 .4566 .48241 .46106 .49391 .45921 .48745 .45456 Mtetra
.529 .776 .988 r
.48745 .45456 .49391 .45921 .50547 .45803 .49905 .45308 Mtetra
.486 .747 .987 r
.49905 .45308 .50547 .45803 .5171 .45776 .5107 .45236 Mtetra
.43 .705 .98 r
.5107 .45236 .5171 .45776 .5288 .45865 .52243 .45266 Mtetra
.362 .649 .965 r
.52243 .45266 .5288 .45865 .54059 .46095 .53425 .4542 Mtetra
.287 .58 .941 r
.53425 .4542 .54059 .46095 .55248 .46484 .54616 .4572 Mtetra
.216 .507 .908 r
.54616 .4572 .55248 .46484 .56451 .47048 .55818 .46177 Mtetra
.158 .437 .872 r
.55818 .46177 .56451 .47048 .57668 .47786 .57035 .46796 Mtetra
.123 .381 .838 r
.57035 .46796 .57668 .47786 .58902 .48688 .58267 .47566 Mtetra
.115 .344 .811 r
.58267 .47566 .58902 .48688 .60154 .49726 .59515 .48466 Mtetra
.135 .328 .792 r
.59515 .48466 .60154 .49726 .61424 .50854 .60781 .49454 Mtetra
.178 .331 .782 r
.60781 .49454 .61424 .50854 .62712 .52013 .62063 .50477 Mtetra
.239 .35 .776 r
.62063 .50477 .62712 .52013 .64016 .53132 .63361 .51471 Mtetra
.311 .38 .773 r
.63361 .51471 .64016 .53132 .65333 .54131 .64672 .52362 Mtetra
.387 .416 .769 r
.64672 .52362 .65333 .54131 .66657 .54931 .65991 .53077 Mtetra
.461 .454 .764 r
.65991 .53077 .66657 .54931 .67984 .55459 .67313 .53549 Mtetra
.53 .491 .757 r
.67313 .53549 .67984 .55459 .69308 .55657 .68634 .53722 Mtetra
.591 .525 .749 r
.68634 .53722 .69308 .55657 .70622 .55487 .69948 .53558 Mtetra
.643 .556 .741 r
.69948 .53558 .70622 .55487 .71922 .54937 .7125 .53043 Mtetra
.688 .583 .733 r
.7125 .53043 .71922 .54937 .73205 .5402 .72537 .52188 Mtetra
.725 .608 .726 r
.72537 .52188 .73205 .5402 .74468 .52775 .73806 .51024 Mtetra
.754 .629 .721 r
.73806 .51024 .74468 .52775 .75711 .51262 .75058 .49606 Mtetra
.778 .648 .718 r
.75058 .49606 .75711 .51262 .76937 .49553 .76295 .47999 Mtetra
.796 .665 .718 r
.76295 .47999 .76937 .49553 .7815 .47726 .77519 .46275 Mtetra
.809 .68 .722 r
.77519 .46275 .7815 .47726 .79354 .45859 .78735 .44508 Mtetra
.817 .694 .728 r
.78735 .44508 .79354 .45859 .80554 .4402 .79947 .42761 Mtetra
.821 .706 .739 r
.79947 .42761 .80554 .4402 .81757 .42264 .81161 .41087 Mtetra
.82 .718 .752 r
.81161 .41087 .81757 .42264 .82965 .40631 .82381 .39524 Mtetra
.815 .727 .768 r
.82381 .39524 .82965 .40631 .84184 .39141 .8361 .38094 Mtetra
.806 .735 .785 r
.8361 .38094 .84184 .39141 .85416 .37804 .84851 .36804 Mtetra
.795 .741 .803 r
.84851 .36804 .85416 .37804 .86661 .36614 .86106 .35651 Mtetra
.781 .745 .82 r
.86106 .35651 .86661 .36614 .87921 .35555 .87374 .34621 Mtetra
.767 .747 .835 r
.87374 .34621 .87921 .35555 .89195 .34609 .88655 .33696 Mtetra
.632 .74 .925 r
.28081 .49531 .28779 .50159 .29846 .49882 .2915 .49259 Mtetra
.63 .741 .928 r
.2915 .49259 .29846 .49882 .30918 .49608 .30223 .48992 Mtetra
.627 .743 .931 r
.30223 .48992 .30918 .49608 .31994 .49337 .31301 .48729 Mtetra
.623 .746 .935 r
.31301 .48729 .31994 .49337 .33075 .49068 .32384 .48472 Mtetra
.619 .75 .94 r
.32384 .48472 .33075 .49068 .3416 .48803 .33471 .48221 Mtetra
.614 .754 .945 r
.33471 .48221 .3416 .48803 .35251 .4854 .34564 .47976 Mtetra
.609 .76 .951 r
.34564 .47976 .35251 .4854 .36346 .48279 .35661 .47736 Mtetra
.604 .766 .957 r
.35661 .47736 .36346 .48279 .37447 .4802 .36763 .47499 Mtetra
.599 .774 .963 r
.36763 .47499 .37447 .4802 .38553 .47761 .37871 .47265 Mtetra
.595 .782 .97 r
.37871 .47265 .38553 .47761 .39664 .47501 .38984 .47031 Mtetra
.591 .791 .976 r
.38984 .47031 .39664 .47501 .4078 .47238 .40102 .46793 Mtetra
.587 .801 .981 r
.40102 .46793 .4078 .47238 .41902 .46972 .41227 .46551 Mtetra
.584 .81 .985 r
.41227 .46551 .41902 .46972 .43029 .46702 .42357 .46303 Mtetra
.582 .818 .989 r
.42357 .46303 .43029 .46702 .44161 .4643 .43493 .46047 Mtetra
.579 .824 .991 r
.43493 .46047 .44161 .4643 .45299 .4616 .44634 .45788 Mtetra
.574 .827 .993 r
.44634 .45788 .45299 .4616 .46443 .459 .45781 .45529 Mtetra
.566 .826 .994 r
.45781 .45529 .46443 .459 .47591 .4566 .46934 .4528 Mtetra
.552 .818 .995 r
.46934 .4528 .47591 .4566 .48745 .45456 .48092 .45054 Mtetra
.531 .803 .996 r
.48092 .45054 .48745 .45456 .49905 .45308 .49256 .44868 Mtetra
.501 .777 .994 r
.49256 .44868 .49905 .45308 .5107 .45236 .50425 .44743 Mtetra
.46 .739 .988 r
.50425 .44743 .5107 .45236 .52243 .45266 .51602 .44701 Mtetra
.412 .689 .976 r
.51602 .44701 .52243 .45266 .53425 .4542 .52785 .44764 Mtetra
.359 .629 .956 r
.52785 .44764 .53425 .4542 .54616 .4572 .53978 .44953 Mtetra
.309 .563 .927 r
.53978 .44953 .54616 .4572 .55818 .46177 .55182 .4528 Mtetra
.27 .5 .894 r
.55182 .4528 .55818 .46177 .57035 .46796 .56397 .45752 Mtetra
.248 .447 .86 r
.56397 .45752 .57035 .46796 .58267 .47566 .57627 .46361 Mtetra
.245 .41 .829 r
.57627 .46361 .58267 .47566 .59515 .48466 .58871 .47088 Mtetra
.262 .388 .803 r
.58871 .47088 .59515 .48466 .60781 .49454 .60131 .479 Mtetra
.294 .382 .783 r
.60131 .479 .60781 .49454 .62063 .50477 .61407 .4875 Mtetra
.338 .388 .767 r
.61407 .4875 .62063 .50477 .63361 .51471 .62698 .49582 Mtetra
.388 .404 .755 r
.62698 .49582 .63361 .51471 .64672 .52362 .64 .5033 Mtetra
.441 .425 .745 r
.64 .5033 .64672 .52362 .65991 .53077 .65312 .5093 Mtetra
.493 .449 .737 r
.65312 .5093 .65991 .53077 .67313 .53549 .66628 .51319 Mtetra
.542 .474 .729 r
.66628 .51319 .67313 .53549 .68634 .53722 .67944 .51447 Mtetra
.588 .5 .722 r
.67944 .51447 .68634 .53722 .69948 .53558 .69255 .51277 Mtetra
.629 .524 .716 r
.69255 .51277 .69948 .53558 .7125 .53043 .70557 .50794 Mtetra
.665 .548 .711 r
.70557 .50794 .7125 .53043 .72537 .52188 .71847 .50005 Mtetra
.696 .569 .708 r
.71847 .50005 .72537 .52188 .73806 .51024 .73122 .48935 Mtetra
.723 .59 .706 r
.73122 .48935 .73806 .51024 .75058 .49606 .74383 .47632 Mtetra
.745 .609 .706 r
.74383 .47632 .75058 .49606 .76295 .47999 .75629 .46153 Mtetra
.763 .626 .708 r
.75629 .46153 .76295 .47999 .77519 .46275 .76865 .44562 Mtetra
.777 .643 .714 r
.76865 .44562 .77519 .46275 .78735 .44508 .78094 .42926 Mtetra
.787 .659 .721 r
.78094 .42926 .78735 .44508 .79947 .42761 .7932 .41302 Mtetra
.793 .673 .732 r
.7932 .41302 .79947 .42761 .81161 .41087 .80548 .3974 Mtetra
.794 .687 .746 r
.80548 .3974 .81161 .41087 .82381 .39524 .8178 .38275 Mtetra
.792 .699 .762 r
.8178 .38275 .82381 .39524 .8361 .38094 .83022 .36928 Mtetra
.786 .71 .78 r
.83022 .36928 .8361 .38094 .84851 .36804 .84274 .35706 Mtetra
.777 .718 .797 r
.84274 .35706 .84851 .36804 .86106 .35651 .85539 .34607 Mtetra
.766 .725 .814 r
.85539 .34607 .86106 .35651 .87374 .34621 .86816 .33619 Mtetra
.755 .73 .829 r
.86816 .33619 .87374 .34621 .88655 .33696 .88105 .32725 Mtetra
.628 .739 .927 r
.27377 .489 .28081 .49531 .2915 .49259 .28448 .48634 Mtetra
.624 .741 .931 r
.28448 .48634 .2915 .49259 .30223 .48992 .29523 .48376 Mtetra
.62 .744 .935 r
.29523 .48376 .30223 .48992 .31301 .48729 .30602 .48126 Mtetra
.614 .747 .94 r
.30602 .48126 .31301 .48729 .32384 .48472 .31687 .47885 Mtetra
.608 .751 .946 r
.31687 .47885 .32384 .48472 .33471 .48221 .32775 .47653 Mtetra
.6 .756 .953 r
.32775 .47653 .33471 .48221 .34564 .47976 .33869 .47431 Mtetra
.592 .763 .96 r
.33869 .47431 .34564 .47976 .35661 .47736 .34968 .47218 Mtetra
.583 .771 .968 r
.34968 .47218 .35661 .47736 .36763 .47499 .36071 .47011 Mtetra
.574 .779 .976 r
.36071 .47011 .36763 .47499 .37871 .47265 .37181 .46809 Mtetra
.565 .789 .983 r
.37181 .46809 .37871 .47265 .38984 .47031 .38295 .46608 Mtetra
.557 .8 .99 r
.38295 .46608 .38984 .47031 .40102 .46793 .39416 .46404 Mtetra
.55 .811 .994 r
.39416 .46404 .40102 .46793 .41227 .46551 .40543 .46194 Mtetra
.545 .822 .997 r
.40543 .46194 .41227 .46551 .42357 .46303 .41676 .45974 Mtetra
.542 .832 .999 r
.41676 .45974 .42357 .46303 .43493 .46047 .42815 .45741 Mtetra
.54 .841 .999 r
.42815 .45741 .43493 .46047 .44634 .45788 .4396 .45495 Mtetra
.539 .846 .999 r
.4396 .45495 .44634 .45788 .45781 .45529 .45111 .4524 Mtetra
.538 .848 .998 r
.45111 .4524 .45781 .45529 .46934 .4528 .46268 .44982 Mtetra
.534 .844 .999 r
.46268 .44982 .46934 .4528 .48092 .45054 .47431 .44732 Mtetra
.526 .833 1 r
.47431 .44732 .48092 .45054 .49256 .44868 .48599 .44505 Mtetra
.511 .812 .999 r
.48599 .44505 .49256 .44868 .50425 .44743 .49774 .44319 Mtetra
.489 .78 .996 r
.49774 .44319 .50425 .44743 .51602 .44701 .50954 .44196 Mtetra
.459 .737 .988 r
.50954 .44196 .51602 .44701 .52785 .44764 .52141 .44156 Mtetra
.425 .682 .97 r
.52141 .44156 .52785 .44764 .53978 .44953 .53336 .44219 Mtetra
.392 .622 .944 r
.53336 .44219 .53978 .44953 .55182 .4528 .54541 .44399 Mtetra
.365 .561 .911 r
.54541 .44399 .55182 .4528 .56397 .45752 .55756 .44704 Mtetra
.349 .508 .875 r
.55756 .44704 .56397 .45752 .57627 .46361 .56983 .45129 Mtetra
.346 .467 .84 r
.56983 .45129 .57627 .46361 .58871 .47088 .58224 .4566 Mtetra
.356 .439 .809 r
.58224 .4566 .58871 .47088 .60131 .479 .59478 .46271 Mtetra
.377 .424 .783 r
.59478 .46271 .60131 .479 .61407 .4875 .60747 .46923 Mtetra
.406 .42 .762 r
.60747 .46923 .61407 .4875 .62698 .49582 .6203 .47566 Mtetra
.441 .425 .746 r
.6203 .47566 .62698 .49582 .64 .5033 .63324 .48147 Mtetra
.478 .436 .733 r
.63324 .48147 .64 .5033 .65312 .5093 .64626 .48607 Mtetra
.516 .451 .722 r
.64626 .48607 .65312 .5093 .66628 .51319 .65935 .48893 Mtetra
.552 .469 .714 r
.65935 .48893 .66628 .51319 .67944 .51447 .67245 .48959 Mtetra
.588 .488 .708 r
.67245 .48959 .67944 .51447 .69255 .51277 .68552 .48771 Mtetra
.62 .507 .703 r
.68552 .48771 .69255 .51277 .70557 .50794 .69853 .48313 Mtetra
.65 .526 .7 r
.69853 .48313 .70557 .50794 .71847 .50005 .71144 .47589 Mtetra
.677 .546 .698 r
.71144 .47589 .71847 .50005 .73122 .48935 .72424 .46619 Mtetra
.7 .564 .698 r
.72424 .46619 .73122 .48935 .74383 .47632 .73692 .4544 Mtetra
.721 .582 .699 r
.73692 .4544 .74383 .47632 .75629 .46153 .74949 .44103 Mtetra
.738 .6 .703 r
.74949 .44103 .75629 .46153 .76865 .44562 .76197 .42663 Mtetra
.751 .617 .71 r
.76197 .42663 .76865 .44562 .78094 .42926 .7744 .41178 Mtetra
.762 .633 .718 r
.7744 .41178 .78094 .42926 .7932 .41302 .7868 .39698 Mtetra
.768 .649 .73 r
.7868 .39698 .7932 .41302 .80548 .3974 .79921 .38268 Mtetra
.771 .664 .744 r
.79921 .38268 .80548 .3974 .8178 .38275 .81168 .36919 Mtetra
.771 .677 .76 r
.81168 .36919 .8178 .38275 .83022 .36928 .82422 .35671 Mtetra
.767 .69 .777 r
.82422 .35671 .83022 .36928 .84274 .35706 .83686 .34531 Mtetra
.761 .7 .795 r
.83686 .34531 .84274 .35706 .85539 .34607 .84962 .33498 Mtetra
.752 .709 .811 r
.84962 .33498 .85539 .34607 .86816 .33619 .86249 .32561 Mtetra
.743 .716 .826 r
.86249 .32561 .86816 .33619 .88105 .32725 .87547 .31707 Mtetra
.623 .739 .93 r
.26667 .48266 .27377 .489 .28448 .48634 .2774 .4801 Mtetra
.618 .741 .934 r
.2774 .4801 .28448 .48634 .29523 .48376 .28816 .47764 Mtetra
.611 .744 .94 r
.28816 .47764 .29523 .48376 .30602 .48126 .29897 .47531 Mtetra
.602 .747 .946 r
.29897 .47531 .30602 .48126 .31687 .47885 .30983 .4731 Mtetra
.592 .752 .954 r
.30983 .4731 .31687 .47885 .32775 .47653 .32072 .47103 Mtetra
.58 .758 .963 r
.32072 .47103 .32775 .47653 .33869 .47431 .33167 .46911 Mtetra
.567 .765 .972 r
.33167 .46911 .33869 .47431 .34968 .47218 .34267 .46731 Mtetra
.552 .774 .981 r
.34267 .46731 .34968 .47218 .36071 .47011 .35371 .46563 Mtetra
.536 .783 .989 r
.35371 .46563 .36071 .47011 .37181 .46809 .36482 .46402 Mtetra
.519 .793 .995 r
.36482 .46402 .37181 .46809 .38295 .46608 .37598 .46243 Mtetra
.503 .804 .999 r
.37598 .46243 .38295 .46608 .39416 .46404 .3872 .46082 Mtetra
.489 .814 1 r
.3872 .46082 .39416 .46404 .40543 .46194 .39849 .45912 Mtetra
.479 .825 .998 r
.39849 .45912 .40543 .46194 .41676 .45974 .40985 .45728 Mtetra
.474 .835 .994 r
.40985 .45728 .41676 .45974 .42815 .45741 .42127 .45524 Mtetra
.474 .845 .989 r
.42127 .45524 .42815 .45741 .4396 .45495 .43277 .45298 Mtetra
.479 .854 .986 r
.43277 .45298 .4396 .45495 .45111 .4524 .44432 .4505 Mtetra
.488 .86 .985 r
.44432 .4505 .45111 .4524 .46268 .44982 .45594 .44784 Mtetra
.499 .863 .987 r
.45594 .44784 .46268 .44982 .47431 .44732 .46762 .44509 Mtetra
.508 .86 .991 r
.46762 .44509 .47431 .44732 .48599 .44505 .47935 .44238 Mtetra
.513 .848 .997 r
.47935 .44238 .48599 .44505 .49774 .44319 .49114 .43987 Mtetra
.512 .826 1 r
.49114 .43987 .49774 .44319 .50954 .44196 .50299 .43776 Mtetra
.503 .79 .997 r
.50299 .43776 .50954 .44196 .52141 .44156 .51491 .43625 Mtetra
.487 .742 .984 r
.51491 .43625 .52141 .44156 .53336 .44219 .52689 .43553 Mtetra
.467 .684 .96 r
.52689 .43553 .53336 .44219 .54541 .44399 .53895 .43575 Mtetra
.448 .624 .927 r
.53895 .43575 .54541 .44399 .55756 .44704 .55111 .437 Mtetra
.434 .568 .889 r
.55111 .437 .55756 .44704 .56983 .45129 .56336 .43928 Mtetra
.428 .521 .851 r
.56336 .43928 .56983 .45129 .58224 .4566 .57574 .44251 Mtetra
.431 .487 .817 r
.57574 .44251 .58224 .4566 .59478 .46271 .58824 .44646 Mtetra
.442 .464 .787 r
.58824 .44646 .59478 .46271 .60747 .46923 .60086 .45084 Mtetra
.459 .452 .763 r
.60086 .45084 .60747 .46923 .6203 .47566 .61361 .45524 Mtetra
.482 .448 .744 r
.61361 .45524 .6203 .47566 .63324 .48147 .62646 .45922 Mtetra
.507 .452 .729 r
.62646 .45922 .63324 .48147 .64626 .48607 .6394 .46228 Mtetra
.535 .459 .718 r
.6394 .46228 .64626 .48607 .65935 .48893 .6524 .46397 Mtetra
.562 .471 .709 r
.6524 .46397 .65935 .48893 .67245 .48959 .66543 .46388 Mtetra
.589 .484 .702 r
.66543 .46388 .67245 .48959 .68552 .48771 .67846 .46171 Mtetra
.616 .5 .698 r
.67846 .46171 .68552 .48771 .69853 .48313 .69144 .4573 Mtetra
.64 .516 .695 r
.69144 .4573 .69853 .48313 .71144 .47589 .70436 .45065 Mtetra
.663 .532 .694 r
.70436 .45065 .71144 .47589 .72424 .46619 .7172 .44192 Mtetra
.684 .549 .695 r
.7172 .44192 .72424 .46619 .73692 .4544 .72995 .43139 Mtetra
.702 .566 .698 r
.72995 .43139 .73692 .4544 .74949 .44103 .74262 .41948 Mtetra
.718 .583 .703 r
.74262 .41948 .74949 .44103 .76197 .42663 .75521 .40664 Mtetra
.731 .599 .71 r
.75521 .40664 .76197 .42663 .7744 .41178 .76777 .39336 Mtetra
.741 .616 .719 r
.76777 .39336 .7744 .41178 .7868 .39698 .7803 .38009 Mtetra
.748 .632 .731 r
.7803 .38009 .7868 .39698 .79921 .38268 .79286 .36719 Mtetra
.752 .648 .745 r
.79286 .36719 .79921 .38268 .81168 .36919 .80547 .35495 Mtetra
.753 .662 .761 r
.80547 .35495 .81168 .36919 .82422 .35671 .81814 .34355 Mtetra
.75 .675 .778 r
.81814 .34355 .82422 .35671 .83686 .34531 .83091 .33304 Mtetra
.746 .687 .795 r
.83091 .33304 .83686 .34531 .84962 .33498 .84377 .32343 Mtetra
.739 .697 .811 r
.84377 .32343 .84962 .33498 .86249 .32561 .85674 .31463 Mtetra
.732 .705 .825 r
.85674 .31463 .86249 .32561 .87547 .31707 .86981 .30653 Mtetra
.617 .738 .933 r
.25952 .47633 .26667 .48266 .2774 .4801 .27026 .47388 Mtetra
.609 .741 .939 r
.27026 .47388 .2774 .4801 .28816 .47764 .28103 .47158 Mtetra
.599 .744 .946 r
.28103 .47158 .28816 .47764 .29897 .47531 .29185 .46945 Mtetra
.586 .748 .954 r
.29185 .46945 .29897 .47531 .30983 .4731 .30271 .4675 Mtetra
.571 .753 .963 r
.30271 .4675 .30983 .4731 .32072 .47103 .31362 .46575 Mtetra
.553 .759 .973 r
.31362 .46575 .32072 .47103 .33167 .46911 .32457 .4642 Mtetra
.531 .765 .983 r
.32457 .4642 .33167 .46911 .34267 .46731 .33557 .46283 Mtetra
.506 .773 .992 r
.33557 .46283 .34267 .46731 .35371 .46563 .34662 .46161 Mtetra
.477 .78 .997 r
.34662 .46161 .35371 .46563 .36482 .46402 .35773 .46051 Mtetra
.447 .787 .998 r
.35773 .46051 .36482 .46402 .37598 .46243 .3689 .45945 Mtetra
.418 .792 .993 r
.3689 .45945 .37598 .46243 .3872 .46082 .38014 .45836 Mtetra
.392 .797 .983 r
.38014 .45836 .3872 .46082 .39849 .45912 .39145 .45716 Mtetra
.374 .802 .968 r
.39145 .45716 .39849 .45912 .40985 .45728 .40283 .45576 Mtetra
.365 .809 .952 r
.40283 .45576 .40985 .45728 .42127 .45524 .41429 .45409 Mtetra
.368 .819 .94 r
.41429 .45409 .42127 .45524 .43277 .45298 .42582 .45208 Mtetra
.382 .831 .933 r
.42582 .45208 .43277 .45298 .44432 .4505 .43742 .44971 Mtetra
.406 .846 .934 r
.43742 .44971 .44432 .4505 .45594 .44784 .44909 .44701 Mtetra
.436 .861 .942 r
.44909 .44701 .45594 .44784 .46762 .44509 .46083 .44402 Mtetra
.469 .873 .957 r
.46083 .44402 .46762 .44509 .47935 .44238 .47262 .44085 Mtetra
.5 .877 .975 r
.47262 .44085 .47935 .44238 .49114 .43987 .48447 .43766 Mtetra
.525 .869 .99 r
.48447 .43766 .49114 .43987 .50299 .43776 .49638 .43463 Mtetra
.54 .846 .999 r
.49638 .43463 .50299 .43776 .51491 .43625 .50834 .43196 Mtetra
.543 .805 .994 r
.50834 .43196 .51491 .43625 .52689 .43553 .52036 .42983 Mtetra
.537 .751 .975 r
.52036 .42983 .52689 .43553 .53895 .43575 .53245 .42842 Mtetra
.524 .69 .944 r
.53245 .42842 .53895 .43575 .55111 .437 .54462 .42782 Mtetra
.51 .63 .905 r
.54462 .42782 .55111 .437 .56336 .43928 .55687 .42809 Mtetra
.499 .578 .866 r
.55687 .42809 .56336 .43928 .57574 .44251 .56923 .42917 Mtetra
.495 .536 .829 r
.56923 .42917 .57574 .44251 .58824 .44646 .58169 .43092 Mtetra
.497 .506 .797 r
.58169 .43092 .58824 .44646 .60086 .45084 .59425 .43312 Mtetra
.505 .486 .77 r
.59425 .43312 .60086 .45084 .61361 .45524 .60693 .43545 Mtetra
.517 .475 .749 r
.60693 .43545 .61361 .45524 .62646 .45922 .6197 .43755 Mtetra
.534 .472 .732 r
.6197 .43755 .62646 .45922 .6394 .46228 .63256 .43901 Mtetra
.553 .473 .72 r
.63256 .43901 .6394 .46228 .6524 .46397 .64549 .43945 Mtetra
.573 .479 .71 r
.64549 .43945 .6524 .46397 .66543 .46388 .65845 .43854 Mtetra
.594 .489 .704 r
.65845 .43854 .66543 .46388 .67846 .46171 .67142 .43599 Mtetra
.615 .5 .699 r
.67142 .43599 .67846 .46171 .69144 .4573 .68438 .43166 Mtetra
.635 .513 .697 r
.68438 .43166 .69144 .4573 .70436 .45065 .6973 .42552 Mtetra
.654 .527 .697 r
.6973 .42552 .70436 .45065 .7172 .44192 .71017 .41767 Mtetra
.672 .542 .698 r
.71017 .41767 .7172 .44192 .72995 .43139 .72298 .40833 Mtetra
.689 .558 .701 r
.72298 .40833 .72995 .43139 .74262 .41948 .73573 .39781 Mtetra
.703 .574 .707 r
.73573 .39781 .74262 .41948 .75521 .40664 .74844 .38649 Mtetra
.715 .59 .714 r
.74844 .38649 .75521 .40664 .76777 .39336 .76111 .37476 Mtetra
.725 .606 .724 r
.76111 .37476 .76777 .39336 .7803 .38009 .77378 .36298 Mtetra
.732 .623 .736 r
.77378 .36298 .7803 .38009 .79286 .36719 .78647 .35147 Mtetra
.736 .638 .75 r
.78647 .35147 .79286 .36719 .80547 .35495 .79921 .34048 Mtetra
.738 .653 .766 r
.79921 .34048 .80547 .35495 .81814 .34355 .81201 .33014 Mtetra
.736 .667 .782 r
.81201 .33014 .81814 .34355 .83091 .33304 .8249 .32053 Mtetra
.733 .679 .798 r
.8249 .32053 .83091 .33304 .84377 .32343 .83787 .31164 Mtetra
.728 .689 .813 r
.83787 .31164 .84377 .32343 .85674 .31463 .85094 .30341 Mtetra
.722 .697 .826 r
.85094 .30341 .85674 .31463 .86981 .30653 .8641 .29574 Mtetra
.609 .738 .937 r
.2523 .47 .25952 .47633 .27026 .47388 .26305 .4677 Mtetra
.597 .74 .944 r
.26305 .4677 .27026 .47388 .28103 .47158 .27384 .4656 Mtetra
.583 .743 .952 r
.27384 .4656 .28103 .47158 .29185 .46945 .28466 .46373 Mtetra
.565 .747 .962 r
.28466 .46373 .29185 .46945 .30271 .4675 .29553 .4621 Mtetra
.542 .751 .973 r
.29553 .4621 .30271 .4675 .31362 .46575 .30643 .46074 Mtetra
.514 .756 .984 r
.30643 .46074 .31362 .46575 .32457 .4642 .31738 .45963 Mtetra
.479 .76 .992 r
.31738 .45963 .32457 .4642 .33557 .46283 .32838 .45878 Mtetra
.438 .762 .996 r
.32838 .45878 .33557 .46283 .34662 .46161 .33943 .45813 Mtetra
.39 .762 .992 r
.33943 .45813 .34662 .46161 .35773 .46051 .35054 .45764 Mtetra
.339 .757 .977 r
.35054 .45764 .35773 .46051 .3689 .45945 .36171 .45721 Mtetra
.29 .749 .952 r
.36171 .45721 .3689 .45945 .38014 .45836 .37296 .45675 Mtetra
.248 .739 .918 r
.37296 .45675 .38014 .45836 .39145 .45716 .38429 .45615 Mtetra
.22 .732 .882 r
.38429 .45615 .39145 .45716 .40283 .45576 .39569 .45529 Mtetra
.209 .731 .85 r
.39569 .45529 .40283 .45576 .41429 .45409 .40718 .45405 Mtetra
.218 .741 .829 r
.40718 .45405 .41429 .45409 .42582 .45208 .41876 .45236 Mtetra
.246 .76 .822 r
.41876 .45236 .42582 .45208 .43742 .44971 .43041 .45015 Mtetra
.289 .789 .831 r
.43041 .45015 .43742 .44971 .44909 .44701 .44213 .44742 Mtetra
.344 .823 .852 r
.44213 .44742 .44909 .44701 .46083 .44402 .45393 .4442 Mtetra
.406 .857 .885 r
.45393 .4442 .46083 .44402 .47262 .44085 .46579 .44058 Mtetra
.469 .886 .923 r
.46579 .44058 .47262 .44085 .48447 .43766 .47771 .43669 Mtetra
.524 .901 .958 r
.47771 .43669 .48447 .43766 .49638 .43463 .48968 .43272 Mtetra
.567 .896 .984 r
.48968 .43272 .49638 .43463 .50834 .43196 .5017 .42887 Mtetra
.592 .868 .994 r
.5017 .42887 .50834 .43196 .52036 .42983 .51377 .42532 Mtetra
.6 .82 .984 r
.51377 .42532 .52036 .42983 .53245 .42842 .5259 .42226 Mtetra
.594 .76 .958 r
.5259 .42226 .53245 .42842 .54462 .42782 .53809 .41982 Mtetra
.58 .697 .922 r
.53809 .41982 .54462 .42782 .55687 .42809 .55036 .41808 Mtetra
.566 .639 .882 r
.55036 .41808 .55687 .42809 .56923 .42917 .5627 .41705 Mtetra
.554 .59 .844 r
.5627 .41705 .56923 .42917 .58169 .43092 .57513 .41665 Mtetra
.548 .552 .811 r
.57513 .41665 .58169 .43092 .59425 .43312 .58766 .4167 Mtetra
.547 .525 .783 r
.58766 .4167 .59425 .43312 .60693 .43545 .60028 .417 Mtetra
.551 .507 .76 r
.60028 .417 .60693 .43545 .6197 .43755 .61299 .41724 Mtetra
.559 .497 .742 r
.61299 .41724 .6197 .43755 .63256 .43901 .62578 .41712 Mtetra
.571 .493 .729 r
.62578 .41712 .63256 .43901 .64549 .43945 .63863 .41632 Mtetra
.585 .494 .718 r
.63863 .41632 .64549 .43945 .65845 .43854 .65153 .41455 Mtetra
.6 .499 .711 r
.65153 .41455 .65845 .43854 .67142 .43599 .66446 .41157 Mtetra
.616 .507 .707 r
.66446 .41157 .67142 .43599 .68438 .43166 .6774 .40725 Mtetra
.633 .517 .704 r
.6774 .40725 .68438 .43166 .6973 .42552 .69032 .40152 Mtetra
.649 .53 .704 r
.69032 .40152 .6973 .42552 .71017 .41767 .70321 .39443 Mtetra
.665 .543 .706 r
.70321 .39443 .71017 .41767 .72298 .40833 .71607 .38615 Mtetra
.68 .557 .71 r
.71607 .38615 .72298 .40833 .73573 .39781 .7289 .3769 Mtetra
.693 .573 .716 r
.7289 .3769 .73573 .39781 .74844 .38649 .7417 .36696 Mtetra
.704 .589 .724 r
.7417 .36696 .74844 .38649 .76111 .37476 .75448 .35665 Mtetra
.713 .605 .734 r
.75448 .35665 .76111 .37476 .77378 .36298 .76727 .34625 Mtetra
.72 .62 .746 r
.76727 .34625 .77378 .36298 .78647 .35147 .78009 .33603 Mtetra
.724 .636 .759 r
.78009 .33603 .78647 .35147 .79921 .34048 .79295 .32618 Mtetra
.726 .651 .774 r
.79295 .32618 .79921 .34048 .81201 .33014 .80587 .31683 Mtetra
.725 .664 .789 r
.80587 .31683 .81201 .33014 .8249 .32053 .81886 .30804 Mtetra
.722 .676 .804 r
.81886 .30804 .8249 .32053 .83787 .31164 .83194 .29982 Mtetra
.718 .686 .818 r
.83194 .29982 .83787 .31164 .85094 .30341 .8451 .29211 Mtetra
.714 .694 .83 r
.8451 .29211 .85094 .30341 .8641 .29574 .85834 .28484 Mtetra
.598 .737 .941 r
.24502 .46368 .2523 .47 .26305 .4677 .25578 .46157 Mtetra
.583 .739 .95 r
.25578 .46157 .26305 .4677 .27384 .4656 .26657 .45972 Mtetra
.563 .741 .96 r
.26657 .45972 .27384 .4656 .28466 .46373 .2774 .45815 Mtetra
.537 .744 .971 r
.2774 .45815 .28466 .46373 .29553 .4621 .28826 .45691 Mtetra
.503 .746 .982 r
.28826 .45691 .29553 .4621 .30643 .46074 .29916 .45601 Mtetra
.46 .747 .991 r
.29916 .45601 .30643 .46074 .31738 .45963 .3101 .45544 Mtetra
.405 .744 .993 r
.3101 .45544 .31738 .45963 .32838 .45878 .32108 .4552 Mtetra
.34 .734 .984 r
.32108 .4552 .32838 .45878 .33943 .45813 .33213 .45522 Mtetra
.264 .715 .957 r
.33213 .45522 .33943 .45813 .35054 .45764 .34323 .45544 Mtetra
.187 .687 .912 r
.34323 .45544 .35054 .45764 .36171 .45721 .35441 .45576 Mtetra
.117 .655 .852 r
.35441 .45576 .36171 .45721 .37296 .45675 .36566 .45603 Mtetra
.063 .624 .788 r
.36566 .45603 .37296 .45675 .38429 .45615 .377 .45612 Mtetra
.033 .604 .73 r
.377 .45612 .38429 .45615 .39569 .45529 .38843 .45588 Mtetra
0 0 0 r
.38843 .45588 .39569 .45529 .40718 .45405 .39995 .45517 Mtetra
.39995 .45517 .40718 .45405 .41876 .45236 .41156 .45385 Mtetra
.41156 .45385 .41876 .45236 .43041 .45015 .42326 .45185 Mtetra
.42326 .45185 .43041 .45015 .44213 .44742 .43505 .44912 Mtetra
.235 .746 .723 r
.43505 .44912 .44213 .44742 .45393 .4442 .44691 .44568 Mtetra
.325 .808 .777 r
.44691 .44568 .45393 .4442 .46579 .44058 .45885 .4416 Mtetra
.42 .866 .839 r
.45885 .4416 .46579 .44058 .47771 .43669 .47084 .43702 Mtetra
.508 .91 .899 r
.47084 .43702 .47771 .43669 .48968 .43272 .48288 .4321 Mtetra
.581 .93 .948 r
.48288 .4321 .48968 .43272 .5017 .42887 .49497 .42706 Mtetra
.631 .921 .977 r
.49497 .42706 .5017 .42887 .51377 .42532 .50711 .4221 Mtetra
.655 .884 .982 r
.50711 .4221 .51377 .42532 .5259 .42226 .51929 .41742 Mtetra
.657 .828 .965 r
.51929 .41742 .5259 .42226 .53809 .41982 .53152 .41319 Mtetra
.646 .765 .935 r
.53152 .41319 .53809 .41982 .55036 .41808 .54381 .40951 Mtetra
.629 .703 .899 r
.54381 .40951 .55036 .41808 .5627 .41705 .55616 .40645 Mtetra
.611 .649 .863 r
.55616 .40645 .5627 .41705 .57513 .41665 .56858 .40398 Mtetra
.597 .604 .829 r
.56858 .40398 .57513 .41665 .58766 .4167 .58108 .402 Mtetra
.589 .57 .8 r
.58108 .402 .58766 .4167 .60028 .417 .59366 .40036 Mtetra
.585 .545 .777 r
.59366 .40036 .60028 .417 .61299 .41724 .60632 .39886 Mtetra
.586 .529 .758 r
.60632 .39886 .61299 .41724 .62578 .41712 .61905 .39724 Mtetra
.591 .52 .743 r
.61905 .39724 .62578 .41712 .63863 .41632 .63185 .39525 Mtetra
.599 .516 .732 r
.63185 .39525 .63863 .41632 .65153 .41455 .64471 .39265 Mtetra
.609 .517 .725 r
.64471 .39265 .65153 .41455 .66446 .41157 .6576 .38923 Mtetra
.621 .522 .72 r
.6576 .38923 .66446 .41157 .6774 .40725 .67051 .38486 Mtetra
.634 .529 .718 r
.67051 .38486 .6774 .40725 .69032 .40152 .68343 .37945 Mtetra
.648 .539 .718 r
.68343 .37945 .69032 .40152 .70321 .39443 .69635 .37301 Mtetra
.661 .552 .72 r
.69635 .37301 .70321 .39443 .71607 .38615 .70926 .36564 Mtetra
.674 .565 .724 r
.70926 .36564 .71607 .38615 .7289 .3769 .72215 .35748 Mtetra
.686 .58 .73 r
.72215 .35748 .7289 .3769 .7417 .36696 .73504 .34874 Mtetra
.697 .595 .738 r
.73504 .34874 .7417 .36696 .75448 .35665 .74792 .33966 Mtetra
.706 .611 .749 r
.74792 .33966 .75448 .35665 .76727 .34625 .76082 .33045 Mtetra
.712 .627 .76 r
.76082 .33045 .76727 .34625 .78009 .33603 .77375 .32133 Mtetra
.716 .641 .773 r
.77375 .32133 .78009 .33603 .79295 .32618 .78671 .31246 Mtetra
.718 .655 .787 r
.78671 .31246 .79295 .32618 .80587 .31683 .79974 .30395 Mtetra
.717 .668 .8 r
.79974 .30395 .80587 .31683 .81886 .30804 .81283 .29586 Mtetra
.715 .678 .813 r
.81283 .29586 .81886 .30804 .83194 .29982 .82599 .28819 Mtetra
.712 .687 .825 r
.82599 .28819 .83194 .29982 .8451 .29211 .83924 .28091 Mtetra
.708 .695 .835 r
.83924 .28091 .8451 .29211 .85834 .28484 .85255 .27398 Mtetra
.585 .735 .946 r
.23768 .4574 .24502 .46368 .25578 .46157 .24844 .45551 Mtetra
.565 .737 .957 r
.24844 .45551 .25578 .46157 .26657 .45972 .25923 .45394 Mtetra
.537 .738 .968 r
.25923 .45394 .26657 .45972 .2774 .45815 .27005 .45274 Mtetra
.5 .738 .979 r
.27005 .45274 .2774 .45815 .28826 .45691 .2809 .45195 Mtetra
.451 .735 .988 r
.2809 .45195 .28826 .45691 .29916 .45601 .29179 .45158 Mtetra
.386 .727 .99 r
.29179 .45158 .29916 .45601 .3101 .45544 .30272 .45164 Mtetra
.304 .708 .977 r
.30272 .45164 .3101 .45544 .32108 .4552 .31369 .4521 Mtetra
.207 .675 .94 r
.31369 .4521 .32108 .4552 .33213 .45522 .32472 .45289 Mtetra
.102 .627 .876 r
.32472 .45289 .33213 .45522 .34323 .45544 .33581 .45393 Mtetra
.003 .569 .79 r
.33581 .45393 .34323 .45544 .35441 .45576 .34697 .45508 Mtetra
.075 0 0 r
.34697 .45508 .35441 .45576 .36566 .45603 .35823 .45619 Mtetra
.125 0 0 r
.35823 .45619 .36566 .45603 .377 .45612 .36957 .45708 Mtetra
.145 0 0 r
.36957 .45708 .377 .45612 .38843 .45588 .38102 .45754 Mtetra
.137 0 0 r
.38102 .45754 .38843 .45588 .39995 .45517 .39257 .45742 Mtetra
.103 0 0 r
.39257 .45742 .39995 .45517 .41156 .45385 .40423 .45653 Mtetra
.046 0 0 r
.40423 .45653 .41156 .45385 .42326 .45185 .41598 .45477 Mtetra
0 0 0 r
.41598 .45477 .42326 .45185 .43505 .44912 .42783 .45206 Mtetra
.42783 .45206 .43505 .44912 .44691 .44568 .43977 .44841 Mtetra
.43977 .44841 .44691 .44568 .45885 .4416 .45178 .44389 Mtetra
.366 .826 .739 r
.45178 .44389 .45885 .4416 .47084 .43702 .46386 .43861 Mtetra
.484 .898 .822 r
.46386 .43861 .47084 .43702 .48288 .4321 .47598 .43275 Mtetra
.585 .945 .893 r
.47598 .43275 .48288 .4321 .49497 .42706 .48815 .42654 Mtetra
.658 .957 .942 r
.48815 .42654 .49497 .42706 .50711 .4221 .50036 .4202 Mtetra
.699 .936 .964 r
.50036 .4202 .50711 .4221 .51929 .41742 .5126 .41395 Mtetra
.713 .89 .961 r
.5126 .41395 .51929 .41742 .53152 .41319 .52489 .40799 Mtetra
.706 .83 .942 r
.52489 .40799 .53152 .41319 .54381 .40951 .53721 .40247 Mtetra
.688 .768 .913 r
.53721 .40247 .54381 .40951 .55616 .40645 .54958 .3975 Mtetra
.667 .71 .881 r
.54958 .3975 .55616 .40645 .56858 .40398 .56201 .3931 Mtetra
.647 .661 .849 r
.56201 .3931 .56858 .40398 .58108 .402 .5745 .38924 Mtetra
.631 .621 .822 r
.5745 .38924 .58108 .402 .59366 .40036 .58706 .38583 Mtetra
.62 .59 .798 r
.58706 .38583 .59366 .40036 .60632 .39886 .59969 .38272 Mtetra
.614 .568 .779 r
.59969 .38272 .60632 .39886 .61905 .39724 .61239 .37974 Mtetra
.612 .553 .764 r
.61239 .37974 .61905 .39724 .63185 .39525 .62515 .37667 Mtetra
.614 .545 .753 r
.62515 .37667 .63185 .39525 .64471 .39265 .63797 .37332 Mtetra
.62 .542 .745 r
.63797 .37332 .64471 .39265 .6576 .38923 .65084 .3695 Mtetra
.628 .544 .74 r
.65084 .3695 .6576 .38923 .67051 .38486 .66375 .36506 Mtetra
.638 .549 .738 r
.66375 .36506 .67051 .38486 .68343 .37945 .67668 .35992 Mtetra
.649 .558 .738 r
.67668 .35992 .68343 .37945 .69635 .37301 .68962 .35402 Mtetra
.661 .569 .741 r
.68962 .35402 .69635 .37301 .70926 .36564 .70257 .3474 Mtetra
.673 .582 .745 r
.70257 .3474 .70926 .36564 .72215 .35748 .71553 .34015 Mtetra
.684 .597 .752 r
.71553 .34015 .72215 .35748 .73504 .34874 .72849 .3324 Mtetra
.695 .612 .76 r
.72849 .3324 .73504 .34874 .74792 .33966 .74146 .32431 Mtetra
.703 .627 .77 r
.74146 .32431 .74792 .33966 .76082 .33045 .75445 .31606 Mtetra
.709 .642 .781 r
.75445 .31606 .76082 .33045 .77375 .32133 .76747 .30781 Mtetra
.713 .656 .792 r
.76747 .30781 .77375 .32133 .78671 .31246 .78053 .2997 Mtetra
.714 .669 .804 r
.78053 .2997 .78671 .31246 .79974 .30395 .79364 .29182 Mtetra
.714 .68 .815 r
.79364 .29182 .79974 .30395 .81283 .29586 .80682 .28424 Mtetra
.711 .688 .826 r
.80682 .28424 .81283 .29586 .82599 .28819 .82006 .27697 Mtetra
.708 .695 .835 r
.82006 .27697 .82599 .28819 .83924 .28091 .83337 .26999 Mtetra
.705 .7 .843 r
.83337 .26999 .83924 .28091 .85255 .27398 .84675 .26329 Mtetra
.57 .733 .952 r
.23027 .45114 .23768 .4574 .24844 .45551 .24103 .44951 Mtetra
.542 .733 .963 r
.24103 .44951 .24844 .45551 .25923 .45394 .25182 .44827 Mtetra
.504 .731 .975 r
.25182 .44827 .25923 .45394 .27005 .45274 .26263 .44749 Mtetra
.452 .726 .985 r
.26263 .44749 .27005 .45274 .2809 .45195 .27346 .44721 Mtetra
.383 .714 .987 r
.27346 .44721 .2809 .45195 .29179 .45158 .28433 .44745 Mtetra
.29 .69 .974 r
.28433 .44745 .29179 .45158 .30272 .45164 .29523 .44821 Mtetra
.175 .646 .933 r
.29523 .44821 .30272 .45164 .31369 .4521 .30618 .44945 Mtetra
.046 .581 .856 r
.30618 .44945 .31369 .4521 .32472 .45289 .31719 .45111 Mtetra
0 .501 .749 r
.31719 .45111 .32472 .45289 .33581 .45393 .32826 .45306 Mtetra
.18 0 0 r
.32826 .45306 .33581 .45393 .34697 .45508 .33941 .45515 Mtetra
.247 0 0 r
.33941 .45515 .34697 .45508 .35823 .45619 .35066 .45718 Mtetra
.281 0 0 r
.35066 .45718 .35823 .45619 .36957 .45708 .36201 .45893 Mtetra
.285 0 0 r
.36201 .45893 .36957 .45708 .38102 .45754 .37347 .46017 Mtetra
.264 0 0 r
.37347 .46017 .38102 .45754 .39257 .45742 .38505 .46069 Mtetra
.219 0 0 r
.38505 .46069 .39257 .45742 .40423 .45653 .39675 .46028 Mtetra
.151 0 0 r
.39675 .46028 .40423 .45653 .41598 .45477 .40856 .45879 Mtetra
.061 0 0 r
.40856 .45879 .41598 .45477 .42783 .45206 .42048 .45613 Mtetra
0 0 0 r
.42048 .45613 .42783 .45206 .43977 .44841 .4325 .45228 Mtetra
.4325 .45228 .43977 .44841 .45178 .44389 .44459 .4473 Mtetra
.324 .783 .648 r
.44459 .4473 .45178 .44389 .46386 .43861 .45676 .44133 Mtetra
.463 .877 .746 r
.45676 .44133 .46386 .43861 .47598 .43275 .46897 .43454 Mtetra
.585 .944 .832 r
.46897 .43454 .47598 .43275 .48815 .42654 .48123 .42718 Mtetra
.677 .975 .895 r
.48123 .42718 .48815 .42654 .50036 .4202 .49352 .4195 Mtetra
.733 .97 .932 r
.49352 .4195 .50036 .4202 .5126 .41395 .50584 .41175 Mtetra
.757 .937 .944 r
.50584 .41175 .5126 .41395 .52489 .40799 .51819 .40415 Mtetra
.756 .886 .937 r
.51819 .40415 .52489 .40799 .53721 .40247 .53056 .39692 Mtetra
.741 .828 .919 r
.53056 .39692 .53721 .40247 .54958 .3975 .54297 .39018 Mtetra
.718 .771 .894 r
.54297 .39018 .54958 .3975 .56201 .3931 .55542 .38402 Mtetra
.695 .72 .869 r
.55542 .38402 .56201 .3931 .5745 .38924 .56792 .37846 Mtetra
.673 .676 .844 r
.56792 .37846 .5745 .38924 .58706 .38583 .58048 .37347 Mtetra
.656 .64 .823 r
.58048 .37347 .58706 .38583 .59969 .38272 .59309 .36895 Mtetra
.643 .613 .805 r
.59309 .36895 .59969 .38272 .61239 .37974 .60577 .36478 Mtetra
.635 .594 .791 r
.60577 .36478 .61239 .37974 .62515 .37667 .61852 .36079 Mtetra
.632 .582 .78 r
.61852 .36079 .62515 .37667 .63797 .37332 .63133 .35682 Mtetra
.633 .576 .773 r
.63133 .35682 .63797 .37332 .65084 .3695 .64419 .35268 Mtetra
.637 .575 .769 r
.64419 .35268 .65084 .3695 .66375 .36506 .6571 .34822 Mtetra
.644 .579 .767 r
.6571 .34822 .66375 .36506 .67668 .35992 .67004 .34332 Mtetra
.653 .587 .768 r
.67004 .34332 .67668 .35992 .68962 .35402 .68302 .3379 Mtetra
.664 .598 .771 r
.68302 .3379 .68962 .35402 .70257 .3474 .69602 .33191 Mtetra
.676 .612 .776 r
.69602 .33191 .70257 .3474 .71553 .34015 .70904 .3254 Mtetra
.687 .627 .783 r
.70904 .3254 .71553 .34015 .72849 .3324 .72207 .31842 Mtetra
.697 .642 .791 r
.72207 .31842 .72849 .3324 .74146 .32431 .73512 .31109 Mtetra
.706 .657 .799 r
.73512 .31109 .74146 .32431 .75445 .31606 .74819 .30353 Mtetra
.712 .672 .809 r
.74819 .30353 .75445 .31606 .76747 .30781 .76129 .29588 Mtetra
.716 .684 .818 r
.76129 .29588 .76747 .30781 .78053 .2997 .77442 .28826 Mtetra
.717 .694 .827 r
.77442 .28826 .78053 .2997 .79364 .29182 .78761 .28076 Mtetra
.716 .701 .835 r
.78761 .28076 .79364 .29182 .80682 .28424 .80085 .27346 Mtetra
.713 .707 .842 r
.80085 .27346 .80682 .28424 .82006 .27697 .81415 .26638 Mtetra
.709 .71 .848 r
.81415 .26638 .82006 .27697 .83337 .26999 .82752 .25954 Mtetra
.706 .712 .853 r
.82752 .25954 .83337 .26999 .84675 .26329 .84095 .25292 Mtetra
.551 .729 .958 r
.2228 .44491 .23027 .45114 .24103 .44951 .23355 .44357 Mtetra
.515 .727 .969 r
.23355 .44357 .24103 .44951 .25182 .44827 .24433 .4427 Mtetra
.464 .721 .98 r
.24433 .4427 .25182 .44827 .26263 .44749 .25512 .44239 Mtetra
.394 .707 .985 r
.25512 .44239 .26263 .44749 .27346 .44721 .26593 .44267 Mtetra
.298 .68 .975 r
.26593 .44267 .27346 .44721 .28433 .44745 .27677 .44358 Mtetra
.173 .632 .936 r
.27677 .44358 .28433 .44745 .29523 .44821 .28765 .44511 Mtetra
.026 .556 .856 r
.28765 .44511 .29523 .44821 .30618 .44945 .29857 .44722 Mtetra
0 .459 .737 r
.29857 .44722 .30618 .44945 .31719 .45111 .30954 .44981 Mtetra
.245 0 0 r
.30954 .44981 .31719 .45111 .32826 .45306 .32059 .45274 Mtetra
.33 0 0 r
.32059 .45274 .32826 .45306 .33941 .45515 .33172 .45583 Mtetra
.378 0 0 r
.33172 .45583 .33941 .45515 .35066 .45718 .34295 .45885 Mtetra
.394 0 0 r
.34295 .45885 .35066 .45718 .36201 .45893 .3543 .46153 Mtetra
.385 0 0 r
.3543 .46153 .36201 .45893 .37347 .46017 .36577 .4636 Mtetra
.352 0 0 r
.36577 .4636 .37347 .46017 .38505 .46069 .37738 .4648 Mtetra
.299 0 0 r
.37738 .4648 .38505 .46069 .39675 .46028 .38912 .46489 Mtetra
.222 0 0 r
.38912 .46489 .39675 .46028 .40856 .45879 .40099 .46368 Mtetra
.122 0 0 r
.40099 .46368 .40856 .45879 .42048 .45613 .41299 .46107 Mtetra
0 0 0 r
.41299 .46107 .42048 .45613 .4325 .45228 .42509 .45703 Mtetra
.42509 .45703 .4325 .45228 .44459 .4473 .43727 .45161 Mtetra
.43727 .45161 .44459 .4473 .45676 .44133 .44954 .44494 Mtetra
.461 .864 .691 r
.44954 .44494 .45676 .44133 .46897 .43454 .46185 .43725 Mtetra
.595 .942 .782 r
.46185 .43725 .46897 .43454 .48123 .42718 .47421 .42877 Mtetra
.696 .983 .851 r
.47421 .42877 .48123 .42718 .49352 .4195 .48659 .4198 Mtetra
.76 .988 .895 r
.48659 .4198 .49352 .4195 .50584 .41175 .49899 .41063 Mtetra
.791 .966 .917 r
.49899 .41063 .50584 .41175 .51819 .40415 .51141 .40151 Mtetra
.797 .926 .921 r
.51141 .40151 .51819 .40415 .53056 .39692 .52385 .39269 Mtetra
.785 .877 .915 r
.52385 .39269 .53056 .39692 .54297 .39018 .53631 .38435 Mtetra
.764 .826 .901 r
.53631 .38435 .54297 .39018 .55542 .38402 .5488 .37661 Mtetra
.739 .777 .884 r
.5488 .37661 .55542 .38402 .56792 .37846 .56132 .36956 Mtetra
.713 .733 .866 r
.56132 .36956 .56792 .37846 .58048 .37347 .57389 .36321 Mtetra
.691 .695 .849 r
.57389 .36321 .58048 .37347 .59309 .36895 .58651 .3575 Mtetra
.672 .665 .835 r
.58651 .3575 .59309 .36895 .60577 .36478 .5992 .35236 Mtetra
.658 .643 .824 r
.5992 .35236 .60577 .36478 .61852 .36079 .61194 .34766 Mtetra
.649 .628 .815 r
.61194 .34766 .61852 .36079 .63133 .35682 .62475 .34324 Mtetra
.645 .62 .81 r
.62475 .34324 .63133 .35682 .64419 .35268 .63763 .33893 Mtetra
.646 .618 .808 r
.63763 .33893 .64419 .35268 .6571 .34822 .65056 .33455 Mtetra
.65 .622 .808 r
.65056 .33455 .6571 .34822 .67004 .34332 .66354 .32994 Mtetra
.658 .631 .811 r
.66354 .32994 .67004 .34332 .68302 .3379 .67656 .32496 Mtetra
.669 .644 .816 r
.67656 .32496 .68302 .3379 .69602 .33191 .68961 .31954 Mtetra
.682 .659 .822 r
.68961 .31954 .69602 .33191 .70904 .3254 .70269 .31362 Mtetra
.694 .676 .828 r
.70269 .31362 .70904 .3254 .72207 .31842 .71579 .30722 Mtetra
.706 .692 .835 r
.71579 .30722 .72207 .31842 .73512 .31109 .72891 .30041 Mtetra
.715 .707 .841 r
.72891 .30041 .73512 .31109 .74819 .30353 .74205 .29327 Mtetra
.722 .719 .847 r
.74205 .29327 .74819 .30353 .76129 .29588 .75522 .28593 Mtetra
.726 .728 .852 r
.75522 .28593 .76129 .29588 .77442 .28826 .76842 .2785 Mtetra
.727 .734 .856 r
.76842 .2785 .77442 .28826 .78761 .28076 .78165 .2711 Mtetra
.725 .736 .86 r
.78165 .2711 .78761 .28076 .80085 .27346 .79494 .26381 Mtetra
.721 .736 .863 r
.79494 .26381 .80085 .27346 .81415 .26638 .80829 .25669 Mtetra
.716 .734 .865 r
.80829 .25669 .81415 .26638 .82752 .25954 .82169 .24976 Mtetra
.711 .731 .866 r
.82169 .24976 .82752 .25954 .84095 .25292 .83517 .24304 Mtetra
.53 .724 .963 r
.21525 .4387 .2228 .44491 .23355 .44357 .226 .43767 Mtetra
.483 .717 .974 r
.226 .43767 .23355 .44357 .24433 .4427 .23676 .43721 Mtetra
.416 .705 .982 r
.23676 .43721 .24433 .4427 .25512 .44239 .24753 .4374 Mtetra
.324 .679 .978 r
.24753 .4374 .25512 .44239 .26593 .44267 .25832 .43829 Mtetra
.199 .631 .948 r
.25832 .43829 .26593 .44267 .27677 .44358 .26913 .43992 Mtetra
.043 .553 .876 r
.26913 .43992 .27677 .44358 .28765 .44511 .27996 .44226 Mtetra
0 .447 .756 r
.27996 .44226 .28765 .44511 .29857 .44722 .29084 .44528 Mtetra
.269 0 0 r
.29084 .44528 .29857 .44722 .30954 .44981 .30178 .44886 Mtetra
.376 0 0 r
.30178 .44886 .30954 .44981 .32059 .45274 .31279 .45283 Mtetra
.441 0 0 r
.31279 .45283 .32059 .45274 .33172 .45583 .3239 .45697 Mtetra
.47 0 0 r
.3239 .45697 .33172 .45583 .34295 .45885 .33511 .46101 Mtetra
.472 0 0 r
.33511 .46101 .34295 .45885 .3543 .46153 .34646 .46465 Mtetra
.453 0 0 r
.34646 .46465 .3543 .46153 .36577 .4636 .35794 .46757 Mtetra
.412 0 0 r
.35794 .46757 .36577 .4636 .37738 .4648 .36957 .46946 Mtetra
.351 0 0 r
.36957 .46946 .37738 .4648 .38912 .46489 .38136 .47005 Mtetra
.266 0 0 r
.38136 .47005 .38912 .46489 .40099 .46368 .39329 .46913 Mtetra
.155 0 0 r
.39329 .46913 .40099 .46368 .41299 .46107 .40536 .46657 Mtetra
.016 0 0 r
.40536 .46657 .41299 .46107 .42509 .45703 .41754 .46232 Mtetra
0 0 0 r
.41754 .46232 .42509 .45703 .43727 .45161 .42983 .45646 Mtetra
.42983 .45646 .43727 .45161 .44954 .44494 .44219 .44912 Mtetra
.485 .869 .669 r
.44219 .44912 .44954 .44494 .46185 .43725 .45461 .44054 Mtetra
.623 .948 .756 r
.45461 .44054 .46185 .43725 .47421 .42877 .46707 .431 Mtetra
.724 .988 .821 r
.46707 .431 .47421 .42877 .48659 .4198 .47955 .42081 Mtetra
.787 .996 .863 r
.47955 .42081 .48659 .4198 .49899 .41063 .49205 .4103 Mtetra
.819 .981 .888 r
.49205 .4103 .49899 .41063 .51141 .40151 .50455 .39978 Mtetra
.827 .951 .9 r
.50455 .39978 .51141 .40151 .52385 .39269 .51706 .38952 Mtetra
.819 .912 .902 r
.51706 .38952 .52385 .39269 .53631 .38435 .52958 .37975 Mtetra
.8 .869 .899 r
.52958 .37975 .53631 .38435 .5488 .37661 .54212 .37064 Mtetra
.775 .826 .892 r
.54212 .37064 .5488 .37661 .56132 .36956 .55468 .36232 Mtetra
.749 .786 .884 r
.55468 .36232 .56132 .36956 .57389 .36321 .56728 .35484 Mtetra
.722 .751 .875 r
.56728 .35484 .57389 .36321 .58651 .3575 .57993 .3482 Mtetra
.699 .722 .868 r
.57993 .3482 .58651 .3575 .5992 .35236 .59263 .34235 Mtetra
.679 .699 .862 r
.59263 .34235 .5992 .35236 .61194 .34766 .6054 .33718 Mtetra
.663 .684 .859 r
.6054 .33718 .61194 .34766 .62475 .34324 .61823 .33255 Mtetra
.654 .676 .859 r
.61823 .33255 .62475 .34324 .63763 .33893 .63114 .32826 Mtetra
.65 .676 .861 r
.63114 .32826 .63763 .33893 .65056 .33455 .64411 .32412 Mtetra
.652 .683 .866 r
.64411 .32412 .65056 .33455 .66354 .32994 .65714 .31991 Mtetra
.659 .696 .873 r
.65714 .31991 .66354 .32994 .67656 .32496 .67022 .31545 Mtetra
.671 .713 .88 r
.67022 .31545 .67656 .32496 .68961 .31954 .68334 .31056 Mtetra
.686 .733 .887 r
.68334 .31056 .68961 .31954 .70269 .31362 .69649 .30516 Mtetra
.702 .753 .892 r
.69649 .30516 .70269 .31362 .71579 .30722 .70967 .29919 Mtetra
.717 .771 .895 r
.70967 .29919 .71579 .30722 .72891 .30041 .72286 .29267 Mtetra
.73 .785 .896 r
.72286 .29267 .72891 .30041 .74205 .29327 .73606 .28569 Mtetra
.739 .793 .896 r
.73606 .28569 .74205 .29327 .75522 .28593 .74928 .27836 Mtetra
.744 .796 .894 r
.74928 .27836 .75522 .28593 .76842 .2785 .76252 .27081 Mtetra
.745 .794 .892 r
.76252 .27081 .76842 .2785 .78165 .2711 .7758 .26318 Mtetra
.743 .788 .89 r
.7758 .26318 .78165 .2711 .79494 .26381 .78912 .25559 Mtetra
.737 .78 .887 r
.78912 .25559 .79494 .26381 .80829 .25669 .80249 .24814 Mtetra
.731 .77 .884 r
.80249 .24814 .80829 .25669 .82169 .24976 .81591 .24088 Mtetra
.723 .759 .881 r
.81591 .24088 .82169 .24976 .83517 .24304 .82941 .23385 Mtetra
.506 .716 .967 r
.20764 .43248 .21525 .4387 .226 .43767 .21838 .43178 Mtetra
.447 .705 .977 r
.21838 .43178 .226 .43767 .23676 .43721 .22912 .43175 Mtetra
.363 .682 .979 r
.22912 .43175 .23676 .43721 .24753 .4374 .23986 .43247 Mtetra
.246 .641 .961 r
.23986 .43247 .24753 .4374 .25832 .43829 .25062 .43399 Mtetra
.093 .569 .906 r
.25062 .43399 .25832 .43829 .26913 .43992 .26139 .43636 Mtetra
0 .463 .8 r
.26139 .43636 .26913 .43992 .27996 .44226 .27219 .43955 Mtetra
.253 0 0 r
.27219 .43955 .27996 .44226 .29084 .44528 .28302 .44351 Mtetra
.385 0 0 r
.28302 .44351 .29084 .44528 .30178 .44886 .29391 .44809 Mtetra
.471 0 0 r
.29391 .44809 .30178 .44886 .31279 .45283 .30489 .45311 Mtetra
.518 0 0 r
.30489 .45311 .31279 .45283 .3239 .45697 .31596 .45831 Mtetra
.534 0 0 r
.31596 .45831 .3239 .45697 .33511 .46101 .32715 .46337 Mtetra
.526 0 0 r
.32715 .46337 .33511 .46101 .34646 .46465 .33849 .46796 Mtetra
.499 0 0 r
.33849 .46796 .34646 .46465 .35794 .46757 .34998 .47172 Mtetra
.452 0 0 r
.34998 .47172 .35794 .46757 .36957 .46946 .36164 .47429 Mtetra
.383 0 0 r
.36164 .47429 .36957 .46946 .38136 .47005 .37347 .47536 Mtetra
.287 0 0 r
.37347 .47536 .38136 .47005 .39329 .46913 .38546 .47471 Mtetra
.16 0 0 r
.38546 .47471 .39329 .46913 .40536 .46657 .3976 .47218 Mtetra
.002 0 0 r
.3976 .47218 .40536 .46657 .41754 .46232 .40988 .46773 Mtetra
0 0 0 r
.40988 .46773 .41754 .46232 .42983 .45646 .42226 .46142 Mtetra
.42226 .46142 .42983 .45646 .44219 .44912 .43473 .45343 Mtetra
.54 .897 .683 r
.43473 .45343 .44219 .44912 .45461 .44054 .44726 .444 Mtetra
.672 .964 .758 r
.44726 .444 .45461 .44054 .46707 .431 .45983 .43345 Mtetra
.763 .995 .81 r
.45983 .43345 .46707 .431 .47955 .42081 .47242 .42214 Mtetra
.817 .998 .843 r
.47242 .42214 .47955 .42081 .49205 .4103 .48501 .41041 Mtetra
.844 .985 .864 r
.48501 .41041 .49205 .4103 .50455 .39978 .49761 .39862 Mtetra
.85 .961 .878 r
.49761 .39862 .50455 .39978 .51706 .38952 .5102 .38708 Mtetra
.843 .931 .886 r
.5102 .38708 .51706 .38952 .52958 .37975 .52279 .37607 Mtetra
.827 .898 .891 r
.52279 .37607 .52958 .37975 .54212 .37064 .53539 .3658 Mtetra
.803 .865 .894 r
.53539 .3658 .54212 .37064 .55468 .36232 .548 .35644 Mtetra
.776 .832 .896 r
.548 .35644 .55468 .36232 .56728 .35484 .56064 .34809 Mtetra
.747 .803 .898 r
.56064 .34809 .56728 .35484 .57993 .3482 .57333 .34079 Mtetra
.718 .778 .9 r
.57333 .34079 .57993 .3482 .59263 .34235 .58607 .33451 Mtetra
.69 .759 .904 r
.58607 .33451 .59263 .34235 .6054 .33718 .59887 .32917 Mtetra
.667 .747 .911 r
.59887 .32917 .6054 .33718 .61823 .33255 .61175 .32461 Mtetra
.648 .744 .919 r
.61175 .32461 .61823 .33255 .63114 .32826 .62471 .32062 Mtetra
.635 .749 .93 r
.62471 .32062 .63114 .32826 .64411 .32412 .63774 .31695 Mtetra
.631 .762 .942 r
.63774 .31695 .64411 .32412 .65714 .31991 .65084 .31334 Mtetra
.635 .784 .953 r
.65084 .31334 .65714 .31991 .67022 .31545 .664 .3095 Mtetra
.647 .811 .962 r
.664 .3095 .67022 .31545 .68334 .31056 .6772 .30522 Mtetra
.665 .839 .966 r
.6772 .30522 .68334 .31056 .69649 .30516 .69044 .3003 Mtetra
.688 .864 .965 r
.69044 .3003 .69649 .30516 .70967 .29919 .70369 .29465 Mtetra
.711 .882 .96 r
.70369 .29465 .70967 .29919 .72286 .29267 .71695 .28826 Mtetra
.733 .893 .952 r
.71695 .28826 .72286 .29267 .73606 .28569 .73022 .28119 Mtetra
.75 .895 .944 r
.73022 .28119 .73606 .28569 .74928 .27836 .74349 .27356 Mtetra
.762 .89 .935 r
.74349 .27356 .74928 .27836 .76252 .27081 .75677 .26556 Mtetra
.767 .878 .927 r
.75677 .26556 .76252 .27081 .7758 .26318 .77007 .25736 Mtetra
.767 .86 .919 r
.77007 .25736 .7758 .26318 .78912 .25559 .7834 .24913 Mtetra
.762 .84 .912 r
.7834 .24913 .78912 .25559 .80249 .24814 .79677 .24101 Mtetra
.753 .819 .904 r
.79677 .24101 .80249 .24814 .81591 .24088 .8102 .23312 Mtetra
.742 .799 .898 r
.8102 .23312 .81591 .24088 .82941 .23385 .8237 .22552 Mtetra
.48 .707 .969 r
.19997 .42623 .20764 .43248 .21838 .43178 .21069 .42587 Mtetra
.408 .689 .976 r
.21069 .42587 .21838 .43178 .22912 .43175 .22141 .42627 Mtetra
.307 .655 .971 r
.22141 .42627 .22912 .43175 .23986 .43247 .23212 .42752 Mtetra
.167 .595 .937 r
.23212 .42752 .23986 .43247 .25062 .43399 .24284 .42968 Mtetra
0 .5 .856 r
.24284 .42968 .25062 .43399 .26139 .43636 .25357 .43279 Mtetra
0 .374 .723 r
.25357 .43279 .26139 .43636 .27219 .43955 .26432 .43683 Mtetra
.355 0 0 r
.26432 .43683 .27219 .43955 .28302 .44351 .27511 .44171 Mtetra
.469 0 0 r
.27511 .44171 .28302 .44351 .29391 .44809 .28596 .44728 Mtetra
.538 0 0 r
.28596 .44728 .29391 .44809 .30489 .45311 .29689 .45332 Mtetra
.571 .004 0 r
.29689 .45332 .30489 .45311 .31596 .45831 .30792 .45955 Mtetra
.578 .026 0 r
.30792 .45955 .31596 .45831 .32715 .46337 .31909 .4656 Mtetra
.564 .022 0 r
.31909 .4656 .32715 .46337 .33849 .46796 .33042 .4711 Mtetra
.531 0 0 r
.33042 .4711 .33849 .46796 .34998 .47172 .34192 .47564 Mtetra
.477 0 0 r
.34192 .47564 .34998 .47172 .36164 .47429 .3536 .47884 Mtetra
.397 0 0 r
.3536 .47884 .36164 .47429 .37347 .47536 .36547 .48036 Mtetra
.286 0 0 r
.36547 .48036 .37347 .47536 .38546 .47471 .37752 .47993 Mtetra
.136 0 0 r
.37752 .47993 .38546 .47471 .3976 .47218 .38974 .4774 Mtetra
0 0 0 r
.38974 .4774 .3976 .47218 .40988 .46773 .4021 .47274 Mtetra
.4021 .47274 .40988 .46773 .42226 .46142 .41459 .466 Mtetra
.461 .852 .648 r
.41459 .466 .42226 .46142 .43473 .45343 .42716 .45738 Mtetra
.623 .942 .73 r
.42716 .45738 .43473 .45343 .44726 .444 .4398 .44717 Mtetra
.737 .986 .783 r
.4398 .44717 .44726 .444 .45983 .43345 .45248 .43569 Mtetra
.808 1 .815 r
.45248 .43569 .45983 .43345 .47242 .42214 .46518 .42335 Mtetra
.848 .995 .835 r
.46518 .42335 .47242 .42214 .48501 .41041 .47788 .41053 Mtetra
.866 .98 .849 r
.47788 .41053 .48501 .41041 .49761 .39862 .49057 .39763 Mtetra
.869 .96 .86 r
.49057 .39763 .49761 .39862 .5102 .38708 .50325 .38499 Mtetra
.861 .937 .871 r
.50325 .38499 .5102 .38708 .52279 .37607 .51592 .37294 Mtetra
.845 .913 .881 r
.51592 .37294 .52279 .37607 .53539 .3658 .52858 .36174 Mtetra
.822 .89 .892 r
.52858 .36174 .53539 .3658 .548 .35644 .54126 .3516 Mtetra
.793 .867 .903 r
.54126 .3516 .548 .35644 .56064 .34809 .55395 .34265 Mtetra
.761 .847 .916 r
.55395 .34265 .56064 .34809 .57333 .34079 .56669 .33498 Mtetra
.724 .83 .93 r
.56669 .33498 .57333 .34079 .58607 .33451 .57948 .32858 Mtetra
.685 .818 .946 r
.57948 .32858 .58607 .33451 .59887 .32917 .59234 .32339 Mtetra
.644 .811 .963 r
.59234 .32339 .59887 .32917 .61175 .32461 .60528 .31922 Mtetra
.603 .811 .98 r
.60528 .31922 .61175 .32461 .62471 .32062 .6183 .31585 Mtetra
.564 .819 .993 r
.6183 .31585 .62471 .32062 .63774 .31695 .63141 .31296 Mtetra
.531 .833 .999 r
.63141 .31296 .63774 .31695 .65084 .31334 .64461 .3102 Mtetra
.508 .852 .995 r
.64461 .3102 .65084 .31334 .664 .3095 .65787 .3072 Mtetra
.502 .874 .979 r
.65787 .3072 .664 .3095 .6772 .30522 .67117 .30364 Mtetra
.515 .897 .957 r
.67117 .30364 .6772 .30522 .69044 .3003 .68451 .29926 Mtetra
.547 .921 .935 r
.68451 .29926 .69044 .3003 .70369 .29465 .69786 .29389 Mtetra
.593 .944 .921 r
.69786 .29389 .70369 .29465 .71695 .28826 .71121 .28748 Mtetra
.647 .963 .916 r
.71121 .28748 .71695 .28826 .73022 .28119 .72454 .2801 Mtetra
.699 .975 .918 r
.72454 .2801 .73022 .28119 .74349 .27356 .73785 .2719 Mtetra
.742 .976 .923 r
.73785 .2719 .74349 .27356 .75677 .26556 .75116 .26311 Mtetra
.772 .965 .927 r
.75116 .26311 .75677 .26556 .77007 .25736 .76447 .25397 Mtetra
.786 .943 .927 r
.76447 .25397 .77007 .25736 .7834 .24913 .77779 .24472 Mtetra
.789 .914 .925 r
.77779 .24472 .7834 .24913 .79677 .24101 .79115 .23559 Mtetra
.782 .882 .919 r
.79115 .23559 .79677 .24101 .8102 .23312 .80456 .22674 Mtetra
.769 .85 .912 r
.80456 .22674 .8102 .23312 .8237 .22552 .81804 .21826 Mtetra
.454 .696 .97 r
.19223 .4199 .19997 .42623 .21069 .42587 .20293 .41988 Mtetra
.37 .67 .974 r
.20293 .41988 .21069 .42587 .22141 .42627 .21363 .4207 Mtetra
.252 .624 .959 r
.21363 .4207 .22141 .42627 .23212 .42752 .22432 .42247 Mtetra
.094 .547 .909 r
.22432 .42247 .23212 .42752 .24284 .42968 .235 .42525 Mtetra
0 .433 .807 r
.235 .42525 .24284 .42968 .25357 .43279 .24568 .42907 Mtetra
0 .297 .659 r
.24568 .42907 .25357 .43279 .26432 .43683 .25639 .43391 Mtetra
.427 0 0 r
.25639 .43391 .26432 .43683 .27511 .44171 .26713 .43967 Mtetra
.526 0 0 r
.26713 .43967 .27511 .44171 .28596 .44728 .27792 .44617 Mtetra
.582 .008 0 r
.27792 .44617 .28596 .44728 .29689 .45332 .28881 .45317 Mtetra
.607 .047 0 r
.28881 .45317 .29689 .45332 .30792 .45955 .29981 .46034 Mtetra
.608 .059 0 r
.29981 .46034 .30792 .45955 .31909 .4656 .31096 .4673 Mtetra
.59 .046 0 r
.31096 .4673 .31909 .4656 .33042 .4711 .32227 .47362 Mtetra
.551 .009 0 r
.32227 .47362 .33042 .4711 .34192 .47564 .33378 .47886 Mtetra
.488 0 0 r
.33378 .47886 .34192 .47564 .3536 .47884 .34548 .4826 Mtetra
.394 0 0 r
.34548 .4826 .3536 .47884 .36547 .48036 .35739 .48449 Mtetra
.258 0 0 r
.35739 .48449 .36547 .48036 .37752 .47993 .3695 .48424 Mtetra
.073 0 0 r
.3695 .48424 .37752 .47993 .38974 .4774 .38179 .48168 Mtetra
0 0 0 r
.38179 .48168 .38974 .4774 .4021 .47274 .39424 .47679 Mtetra
.387 .818 .656 r
.39424 .47679 .4021 .47274 .41459 .466 .40683 .46964 Mtetra
.582 .929 .744 r
.40683 .46964 .41459 .466 .42716 .45738 .41951 .46045 Mtetra
.719 .984 .793 r
.41951 .46045 .42716 .45738 .4398 .44717 .43226 .44952 Mtetra
.804 1 .816 r
.43226 .44952 .4398 .44717 .45248 .43569 .44505 .43723 Mtetra
.852 .995 .827 r
.44505 .43723 .45248 .43569 .46518 .42335 .45786 .42399 Mtetra
.876 .982 .833 r
.45786 .42399 .46518 .42335 .47788 .41053 .47066 .41023 Mtetra
.885 .966 .84 r
.47066 .41023 .47788 .41053 .49057 .39763 .48345 .39639 Mtetra
.883 .949 .848 r
.48345 .39639 .49057 .39763 .50325 .38499 .49621 .38286 Mtetra
.873 .932 .858 r
.49621 .38286 .50325 .38499 .51592 .37294 .50896 .36999 Mtetra
.856 .917 .871 r
.50896 .36999 .51592 .37294 .52858 .36174 .5217 .35809 Mtetra
.833 .902 .888 r
.5217 .35809 .52858 .36174 .54126 .3516 .53444 .34741 Mtetra
.802 .89 .907 r
.53444 .34741 .54126 .3516 .55395 .34265 .5472 .33815 Mtetra
.763 .879 .93 r
.5472 .33815 .55395 .34265 .56669 .33498 .56 .33041 Mtetra
.713 .87 .956 r
.56 .33041 .56669 .33498 .57948 .32858 .57285 .32422 Mtetra
.649 .862 .98 r
.57285 .32422 .57948 .32858 .59234 .32339 .58578 .31952 Mtetra
.568 .852 .997 r
.58578 .31952 .59234 .32339 .60528 .31922 .59879 .31612 Mtetra
.467 .833 .993 r
.59879 .31612 .60528 .31922 .6183 .31585 .61191 .31372 Mtetra
.352 .799 .954 r
.61191 .31372 .6183 .31585 .63141 .31296 .62512 .31196 Mtetra
.243 .751 .875 r
.62512 .31196 .63141 .31296 .64461 .3102 .63842 .31037 Mtetra
.162 .702 .775 r
.63842 .31037 .64461 .3102 .65787 .3072 .65181 .30848 Mtetra
0 0 0 r
.65181 .30848 .65787 .3072 .67117 .30364 .66524 .30586 Mtetra
.66524 .30586 .67117 .30364 .68451 .29926 .6787 .30213 Mtetra
.6787 .30213 .68451 .29926 .69786 .29389 .69216 .29705 Mtetra
.69216 .29705 .69786 .29389 .71121 .28748 .7056 .29055 Mtetra
.378 .806 .631 r
.7056 .29055 .71121 .28748 .72454 .2801 .71901 .28268 Mtetra
.495 .879 .689 r
.71901 .28268 .72454 .2801 .73785 .2719 .73237 .27364 Mtetra
.609 .943 .758 r
.73237 .27364 .73785 .2719 .75116 .26311 .7457 .26373 Mtetra
.704 .983 .821 r
.7457 .26373 .75116 .26311 .76447 .25397 .75901 .25329 Mtetra
.769 .995 .87 r
.75901 .25329 .76447 .25397 .77779 .24472 .77231 .24264 Mtetra
.802 .979 .9 r
.77231 .24264 .77779 .24472 .79115 .23559 .78564 .23211 Mtetra
.809 .947 .913 r
.78564 .23211 .79115 .23559 .80456 .22674 .79902 .22192 Mtetra
.801 .908 .915 r
.79902 .22192 .80456 .22674 .81804 .21826 .81246 .21224 Mtetra
.43 .683 .97 r
.18443 .41346 .19223 .4199 .20293 .41988 .19512 .41375 Mtetra
.336 .65 .968 r
.19512 .41375 .20293 .41988 .21363 .4207 .2058 .41497 Mtetra
.204 .592 .945 r
.2058 .41497 .21363 .4207 .22432 .42247 .21645 .41721 Mtetra
.034 .502 .882 r
.21645 .41721 .22432 .42247 .235 .42525 .2271 .42056 Mtetra
0 .377 .768 r
.2271 .42056 .235 .42525 .24568 .42907 .23774 .42503 Mtetra
.336 0 0 r
.23774 .42503 .24568 .42907 .25639 .43391 .2484 .4306 Mtetra
.472 0 0 r
.2484 .4306 .25639 .43391 .26713 .43967 .25909 .43714 Mtetra
.56 0 0 r
.25909 .43714 .26713 .43967 .27792 .44617 .26984 .44447 Mtetra
.609 .04 0 r
.26984 .44447 .27792 .44617 .28881 .45317 .28068 .45231 Mtetra
.629 .07 0 r
.28068 .45231 .28881 .45317 .29981 .46034 .29165 .46031 Mtetra
.627 .074 0 r
.29165 .46031 .29981 .46034 .31096 .4673 .30277 .46804 Mtetra
.604 .052 0 r
.30277 .46804 .31096 .4673 .32227 .47362 .31408 .47505 Mtetra
.558 .001 0 r
.31408 .47505 .32227 .47362 .33378 .47886 .32559 .48087 Mtetra
.482 0 0 r
.32559 .48087 .33378 .47886 .34548 .4826 .33731 .48505 Mtetra
.364 0 0 r
.33731 .48505 .34548 .4826 .35739 .48449 .34926 .48721 Mtetra
.189 0 0 r
.34926 .48721 .35739 .48449 .3695 .48424 .36143 .48707 Mtetra
0 0 0 r
.36143 .48707 .3695 .48424 .38179 .48168 .37379 .48445 Mtetra
.314 .791 .707 r
.37379 .48445 .38179 .48168 .39424 .47679 .38633 .47933 Mtetra
.547 .925 .801 r
.38633 .47933 .39424 .47679 .40683 .46964 .39901 .4718 Mtetra
.707 .985 .84 r
.39901 .4718 .40683 .46964 .41951 .46045 .41179 .4621 Mtetra
.802 .998 .847 r
.41179 .4621 .41951 .46045 .43226 .44952 .42465 .45055 Mtetra
.855 .99 .842 r
.42465 .45055 .43226 .44952 .44505 .43723 .43754 .43757 Mtetra
.882 .975 .836 r
.43754 .43757 .44505 .43723 .45786 .42399 .45045 .42359 Mtetra
.894 .958 .832 r
.45045 .42359 .45786 .42399 .47066 .41023 .46336 .40908 Mtetra
.896 .943 .833 r
.46336 .40908 .47066 .41023 .48345 .39639 .47624 .3945 Mtetra
.89 .93 .838 r
.47624 .3945 .48345 .39639 .49621 .38286 .4891 .38028 Mtetra
.879 .919 .849 r
.4891 .38028 .49621 .38286 .50896 .36999 .50193 .36682 Mtetra
.862 .91 .864 r
.50193 .36682 .50896 .36999 .5217 .35809 .51475 .35446 Mtetra
.837 .904 .885 r
.51475 .35446 .5217 .35809 .53444 .34741 .52756 .34352 Mtetra
.802 .9 .911 r
.52756 .34352 .53444 .34741 .5472 .33815 .54038 .33422 Mtetra
.753 .897 .943 r
.54038 .33422 .5472 .33815 .56 .33041 .55324 .32671 Mtetra
.68 .893 .975 r
.55324 .32671 .56 .33041 .57285 .32422 .56617 .32106 Mtetra
.571 .876 .994 r
.56617 .32106 .57285 .32422 .58578 .31952 .57917 .3172 Mtetra
.411 .827 .971 r
.57917 .3172 .58578 .31952 .59879 .31612 .59227 .31492 Mtetra
.208 .725 .872 r
.59227 .31492 .59879 .31612 .61191 .31372 .60549 .31388 Mtetra
0 0 0 r
.60549 .31388 .61191 .31372 .62512 .31196 .61882 .31362 Mtetra
.126 0 0 r
.61882 .31362 .62512 .31196 .63842 .31037 .63226 .31356 Mtetra
.193 0 0 r
.63226 .31356 .63842 .31037 .65181 .30848 .64578 .31311 Mtetra
.202 0 0 r
.64578 .31311 .65181 .30848 .66524 .30586 .65937 .31168 Mtetra
.17 0 0 r
.65937 .31168 .66524 .30586 .6787 .30213 .67297 .30878 Mtetra
.105 0 0 r
.67297 .30878 .6787 .30213 .69216 .29705 .68657 .30409 Mtetra
.013 0 0 r
.68657 .30409 .69216 .29705 .7056 .29055 .70012 .29747 Mtetra
0 0 0 r
.70012 .29747 .7056 .29055 .71901 .28268 .71361 .28899 Mtetra
.71361 .28899 .71901 .28268 .73237 .27364 .72703 .2789 Mtetra
.72703 .2789 .73237 .27364 .7457 .26373 .74038 .26757 Mtetra
.554 .877 .601 r
.74038 .26757 .7457 .26373 .75901 .25329 .75368 .25546 Mtetra
.686 .959 .716 r
.75368 .25546 .75901 .25329 .77231 .24264 .76696 .24304 Mtetra
.777 .997 .808 r
.76696 .24304 .77231 .24264 .78564 .23211 .78024 .23071 Mtetra
.821 .992 .866 r
.78024 .23071 .78564 .23211 .79902 .22192 .79356 .21881 Mtetra
.829 .961 .895 r
.79356 .21881 .79902 .22192 .81246 .21224 .80695 .20759 Mtetra
.41 .67 .967 r
.17658 .40686 .18443 .41346 .19512 .41375 .18726 .40742 Mtetra
.308 .63 .962 r
.18726 .40742 .19512 .41375 .2058 .41497 .19791 .40898 Mtetra
.168 .564 .933 r
.19791 .40898 .2058 .41497 .21645 .41721 .20854 .41164 Mtetra
0 .465 .863 r
.20854 .41164 .21645 .41721 .2271 .42056 .21915 .41548 Mtetra
0 .337 .746 r
.21915 .41548 .2271 .42056 .23774 .42503 .22976 .42051 Mtetra
.365 0 0 r
.22976 .42051 .23774 .42503 .2484 .4306 .24037 .42669 Mtetra
.492 0 0 r
.24037 .42669 .2484 .4306 .25909 .43714 .25102 .43389 Mtetra
.573 0 0 r
.25102 .43389 .25909 .43714 .26984 .44447 .26173 .4419 Mtetra
.619 .052 0 r
.26173 .4419 .26984 .44447 .28068 .45231 .27254 .45043 Mtetra
.636 .074 0 r
.27254 .45043 .28068 .45231 .29165 .46031 .28347 .45908 Mtetra
.63 .069 0 r
.28347 .45908 .29165 .46031 .30277 .46804 .29458 .46742 Mtetra
.601 .035 0 r
.29458 .46742 .30277 .46804 .31408 .47505 .30587 .47496 Mtetra
.544 0 0 r
.30587 .47496 .31408 .47505 .32559 .48087 .31739 .48119 Mtetra
.446 0 0 r
.31739 .48119 .32559 .48087 .33731 .48505 .32914 .48567 Mtetra
.288 0 0 r
.32914 .48567 .33731 .48505 .34926 .48721 .34113 .488 Mtetra
.053 0 0 r
.34113 .488 .34926 .48721 .36143 .48707 .35334 .48788 Mtetra
.238 .755 .791 r
.35334 .48788 .36143 .48707 .37379 .48445 .36577 .48516 Mtetra
.505 .91 .888 r
.36577 .48516 .37379 .48445 .38633 .47933 .37839 .47981 Mtetra
.688 .975 .911 r
.37839 .47981 .38633 .47933 .39901 .4718 .39115 .47195 Mtetra
.793 .984 .896 r
.39115 .47195 .39901 .4718 .41179 .4621 .40403 .46183 Mtetra
.85 .972 .872 r
.40403 .46183 .41179 .4621 .42465 .45055 .41698 .4498 Mtetra
.879 .954 .851 r
.41698 .4498 .42465 .45055 .43754 .43757 .42998 .43628 Mtetra
.893 .937 .836 r
.42998 .43628 .43754 .43757 .45045 .42359 .44299 .42174 Mtetra
.898 .923 .828 r
.44299 .42174 .45045 .42359 .46336 .40908 .45599 .40668 Mtetra
.897 .911 .826 r
.45599 .40668 .46336 .40908 .47624 .3945 .46897 .39157 Mtetra
.89 .903 .83 r
.46897 .39157 .47624 .3945 .4891 .38028 .48191 .37689 Mtetra
.878 .897 .841 r
.48191 .37689 .4891 .38028 .50193 .36682 .49482 .36307 Mtetra
.861 .895 .858 r
.49482 .36307 .50193 .36682 .51475 .35446 .50771 .3505 Mtetra
.835 .895 .883 r
.50771 .3505 .51475 .35446 .52756 .34352 .52059 .33954 Mtetra
.795 .899 .916 r
.52059 .33954 .52756 .34352 .54038 .33422 .53348 .33046 Mtetra
.733 .902 .954 r
.53348 .33046 .54038 .33422 .55324 .32671 .54641 .32347 Mtetra
.628 .893 .987 r
.54641 .32347 .55324 .32671 .56617 .32106 .55941 .31865 Mtetra
.45 .845 .978 r
.55941 .31865 .56617 .32106 .57917 .3172 .57249 .31595 Mtetra
.19 .712 .867 r
.57249 .31595 .57917 .3172 .59227 .31492 .58569 .31513 Mtetra
.081 0 0 r
.58569 .31513 .59227 .31492 .60549 .31388 .59902 .31581 Mtetra
.267 0 0 r
.59902 .31581 .60549 .31388 .61882 .31362 .61248 .31742 Mtetra
.359 0 0 r
.61248 .31742 .61882 .31362 .63226 .31356 .62607 .31926 Mtetra
.385 0 0 r
.62607 .31926 .63226 .31356 .64578 .31311 .63976 .32059 Mtetra
.369 0 0 r
.63976 .32059 .64578 .31311 .65937 .31168 .65351 .32065 Mtetra
.323 0 0 r
.65351 .32065 .65937 .31168 .67297 .30878 .66728 .31882 Mtetra
.254 0 0 r
.66728 .31882 .67297 .30878 .68657 .30409 .68104 .31466 Mtetra
.162 0 0 r
.68104 .31466 .68657 .30409 .70012 .29747 .69472 .30797 Mtetra
.05 0 0 r
.69472 .30797 .70012 .29747 .71361 .28899 .70831 .29881 Mtetra
0 0 0 r
.70831 .29881 .71361 .28899 .72703 .2789 .7218 .2875 Mtetra
.7218 .2875 .72703 .2789 .74038 .26757 .73518 .27452 Mtetra
.73518 .27452 .74038 .26757 .75368 .25546 .74847 .26044 Mtetra
.576 .857 .527 r
.74847 .26044 .75368 .25546 .76696 .24304 .76171 .24589 Mtetra
.716 .952 .664 r
.76171 .24589 .76696 .24304 .78024 .23071 .77494 .2314 Mtetra
.807 .996 .773 r
.77494 .2314 .78024 .23071 .79356 .21881 .78819 .21743 Mtetra
.846 .993 .844 r
.78819 .21743 .79356 .21881 .80695 .20759 .8015 .20433 Mtetra
.396 .658 .964 r
.16868 .40005 .17658 .40686 .18726 .40742 .17935 .40083 Mtetra
.29 .613 .956 r
.17935 .40083 .18726 .40742 .19791 .40898 .18999 .40266 Mtetra
.148 .542 .924 r
.18999 .40266 .19791 .40898 .20854 .41164 .20059 .40565 Mtetra
0 .44 .853 r
.20059 .40565 .20854 .41164 .21915 .41548 .21118 .40987 Mtetra
0 .316 .743 r
.21118 .40987 .21915 .41548 .22976 .42051 .22175 .41533 Mtetra
0 .188 .61 r
.22175 .41533 .22976 .42051 .24037 .42669 .23233 .42198 Mtetra
.486 0 0 r
.23233 .42198 .24037 .42669 .25102 .43389 .24294 .42967 Mtetra
.564 0 0 r
.24294 .42967 .25102 .43389 .26173 .4419 .25362 .43819 Mtetra
.607 .042 0 r
.25362 .43819 .26173 .4419 .27254 .45043 .2644 .4472 Mtetra
.621 .057 0 r
.2644 .4472 .27254 .45043 .28347 .45908 .27531 .45631 Mtetra
.61 .042 0 r
.27531 .45631 .28347 .45908 .29458 .46742 .2864 .46505 Mtetra
.57 0 0 r
.2864 .46505 .29458 .46742 .30587 .47496 .2977 .47291 Mtetra
.491 0 0 r
.2977 .47291 .30587 .47496 .31739 .48119 .30922 .47939 Mtetra
.352 0 0 r
.30922 .47939 .31739 .48119 .32914 .48567 .321 .48401 Mtetra
0 .458 .7 r
.321 .48401 .32914 .48567 .34113 .488 .33302 .48638 Mtetra
.16 .686 .871 r
.33302 .48638 .34113 .488 .35334 .48788 .34528 .48621 Mtetra
.444 .853 .966 r
.34528 .48621 .35334 .48788 .36577 .48516 .35777 .48335 Mtetra
.645 .926 .974 r
.35777 .48335 .36577 .48516 .37839 .47981 .37046 .47779 Mtetra
.762 .94 .941 r
.37046 .47779 .37839 .47981 .39115 .47195 .3833 .46966 Mtetra
.825 .93 .901 r
.3833 .46966 .39115 .47195 .40403 .46183 .39626 .45922 Mtetra
.859 .915 .868 r
.39626 .45922 .40403 .46183 .41698 .4498 .4093 .44684 Mtetra
.878 .9 .843 r
.4093 .44684 .41698 .4498 .42998 .43628 .42239 .43297 Mtetra
.887 .888 .827 r
.42239 .43297 .42998 .43628 .44299 .42174 .43548 .41808 Mtetra
.889 .879 .818 r
.43548 .41808 .44299 .42174 .45599 .40668 .44857 .40268 Mtetra
.888 .873 .816 r
.44857 .40268 .45599 .40668 .46897 .39157 .46163 .38727 Mtetra
.882 .869 .821 r
.46163 .38727 .46897 .39157 .48191 .37689 .47465 .37236 Mtetra
.871 .869 .833 r
.47465 .37236 .48191 .37689 .49482 .36307 .48764 .35841 Mtetra
.854 .872 .853 r
.48764 .35841 .49482 .36307 .50771 .3505 .5006 .34587 Mtetra
.827 .878 .881 r
.5006 .34587 .50771 .3505 .52059 .33954 .51355 .33511 Mtetra
.782 .886 .92 r
.51355 .33511 .52059 .33954 .53348 .33046 .52651 .32649 Mtetra
.705 .891 .965 r
.52651 .32649 .53348 .33046 .54641 .32347 .5395 .32025 Mtetra
.561 .872 .994 r
.5395 .32025 .54641 .32347 .55941 .31865 .55257 .3165 Mtetra
.307 .773 .941 r
.55257 .3165 .55941 .31865 .57249 .31595 .56574 .31521 Mtetra
0 .553 .733 r
.56574 .31521 .57249 .31595 .58569 .31513 .57903 .31614 Mtetra
.293 0 0 r
.57903 .31614 .58569 .31513 .59902 .31581 .59247 .31882 Mtetra
.433 0 0 r
.59247 .31882 .59902 .31581 .61248 .31742 .60607 .32261 Mtetra
.486 0 0 r
.60607 .32261 .61248 .31742 .62607 .31926 .61982 .32668 Mtetra
.488 0 .006 r
.61982 .32668 .62607 .31926 .63976 .32059 .63368 .3301 Mtetra
.459 0 .057 r
.63368 .3301 .63976 .32059 .65351 .32065 .64762 .33195 Mtetra
.405 0 .08 r
.64762 .33195 .65351 .32065 .66728 .31882 .66158 .33144 Mtetra
.33 0 .081 r
.66158 .33144 .66728 .31882 .68104 .31466 .67551 .328 Mtetra
.236 0 .062 r
.67551 .328 .68104 .31466 .69472 .30797 .68935 .32135 Mtetra
.123 0 .021 r
.68935 .32135 .69472 .30797 .70831 .29881 .70306 .31155 Mtetra
0 0 0 r
.70306 .31155 .70831 .29881 .7218 .2875 .71663 .29895 Mtetra
.71663 .29895 .7218 .2875 .73518 .27452 .73004 .28415 Mtetra
.73004 .28415 .73518 .27452 .74847 .26044 .74334 .26788 Mtetra
.74334 .26788 .74847 .26044 .76171 .24589 .75654 .25091 Mtetra
.662 .887 .531 r
.75654 .25091 .76171 .24589 .77494 .2314 .7697 .23396 Mtetra
.783 .967 .667 r
.7697 .23396 .77494 .2314 .78819 .21743 .78287 .21763 Mtetra
.851 .997 .771 r
.78287 .21763 .78819 .21743 .8015 .20433 .7961 .20234 Mtetra
.388 .648 .96 r
.16074 .39299 .16868 .40005 .17935 .40083 .1714 .39391 Mtetra
.283 .6 .951 r
.1714 .39391 .17935 .40083 .18999 .40266 .18203 .39593 Mtetra
.145 .528 .919 r
.18203 .39593 .18999 .40266 .20059 .40565 .19262 .39914 Mtetra
0 .429 .854 r
.19262 .39914 .20059 .40565 .21118 .40987 .20319 .40361 Mtetra
0 .312 .757 r
.20319 .40361 .21118 .40987 .22175 .41533 .21374 .40935 Mtetra
0 .195 .643 r
.21374 .40935 .22175 .41533 .23233 .42198 .2243 .4163 Mtetra
.451 0 0 r
.2243 .4163 .23233 .42198 .24294 .42967 .23488 .42429 Mtetra
.526 0 0 r
.23488 .42429 .24294 .42967 .25362 .43819 .24554 .4331 Mtetra
.565 .009 0 r
.24554 .4331 .25362 .43819 .2644 .4472 .2563 .44237 Mtetra
.573 .014 0 r
.2563 .44237 .2644 .4472 .27531 .45631 .2672 .45171 Mtetra
.548 0 0 r
.2672 .45171 .27531 .45631 .2864 .46505 .27828 .46061 Mtetra
.485 0 0 r
.27828 .46061 .2864 .46505 .2977 .47291 .28958 .46858 Mtetra
.365 0 0 r
.28958 .46858 .2977 .47291 .30922 .47939 .30112 .4751 Mtetra
0 .382 .751 r
.30112 .4751 .30922 .47939 .321 .48401 .31292 .4797 Mtetra
.094 .581 .904 r
.31292 .4797 .321 .48401 .33302 .48638 .32498 .48199 Mtetra
.365 .741 .989 r
.32498 .48199 .33302 .48638 .34528 .48621 .33729 .4817 Mtetra
.57 .827 .994 r
.33729 .4817 .34528 .48621 .35777 .48335 .34983 .47867 Mtetra
.699 .856 .958 r
.34983 .47867 .35777 .48335 .37046 .47779 .36257 .47292 Mtetra
.774 .86 .914 r
.36257 .47292 .37046 .47779 .3833 .46966 .37548 .4646 Mtetra
.818 .854 .875 r
.37548 .4646 .3833 .46966 .39626 .45922 .38851 .45397 Mtetra
.844 .846 .846 r
.38851 .45397 .39626 .45922 .4093 .44684 .40162 .44141 Mtetra
.859 .84 .825 r
.40162 .44141 .4093 .44684 .42239 .43297 .41478 .42737 Mtetra
.868 .835 .811 r
.41478 .42737 .42239 .43297 .43548 .41808 .42795 .41233 Mtetra
.872 .832 .805 r
.42795 .41233 .43548 .41808 .44857 .40268 .44111 .39682 Mtetra
.871 .831 .805 r
.44111 .39682 .44857 .40268 .46163 .38727 .45425 .38135 Mtetra
.867 .832 .811 r
.45425 .38135 .46163 .38727 .47465 .37236 .46734 .36643 Mtetra
.857 .836 .824 r
.46734 .36643 .47465 .37236 .48764 .35841 .4804 .35258 Mtetra
.84 .842 .846 r
.4804 .35258 .48764 .35841 .5006 .34587 .49342 .34025 Mtetra
.813 .851 .878 r
.49342 .34025 .5006 .34587 .51355 .33511 .50643 .3299 Mtetra
.764 .862 .922 r
.50643 .3299 .51355 .33511 .52651 .32649 .51945 .32192 Mtetra
.673 .866 .972 r
.51945 .32192 .52651 .32649 .5395 .32025 .53251 .31659 Mtetra
.493 .831 .998 r
.53251 .31659 .5395 .32025 .55257 .3165 .54564 .31407 Mtetra
.176 .683 .904 r
.54564 .31407 .55257 .3165 .56574 .31521 .55889 .31435 Mtetra
.189 0 0 r
.55889 .31435 .56574 .31521 .57903 .31614 .57227 .31718 Mtetra
.428 0 0 r
.57227 .31718 .57903 .31614 .59247 .31882 .58583 .32205 Mtetra
.534 0 0 r
.58583 .32205 .59247 .31882 .60607 .32261 .59956 .32822 Mtetra
.566 .051 0 r
.59956 .32822 .60607 .32261 .61982 .32668 .61346 .33473 Mtetra
.556 .072 .062 r
.61346 .33473 .61982 .32668 .63368 .3301 .6275 .34049 Mtetra
.517 .06 .105 r
.6275 .34049 .63368 .3301 .64762 .33195 .64163 .34439 Mtetra
.456 .022 .124 r
.64163 .34439 .64762 .33195 .66158 .33144 .65579 .34545 Mtetra
.374 0 .123 r
.65579 .34545 .66158 .33144 .67551 .328 .66991 .34295 Mtetra
.271 0 .102 r
.66991 .34295 .67551 .328 .68935 .32135 .68392 .33651 Mtetra
.148 0 .063 r
.68392 .33651 .68935 .32135 .70306 .31155 .69777 .32617 Mtetra
.006 0 .002 r
.69777 .32617 .70306 .31155 .71663 .29895 .71143 .31231 Mtetra
0 0 0 r
.71143 .31231 .71663 .29895 .73004 .28415 .72491 .29566 Mtetra
.72491 .29566 .73004 .28415 .74334 .26788 .73821 .27709 Mtetra
.73821 .27709 .74334 .26788 .75654 .25091 .75138 .25755 Mtetra
.65 .847 .449 r
.75138 .25755 .75654 .25091 .7697 .23396 .76449 .23795 Mtetra
.777 .937 .585 r
.76449 .23795 .7697 .23396 .78287 .21763 .77758 .21903 Mtetra
.858 .984 .702 r
.77758 .21903 .78287 .21763 .7961 .20234 .79072 .20135 Mtetra
.389 .641 .956 r
.15275 .38564 .16074 .39299 .1714 .39391 .16342 .38663 Mtetra
.288 .592 .947 r
.16342 .38663 .1714 .39391 .18203 .39593 .17405 .38873 Mtetra
.159 .522 .918 r
.17405 .38873 .18203 .39593 .19262 .39914 .18464 .39204 Mtetra
.01 .431 .863 r
.18464 .39204 .19262 .39914 .20319 .40361 .1952 .39662 Mtetra
0 .325 .783 r
.1952 .39662 .20319 .40361 .21374 .40935 .20574 .40247 Mtetra
0 .221 .691 r
.20574 .40247 .21374 .40935 .2243 .4163 .21629 .40951 Mtetra
0 .134 .607 r
.21629 .40951 .2243 .4163 .23488 .42429 .22687 .4176 Mtetra
0 .075 .545 r
.22687 .4176 .23488 .42429 .24554 .4331 .23751 .42646 Mtetra
.481 0 0 r
.23751 .42646 .24554 .4331 .2563 .44237 .24827 .43575 Mtetra
.474 0 0 r
.24827 .43575 .2563 .44237 .2672 .45171 .25917 .44506 Mtetra
0 .101 .569 r
.25917 .44506 .2672 .45171 .27828 .46061 .27026 .4539 Mtetra
0 .189 .656 r
.27026 .4539 .27828 .46061 .28958 .46858 .28157 .46175 Mtetra
0 .32 .773 r
.28157 .46175 .28958 .46858 .30112 .4751 .29313 .46811 Mtetra
.057 .473 .887 r
.29313 .46811 .30112 .4751 .31292 .4797 .30495 .47253 Mtetra
.288 .61 .955 r
.30495 .47253 .31292 .4797 .32498 .48199 .31703 .47462 Mtetra
.48 .7 .966 r
.31703 .47462 .32498 .48199 .33729 .4817 .32938 .47413 Mtetra
.615 .748 .94 r
.32938 .47413 .33729 .4817 .34983 .47867 .34196 .47092 Mtetra
.702 .769 .904 r
.34196 .47092 .34983 .47867 .36257 .47292 .35475 .46503 Mtetra
.758 .777 .869 r
.35475 .46503 .36257 .47292 .37548 .4646 .36771 .4566 Mtetra
.794 .78 .84 r
.36771 .4566 .37548 .4646 .38851 .45397 .38079 .4459 Mtetra
.818 .781 .818 r
.38079 .4459 .38851 .45397 .40162 .44141 .39396 .43333 Mtetra
.834 .782 .803 r
.39396 .43333 .40162 .44141 .41478 .42737 .40718 .41931 Mtetra
.844 .784 .794 r
.40718 .41931 .41478 .42737 .42795 .41233 .42042 .40435 Mtetra
.849 .786 .79 r
.42042 .40435 .42795 .41233 .44111 .39682 .43364 .38894 Mtetra
.85 .789 .792 r
.43364 .38894 .44111 .39682 .45425 .38135 .44683 .37363 Mtetra
.847 .794 .8 r
.44683 .37363 .45425 .38135 .46734 .36643 .45999 .35892 Mtetra
.838 .8 .814 r
.45999 .35892 .46734 .36643 .4804 .35258 .4731 .34534 Mtetra
.822 .808 .838 r
.4731 .34534 .4804 .35258 .49342 .34025 .48618 .33341 Mtetra
.793 .818 .872 r
.48618 .33341 .49342 .34025 .50643 .3299 .49925 .32361 Mtetra
.741 .828 .918 r
.49925 .32361 .50643 .3299 .51945 .32192 .51232 .31636 Mtetra
.639 .826 .972 r
.51232 .31636 .51945 .32192 .53251 .31659 .52543 .31202 Mtetra
.436 .776 .997 r
.52543 .31202 .53251 .31659 .54564 .31407 .53863 .31079 Mtetra
.085 .6 .886 r
.53863 .31079 .54564 .31407 .55889 .31435 .55194 .31267 Mtetra
.287 0 0 r
.55194 .31267 .55889 .31435 .57227 .31718 .5654 .31741 Mtetra
.508 0 0 r
.5654 .31741 .57227 .31718 .58583 .32205 .57905 .32449 Mtetra
.601 .05 0 r
.57905 .32449 .58583 .32205 .59956 .32822 .59291 .33308 Mtetra
.624 .108 0 r
.59291 .33308 .59956 .32822 .61346 .33473 .60695 .34211 Mtetra
.608 .12 .07 r
.60695 .34211 .61346 .33473 .6275 .34049 .62116 .35032 Mtetra
.563 .099 .109 r
.62116 .35032 .6275 .34049 .64163 .34439 .63548 .35642 Mtetra
.494 .051 .126 r
.63548 .35642 .64163 .34439 .65579 .34545 .64984 .35924 Mtetra
.399 0 .122 r
.64984 .35924 .65579 .34545 .66991 .34295 .66415 .35789 Mtetra
.279 0 .098 r
.66415 .35789 .66991 .34295 .68392 .33651 .67835 .35188 Mtetra
.135 0 .055 r
.67835 .35188 .68392 .33651 .69777 .32617 .69235 .34118 Mtetra
0 0 0 r
.69235 .34118 .69777 .32617 .71143 .31231 .70613 .32622 Mtetra
.70613 .32622 .71143 .31231 .72491 .29566 .71968 .30782 Mtetra
.71968 .30782 .72491 .29566 .73821 .27709 .73301 .28701 Mtetra
.73301 .28701 .73821 .27709 .75138 .25755 .74617 .26491 Mtetra
.69 .848 .428 r
.74617 .26491 .75138 .25755 .76449 .23795 .75923 .24262 Mtetra
.804 .926 .548 r
.75923 .24262 .76449 .23795 .77758 .21903 .77225 .22105 Mtetra
.878 .971 .657 r
.77225 .22105 .77758 .21903 .79072 .20135 .78531 .2009 Mtetra
.397 .636 .952 r
.14474 .37798 .15275 .38564 .16342 .38663 .15542 .37894 Mtetra
.303 .589 .943 r
.15542 .37894 .16342 .38663 .17405 .38873 .16606 .38102 Mtetra
.187 .524 .92 r
.16606 .38102 .17405 .38873 .18464 .39204 .17665 .38429 Mtetra
.056 .442 .876 r
.17665 .38429 .18464 .39204 .1952 .39662 .18722 .38882 Mtetra
0 .35 .814 r
.18722 .38882 .1952 .39662 .20574 .40247 .19777 .3946 Mtetra
0 .26 .745 r
.19777 .3946 .20574 .40247 .21629 .40951 .20832 .40155 Mtetra
0 .188 .684 r
.20832 .40155 .21629 .40951 .22687 .4176 .2189 .40949 Mtetra
0 .141 .644 r
.2189 .40949 .22687 .4176 .23751 .42646 .22956 .41817 Mtetra
0 .125 .632 r
.22956 .41817 .23751 .42646 .24827 .43575 .24032 .42724 Mtetra
0 .144 .654 r
.24032 .42724 .24827 .43575 .25917 .44506 .25124 .43628 Mtetra
0 .198 .706 r
.25124 .43628 .25917 .44506 .27026 .4539 .26234 .44481 Mtetra
0 .286 .779 r
.26234 .44481 .27026 .4539 .28157 .46175 .27367 .45233 Mtetra
.05 .394 .852 r
.27367 .45233 .28157 .46175 .29313 .46811 .28525 .45834 Mtetra
.235 .5 .901 r
.28525 .45834 .29313 .46811 .30495 .47253 .2971 .46242 Mtetra
.401 .584 .915 r
.2971 .46242 .30495 .47253 .31703 .47462 .30922 .46421 Mtetra
.531 .64 .903 r
.30922 .46421 .31703 .47462 .32938 .47413 .32159 .46346 Mtetra
.625 .675 .878 r
.32159 .46346 .32938 .47413 .34196 .47092 .33421 .46007 Mtetra
.69 .696 .851 r
.33421 .46007 .34196 .47092 .35475 .46503 .34703 .45407 Mtetra
.735 .709 .826 r
.34703 .45407 .35475 .46503 .36771 .4566 .36002 .44563 Mtetra
.767 .718 .807 r
.36002 .44563 .36771 .4566 .38079 .4459 .37314 .43501 Mtetra
.79 .726 .792 r
.37314 .43501 .38079 .4459 .39396 .43333 .38635 .42259 Mtetra
.806 .732 .782 r
.38635 .42259 .39396 .43333 .40718 .41931 .39961 .40879 Mtetra
.817 .738 .777 r
.39961 .40879 .40718 .41931 .42042 .40435 .41289 .39409 Mtetra
.824 .744 .776 r
.41289 .39409 .42042 .40435 .43364 .38894 .42616 .37901 Mtetra
.827 .751 .779 r
.42616 .37901 .43364 .38894 .44683 .37363 .4394 .36404 Mtetra
.825 .758 .789 r
.4394 .36404 .44683 .37363 .45999 .35892 .4526 .34972 Mtetra
.817 .765 .804 r
.4526 .34972 .45999 .35892 .4731 .34534 .46577 .33659 Mtetra
.801 .773 .828 r
.46577 .33659 .4731 .34534 .48618 .33341 .47889 .32517 Mtetra
.771 .781 .862 r
.47889 .32517 .48618 .33341 .49925 .32361 .49201 .31599 Mtetra
.715 .786 .908 r
.49201 .31599 .49925 .32361 .51232 .31636 .50512 .30952 Mtetra
.608 .776 .961 r
.50512 .30952 .51232 .31636 .52543 .31202 .51828 .30614 Mtetra
.399 .715 .987 r
.51828 .30614 .52543 .31202 .53863 .31079 .53152 .30612 Mtetra
.049 .535 .887 r
.53152 .30612 .53863 .31079 .55194 .31267 .54488 .30947 Mtetra
.32 0 0 r
.54488 .30947 .55194 .31267 .5654 .31741 .55841 .31598 Mtetra
.544 0 0 r
.55841 .31598 .5654 .31741 .57905 .32449 .57214 .3251 Mtetra
.641 .085 0 r
.57214 .3251 .57905 .32449 .59291 .33308 .5861 .33596 Mtetra
.668 .139 0 r
.5861 .33596 .59291 .33308 .60695 .34211 .60026 .34737 Mtetra
.652 .146 .029 r
.60026 .34737 .60695 .34211 .62116 .35032 .61462 .35795 Mtetra
.605 .116 .067 r
.61462 .35795 .62116 .35032 .63548 .35642 .62911 .36626 Mtetra
.525 .055 .081 r
.62911 .36626 .63548 .35642 .64984 .35924 .64366 .37092 Mtetra
.41 0 .072 r
.64366 .37092 .64984 .35924 .66415 .35789 .65816 .37089 Mtetra
.259 0 .04 r
.65816 .37089 .66415 .35789 .67835 .35188 .67254 .36553 Mtetra
.075 0 0 r
.67254 .36553 .67835 .35188 .69235 .34118 .68671 .35474 Mtetra
0 0 0 r
.68671 .35474 .69235 .34118 .70613 .32622 .70062 .33896 Mtetra
.70062 .33896 .70613 .32622 .71968 .30782 .71426 .31908 Mtetra
.71426 .31908 .71968 .30782 .73301 .28701 .72764 .29626 Mtetra
.657 .807 .365 r
.72764 .29626 .73301 .28701 .74617 .26491 .74081 .27181 Mtetra
.775 .882 .461 r
.74081 .27181 .74617 .26491 .75923 .24262 .75384 .247 Mtetra
.859 .933 .555 r
.75384 .247 .75923 .24262 .77225 .22105 .76681 .2229 Mtetra
.912 .962 .642 r
.76681 .2229 .77225 .22105 .78531 .2009 .7798 .20036 Mtetra
.411 .634 .947 r
.13669 .36999 .14474 .37798 .15542 .37894 .14739 .37085 Mtetra
.327 .59 .94 r
.14739 .37085 .15542 .37894 .16606 .38102 .15805 .37278 Mtetra
.227 .532 .921 r
.15805 .37278 .16606 .38102 .17665 .38429 .16867 .37589 Mtetra
.115 .46 .888 r
.16867 .37589 .17665 .38429 .18722 .38882 .17925 .38022 Mtetra
.003 .382 .843 r
.17925 .38022 .18722 .38882 .19777 .3946 .18982 .38575 Mtetra
0 .308 .794 r
.18982 .38575 .19777 .3946 .20832 .40155 .2004 .39239 Mtetra
0 .249 .752 r
.2004 .39239 .20832 .40155 .2189 .40949 .21101 .39998 Mtetra
0 .214 .728 r
.21101 .39998 .2189 .40949 .22956 .41817 .22169 .40825 Mtetra
0 .207 .726 r
.22169 .40825 .22956 .41817 .24032 .42724 .23248 .41685 Mtetra
0 .231 .747 r
.23248 .41685 .24032 .42724 .25124 .43628 .24342 .42539 Mtetra
0 .281 .784 r
.24342 .42539 .25124 .43628 .26234 .44481 .25455 .43338 Mtetra
.068 .351 .824 r
.25455 .43338 .26234 .44481 .27367 .45233 .26591 .44036 Mtetra
.208 .427 .854 r
.26591 .44036 .27367 .45233 .28525 .45834 .27752 .44587 Mtetra
.344 .496 .866 r
.27752 .44587 .28525 .45834 .2971 .46242 .2894 .44948 Mtetra
.461 .551 .862 r
.2894 .44948 .2971 .46242 .30922 .46421 .30154 .45087 Mtetra
.553 .591 .846 r
.30154 .45087 .30922 .46421 .32159 .46346 .31394 .44982 Mtetra
.623 .62 .827 r
.31394 .44982 .32159 .46346 .33421 .46007 .32657 .44626 Mtetra
.675 .641 .809 r
.32657 .44626 .33421 .46007 .34703 .45407 .33941 .44021 Mtetra
.713 .657 .792 r
.33941 .44021 .34703 .45407 .36002 .44563 .35242 .43184 Mtetra
.742 .67 .779 r
.35242 .43184 .36002 .44563 .37314 .43501 .36557 .42142 Mtetra
.764 .68 .77 r
.36557 .42142 .37314 .43501 .38635 .42259 .3788 .4093 Mtetra
.781 .69 .764 r
.3788 .4093 .38635 .42259 .39961 .40879 .39208 .3959 Mtetra
.792 .699 .762 r
.39208 .3959 .39961 .40879 .41289 .39409 .40538 .38166 Mtetra
.8 .708 .763 r
.40538 .38166 .41289 .39409 .42616 .37901 .41868 .36706 Mtetra
.804 .716 .768 r
.41868 .36706 .42616 .37901 .4394 .36404 .43196 .35262 Mtetra
.802 .724 .778 r
.43196 .35262 .4394 .36404 .4526 .34972 .4452 .33884 Mtetra
.795 .732 .794 r
.4452 .33884 .4526 .34972 .46577 .33659 .4584 .32626 Mtetra
.778 .739 .817 r
.4584 .32626 .46577 .33659 .47889 .32517 .47156 .31543 Mtetra
.747 .743 .849 r
.47156 .31543 .47889 .32517 .49201 .31599 .48471 .30689 Mtetra
.69 .742 .891 r
.48471 .30689 .49201 .31599 .50512 .30952 .49787 .30114 Mtetra
.583 .722 .939 r
.49787 .30114 .50512 .30952 .51828 .30614 .51106 .29862 Mtetra
.385 .655 .964 r
.51106 .29862 .51828 .30614 .53152 .30612 .52433 .2996 Mtetra
.067 .491 .894 r
.52433 .2996 .53152 .30612 .54488 .30947 .53773 .30417 Mtetra
0 .249 .685 r
.53773 .30417 .54488 .30947 .55841 .31598 .55131 .31212 Mtetra
.524 0 0 r
.55131 .31212 .55841 .31598 .57214 .3251 .56509 .32292 Mtetra
.643 .086 0 r
.56509 .32292 .57214 .3251 .5861 .33596 .57912 .33566 Mtetra
.686 .141 0 r
.57912 .33566 .5861 .33596 .60026 .34737 .59338 .34911 Mtetra
.682 .146 0 r
.59338 .34911 .60026 .34737 .61462 .35795 .60785 .36179 Mtetra
.637 .107 0 r
.60785 .36179 .61462 .35795 .62911 .36626 .62248 .37211 Mtetra
.547 .024 0 r
.62248 .37211 .62911 .36626 .64366 .37092 .63719 .37856 Mtetra
.399 0 0 r
.63719 .37856 .64366 .37092 .65816 .37089 .65186 .37991 Mtetra
.184 0 0 r
.65186 .37991 .65816 .37089 .67254 .36553 .66641 .3754 Mtetra
0 0 0 r
.66641 .3754 .67254 .36553 .68671 .35474 .68074 .36483 Mtetra
.68074 .36483 .68671 .35474 .70062 .33896 .6948 .34861 Mtetra
.6948 .34861 .70062 .33896 .71426 .31908 .70854 .32767 Mtetra
.702 .844 .415 r
.70854 .32767 .71426 .31908 .72764 .29626 .722 .30328 Mtetra
.808 .892 .474 r
.722 .30328 .72764 .29626 .74081 .27181 .73521 .2769 Mtetra
.879 .923 .532 r
.73521 .2769 .74081 .27181 .75384 .247 .74824 .24994 Mtetra
.925 .942 .591 r
.74824 .24994 .75384 .247 .76681 .2229 .7612 .22365 Mtetra
.949 .951 .65 r
.7612 .22365 .76681 .2229 .7798 .20036 .77415 .199 Mtetra
.43 .635 .942 r
.12861 .36168 .13669 .36999 .14739 .37085 .13934 .36234 Mtetra
.357 .595 .936 r
.13934 .36234 .14739 .37085 .15805 .37278 .15003 .36404 Mtetra
.272 .543 .922 r
.15003 .36404 .15805 .37278 .16867 .37589 .16069 .36685 Mtetra
.18 .482 .897 r
.16069 .36685 .16867 .37589 .17925 .38022 .17131 .37082 Mtetra
.09 .416 .865 r
.17131 .37082 .17925 .38022 .18982 .38575 .18192 .37593 Mtetra
.016 .356 .83 r
.18192 .37593 .18982 .38575 .2004 .39239 .19253 .38209 Mtetra
0 .309 .801 r
.19253 .38209 .2004 .39239 .21101 .39998 .20318 .38912 Mtetra
0 .283 .785 r
.20318 .38912 .21101 .39998 .22169 .40825 .2139 .39676 Mtetra
0 .28 .783 r
.2139 .39676 .22169 .40825 .23248 .41685 .22474 .40469 Mtetra
.021 .3 .793 r
.22474 .40469 .23248 .41685 .24342 .42539 .23572 .41251 Mtetra
.104 .339 .809 r
.23572 .41251 .24342 .42539 .25455 .43338 .2469 .41979 Mtetra
.205 .388 .824 r
.2469 .41979 .25455 .43338 .26591 .44036 .25829 .42606 Mtetra
.311 .44 .83 r
.25829 .42606 .26591 .44036 .27752 .44587 .26994 .4309 Mtetra
.41 .487 .828 r
.26994 .4309 .27752 .44587 .2894 .44948 .28184 .43394 Mtetra
.495 .526 .818 r
.28184 .43394 .2894 .44948 .30154 .45087 .294 .43487 Mtetra
.564 .557 .805 r
.294 .43487 .30154 .45087 .31394 .44982 .30642 .4335 Mtetra
.618 .582 .791 r
.30642 .4335 .31394 .44982 .32657 .44626 .31906 .42977 Mtetra
.661 .602 .778 r
.31906 .42977 .32657 .44626 .33941 .44021 .33191 .42373 Mtetra
.694 .618 .767 r
.33191 .42373 .33941 .44021 .35242 .43184 .34493 .41552 Mtetra
.721 .632 .759 r
.34493 .41552 .35242 .43184 .36557 .42142 .35807 .40542 Mtetra
.741 .645 .753 r
.35807 .40542 .36557 .42142 .3788 .4093 .3713 .39374 Mtetra
.757 .656 .75 r
.3713 .39374 .3788 .4093 .39208 .3959 .38459 .38087 Mtetra
.769 .667 .75 r
.38459 .38087 .39208 .3959 .40538 .38166 .39791 .36724 Mtetra
.778 .677 .753 r
.39791 .36724 .40538 .38166 .41868 .36706 .41122 .35328 Mtetra
.782 .686 .759 r
.41122 .35328 .41868 .36706 .43196 .35262 .42452 .33949 Mtetra
.781 .695 .769 r
.42452 .33949 .43196 .35262 .4452 .33884 .43778 .32636 Mtetra
.773 .702 .784 r
.43778 .32636 .4452 .33884 .4584 .32626 .45101 .31441 Mtetra
.757 .707 .806 r
.45101 .31441 .4584 .32626 .47156 .31543 .4642 .30419 Mtetra
.725 .708 .835 r
.4642 .30419 .47156 .31543 .48471 .30689 .47738 .29625 Mtetra
.667 .7 .871 r
.47738 .29625 .48471 .30689 .49787 .30114 .49056 .29111 Mtetra
.565 .673 .911 r
.49056 .29111 .49787 .30114 .51106 .29862 .50378 .28923 Mtetra
.39 .603 .932 r
.50378 .28923 .51106 .29862 .52433 .2996 .51708 .29094 Mtetra
.122 .463 .89 r
.51708 .29094 .52433 .2996 .53773 .30417 .5305 .29633 Mtetra
0 .265 .752 r
.5305 .29633 .53773 .30417 .55131 .31212 .5441 .30525 Mtetra
0 .08 .571 r
.5441 .30525 .55131 .31212 .56509 .32292 .55791 .31719 Mtetra
.57 .042 0 r
.55791 .31719 .56509 .32292 .57912 .33566 .57198 .33124 Mtetra
.638 .1 0 r
.57198 .33124 .57912 .33566 .59338 .34911 .58629 .34618 Mtetra
.652 .102 0 r
.58629 .34618 .59338 .34911 .60785 .36179 .60084 .36046 Mtetra
.615 .048 0 r
.60084 .36046 .60785 .36179 .62248 .37211 .61557 .37241 Mtetra
.512 0 0 r
.61557 .37241 .62248 .37211 .63719 .37856 .63039 .38041 Mtetra
.298 0 0 r
.63039 .38041 .63719 .37856 .65186 .37991 .64521 .38309 Mtetra
0 0 0 r
.64521 .38309 .65186 .37991 .66641 .3754 .6599 .37955 Mtetra
.429 .825 .609 r
.6599 .37955 .66641 .3754 .68074 .36483 .67439 .3695 Mtetra
.687 .927 .614 r
.67439 .3695 .68074 .36483 .6948 .34861 .68858 .3533 Mtetra
.824 .949 .599 r
.68858 .3533 .6948 .34861 .70854 .32767 .70245 .33185 Mtetra
.896 .946 .59 r
.70245 .33185 .70854 .32767 .722 .30328 .716 .30649 Mtetra
.935 .94 .593 r
.716 .30649 .722 .30328 .73521 .2769 .72928 .27878 Mtetra
.958 .934 .608 r
.72928 .27878 .73521 .2769 .74824 .24994 .74236 .25027 Mtetra
.97 .93 .634 r
.74236 .25027 .74824 .24994 .7612 .22365 .75533 .22232 Mtetra
.973 .926 .668 r
.75533 .22232 .7612 .22365 .77415 .199 .76829 .19603 Mtetra
.452 .638 .936 r
.1205 .35308 .12861 .36168 .13934 .36234 .13127 .35346 Mtetra
.39 .602 .932 r
.13127 .35346 .13934 .36234 .15003 .36404 .14201 .35482 Mtetra
.32 .556 .92 r
.14201 .35482 .15003 .36404 .16069 .36685 .15271 .35722 Mtetra
.245 .504 .902 r
.15271 .35722 .16069 .36685 .17131 .37082 .16338 .36071 Mtetra
.176 .45 .878 r
.16338 .36071 .17131 .37082 .18192 .37593 .17404 .36525 Mtetra
.12 .4 .852 r
.17404 .36525 .18192 .37593 .19253 .38209 .18471 .37075 Mtetra
.086 .362 .83 r
.18471 .37075 .19253 .38209 .20318 .38912 .19542 .37704 Mtetra
.081 .341 .815 r
.19542 .37704 .20318 .38912 .2139 .39676 .2062 .38389 Mtetra
.104 .338 .808 r
.2062 .38389 .2139 .39676 .22474 .40469 .2171 .39096 Mtetra
.153 .351 .808 r
.2171 .39096 .22474 .40469 .23572 .41251 .22814 .3979 Mtetra
.221 .378 .809 r
.22814 .3979 .23572 .41251 .2469 .41979 .23936 .40429 Mtetra
.299 .411 .809 r
.23936 .40429 .2469 .41979 .25829 .42606 .25081 .40972 Mtetra
.379 .446 .804 r
.25081 .40972 .25829 .42606 .26994 .4309 .26249 .4138 Mtetra
.452 .479 .797 r
.26249 .4138 .26994 .4309 .28184 .43394 .27442 .41618 Mtetra
.516 .508 .786 r
.27442 .41618 .28184 .43394 .294 .43487 .2866 .4166 Mtetra
.569 .534 .775 r
.2866 .4166 .294 .43487 .30642 .4335 .29902 .41491 Mtetra
.614 .555 .765 r
.29902 .41491 .30642 .4335 .31906 .42977 .31167 .41104 Mtetra
.649 .573 .756 r
.31167 .41104 .31906 .42977 .33191 .42373 .32451 .40504 Mtetra
.679 .589 .748 r
.32451 .40504 .33191 .42373 .34493 .41552 .33752 .39708 Mtetra
.702 .604 .743 r
.33752 .39708 .34493 .41552 .35807 .40542 .35065 .38738 Mtetra
.722 .617 .74 r
.35065 .38738 .35807 .40542 .3713 .39374 .36387 .37625 Mtetra
.737 .629 .739 r
.36387 .37625 .3713 .39374 .38459 .38087 .37715 .36403 Mtetra
.749 .641 .741 r
.37715 .36403 .38459 .38087 .39791 .36724 .39047 .35112 Mtetra
.757 .652 .745 r
.39047 .35112 .39791 .36724 .41122 .35328 .40378 .33792 Mtetra
.762 .661 .751 r
.40378 .33792 .41122 .35328 .42452 .33949 .41708 .32487 Mtetra
.761 .67 .762 r
.41708 .32487 .42452 .33949 .43778 .32636 .43036 .31246 Mtetra
.754 .677 .776 r
.43036 .31246 .43778 .32636 .45101 .31441 .4436 .30117 Mtetra
.737 .68 .795 r
.4436 .30117 .45101 .31441 .4642 .30419 .45682 .29155 Mtetra
.705 .678 .821 r
.45682 .29155 .4642 .30419 .47738 .29625 .47002 .28412 Mtetra
.65 .665 .851 r
.47002 .28412 .47738 .29625 .49056 .29111 .48322 .27943 Mtetra
.556 .632 .882 r
.48322 .27943 .49056 .29111 .50378 .28923 .49645 .27794 Mtetra
.407 .564 .898 r
.49645 .27794 .50378 .28923 .51708 .29094 .50976 .28 Mtetra
.195 .448 .873 r
.50976 .28 .51708 .29094 .5305 .29633 .5232 .28576 Mtetra
0 .294 .792 r
.5232 .28576 .5305 .29633 .5441 .30525 .5368 .29508 Mtetra
0 .146 .68 r
.5368 .29508 .5441 .30525 .55791 .31719 .55062 .3075 Mtetra
0 .041 .582 r
.55062 .3075 .55791 .31719 .57198 .33124 .56469 .32216 Mtetra
0 0 .527 r
.56469 .32216 .57198 .33124 .58629 .34618 .57902 .33787 Mtetra
0 .003 .524 r
.57902 .33787 .58629 .34618 .60084 .36046 .5936 .35308 Mtetra
0 .082 .582 r
.5936 .35308 .60084 .36046 .61557 .37241 .60837 .36609 Mtetra
0 .253 .712 r
.60837 .36609 .61557 .37241 .63039 .38041 .62327 .37523 Mtetra
.055 .533 .891 r
.62327 .37523 .63039 .38041 .64521 .38309 .63817 .37904 Mtetra
.458 .821 .995 r
.63817 .37904 .64521 .38309 .6599 .37955 .65299 .37651 Mtetra
.751 .954 .941 r
.65299 .37651 .6599 .37955 .67439 .3695 .6676 .36724 Mtetra
.888 .967 .835 r
.6676 .36724 .67439 .3695 .68858 .3533 .68193 .3515 Mtetra
.944 .947 .751 r
.68193 .3515 .68858 .3533 .70245 .33185 .69593 .33016 Mtetra
.968 .924 .698 r
.69593 .33016 .70245 .33185 .716 .30649 .7096 .30455 Mtetra
.977 .908 .669 r
.7096 .30455 .716 .30649 .72928 .27878 .72298 .27628 Mtetra
.981 .896 .66 r
.72298 .27628 .72928 .27878 .74236 .25027 .73614 .24696 Mtetra
.979 .889 .666 r
.73614 .24696 .74236 .25027 .75533 .22232 .74917 .21807 Mtetra
.973 .885 .683 r
.74917 .21807 .75533 .22232 .76829 .19603 .76216 .19078 Mtetra
.475 .643 .93 r
.11235 .34422 .1205 .35308 .13127 .35346 .12317 .34425 Mtetra
.424 .61 .926 r
.12317 .34425 .13127 .35346 .14201 .35482 .13396 .34519 Mtetra
.366 .571 .917 r
.13396 .34519 .14201 .35482 .15271 .35722 .14472 .34709 Mtetra
.307 .526 .902 r
.14472 .34709 .15271 .35722 .16338 .36071 .15546 .34997 Mtetra
.254 .481 .883 r
.15546 .34997 .16338 .36071 .17404 .36525 .16619 .35382 Mtetra
.213 .439 .863 r
.16619 .35382 .17404 .36525 .18471 .37075 .17693 .35854 Mtetra
.19 .407 .843 r
.17693 .35854 .18471 .37075 .19542 .37704 .18772 .36396 Mtetra
.19 .388 .827 r
.18772 .36396 .19542 .37704 .2062 .38389 .19857 .36986 Mtetra
.211 .382 .816 r
.19857 .36986 .2062 .38389 .2171 .39096 .20954 .37595 Mtetra
.252 .389 .808 r
.20954 .37595 .2171 .39096 .22814 .3979 .22065 .38187 Mtetra
.305 .406 .8 r
.22065 .38187 .22814 .3979 .23936 .40429 .23193 .38727 Mtetra
.365 .428 .793 r
.23193 .38727 .23936 .40429 .25081 .40972 .24343 .39177 Mtetra
.425 .452 .784 r
.24343 .39177 .25081 .40972 .26249 .4138 .25515 .395 Mtetra
.481 .476 .775 r
.25515 .395 .26249 .4138 .27442 .41618 .26711 .39668 Mtetra
.531 .498 .765 r
.26711 .39668 .27442 .41618 .2866 .4166 .27931 .39658 Mtetra
.573 .519 .756 r
.27931 .39658 .2866 .4166 .29902 .41491 .29174 .39455 Mtetra
.61 .537 .748 r
.29174 .39455 .29902 .41491 .31167 .41104 .30438 .39056 Mtetra
.64 .554 .741 r
.30438 .39056 .31167 .41104 .32451 .40504 .31721 .38466 Mtetra
.666 .569 .736 r
.31721 .38466 .32451 .40504 .33752 .39708 .33019 .37699 Mtetra
.687 .583 .733 r
.33019 .37699 .33752 .39708 .35065 .38738 .3433 .36777 Mtetra
.705 .596 .732 r
.3433 .36777 .35065 .38738 .36387 .37625 .3565 .35726 Mtetra
.72 .609 .732 r
.3565 .35726 .36387 .37625 .37715 .36403 .36976 .34577 Mtetra
.731 .62 .735 r
.36976 .34577 .37715 .36403 .39047 .35112 .38305 .33365 Mtetra
.739 .631 .739 r
.38305 .33365 .39047 .35112 .40378 .33792 .39635 .32127 Mtetra
.744 .641 .747 r
.39635 .32127 .40378 .33792 .41708 .32487 .40965 .30903 Mtetra
.743 .65 .757 r
.40965 .30903 .41708 .32487 .43036 .31246 .42293 .29737 Mtetra
.736 .656 .77 r
.42293 .29737 .43036 .31246 .4436 .30117 .43619 .28675 Mtetra
.72 .658 .787 r
.43619 .28675 .4436 .30117 .45682 .29155 .44942 .27767 Mtetra
.69 .653 .809 r
.44942 .27767 .45682 .29155 .47002 .28412 .46263 .27065 Mtetra
.638 .637 .833 r
.46263 .27065 .47002 .28412 .48322 .27943 .47585 .26623 Mtetra
.555 .603 .856 r
.47585 .26623 .48322 .27943 .49645 .27794 .48909 .26485 Mtetra
.431 .54 .866 r
.48909 .26485 .49645 .27794 .50976 .28 .50241 .26689 Mtetra
.267 .444 .85 r
.50241 .26689 .50976 .28 .5232 .28576 .51584 .27251 Mtetra
.086 .325 .802 r
.51584 .27251 .5232 .28576 .5368 .29508 .52944 .28163 Mtetra
0 .213 .736 r
.52944 .28163 .5368 .29508 .55062 .3075 .54324 .29383 Mtetra
0 .134 .682 r
.54324 .29383 .55062 .3075 .56469 .32216 .55729 .30834 Mtetra
0 .102 .658 r
.55729 .30834 .56469 .32216 .57902 .33787 .5716 .32401 Mtetra
0 .123 .673 r
.5716 .32401 .57902 .33787 .5936 .35308 .58616 .33937 Mtetra
0 .2 .728 r
.58616 .33937 .5936 .35308 .60837 .36609 .60093 .35277 Mtetra
.083 .332 .808 r
.60093 .35277 .60837 .36609 .62327 .37523 .61584 .36251 Mtetra
.316 .497 .877 r
.61584 .36251 .62327 .37523 .63817 .37904 .63079 .36712 Mtetra
.55 .646 .898 r
.63079 .36712 .63817 .37904 .65299 .37651 .64568 .36551 Mtetra
.726 .744 .866 r
.64568 .36551 .65299 .37651 .6676 .36724 .66038 .35719 Mtetra
.835 .793 .812 r
.66038 .35719 .6676 .36724 .68193 .3515 .67483 .34232 Mtetra
.896 .814 .76 r
.67483 .34232 .68193 .3515 .69593 .33016 .68895 .32169 Mtetra
.929 .822 .72 r
.68895 .32169 .69593 .33016 .7096 .30455 .70276 .29658 Mtetra
.946 .826 .694 r
.70276 .29658 .7096 .30455 .72298 .27628 .71626 .26857 Mtetra
.954 .828 .681 r
.71626 .26857 .72298 .27628 .73614 .24696 .72954 .2393 Mtetra
.955 .83 .681 r
.72954 .2393 .73614 .24696 .74917 .21807 .74267 .21027 Mtetra
.951 .832 .691 r
.74267 .21027 .74917 .21807 .76216 .19078 .75576 .18272 Mtetra
.499 .649 .925 r
.10416 .33514 .11235 .34422 .12317 .34425 .11504 .33477 Mtetra
.456 .62 .921 r
.11504 .33477 .12317 .34425 .13396 .34519 .1259 .33522 Mtetra
.41 .585 .913 r
.1259 .33522 .13396 .34519 .14472 .34709 .13673 .33654 Mtetra
.364 .547 .901 r
.13673 .33654 .14472 .34709 .15546 .34997 .14754 .33875 Mtetra
.322 .508 .884 r
.14754 .33875 .15546 .34997 .16619 .35382 .15835 .34182 Mtetra
.291 .473 .866 r
.15835 .34182 .16619 .35382 .17693 .35854 .16918 .34565 Mtetra
.276 .444 .848 r
.16918 .34565 .17693 .35854 .18772 .36396 .18005 .35011 Mtetra
.277 .425 .831 r
.18005 .35011 .18772 .36396 .19857 .36986 .19099 .35497 Mtetra
.295 .417 .816 r
.19099 .35497 .19857 .36986 .20954 .37595 .20204 .35997 Mtetra
.327 .419 .803 r
.20204 .35997 .20954 .37595 .22065 .38187 .21323 .36481 Mtetra
.368 .428 .792 r
.21323 .36481 .22065 .38187 .23193 .38727 .22458 .36914 Mtetra
.413 .442 .781 r
.22458 .36914 .23193 .38727 .24343 .39177 .23613 .37264 Mtetra
.459 .459 .77 r
.23613 .37264 .24343 .39177 .25515 .395 .2479 .37501 Mtetra
.502 .476 .761 r
.2479 .37501 .25515 .395 .26711 .39668 .25989 .37597 Mtetra
.542 .493 .751 r
.25989 .37597 .26711 .39668 .27931 .39658 .2721 .37533 Mtetra
.577 .51 .743 r
.2721 .37533 .27931 .39658 .29174 .39455 .28453 .37299 Mtetra
.607 .526 .737 r
.28453 .37299 .29174 .39455 .30438 .39056 .29716 .3689 Mtetra
.633 .541 .732 r
.29716 .3689 .30438 .39056 .31721 .38466 .30996 .36313 Mtetra
.656 .555 .728 r
.30996 .36313 .31721 .38466 .33019 .37699 .32292 .35579 Mtetra
.675 .568 .727 r
.32292 .35579 .33019 .37699 .3433 .36777 .33599 .34708 Mtetra
.692 .581 .727 r
.33599 .34708 .3433 .36777 .3565 .35726 .34916 .33723 Mtetra
.705 .593 .728 r
.34916 .33723 .3565 .35726 .36976 .34577 .36239 .32651 Mtetra
.716 .605 .732 r
.36239 .32651 .36976 .34577 .38305 .33365 .37565 .31523 Mtetra
.724 .616 .737 r
.37565 .31523 .38305 .33365 .39635 .32127 .38894 .3037 Mtetra
.728 .626 .744 r
.38894 .3037 .39635 .32127 .40965 .30903 .40222 .29229 Mtetra
.728 .634 .754 r
.40222 .29229 .40965 .30903 .42293 .29737 .4155 .28137 Mtetra
.722 .64 .766 r
.4155 .28137 .42293 .29737 .43619 .28675 .42876 .27139 Mtetra
.706 .641 .781 r
.42876 .27139 .43619 .28675 .44942 .27767 .442 .26279 Mtetra
.678 .635 .799 r
.442 .26279 .44942 .27767 .46263 .27065 .45522 .25608 Mtetra
.631 .618 .819 r
.45522 .25608 .46263 .27065 .47585 .26623 .46845 .25174 Mtetra
.56 .584 .835 r
.46845 .25174 .47585 .26623 .48909 .26485 .48171 .25022 Mtetra
.458 .528 .841 r
.48171 .25022 .48909 .26485 .50241 .26689 .49503 .25187 Mtetra
.331 .448 .829 r
.49503 .25187 .50241 .26689 .51584 .27251 .50846 .2569 Mtetra
.197 .355 .796 r
.50846 .2569 .51584 .27251 .52944 .28163 .52204 .26525 Mtetra
.084 .269 .754 r
.52204 .26525 .52944 .28163 .54324 .29383 .53581 .27658 Mtetra
.015 .21 .719 r
.53581 .27658 .54324 .29383 .55729 .30834 .54981 .2902 Mtetra
0 .187 .703 r
.54981 .2902 .55729 .30834 .5716 .32401 .56407 .30505 Mtetra
.037 .204 .708 r
.56407 .30505 .5716 .32401 .58616 .33937 .57858 .31978 Mtetra
.125 .258 .731 r
.57858 .31978 .58616 .33937 .60093 .35277 .5933 .33282 Mtetra
.253 .34 .76 r
.5933 .33282 .60093 .35277 .61584 .36251 .60818 .34256 Mtetra
.4 .435 .781 r
.60818 .34256 .61584 .36251 .63079 .36712 .62312 .34754 Mtetra
.543 .525 .785 r
.62312 .34754 .63079 .36712 .64568 .36551 .63803 .34666 Mtetra
.663 .599 .773 r
.63803 .34666 .64568 .36551 .66038 .35719 .65279 .33934 Mtetra
.754 .655 .752 r
.65279 .33934 .66038 .35719 .67483 .34232 .66732 .32565 Mtetra
.817 .693 .728 r
.66732 .32565 .67483 .34232 .68895 .32169 .68157 .30625 Mtetra
.86 .72 .706 r
.68157 .30625 .68895 .32169 .70276 .29658 .6955 .28233 Mtetra
.888 .74 .691 r
.6955 .28233 .70276 .29658 .71626 .26857 .70915 .25538 Mtetra
.905 .755 .683 r
.70915 .25538 .71626 .26857 .72954 .2393 .72257 .227 Mtetra
.914 .767 .684 r
.72257 .227 .72954 .2393 .74267 .21027 .73584 .19866 Mtetra
.917 .778 .692 r
.73584 .19866 .74267 .21027 .75576 .18272 .74906 .17162 Mtetra
.521 .656 .92 r
.09592 .32589 .10416 .33514 .11504 .33477 .10687 .32509 Mtetra
.487 .63 .916 r
.10687 .32509 .11504 .33477 .1259 .33522 .1178 .32502 Mtetra
.449 .6 .909 r
.1178 .32502 .1259 .33522 .13673 .33654 .12871 .32571 Mtetra
.413 .567 .897 r
.12871 .32571 .13673 .33654 .14754 .33875 .1396 .32719 Mtetra
.381 .533 .883 r
.1396 .32719 .14754 .33875 .15835 .34182 .15051 .32941 Mtetra
.357 .502 .866 r
.15051 .32941 .15835 .34182 .16918 .34565 .16143 .33231 Mtetra
.345 .476 .848 r
.16143 .33231 .16918 .34565 .18005 .35011 .17239 .33574 Mtetra
.346 .457 .831 r
.17239 .33574 .18005 .35011 .19099 .35497 .18343 .33951 Mtetra
.36 .447 .815 r
.18343 .33951 .19099 .35497 .20204 .35997 .19457 .34339 Mtetra
.384 .444 .8 r
.19457 .34339 .20204 .35997 .21323 .36481 .20584 .34709 Mtetra
.415 .448 .786 r
.20584 .34709 .21323 .36481 .22458 .36914 .21727 .35034 Mtetra
.45 .456 .774 r
.21727 .35034 .22458 .36914 .23613 .37264 .22889 .35284 Mtetra
.485 .467 .762 r
.22889 .35284 .23613 .37264 .2479 .37501 .2407 .35432 Mtetra
.519 .48 .753 r
.2407 .35432 .2479 .37501 .25989 .37597 .25272 .35457 Mtetra
.551 .493 .744 r
.25272 .35457 .25989 .37597 .2721 .37533 .26494 .35342 Mtetra
.58 .507 .737 r
.26494 .35342 .2721 .37533 .28453 .37299 .27737 .35077 Mtetra
.606 .52 .731 r
.27737 .35077 .28453 .37299 .29716 .3689 .28998 .34661 Mtetra
.628 .533 .727 r
.28998 .34661 .29716 .3689 .30996 .36313 .30276 .34098 Mtetra
.648 .546 .725 r
.30276 .34098 .30996 .36313 .32292 .35579 .31568 .33399 Mtetra
.665 .559 .724 r
.31568 .33399 .32292 .35579 .33599 .34708 .32872 .32581 Mtetra
.68 .571 .725 r
.32872 .32581 .33599 .34708 .34916 .33723 .34184 .31663 Mtetra
.693 .583 .727 r
.34184 .31663 .34916 .33723 .36239 .32651 .35503 .30669 Mtetra
.703 .594 .731 r
.35503 .30669 .36239 .32651 .37565 .31523 .36826 .29624 Mtetra
.711 .605 .737 r
.36826 .29624 .37565 .31523 .38894 .3037 .38152 .28556 Mtetra
.715 .615 .744 r
.38152 .28556 .38894 .3037 .40222 .29229 .39479 .27496 Mtetra
.715 .623 .753 r
.39479 .27496 .40222 .29229 .4155 .28137 .40806 .26478 Mtetra
.71 .628 .764 r
.40806 .26478 .4155 .28137 .42876 .27139 .42131 .25539 Mtetra
.696 .629 .778 r
.42131 .25539 .42876 .27139 .442 .26279 .43456 .24721 Mtetra
.67 .623 .793 r
.43456 .24721 .442 .26279 .45522 .25608 .44779 .24069 Mtetra
.629 .606 .808 r
.44779 .24069 .45522 .25608 .46845 .25174 .46104 .23628 Mtetra
.568 .575 .82 r
.46104 .23628 .46845 .25174 .48171 .25022 .47431 .2344 Mtetra
.486 .525 .823 r
.47431 .2344 .48171 .25022 .49503 .25187 .48763 .23539 Mtetra
.387 .458 .812 r
.48763 .23539 .49503 .25187 .50846 .2569 .50105 .23945 Mtetra
.286 .383 .788 r
.50105 .23945 .50846 .2569 .52204 .26525 .51461 .24657 Mtetra
.203 .315 .756 r
.51461 .24657 .52204 .26525 .53581 .27658 .52834 .25647 Mtetra
.155 .267 .728 r
.52834 .25647 .53581 .27658 .54981 .2902 .54229 .26856 Mtetra
.148 .247 .711 r
.54229 .26856 .54981 .2902 .56407 .30505 .55647 .28191 Mtetra
.18 .256 .706 r
.55647 .28191 .56407 .30505 .57858 .31978 .5709 .2953 Mtetra
.247 .29 .71 r
.5709 .2953 .57858 .31978 .5933 .33282 .58554 .30732 Mtetra
.336 .342 .718 r
.58554 .30732 .5933 .33282 .60818 .34256 .60035 .31646 Mtetra
.436 .403 .723 r
.60035 .31646 .60818 .34256 .62312 .34754 .61524 .32136 Mtetra
.534 .465 .724 r
.61524 .32136 .62312 .34754 .63803 .34666 .63012 .32092 Mtetra
.623 .521 .719 r
.63012 .32092 .63803 .34666 .65279 .33934 .6449 .31454 Mtetra
.696 .57 .709 r
.6449 .31454 .65279 .33934 .66732 .32565 .65949 .3022 Mtetra
.755 .61 .698 r
.65949 .3022 .66732 .32565 .68157 .30625 .67383 .28442 Mtetra
.799 .643 .688 r
.67383 .28442 .68157 .30625 .6955 .28233 .6879 .26224 Mtetra
.832 .669 .681 r
.6879 .26224 .6955 .28233 .70915 .25538 .7017 .23703 Mtetra
.855 .692 .679 r
.7017 .23703 .70915 .25538 .72257 .227 .71528 .21027 Mtetra
.87 .711 .682 r
.71528 .21027 .72257 .227 .73584 .19866 .72872 .18339 Mtetra
.878 .728 .691 r
.72872 .18339 .73584 .19866 .74906 .17162 .7421 .15757 Mtetra
.543 .663 .915 r
.08763 .31653 .09592 .32589 .10687 .32509 .09865 .31528 Mtetra
.515 .641 .911 r
.09865 .31528 .10687 .32509 .1178 .32502 .10965 .31466 Mtetra
.485 .614 .904 r
.10965 .31466 .1178 .32502 .12871 .32571 .12065 .3147 Mtetra
.456 .586 .894 r
.12065 .3147 .12871 .32571 .1396 .32719 .13164 .31543 Mtetra
.43 .556 .881 r
.13164 .31543 .1396 .32719 .15051 .32941 .14263 .31679 Mtetra
.412 .528 .865 r
.14263 .31679 .15051 .32941 .16143 .33231 .15366 .31873 Mtetra
.402 .504 .848 r
.15366 .31873 .16143 .33231 .17239 .33574 .16473 .32112 Mtetra
.402 .486 .831 r
.16473 .32112 .17239 .33574 .18343 .33951 .17587 .3238 Mtetra
.412 .474 .814 r
.17587 .3238 .18343 .33951 .19457 .34339 .1871 .32654 Mtetra
.429 .468 .798 r
.1871 .32654 .19457 .34339 .20584 .34709 .19846 .32913 Mtetra
.453 .467 .784 r
.19846 .32913 .20584 .34709 .21727 .35034 .20997 .3313 Mtetra
.479 .471 .771 r
.20997 .3313 .21727 .35034 .22889 .35284 .22165 .33281 Mtetra
.507 .478 .76 r
.22165 .33281 .22889 .35284 .2407 .35432 .23351 .33344 Mtetra
.534 .487 .75 r
.23351 .33344 .2407 .35432 .25272 .35457 .24556 .333 Mtetra
.56 .497 .742 r
.24556 .333 .25272 .35457 .26494 .35342 .2578 .33135 Mtetra
.584 .508 .735 r
.2578 .33135 .26494 .35342 .27737 .35077 .27022 .32843 Mtetra
.606 .519 .73 r
.27022 .32843 .27737 .35077 .28998 .34661 .28282 .3242 Mtetra
.625 .53 .727 r
.28282 .3242 .28998 .34661 .30276 .34098 .29557 .31872 Mtetra
.642 .542 .725 r
.29557 .31872 .30276 .34098 .31568 .33399 .30845 .31209 Mtetra
.658 .553 .725 r
.30845 .31209 .31568 .33399 .32872 .32581 .32144 .30442 Mtetra
.671 .565 .727 r
.32144 .30442 .32872 .32581 .34184 .31663 .33452 .2959 Mtetra
.683 .576 .729 r
.33452 .2959 .34184 .31663 .35503 .30669 .34767 .28671 Mtetra
.693 .588 .734 r
.34767 .28671 .35503 .30669 .36826 .29624 .36086 .27707 Mtetra
.7 .598 .739 r
.36086 .27707 .36826 .29624 .38152 .28556 .37409 .2672 Mtetra
.704 .608 .746 r
.37409 .2672 .38152 .28556 .39479 .27496 .38734 .25738 Mtetra
.705 .616 .755 r
.38734 .25738 .39479 .27496 .40806 .26478 .40059 .24789 Mtetra
.7 .621 .765 r
.40059 .24789 .40806 .26478 .42131 .25539 .41385 .23905 Mtetra
.688 .622 .777 r
.41385 .23905 .42131 .25539 .43456 .24721 .4271 .23123 Mtetra
.666 .616 .79 r
.4271 .23123 .43456 .24721 .44779 .24069 .44034 .22482 Mtetra
.631 .601 .802 r
.44034 .22482 .44779 .24069 .46104 .23628 .4536 .22023 Mtetra
.58 .573 .81 r
.4536 .22023 .46104 .23628 .47431 .2344 .46688 .21784 Mtetra
.513 .53 .812 r
.46688 .21784 .47431 .2344 .48763 .23539 .48021 .21796 Mtetra
.434 .474 .802 r
.48021 .21796 .48763 .23539 .50105 .23945 .49363 .22079 Mtetra
.356 .412 .782 r
.49363 .22079 .50105 .23945 .51461 .24657 .50716 .22635 Mtetra
.293 .354 .755 r
.50716 .22635 .51461 .24657 .52834 .25647 .52086 .23443 Mtetra
.256 .312 .73 r
.52086 .23443 .52834 .25647 .54229 .26856 .53475 .24452 Mtetra
.25 .292 .711 r
.53475 .24452 .54229 .26856 .55647 .28191 .54885 .25585 Mtetra
.274 .293 .699 r
.54885 .25585 .55647 .28191 .5709 .2953 .56318 .26736 Mtetra
.322 .313 .694 r
.56318 .26736 .5709 .2953 .58554 .30732 .57772 .2778 Mtetra
.386 .347 .693 r
.57772 .2778 .58554 .30732 .60035 .31646 .59242 .28583 Mtetra
.458 .389 .693 r
.59242 .28583 .60035 .31646 .61524 .32136 .60723 .29021 Mtetra
.53 .434 .691 r
.60723 .29021 .61524 .32136 .63012 .32092 .62206 .28991 Mtetra
.598 .478 .688 r
.62206 .28991 .63012 .32092 .6449 .31454 .63682 .28433 Mtetra
.658 .519 .683 r
.63682 .28433 .6449 .31454 .65949 .3022 .65144 .27335 Mtetra
.71 .556 .678 r
.65144 .27335 .65949 .3022 .67383 .28442 .66585 .2574 Mtetra
.752 .589 .674 r
.66585 .2574 .67383 .28442 .6879 .26224 .68003 .23734 Mtetra
.785 .617 .672 r
.68003 .23734 .6879 .26224 .7017 .23703 .69398 .21436 Mtetra
.811 .642 .674 r
.69398 .21436 .7017 .23703 .71528 .21027 .70773 .1898 Mtetra
.829 .665 .679 r
.70773 .1898 .71528 .21027 .72872 .18339 .72135 .16495 Mtetra
.841 .686 .69 r
.72135 .16495 .72872 .18339 .7421 .15757 .73491 .14094 Mtetra
.562 .671 .911 r
.07928 .3071 .08763 .31653 .09865 .31528 .09036 .3054 Mtetra
.539 .651 .907 r
.09036 .3054 .09865 .31528 .10965 .31466 .10145 .30424 Mtetra
.516 .628 .901 r
.10145 .30424 .10965 .31466 .12065 .3147 .11253 .30364 Mtetra
.492 .603 .891 r
.11253 .30364 .12065 .3147 .13164 .31543 .12362 .30361 Mtetra
.472 .577 .879 r
.12362 .30361 .13164 .31543 .14263 .31679 .13471 .30413 Mtetra
.457 .552 .865 r
.13471 .30413 .14263 .31679 .15366 .31873 .14584 .30513 Mtetra
.448 .53 .849 r
.14584 .30513 .15366 .31873 .16473 .32112 .15702 .3065 Mtetra
.447 .512 .832 r
.15702 .3065 .16473 .32112 .17587 .3238 .16826 .3081 Mtetra
.454 .499 .815 r
.16826 .3081 .17587 .3238 .1871 .32654 .1796 .30975 Mtetra
.466 .491 .8 r
.1796 .30975 .1871 .32654 .19846 .32913 .19105 .31125 Mtetra
.484 .487 .785 r
.19105 .31125 .19846 .32913 .20997 .3313 .20264 .3124 Mtetra
.504 .488 .772 r
.20264 .3124 .20997 .3313 .22165 .33281 .21438 .31297 Mtetra
.526 .491 .761 r
.21438 .31297 .22165 .33281 .23351 .33344 .22629 .31279 Mtetra
.547 .497 .751 r
.22629 .31279 .23351 .33344 .24556 .333 .23837 .3117 Mtetra
.568 .504 .743 r
.23837 .3117 .24556 .333 .2578 .33135 .25062 .3096 Mtetra
.588 .513 .737 r
.25062 .3096 .2578 .33135 .27022 .32843 .26305 .30641 Mtetra
.606 .522 .733 r
.26305 .30641 .27022 .32843 .28282 .3242 .27562 .30213 Mtetra
.623 .532 .73 r
.27562 .30213 .28282 .3242 .29557 .31872 .28834 .2968 Mtetra
.638 .542 .729 r
.28834 .2968 .29557 .31872 .30845 .31209 .30119 .29049 Mtetra
.652 .553 .729 r
.30119 .29049 .30845 .31209 .32144 .30442 .31414 .28331 Mtetra
.664 .563 .731 r
.31414 .28331 .32144 .30442 .33452 .2959 .32717 .27541 Mtetra
.675 .574 .734 r
.32717 .27541 .33452 .2959 .34767 .28671 .34028 .26692 Mtetra
.684 .585 .739 r
.34028 .26692 .34767 .28671 .36086 .27707 .35344 .25803 Mtetra
.691 .595 .744 r
.35344 .25803 .36086 .27707 .37409 .2672 .36664 .24893 Mtetra
.695 .605 .751 r
.36664 .24893 .37409 .2672 .38734 .25738 .37986 .23983 Mtetra
.696 .613 .759 r
.37986 .23983 .38734 .25738 .40059 .24789 .3931 .23097 Mtetra
.692 .618 .769 r
.3931 .23097 .40059 .24789 .41385 .23905 .40635 .22263 Mtetra
.682 .619 .779 r
.40635 .22263 .41385 .23905 .4271 .23123 .4196 .21512 Mtetra
.664 .615 .79 r
.4196 .21512 .4271 .23123 .44034 .22482 .43286 .20877 Mtetra
.634 .602 .799 r
.43286 .20877 .44034 .22482 .4536 .22023 .44613 .20394 Mtetra
.592 .578 .806 r
.44613 .20394 .4536 .22023 .46688 .21784 .45943 .20095 Mtetra
.538 .541 .806 r
.45943 .20095 .46688 .21784 .48021 .21796 .47277 .2001 Mtetra
.476 .494 .797 r
.47277 .2001 .48021 .21796 .49363 .22079 .48619 .20157 Mtetra
.414 .441 .78 r
.48619 .20157 .49363 .22079 .50716 .22635 .49971 .2054 Mtetra
.363 .391 .756 r
.49971 .2054 .50716 .22635 .52086 .23443 .51337 .21144 Mtetra
.332 .353 .733 r
.51337 .21144 .52086 .23443 .53475 .24452 .52721 .21927 Mtetra
.324 .331 .712 r
.52721 .21927 .53475 .24452 .54885 .25585 .54123 .22827 Mtetra
.34 .326 .697 r
.54123 .22827 .54885 .25585 .56318 .26736 .55546 .23753 Mtetra
.374 .336 .688 r
.55546 .23753 .56318 .26736 .57772 .2778 .56989 .24601 Mtetra
.42 .358 .681 r
.56989 .24601 .57772 .2778 .59242 .28583 .58448 .25256 Mtetra
.474 .387 .677 r
.58448 .25256 .59242 .28583 .60723 .29021 .59918 .25606 Mtetra
.53 .421 .674 r
.59918 .25606 .60723 .29021 .62206 .28991 .61393 .2556 Mtetra
.584 .455 .671 r
.61393 .2556 .62206 .28991 .63682 .28433 .62865 .25061 Mtetra
.634 .489 .669 r
.62865 .25061 .63682 .28433 .65144 .27335 .64326 .24093 Mtetra
.678 .522 .667 r
.64326 .24093 .65144 .27335 .66585 .2574 .65772 .22684 Mtetra
.716 .552 .666 r
.65772 .22684 .66585 .2574 .68003 .23734 .672 .20905 Mtetra
.748 .58 .667 r
.672 .20905 .68003 .23734 .69398 .21436 .68608 .18857 Mtetra
.774 .606 .671 r
.68608 .18857 .69398 .21436 .70773 .1898 .7 .16656 Mtetra
.794 .63 .679 r
.7 .16656 .70773 .1898 .72135 .16495 .71381 .14414 Mtetra
.808 .653 .691 r
.71381 .14414 .72135 .16495 .73491 .14094 .72756 .12235 Mtetra
.58 .679 .908 r
.07085 .29766 .07928 .3071 .09036 .3054 .08201 .29552 Mtetra
.561 .662 .904 r
.08201 .29552 .09036 .3054 .10145 .30424 .09318 .29383 Mtetra
.542 .642 .898 r
.09318 .29383 .10145 .30424 .11253 .30364 .10435 .29261 Mtetra
.524 .62 .89 r
.10435 .29261 .11253 .30364 .12362 .30361 .11553 .29186 Mtetra
.507 .597 .879 r
.11553 .29186 .12362 .30361 .13471 .30413 .12673 .29157 Mtetra
.495 .575 .865 r
.12673 .29157 .13471 .30413 .14584 .30513 .13796 .29167 Mtetra
.487 .554 .851 r
.13796 .29167 .14584 .30513 .15702 .3065 .14924 .29208 Mtetra
.485 .537 .835 r
.14924 .29208 .15702 .3065 .16826 .3081 .16059 .29266 Mtetra
.489 .523 .819 r
.16059 .29266 .16826 .3081 .1796 .30975 .17203 .29329 Mtetra
.498 .514 .804 r
.17203 .29329 .1796 .30975 .19105 .31125 .18357 .29377 Mtetra
.51 .508 .79 r
.18357 .29377 .19105 .31125 .20264 .3124 .19524 .29395 Mtetra
.526 .506 .777 r
.19524 .29395 .20264 .3124 .21438 .31297 .20704 .29365 Mtetra
.542 .507 .766 r
.20704 .29365 .21438 .31297 .22629 .31279 .219 .29273 Mtetra
.56 .51 .757 r
.219 .29273 .22629 .31279 .23837 .3117 .23112 .29104 Mtetra
.577 .515 .749 r
.23112 .29104 .23837 .3117 .25062 .3096 .24339 .28851 Mtetra
.593 .521 .743 r
.24339 .28851 .25062 .3096 .26305 .30641 .25581 .28509 Mtetra
.608 .529 .739 r
.25581 .28509 .26305 .30641 .27562 .30213 .26837 .28076 Mtetra
.623 .537 .737 r
.26837 .28076 .27562 .30213 .28834 .2968 .28106 .27556 Mtetra
.636 .546 .736 r
.28106 .27556 .28834 .2968 .30119 .29049 .29387 .26955 Mtetra
.648 .555 .736 r
.29387 .26955 .30119 .29049 .31414 .28331 .30678 .26282 Mtetra
.659 .565 .738 r
.30678 .26282 .31414 .28331 .32717 .27541 .31978 .25546 Mtetra
.669 .576 .742 r
.31978 .25546 .32717 .27541 .34028 .26692 .33285 .24761 Mtetra
.677 .586 .746 r
.33285 .24761 .34028 .26692 .35344 .25803 .34597 .23941 Mtetra
.683 .596 .751 r
.34597 .23941 .35344 .25803 .36664 .24893 .35914 .231 Mtetra
.688 .605 .758 r
.35914 .231 .36664 .24893 .37986 .23983 .37234 .22256 Mtetra
.689 .613 .766 r
.37234 .22256 .37986 .23983 .3931 .23097 .38557 .21428 Mtetra
.686 .618 .774 r
.38557 .21428 .3931 .23097 .40635 .22263 .39881 .20639 Mtetra
.678 .62 .783 r
.39881 .20639 .40635 .22263 .4196 .21512 .41207 .19915 Mtetra
.663 .617 .793 r
.41207 .19915 .4196 .21512 .43286 .20877 .42534 .19283 Mtetra
.639 .606 .801 r
.42534 .19283 .43286 .20877 .44613 .20394 .43863 .18773 Mtetra
.605 .586 .805 r
.43863 .18773 .44613 .20394 .45943 .20095 .45195 .18414 Mtetra
.562 .556 .805 r
.45195 .18414 .45943 .20095 .47277 .2001 .46531 .18231 Mtetra
.512 .516 .797 r
.46531 .18231 .47277 .2001 .48619 .20157 .47873 .1824 Mtetra
.462 .471 .782 r
.47873 .1824 .48619 .20157 .49971 .2054 .49225 .18448 Mtetra
.42 .427 .761 r
.49225 .18448 .49971 .2054 .51337 .21144 .50589 .18842 Mtetra
.392 .391 .739 r
.50589 .18842 .51337 .21144 .52721 .21927 .51967 .19392 Mtetra
.382 .367 .718 r
.51967 .19392 .52721 .21927 .54123 .22827 .53363 .20047 Mtetra
.391 .357 .701 r
.53363 .20047 .54123 .22827 .55546 .23753 .54777 .20735 Mtetra
.414 .36 .688 r
.54777 .20735 .55546 .23753 .56989 .24601 .56209 .21368 Mtetra
.448 .373 .679 r
.56209 .21368 .56989 .24601 .58448 .25256 .57656 .2185 Mtetra
.489 .393 .673 r
.57656 .2185 .58448 .25256 .59918 .25606 .59116 .22088 Mtetra
.533 .418 .668 r
.59116 .22088 .59918 .25606 .61393 .2556 .60581 .22002 Mtetra
.576 .445 .665 r
.60581 .22002 .61393 .2556 .62865 .25061 .62047 .2154 Mtetra
.618 .473 .663 r
.62047 .2154 .62865 .25061 .64326 .24093 .63506 .20684 Mtetra
.656 .501 .662 r
.63506 .20684 .64326 .24093 .65772 .22684 .64955 .19451 Mtetra
.69 .529 .663 r
.64955 .19451 .65772 .22684 .672 .20905 .6639 .17898 Mtetra
.72 .555 .666 r
.6639 .17898 .672 .20905 .68608 .18857 .6781 .16106 Mtetra
.745 .581 .672 r
.6781 .16106 .68608 .18857 .7 .16656 .69218 .14172 Mtetra
.764 .605 .681 r
.69218 .14172 .7 .16656 .71381 .14414 .70616 .12191 Mtetra
.779 .629 .695 r
.70616 .12191 .71381 .14414 .72756 .12235 .7201 .10253 Mtetra
.595 .687 .906 r
.06235 .28824 .07085 .29766 .08201 .29552 .07358 .28569 Mtetra
.58 .672 .902 r
.07358 .28569 .08201 .29552 .09318 .29383 .08483 .2835 Mtetra
.565 .655 .897 r
.08483 .2835 .09318 .29383 .10435 .29261 .09608 .2817 Mtetra
.55 .636 .889 r
.09608 .2817 .10435 .29261 .11553 .29186 .10736 .28028 Mtetra
.537 .616 .879 r
.10736 .28028 .11553 .29186 .12673 .29157 .11866 .27924 Mtetra
.526 .596 .867 r
.11866 .27924 .12673 .29157 .13796 .29167 .12999 .2785 Mtetra
.52 .578 .854 r
.12999 .2785 .13796 .29167 .14924 .29208 .14138 .27802 Mtetra
.517 .561 .839 r
.14138 .27802 .14924 .29208 .16059 .29266 .15283 .27767 Mtetra
.519 .547 .825 r
.15283 .27767 .16059 .29266 .17203 .29329 .16436 .27735 Mtetra
.525 .537 .81 r
.16436 .27735 .17203 .29329 .18357 .29377 .17599 .27691 Mtetra
.534 .53 .797 r
.17599 .27691 .18357 .29377 .19524 .29395 .18774 .27621 Mtetra
.545 .526 .785 r
.18774 .27621 .19524 .29395 .20704 .29365 .19961 .27512 Mtetra
.558 .524 .774 r
.19961 .27512 .20704 .29365 .219 .29273 .21162 .27352 Mtetra
.571 .525 .765 r
.21162 .27352 .219 .29273 .23112 .29104 .22376 .27129 Mtetra
.585 .528 .758 r
.22376 .27129 .23112 .29104 .24339 .28851 .23605 .26838 Mtetra
.599 .533 .752 r
.23605 .26838 .24339 .28851 .25581 .28509 .24847 .26474 Mtetra
.611 .539 .748 r
.24847 .26474 .25581 .28509 .26837 .28076 .26103 .26036 Mtetra
.624 .546 .746 r
.26103 .26036 .26837 .28076 .28106 .27556 .2737 .25527 Mtetra
.635 .553 .745 r
.2737 .25527 .28106 .27556 .29387 .26955 .28648 .24952 Mtetra
.646 .562 .746 r
.28648 .24952 .29387 .26955 .30678 .26282 .29936 .24317 Mtetra
.655 .571 .748 r
.29936 .24317 .30678 .26282 .31978 .25546 .31232 .2363 Mtetra
.664 .58 .751 r
.31232 .2363 .31978 .25546 .33285 .24761 .32535 .22901 Mtetra
.671 .59 .756 r
.32535 .22901 .33285 .24761 .34597 .23941 .33844 .22141 Mtetra
.678 .599 .761 r
.33844 .22141 .34597 .23941 .35914 .231 .35158 .21361 Mtetra
.682 .608 .767 r
.35158 .21361 .35914 .231 .37234 .22256 .36476 .20576 Mtetra
.684 .616 .774 r
.36476 .20576 .37234 .22256 .38557 .21428 .37798 .198 Mtetra
.682 .622 .782 r
.37798 .198 .38557 .21428 .39881 .20639 .39122 .19051 Mtetra
.676 .625 .79 r
.39122 .19051 .39881 .20639 .41207 .19915 .40449 .18351 Mtetra
.664 .623 .798 r
.40449 .18351 .41207 .19915 .42534 .19283 .41777 .17721 Mtetra
.645 .615 .805 r
.41777 .17721 .42534 .19283 .43863 .18773 .43108 .17187 Mtetra
.618 .599 .809 r
.43108 .17187 .43863 .18773 .45195 .18414 .44442 .16772 Mtetra
.584 .574 .808 r
.44442 .16772 .45195 .18414 .46531 .18231 .4578 .16497 Mtetra
.544 .541 .802 r
.4578 .16497 .46531 .18231 .47873 .1824 .47124 .16377 Mtetra
.503 .502 .789 r
.47124 .16377 .47873 .1824 .49225 .18448 .48477 .16418 Mtetra
.468 .464 .77 r
.48477 .16418 .49225 .18448 .50589 .18842 .49839 .16612 Mtetra
.442 .429 .749 r
.49839 .16612 .50589 .18842 .51967 .19392 .51215 .16938 Mtetra
.431 .404 .729 r
.51215 .16938 .51967 .19392 .53363 .20047 .52605 .17355 Mtetra
.433 .39 .71 r
.52605 .17355 .53363 .20047 .54777 .20735 .54012 .17806 Mtetra
.449 .386 .696 r
.54012 .17806 .54777 .20735 .56209 .21368 .55434 .18222 Mtetra
.473 .392 .684 r
.55434 .18222 .56209 .21368 .57656 .2185 .56871 .18525 Mtetra
.504 .405 .676 r
.56871 .18525 .57656 .2185 .59116 .22088 .5832 .18639 Mtetra
.539 .423 .67 r
.5832 .18639 .59116 .22088 .60581 .22002 .59776 .18496 Mtetra
.574 .444 .666 r
.59776 .18496 .60581 .22002 .62047 .2154 .61235 .18051 Mtetra
.609 .468 .664 r
.61235 .18051 .62047 .2154 .63506 .20684 .62691 .17284 Mtetra
.642 .492 .664 r
.62691 .17284 .63506 .20684 .64955 .19451 .64141 .16209 Mtetra
.672 .516 .666 r
.64141 .16209 .64955 .19451 .6639 .17898 .65582 .14865 Mtetra
.698 .541 .67 r
.65582 .14865 .6639 .17898 .6781 .16106 .67012 .13317 Mtetra
.721 .565 .678 r
.67012 .13317 .6781 .16106 .69218 .14172 .68433 .11642 Mtetra
.74 .59 .688 r
.68433 .11642 .69218 .14172 .70616 .12191 .69848 .09921 Mtetra
.755 .614 .702 r
.69848 .09921 .70616 .12191 .7201 .10253 .7126 .08226 Mtetra
.608 .694 .904 r
.05377 .27887 .06235 .28824 .07358 .28569 .06507 .27594 Mtetra
.597 .682 .901 r
.06507 .27594 .07358 .28569 .08483 .2835 .07639 .2733 Mtetra
.585 .667 .896 r
.07639 .2733 .08483 .2835 .09608 .2817 .08773 .27097 Mtetra
.573 .651 .889 r
.08773 .27097 .09608 .2817 .10736 .28028 .09909 .26894 Mtetra
.562 .634 .88 r
.09909 .26894 .10736 .28028 .11866 .27924 .11049 .26721 Mtetra
.553 .617 .87 r
.11049 .26721 .11866 .27924 .12999 .2785 .12192 .26573 Mtetra
.547 .6 .858 r
.12192 .26573 .12999 .2785 .14138 .27802 .13341 .26444 Mtetra
.544 .584 .845 r
.13341 .26444 .14138 .27802 .15283 .27767 .14496 .26326 Mtetra
.545 .571 .832 r
.14496 .26326 .15283 .27767 .16436 .27735 .15658 .26209 Mtetra
.548 .56 .818 r
.15658 .26209 .16436 .27735 .17599 .27691 .1683 .26082 Mtetra
.554 .552 .806 r
.1683 .26082 .17599 .27691 .18774 .27621 .18012 .25935 Mtetra
.563 .547 .795 r
.18012 .25935 .18774 .27621 .19961 .27512 .19205 .25755 Mtetra
.572 .544 .785 r
.19205 .25755 .19961 .27512 .21162 .27352 .20411 .25534 Mtetra
.583 .543 .776 r
.20411 .25534 .21162 .27352 .22376 .27129 .21629 .25264 Mtetra
.594 .545 .769 r
.21629 .25264 .22376 .27129 .23605 .26838 .22859 .24938 Mtetra
.605 .548 .764 r
.22859 .24938 .23605 .26838 .24847 .26474 .24102 .24554 Mtetra
.615 .552 .76 r
.24102 .24554 .24847 .26474 .26103 .26036 .25357 .24111 Mtetra
.626 .558 .758 r
.25357 .24111 .26103 .26036 .2737 .25527 .26623 .2361 Mtetra
.635 .564 .757 r
.26623 .2361 .2737 .25527 .28648 .24952 .27899 .23056 Mtetra
.644 .572 .758 r
.27899 .23056 .28648 .24952 .29936 .24317 .29184 .22453 Mtetra
.653 .58 .76 r
.29184 .22453 .29936 .24317 .31232 .2363 .30477 .21808 Mtetra
.661 .588 .763 r
.30477 .21808 .31232 .2363 .32535 .22901 .31777 .21127 Mtetra
.667 .597 .767 r
.31777 .21127 .32535 .22901 .33844 .22141 .33083 .20418 Mtetra
.673 .606 .772 r
.33083 .20418 .33844 .22141 .35158 .21361 .34395 .19691 Mtetra
.677 .615 .778 r
.34395 .19691 .35158 .21361 .36476 .20576 .35712 .18956 Mtetra
.679 .622 .785 r
.35712 .18956 .36476 .20576 .37798 .198 .37033 .18226 Mtetra
.679 .628 .792 r
.37033 .18226 .37798 .198 .39122 .19051 .38357 .17513 Mtetra
.674 .632 .799 r
.38357 .17513 .39122 .19051 .40449 .18351 .39684 .16835 Mtetra
.665 .631 .806 r
.39684 .16835 .40449 .18351 .41777 .17721 .41014 .16208 Mtetra
.651 .625 .811 r
.41014 .16208 .41777 .17721 .43108 .17187 .42348 .15654 Mtetra
.63 .613 .815 r
.42348 .15654 .43108 .17187 .44442 .16772 .43684 .1519 Mtetra
.603 .593 .814 r
.43684 .1519 .44442 .16772 .4578 .16497 .45025 .14835 Mtetra
.572 .567 .809 r
.45025 .14835 .4578 .16497 .47124 .16377 .46371 .146 Mtetra
.539 .534 .798 r
.46371 .146 .47124 .16377 .48477 .16418 .47725 .14493 Mtetra
.509 .5 .782 r
.47725 .14493 .48477 .16418 .49839 .16612 .49088 .14508 Mtetra
.486 .468 .763 r
.49088 .14508 .49839 .16612 .51215 .16938 .50462 .1463 Mtetra
.473 .443 .743 r
.50462 .1463 .51215 .16938 .52605 .17355 .51848 .14829 Mtetra
.471 .425 .725 r
.51848 .14829 .52605 .17355 .54012 .17806 .53249 .15061 Mtetra
.48 .417 .709 r
.53249 .15061 .54012 .17806 .55434 .18222 .54664 .15272 Mtetra
.497 .417 .696 r
.54664 .15272 .55434 .18222 .56871 .18525 .56092 .15402 Mtetra
.52 .424 .686 r
.56092 .15402 .56871 .18525 .5832 .18639 .57532 .15388 Mtetra
.547 .436 .679 r
.57532 .15388 .5832 .18639 .59776 .18496 .5898 .15179 Mtetra
.576 .452 .674 r
.5898 .15179 .59776 .18496 .61235 .18051 .60432 .14734 Mtetra
.605 .471 .672 r
.60432 .14734 .61235 .18051 .62691 .17284 .61885 .14036 Mtetra
.633 .491 .672 r
.61885 .14036 .62691 .17284 .64141 .16209 .63335 .13092 Mtetra
.659 .513 .674 r
.63335 .13092 .64141 .16209 .65582 .14865 .6478 .11931 Mtetra
.683 .536 .679 r
.6478 .11931 .65582 .14865 .67012 .13317 .66219 .10603 Mtetra
.704 .559 .688 r
.66219 .10603 .67012 .13317 .68433 .11642 .67652 .09166 Mtetra
.721 .583 .699 r
.67652 .09166 .68433 .11642 .69848 .09921 .69081 .07686 Mtetra
.735 .606 .714 r
.69081 .07686 .69848 .09921 .7126 .08226 .70509 .0622 Mtetra
.62 .702 .903 r
.0451 .26957 .05377 .27887 .06507 .27594 .05647 .2663 Mtetra
.611 .691 .9 r
.05647 .2663 .06507 .27594 .07639 .2733 .06786 .26325 Mtetra
.601 .679 .896 r
.06786 .26325 .07639 .2733 .08773 .27097 .07928 .26045 Mtetra
.592 .665 .89 r
.07928 .26045 .08773 .27097 .09909 .26894 .09073 .25788 Mtetra
.583 .651 .882 r
.09073 .25788 .09909 .26894 .11049 .26721 .10221 .25554 Mtetra
.576 .636 .873 r
.10221 .25554 .11049 .26721 .12192 .26573 .11373 .2534 Mtetra
.57 .621 .863 r
.11373 .2534 .12192 .26573 .13341 .26444 .12531 .2514 Mtetra
.567 .607 .852 r
.12531 .2514 .13341 .26444 .14496 .26326 .13695 .24949 Mtetra
.567 .594 .84 r
.13695 .24949 .14496 .26326 .15658 .26209 .14866 .24758 Mtetra
.569 .583 .828 r
.14866 .24758 .15658 .26209 .1683 .26082 .16046 .24559 Mtetra
.573 .575 .817 r
.16046 .24559 .1683 .26082 .18012 .25935 .17235 .24344 Mtetra
.579 .569 .806 r
.17235 .24344 .18012 .25935 .19205 .25755 .18435 .24103 Mtetra
.586 .565 .797 r
.18435 .24103 .19205 .25755 .20411 .25534 .19645 .23829 Mtetra
.594 .563 .789 r
.19645 .23829 .20411 .25534 .21629 .25264 .20867 .23516 Mtetra
.603 .563 .783 r
.20867 .23516 .21629 .25264 .22859 .24938 .221 .23159 Mtetra
.611 .565 .778 r
.221 .23159 .22859 .24938 .24102 .24554 .23344 .22757 Mtetra
.62 .568 .774 r
.23344 .22757 .24102 .24554 .25357 .24111 .24598 .22308 Mtetra
.629 .572 .772 r
.24598 .22308 .25357 .24111 .26623 .2361 .25863 .21813 Mtetra
.637 .578 .772 r
.25863 .21813 .26623 .2361 .27899 .23056 .27138 .21276 Mtetra
.645 .584 .772 r
.27138 .21276 .27899 .23056 .29184 .22453 .2842 .20699 Mtetra
.652 .591 .774 r
.2842 .20699 .29184 .22453 .30477 .21808 .29711 .20087 Mtetra
.659 .599 .777 r
.29711 .20087 .30477 .21808 .31777 .21127 .31009 .19445 Mtetra
.665 .607 .78 r
.31009 .19445 .31777 .21127 .33083 .20418 .32314 .1878 Mtetra
.67 .615 .785 r
.32314 .1878 .33083 .20418 .34395 .19691 .33624 .18098 Mtetra
.674 .623 .79 r
.33624 .18098 .34395 .19691 .35712 .18956 .3494 .17406 Mtetra
.676 .631 .796 r
.3494 .17406 .35712 .18956 .37033 .18226 .3626 .16714 Mtetra
.676 .637 .803 r
.3626 .16714 .37033 .18226 .38357 .17513 .37585 .16033 Mtetra
.673 .64 .809 r
.37585 .16033 .38357 .17513 .39684 .16835 .38913 .15375 Mtetra
.667 .641 .815 r
.38913 .15375 .39684 .16835 .41014 .16208 .40245 .14753 Mtetra
.656 .638 .82 r
.40245 .14753 .41014 .16208 .42348 .15654 .41581 .14184 Mtetra
.64 .629 .823 r
.41581 .14184 .42348 .15654 .43684 .1519 .4292 .13681 Mtetra
.62 .614 .823 r
.4292 .13681 .43684 .1519 .45025 .14835 .44264 .1326 Mtetra
.595 .593 .819 r
.44264 .1326 .45025 .14835 .46371 .146 .45613 .1293 Mtetra
.569 .566 .81 r
.45613 .1293 .46371 .146 .47725 .14493 .46969 .12697 Mtetra
.544 .537 .797 r
.46969 .12697 .47725 .14493 .49088 .14508 .48333 .1256 Mtetra
.524 .508 .78 r
.48333 .1256 .49088 .14508 .50462 .1463 .49707 .12506 Mtetra
.511 .483 .762 r
.49707 .12506 .50462 .1463 .51848 .14829 .51092 .12514 Mtetra
.506 .463 .744 r
.51092 .12514 .51848 .14829 .53249 .15061 .52489 .12553 Mtetra
.51 .451 .727 r
.52489 .12553 .53249 .15061 .54664 .15272 .53898 .12581 Mtetra
.521 .447 .713 r
.53898 .12581 .54664 .15272 .56092 .15402 .5532 .12552 Mtetra
.537 .448 .702 r
.5532 .12552 .56092 .15402 .57532 .15388 .56753 .1242 Mtetra
.558 .456 .694 r
.56753 .1242 .57532 .15388 .5898 .15179 .58194 .12141 Mtetra
.581 .467 .688 r
.58194 .12141 .5898 .15179 .60432 .14734 .59641 .11685 Mtetra
.605 .482 .686 r
.59641 .11685 .60432 .14734 .61885 .14036 .61091 .11036 Mtetra
.629 .499 .686 r
.61091 .11036 .61885 .14036 .63335 .13092 .62541 .10197 Mtetra
.651 .518 .688 r
.62541 .10197 .63335 .13092 .6478 .11931 .63989 .09189 Mtetra
.672 .539 .694 r
.63989 .09189 .6478 .11931 .66219 .10603 .65434 .08047 Mtetra
.691 .56 .702 r
.65434 .08047 .66219 .10603 .67652 .09166 .66877 .06818 Mtetra
.707 .583 .714 r
.66877 .06818 .67652 .09166 .69081 .07686 .68318 .05549 Mtetra
.719 .606 .73 r
.68318 .05549 .69081 .07686 .70509 .0622 .69761 .04287 Mtetra
.629 .708 .903 r
.03634 .26033 .0451 .26957 .05647 .2663 .04777 .25677 Mtetra
.622 .7 .9 r
.04777 .25677 .05647 .2663 .06786 .26325 .05923 .25337 Mtetra
.615 .69 .896 r
.05923 .25337 .06786 .26325 .07928 .26045 .07072 .25015 Mtetra
.608 .678 .891 r
.07072 .25015 .07928 .26045 .09073 .25788 .08224 .24712 Mtetra
.601 .666 .885 r
.08224 .24712 .09073 .25788 .10221 .25554 .09381 .24426 Mtetra
.595 .653 .877 r
.09381 .24426 .10221 .25554 .11373 .2534 .10542 .24155 Mtetra
.59 .64 .869 r
.10542 .24155 .11373 .2534 .12531 .2514 .11709 .23894 Mtetra
.587 .628 .859 r
.11709 .23894 .12531 .2514 .13695 .24949 .12881 .2364 Mtetra
.586 .616 .849 r
.12881 .2364 .13695 .24949 .14866 .24758 .1406 .23385 Mtetra
.587 .606 .838 r
.1406 .23385 .14866 .24758 .16046 .24559 .15248 .23124 Mtetra
.59 .598 .829 r
.15248 .23124 .16046 .24559 .17235 .24344 .16444 .2285 Mtetra
.594 .591 .819 r
.16444 .2285 .17235 .24344 .18435 .24103 .17649 .22557 Mtetra
.599 .587 .811 r
.17649 .22557 .18435 .24103 .19645 .23829 .18864 .22237 Mtetra
.605 .584 .804 r
.18864 .22237 .19645 .23829 .20867 .23516 .20089 .21887 Mtetra
.611 .583 .798 r
.20089 .21887 .20867 .23516 .221 .23159 .21325 .21504 Mtetra
.618 .584 .793 r
.21325 .21504 .221 .23159 .23344 .22757 .2257 .21084 Mtetra
.625 .586 .79 r
.2257 .21084 .23344 .22757 .24598 .22308 .23825 .20629 Mtetra
.632 .589 .788 r
.23825 .20629 .24598 .22308 .25863 .21813 .2509 .20137 Mtetra
.639 .594 .787 r
.2509 .20137 .25863 .21813 .27138 .21276 .26363 .19612 Mtetra
.646 .599 .788 r
.26363 .19612 .27138 .21276 .2842 .20699 .27645 .19055 Mtetra
.652 .605 .789 r
.27645 .19055 .2842 .20699 .29711 .20087 .28935 .1847 Mtetra
.658 .612 .792 r
.28935 .1847 .29711 .20087 .31009 .19445 .30231 .1786 Mtetra
.663 .619 .795 r
.30231 .1786 .31009 .19445 .32314 .1878 .31535 .17229 Mtetra
.668 .626 .799 r
.31535 .17229 .32314 .1878 .33624 .18098 .32844 .16583 Mtetra
.671 .634 .804 r
.32844 .16583 .33624 .18098 .3494 .17406 .34159 .15928 Mtetra
.674 .641 .809 r
.34159 .15928 .3494 .17406 .3626 .16714 .3548 .15269 Mtetra
.674 .647 .814 r
.3548 .15269 .3626 .16714 .37585 .16033 .36805 .14615 Mtetra
.673 .651 .82 r
.36805 .14615 .37585 .16033 .38913 .15375 .38134 .13975 Mtetra
.668 .652 .825 r
.38134 .13975 .38913 .15375 .40245 .14753 .39468 .1336 Mtetra
.66 .651 .83 r
.39468 .1336 .40245 .14753 .41581 .14184 .40806 .12781 Mtetra
.649 .645 .833 r
.40806 .12781 .41581 .14184 .4292 .13681 .42149 .1225 Mtetra
.634 .634 .833 r
.42149 .1225 .4292 .13681 .44264 .1326 .43496 .11777 Mtetra
.615 .618 .83 r
.43496 .11777 .44264 .1326 .45613 .1293 .44848 .11371 Mtetra
.595 .597 .824 r
.44848 .11371 .45613 .1293 .46969 .12697 .46207 .11037 Mtetra
.575 .572 .813 r
.46207 .11037 .46969 .12697 .48333 .1256 .47573 .10775 Mtetra
.557 .547 .799 r
.47573 .10775 .48333 .1256 .49707 .12506 .48948 .10577 Mtetra
.545 .524 .782 r
.48948 .10577 .49707 .12506 .51092 .12514 .50333 .10427 Mtetra
.538 .504 .766 r
.50333 .10427 .51092 .12514 .52489 .12553 .51728 .10304 Mtetra
.538 .489 .749 r
.51728 .10304 .52489 .12553 .53898 .12581 .53135 .10176 Mtetra
.545 .481 .735 r
.53135 .10176 .53898 .12581 .5532 .12552 .54552 .1001 Mtetra
.556 .479 .723 r
.54552 .1001 .5532 .12552 .56753 .1242 .5598 .09771 Mtetra
.572 .482 .714 r
.5598 .09771 .56753 .1242 .58194 .12141 .57416 .09426 Mtetra
.589 .489 .708 r
.57416 .09426 .58194 .12141 .59641 .11685 .58859 .08952 Mtetra
.609 .5 .705 r
.58859 .08952 .59641 .11685 .61091 .11036 .60307 .08335 Mtetra
.628 .514 .705 r
.60307 .08335 .61091 .11036 .62541 .10197 .61757 .07576 Mtetra
.648 .531 .707 r
.61757 .07576 .62541 .10197 .63989 .09189 .63208 .0669 Mtetra
.666 .549 .713 r
.63208 .0669 .63989 .09189 .65434 .08047 .64659 .057 Mtetra
.682 .569 .722 r
.64659 .057 .65434 .08047 .66877 .06818 .6611 .04642 Mtetra
.696 .591 .734 r
.6611 .04642 .66877 .06818 .68318 .05549 .67562 .03551 Mtetra
.706 .613 .75 r
.67562 .03551 .68318 .05549 .69761 .04287 .69017 .02461 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.758 .12716 m
.7838 .12238 L
.8096 .12408 L
.8354 .13271 L
.84703 .1388 L
.8612 .15011 L
.87404 .1646 L
.887 .18802 L
.88776 .1904 L
.89386 .2162 L
.89329 .242 L
.887 .26525 L
.88599 .2678 L
.87046 .2936 L
.8612 .30347 L
.83864 .3194 L
.8354 .32089 L
.8096 .32957 L
.7838 .33129 L
.758 .32647 L
.73874 .3194 L
.7322 .31423 L
.70923 .2936 L
.7064 .29046 L
.69351 .2678 L
.68631 .242 L
.68576 .2162 L
.69171 .1904 L
.70589 .1646 L
.7064 .1639 L
.7322 .13963 L
.73298 .1388 L
.758 .12716 L
s
.9902 .88794 m
.9644 .89255 L
.9386 .89375 L
.9128 .89159 L
.88891 .887 L
.887 .88596 L
.8612 .87659 L
.8354 .86275 L
.83296 .8612 L
.8096 .84334 L
.80116 .8354 L
.7838 .81561 L
.77939 .8096 L
.76386 .7838 L
.758 .77138 L
.75309 .758 L
.74625 .7322 L
.74295 .7064 L
.74303 .6806 L
.74647 .6548 L
.75348 .629 L
.758 .61679 L
.76444 .6032 L
.7802 .5774 L
.7838 .57254 L
.80232 .5516 L
.8096 .5448 L
.83474 .5258 L
.8354 .52539 L
.8612 .51155 L
.887 .50217 L
.89209 .5 L
.9128 .49655 L
.9386 .4944 L
.9644 .49559 L
.98936 .5 L
.9902 .5002 L
s
.6032 .60075 m
.629 .59701 L
.6548 .5992 L
.66948 .6032 L
.6806 .60755 L
.7064 .62399 L
.71201 .629 L
.73202 .6548 L
.7322 .65497 L
.74298 .6806 L
.7472 .7064 L
.74554 .7322 L
.73766 .758 L
.7322 .76966 L
.72223 .7838 L
.7064 .80005 L
.6937 .8096 L
.6806 .81629 L
.6548 .82474 L
.629 .82691 L
.6032 .82322 L
.5774 .81292 L
.5714 .8096 L
.5516 .79399 L
.54247 .7838 L
.527 .758 L
.5258 .75505 L
.51913 .7322 L
.51746 .7064 L
.52171 .6806 L
.5258 .66603 L
.53245 .6548 L
.5516 .63005 L
.55267 .629 L
.5774 .61083 L
.59236 .6032 L
.6032 .60075 L
s
.3968 .11242 m
.4226 .10264 L
.4484 .09786 L
.4742 .09756 L
.5 .10173 L
.5258 .11079 L
.53064 .113 L
.5516 .12567 L
.56751 .1388 L
.5774 .14911 L
.58918 .1646 L
.60294 .1904 L
.6032 .19078 L
.61113 .2162 L
.61453 .242 L
.61349 .2678 L
.60789 .2936 L
.6032 .30762 L
.59726 .3194 L
.58008 .3452 L
.5774 .34838 L
.5528 .371 L
.5516 .37187 L
.5258 .38688 L
.5 .39586 L
.49597 .3968 L
.4742 .40003 L
.4484 .39973 L
.43007 .3968 L
.4226 .39495 L
.3968 .38526 L
.37315 .371 L
.371 .36933 L
.34598 .3452 L
.3452 .34427 L
.32878 .3194 L
.3194 .29783 L
.31817 .2936 L
.31257 .2678 L
.31153 .242 L
.31493 .2162 L
.3194 .19775 L
.32308 .1904 L
.33688 .1646 L
.3452 .15321 L
.35855 .1388 L
.371 .12823 L
.39557 .113 L
.3968 .11242 L
s
.2678 .11146 m
.28668 .113 L
.2936 .11423 L
.3194 .12227 L
.3452 .13698 L
.3477 .1388 L
.371 .16141 L
.37347 .1646 L
.3889 .1904 L
.3968 .2123 L
.39748 .2162 L
.40077 .242 L
.39902 .2678 L
.3968 .27843 L
.39211 .2936 L
.379 .3194 L
.371 .33055 L
.35719 .3452 L
.3452 .35488 L
.3194 .36944 L
.31794 .371 L
.2936 .37757 L
.2678 .38037 L
.242 .37814 L
.2172 .371 L
.2162 .37061 L
.1904 .35691 L
.17553 .3452 L
.1646 .33399 L
.15372 .3194 L
.14066 .2936 L
.1388 .28829 L
.1337 .2678 L
.13195 .242 L
.13523 .2162 L
.1388 .20015 L
.14386 .1904 L
.15924 .1646 L
.1646 .15791 L
.18496 .1388 L
.1904 .13494 L
.2162 .12109 L
.242 .11368 L
.24606 .113 L
.2678 .11146 L
s
.8354 .07686 m
.8612 .06893 L
.887 .06777 L
.9128 .07309 L
.9386 .08637 L
.93982 .0872 L
.9644 .11209 L
.96495 .113 L
.97686 .1388 L
.98201 .1646 L
.98062 .1904 L
.97279 .2162 L
.9644 .23306 L
.95685 .242 L
.9386 .25806 L
.92244 .2678 L
.9128 .27092 L
.887 .27635 L
.8612 .27516 L
.83693 .2678 L
.8354 .26715 L
.8096 .25061 L
.80091 .242 L
.78408 .2162 L
.7838 .21555 L
.77583 .1904 L
.77447 .1646 L
.7797 .1388 L
.7838 .12639 L
.79233 .113 L
.8096 .09342 L
.81684 .0872 L
.8354 .07686 L
s
.7064 .57213 m
.7322 .56661 L
.758 .56709 L
.7838 .57364 L
.79362 .5774 L
.8096 .58724 L
.82778 .6032 L
.8354 .61212 L
.84556 .629 L
.85498 .6548 L
.85798 .6806 L
.85521 .7064 L
.84608 .7322 L
.8354 .75011 L
.8287 .758 L
.8096 .77498 L
.79587 .7838 L
.7838 .7886 L
.758 .79515 L
.7322 .79562 L
.7064 .79011 L
.68962 .7838 L
.6806 .77777 L
.65745 .758 L
.6548 .75508 L
.63992 .7322 L
.63088 .7064 L
.629 .69544 L
.62809 .6806 L
.629 .66679 L
.63111 .6548 L
.64044 .629 L
.6548 .60708 L
.65834 .6032 L
.6806 .58444 L
.69171 .5774 L
.7064 .57213 L
s
.0098 .78688 m
.02591 .8096 L
.0356 .82141 L
.04858 .8354 L
.0614 .84759 L
.07776 .8612 L
.0872 .86818 L
.113 .88455 L
.11739 .887 L
.1388 .89748 L
.1646 .90743 L
.18242 .9128 L
.1904 .91471 L
.2162 .91953 L
.242 .92202 L
.2678 .92222 L
.2936 .92014 L
.3194 .91574 L
.33211 .9128 L
.3452 .90891 L
.371 .89945 L
.3968 .88708 L
.39696 .887 L
.4226 .87138 L
.43663 .8612 L
.4484 .8516 L
.4658 .8354 L
.4742 .82656 L
.48851 .8096 L
.5 .79386 L
.50652 .7838 L
.52081 .758 L
.5258 .74736 L
.53195 .7322 L
.54032 .7064 L
.54614 .6806 L
.54959 .6548 L
.55073 .629 L
.54961 .6032 L
.54619 .5774 L
.54039 .5516 L
.53205 .5258 L
.5258 .51037 L
.52094 .5 L
.50669 .4742 L
.5 .46388 L
.48872 .4484 L
.4742 .43118 L
.46606 .4226 L
.4484 .40613 L
Mistroke
.43697 .3968 L
.4226 .38636 L
.39745 .371 L
.3968 .37065 L
.371 .35828 L
.3452 .34883 L
.33311 .3452 L
.3194 .34199 L
.2936 .33759 L
.2678 .33551 L
.242 .33571 L
.2162 .3382 L
.1904 .34302 L
.1814 .3452 L
.1646 .35031 L
.1388 .36025 L
.1169 .371 L
.113 .37318 L
.0872 .38955 L
.07742 .3968 L
.0614 .41015 L
.04832 .4226 L
.0356 .43633 L
.02571 .4484 L
.0098 .47085 L
Mfstroke
.2936 .2288 m
.3194 .21982 L
.3452 .21629 L
.371 .2177 L
.3968 .22426 L
.4226 .23699 L
.4301 .242 L
.4484 .25813 L
.45666 .2678 L
.47244 .2936 L
.4742 .29598 L
.48147 .3194 L
.48505 .3452 L
.48359 .371 L
.47693 .3968 L
.4742 .40429 L
.46431 .4226 L
.4484 .4431 L
.44309 .4484 L
.4226 .46428 L
.40421 .4742 L
.3968 .47689 L
.371 .48354 L
.3452 .48498 L
.3194 .4814 L
.29612 .4742 L
.2936 .47235 L
.2678 .45656 L
.25826 .4484 L
.242 .42996 L
.23709 .4226 L
.22434 .3968 L
.21777 .371 L
.21634 .3452 L
.21986 .3194 L
.22883 .2936 L
.242 .2712 L
.24469 .2678 L
.2678 .24468 L
.27118 .242 L
.2936 .2288 L
s
0 g
.03 w
.78983 .22684 Mdot
.94229 .69407 Mdot
.63231 .71193 Mdot
.46302 .24881 Mdot
.26637 .24589 Mdot
.87881 .17207 Mdot
.74301 .68111 Mdot
.25719 .62887 Mdot
.35066 .35061 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.81373 .16455 m
.83333 .15874 L
.85294 .16148 L
.86164 .16667 L
.87255 .17916 L
.87552 .18627 L
.87544 .20588 L
.87255 .21351 L
.86633 .22549 L
.85294 .23684 L
.83333 .24377 L
.81373 .24379 L
.79412 .23476 L
.78885 .22549 L
.78388 .20588 L
.79003 .18627 L
.79412 .17788 L
.80881 .16667 L
.81373 .16455 L
s
.67647 .6515 m
.69608 .6477 L
.71569 .65031 L
.72904 .65686 L
.73529 .66163 L
.74651 .67647 L
.74943 .69608 L
.74241 .71569 L
.73529 .72632 L
.72079 .73529 L
.71569 .73725 L
.69608 .74226 L
.67647 .74077 L
.66304 .73529 L
.65686 .7313 L
.64332 .71569 L
.63964 .69608 L
.6453 .67647 L
.65686 .66039 L
.6624 .65686 L
.67647 .6515 L
s
.81373 .13977 m
.83333 .13551 L
.85294 .13625 L
.87255 .14305 L
.87936 .14706 L
.89216 .15951 L
.89594 .16667 L
.90192 .18627 L
.90093 .20588 L
.89351 .22549 L
.89216 .22811 L
.87837 .2451 L
.87255 .25009 L
.85294 .26167 L
.84418 .26471 L
.83333 .26725 L
.81373 .26797 L
.79805 .26471 L
.79412 .2634 L
.77451 .25139 L
.76894 .2451 L
.759 .22549 L
.75735 .20588 L
.76228 .18627 L
.77451 .16667 L
.77451 .16667 L
.79412 .14926 L
.79692 .14706 L
.81373 .13977 L
s
.65686 .62838 m
.67647 .62174 L
.69608 .61914 L
.71569 .62022 L
.73529 .62534 L
.7549 .6361 L
.75644 .63725 L
.77412 .65686 L
.77451 .65753 L
.78208 .67647 L
.78335 .69608 L
.77854 .71569 L
.77451 .72566 L
.76689 .73529 L
.7549 .74761 L
.74468 .7549 L
.73529 .76004 L
.71569 .76733 L
.69608 .77052 L
.67647 .77 L
.65686 .76544 L
.63725 .75537 L
.63657 .7549 L
.61765 .73542 L
.61757 .73529 L
.60889 .71569 L
.60693 .69608 L
.61086 .67647 L
.61765 .66044 L
.62128 .65686 L
.63725 .64026 L
.64127 .63725 L
.65686 .62838 L
s
.32353 .24179 m
.34314 .24013 L
.36275 .24484 L
.36353 .2451 L
.38235 .2565 L
.38922 .26471 L
.3984 .28431 L
.39915 .30392 L
.39201 .32353 L
.38235 .33594 L
.37353 .34314 L
.36275 .34644 L
.34314 .34973 L
.32353 .34615 L
.3167 .34314 L
.30392 .3356 L
.29329 .32353 L
.28483 .30392 L
.28431 .30119 L
.28386 .28431 L
.28431 .28167 L
.2904 .26471 L
.30392 .24984 L
.31416 .2451 L
.32353 .24179 L
s
.81373 .12047 m
.83333 .1167 L
.85294 .11677 L
.87255 .12116 L
.88693 .12745 L
.89216 .13119 L
.90834 .14706 L
.91176 .15092 L
.9186 .16667 L
.92243 .18627 L
.92116 .20588 L
.91501 .22549 L
.91176 .23266 L
.90343 .2451 L
.89216 .25777 L
.88412 .26471 L
.87255 .27254 L
.85294 .28176 L
.84464 .28431 L
.83333 .28673 L
.81373 .28789 L
.79412 .28511 L
.79037 .28431 L
.77451 .27775 L
.75639 .26471 L
.7549 .26336 L
.74186 .2451 L
.73554 .22549 L
.73529 .22379 L
.73509 .20588 L
.73529 .20428 L
.73984 .18627 L
.74999 .16667 L
.7549 .1597 L
.76679 .14706 L
.77451 .1405 L
.79412 .1282 L
.79531 .12745 L
.81373 .12047 L
s
.67647 .59783 m
.69608 .59561 L
.71569 .59621 L
.72779 .59804 L
.73529 .59976 L
.7549 .60673 L
.77358 .61765 L
.77451 .61833 L
.79379 .63725 L
.79412 .63763 L
.8052 .65686 L
.81071 .67647 L
.81137 .69608 L
.80741 .71569 L
.79842 .73529 L
.79412 .74209 L
.78321 .7549 L
.77451 .76298 L
.75807 .77451 L
.7549 .77632 L
.73529 .78526 L
.71569 .79079 L
.69608 .79338 L
.67647 .79315 L
.65686 .78994 L
.63725 .78322 L
.62143 .77451 L
.61765 .77182 L
.59999 .7549 L
.59804 .75263 L
.58798 .73529 L
.58192 .71569 L
.5806 .69608 L
.58366 .67647 L
.5914 .65686 L
.59804 .64571 L
.60487 .63725 L
.61765 .62475 L
.62716 .61765 L
.63725 .61158 L
.65686 .60297 L
.67506 .59804 L
.67647 .59783 L
s
.30392 .20374 m
.32353 .19946 L
.34314 .19876 L
.36275 .20137 L
.37942 .20588 L
.38235 .20743 L
.40196 .21762 L
.41255 .22549 L
.42157 .23393 L
.43041 .2451 L
.44066 .26471 L
.44118 .26613 L
.44552 .28431 L
.44576 .30392 L
.44158 .32353 L
.44118 .32495 L
.43263 .34314 L
.42157 .3583 L
.41726 .36275 L
.40196 .37519 L
.38952 .38235 L
.38235 .38521 L
.36275 .39054 L
.34314 .39186 L
.32353 .38939 L
.30392 .38289 L
.30266 .38235 L
.28431 .37167 L
.27347 .36275 L
.26471 .3535 L
.25709 .34314 L
.24702 .32353 L
.2451 .31805 L
.24162 .30392 L
.24039 .28431 L
.24346 .26471 L
.2451 .25795 L
.25149 .2451 L
.26471 .22748 L
.26675 .22549 L
.28431 .2123 L
.29724 .20588 L
.30392 .20374 L
s
.81373 .10296 m
.83333 .09947 L
.85294 .09916 L
.87255 .10234 L
.88901 .10784 L
.89216 .10969 L
.91176 .12296 L
.91644 .12745 L
.93069 .14706 L
.93137 .14784 L
.93826 .16667 L
.941 .18627 L
.9396 .20588 L
.93419 .22549 L
.93137 .2327 L
.92446 .2451 L
.91176 .26211 L
.90935 .26471 L
.89216 .28002 L
.88613 .28431 L
.87255 .29214 L
.85294 .30017 L
.83826 .30392 L
.83333 .30478 L
.81373 .30624 L
.79412 .30449 L
.78984 .30392 L
.77451 .29924 L
.7549 .28963 L
.74722 .28431 L
.73529 .27359 L
.72819 .26471 L
.71781 .2451 L
.71569 .23835 L
.71334 .22549 L
.71373 .20588 L
.71569 .19573 L
.71855 .18627 L
.72784 .16667 L
.73529 .15529 L
.74217 .14706 L
.7549 .1343 L
.76334 .12745 L
.77451 .11981 L
.79412 .10964 L
.79791 .10784 L
.81373 .10296 L
s
.67647 .57525 m
.69608 .57334 L
.71569 .57368 L
.73529 .57638 L
.74499 .57843 L
.7549 .58165 L
.77451 .59001 L
.78805 .59804 L
.79412 .60241 L
.81066 .61765 L
.81373 .62109 L
.82487 .63725 L
.83333 .65613 L
.83354 .65686 L
.83781 .67647 L
.83816 .69608 L
.83469 .71569 L
.83333 .72104 L
.82718 .73529 L
.815 .7549 L
.81373 .75658 L
.79673 .77451 L
.79412 .77677 L
.77451 .79078 L
.76873 .79412 L
.7549 .80084 L
.73529 .80792 L
.71569 .81246 L
.70694 .81373 L
.69608 .81467 L
.67647 .81458 L
.66733 .81373 L
.65686 .81209 L
.63725 .80691 L
.61765 .79848 L
.60997 .79412 L
.59804 .78573 L
.58585 .77451 L
.57843 .76595 L
.57104 .7549 L
.56192 .73529 L
.55882 .72458 L
.55713 .71569 L
.55605 .69608 L
.5585 .67647 L
.55882 .6746 L
.56461 .65686 L
.57491 .63725 L
.57843 .63205 L
.59062 .61765 L
Mistroke
.59804 .61063 L
.61489 .59804 L
.61765 .59633 L
.63725 .58633 L
.65686 .57949 L
.65984 .57843 L
.67647 .57525 L
Mfstroke
.34314 .16665 m
.34361 .16667 L
.36275 .16853 L
.38235 .17283 L
.40196 .17975 L
.41552 .18627 L
.42157 .18976 L
.44118 .20384 L
.44352 .20588 L
.46078 .22437 L
.46162 .22549 L
.47359 .2451 L
.48039 .26273 L
.48084 .26471 L
.4841 .28431 L
.48379 .30392 L
.48039 .3226 L
.48015 .32353 L
.47317 .34314 L
.46249 .36275 L
.46078 .36532 L
.44709 .38235 L
.44118 .38829 L
.42414 .40196 L
.42157 .40365 L
.40196 .41416 L
.38235 .4209 L
.37968 .42157 L
.36275 .42448 L
.34314 .42515 L
.32353 .42297 L
.31524 .42157 L
.30392 .41784 L
.28431 .40942 L
.27156 .40196 L
.26471 .39708 L
.24788 .38235 L
.2451 .37944 L
.23175 .36275 L
.22549 .35292 L
.22044 .34314 L
.21284 .32353 L
.20849 .30392 L
.2072 .28431 L
.20905 .26471 L
.21435 .2451 L
.2238 .22549 L
.22549 .22275 L
.23882 .20588 L
.2451 .19979 L
Mistroke
.26336 .18627 L
.26471 .18548 L
.28431 .17604 L
.30392 .17016 L
.32353 .16715 L
.33119 .16667 L
.34314 .16665 L
Mfstroke
.81373 .08592 m
.83333 .08264 L
.85294 .08209 L
.87255 .08447 L
.88794 .08824 L
.89216 .09022 L
.91176 .10022 L
.92217 .10784 L
.93137 .11651 L
.94023 .12745 L
.95098 .14696 L
.95102 .14706 L
.95696 .16667 L
.95901 .18627 L
.95756 .20588 L
.95269 .22549 L
.95098 .23058 L
.94421 .2451 L
.93155 .26471 L
.93137 .26493 L
.91345 .28431 L
.91176 .28582 L
.89216 .30053 L
.88665 .30392 L
.87255 .31109 L
.85294 .31838 L
.83333 .32279 L
.82784 .32353 L
.81373 .32448 L
.79478 .32353 L
.79412 .32345 L
.77451 .31956 L
.7549 .31245 L
.73909 .30392 L
.73529 .3014 L
.71569 .28451 L
.71551 .28431 L
.70123 .26471 L
.69608 .25553 L
.69314 .2451 L
.69004 .22549 L
.69124 .20588 L
.69608 .18714 L
.69639 .18627 L
.70547 .16667 L
.71569 .1508 L
.71864 .14706 L
.73529 .12884 L
.73679 .12745 L
.7549 .11276 L
Mistroke
.76221 .10784 L
.77451 .10073 L
.79412 .0919 L
.8043 .08824 L
.81373 .08592 L
Mfstroke
.65686 .55544 m
.67647 .55196 L
.69608 .55035 L
.71569 .55058 L
.73529 .55273 L
.7549 .55695 L
.76151 .55882 L
.77451 .56352 L
.79412 .57287 L
.80337 .57843 L
.81373 .58577 L
.82776 .59804 L
.83333 .60384 L
.84423 .61765 L
.85294 .63199 L
.85543 .63725 L
.86249 .65686 L
.86598 .67647 L
.86614 .69608 L
.86304 .71569 L
.85652 .73529 L
.85294 .74326 L
.84621 .7549 L
.83333 .77229 L
.83136 .77451 L
.81373 .79149 L
.81048 .79412 L
.79412 .80564 L
.77988 .81373 L
.77451 .81637 L
.7549 .82445 L
.73529 .8303 L
.7214 .83333 L
.71569 .83412 L
.69608 .83601 L
.67647 .83599 L
.65686 .83397 L
.65248 .83333 L
.63725 .82975 L
.61765 .82304 L
.59882 .81373 L
.59804 .81326 L
.57843 .79941 L
.5725 .79412 L
.55882 .77917 L
.55536 .77451 L
.5438 .7549 L
.53922 .74464 L
.53635 .73529 L
.5323 .71569 L
Mistroke
.53128 .69608 L
.53315 .67647 L
.53794 .65686 L
.53922 .65293 L
.54595 .63725 L
.55778 .61765 L
.55882 .61622 L
.57477 .59804 L
.57843 .59463 L
.59804 .57966 L
.59997 .57843 L
.61765 .56883 L
.63725 .56095 L
.64369 .55882 L
.65686 .55544 L
Mfstroke
.28431 .14431 m
.30392 .13971 L
.32353 .13729 L
.34314 .13684 L
.36275 .13826 L
.38235 .14156 L
.40196 .1468 L
.40279 .14706 L
.42157 .15414 L
.44118 .16389 L
.44592 .16667 L
.46078 .17655 L
.47297 .18627 L
.48039 .19302 L
.49242 .20588 L
.5 .21541 L
.50659 .22549 L
.51635 .2451 L
.51961 .25185 L
.52198 .26471 L
.52388 .28431 L
.52254 .30392 L
.51961 .31894 L
.5184 .32353 L
.51171 .34314 L
.50255 .36275 L
.5 .36743 L
.4906 .38235 L
.48039 .39582 L
.47504 .40196 L
.46078 .41596 L
.45403 .42157 L
.44118 .43072 L
.42227 .44118 L
.42157 .4415 L
.40196 .44912 L
.38235 .45405 L
.36275 .45656 L
.34314 .45677 L
.32353 .4547 L
.30392 .45026 L
.28431 .44327 L
.27954 .44118 L
.26471 .43339 L
.24705 .42157 L
.2451 .42006 L
.22549 .40225 L
.22521 .40196 L
.20906 .38235 L
.20588 .37777 L
Mistroke
.19689 .36275 L
.18788 .34314 L
.18627 .33914 L
.18161 .32353 L
.17786 .30392 L
.17658 .28431 L
.1778 .26471 L
.18172 .2451 L
.18627 .23086 L
.18866 .22549 L
.19924 .20588 L
.20588 .19646 L
.21459 .18627 L
.22549 .17583 L
.23727 .16667 L
.2451 .16156 L
.26471 .1514 L
.27558 .14706 L
.28431 .14431 L
Mfstroke
.81373 .06848 m
.83333 .06538 L
.85294 .06466 L
.87255 .06647 L
.88529 .06863 L
.89216 .07111 L
.91176 .07911 L
.927 .08824 L
.93137 .09149 L
.94863 .10784 L
.95098 .11062 L
.96232 .12745 L
.97059 .14581 L
.97099 .14706 L
.97583 .16667 L
.97739 .18627 L
.97593 .20588 L
.9715 .22549 L
.97059 .2286 L
.96399 .2451 L
.95307 .26471 L
.95098 .26784 L
.93805 .28431 L
.93137 .29142 L
.91755 .30392 L
.91176 .30842 L
.89216 .3212 L
.88797 .32353 L
.87255 .33072 L
.85294 .33753 L
.83333 .34186 L
.82343 .34314 L
.81373 .3438 L
.79412 .34338 L
.79149 .34314 L
.77451 .34052 L
.7549 .33509 L
.73529 .32689 L
.72886 .32353 L
.71569 .31541 L
.70087 .30392 L
.69608 .2996 L
.68241 .28431 L
.67647 .27626 L
.67047 .26471 L
.66388 .2451 L
.66212 .22549 L
.66468 .20588 L
.67092 .18627 L
.67647 .17355 L
Mistroke
.68052 .16667 L
.69358 .14706 L
.69608 .14377 L
.71043 .12745 L
.71569 .12219 L
.73217 .10784 L
.73529 .10542 L
.7549 .09215 L
.76167 .08824 L
.77451 .08177 L
.79412 .07393 L
.81297 .06863 L
.81373 .06848 L
Mfstroke
.61765 .53822 m
.63725 .5324 L
.65686 .52823 L
.67647 .52555 L
.69608 .52432 L
.71569 .52457 L
.73529 .5264 L
.7549 .52993 L
.77451 .53532 L
.78553 .53922 L
.79412 .54284 L
.81373 .55283 L
.82346 .55882 L
.83333 .56579 L
.84843 .57843 L
.85294 .58278 L
.86648 .59804 L
.87255 .60621 L
.87968 .61765 L
.88901 .63725 L
.89216 .64525 L
.895 .65686 L
.89796 .67647 L
.89804 .69608 L
.89524 .71569 L
.89216 .72856 L
.88947 .73529 L
.88047 .7549 L
.87255 .76796 L
.86783 .77451 L
.85294 .7919 L
.85074 .79412 L
.83333 .80949 L
.82773 .81373 L
.81373 .82314 L
.7954 .83333 L
.79412 .83397 L
.77451 .84251 L
.7549 .84911 L
.74024 .85294 L
.73529 .85397 L
.71569 .85717 L
.69608 .85877 L
.67647 .85876 L
.65686 .85706 L
.63725 .85356 L
.63453 .85294 L
.61765 .84802 L
.59804 .84015 L
.58489 .83333 L
Mistroke
.57843 .82943 L
.55882 .81495 L
.55742 .81373 L
.53922 .79489 L
.53859 .79412 L
.52512 .77451 L
.51961 .76422 L
.51559 .7549 L
.50923 .73529 L
.5056 .71569 L
.50443 .69608 L
.50561 .67647 L
.50908 .65686 L
.51492 .63725 L
.51961 .62557 L
.52344 .61765 L
.53523 .59804 L
.53922 .59263 L
.5516 .57843 L
.55882 .57163 L
.57543 .55882 L
.57843 .55689 L
.59804 .54619 L
.61479 .53922 L
.61765 .53822 L
Mfstroke
.9902 .23068 m
.98495 .2451 L
.97542 .26471 L
.97059 .2728 L
.96264 .28431 L
.95098 .29854 L
.94594 .30392 L
.93137 .31752 L
.92396 .32353 L
.91176 .33222 L
.89339 .34314 L
.89216 .34377 L
.87255 .35262 L
.85294 .35922 L
.83895 .36275 L
.83333 .36363 L
.81373 .36588 L
.79412 .36608 L
.77451 .3642 L
.76505 .36275 L
.7549 .36017 L
.73529 .35395 L
.71569 .34567 L
.71051 .34314 L
.69608 .3353 L
.67738 .32353 L
.67647 .32293 L
.65686 .30867 L
.65277 .30392 L
.63725 .29291 L
.62738 .28431 L
.61765 .27876 L
.59804 .26664 L
.58527 .28431 L
.57843 .3006 L
.57525 .30392 L
.56581 .32353 L
.55882 .33867 L
.55651 .34314 L
.54631 .36275 L
.53922 .37557 L
.53519 .38235 L
.52255 .40196 L
.51961 .40612 L
.5076 .42157 L
.5 .43015 L
.48893 .44118 L
.48039 .44854 L
.46339 .46078 L
.46078 .46239 L
Mistroke
.44118 .47269 L
.42157 .48024 L
.42113 .48039 L
.40196 .48552 L
.38235 .48883 L
.36275 .49033 L
.34314 .49004 L
.32353 .48793 L
.30392 .48391 L
.29154 .48039 L
.28431 .47782 L
.26471 .46944 L
.24882 .46078 L
.2451 .45847 L
.22549 .44442 L
.22155 .44118 L
.20588 .42652 L
.20124 .42157 L
.18627 .40323 L
.18536 .40196 L
.17278 .38235 L
.16667 .37086 L
.16291 .36275 L
.1554 .34314 L
.15005 .32353 L
.14706 .30718 L
.14678 .30392 L
.14555 .28431 L
.14641 .26471 L
.14706 .25902 L
.14946 .2451 L
.1549 .22549 L
.16306 .20588 L
.16667 .19893 L
.17446 .18627 L
.18627 .17086 L
.19003 .16667 L
.20588 .1516 L
.21154 .14706 L
.22549 .13738 L
.24349 .12745 L
.2451 .12669 L
.26471 .11871 L
.28431 .11298 L
.30392 .10917 L
.31448 .10784 L
.32353 .10709 L
.34314 .10661 L
.36275 .10766 L
.36527 .10784 L
Mistroke
.38235 .11021 L
.40196 .11429 L
.42157 .11997 L
.44118 .12734 L
.44143 .12745 L
.46078 .13657 L
.4792 .14706 L
.48039 .1478 L
.5 .16114 L
.50725 .16667 L
.51961 .1766 L
.53055 .18627 L
.53922 .19393 L
.55102 .20588 L
.55882 .21241 L
.57214 .22549 L
.57843 .23133 L
.59804 .24066 L
.60994 .22549 L
.61765 .2127 L
.62252 .20588 L
.63473 .18627 L
.63725 .18129 L
.64792 .16667 L
.65686 .15439 L
.66298 .14706 L
.67647 .13159 L
.68046 .12745 L
.69608 .11225 L
.70107 .10784 L
.71569 .09592 L
.72625 .08824 L
.73529 .08223 L
.7549 .0709 L
.75935 .06863 L
.77451 .0618 L
.79412 .05476 L
.81373 .04976 L
.81759 .04902 L
.83333 .04683 L
.85294 .04598 L
.87255 .04734 L
.88556 .04902 L
.89216 .05113 L
.91176 .0577 L
.93137 .06761 L
.93303 .06863 L
.95098 .08199 L
.95761 .08824 L
.97059 .10336 L
Mistroke
.97373 .10784 L
.9847 .12745 L
.9902 .14126 L
Mfstroke
.9902 .28306 m
.98942 .28431 L
.9756 .30392 L
.97059 .31003 L
.95824 .32353 L
.95098 .33054 L
.93635 .34314 L
.93137 .34694 L
.91176 .36033 L
.90783 .36275 L
.89216 .37116 L
.87255 .38005 L
.86682 .38235 L
.85294 .38679 L
.83333 .39179 L
.81373 .39506 L
.79412 .39643 L
.77451 .39576 L
.7549 .39304 L
.73529 .38857 L
.71569 .38306 L
.71333 .38235 L
.69608 .37619 L
.67647 .36934 L
.65686 .36402 L
.64907 .36275 L
.63725 .36221 L
.63202 .36275 L
.61765 .36718 L
.59814 .38235 L
.59804 .38249 L
.58273 .40196 L
.57843 .40832 L
.5706 .42157 L
.55984 .44118 L
.55882 .44313 L
.54988 .46078 L
.54108 .48039 L
.53922 .4857 L
.53832 .5 L
.53922 .50089 L
.55882 .50327 L
.57843 .50039 L
.5826 .5 L
.59804 .49814 L
.61765 .49563 L
.63725 .49335 L
.65686 .49149 L
.67647 .49019 L
.69608 .48966 L
Mistroke
.71569 .49013 L
.73529 .49185 L
.7549 .495 L
.77451 .49948 L
.77655 .5 L
.79412 .50627 L
.81373 .51489 L
.82324 .51961 L
.83333 .52539 L
.85294 .53816 L
.85442 .53922 L
.87255 .55366 L
.8783 .55882 L
.89216 .57282 L
.89706 .57843 L
.91176 .59804 L
.91176 .59804 L
.92296 .61765 L
.93113 .63725 L
.93137 .63782 L
.93645 .65686 L
.93913 .67647 L
.93921 .69608 L
.9367 .71569 L
.93154 .73529 L
.93137 .7358 L
.9235 .7549 L
.91239 .77451 L
.91176 .77547 L
.8977 .79412 L
.89216 .8004 L
.87874 .81373 L
.87255 .81919 L
.8542 .83333 L
.85294 .83421 L
.83333 .84649 L
.82132 .85294 L
.81373 .85663 L
.79412 .86495 L
.77451 .87171 L
.77177 .87255 L
.7549 .877 L
.73529 .88092 L
.71569 .88353 L
.69608 .88481 L
.67647 .88475 L
.65686 .88327 L
.63725 .8803 L
.61765 .87569 L
.60725 .87255 L
Mistroke
.59804 .86923 L
.57843 .86064 L
.56434 .85294 L
.55882 .8495 L
.53922 .83509 L
.53714 .83333 L
.51961 .81615 L
.51748 .81373 L
.50273 .79412 L
.5 .78984 L
.49164 .77451 L
.48345 .7549 L
.48039 .7458 L
.47775 .73529 L
.47421 .71569 L
.47259 .69608 L
.47268 .67647 L
.47433 .65686 L
.47736 .63725 L
.48039 .62279 L
.48163 .61765 L
.48701 .59804 L
.49325 .57843 L
.5 .55889 L
.50001 .55882 L
.5068 .53922 L
.5 .52061 L
.48039 .52086 L
.46078 .5236 L
.44118 .52605 L
.42157 .52812 L
.40196 .52963 L
.38235 .5304 L
.36275 .53026 L
.34314 .52905 L
.32353 .52659 L
.30392 .5227 L
.29196 .51961 L
.28431 .51721 L
.26471 .50989 L
.2451 .50056 L
.24405 .5 L
.22549 .48887 L
.21344 .48039 L
.20588 .47448 L
.19036 .46078 L
.18627 .45677 L
.17194 .44118 L
.16667 .43475 L
.15687 .42157 L
Mistroke
.14706 .4064 L
.14447 .40196 L
.13432 .38235 L
.12745 .36616 L
.12618 .36275 L
.1199 .34314 L
.11537 .32353 L
.11255 .30392 L
.11145 .28431 L
.11209 .26471 L
.11457 .2451 L
.11898 .22549 L
.12554 .20588 L
.12745 .20114 L
.13452 .18627 L
.14635 .16667 L
.14706 .16564 L
.16174 .14706 L
.16667 .14174 L
.18191 .12745 L
.18627 .12387 L
.20588 .10999 L
.20938 .10784 L
.22549 .09909 L
.2451 .09056 L
.2514 .08824 L
.26471 .08403 L
.28431 .07922 L
.30392 .07594 L
.32353 .07407 L
.34314 .07351 L
.36275 .0742 L
.38235 .07612 L
.40196 .07927 L
.42157 .08367 L
.43767 .08824 L
.44118 .08936 L
.46078 .09639 L
.48039 .10474 L
.48702 .10784 L
.5 .11428 L
.51961 .12463 L
.52472 .12745 L
.53922 .13492 L
.55882 .14361 L
.57024 .14706 L
.57843 .14845 L
.59804 .14724 L
.59878 .14706 L
.61765 .13933 L
Mistroke
.63627 .12745 L
.63725 .12651 L
.65686 .1114 L
.66147 .10784 L
.67647 .09607 L
.68696 .08824 L
.69608 .08162 L
.71559 .06863 L
.71569 .06857 L
.73529 .05715 L
.75135 .04902 L
.7549 .04739 L
.77451 .03938 L
.79412 .03306 L
.80873 .02941 L
.81373 .02847 L
.83333 .02567 L
.85294 .02473 L
.87255 .02573 L
.89216 .02884 L
.89489 .02941 L
.91176 .03428 L
.93137 .04239 L
.94362 .04902 L
.95098 .05376 L
.96966 .06863 L
.97059 .0695 L
.98743 .08824 L
.9902 .09196 L
Mfstroke
.9902 .61645 m
.98026 .59804 L
.97059 .58337 L
.96695 .57843 L
.95098 .559 L
.95082 .55882 L
.93187 .53922 L
.93137 .53874 L
.91176 .52069 L
.91055 .51961 L
.89216 .50367 L
.88817 .5 L
.87255 .4867 L
.86782 .48039 L
.85589 .46078 L
.8614 .44118 L
.87255 .43043 L
.88441 .42157 L
.89216 .41554 L
.91176 .40256 L
.91284 .40196 L
.93137 .38814 L
.93916 .38235 L
.95098 .37235 L
.96179 .36275 L
.97059 .35407 L
.98099 .34314 L
.9902 .3323 L
s
.9902 .04998 m
.98917 .04902 L
.97059 .03391 L
.96398 .02941 L
.95098 .02172 L
.93137 .01261 L
.9239 .0098 L
s
.9902 .76077 m
.9827 .77451 L
.97059 .79249 L
.96934 .79412 L
.95249 .81373 L
.95098 .81529 L
.93153 .83333 L
.93137 .83347 L
.91176 .84861 L
.9055 .85294 L
.89216 .8615 L
.87265 .87255 L
.87255 .8726 L
.85294 .88217 L
.83333 .89045 L
.82888 .89216 L
.81373 .8975 L
.79412 .90346 L
.77451 .90838 L
.75795 .91176 L
.7549 .91229 L
.73529 .91517 L
.71569 .91704 L
.69608 .91789 L
.67647 .91767 L
.65686 .91633 L
.63725 .9138 L
.62573 .91176 L
.61765 .90996 L
.59804 .90467 L
.57843 .89782 L
.56507 .89216 L
.55882 .88917 L
.53922 .87839 L
.53008 .87255 L
.51961 .86507 L
.50485 .85294 L
.5 .84848 L
.48544 .83333 L
.48039 .82738 L
.47013 .81373 L
.46078 .79915 L
.45795 .79412 L
.44835 .77451 L
.44118 .75596 L
.44083 .7549 L
.43518 .73529 L
.43094 .71569 L
.42778 .69608 L
.42524 .67647 L
Mistroke
.42262 .65686 L
.42157 .65061 L
.41872 .63725 L
.41056 .61765 L
.40196 .60731 L
.38808 .59804 L
.38235 .59542 L
.36275 .58906 L
.34314 .58452 L
.32353 .58035 L
.31494 .57843 L
.30392 .57577 L
.28431 .57033 L
.26471 .5637 L
.2524 .55882 L
.2451 .55559 L
.22549 .54569 L
.21436 .53922 L
.20588 .53378 L
.18639 .51961 L
.18627 .51951 L
.16667 .50246 L
.1641 .5 L
.14706 .48203 L
.14563 .48039 L
.13004 .46078 L
.12745 .45721 L
.11676 .44118 L
.10784 .42602 L
.10544 .42157 L
.09587 .40196 L
.08824 .38331 L
.08789 .38235 L
.08143 .36275 L
.07639 .34314 L
.07275 .32353 L
.07052 .30392 L
.06969 .28431 L
.07031 .26471 L
.07244 .2451 L
.07614 .22549 L
.08154 .20588 L
.08824 .18756 L
.08878 .18627 L
.09813 .16667 L
.10784 .15014 L
.10987 .14706 L
.12451 .12745 L
.12745 .12398 L
.1428 .10784 L
Mistroke
.14706 .10387 L
.16607 .08824 L
.16667 .0878 L
.18627 .07475 L
.19702 .06863 L
.20588 .06409 L
.22549 .05543 L
.24331 .04902 L
.2451 .04845 L
.26471 .04301 L
.28431 .03889 L
.30392 .03598 L
.32353 .03421 L
.34314 .0335 L
.36275 .03381 L
.38235 .03511 L
.40196 .0374 L
.42157 .04068 L
.44118 .04497 L
.45652 .04902 L
.46078 .05027 L
.48039 .05657 L
.5 .06373 L
.51253 .06863 L
.51961 .07143 L
.53922 .07905 L
.55882 .08554 L
.57013 .08824 L
.57843 .08954 L
.59804 .08983 L
.60862 .08824 L
.61765 .08596 L
.63725 .07851 L
.65686 .0687 L
.657 .06863 L
.67647 .05786 L
.69228 .04902 L
.69608 .0469 L
.71569 .03653 L
.73017 .02941 L
.73529 .02703 L
.7549 .0187 L
.77451 .01174 L
.78076 .0098 L
Mfstroke
.0098 .34921 m
.01198 .36275 L
.01593 .38235 L
.02085 .40196 L
.02674 .42157 L
.02941 .42956 L
.03357 .44118 L
.04136 .46078 L
.04902 .47808 L
.05011 .48039 L
.05993 .5 L
.06863 .51579 L
.07085 .51961 L
.08302 .53922 L
.08824 .54699 L
.0966 .55882 L
.10784 .57348 L
.11187 .57843 L
.12745 .59614 L
.12924 .59804 L
.14706 .61552 L
.1494 .61765 L
.16667 .63205 L
.17352 .63725 L
.18627 .64612 L
.20369 .65686 L
.20588 .65811 L
.22549 .66838 L
.24272 .67647 L
.2451 .67754 L
.26471 .68628 L
.28431 .69575 L
.28492 .69608 L
.30392 .70775 L
.31395 .71569 L
.32353 .72516 L
.33223 .73529 L
.34314 .75081 L
.34586 .7549 L
.35815 .77451 L
.36275 .78218 L
.37036 .79412 L
.38235 .81234 L
.38333 .81373 L
.39796 .83333 L
.40196 .83841 L
.41455 .85294 L
.42157 .86054 L
.43376 .87255 L
.44118 .87939 L
Mistroke
.45642 .89216 L
.46078 .89557 L
.48039 .90949 L
.4839 .91176 L
.5 .92144 L
.51881 .93137 L
.51961 .93176 L
.53922 .9405 L
.55882 .94795 L
.56785 .95098 L
.57843 .95414 L
.59804 .9592 L
.61765 .96326 L
.63725 .96638 L
.65686 .96864 L
.67647 .97008 L
.68858 .97059 L
.69608 .97077 L
.71569 .97077 L
.72339 .97059 L
.73529 .97013 L
.7549 .9689 L
.77451 .96714 L
.79412 .96489 L
.81373 .96219 L
.83333 .95906 L
.85294 .95552 L
.87255 .95158 L
.87534 .95098 L
.89216 .94719 L
.91176 .94234 L
.93137 .93698 L
.9498 .93137 L
.95098 .93099 L
.97059 .92423 L
.9902 .91652 L
Mfstroke
.66435 .0098 m
.65686 .01204 L
.63725 .01709 L
.61765 .01988 L
.59804 .01992 L
.57843 .01729 L
.55882 .01266 L
.54865 .0098 L
s
.0098 .24156 m
.01269 .22549 L
.01735 .20588 L
.02339 .18627 L
.02941 .17029 L
.03093 .16667 L
.04008 .14706 L
.04902 .13075 L
.05101 .12745 L
.06407 .10784 L
.06863 .1017 L
.07959 .08824 L
.08824 .07865 L
.09815 .06863 L
.10784 .05969 L
.12063 .04902 L
.12745 .0438 L
.14706 .03035 L
.14855 .02941 L
.16667 .01891 L
.18507 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo01kooooo0ol0
000oooooo`Go00003Oooool4o`00017ooooo00<00000o`000?l000006Oooool3o`0000cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo6P000003o`0004L06ATI3Ol0
000B01TI6@<000007`0c<c<00ol000006ATI01TI6@0501TI6@Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo6@0000000ol000006ATI01TI6@1U01TI6@8000003@0c
<c<;000000/0<c<c0ol0000401TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo5`000002o`0006D06ATI00<00000o`00000000002`0c<c<01000003o00000000
0000000;04a<C0@000002P0c<c<01?l000006ATI01TI6@0I6AT4ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?oooooooooooooooaH0000000?o000001TI6@0I6AT06@0I6ATC000003L0
6ATI0P00000;03<c<`<000004`1<C4`3000000P0<c<c00?o000001TI6@0I6AT01?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooolE00000003o`00000I6AT06ATI01L0
6ATI0`00000C03<c<`L00000;P0I6AT2000000X0<c<c0`00000I04a<C08000001`0c<c<00ol00000
6ATIooooo`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooa@0
000000?o000001TI6@0I6AT04P0I6AT6000001d0<c<c0`00000Z01TI6@030000000c<c<0<c<c00P0
<c<c0P00000;04a<C0X000002@1<C4`00`000000<c<c03<c<`0503<c<`03o`000?oooooooooo00;o
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo4P000002o`0001@0
6ATI00<00000o`00000c<c<0900c<c<01?l00000000000000000000U01TI6@0300000?l00000<c<c
00L0<c<c00<00000o`00001<C4`0201<C4`01000003o000000000000000:06IVIP04o`0000000000
0000000000H0C4a<00?o00000000000000001@0c<c<01Ol0003oooooooooooooool000000=7ooooo
0009ooooo`0400000?oooooooooooooooa40000000?o000001TI6@0I6AT0400I6AT4000002/0<c<c
0`00000O01TI6@<000001`0c<c<3000000L0C4a<1000000B06IVIP8000001`1<C4`00`000000<c<c
03<c<`0203<c<`Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
400000000ol000006ATI01TI6@0?01TI6@800000<P0c<c<3000001X06ATI0P00000903<c<`030000
001<C4`0C4a<00D0C4a<0`00000706IVIPP000002@1VIVH2000000H0C4a<00@0000003<c<`0c<c<0
<c<c1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool?00000003
o`00000I6AT06ATI00h06ATI00<00000o`00000c<c<0=P0c<c<00ol000006ATI01TI6@0E01TI6@80
00002@0c<c<2000000D0C4a<0`00000706IVIP0300000?l00000000000P0Ogmo0`0000000ol00000
00000000000506IVIP8000001@1<C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooo`l0000000?o000001TI6@0I6AT0300I6AT200000180
<c<c4`00000E03<c<`<000004`0I6AT00`000000<c<c03<c<`0703<c<`8000001@1<C4`2000000H0
IVIV1000000A07moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000
<c<c03<c<`04ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`h0
000000?o000001TI6@0I6AT02`0I6AT200000140<c<c0`00000C04a<C0<000005@0c<c<3000000d0
6ATI0`00000903<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH2000000/0
Ogmo1000000707moO`8000001@1VIVH00`000000C4a<04a<C00204a<C0030000000c<c?ooooo00?o
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo3@0000000ol00000
6ATI01TI6@0;01TI6@030000000c<c<0<c<c00h0<c<c0`00000I04a<C0<000005@0c<c<3000000P0
6ATI0P00000<03<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000
Ogmo07moO`0407moO`L00000102IVIT3000000H0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00204a<C00300000?oooooooooo00;ooooo00<00000ooooooooool0Roooool2o`0004;o
oooo0009ooooo`0400000?ooooooooooooooo``0000000?o000001TI6@0I6AT02`0I6AT00`00003o
000003<c<`0;03<c<`0400000?l000000000000001l0C4a<00Co00000000000000000000500c<c<0
0ol0000000000000000400000003o`00000c<c<0<c<c00X0<c<c0P00000504a<C08000000`1VIVH0
0`00003o00000000000407moO`0300000?l00000000000h0VIVI00?o0000000000000000101oOgl0
0ol00000000006IVIP0306IVIP030000001<C4`0C4a<0080C4a<00Go0000oooooooooooooooo0000
002:ooooo`?o000000?oooooo`000?ooool0@Oooool000Wooooo00@00000oooooooooooooooo2`00
00000ol000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00T0<c<c0`00000W04a<C0@000008P0c
<c<2000000D0C4a<0P00000406IVIP030000001oOgl0Ogmo00<0Ogmo0P00000:09VIV@Co00001P2I
VIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV00@0000004a<C01<C4`0C4a<
1?ooool00`00003oooooooooo`26ooooo`;o00001?ooool2o`00047ooooo0009ooooo`0400000?oo
ooooooooooooo`X0000000?o000001TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0903<c<`030000
001<C4`0C4a<02`0C4a<00?o000003<c<`0c<c<07P0c<c<00`000000C4a<04a<C00404a<C0030000
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl2000000D0VIVI1ol000040;>c/`?o0000
102IVIT2000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C004ooooo`030000
0?oooooooooo08?ooooo0ol00006ooooo`03o`000?oooooo0000043ooooo0009ooooo`0400000?oo
ooooooooooooo`T0000000?o000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`0803<c<`03o`00
00000000C4a<00d0C4a<100000000ol0000000000000000500000003o`0000000000000000@00000
3`1<C4`2000001d0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT3o`0000h0/k>c0_l0000409VIV@030000
001oOgl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0Cooooo00<00000oooooooo
ool0P?ooool3o`0000Wooooo00?o0000ooooool00000@?ooool000Wooooo00@00000oooooooooooo
oooo2@0000000ol000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<
C4`02`1<C4`3000001<0IVIV0`00000>04a<C08000006@0c<c<00`00003o000004a<C00404a<C003
00000?l00000IVIV00@0IVIV00H0000007moO`1oOgl0Ogmo00000?l0000309VIV@;o00004`2c/k<0
0ol00000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH00`000000C4a<04a<
C004ooooo`0300000?oooooooooo07kooooo0_l0000<ooooo`04o`000?ooooooooooo`0003oooooo
0009ooooo`0400000?ooooooooooooooo`P0000000?o000001TI6@0I6AT02P0I6AT00`000000<c<c
03<c<`0803<c<`030000001<C4`0C4a<00P0C4a<1000000I06IVIP@00000301<C4`2000001H0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00800000
0`2IVIT2o`0000D0/k>c3_l000030;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1oOgl0
Ogmo0000000306IVIP030000001<C4cooooo00?ooooo00<00000ooooooooool0Noooool3o`0000go
oooo00?o]9boo`000?ooool00_ooool00ol0003oooooooooo`0looooo`002Oooool01000003ooooo
ooooooooool700000003o`00000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01`0c<c<00ol00000
000004a<C00704a<C0<000008@1VIVH2000000`0C4a<00?o00000000000c<c<04@0c<c<2000000H0
C4a<00<0000006IVIP1VIVH00`1VIVH01Ol00000000007moO`1oOgl0000000@0VIVI00?o00000;>c
/`2c/k<00`2c/k<2o`0000h0c<c<00Co00000;>c/`2c/k<0/k>c0_l0000309VIV@050000001oOgl0
Ogmo07moO`0000000`1VIVH00`00003oooooooooo`02ooooo`0300000?oooooooooo07Wooooo0_l0
000?ooooo`;o]9bo00Go0000ooooooooooooooooo`00000nooooo`002Oooool01000003ooooooooo
ooooool700000003o`00000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<
04a<C00704a<C0030000001VIVH0IVIV02@0IVIV0P00000<04a<C0030000000c<c<0<c<c00h0<c<c
00<0000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo
00?o000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`020;>c/`;o0000403<c<`01Ol00000/k>c
0;>c/`2c/k?o000000<0VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP0300000?oooooooooo
00;ooooo00<00000ooooooooool0M_ooool3o`00013ooooo0ondW;l00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo0009ooooo`0400000?ooooooooooooooo`L0000000?o000001TI
6@0I6AT02@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<0P00000?06IV
IP/000003`1VIVH2000000/0C4a<0`00000<03<c<`030000001<C4`0C4a<00H0C4a<00<0000006IV
IP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`040000002IVIT0VIVI09VIV@;o00000`2c/k<2
o`0000H0c<c<200000050<c<c005o`00002c/k<0/k>c0;>c/ol000000`2IVIT01@000000Ogmo07mo
O`1oOgl0000000<0IVIV00D00000oooooooooooooooo0000001fooooo`;o00004_ooool2ok:G^`;o
]9bo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`002Oooool01000003ooooo
ooooooooool600000003o`00000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01P0c<c<00`000000
C4a<04a<C00604a<C0030000001VIVH0IVIV00T0IVIV00?o00000000000000000`00000;07moO`@0
00003@1VIVH00`000000C4a<04a<C00;04a<C0<000001`0c<c<2000000P0C4a<00<0000006IVIP1V
IVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl00000102c/k<00ol0
0000c<c<0<c<c0030<c<c0<00000203Vi^H2000000@0c<c<00Go00000;>c/`2c/k<0/k>co`000002
09VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH01@00003oooooooooooooool0000007?ooooo
0ol0000Booooo`03ojjA^?nbUk_o/YNk00;o/YNk00?o]9boo`000?nhVkX01?ooool00ol0003ooooo
ooooo`0jooooo`002Oooool01000003oooooooooooooool500000003o`00000I6AT06ATI00T06ATI
00<0000003<c<`0c<c<01`0c<c<00ol00000C4a<04a<C00504a<C0030000001VIVH0IVIV00P0IVIV
00<00000o`00001oOgl0501oOgl3000000/0IVIV0P00000>04a<C003o`0000000000000000@00000
2@1<C4`00`000000IVIV06IVIP0306IVIP05o`00001oOgl0Ogmo07moO`0000000`2IVIT00ol00000
/k>c0;>c/`020;>c/`04o`00003<c<`0c<c<0<c<c0<000003@3Vi^H00`000000c<c<0<c<c0020<c<
c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV1?oo
ool00`00003oooooooooo`1^ooooo`?o00004_ooool00onZS;Ko[Y6hojjA^002ojjA^0;o/YNk00?o
]9FfokRK^_l000000_nhVkX4ooooo`03o`000?oooooooooo03Wooooo0009ooooo`0400000?oooooo
ooooooooo`D0000000?o000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0603<c<`030000001<
C4`0C4a<00D0C4a<00?o000006IVIP1VIVH01`1VIVH2000001X0Ogmo0`00000:06IVIP030000001<
C4`0C4a<01X0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`04o`00002I
VIT0VIVIo`0000@0/k>c00Go00000<c<c03<c<`0c<c<0000000A0>KViP050000003<c<`0c<c<0<c<
c?l000000`2c/k<01?l00000VIVI09VIV@00000307moO`030000001VIVH0IVIV00Cooooo00<00000
ooooooooool0K?ooool2o`0001Cooooo0_nZS;H4ojjA^003ok:G^ondUKKo]9Ff00;o^9^j00?o0000
okRK^_ooool00oooool00ol0003oooooooooo`0iooooo`002Oooool01000003oooooooooooooool4
00000003o`00000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C005
04a<C0030000001VIVH0IVIV00H0IVIV0P00000O07moO`030000001VIVH0IVIV00P0IVIV0P00000J
04a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2I
VIWo000000<0/k>c00Go00000<c<c03<c<`0c<c<000000070>KViPGo00001`3Vi^H01Ol00000c<c<
0<c<c03<c<co000000<0/k>c00Co000009VIV@2IVIT000000`1oOgl00`000000IVIVooooo`03oooo
o`0300000?oooooooooo06Wooooo0ol0000Eooooo`CoZXbf0on^TKP4okBE]P03okRK^_l0003o_9^f
00Gooooo00?o0000ooooooooool0>?ooool000Wooooo00@00000oooooooooooooooo0`0000000ol0
00006ATI01TI6@0901TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`00
0000IVIV06IVIP0506IVIP03o`0000000000Ogmo00d0Ogmo1P00000>07moO`03o`00000000000000
00T0IVIV00<0000004a<C01<C4`05P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo
0080Ogmo00D0000009VIV@2IVIT0VIVIo`0000030;>c/`05o`00003<c<`0c<c<0<c<c00000001@3V
i^H3o`0000D0oooo0ol000050>KViP050000003<c<`0c<c<0<c<c?l000000P2c/k<01?l00000VIVI
09VIV@00000307moO`030000001VIVKooooo00?ooooo00<00000ooooooooool0Ioooool2o`0001Oo
oooo0_nUQk@3ojZ<]P;o[Y6h00?o/8ncokBE]_ndUKH00_ndUKH01?nhVk[o0000okbK]_nlVkH5oooo
o`03o`000?oooooooooo03Oooooo0009ooooo`0400000?ooooooooooooooo`<0000000?o000001TI
6@0I6AT02@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00?o000006IV
IP1VIVH01@1VIVH00`000000Ogmo07moO`0807moO`H000001P2IVIT3000000h0Ogmo00<0000006IV
IP1VIVH01`1VIVH00`000000C4a<04a<C00E04a<C0030000001VIVH0IVIV0080IVIV00<0000007mo
O`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIWo000000<0/k>c00Go00000<c<c03<c<`0c<c<0000
00040>KViP03o`00003oool0oooo00P0oooo00?o00000>KViP3Vi^H00`3Vi^H01@000000c<c<0<c<
c03<c<co00000080/k>c00Co000009VIV@2IVIT000000`1oOgl00`000000IVIVooooo`03ooooo`03
00000?oooooooooo06Cooooo0ol0000Gooooo`04oj23]?nUQkCoYHNdojF7]0?oZXbf00Co[Y6hok2?
/on`Sk?o/8nc0ondUKH01?nlVkKo0000okbK]_nlVkH5ooooo`03o`000?oooooooooo03Oooooo0009
ooooo`0400000?ooooooooooooooo`<0000000?o000001TI6@0I6AT02@0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07mo
O`0607moO`<000003`2IVIT4000000/0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<
C00C04a<C0030000001VIVH0IVIV00<0IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@05o`00
002c/k<0/k>c0;>c/ol000000`3<c<`00`000000i^KV0>KViP020>KViP03o`00003oool0oooo00X0
oooo00?o00000>KViP3Vi^H00P3Vi^H01@000000c<c<0<c<c03<c<co00000080/k>c00Co000009VI
V@2IVIT000000`1oOgl00`000000IVIVooooo`03ooooo`0300000?oooooooooo06;ooooo0_l0000G
ooooo`04oi]o]?nPPkCoX8>doj23]0?oYHNd0onZS;H4ok2?/`;o]9Ff00?o^9FbokbK]_l000000_nl
VkH6ooooo`03o`000?oooooooooo03Kooooo0009ooooo`0400000?ooooooooooooooo`80000000?o
000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI01@0VIVI0`00
000907moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`04@1<C4`00`000000IVIV06IV
IP0406IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01Ol00000/k>c0;>c/`2c/k?o000000<0
c<c<00<000000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00003Vi^H0i^KV00<0
i^KV00@000000<c<c03<c<co00000`2c/k<01?l00000VIVI09VIV@00000207moO`030000001VIVKo
oooo00?ooooo00<00000ooooooooool0Goooool3o`0001Kooooo00?oUWfeoi]o]?nKOk@00_nKOk@3
oj23]0?oYHNd00?oZXbfojb9/On/RK400on`Sk<01ondUKKo^9FbokRE/_nhUK;o0000okbK]_o1WK<0
1oooool00ol0003oooooooooo`0eooooo`002Oooool01000003oooooooooooooool200000003o`00
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000
001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl2000001X0VIVI00?o000007moO`1oOgl0
1`1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00l0C4a<00?o000006IVIP1VIVH0
101VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00Go00000;>c/`2c/k<0/k>co`0000030<c<
c0030000003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool0303oool00ol00000i^KV0>KViP020>KV
iP040000003<c<`0c<c<o`0000<0/k>c00Co000009VIV@2IVIT000000P1oOgl00`000000IVIVoooo
o`03ooooo`0300000?oooooooooo05gooooo0_l0000Gooooo`04oi9k]_nFOKGoUWfeoiIm]@?oVgnd
0onPPk@2ojF7]004ojJ4/?n/RK7o[8Vaojb9/@?o/8nc1?nhUK801?l0003o`Ifcol6M/oo1WK<6oooo
o`03o`000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`80000000?o000001TI
6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`8000007@2IVIT2000000P0Ogmo00<0000006IV
IP1VIVH01`1VIVH2000000l0C4a<00<0000006IVIP1VIVH0101VIVH01@000000Ogmo07moO`1oOgl0
000000<0VIVI00Go00000;>c/`2c/k<0/k>co`0000030<c<c0030000003Vi^H0i^KV0080i^KV00?o
00000?ooo`3oool0303oool00ol00000i^KV0>KViP020>KViP040000003<c<`0c<c<o`0000<0/k>c
00Co000009VIV@2IVIT000000P1oOgl00`000000IVIVooooo`03ooooo`0300000?oooooooooo05[o
oooo0ol0000Dooooo`03oh]k_?n>N[WoSWZi00?oTW^f0onFOKD3oi]o]0?oX8>d00?oYHNdojJ4/?nV
Q;001?n/RK400on`Sk?o]8n`okB?/003okRE/P04o`000?o1WK?o`Ifcol6M/`Oooooo00?o0000oooo
ooooool0=?ooool000Wooooo00H00000oooooooooooooooo00000?l0000;01TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT02P2IVIT8o`0000d0VIVI00<0000007moO`1oOgl01P1oOgl0
0`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH0101VIVH0
1@000000Ogmo07moO`1oOgl0000000@0VIVI00Co00000;>c/`2c/k?o00000`3<c<`00`000000i^KV
0>KViP020>KViP03o`00003oool0oooo00d0oooo00?o00000>KViP3Vi^H00P3Vi^H010000000c<c<
0<c<c?l000020;>c/`05o`00002IVIT0VIVI09VIV@0000000P1oOgl00`000000IVIVooooo`03oooo
o`0300000?oooooooooo05Oooooo0ol0000=ooooo`03ohj<c?n;Q/SoRhK800?oRH740_n9OKl3oh]k
_0?oSWZi0onBNkH2oiIm]@CoVgnd00?oX8>doj5o[onVQ;000onVQ;03ojb9/@?o]8n`0onhUK801?l0
003o`Ifcol6M/oo1WK<8ooooo`03o`000?oooooooooo03?ooooo0009ooooo`0600000?oooooooooo
ooooo`00003o00002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00?o
000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI00L0VIVI1?l0
00080;>c/`Co00002P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00P0IVIV00<0
000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0506IVIP050000001oOgl0Ogmo07moO`000000
0`2IVIT01Ol00000/k>c0;>c/`2c/k?o000000<0c<c<00<000000>KViP3Vi^H00P3Vi^H00ol00000
oooo0?ooo`0=0?ooo`03o`00003Vi^H0i^KV0080i^KV00@000000<c<c03<c<co00000P2c/k<01Ol0
0000VIVI09VIV@2IVIT000000080Ogmo00<0000006IVI_ooool00oooool00`00003oooooooooo`1E
ooooo`;o00002oooool00onHV=;oTi;@oi>Bd003ohj<c0;oRhK80on9PL@3ohUm_`?oRg^l0_n>N[T3
oi9k]P?oUWfe0_nKOk@01?nJNjooXGn_oj5o[onQOjl3ojJ4/0;o[8Va00?o[XV]okB?/?ndSk000_nd
Sk000onhUK;o_IN`o`000003ol6M/`03olNQ/Ooooooooooo00Gooooo00?o0000ooooooooool0<ooo
ool000Wooooo00H00000oooooooooooooooo00000?l0000:01TI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT01P2IVIT00ol00000/k>c0;>c/`0>0;>c/`?o0000202IVIT00`000000Ogmo
07moO`0507moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`02@1<C4`00`000000IVIV
06IVIP0506IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01Ol00000/k>c0;>c/`2c/k?o0000
00<0c<c<00<000000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`0=0?ooo`03o`00003Vi^H0i^KV
0080i^KV00@000000<c<c03<c<co00000P2c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00<0
000006IVI_ooool00oooool00`00003oooooooooo`1Booooo`?o00002?ooool00onRX]GoWIkDoifN
e004oiRHdP;oTi;@0on>S<`2oh^6b0?oRH740_n9OKl3oh]k_0;oSWZi0onBNkH2oiIm]@04oiAg/?nJ
NjooVW^_oiYk[`?oXGn_0onVQ;001?n/RK7o[XV]ojj9[On^RJd3okB?/0;o_IN`00?o0000okfG/?o1
WK<00oo7XK47ooooo`03o`000?oooooooooo03;ooooo0009ooooo`0600000?ooooooooooooooo`00
003o00002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00D0VIVI0_l0000D0;>c
/`03o`00002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0806IV
IP030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH01P1VIVH01@000000Ogmo07moO`1oOgl0
000000<0VIVI00Go00000;>c/`2c/k<0/k>co`0000030<c<c0030000003Vi^H0i^KV0080i^KV00?o
00000?ooo`3oool0303oool00ol00000i^KV0>KViP020>KViP050000003<c<`0c<c<0<c<c?l00000
0P2c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00<0000006IVI_ooool00oooool00`00003o
ooooooooo`1@ooooo`;o00002?ooool00onVYMGoXZ;Eoj:Re@02oj:Re@;oWIkD0onHV=82oi>Bd0?o
SXc<0_n;Q/P3ohV1a0?oRGfo0_n;Nk`3ohij^@03oi9k]_n>M;7oU7N`00;oU7N`0onJNjl3oj5o[`?o
YXB`1?n^RJd2okB?/005okR@[OnmUk3o_IN`o`000?nmUk001?o7XK47ooooo`03o`000?oooooooooo
03;ooooo0009ooooo`0500000?ooooooooooooooool000002P0I6AT00`000000<c<c03<c<`0503<c
<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307mo
O`030000002IVIT0VIVI00D0VIVI00?o00000;>c/`2c/k<05@2c/k<00ol00000VIVI09VIV@0609VI
V@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00604a<
C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIWo
000000<0/k>c00Go00000<c<c03<c<`0c<c<000000050>KViP03o`00003oool0oooo00/0oooo00?o
00000>KViP3Vi^H00P3Vi^H010000000c<c<0<c<c?l000020;>c/`05o`00002IVIT0VIVI09VIV@00
00000P1oOgl00`000000IVIV06IVIP04ooooo`0300000?oooooooooo04gooooo0ol00008ooooo`04
ojRVe?nVYMGoYZGEojJUe@?oXZ;E0onMW]@01?nHV=;oTI3?oh^9c?n;RL`3ohJ2a`;oPW_30on1M[h3
oh9c^P;oQG:f0on9L[<3ohid/@;oU7N`1?nJNjl3oj5o[`03ojJ4/?nXPjcoZ8>/00?o[XV]00Oo]8n`
okR@[OnhT:go^92]okfG/?l0003o_IN`00Coaj6a2?ooool00ol0003oooooooooo`0aooooo`002Ooo
ool01@00003ooooooooooooooooo000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00ol00000VIVI
09VIV@0409VIV@03o`00002c/k<0/k>c01L0/k>c0_l0000709VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH0201VIVH00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV00H0IVIV
00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIWo000000<0/k>c00Go00000<c<c03<
c<`0c<c<000000050>KViP03o`00003oool0oooo00X0oooo00?o00000>KViP3Vi^H00P3Vi^H01@00
0000c<c<0<c<c03<c<co00000080/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`030000001V
IVH0IVIV00Cooooo00<00000ooooooooool0Boooool2o`0000Sooooo00?oZjKCojRVe?nXY]@00_nX
Y]@3ojJUe@03oj:ReOnNWM;oV9OA00;oV9OA0onAT<l2oh^9c0;oQX;70on2Nl<2oh5f_P?oPW>j0_n5
L[H3ohUb/`?oSWBa0onDMk03oiYk[`;oXGn_00CoXWf/ojR3[?nXPjcoZ8>/0on^RJd4okR@[@04okfG
/?l0003o`iZ^ol>J[P;oaj6a0_o>Yk08ooooo`03o`000?oooooooooo033ooooo0009ooooo`050000
0?ooooooooooooooool000002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0
C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0407moO`030000002IVIT0VIVI00<0
VIVI00?o00000;>c/`2c/k<06P2c/k<00ol00000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00D0
Ogmo00<0000006IVIP1VIVH02@1VIVH2000000@0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000
Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl000000`2c/k<01Ol00000c<c<0<c<c03<c<`0
000000H0i^KV0_l000090?ooo`03o`00003Vi^H0i^KV00<0i^KV00@000000<c<c03<c<co00000`2c
/k<01?l00000VIVI09VIV@00000307moO`040000001VIVH0IVIV000000?ooooo00<00000oooooooo
ool0B?ooool3o`0000Wooooo0on[Y]<3ojRVe0;oYZGE00CoXj7BoijMd_nNWM;oWYgB0onHUm42oi6@
c`?oRhW<0_n6P/L2oh9k``?oPGJn0on2LkX2ohEb]P?oRG:c0_n>M;43oiAg/0?oVW^_00?oXGn_oj9m
[?nROJ`00onXPj`3ojj9[@06ok::ZonhT:go^92]okR@[OnmUk3o00000_o3VZh01?o7XK7ocZN`oljW
/?o>Yk08ooooo`03o`000?oooooooooo033ooooo0009ooooo`0500000?ooooooooooooooool00000
2P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<0
2`2c/k<5o`0000/0/k>c00?o000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000
001VIVH0IVIV00X0IVIV0P0000000`1<C4`0000006IVIP0906IVIP030000001oOgl0Ogmo0080Ogmo
00D0000009VIV@2IVIT0VIVIo`0000030;>c/`05o`00003<c<`0c<c<0<c<c00000001`3Vi^H00ol0
0000oooo0?ooo`040?ooo`;o00001@3Vi^H01@000000c<c<0<c<c03<c<co000000<0/k>c00Co0000
09VIV@2IVIT000000P1oOgl01@000000IVIV06IVIP1VIVH0000000?ooooo00<00000ooooooooool0
AOooool3o`0000_ooooo0_n/Y]43oj^Vd`03ojRVe?nWXm7oYj?A00?oXj7B0_nNWM83oiRGd@03oi6@
con9R<coPWo800;oPWo80_mlMl<3oh9k``;oPGJn0on2LkX2ohEb]P?oRG:c0on>M;42oiAg/0;oVW^_
00?oVWR/oj9m[?nROJ`00_nROJ`3ojR3[003ojj9[OnbRZ_o/XZ[00?o^92]00Co`iZ^o`000?o3VZko
`iZ^1?o>Yk09ooooo`03o`000?oooooooooo02oooooo0009ooooo`0500000?ooooooooooooooool0
00002P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c
/k<0202c/k<4o`0000D0c<c<0_l0000:0;>c/`03o`00002IVIT0VIVI00D0VIVI00<0000007moO`1o
Ogl0101oOgl00`000000IVIV06IVIP0<06IVIP030000001VIVH0IVIV00T0IVIV00<0000007moO`1o
Ogl00P1oOgl01@000000VIVI09VIV@2IVIWo000000<0/k>c00?o00000<c<c03<c<`00P3<c<`00`00
0000i^KV0>KViP050>KViPKo00001@3Vi^H2000000<0c<c<00Go00000;>c/`2c/k<0/k>co`000002
09VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH00`00003oooooooooo`02ooooo`0300000?oo
oooooooo04?ooooo0_l0000<ooooo`04ojbUd?n/Y]7o[:KAojbVd@;oZjKC00?oZZC@ojNSdOnWXm40
0_nWXm42oj>QdP03oijMd_nJUm3oTY7?00;oTY7?0on9R<`2oh9ob0;oO7O30omiLKh2ogQ/^@?oNVZe
0_n5L[H3ohUb/`?oSWBa00?oU7N`oi=c[?nJN:`00_nJN:`4oj9m[0;oZ8>/00Co[8BZok::ZonbRZ_o
/XZ[0onhT:d01OnnU:co0000ol>J[_o3VZkobj6]00?ocZN`00?oejn`ooooooooool01oooool00ol0
003oooooooooo`0^ooooo`002Oooool01000003oooooooooooooool;01TI6@030000000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo
00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`070;>c/`03o`00003<c<`0c<c<
00T0c<c<0_l000080;>c/`03o`00002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0H06IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVIo`000003
0;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000000003Vi^H03@3Vi^H2000000D0c<c<00Co0000
0;>c/`2c/k?o00000`2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00<00000ooooooooool0
0_ooool00`00003oooooooooo`10ooooo`?o00002oooool2ojbTc`?o[:G@00?o[:KAojbSconZY=00
0onZY=02ojNSd@03ojJOconQW=3oXIc@00?oVYO@0onBTLl2ohV8c0?oPWo80_mlMl<2ogUa_P?oN6bi
0_mjJ[D2ogmZ/P?oQFb_0on<Kjd3oi=c[0?oVWR/0onROJ`00onXPjco[8BZojb4ZP04ok::Z`05okR@
[OnnU:co_YB/o`000?o3VZh00_o;XJd2oljW/0;oejn`2Oooool00ol0003oooooooooo`0^ooooo`00
2Oooool01000003oooooooooooooool;01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00P2IVIT00ol00000/k>c0;>c/`070;>c/`03o`00003<c<`0c<c<00`0c<c<00?o00000;>c/`2c
/k<01P2c/k<00ol00000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH05`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00Go00000;>c/`2c
/k<0/k>co`0000060<c<c0030000003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`0103<c<`01?l0
0000/k>c0;>c/ol0000309VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH00`00003ooooooooo
o`02ooooo`0300000?oooooooooo03kooooo0_l0000<ooooo`03oj^RcOn/Y<oo[:C?00;o[:C?00?o
[:G@ojfScOn/Xll00_n/Xll3ojZTd0CoYYo?0_nQW=03oiZGd0;oTY7?0on9R<`2oh9ob0;oO7O30omi
LKh2ogQ/^@;oNVZe0omoJ[83ohE/[`;oS6n]0onCLj`3oiYh[0;oXWf/00?oY7fYojb4Z_n/Q:X00_n/
Q:X3ok::Z`?o_YB/00?o0000ol>J[_o;XJd00_o;XJd01?o>Yk3oejn`omN_/?oP^[09ooooo`03o`00
0?oooooooooo02gooooo0009ooooo`0400000?ooooooooooooooo`X06ATI00<0000003<c<`0c<c<0
1@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl0
0`1oOgl00`000000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00H0/k>c00?o00000<c<c03<c<`0
3@3<c<`00ol00000/k>c0;>c/`060;>c/`03o`00002IVIT0VIVI00D0VIVI00?o000007moO`1oOgl0
101oOgl00`000000IVIV06IVIP0H06IVIP050000001oOgl0Ogmo07moO`000000102IVIT00ol00000
/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H01`3Vi^H2000000H0
c<c<00Co00000;>c/`2c/k?o0000102IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00<00000
04a<C?ooool00oooool00`00003oooooooooo`0kooooo`?o00002oooool00on[X<coZj;=oj^Rc@02
oj^Rc@;o[:C?00Co[J7;ojfScOn]Xlgo[J?=0on/Xll00onZY=3oZZ7>ojZQcP03ojJOc`03oj6Ld?nN
VLooUI;>00;oUI;>0_n;R/d3oh20b@;oMgK50omaKKl2ogUa_P;oN6bi0omjJ[D2ogmZ/P?oQFb_0_n<
Kjd3oi=c[0?oVWR/00CoXWf/ojAmZOnTOJWoY7fY0on/Q:X2ok::Z`05okR>Z_nnU:co_YB/okjD[?l0
00001?o;XJd3omN_/0;oh;Z`2Oooool00ol0003oooooooooo`0/ooooo`002Oooool01000003ooooo
ooooooooool:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000
IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000
/k>c0;>c/`050;>c/`03o`00003<c<`0c<c<00l0c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000
VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH02`1VIVH2000000/0
IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c0080
/k>c0_l000050<c<c0P0000000?o00000<c<c03<c<`0103<c<`2o`0000<0/k>c00Go000009VIV@2I
VIT0VIVI0000000207moO`0300000?l00000IVIV0080IVIV00?o000004a<C?ooool00oooool00`00
003oooooooooo`0iooooo`;o00003?ooool01?nYW/_oZj3<oj^Pc?n[X<`3oj^Rc@04ojbTcon]XL_o
[J7;ojfQb`;o[J?=0_n/Xll00on/XLcoZZ7>ojZQcP02ojZQcP03ojJOconUWLkoWYW?00;oWYW?0onE
T/h2oh^:c@?oP8390_mgM/D2og5]_`;oKVNj0omhK;T2ogYZ]@;oOfZb0on5K:l3oha_[@?oTg>/0_nJ
N:`4ojAmZ@?o[8BZ00Co/XZ[okR>Z_nhSZ[o^8jZ0_nnU:`00ol0003obj6]ol^Q[@02ol^Q[@03omBZ
[OoG[k3oh;Z`00;oh;Z`2Oooool00ol0003oooooooooo`0/ooooo`002Oooool01000003ooooooooo
ooooool:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c
0;>c/`050;>c/`03o`00003<c<`0c<c<00l0c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH02`1VIVH00`000000C4a<
0000000:06IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c
0;>c/`030;>c/`03o`00003<c<`0c<c<00h0c<c<0ol000040;>c/`05o`00002IVIT0VIVI09VIV@00
00000`1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<1?ooool00`00003oooooooooo`0foooo
o`?o00003?ooool01?nXW<[oZIk;ojVNbonYW//3oj^Pc003oj^RcOn/Wl[o[9o:00?o[J7;00?o[J?=
ojfPb_n/XL`00on/XL`2ojZQcP04ojVOc?nUWLkoYIg>ojFMcP?oWYW?0_nET/h3oh^:c@;oP8390_mg
M/D2og5]_`;oKVNj0om^HkD2og9R/P?oOfZb0on5K:l2oha_[@?oTg>/00?oVWR/oi]gZOnTOJT00onT
OJT3ojb4ZPCo^8jZ0_nnU:`01?l0003oaY^[ol^Q[Oo;XJd2omBZ[@05omN_/?oP^[3oh;Z`on2j/?oZ
ak402Oooool00ol0003oooooooooo`0[ooooo`002Oooool01000003oooooooooooooool:01TI6@03
0000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`050;>c/`03
o`00003<c<`0c<c<0140c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0409VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH02@1VIVH010000000C4a<04a<C01<C4`20000
00T0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c
00<0/k>c0ol0000<0<c<c003o`00002c/k<0/k>c00@0/k>c00Go000009VIV@2IVIT0VIVI00000003
07moO`050000001VIVH0IVIV06IVIP0000000`1<C4`4ooooo`0300000?oooooooooo03?ooooo0ol0
000>ooooo`?oZ9c:0_nYW//2oj^Pc003oj^Mb?n/Wl[o[9o:00;o[9o:00?o[J7;ojfOb?n]X<X00_n]
X<X3ojbQc0CoZIo<0_nUWLh2oijIc`03oiZFc_n?S/koShk>00?oPhC<0_mfN<P3of]]`P;oLFfo0_m^
IkX2ofiS]@;oLV:b0omiI:l3ohE/[`;oS6n]0_nCLj`01?nBLJ[oVgNYoi]gZOnKMjT4ojAmZ@;o[8BZ
00Wo/8NYokR>Z_nhSZ[o^8jZokjD[?o6Vj_o0000olJKZoo;XJd00ooDZZd3on2j/0;oj/Na2Oooool0
0ol0003oooooooooo`0[ooooo`002Oooool01000003oooooooooooooool:01TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`050;>c/`03o`00003<c<`0
c<c<0140c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0409VIV@030000001oOgl0
Ogmo00@0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV00L0IVIV00?o000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@;o00001P2c/k<4
o`0000D0c<c<0ol000040;>c/`?o00000`2IVIT01Ol00000Ogmo07moO`1oOgl0000000<0IVIV00<0
000004a<C01<C4`00P1<C4`01@00003oooooooooooooool0000003?ooooo0_l0000?ooooo`;oYY[9
0onXW<X00onYW/_oZY_7oj^Mb003oj^Mb0;o[9o:00Co[Ig7ojfOb?n]WlSo[Io80on]X<X00on/XLco
[Io:ojfObP03ojVOc003ojFMc_nSVlgoVYK>00?oVYK>0_n?S/h2oh>4c0;oMWS80om[KL82ofAT_@;o
KVNj0_m^HkD3og9R/P;oNFB_0on1Ijd2ohU/Z`?oTW6Z0onKMjT4ojAmZ@03ojb4Z_n`QjWo/8NY00?o
^8jZ0oo6Vj/00ol0003oe:Z]omBZ[@02omBZ[@03omjf[_oP^[3oj/Na00;oj/Na00?olmB`oooooooo
ool01oooool00ol0003oooooooooo`0Zooooo`002Oooool01000003oooooooooooooool:01TI6@03
0000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`050;>c/`03
o`00003<c<`0c<c<0140c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0409VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00504a<C003
0000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0309VIV@;o
0000202c/k<5o`0000H0/k>c00?o000009VIV@2IVIT00P2IVIT2000000@0Ogmo00D0000006IVIP1V
IVH0IVIV0000000404a<C00500000?ooooooooooooooo`000000<?ooool3o`0000oooooo00?oYIW9
ojJJbOnVV/T00_nVV/T00onXW<[oZ9W6ojZKa`02ojZKa`?oZig800Co[9o:ojfMaon]WLOo[Ig70_n]
WlP2ojfPbP03ojjOb?n]Wl[o[Io:00;o[Io:00?oZIo<ojVMbonSVld00_nSVld3oiZFcP?oShk>0_n3
Q<`2ogIhb0;oJfg20_mTI;d3of5M]`;oKV>e0_mbH[82ogUT[`?oPFN]0on9K:/2oi9aZP?oVgNY1?nT
OJT3ok27Z@?o^8jZ00Co_iBZolJKZoo6Vj_o00000ooDZZd2omjf[P03on2j/?oZak7oj/Na00;olmB`
00?onN:^ooooooooool01oooool00ol0003oooooooooo`0Yooooo`002Oooool01000003ooooooooo
ooooool:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c
0;>c/`050;>c/`03o`00003<c<`0c<c<0140c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<
04a<C00704a<C08000001`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI
00?o00000;>c/`2c/k<03P2c/k<2o`0000@0VIVI00<0000007moO`1oOgl00P1oOgl2000000<0IVIV
00<0000004a<C01<C4`00P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo02cooooo
0_l0000@ooooo`04oj>HbOnUVLWoYIW9ojFIb@;oYY[900CoYYO6ojRIa_nXVLKoZ9W60onZVlL00on[
WLSo[9_5ojfMa`03ojfMa`03ojfOb?n_WLKo[Yo800?o[Yo80_n]WlX01?n]W/SoZIg;ojVMbonYWL/3
oj>Kc@03oiZFc_nGTlkoRH[>00;oRH[>0_miO/`2ogIhb0?oJfg200KoI6Bmof5M]omQGKOoHEfgofAK
/om^HkD2og9R/P;oNFB_0on1Ijd3ohU/Z`?oTW6Z0onKMjT2ojAmZ@03ojN0ZOn`QjWo/8NY00;o/8NY
00?o^8jZoknDZ_noU:X00_o6Vj/00ol0003ocjB/omBZ[@03omjf[P;oj/Na0ooce;001OoihZkonNf[
oo;cY_oYmZCoh?RX00Gooooo00?o0000ooooooooool0:Oooool000Wooooo00@00000oooooooooooo
oooo2P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1V
IVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c
/k<0102c/k<00ol00000c<c<0<c<c00B0<c<c003o`00002c/k<0/k>c00D0/k>c00?o000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00L0IVIV00?o000004a<C01<
C4`02P1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2I
VIT0102IVIT3o`0000X0/k>c0ol0000509VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00P1VIVH00ol00000C4a<04a<C00304a<C00300000?oooooooooo00;ooooo00<00000oooooooo
ool0:Oooool3o`0000gooooo00?oWiK:oj6FbOnQU/T01?nSV<T2ojFIb@03ojJJbOnVUlKoYYO600?o
Z9W60_nZVlL01?nZV<Co[9_5ojbKaOn/VlD3ojfMa`?o[ig60on^WlP4ojfNb0;oZIg;0_nSVld00onR
V/coUi?>oiNCcP03ohV:cP;oNGk<0_mYL<L3oeaT`@;oI6Bm0_mQGKL2ofAK/`?oLV:b0_miI:l3oh5W
[@;oRFb[0onBLJX3oi]gZ@03ojAmZOnWP:WoYh2Y00Co/8NY00?o^8jZoknDZ_noU:X00_o6Vj/00ol0
003ocjB/omBZ[@03omjf[P04onW4[ooZak7olmB`oo?D/0;onN:^00OonNf[oo;cY_oYmZCoh?RXom_k
/ooIolGof?kH00?ooooo00?o0000ooooooooool0:?ooool000Wooooo00@00000oooooooooooooooo
2P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<0
102c/k<00ol00000c<c<0<c<c00B0<c<c003o`00002c/k<0/k>c00D0/k>c00?o000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`0
2`1<C4`00`000000IVIV06IVIP0506IVIP03o`0000000000Ogmo00@0Ogmo00?o0000000000000000
1P2IVIT:o`0000H0VIVI0P00000407moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0`1<C4`00ol00000<c<cooooo`03ooooo`0300000?oooooooooo02Oooooo0_l0000>ooooo`04oijE
bonOU/[oWiK:oinFbP;oXIK90onSV<T00onUVLWoYIG5ojJGaP03ojJGaP;oZ9W61?nZV<@3ojbKa@03
ojfMaon^VlCo[Y_400?o[ig600?o[Yo8ojnNa_n_W/H00on]W/P00onYWL_oZIg:oj:Jc003oj:Jc0;o
Ui?>0on9R/h2ogUnc0;oJG370_mLI<400omDF[_oI6Bmof5M]`02of5M]`04ofAK/omYG;3oJEb`ofUL
/0;oNFB_0on1Ijd3ohU/Z`;oTW6Z0_nKMjT00onNNJWoYh2YojN0Z@02ojN0Z@?o/8NY1?noU:X00oo6
Vj_o0000olnT[003omjf[P;ojLB_00Oom=B^oo?D/?oce;3onN:^ooW]ZoobljKojOJT00;oh?RX00Co
fOo5omSnf?oHo]Soe?KU0oooool00ol0003oooooooooo`0Wooooo`002Oooool01000003ooooooooo
ooooool:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c
0;>c/`040;>c/`03o`00003<c<`0c<c<0180c<c<00?o00000;>c/`2c/k<01@2c/k<00ol00000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<
04a<C00;04a<C003o`0000000000IVIV00L0IVIV00<0000007moO`1oOgl01@1oOgl200000140VIVI
0`00000407moO`800000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00Cooooo
00<00000ooooooooool09?ooool3o`0000kooooo00CoW9G<oijEbonNUL_oWYG;0onOU/X2oj6Fb@03
oj>HbOnSTlGoYIG500;oYIG50onVUlH00onXVLKoZIK3ojVF``03ojZHa0;o[9_500Co[IW2ojjKa?n^
VlCo[Y_40_n_WLH00on`W<Co[ik6ojnNaP02ojnNaP03ojfNb?n^W/OoZIg:00;oZIg:0onRV/`2oiNC
cP?oRH[>0_miO/`2ofU`a`;oG6C10_mDF[/3of5M]`;oI5^c0_mYG;02og9O[@?oPFN]0on9K:/00onB
LJ[oTg6ZoiiiZ@02oiiiZ@CoYh2Y0_n`QjT00ongSJ[o_iBZoknDZP02oknDZP04olnT[?l0003ocjB/
omZa[@;og[J^0_oYa:l2ooCD[P0:oo?D/?oihZkonNf[oo;cY_oYmZCoh?RXolSgZ_o>o/Gof?kHomCf
i@;ocNSZ0_ooool00ol0003oooooooooo`0Wooooo`002Oooool01000003oooooooooooooool;01TI
6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`050;>c
/`03o`00003<c<`0c<c<0100c<c<00?o00000;>c/`2c/k<01@2c/k<00ol00000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00>04a<
C08000001`1VIVH2000000L0Ogmo00<0000009VIV@2IVIT02`2IVIT3000000H0Ogmo00<0000006IV
IP1VIVH00`1VIVH00ol00000C4a<04a<C00304a<C0040000000c<c<0<c<c03<c<`Cooooo00<00000
ooooooooool08_ooool2o`0000cooooo00?oVIK?oiZEcOnJULd01?nLUL`2oijEb`;oWiK:00?oWY76
oj6BaOnQT/D00onSTlD3ojFEa@03ojJGa_nWU<;oZIK300;oZIK30onZV<@4ojfI`P;o[Y_41?n`W<@2
ojnNaP04ok6Na?n^W/Oo[Yk7ojjNa`?oZIg:00CoXY[<oj6IcOnDT/ooU9;?0on3Qll2ofmic@?oFfW8
0_mLI<401?mDF[_oDUBfoe9D]_mBE;H2ofAK/`;oJEb`0_mbGjd3ogeT[0?oR6^[0onCLJX2oiiiZ@Co
Yh2Y00Co/8NYokN=Z_ngSJ[o]hfZ0onoU:X00oo?Y:co0000omZa[@02omZa[@03omjf[_oYa:oom=B^
00;om=B^00Son^>ZooS^X_oikJ_ofnj>olg]S?o8mj[oc_k5om;mg@;oco;Y00?ocNSZolCIjOo4fNT0
0_ooool00ol0003oooooooooo`0Vooooo`002Oooool01000003oooooooooooooool;01TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`050;>c/`03o`00
003<c<`0c<c<00h0c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0409VIV@030000
001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00A04a<C0800000
1`1VIVH00`000000Ogmo07moO`0507moO`/0000000?o00000000001oOgl01@1oOgl200000003o`00
001VIVH0IVIV0080IVIV0P00000404a<C0800000100c<c<4ooooo`0300000?oooooooooo01oooooo
0ol0000:ooooo`03oiNIe?nHUm7oV9OA00?oVIK?0_nJULd3oibEc003oijEbonLT<OoWY7600;oWY76
0onQT/D2oj>Ca@;oYIG500CoY9;2ojND`_nWU<;oYiC20onYU/<00onZV<CoZiO1oj^G`@03ojfI`P03
ojjKa?n`V/;o/9[200?o/9c400Co[ik6ok6Na?naW/Co/Ik40_n^W/L2ojVMbP04ojZMb_nQVLgoXIW=
oj6Ic@;oU9;?0on3Qll2ofmic@;oFfW800CoBe[1oeaT`OmDF[_oE5Zk0_mBE;H2oeMC/P;oJEb`0omb
Gjd2ogeT[0?oR6^[0onCLJX3oiiiZ@?oYh2Y1?ngSJX2oknDZP;ob9f/00Co0000omZa[OoJ/Jgof[6]
0_oYa:l3ooCD[P07oo[SZ_ohkZ;ok?6Gom_^S_o8mj[oc_k5om;mg@02olobj@;ob>7[00?oa=WYokg<
iOnmc>D00_ooool00ol0003oooooooooo`0Uooooo`002Oooool01000003oooooooooooooool;01TI
6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`060;>c
/`03o`00003<c<`0c<c<00d0c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00C04a<
C0030000001VIVH0IVIV00D0IVIV00?o00000000000000005P1oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<4ooooo`0300000?oooooooooo
01cooooo0ol00008ooooo`04oiJMfOnFVmKoUY_FoiJKeP?oUiWD0_nHUm43oiVFc`;oVYG=00?oW9G<
oiZ@b?nLT<L00_nLT<L3oijAaP;oXI;500?oXi?5oj:@`OnTT/800onTT/83ojND`P03ojVF`onYU<3o
ZiO100?oZiO100?o[IW2ojjH`?n`V/800_n`V/83ok2La0Co/Ik400?o[Yk7ok2Oa_nZWLX00onZWLX2
oj6Ic@?oU9;?0_n3Qll3ofmic@03oe]Yb?m;F/7oBe[100;oE5Zk0_mBE;H3oeMC/P;oJEb`0_mbGjd2
ogeT[0?oR6^[0onCLJX3oiiiZ@;oYh2Y00?o[HFZokN=Z_ngSJX00_ngSJX01OnoU:[ob9f/olRM[?o8
WJco000000?of[6]00Goil6^onW4[oode:kom=B^oo[SZP02ooS^XP06om_^S_nYhhOo]o>YolKoc_o=
n^Koco;Y0_o8hN/01?o0dNOo_LcUokg<iOnmc>D2ooooo`03o`000?oooooooooo02Gooooo0009oooo
o`0400000?ooooooooooooooo`/06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@03
09VIV@03o`00002c/k<0/k>c00L0/k>c00?o00000<c<c03<c<`02`3<c<`00ol00000/k>c0;>c/`07
0;>c/`03o`00002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<01D0C4a<0P00000806IVIP@00000401oOgl2000000D0IVIV0P000006
04a<C0030000000c<c<0<c<c00@0<c<c00Go0000oooooooooooooooo0000000Looooo`;o00001ooo
ool01?nGXmkoUZ3KoiJPfonFX=/2oiJMf@?oUY_F0_nGVM@2oiRGd@;oVIK?00?oUY3<oiR@bOnHT<T0
0onJT<P2oib@a`?oWY7600?oXI;5oj2>`_nRT<400_nRT<43ojBB`P;oYiC200CoYi:oojVD`?nYU<3o
ZIC00_n[Ul401?n]U[ko[YS0ojjH`?n^V<03ok2J`P03ok2La?nbW<;o/Yc200;o/Ik400Co/ik3ok2O
a_n`WlKo/9o60onZWLX00onQVLgoXI_>oi6Cd@02oi6Cd@;oO8KB0omSMLl00om9H/WoFfW8od]J`@03
od5?^P;oDUBf0_mGDk801?mOE[3oJEb`og9O[OmbGjd3ogeT[0?oR6^[0onCLJX2oiiiZ@03ojN0ZOn]
QJ[o[HFZ00Co]hfZ1?o8WJ`00ol0003of[6]omZa[@02onO1[P;om=B^00Son^>ZooS^X_ohkZ;ofnj>
ojKHL_nYhhOoa_o>olgjiP;obNW/00Gob>7[ol3Aioo0dNOo`=7Wokg<i@02okW2h@;ooooo00?o0000
ooooooooool09?ooool000Wooooo00@00000oooooooooooooooo2`0I6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`03
07moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<01`2c/k<00ol00000c<c<0<c<c009
0<c<c003o`00002c/k<0/k>c00L0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`04
07moO`030000001VIVH0IVIV00D0IVIV00?o000004a<C01<C4`05`1<C4`00`000000IVIV06IVIP09
06IVIP<000001`1oOgl6000000H0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`05
03<c<`05o`000?ooooooooooooooo`0000006Oooool3o`0000Gooooo00CoVJ[RoiRWh?nHYn3oV:OP
0_nGXmh3oiJPf`;oUYgI0_nFVmH01?nGVMCoTY?AoiBAc_nDTLh4oiJ@c0;oV9390_nJT<P3oib@a`03
oijAa_nMSL;oX8k200;oX8k20onRT<400onTT/;oYHnnojNB_`03ojNB_`;oZIC000?oZiO1ojfF__n]
U[h00on^V<02ok2J`P05ok6J`?nbW<;o/Yc2ok:L`_naW/@00oncW/<3ok2OaP03ojZMb_n[Wl_oXI_>
00;oXI_>0onATm42ogb6dP;oHgG?0_m9H/T2od]J`@;o@Dnj00Co?dZfoe9D]_mGDk;oEe>b0_mOE[03
og9O[@;oOFB/0on8Jj/3oi=aZP03oiiiZOnROJ_o[HFZ00?o[HFZ0ongSJX3olRM[0;o000000cof[6]
onO1[_oW`Jkoil6^ooCC[_ode:kon^>ZooS^X_o/lIOo/=U]ojWSQoo4o]h2olWak@03olWYk?o3enWo
`mOY00;o`=7W0_nkaN800oni`^7o][_Mooooo`02ooooo`03o`000?oooooooooo02?ooooo0009oooo
o`0400000?ooooooooooooooo`/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@03
09VIV@03o`00002c/k<0/k>c00P0/k>c1?l000030<c<c0Co00002P2c/k<00ol00000VIVI09VIV@04
09VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00I
04a<C00300000?l00000000000/0IVIV00<00000o`00000000001000000906IVIP<000001@1<C4`2
00000003o`00000c<c<0<c<c00D0<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`0F
ooooo`;o00000oooool00onM/>GoVjgToi^]i003oiVZhP?oV:OP0_nGXmh01?nFX=_oTI_Joi6HeonA
V=L2oi6Ed`?oTY?A0_nDTLh3oiJ@c0;oV93900?oVY38oiR;a?nJS<<00_nJS<<3oif=`P?oX8k200?o
XY31oj:=__nUSkh00_nUSkh3ojNB_`03ojVD`?n[Tkgo[IJn00?o[IJn0_n^V<04ok6J`0;o/Yc21?nc
W/<2ok2OaP04ok:Qaon[Wl_oZio;oj^Ob`?oXI_>00?oTI?AohnEeOmeQmL00_meQmL2of=ec`03odUR
bOlcD<7o<e3100;o@Dnj0_loB[H3oeMC/P04oemF/?m[FjkoJe^^of]K[P;oOFB/0on8Jj/2oi=aZP04
oiEdZonROJ_oXWf[oj9mZ`?o[HFZ0_ngSJX01oo0UZco0000o`000?l0003oe:^^o`000?oJ/Jd00_oW
`Jh2ooCC[P06oo_UZ?oeki_ohNb8olKQM_nVf7;oa?kN0_o9lNd2olCLj`03ol?GjOnlan?o^lGR00;o
^lGR00Co]k_MokJkgOnf^mgo][_M0_ooool00ol0003oooooooooo`0Sooooo`002Oooool01@00003o
ooooooooooooool0000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<
C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00ol00000VIVI09VIV@0309VI
V@03o`00002c/k<0/k>c00/0/k>c0ol0000=0;>c/`03o`00002IVIT0VIVI00D0VIVI00<0000007mo
O`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<01`0C4a<00<0000006IV
IP1VIVH05@1VIVH3000000L0C4a<00<0000003<c<`0c<c<01`0c<c<00ol000006ATIooooo`03oooo
o`0300000?oooooooooo01Kooooo00Co0000ooooool0003oWk?V0onM/>D2oi^]i003oiVZh_nEY^7o
UJKQ00;oTj;O0_nAW]`3oi6KfP;oTISG0_nAUM<3oi:Cd@;oU97>00CoUY3<oi:;b?nERlKoUH_60onH
Rl@3oiZ<``;oWHg20_nPS/800onORkkoXXfnoj:=_P03ojF?_P?oYi:o0on[Tkd3ojfF_P03ojjH`?n`
V;ko/9Rn00?o/I[000?o/Yc2okBM`OndWL400oncW/<4ok:Qa`;oZio;0onQW]43ohnEe@;oMHOG0_mD
L]@2odURb@;o<e310_m1CkX01?loB[KoAT^bodI;/_mGDk82oemF/0;oJe^^0_miHjd3ohM[[0?oUGB[
0onROJ/3ojf5ZP?o000000?o`9J/olRM[?oDZjh00_oDZjh00ol0003oil6^onO1[P02ooCC[P07oo_U
Z?oeki_ohNb8ok3IKOndnm;oaOO]olWak@02olCLj`05okk9honlan?o_<OSokc7honkaN800ong^md0
0onf^mgo];KJooooo`02ooooo`03o`000?oooooooooo02;ooooo0009ooooo`0500000?oooooooooo
ooooo`0000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00?o0000
0;>c/`2c/k<06@2c/k<00ol00000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<00000
06IVIP1VIVH0101VIVH00`000000C4a<04a<C00N04a<C0<000004`1VIVH00`000000C4a<04a<C007
04a<C0030000000c<c<0<c<c00H0<c<c0_l0000201TI6@Cooooo00<00000ooooooooool05_ooool0
0ol0003oXKGWoj6ei`02oinciP03oif`iOnI[NGoVJgU00;oUj[S0onEY^42oi>Rg`;oTIkL0_nAVmX2
oi6He`03oi6Edon<Sm7oSHg>00;oSHg>0_n@S</2oi:;b0?oUH_60_nHRl@3oiZ<``03oif=`_nLRKoo
Wh^n00;oWh^n0onRSKh3ojF?_P03ojNB_onXT;coZi>m00?oZi>m00?o[IJnojnE_On`V;h00on`V;h0
0onaV/3o]9^nokBM`@03okBM`@03ok>N`oneX<?o]J3300?o/Z7700?oZio;ojfRc?n]X/`00onQW]42
ohnEe@?oMHOG00?oE7;Doc9JbolbF//00_lcD<401?lWA;[o@Dnjocm:]_loB[H2odI;/P;oGeJ`0_m[
Fjh2ogUS[@?oQf^/0onEM:/3oj9mZ`?o00001?o0UZ`03_o8WJcoe:^^omB[[_oDZjkohkf`o`000?oW
`Jkom=>^oo_UZ?oeki_ohNb8olKQM_ndnm;oaOO]0_o4h>d01Oo4g>_o_/WSokk9honnbN?o_<OS00;o
^;cL0_ng^md01?ne]MWo];KJokBff_nd]]X2ooooo`03o`000?oooooooooo02;ooooo0009ooooo`05
00000?ooooooooooooooo`0000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI
00@0VIVI00?o00000;>c/`2c/k<05P2c/k<2o`0000L0VIVI00?o000007moO`1oOgl0101oOgl00ol0
0000IVIV06IVIP0506IVIP030000001<C4`0C4a<00/0C4a<0P0000001?l00000000000000?l00002
000000h0C4a<0P0000000ol00000000000000002000000H0IVIV0`0000000ol00000000000000008
04a<C0800000200c<c<00ol000006ATI01TI6@0201TI6@Cooooo00<00000ooooooooool05_ooool0
1?l0003oXKGWoijcionN/nL2oib`iP?oVJgU0_nGZ^<01?nEY^7oSj;QohfMg_n=WMh3ohbIf`;oRiGH
0_n;T]@2ohb?d@?oSHg>0_n@S</2oi:;b0;oUH_60onHRl@00onJS<?oVHS0oib9_`02oib9_`?oWh^n
0_nRSKh2ojF?_P04ojF>_?nXT;coZ92lojR@_0;oZi>m00Co[9:kojnE_On_UKgo[iFm0_n`V;h01?nc
VKgo]9^nokBK__ndVkh2okBM`@03okNO`?neX<?o]J3300;o]J3300?o/Z77okBTaon]X/`00on]X/`0
0onQW]7oXj?EohjJf`02ohjJf`;oKX[M0_m4LMT01OlbF/_o5DC1oaE4`OlcD<7o9dBj00;o?dZf0_m6
Bk82oe9@/@;oJe^^0omiHjd3ohM[[0;oUGB[0ol000001?nROJ_o[HFZojf5Z_neSZd3ol2F[0?oe:^^
0ooS_K002Ol0003om=>^oo_UZ?oeki_ohNb8o`000?nmnNco`n?_olCPk@02okk;i0;o_/WS00Co^KcL
okRlg?nh_=co^;cL1?ne]MT00ond]][o];?Gooooo`02ooooo`03o`000?oooooooooo027ooooo0009
ooooo`0500000?ooooooooooooooo`0000002`0I6AT00`000000<c<c03<c<`0503<c<`03o`00001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI00D0VIVI00?o00000;>c/`2c/k<0502c/k<00ol00000VIVI09VIV@0709VIV@030000001o
Ogl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00:04a<C0800000200c
<c<300000180C4a<1P00000=04a<C0030000000c<c<0<c<c00L0<c<c00?o000001TI6@0I6AT00`0I
6AT4ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00onN/nL2oib`iP04oiV]iOnE
Z^GoTZKSoi:Vh`?oSj;Q0_n=WMh3ohbIf`;oRiGH0_n;T]@2ohb?d@;oSHg>0_n@S</2oi:;b003oiF;
a_nBQ/?oUHO200;oUHO20_nIR<03oib9_`?oWh^n00?oXXfnoj:;_?nUS[`00onUS[`2ojR@_003oj^C
_On/T[_o[9:k00?o[iFm00?o/9Rnok>I_OncVKd00ondVkh01?ndWL7o]io0okNO`?ngWl02okFP``04
okRSa?ndY<Oo]:C7okBTa`;o[J;<00Co/:O?oj>SeOnSXmGoXj?E0on>V]/2ofj:g@03odAafOlFDlgo
5U?=00;o5DC100?o9dBjobDo]_lU?kH00_m6Bk83oe9@/@;oJe^^0_miHjd2ohM[[0?o000000GoUGB[
oj9mZonROJ_oXWf[ojf5ZP02okF>[@?o`9J/00?oc:B`omB[[_oDZjh00ooS_K001ol0003om=>^oo_U
Z?oeki_oZ<iMokgik?o3hnl01?nnbn@01Onj^m_o^KcLokVlg?ni_=co^;cL00;o][CG0_ne]MT01?ne
/MGo];?GokBceond/mL3ooooo`03o`000?oooooooooo023ooooo0009ooooo`0500000?oooooooooo
ooooo`0000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI0_l0000C
0;>c/`03o`00002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00O
04a<C0<000002@0c<c<00ol000006ATI01TI6@0401TI6@Cooooo00<00000ooooooooool05Oooool0
1_l0003oooooooooooooooooW[?Woi^ai`?oV:kV0_nEZ^D2oi:Vh`;oSj;Q0on=WMh01?n<VM_oQI?J
ohB?e_n4SmH2ohB<d`;oQXW?0_n8Ql`2oh^6b0;oSXK60onBQ/<3oiF7`P;oVHS00onLRKl01?nORkko
WhVloj:;_?nRRk`4ojF>_003ojR@_?nYT;_o[9:k00?o[9:k0_n_UKd4ok>I_@;o]9^n1?ngWl001?ne
X<?o^:?4okRSa?nhXl@2okBTa`Co/:O?0_nSXmD2ohjJf`03ohjQhOmXT>GoJ93U00;oA77I0_lFDld0
0olEA<7o9dBjobDo]P02obDo]P07odI;/_mBD;7oDU2aoe9@/OmRF;7oJe^^ogUS[@03o`000004ohM[
[?nEM:_oUGB[oiEdZ`;oXWf[00CoZ8B^okF>[OneSZgo]Hj]0_o0UZ`3olbT/00:omB[[_oS_K3ohkf`
on>m/?obdk7o0000ooG_Voo>i7Wo_nGaokg;i@Co_/_T0onj^m/00oni_=co]k?EokJde`02okJde`Co
]K7E00?o];?GokFaeOooool00_ooool00ol0003oooooooooo`0Pooooo`002Oooool01000003ooooo
ooooooooool2000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C003
0000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@;o
0000402c/k<00ol00000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH01@1VIVH00`000000C4a<04a<C00804a<C003o`0000000000<c<c00h0<c<c0`00000L04a<C003
o`0000000000<c<c00X0<c<c00?o000001TI6@0I6AT01@0I6AT4ooooo`0300000?oooooooooo01Go
oooo00?o0000ooooooooool00_ooool2oi^ai`03oiR^i_nD[>KoU:cV00;oT:OU0_n<X^<2ohVMh@;o
QYSM0on5TmX2ohB?eP;oQ8cC0_n6RLl2ohR7c0;oRhK80_n>Q/H2oi:6``?oUHO20_nIR<02oib9_`03
oi^7_OnORKcoWhVl00?oXX^l0_nUS[`01?nVSK[oZI2kojV@^onYT;/3ojbB^`03ojnE_OnaU[_o/IJk
00?o/iVm00?o]9^nokNM__ngWKh00ongWl04okRSa003okBTaonhZ<Wo^:S900?o/:O?00?oXj?EojJZ
fOnVZ]T00on>XN42ofR@i@;o<G;O00Co5U?=o`0f_?lEA<7o9dBj0_lU?kH2odI;/P;oDU2a0ol00002
ogUS[@?oQf^/0_nEM:/00onROJ_oZ8B^ojR4[P04okF>[@04ol2F[?o<Y;3oc:B`olbT/0?ohkf`0_ob
dk400oojj:_o0000ojS>G@03okg;i@03okk;i?ni^][o^K[J00;o^[_K00Go]k7CokNceOng/mGo]k?E
okJde`02okJ`d`;o]K7E00Co]ZoCokFaeOne/MGo]K7E0oooool00ol0003oooooooooo`0Oooooo`00
2Oooool01000003oooooooooooooool2000000/06ATI00<00000o`00000c<c<01P0c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV00@0IVIV00?o000007moO`1oOgl0101oOgl00ol00000
000009VIV@0709VIV@?o00002@2c/k<4o`0000T0VIVI00?o000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0506IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<04@0c<c<01000003o
000000000000000D04a<C0@00000300c<c<00ol000006ATI01TI6@0601TI6@Cooooo00<00000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`;oV:oW0onD[>H2oi2Wi@;oS:;S0_n9WN42ohJH
g@;oQI?J0_n4SmH2ohB<d`;oQXW?0_n8Ql`2oh^6b0?oSXK60_nBQ/<01?nEQl;oTh>ooiN5__nGQKh3
oi^7_@?oWhVl0_nRRk`00onUS[coYXfjojJ=^P03ojV@^`?o[9:k0onaU[/3ok>I_@Co]ifn00?o]io0
okZR`OnjX/400onhXl@4okRXb@03ok2Wcond[M;oYZ[I00?oYZ[I00?oSZ7Qoi2/jOmSV^h00_mSV^h0
1OlaL]oo04_:oaICcOl0=[co0cFh00;o9Cnf00Co;T6do`000?l0003o00000_mRF;43ogES/@?oQf^/
00?oUGB[oiUj/?nXQ:h00onXQ:h3okF>[@Coc:B`00Cog;Rdon>m/?obdk7ol]>a0_ojj:/01Oo>i7Wo
0000okg;iOnmbnGo^;SH00?o^K[J1?ng/M<00ong/mGo]Zk@okJ`d`02okJ`d`06okN]d?nf[m?o]ZoC
okJ_done/MGo][7D1?ooool00ol0003oooooooooo`0Nooooo`002Oooool01000003ooooooooooooo
ool2000000`06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0809VIV@Wo00002`2I
VIT2000000L0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00804a<C0030000000c
<c<0<c<c01H0<c<c0`00000=04a<C0@000003P0c<c<2o`0000T06ATI1?ooool00`00003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo0_nH[nL01?nD[>KoSjWWohZTiOn:Y>D2ohJNh`;oPISQ
0_mnTmd2ogb=f@;oO8WE0_mmQM42ogn3c@;oPX;:0_n6PLH3ohZ1a0;oSh;10_nCPkl3oiN5_P?oVhNm
0_nORK`00onRRkcoXhZjojJ=^P03ojJ=^P?oZI2k00?o[9:kojjC^_naU[/00onaU[/00oncVKgo]YZl
okJJ_002okNM_P03okZP__njX/7o^Z;100;o^Z;100?o^:?4okbWaOnlYlD00_nhZ<T01?nl[/_o]:gB
okB]d_nd[M82ojJZf@04ojZcg_n@[>WoT:cYoi2/j@?oHi[^00Go7gKSo`1;b_l0=[co02:^o`0_/`02
o`000004obi1]?mBD;7oDU2aoe9@/@;oHURa0_meHk43ohM_/0?oVGZ`0onXQ:h2okF>[@04ol6L/_o<
Y;3oc:B`olbT/0;og;Rd00Oohkf`oo;C/Oojj:_on^R[ono`Uoo>i7Wo000000Co^;SH00?o^K[JokN_
dOng[m400_ng/M<01OnfZlgo]Zk@okJ^d?nf[]3o][3C00?o]jg@00?o]ZoCokN_dOnf/M@00_nf/M@3
ooooo`03o`000?oooooooooo01kooooo0009ooooo`0400000?ooooooooooooooo`<00000300I6AT0
0`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH0
0`000000Ogmo07moO`0507moO`030000002IVIT0VIVI01X0VIVI00<0000007moO`1oOgl01P1oOgl0
0ol00000IVIV06IVIP0506IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<06P0c<c<=
00000140<c<c00?o000001TI6@0I6AT02@0I6AT4ooooo`0300000?oooooooooo01Gooooo00?o0000
ooooooooool01?ooool3oiB]j0;oSjWW0_n:Y>D2ohJNh`;oPISQ0_mnTmd2ogb=f@;oO8WE0_mmQM42
ogn3c@;oPX;:0_n6PLH2ohZ1a0;oSh;10onCPkl2oiN5_P?oVhNm00?oWhVloin8^_nSR[X00_nSR[X3
ojJ=^P;oZI2k00CoZi2jojjC^_n^Tk[o[Y>j0_naU[/01OncV;_o]YZlokJJ_?nfV[co]ifn00?o^Z2n
0_njX/401OnnY/7o_:O5okbWaOnlYlGo^:S900?o_:k;00?o]:gBokVeeOni]MD00onZ/mh00on@[>Wo
UKS`oiFhl002of:WmP;o4GgT0ol00002o`0_/`04obi1]?loB[Go?dZeoe9@/@;oHURa0_meHk43ohM_
/0?oVGZ`0onXQ:h01OneSZgo`Ibbol6L/_o1W;;oc:B`00?og;Rd00GokM:hoo;C/Oojj:_on^R[ono`
U`02okNde`04o`000?nh^=So^;SHokJ/c`?o]joA1?nfZld00onf[]3o]j_<okN]d002okN]d006okR]
cOng[m7o]joAokN_dOnf/MCo^;;C1?ooool00ol0003oooooooooo`0Mooooo`002Oooool01000003o
ooooooooooooool3000000`06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<
C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00ol00000000009VIV@0G09VI
V@800000201oOgl00`000000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00P0C4a<00?o000003<c
<`0c<c<0=`0c<c<2o`0000`06ATI1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo
00Kooooo00?oU:gXohn[jOn?ZnT00_n9Y^P2ohBPiP;oOI[T0_mhTn400omdSMgoLXOIog:7f@02ogb9
e@;oOHGA0omoPld00on2P/[oQX76ohJ1aP03ohZ1a0;oSh;10_nCPkl3oiN5_P04oi^7_OnKQK_oWhRj
oin8^P?oXhZj0onVSKX4oj^@^P;o[Y>j00Co/IJkok>H^oncV;_o/iRk0_nfV[`4okZP_P04okZR`Onn
Y/7o_ZK1okjV`@;o_:O500Co`Jg6okb^bonl[/_o_:k;1?ni]MD00onZ/mko/;gTok2mi003oiFhl0?o
00000_lAON@01Ol09Jko02:^o`0_/ol9=;Go;T6d00;o?dZe0_mRF;43ogES/@?oQfn`0_nIN[03ojR4
[PCo`Ibb00Goc:B`ombh]?oL^;Cog;RdongB^002ooO//P06oo[XZoncf6[o];7EokNdeondZ<co0000
0onf[<l00ong[m7o]ZO:okJWbP02okJ[c@05okNWbOngZlco]j_<okN[c?ng[M000onh[Ld2okN_d@?o
^;;C1?ooool00ol0003oooooooooo`0Looooo`002Oooool01000003oooooooooooooool3000000`0
6ATI00<0000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0
IVIV00<0000007moO`1oOgl01P1oOgl2000001@0VIVI0P00000:07moO`030000001VIVH0IVIV00D0
IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0g03<c<`03o`00000I6AT06ATI00`0
6ATI1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0_n?ZnT2ohVVj0;o
Q:3V0_mmV^@2ogRCh@04ogB=gOmbQmWoLXOIog:3e0;oM7o@0omgOL`2og]lb0;oQX760_n:PL@2ohn2
`@03oi>3_onAPKkoUX>l00;oUX>l0_nKQK/3oin8^P?oXhZj00?oYXfjojR=^On[T;X00on[T;X00on^
Tk[o/IFjok>H^`03ok>H^`03okJJ_?niWKco^Ifl00?o^Z2n1?nnY/401OnlYlGo`Jg6ol6]a_o1[LKo
_:k;00;o`KC>0_ni]MD2oknnf@03ok2mi?ngbNSo000000;o000000?oVlKfofJgo?m_a_l00_m_a_l0
0olEVN;o00ZDo`0_/`02o`Td]@;o?dZe0omFEkL2ogES/@?oQfn`0onIN[000onXQ:ko/Y6eok:A]@03
ol6L/P03om6a^_oL^;Cog;Rd00;okM:h0_ogk;800ooUlYOo];7EokBae@03okBXc003o`000?nf[<oo
]JC700?o]ZO:00Ko]Z_=okNWbOngYlWo]jO9okN[c?niZLT4okR]c@04okN_dOnj/=3o^[3@okRbd`;o
^kCC0oooool00ol0003oooooooooo`0Looooo`002Oooool01000003oooooooooooooool3000000d0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0
IVIV00<0000007moO`1oOgl01`1oOgl200000100VIVI0P00000;07moO`030000001VIVH0IVIV00H0
IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0f03<c<`03o`00000I6AT06ATI00d0
6ATI1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0_n;ZNX2oh>Tj@;o
O9gW0_mdU^@2ofj>h@;oJHOM0_mbQmT00ombPmCoM7o@ogAod002ogMmc0;oNgc80_n1O<D2ohIm`P;o
S7o00onAPKh2oiJ3_0?oVhFk0_nOR;X2oj>:^P04ojB:^OnXSKWoZ8fiojR=^@;oZi2j00Co[Y:iok6E
^_naUK[o/IFj0oncV;/4okVM_003okZP__nnY;oo_ZBo00;o_ZK100Go`Z_3ol6]a_o1[LKo`Jg6olFc
b003ol6dcP03olNmdOno_]Wo_kkI00?o000000Co]lWXokgCjonmdn_oXm?h0on/gOP01Omne?ooSmon
ohoOo_l02YCo02nc00;o2CBe00Co?dZeoeIG]omFEkOoEUNg0_m_IkT3ohM_/0;oVGZ`00CoWhFhok:A
]OnbTKGo/Y6e0oo1W;82om6a^P03ombh]?o]d[Somnbb00;omnbb00Co/JgCokBaeOnbY<[o/ZC:0_nd
Z<`01_l0003o]JC7okFTaoneY<Oo]ZO:okNTa@?o]jO900Co^JK6okVYbOniZLWo^JW90_nh[Ld01?nk
[Lco^[3@okZ`d?nj/=03ok^dd`Cooooo00?o0000ooooooooool06oooool000Wooooo00@00000oooo
oooooooooooo1000000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`0
0`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00P0Ogmo0P00000<09VIV@03o`0000000000
Ogmo00X0Ogmo0P00000806IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0=P0c<c<0
0ol000006ATI01TI6@0>01TI6@Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`09
ooooo`;oRjWZ0_n3Y>T2ogbMi`;oM9KT0_m^S^400omYQmgoIX7IofJ1f@02ofIle0;oM7o@0_mgOL`2
og]lb0;oPGc50_n6OL82ohao`0;oTH6n0onFPk`2oi^5^`03oin8^_nOQk[oY8Zi00;oY8Zi0onXSKT0
0on[T;[o[Y:iojjB^@04ok6E^P03ok>H^ongV[_o]iZk00;o^Ifl00Go_J6mokjT_onnY;oo_ZBookjV
`@03ol:[``06ol6]a_o5/lSoaK?8olFcb?o1]<koakgA0ol00002olG7g005okO9j?nmdn_o_M?[okgC
joo3g>`00_n/gOP2okCTm`04ohoOo_nPi?co[^Cio`00QP;o2CBe00Co7d:kocm:]OmFEkOoEUNg0_m_
IkT3ohQg^@?oWhFh1?nbTKD01?o1W;;odK6jom6a^_oA/KX2ongB^0;omnbb00?o/JgCojnPb?nbY<X0
0_nbY<X01?ndZ<co/j35ok>PaOl00002okFTa`?o]jC500Co]jO9okVVa_niY/Ko^JK60_niZLT4ok^]
c004okZ`d?nm//oo_K;?ok^dd`;o_[OC1?ooool00ol0003oooooooooo`0Jooooo`002Oooool01000
003oooooooooooooool300000003o`00000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00?o00000000001oOgl02@1oOgl0
0`00003o000000000009000000/0Ogmo0P00000806IVIP8000002P1<C4`00`000000<c<c03<c<`0d
03<c<`;o00004@0I6AT4ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool2
ohFWj`;oO:7Z0_mbVNP2ofVAi@03of68h_mYQmgoJHOM00;oIX7I00?oIWcDofUid?mYNM000_m]Ml`2
og]lb0;oPGc50_n6OL82ohao`0?oTH6n0_nFPk`00onKQK_oVhBjoin7^P02oin7^P?oY8Zi0_nXSKT4
ojjB^@;o/IFj00Go]9NjokNJ^ongV[_o]iZkokVM_003okfQ_@;o_ZBo1?o2Zl<00oo7/LCoaK?8olFc
b003o`000004olNmdOo=aM?ocLGColG7g0?obm7O00?o_M?[ol?Lk?o3g>`00_o8h^/01?ndi?Oo^nKd
ok_Vm?o0iO42ojkTn@04o`00Q_l9=;Go7d:koam2^`?oEUNg0_m_IkT2ohQg^@CoWhFh0onbTKD4om6a
^P04onG@`_o]d[Somnbbo`0000?o[j3800?o/ZC:ok6L`_ncX<D00oncX<D00ol0003o]Z32okJP`P02
okNTa@Co^JK600?o^JW9okbZb?nlZ/P00_nk[L`01?nn[l_o_K;?okfbconm//l3okjgd`Cooooo00?o
0000ooooooooool06_ooool000Wooooo00@00000oooooooooooooooo1000000=01TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo01`0Ogmo0P00000906IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<0<P0c
<c<2o`0001<06ATI1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo0_n5
Yn/2ogbQjP;oLYWX0_mYTND01?mQR>;oFh3MoeQifOmHNMT2ofIle0;oJGW@00?oKGO<og=gb?mcMlP0
0_mjN<D2oh5j`P;oR7bo0on?Okd2oiF2_0;oVhBj0onOQkX3ojB:^@03ojR=^OnZSkWoZXni00?o[Y:i
00?o/IFjokBG^_ndUkX00ongV[/4okfQ_@03okjT_oo3ZL3o`jW000?o`Z_30ol00002ol^kb`04olNm
dOo=aM?ocLGColg5d`?obm7O0_o@fN000oo3g>cob>;[olSRj`02ol_VjP03ok_Vm?o0iO7o`n7^00;o
`n7^00Co]]kdo`00Q_l9=;Go7d:k0_m0El800omFEkOoKfNiofmW^@03ohQg^@?oWhFh0_nbTKD2ol6W
`0;odK6j0_oUd<800ooal/3od_:IojfLaP02ojnPb004ojnH`?naW<;o/Ic2ok6L`P;o/j3500Go]9bo
o`000?nfX<;o]Z32okNTa@02okVR`P?o^JK60onlZ/P4okj_b`04okfbcoo0]Loo`;G?okjgd`;o`K[D
1?ooool00ol0003oooooooooo`0Iooooo`002Oooool01000003oooooooooooooool4000000h06ATI
00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00H0IVIV
0P00000K07moO`030000001VIVH0IVIV00T0IVIV00<0000004a<C01<C4`02@1<C4`00`000000<c<c
03<c<`0c03<c<`03o`00000I6AT06ATI01806ATI1?ooool00`00003oooooooooo`0Cooooo`03o`00
0?oooooooooo00gooooo0_moY^`00omdW^_oJ9GYofREj@02oef<iP;oDX;R00CoFh3MoeQifOmHNMWo
F7CD0_mYNM02ofegc003og=gb?mjN<GoNWS500?oPG[20_n8O;l2ohmo_@;oUH:l0onKQ;X3oin7^P03
ojB:^OnURkWoZXni00;oZXni0on^T[T4okBG^P;o]iZk00Co^ijlokfQ_OnmXKgo_J6m0oo3ZL03o`00
00;oak740oo;^l/01_oA`lgocLGColg5doo=aM?od/kFol_Ag`?od=WP00Codn3QolSRjoo;i^[obnKZ
0_o=i^T00oo=hnSo`n7^ol?QkP02ol;HjP04okWDk_l07jco7d:koam2^`;o@5O20_m_IkT3ohQg^@?o
WhFh00Go/Y6eol6W`?o1Yl3o`JO0om6a^P03onG@`P04oo7b`?n]W<Ko[Ic6ojnPb0?o[iS00_naW<80
1_ncX<Go]9bookBL_ondW;oo0000okJP`PCo^J;200Co^JK6okbWa?nlYlCo_:[80_no[<L2okj_b`04
ol:cboo0]Loo`;G?ol2ec`?o`K[D1?ooool00ol0003oooooooooo`0Iooooo`002Oooool01000003o
ooooooooooooool5000000h06ATI00<0000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00604a<
C0030000001VIVH0IVIV00L0IVIV00<00000o`00000000005@1oOgl3000000X0IVIV0P00000;04a<
C0030000000c<c<0<c<c03<0<c<c00?o000001TI6@0I6AT04`0I6AT4ooooo`0300000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool2ogVTkP03ofbLkOmXUNWoJ9GY00;oGHcV00?oDX;RodYi
gOm:NMd00_mHNMT01?mHM=CoG7;@of9ac?mRLL`2og=gb0;oNWS50_n1N/82ohQl_`?oSgnm0_nEP[`2
oi^4^P;oWhNj00CoX8RjojF;^OnURkWoYH^i0onZSkT00on^T[Wo/IBjok6D^P03okBG^P03okNJ^onk
W[co^ijl00?o_J6m00Co`JJno`000?l0003ob:o20oo7/L@2olfia`05ol^kbooA`lgodL?=om73cOo=
aM<00_oBc]H2omOGf004om3Ih?oCh>7odn3QomGUhP;oe^OR00CocNKYolgSj?o=hnSobmgW0_o2f>X2
oko=i@03okO7i_l0<k[o03>j00;o@5O20omVKlL2ohQg^@;oWhFh00?oZIW5ol6W`?o1Yl000_o1Yl03
onG@`P04oo7b`?oBlYWo[Ic6ojbD_PCo[iS000?o/Ic2ok:H_?ndW;l00ondW;l00onfX<;o0000okRN
_P02okVR`P04okbS_onlYlCo_:O4okbWa0?o_jc700Go_Zo;ol:cboo2/l_o`[?;ol2ec`02olBid003
ol6je?o4_mGoa;oE00Cooooo00?o0000ooooooooool06?ooool000Wooooo00@00000oooooooooooo
oooo1@00000>01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01P1<C4`00ol00000
000006IVIP0906IVIP800000401oOgl3000000`0IVIV00<0000004a<C01<C4`02`1<C4`00`000000
<c<c03<c<`0c03<c<`03o`00000I6AT06ATI01<06ATI1?ooool00`00003oooooooooo`0Cooooo`03
o`000?oooooooooo00oooooo0_miY>h2ofbLk@05oefBj_m>Q^KoCXKVod5kh_m:NMd00_m6LMT2odI/
e004oeabd?mRLLcoJW;9ofYbb@;oNWS50on1N/82ohQl_`;oSgnm0_nEP[`00onKQ;[oVhFkoj28^P02
oj28^P?oYH^i0_nZSkT01?n/TK[o/IBjok6D^_naU;X3okBG^PCo^ijl0ol000001Oo3ZL3ob:o2olR_
`_o8[l;oak7400?ocKW70ooA`ld2omK<d003om;>e_oGemSoemOH00;of]oJ00Codn3QomGUh_oFin;o
e^OR0_oEi^<00oo=hnSobmgWol_Mi`02olKDi@04oko=iOnh`=oo/[SNok:hgP;o03>j00Co@5O2ofI_
aomVKlOoIVo70_n;Q/P4ojVIa@;o`JO00_oEbll01?oUd<;olO;0oo7b`?nYTKd3ojbD_P?o[iS00onb
V;`3okBL_`;o^9jn00?o0000okVR`_nlXkl00_nlXkl00onlYlCo`:W2ol2Y`P02okn/a`?o`[?;00Ko
a[O<olBid?o4^M3oa;W@olNndOo4_mD2olO4f0Cooooo00?o0000ooooooooool05oooool000Wooooo
00@00000oooooooooooooooo1@00000?01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<
C4`01`1<C4`00`000000IVIV06IVIP0906IVIPH000001P1oOgl4000000h0IVIV00<0000004a<C01<
C4`02`1<C4`00`000000<c<c03<c<`0d03<c<`03o`00000I6AT06ATI01<06ATI1?ooool00`00003o
ooooooooo`0Cooooo`03o`000?oooooooooo00oooooo0_mcXnl2of>JkP;oDHk[0_m>Q^H2ocI`g0;o
AW7I00GoAVcDod]Zd?m;J]3oHW7<ofYbb@02og=daP?oO7O30_n4N/02ohen_P;oU86l0onKQK/3oj28
^P;oYH^i0on/TKX4ok6D^P03okBG^_nhVk_o^9^k00?o00000oo1Y[h4olR_`P06olfga?o=^LOocKW7
olfiaooC`/WodL?=0ooFc=000ooKe];oemOHom[OfP02om[OfP03omcUfooLj=goe^OR00?oeNKS00Go
d^?Tol_Mioo6e>Goa]CUoko9hP03okS0g`05ok:hg_n/Z]Go[:[EoaEDc_m0El800_mVKlL3oh^6b0?o
ZIW500Co`JO0omG;cooEblooeL_?0_oSmmD3ojVA_@?o[9Bn00?o[iS0ojnD^_nbV;`00onbV;`01Ond
W;oo]YZkokJJ^onhW[ko000000Co_:>o0oo0ZL801?no[<Ooa;36olB`a_o2/l/3olJgc003olBid?o7
_]7oakkA00?oalCH1?ooool00ol0003oooooooooo`0Gooooo`002Oooool01000003ooooooooooooo
ool6000000h06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00704a<C0030000001V
IVH0IVIV00h0IVIV1P00000A06IVIP030000001<C4`0C4a<00`0C4a<00<0000003<c<`0c<c<0<`0c
<c<00ol000006ATI01TI6@0D01TI6@Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0@ooooo`;oLj?_0_mSV^h2oe6>j`03ocj1i_l]Ln3o=W3L00;o<6SG0_m6K=@01?m;J]3oDf_=oe=[
cOmZL/T2og=daP;oO7O30_n4N/02ohen_P;oU86l0onKQK/3oj28^P03ojF;^OnWS[[oYhjj00?o[96j
0_naU;X01OndV;_o0000o`000?l0003o^ijl00?o_jBm0_o1Y[h01?o7[L3ob:o2olR_`_o8[l82olfg
a003olfiaooC`/Wodl;900;of<_<00?oe/c@om_Fd_oKe]800_oNg]D01?oJgm[og>GKomcXgOoLj=d2
om_ZgP05omGVhooBhnCocMgTolgMi?o6e>D00onobN800onh`=oo/;7IojbZe@03ojbZe@04oaEDc_mV
KlOoIVo7ofI_a`?oRhK800?oZIW5okVngOni_]d00ooEbll00ooSmmGoYXjlojVA_@02ojVA_@;o[9Bn
00Co[92iojnD^_n_U;[o[iBj0_nbV;`01ondU[Wo]YZkokJJ^onfV[_o^9jnok^O_?l000000_nlXkl2
ol2U_P;o`:W20oo4/<H01_o9]LOoa[O<olJgc?o6]lcobkg=olNnd@;oblCD00?oalCHolW9f_o9bMX0
1?ooool00ol0003oooooooooo`0Fooooo`002Oooool01000003oooooooooooooool6000000l06ATI
00?o000003<c<`0c<c<0200c<c<00ol00000C4a<04a<C00704a<C003o`000000000000000280IVIV
0P00000>04a<C0030000000c<c<0<c<c03@0<c<c00?o000001TI6@0I6AT0500I6AT4ooooo`030000
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2ofjRl@07oe^Hkom5RncoAH_/obikiOl]
Ln3o7VKJoc1Xe`02oc1Sd`;oBf[@00CoDf_=oei]b_mNKL[oLgC60omlMl<2ohAj`0;oSGjn0_nDPK`3
oi^5^`03oj28^_nRR[_oYhjj00;oYhjj0on/TKX3o`000003okBH^onhVk_o^9^k00Co_jBm00Go`JJn
olN]`?o7[L3oajg0olR_`P03olfga0?odl;90_oHbl`01?oMe<oofmKBomkNeOoNg]D2on3Ue`04on7[
fOoLj=gofn[Nom_ZgP;of>WQ00?odnGTolgMi?o6dn@00_o6dn@00onobN;o][_Mok2af@02ok2af@;o
[:[E00?oY9c>oj:Hb_l0@;H00_m@On02oh^6b003ohbUiOni_]go^KkM00;o^KkM00?oeL_?on?geOnV
S[`00_nVS[`2ojVA_@Co[92i0_n_U;X01?nbV;co]9JiokBF^OndU[T2okJJ^`?o^inl00Go0000ol2U
__o0YKko`:Fnol2Y`P02olF]`P05olB`a_o9]LOobKG7olVeaoo6]l`00_o;_Ld3ol_4e004olk;eoo9
bM[obloMol_?g@Cooooo00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo
1P00000@01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`02@1<C4`2000001h0IVIV
0P00000@04a<C0030000000c<c<0<c<c03@0<c<c00?o000001TI6@0I6AT0500I6AT4ooooo`030000
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool2ofVRlP;oDiO`0_m5Rn`2oaMZg@03oaiV
f_lFG=Co<6?C00;o=V7@0_mCJld00omNKL[oJG77ofUaa`02ogag``;oQ7[00_n=O[h2oiB1_0;oVhFk
00?oVhJloj::^onRR[/00onWS[X3o`0000Co]9Rk00?o^9^kokbQ_OnlXKd00onoY;d3olN]`004olbe
`oo=]lCocKO4olfga0;odl3700?odl;9omS;c?oHbl`00_oMe<l01?oQg];og]kEon3UeooPiML2on7[
f@04omo^fooKj]kof>WQomSYh@;odnGT00Coc=kVolKCi?o6dnCo_LKR0onf^md00on`/MWoYj?BojNS
dP03ojBLcP;oXYS:00?oD7oPohbUiOn<YND00_n<YND2okVng@03ol3dl?m]di_oXhbl00?oYXjl00?o
ZI6mojV=^?nYSKP00on/T;T00on_U;[o/I:gokBF^@03okBF^@03okJJ^oniVkWo^I^i00;o^inl00Co
_j6ko`000?o0YKko`:Fn0oo5[L83olVea`06oljlb?o;_Lgobkg=ol^mcOo?a<ooblCD0_o>bmL3ol_?
g@05olcEhOooooooooooooooool000005oooool000Wooooo00@00000oooooooooooooooo1`00000@
01TI6@030000000c<c<0<c<c00P0<c<c0P00000;04a<C0030000001VIVH0IVIV01T0IVIV0P00000A
04a<C0030000000c<c<0<c<c03H0<c<c00?o000001TI6@0I6AT04`0I6AT4ooooo`0300000?oooooo
oooo01;ooooo00?o0000ooooooooool05?ooool2ofVRlP;oDiO`00?o>XS[oaeeholGJ]d00_l4Fm@0
0olDEm3o<6?CocIQd002od1ScP;oGVg:00?oJG77ogEeaOmeMLD00_n0NL82ohYn`0;oTh:n0onKQ[`2
oj::^`?o000000CoZY6lojnE^on_UK_o[iFk0_ndV;/00onhWKgo_:6mokbQ_@02okbQ_@04oknT_Oo4
Z[ooa:ZoolN]`0?oc;G300?ocKO4om?0aooC`<L00_oIbLX01ooHblcogMC?omgDcooMe<oohMkBon?W
e?oPiML00_oQjmT2omo^f`04omc_g_oGk^;oenkRom?Ui0;oc=kV1?nma^800onf^mgo[:gHojNSdP03
ojNSdP;oY9c>00CoXYS:oib=`onMRl3o3XST0_n<YND2ogGBoP03ol3dl?nPRkgoXhbl00;oXhbl00?o
YXjlojF9]onYSKP00_nYSKP3ojb@^@?o/I:g0_ndU[T01OngUkKo^I^iokVK^OniVkWo^inl00;o_j6k
00Go0000ol2U__o5ZKkoaJVnolF]`P02olZb``05olVeaoo>_<Soc[c8oljlb?o;_Ld00_o?a<l01OoC
c=;oc/_Gom7Bf_oAd][obloM00;oc=GQ00Gobm[Tooooooooooooooooo`00000Fooooo`002Oooool0
1000003oooooooooooooool8000001006ATI00<0000003<c<`0c<c<02@0c<c<00`000000C4a<04a<
C00904a<C0@000004`1VIVH200000003o`0000000000C4a<0180C4a<00?o000003<c<`0c<c<0=`0c
<c<00ol000006ATI01TI6@0B01TI6@Cooooo00<00000ooooooooool04_ooool00ol0003ooooooooo
o`0Fooooo`;oIJ;c00OoCIKaobn6jolMMN?o7GGSo`AKe?l0Clgo55O@00;o=V7@00?o@6?>odiWc?m>
Il`00_mYLLL00omeMLGoP7W2oh1i`P03ohYn`0;oTh:n00KoVhJlo`000?l0003o0000oj::^onWS[X2
ojZA_0?o[iFk00Co]9RkokRM_OnhWKgo^9fm0_nlXKd01Oo1Ykooa:ZoolBZ_oo4Z[oob[;300?oc;G3
00?od[k6om?0aooIbLX00_oIbLX2omkDcP04omgDcooQg];ohMkBon?We0;ohnkF00?oh_;Iomo^fooL
kmh00ooGk^801?oAjNKoc=kVol?Ci_o3dnH2okg6hP04ok6hg_n/[MSo[:gHojb]f0;oYj?B00?oWYO<
oifAaonMTLL00_nLSL<3oif;`0?oWXZn0_nPRkd2oj><_004oj:7]onURKOoYHVgojF9]`?oZHfh00?o
[92iojj>]OnaT[L00_naT[L01?ndU[Wo]iNfokNG]_ngUkH2okVK^@Co_j6k00?o0000olFY__o5ZKh0
0oo://<3oljlb0;odlC;00?oclC?om?<d_oCc=800ooAd]X01OoBfMkoc=GQol_Ji?o;f^Cob]kX00?o
oooo00?o0000ooooooooool04oooool000Wooooo00@00000oooooooooooooooo2000000A01TI6@03
0000000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`0301<C4`6000000X0IVIV0`00000F04a<C003
0000000c<c<0<c<c03P0<c<c0_l0000C01TI6@Cooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`0Gooooo`;oHjCd00SoBIObobR5jol>LN3o05W@o`1>bol0Clgo55O@oaYFcP;o@6?>00?o
CVO<oee]bomMKL/00_meMLD2oh1i`P;oRWk000?oTh:no`000?l000000_nKQ[`00onRR[_oXhfmojZA
_003ojZA_0;o[iFk1?nhWKd01?nlXKgo`JNool6W_oo1Ykl2olBZ_`;ob[;300?oc;G3om:na_oB_/H0
1?oIbLX2omkDcP03on?Od?oQg];ohnOD00;ohnkF0_oRl]T01OoNmMcofOKPomWfh?oGk^;odNWV00;o
b>3Z00Co`m?VokO5i?ngaNCo]lGT0_na^=h00on/[MSoXIkBoijGc003oijGc0;oWI770_nLSL<3oif;
`0;oWXZn00?oX8^moij5^?nRQkL00_nRQkL3ojF9]`;oZHfh00CoZX^dojj>]On^S[Go[Xje0_naT[L4
okNG]P03okVK^OnmWKSo_Ifh00;o_j6k0_o4Y[X00ol0003oaJVnol^__P02olZb``03om2ja?o>_<So
dlC;00;odlC;0ooCc=801_oGeMKodM;Jom;Ig_oBfMkod]oRol_Ji0;ob]kX00Coan7[oooooooooooo
00005Oooool000Wooooo00@00000oooooooooooooooo2@00000A01TI6@030000000c<c<0<c<c00T0
<c<c0`00000A04a<C0X000006@1<C4`00`000000<c<c03<c<`0=03<c<aH000005`0c<c<00ol00000
6ATI01TI6@0@01TI6@Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`;o
B9Wc0_lXQN/01_l0FM3o04k;o`0o`?l0B<So6UK>obMIcP;oCVO<00?oGFg;ofacb?m/LlP00_n0NL83
o`0000;oTh:n00?oVhJloib9_onSSKd00_nSSKd3ojZA_003ojnE^oncV[ko/iZn00?o^9fm1?o1Ykl0
1?o4Z[oob[;3olZb`oo://<3om:naP?ofLW:0_oNe<h2on?Od003onGYdooUlMGohnkF00;oh_;I00?o
g_GLomWfh?oIm^000_oClnH01?o<kN_ob>3ZokgCjonmdn/2okO5i003ojZehOnUZMWoYJWI00?oXIkB
0onNUl`2oifAa`;oW8g30_nMRl000onIQ;_oVhBioi^4^@03oij5^0?oXXNg0_nURKL3ojZ;]0?o[Xje
00?o/I:gok>B]?ncT[@00ongUkH3okfM^008oknQ^oo4Y[[oa:JjolBV^_o5ZKko0000ol^___o://<2
om2ja0?odlC;0_oIcLh01_oCc=;oemGFomWMf_oIgM[od]WNom;OhP;od>CV00Cob]kXolOQjoo4hnko
a>?^0_ooool00ol0003oooooooooo`0Booooo`002Oooool01000003oooooooooooooool900000180
6ATI00<0000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00a04a<C003o`00000c<c<0<c<c00D0
<c<c2000000F04a<C0H000004P0c<c<00ol000006ATI01TI6@0?01TI6@Cooooo00<00000oooooooo
ool04_ooool00ol0003oooooooooo`0Iooooo`04ofFXm_m8VO?oB9WcobF7j`;o06gJ00Co04:no`0o
`?l0AlSo04O80_lhH<l2oee]b`?o00000on7Ol<2oi:4`@?oW8Vo0onSSKd00onZTKco[IJook>J_P03
ok>J_P03okRM_OnmYL3o_JG000?o`JNo0oo://<2om6laP06om:na_oIbL[ofLW:omW9b_oOe<kog]C>
0ooSgm000ooUjM?oiO7Eon;ge`02omgjf@05omSlgOoAnn?odO_Som?ci_o<kN/00_o1h^l00onmdn_o
/<CYok34j@03ojZeh@;oYJWI0_nQW]82oijGc003oiF;a_nFQl;oUXO200;oUhFn0onIQ;/2oi^4^@?o
WXFh0onRQkL00onURKOoYXNdojZ;]003ojZ;]0;o[Xje0oncT[@3okNG]P?o_Ifh1?o4Y[X00oo;[kko
0000ol^__P03om2ja006omO3a_oCa<_ofLg>omW=c_oMem;oemGF0_oIgMX01_oIiMkod]oRom3Ti_o@
i>KocNSYolOQj`;oa>?^00Co_n?`oooooooooooo00005?ooool000Wooooo00@00000oooooooooooo
oooo2@00000B01TI6@03o`0000000000<c<c00/0<c<c00?o0000000000000000<@1<C4`700000003
o`00001<C4`0C4a<0280C4a<0P00000A03<c<`03o`00000I6AT06ATI00h06ATI1?ooool00`00003o
ooooooooo`0Booooo`03o`000?oooooooooo01[ooooo0_mUZ?H2odZLm0;o06gJ00Co04o1o`0`[ol0
AlSo1Dc;0ol00002ofacb0;oNgW60on7Ol<2oi:4`@;oW8Vo0_nSSKd01?nVT/7o[IJoojfF_on]U[l2
ok>J_P03okRQ`_nmYL3o_JG000;o_JG000Co`JNoolN``oo7/<?ob[;30ooA_<H3omW9bP;ogmC>0_oS
hM401?oSgm3oiNWConGaeOoRmmL2omgjf@03omSlgOoAnn?odO_S00;ob_OZ00Co`Noaol7Rkonde?7o
]=Ca0on`a>T01?nZ]N7oW:KLoiRJe?nHV]@2oiJAc0?oUH_60_nFQl83oiN5_P?oVHBk0_nKQ;T3oij5
^003oj:7]onRQ;CoYXNd00;oYXNd0onZRk@00on^S[Go/8jcok>B]003ok>B]003okNG]_nkVKGo^iVe
00;o_Ifh00Wo`j:golBV^_o4Y[[oa:Jjol^/^oo;[kko0000om6g`?o@^/@00_oG`lH01ooMcLWofLg>
omgGd_oMem;ogn7FomWMf_oIiMh00_oGjn801_oBknKocNSYolSYkOo8jNgo`nW`okoSl0;o^n;b0_oo
ool00ol0003oooooooooo`0Aooooo`002Oooool01000003oooooooooooooool:000001<06ATI00<0
000003<c<`0c<c<0300c<c<3000005`0C4a<0`00000?03<c<`03o`00000I6AT06ATI00d06ATI1?oo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo0_mXZoL2odjQmP03ob^@k_l0
L=[o000000;o000000?o1Dc;ocQPcom<JLl00_mQL/d3og]iaP;oQgo30_nBQ<400onLRKooWHk3ojJB
`@02ojJB`@?o[IJo00Co/iZnokRQ`_nhXL;o^:720_nmYL001Oo3[/Goak33olN``oo7/<?oc[_800?o
dKc600?of<S;omW9b_oOe<h00_oOe<h01_oShM7oiNcConG/dooTmMCoh?_EomWne@;odOoG00GobOkL
ol;liOo2o>Gob_OZol7_l@02okKSmP03okCDlOnU`nooYL?_00;oXK?V0onLY]`2oiRJe0;oUY7<0onE
RlH2oiJ7`P?oUhFn0_nIQ;/2oi^4^@;oWXFh00?oWH6doj:4]?nRQ;@00onVQk@2ojZ;]004ojb:/_n`
S[?o/8jcok2>/`;o/i:d00Go]iFcok^I]OnkVKGo^iVeokfM^003ol>R]`03olBV^_o;[;_objbk00;o
dKO000?o0000omW1`_oG`lH00_oMcLT01ooRfLgogMOBomoQe_oOhMKoh>_IomgbgOoGjn800_oBknH0
0oo=lN_ob>W]ol?Yl002okkXl`03ok_Rl_nhh?Co^>3d00;ooooo00?o0000ooooooooool04?ooool0
00Wooooo00@00000oooooooooooooooo2P0000000ol000006ATI01TI6@0A01TI6@030000000c<c<0
<c<c00h0<c<c00<0000004a<C01<C4`0G01<C4`2000000h0<c<c00?o000001TI6@0I6AT0300I6AT4
ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool07_ooool01?m^[_So0000o`000?l0
0002o`1gg006o`0TY?l5C<_o6UK?oaYFcom<JLooHG;=0omcN/`2ohB2b@;oTHS60onMS/<3ojJB`@;o
[IJo1?nhXL801?nmYL3o`jk5ol>^aOo3[/D2olN```;oc[_800?odKc6omS8booHb</00_oNeLl00ooO
e<kohn7AonG/d`02onG/d`05onCee?oPnmGodOoGom7oeoo9o]`00_o2o>D01?nkn>ko/^ofok;_m_nf
hoH2ojSCm`?oYL?_0_nQ/nH2oibVg0;oV9[D0onFTL`2oiF;aP;oUXO20_nGQKh00onBO[[oUGjgoiEn
]`02oiUo]P?oWH6d0onRQ;@2ojJ7]003ojZ;]?n/R[;o[8Zb00?o/8jc00Co/i:dokNE/ongUK?o]iFc
0_nkVKD4ol>R]`?objbk00Cod[Bmom6g`?oA]l3o00000ooMcLT00ooRfLgoi^G@omoQeP02on3[f@04
omgbgOoHmn7od^oVolgaj`;oa_7^00Ko`>obokkXloniiOCo^NGdokSPm?ndgO@2ok;Jm@03o`000?oo
oooooooo013ooooo0009ooooo`0400000?ooooooooooooooo`/00000500I6AT2000000l0<c<c1000
000N04a<C0D00000>@1<C4`2000000d0<c<c0_l0000<01TI6@Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Looooo`?o00000_md/_P2oej[n@05od2OmOl8P>7o283Qo`0k_olJE/l0
0_ldHm800omQL/goLg[<og=jc002ohB2b@;oTHS60onMS/<3ojJB`@03ojfF_onaW/Co/Ik400?o^:72
1?o3[/D01_o7/<?oc[_8oljkb?o>^lSoeLS=omS8b`;og]G?0_oShm<2onC_eP03onG/dooTmMCoh?_E
00;o`ok?00Co^OcBojgiiOn]nNGoZ?Ca0_nQjoX2ojORn`03ojSCmonH`_GoV<;e00;oU;;/0_n@Xn42
ohfGf0?oS8g?0_n<Q/P2ohf1`P;oSgnm0onBO[X2oiEn]`;oVGnf1?nMPK@2oj:4]003ojJ7]?nWQ[;o
[8Zb00?o[8Zb0_n`S[<4okNE/`03ok^I]Oo0WKGo`9fe00;o`j:g0_o9Z;P02?o;[;_od[Bmom:d_OoA
]l3ofL72o`000?oPcLGogLg90_oRfLd01OoViM3oi_3Con3[fOoMl]gof?OQ00;od?WU00Cob?WYolKa
k_o0ko;o^ncd0_niiO@2ok;NmP;o/][e00?o[mOeooooool000004Oooool000Wooooo00@00000oooo
oooooooooooo3000000E01TI6@030000000c<c<0<c<c0100<c<c1P00000=04a<C0/00000100c<c<0
0`000000C4a<04a<C00K04a<C0l000003`1<C4`2000000d0<c<c00?o000001TI6@0I6AT02@0I6AT4
ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool06Oooool3o`0000Gooooo0_mj]?P0
1omX/?WoCZOhodjWn?lZV>oo04O8oaYFcoldHm800_m?L=@2og=jc0;oQ8;90_nAR<H3oif>``03ojJB
`OnYV/Oo/Ik400?o/Ik400?o^:72okf[aonmZlL00oo3[/D3oljkb0;oeLS=00?ofmOComkEcooShm<0
0_oShm<01ooTkmKohOWFon7ie_oJo]?oc_o@ol?nconio=800_nElN@2oiC^lP03oj7[n_nGg_koUmkn
00;oVM7k0onH`_D2oiBbk0;oT:?Q0_n=UmP3ohb=c`;oS8K80_n=PL800on?OkgoTWjjoi9n^P02oi9n
^P;oUGjg0_nIOkH3oif1]003oj:4]?nRPk;oYhJb00;oYhJb0on/R[800on`S[?o/i2bok>@/P03okNE
/`?o`9fe00Co`j:golVX^?o9Z;SobJRh0ooB];d01ooJ_koofL72on3=aOl0003oim_8on;IcOoViM00
0_oVl=<01OoRn=Kof_gHom3nf_o@nNGob?WY00;o^o?b00Go^ncdokKWm_nbhoOo/^?gok;NmP02ojoJ
mP03ojoGmOn^e?Co[]Cd00;o00004?ooool000Wooooo00@00000oooooooooooooooo3@00000E01TI
6@8000005P0c<c<=00000100<c<c00<0000004a<C01<C4`04`1<C4`7000000l0IVIV1000000=04a<
C0030000000c<c<0<c<c00/0<c<c00?o000001TI6@0I6AT0200I6AT4ooooo`0300000?oooooooooo
017ooooo00?o0000ooooooooool05_ooool3o`0000Wooooo0_n1]oL2og:dnP;oG:kj00Co04O8ocAS
d_ldHm;oCg3D0_mXO=<2ohB2b@;oTHS60_nMS/<01?nNU<[oZI[7ojVJaonYV/L2ok6Na003okJXb_nm
ZlOo_J_700;o_J_700Co`jk5olZib_o:^L[oc[_80ooEb<d01OoKem?oh>KGon3VeooShm?oi>oF00;o
hOWF00Cof_kColkod?nOl/7oV?780_n2j>H2ohKVm@03oi7Unon:f?ooR]So00;oRlkn0on9`?T2ohJ`
l@03oh:QiomoTmgoOi?M00;oOXWD0omoPL`2oh5la@;oSH720_n?Okd3oi9n^P;oUGjg0_nIOkH2oif1
]003oieo/_nRPk;oXX>b00?oYhJb0on/R[83ok>@/P?o]iFc0oo0WKD4olVX^004om6a^_oB];god[Bm
omZo_`?oh<g500co0000on_Xboo[m<coi_3Con;he_oJoMSod?kJolKngonno>Ko^?W]ok_cl_nfk_H2
ok;Xn004ok;Smon_g_Oo[mkgojoJmP;o[MOf00Co[]CdojgBm?n]d_Co00004?ooool000Wooooo00@0
0000oooooooooooooooo3P00000F01TI6@030000000c<c<0<c<c0340<c<c00<0000004a<C01<C4`0
3`1<C4`00`00003o00000000000J06IVIP@000002P1<C4`00`000000<c<c03<c<`0;03<c<`03o`00
000I6AT06ATI00L06ATI1?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo
0_l0000<ooooo`?oQkWf0_mk]oT2ofZdn`;o4EWB0_m?L=@00omXO=?oOXKAogj6d@02oi2>cPCoWYC:
0_nYV/L01?naW/Co]ZS:okJXb_nfZ<X2okf[a`04olBgc_o:^L[ob[W:olZibP;odLOA00?oeLS=om_G
dooKem<00_oPi]L01ooQm=Wof_gGolgod?o=om3o[?K2ogKM/?m[gMH00_mhh^`2ogoPn@03ohKNoOn3
doooPm?o00;oP<[o0oml_O/2ogN_m@03og:OkOm_TN?oKi7S00;oOi?M0_mnRM@2ogn1c0;oPGc50_n4
NKl2ohQh^`?oTWjj00CoUGjgoi9j]OnHOKCoV7fd0onMOk83oj:3/P?oYhJb00?o[8Zbojn</OncT;80
0oncT;800ongUK?o_9VcokbI/`02ol2M]@03olJT]_o9Z;SobJRh00;odK6j00God[BmomZo_ooJ_koo
hlg2on3=a@02onOKb009o`000?o[m<coi?c;omSobOo@o][oa_kOokkli_nhnNgo]?Cc00;o/>gg00Co
/^ShojoRn?n_h_So[mkg0_n]fOL01_n]eoKo[=?dojcCm?n]d_Co[<oco`00013ooooo0009ooooo`04
00000?ooooooooooooooo`h000005`0I6AT00`000000<c<c03<c<`0`03<c<`030000001<C4`0C4a<
00h0C4a<00<0000006IVIP1VIVH07`1VIVH2000000T0C4a<00<0000003<c<`0c<c<02P0c<c<00ol0
00006ATI01TI6@0701TI6@Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0Boooo
o`?o00003oooool01?n7^OKoSK[eohfjmOn=^_D2oh>jn004ogJhn_lAFM;o4EWBocE]fP;oJ7cC0_mn
Q]42oi2>cP?oWYC:00?oZI[7ojbTcon/Y<l00onfZ<X01OnmZlOoa;O>olBgc_o4]lkob[W:00;odLOA
0_oHf=P00ooKem?oh>KGon3Ve`02on7df@;ocOo@00GoO=j[ofoLlOm_g?7oKmcaogSOm002oh;Lo@03
oh?Ioon2coooP/oo00;oOLOn0ome_?`2ofb^n004ofBOlOmMSnWoGHoYofnAh`;oKHGI0_m^O=43ogn1
c0;oPGc500?oQ7VoohQh^on8N;/00on=NKP2oi9j]@?oV7fd0onMOk82oj:3/P;oYhJb00CoZHRaojn<
/On_S;7o[hba0_ncT;801OnhU;;o_9VcokbI/onlVK?o`9fe00;oaZBf00CobJRhom6a^_oA/K[odK6j
0_oJ_kl2on?=`P09on_LaOoWflSojnS;o`000?o[m<coi?c;okgmcOneo=Ko/?[Q00;o[O;d0_n`kOL0
0on^ioWo[n;hojoRn002oj_Gm`;o[=Gf0_n/do@01?n[d?Co[<ocojc?lol0000@ooooo`002Oooool0
1000003oooooooooooooool?000001L06ATI0`00000^03<c<`030000001<C4`0C4a<00d0C4a<0P00
000?06IVIPP000003@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00X0<c<c00?o
000001TI6@0I6AT01P0I6AT4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool3o`0001Cooooo00?oSK[eoi6klon:^oH00_n:^oH01On1^oWo01VAo`19aoleKM[oF7kM00?oMXgL
0_n@S/h00onNU<[oWikCojbTc`03ojbTc`03okJXb_nl]M?o_;GC00?oa;O>00?oblOGom77dOoHf=P0
0_oHf=P01ooKj]koh>KGon7dfOoQm=Wo^?_;oioa^_mWf>l00omlg?`01?mog?coR=SoohSHoon6eOl2
ohO=oP;oP<Kn0ome_O`2ofV`n@04oe^Qm?m?T>goCi3]oef?j@;oFH;O0_m]QMT01?m^O=7oLGK9og5f
bOmaM/T2oh5la@;oQ7Vo0_n8N;/2ohei^0?oTWZe0_nHOK@3oieo/P;oXX>b00?oYhJbojV8/OnYR;40
0on_S;400oncT;;o^9BbokRD/P03okbI/`?oaZBf00Kocjjhom6a^_oA/K[odK6jomZm_OoJ_kl2on?=
`P0;on_LaOo_k<Kok?S3on_dc?l0003oZ_:aoj;b^onSmmooY_G^ojgbm?n/joT00_n[i?X01?n/h?Wo
Z][hoj[Jn?n[eoL2oj[CmP03oj_Bm?oooooooooo00Cooooo00?o0000ooooooooool03Oooool000Wo
oooo00@00000oooooooooooooooo3`00000J01TI6@800000;00c<c<00`000000C4a<04a<C00;04a<
C08000002P1VIVH7000000P0Ogmo0`00000;06IVIP800000201<C4`2000000/0<c<c00?o000001TI
6@0I6AT01@0I6AT4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool03?ooool3o`00
01Sooooo0_nA^o<00on:^oKoT;cdoi2lm002ohVlm`;o36CJ00?oF7kMogJ=g?mfSM`00_n=UmP3oinN
d`;o[:C?00?o/;;Iokbedonl]M<00_nl]M<00oo4]lkoblOGol_7e`02om7Jg`03omSHf?oKj]kofn[N
00;ofOSO00Go^?_;o`000?n:eoooR]OoohWHo`02oi;CoP;oT=?n00?oSM7noho;o?n?bo`00_n7a_`3
ogboo0;oK[Cj00CoG:KgodVDl?m9U?3oCi3]0_m5On@00omIP]ooF7OGoeQge`02ofild@;oLGK90_me
Ll<2og]b_P;oR7Rk0on=NKP2oi9j]@;oV7fd0onMOk800onRPk;oXhBaojV8/@03ojV8/@;o[hba1?nh
U;82okbI/`03ol>P]Oo6Y;KoaZBf00;ocjjh00GodK6jomZm_OoJ_Kgoi<boon?=`P02on_La@08ono/
a_o/n<?ocO^dokWf[ol0003oXoOOojKek_nXkoL2ojSXnP04oj_Tn_nYgOWoZMgioj[Jn0;oZMCf00?o
Z]?fooooooooool01_ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooo
ool@000001/06ATI0P00000Y03<c<`0300000?l00000C4a<00X0C4a<0P00000906IVIP0300000?l0
000000000180Ogmo00@00000o`000000000000002@1VIVH2000000P0C4a<00<0000003<c<`0c<c<0
2@0c<c<00ol000006ATI01TI6@0401TI6@Cooooo00<00000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`?o00007?ooool2oiFllP06oi2lm?nE_O?oUKgcoiFmlon@_OGo36CJ0_llOnH2ogJ=
g0;oSIOH00?oWikCoin/h?nO[>000on`/]T2okbed`;o`/KN00?oblOGom7JgooAf]l00_oCk^H01OoK
j]kofOSOomWhgomffZGoR]Co00;oU=7m0_nDd_d00onBdokoUlkkoiO>n`02oiC=o004oho;o?n?a_[o
SlKjoho6nP;oQ/7k0_mh^O/2ofJ]n@05odnMm?m9U?3oBIC`ocN1j?m5On@00_loL]`2oeQge`;oFg3?
0_maM/T00omeLl?oNg:nog]b_P03oh5c^P;oSGVh0_nBN[D3oiQm]0;oWGnb0onSQ;43ojV8/@03ojn<
/OncT;;o/i2b00?o^9Bb00Co_9Vcol>P]Oo3X;GoaZBf0oo?[[P3omZm_@0;onC<_oo]gL;ojmc5ono/
a_o/n<?ocO^dokWf[on>kLSo0000oj7bl_nUjoX00_nXj?X2ojSIn@?oZMOh00?oZMCfooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool@000001d06ATI
0`00000V03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01`1VIVH2000001T0Ogmo
0`00000806IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<00ol000006ATI
01TI6@0301TI6@Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`?o0000
8Oooool2oiVll006oiFmlonH_O7oV;gaoiFnlol0DLGo?7oV0_mVUNX3ohNSi`?oWjcP00?o/;;Iok?4
ionca>L00oo2a]h00oo6g>WodM[Oom?^iP02om?^iP03ol_kiOndo=OoU/gk00;oULol00CoU=7moi_=
nOnKcOWoVLkj0_nMb_L2oi[:n004oiK9nOnGaOOoUlGgoiO5m`;oT<?h0_n5_OT2ogBenP;oGZWh00Ko
@YObocJ9k?lLLn;o77?RobQ_goloL]`3ociXe003oe]`comPK<SoH6c800;oMG?30_mkL[h2oh5c^P;o
R7Fg0_n?N;D3oiIk/`;oWGnb0onSQ;43ojV8/@?o/i2b0onhU;83ol>P]@?ocjjh0_oI^[/03OoJ_Kgo
i<boonC<_oo]gL;olNo1on_j^_nikYWoW^6=ohGYc_nOk_OoY>Kko`000?nWho/00_nWfoX00onXfOWo
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooa40
00007`0I6AT300000280<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP80
0000301oOgl4000000h0Ogmo00<00000o`00001VIVH01P1VIVH00`000000C4a<04a<C00604a<C003
o`00000c<c<0<c<c00T0<c<c00?o000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooooooo013o
oooo00?o0000ooooooooool00oooool3o`0002Gooooo0_nK_>l00onH_O7oVkg`oiVnlP02oiVnlP03
o`iihomVUN[oIYGZ00?oQj?W00?oWjcPoifol?nca>L00onca>L00oo2a]koa]cYolKLj@02ol?`l004
om?^i_n<k<goHm6WoiK=n`;oW<[g00?oVlchoio8mOnOb?D00_nNbOH00onMb_OoWlOdoio7m003oic7
mP03oiO5monH`oGoV<?e00;oT<3g0_n4^oT2og:cn@;oFJKg00Co=i;`ob5oj?lLLn;o1UkF0_lOHMH2
ociXe003od=ScOmKL<ooH6c800;oIf_30_mkL[h2oh5c^P;oR7Fg0on?N;D2oiIk/`?oWGnb0onSQ;40
0onYR;7o[H^bok>@/P03ok>@/P03okRD/_nnVkCo_Y^d00;o`j2e00?objZgoln^^?oI^[/00_oI^[/0
2?oTbkooi<boongM`_o]gL;olNo1omOiZonNhHgoUnkc0_nPj?/01?nTi__oY]gko`000?nWfoXAoooo
o`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooa40000000?o00000000
000I6AT07`0I6AT4000001h0<c<c00<0000004a<C01<C4`0201<C4`00ol00000IVIV06IVIP0506IV
IP8000002@1oOgl5000000@0VIVI2000000807moO`030000001VIVH0IVIV00D0IVIV00?o000004a<
C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`04o`00000I6AT06ATI01TI6@Cooooo00<00000
ooooooooool03oooool01?l0003oooooooooooooool3o`0002Wooooo0_nM_>h2oi^ml005oiVnl_nL
__3oW;k`oiZol_l0HL000_m9W?@2ogZcm`;oWKo`0_nca>L2ok;Km@04olKLjOo3l?3o`o3`ok3ij@;o
WLKe00?oW<Sfoj36lonPa_<00_nOao@00onOb?GoX/Kboj;6lP02oj77l`04oio7m?nPaO;oX<Gboj35
lP;oWLCd00?oV<?eoiW2m?nI`_@00_n@_oH2ohBkn0;oLK?i0_mEY_L01?l_T>oo3WORo`1UfOl6G]H2
oamQeP03oaeHcolnJ=Co@f?=00;oH6c800CoIf_3og1/__m`K;koL6bn0_n1LkX2ohQe]`;oSgRe0onF
Nk<2oieo/P;oXhBa00CoYXJcojf;/_n]Rk;o[H^b0oncT;83okjK]003ol>P]Oo;Z[OobjZg00CofKZk
00Ooi<^oonkO`Oo]gL;olNo1omOiZol0003oVnWj00;oX^7l00GoY=okooooooooooooooooo`00000A
ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooa<00000900I6AT0
0ol00000000000000004000001L0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP05
06IVIP0300000?l00000Ogmo00L0Ogmo00<00000o`00002IVIT0402IVIT3000000H0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00?o0000
01TI6@0I6AT01?ooool00`00003oooooooooo`0?ooooo`Co0000;Oooool2oinmkP;oW[g_00GoW;k`
oijnkonN_^ooW[k_oifol002oaRDi`;oGKgm0onAdoh01OnbfoGoYNgioh7Xhon1j>?oWLCc00;oX<?a
0_nPa?800onPa_?oX/Caoj;4l@02oj;5lP04oj;6l_nSa?7oXlCaoj?4l@;oX/Ga00?oX<Gboj74lOnQ
a?400_nN`o800onI`_CoV/7coi[1l`02oi6omP;oQK_h0_ma]?X2oeBWn004ob^Akol0LMco05O=o`1;
b0;o04g<00Go7ES?od=ScOm;HLSoBf78ofM[``03og1/_P;oNVnk0_n8MKL2ohmh]@?oUW^c0_nMOk80
0onSQ;7oYXJcojJ6/`03ojf;/P;o/i2b00Co^INdokjK]?nnVkCo_Y^d0oo;Z[L00ooF]k_ofKZkomVj
^`02onC;_`05onkO`Oobl[kolNo1oicHNOnOh_`00_nRhO`5ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5000000Z01TI6@<00000
500c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00@0IVIV0P00000707moO`<00000
5P2IVIT2000000D0Ogmo0P00000506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0
2@0c<c<00ol000006ATI01TI6@04ooooo`0300000?oooooooooo00oooooo0_l0000`ooooo`03oinm
k_nP_NgoX;g]00;oWkg^00?oW[k_oj2nk_nP_^h00_nO_^l00onN_o3oX;o_oj2ok`02oio0l003oio1
lOnQ`NooXL;`00;oXL;`00?oX<?aoj;2l?nR`o000_nR`o001?nRa?7oY<?_ojC3konT`nl2ojC4l003
oj?4lOnT`nooY<?_00;oXlC`00?oXLCaoj;3l?nR`o000_nO`_400onJ`O?oVl7coi_1l`02oi>om@;o
Qkch0_md]_X2oeN[n@0;obbFl?l0L=So04bno`1<__l0=[Wo04;5ob9Cb_m3HlgoBf78oeISa?mWJl<0
0_m`K;h2ogY_^`;oQ7>h0on?N;D01?nFNk?oUWbeoij1/onNPK<4ojJ6/`;o[H^b00Co/i2bokVG]?ni
UkCo^INd0_nnVk@01Oo7YKOobjZgomJg^ooF]k_ofKZk00;oi<^o0_o^gl400oobl[koaNnEooooo`09
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooo
oooooooooooo5000000]01TI6@8000004@0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0
IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl2000000X0VIVI1?l0000=09VIV@030000001oOgl0
Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0
<c<c00X0<c<c00?o000001TI6Oooool00oooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo02kooooo00?oX;g]oj6mk?nQ_N`00_nQ_Nd00onP_^koXKk]oj6nk@02oj6nkP03oj2okonR_nko
XL3_00;oXL3_0_nQ`Nl00onQ`_3oX/7_oj;1k`02oj;2l005oj;3l?nT`^ooY<;_ojC2konT`nl00_nU
`^h2ojG3k`03ojC3konU`nkoYL?^00;oY<?_00?oX/?`oj?2konS`^l00_nP`_400onK`O?oW<7boic1
lP02oiG0m@;oR[kh0_mi^OX2oef`n`?o=9gb00Co07cJo`0f^Ol0@/Go8U?:0_m;HLP01OmFHlCoL6bn
og1/__m`K;koNVnk00;oQ7>h0on=N;H2oiIl]@?oWX6c0onVQ[<2ojf;/PCo^INd00Co_Y^dolNU]oo7
YKOobjZg0_oF]k/2on;:_`04onC;_oo^gl7ol_:nolG_U@cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolD00000003o`0000000000
6ATI02`06ATI00?o000003<c<`0c<c<03P0c<c<00`000000C4a<04a<C00604a<C003o`00001VIVH0
IVIV00@0IVIV00?o000007moO`1oOgl00`1oOgl2000000P0VIVI1?l000040;>c/`Oo00001`2IVIT0
0ol00000Ogmo07moO`0407moO`03o`00001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`01@1<C4`0
0`00003o000003<c<`0:03<c<`03o`000?oooooooooo00;ooooo00<00000ooooooooool04_ooool0
0ol0003oooooooooo`0^ooooo`03oj6mk?nR_NcoX[g/00;oX[g]00?oXKk]oj:nkOnR_^d00_nR_^d2
oj:okP03oj70konS_nkoXko^00;oX/3^00CoX/7_ojC1k_nT`NkoY<7^0_nT`^h01?nT`^ooYL;^ojG2
k_nU`^h4ojK2kP03ojG3k_nV`^koY/;^00;oYL;^00?oXl;_ojC2konT`^l00_nQ`_000onL`O;oW/;a
oik2l@02oiS1m0;oS[og00CoO[cjohFon_n5_o[oQKoj0_ma^o`01?mB/O[o2h_Qo`0LVol0?/82obeD
b004oeISa?mSIl7oHfO1of=W`@;oNVnk0_n4LkP2oheh]P?oUWbe0_nNPK<3ojJ6/`03ojf;/_nbTKGo
/Y6e00?o^INd0oo7YKL3omJg^`;oh/Zo00?ok^32onkO`OoUn[003_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooaL00000;@0I6AT0
0`000000<c<c03<c<`0=03<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI0ol0000?0;>c/`?o00001@2IVIT2
000000D0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00X0<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooo
oooo02kooooo00?oX[g/oj>mk?nR_N`00_nR_N`3oj:nk@?oXkk]00?oXko]oj>ok_nT_nd00_nT_nd2
ojC0kP03ojC1k_nU`NgoYL7]00;oYL7^00?oYL;^ojK1kOnV`Nd00onV`^h2ojK2k@03ojK2k_nV`^go
Y/;]00;oYL;^00?oY<;_ojC2k_nT`^h00_nR`_000onN`_7oWl;aoio2l@02oi[2l`;oT/7g0_n5_oX2
ohc2n@;oO;ol0_mT^_d00ol09jko03k2obeDb002oceIaP;oHfO10_m`K;h2ohAc^0?oSGRf0_nFO;D3
oij1/`03ojJ6/onZS;Ko/Y6e00?o/Y6e00?o^INdol6Q^?o1XKP00_o7YKL01?oB];coe[Nkon;:_ooR
b[l2onkP`P03om[gYOnYgWcooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`002Oooool01000003ooooooooooooooolH000002d06ATI0P00000<03<c<`030000001<
C4`0C4a<00H0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI00<0VIVI0ol0000E0;>c/`03o`00002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1o
Ogl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<02P0c
<c<01Ol0003oooooooooooooool0000001Kooooo0_l0000`ooooo`03oj>mk?nR_NcoXkk/00CoXkk/
00?oXkk]oj>okOnS_nd00_nS_nd3ojBok@;oY<3]1OnU`Nd3ojK1k@KoY/;]0_nW`^d2ojK2kP03ojC2
k_nU`^koYL;^00;oXl;_00?oWl;aoj73l?nQ`o000onM`o800onF`_KoV/?doi[3m002oi;3n0;oQl?k
00GoML7noh?5oOl08J_o0D;3obeDb002oceIaP03of=W`Om`K;koL6bn00?oOW:l0_n=N;H2oiIl]@;o
WX6c00?oXHJgojZ<]_nZS;H01?nbTKD3ol6Q^005olNU]ooB];cod[Blomo8`_oRb[l00_o^h<800oo`
mKgof_NUooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool000Wo
oooo00@00000oooooooooooooooo6@00000^01TI6@030000000c<c<0<c<c00T0<c<c00<0000004a<
C01<C4`01@1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00?o000009VI
V@2IVIT00`2IVIT00ol00000/k>c0;>c/`0G0;>c/`03o`00002IVIT0VIVI00@0VIVI00?o000007mo
O`1oOgl00P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<02@0c<c<01Ol0003oooooooooooooool0000001Sooooo00?o0000ooooooooool0;_ooool2
oj>mk0GoXkk/00?oXko]ojBok?nT_n`00onT_nd4ojG0k@03ojG1kOnV`NgoY/7]00GoY/7]0_nW`^d0
0onV`^goYl;]ojO2k@02ojO2k@?oY/;]00?oYL;^ojK2k_nV`^h00_nT`^l01?nQ`o3oXl?`oj?3l?nS
`o02oio3lP03oi[3m?nNa??oW/Cc00;oV<Cf00KoT<GioiO6monGa_OoSlOjo`0QZol1@/<2oceIaP03
odmQaOmSIl7oL6bn00?oOW:l0_n:NKX2oiIo^0?oXHJg0onZS;H2ok:A]@04okVK^Oo1XKSo`J6hol6Q
^0?od[Bl00GoglS2oncRa_o^h<;ol?Fmom[gY@0Booooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo6P00000]01TI6@030000000c<c<0
<c<c00T0<c<c00?o000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`050;>c/`co0000202c/k<0
0ol00000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00T0<c<c1?ooool00`00003oooooooooo`0G
ooooo`03o`000?oooooooooo02kooooo0onS_^`4ojBnk0GoY;o/00?oYL3]ojG0k?nU`>`00_nU`>d6
ojK1k@;oYl7]1onW`^d01?nV`^goYl;]ojO2kOnV`^h3ojK3kP;oYL?^00?oXl?`ojC3konT`nl00_nR
`o400onNa??oXLCaoj74l@02oig5m005oiO6monMa_CoWLKdoiO7n?l09:h00_lDBlH01?lmFLKoCf75
og1/__m`K;h2ogib_0;oRWVj0onFOkP3oj66]`;oZXbf00Co/Y6eokVK^OniVkWo^I^i0_o1XKP01oo<
/;kod[Blomo8`_oOb<;ok>;6onci__o7lIP05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?oooooooooooooooa/00000;00I6AT00`000000<c<c03<c
<`0903<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0207moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<0102c/k<2o`0000`0c<c<0_l0
00070;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IV
IP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0200c<c<4ooooo`0300000?oo
oooooooo01Sooooo00?o0000ooooooooool0;_ooool5ojBnk0?oY;o/1?nU_n`3ojG0k0;oY/3]1OnV
`Nd3ojO1k@_oYl;]00?oY/?^ojO3kOnW`nd00_nV`nh00onT`nooY/?^ojK3kP02ojC3l003oj74lOnS
a?3oXlC`00;oXLGb00GoWLKdoj75l_nQaO;oWLOeo`0T[P02oaA;aP03odmQaOmSJ/CoHf[400?oOW:l
0_n:NKX2oiIo^0?oXHJg00?oZXbfok2E^oniVkT00oniVkT00oo1XKSoc;2nolb`_P02omo8`P;ok>;6
00?ok?Vnooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
0009ooooo`0400000?oooooooooooooooad00000:`0I6AT00`000000<c<c03<c<`0703<c<`030000
001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH01@000000Ogmo07moO`1oOgl0000000D0
VIVI00?o00000;>c/`2c/k<0102c/k<00ol00000c<c<0<c<c00>0<c<c0;o00001P2c/k<00ol00000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00404a<C0030000000c<c<0<c<c00P0<c<c1?ooool00`00003oooooooooo`0Iooooo`;o
0000;oooool3ojBnk0CoY;o/0_nU_n`4ojG0k0?oY/3/00?oY/7/ojK1kOnV`Nd00_nV`Nd00onW`Nco
Yl7]ojO2k002ojO2k0?oYl;]1?nX`^d01?nW`^goZ<;]ojS2kOnW`nd2ojS3k@;oYl?^00?oY/?^ojO3
k_nW`nh00_nU`nl01?nSa?3oYLC_ojG4konSa?02ojG4k`;oY<G`00KoX/KbojG5l?lDBlKo;US;odmQ
aOmSJ/@3ogId``;oRWVj0onFOkP00onQQ[OoY8jmok2E^`02ok2E^`;o^I^i00Wo`j_1olb`__o</;ko
c;2nom[6a_oOb<;ok>;6onci__l000005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo0009ooooo`0400000?oooooooooooooooal00000:@0I6AT00`000000<c<c03<c<`07
03<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`02
07moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<2o`0001<0c<c<00?o0000
0;>c/`2c/k<0102c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<00000
06IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c1?ooool0
0`00003oooooooooo`0Kooooo`03o`000?oooooooooo02gooooo0onT_^`2ojBok0CoYKo/1?nU`>`0
0onV`>coY/7]ojK1k@03ojK1k@;oYl7]0_nW`N`5ojO2k003ojS2kOnX`^coZ<;/00?oZ<;]1onX`nd0
0onW`nkoYl?]ojO3k@02ojO3kP04ojG4konW`nkoYl?^ojG4k`;oYlC^0_nVa>l01?nUaO3ooooooaA;
a_l^F</2of=Za0;oMWC30_n7OL43oiN6_`;oY8jm0on`UK/01OniVkWo`j_1ol>[`Oo3Zl7oc;2n00;o
f/K600?oj>G=on?m`_nYhhT06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_o
oooo0009ooooo`0400000?ooooooooooooooob4000009`0I6AT00`000000<c<c03<c<`0703<c<`03
0000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`05
0000002IVIT0VIVI09VIVOl000001@2c/k<00ol00000c<c<0<c<c00D0<c<c003o`00002c/k<0/k>c
00<0/k>c00?o000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0703<c<`Cooooo00<00000oooo
ooooool07?ooool00ol0003oooooooooo`0]ooooo`03ojBnk?nT_ncoY;o/00;oY;o/0onU_n`5ojG0
k0GoY/7]0onW`Nd2ojO2k@?oYl;/1OnX`^`2ojS2k@CoZ<?]0_nX`n`2ojS3k@03ojO3kOnX`ngoZ<?]
00;oZ<?]00CoYl?^ojS3kOnX`ngoYlC^1_ooool00ol^F<_oBfO>od]WcP03ogId``04ohMm`OnGQ[oo
UhJooiN6_`?oY8jm0_n`UK/01?nhY<Go`j_1ol>[`Oo3Zl43om[6aP03onSUcOoSoL;ooooo01Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooo
oooooolR000002L06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00
002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`01@3<c<`:o`0000L0c<c<00?o00000;>c/`2c/k<0
0`2c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02gooooo00?oY;o/ojFok?nU_n`00onU_n`5ojG0k0;oY/3]
1OnV`Nd3ojO1k@?oYl;/2OnX`^`01?nX`ngoZ<;/ojS2k?nX`n`2ojW3k0;oZ<?/00?oZ<?]ojW3k?nY
`n`00onX`nd9ooooo`03obiHbom;IlkoBfO>00;oMWC30_n7OL43oiN6_`;oY8jm00Go/9FkokRTaOnh
Y<Go^:C5ol>[`@02om73c003om[6a_oXiLgohog201_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolR00000003o`00000I6AT06ATI
02@06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c
0080/k>c00?o00000<c<c03<c<`0103<c<`2o`0000X0i^KV00?o00000<c<c03<c<`01@3<c<`00ol0
0000/k>c0;>c/`030;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`00
0000IVIV06IVIP0206IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<4oooo
o`0300000?oooooooooo01kooooo0_l0000^ooooo`GoYKo/1OnU`>`00onV`>goY/7]ojK1k@03ojK1
k@?oYl7]0_nW`N`2ojO2k0_oZ<;/0_nY`^`00onY`ncoZL;/ojW2k002ojW2k003ojW3k?oooooooooo
00cooooo0_m;Ilh2ofMgc`;oPXK>0onGQ[l00onTS[goZYc8okRTa@02okRTa@06olFndooA`lcodL?<
om73c?oQimSod_o77Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`0400000?ooooooooooooooobD00000900I6AT00`000000<c<c03<c<`0603<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI0080VIVI00Go00000;>c/`2c/k<0/k>co`0000060<c<c003o`00003Vi^H0i^KV00/0i^KV
00?o00000<c<c03<c<`0103<c<`00ol00000/k>c0;>c/`030;>c/`03o`00002IVIT0VIVI0080VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00D0C4a<
00<0000003<c<`0c<c<01P0c<c<4ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool0
;?ooool3ojFok0GoYL3/0_nV`>d5ojK1k@?oYl7]00?oYl7/ojO2k?nW`^`00_nW`^`:ojS2k0CoZL;/
4oooool01OnQ4@3o6eoFofMgcomWMlooPXK>00?oV9;<0onZW<P01OnhY<GoaKkColFndoo5_]?odL?<
00;ohNOH7oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0009ooooo`04
00000?ooooooooooooooobP000008@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<
00<0C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00?o0000
0;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00/0i^KV00?o0000
0<c<c03<c<`0103<c<`00ol00000/k>c0;>c/`030;>c/`03o`00002IVIT0VIVI0080VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00D0C4a<00<00000
03<c<`0c<c<01P0c<c<4ooooo`0300000?oooooooooo027ooooo00?o0000ooooooooool0;?ooool3
ojFok0?oYL3/0_nV`>`2ojK1k003ojK1kOnV`NcoY/7/00;oY/7]00?oYl7]ojO1k?nW`N`01OnW`^`8
ojS2k003ojW2k?oooooooooo01Oooooo0_m8O>42oh:6cP?oV9;<00?oZYc8ok>ffoo5_]<00_o5_]<2
om;Wi@03on7Wf?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`002Oooool01000003ooooooooooooooolY000002006ATI00<0000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl0
0`000000VIVI09VIV@0209VIV@05o`00002c/k<0/k>c0;>c/ol000001P3<c<`00ol00000i^KV0>KV
iP0=0>KViP03o`00003<c<`0c<c<00@0c<c<00?o00000;>c/`2c/k<00`2c/k<01Ol00000VIVI09VI
V@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000
000c<c<0<c<c00H0<c<c1?ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo02gooooo
00CoYKo/ojG0k?nU`>coYL3/0onV`>`5ojK1k0GoYl7/0onW`^`8ojS2k1cooooo00KoB7cQogBFiOmd
U^GoM9KUoiRBc?nHZN83ok>ff`03olFndooBinGod^OU02?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`002Oooool01000003oooooooooooooool[000001h06ATI00<00000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl01Ol00000VIVI09VIV@2IVIWo000000@0/k>c00?o00000<c<c03<c<`00`3<
c<`00ol00000i^KV0>KViP0?0>KViP03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00`2c
/k<01Ol00000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<
04a<C00404a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003oooooooooo`0Sooooo`03o`00
0?oooooooooo02gooooo00?oYL3/ojK0k?nV`>`01OnV`>`2ojK1k0OoYl7/00?oYl;/ojO1k?nW`N`0
0onX`^`Qooooo`04o`1af_mdU^GoM9KUogBFi@;oV:WR00?o/kKKokORmOngh_D09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooobd0
0000700I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1V
IVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl00000102c/k<00ol0
0000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00l0i^KV00?o00000<c<c03<c<`00`3<c<`00ol0
0000/k>c0;>c/`030;>c/`05o`00002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<4ooooo`0300000?oooooo
oooo02Cooooo0_l0000^ooooo`SoY/3/0_nV`N`8ojO1k2Oooooo0om2YoL2ohO?o`03okORmOoooooo
oooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000
003oooooooooooooool`000001X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@05o`00002c
/k<0/k>c0;>c/ol000001@3<c<`00ol00000i^KV0>KViP0A0>KViP03o`00003<c<`0c<c<00<0c<c<
00?o00000;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1V
IVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003o
ooooooooo`0Vooooo`03o`000?oooooooooo02cooooo2?nV`>`6ojO1k5Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolb000001P0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080
IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@05o`00002c/k<0/k>c0;>c/ol000001@3<c<`0
0ol00000i^KV0>KViP0A0>KViP03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00P2c/k<0
1Ol00000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003oooooooooo`0Wooooo`03o`000?oo
oooooooo02cooooo1_nV`>`2ojO0k003ojO1k?oooooooooo05_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooold000001H06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0
000007moO`1oOgl0Ogmo0000000409VIV@05o`00002c/k<0/k>c0;>c/ol000001@3<c<`00ol00000
i^KV0>KViP0A0>KViP03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000
VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003oooooooooo`0Xooooo`03o`000?oooooooooo
02cooooo0onV`>`00onW`>coooooooooo`1Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool000Wooooo00@00000oooooooooooooooo=@00000E01TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo
07moO`000000102IVIT01Ol00000/k>c0;>c/`2c/k?o000000D0c<c<00?o00000>KViP3Vi^H0403V
i^H00ol00000c<c<0<c<c0040<c<c003o`00002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVI
0000000407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0603<c<`Cooooo00<00000ooooooooool0:Oooool2o`0002gooooo00?oY/3/ooooooooool0
Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?oo
ooooooooooooocH00000500I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl0
0000102c/k<00ol00000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00l0i^KV00?o00000<c<c03<
c<`00`3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01P0c<c<4ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo
00@00000oooooooooooooooo=P0000000ol000006ATI01TI6@0A01TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080
Ogmo00D0000009VIV@2IVIT0VIVIo`0000040;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000>KV
iP3Vi^H03P3Vi^H00ol00000c<c<0<c<c0040<c<c003o`00002c/k<0/k>c0080/k>c00?o000009VI
V@2IVIT00P2IVIT00ol00000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<
C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`Cooooo00<00000ooooooooool0;?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`002Oooool01000003ooooooooooooooolh000001806ATI00<0000003<c<`0c<c<01@0c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl0
1Ol00000VIVI09VIV@2IVIWo000000@0/k>c00?o00000<c<c03<c<`0103<c<`00ol00000i^KV0>KV
iP0=0>KViP03o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00`2c/k<00ol00000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003oooooooooo`0]ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0000;ooooo`002Ooo
ool01000003oooooooooooooooli000001806ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@03
o`00002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP0:0>KViP;o
00001P3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01`0c<c<4ooooo`0300000?oooooooooo02kooooo0_l0000Xooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooool000002oooool000Wooooo00@00000oooooooooooooooo>P00000A01TI6@03
0000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP05
0000001oOgl0Ogmo07moO`000000102IVIT00ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<
00D0c<c<0ol000080>KViP03o`00003<c<`0c<c<00D0c<c<00?o00000;>c/`2c/k<00P2c/k<00ol0
0000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`00
0000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c1?ooool00`00003oooooooooo`0`oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;oooo
o`002Oooool01000003ooooooooooooooolj000001406ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo00000004
09VIV@03o`00002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`01`3<c<`8o`0000L0c<c<00?o0000
0;>c/`2c/k<00`2c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH00P1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c1?ooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooo`00000:ooooo`002Oooool01000003ooooooooooooooolk000001006ATI00<00000
03<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00?o0000
0<c<c03<c<`0503<c<`00ol00000/k>c0;>c/`040;>c/`05o`00002IVIT0VIVI09VIV@0000001@1o
Ogl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c
<c<4ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Xooooo`;o00002_ooool000Wooooo00@00000oooooooooooooooo>`0000000ol000006ATI01TI
6@0>01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IV
IP1VIVH0000000@0Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00
003<c<`0c<c<0180c<c<00?o00000;>c/`2c/k<0102c/k<00ol00000VIVI09VIV@0209VIV@030000
001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00504a<C0030000
000c<c<0<c<c00P0<c<c1?ooool00`00003oooooooooo`0cooooo`;o00008oooool00ol0003ooooo
ooooo`1Wooooo`?o00002_ooool000Wooooo00@00000oooooooooooooooo?000000@01TI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`040;>c/`;o0000
403<c<`2o`0000D0/k>c0_l0000409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c1?ooool00`00003ooooo
ooooo`0eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo
0009ooooo`0400000?oooooooooooooooc`00000400I6AT00`000000<c<c03<c<`0503<c<`030000
001<C4`0C4a<00<0C4a<00Go000006IVIP1VIVH0IVIV0000000407moO`030000002IVIT0VIVI00<0
VIVI00?o00000;>c/`2c/k<01@2c/k<00ol00000c<c<0<c<c00;0<c<c0;o00001@2c/k<2o`0000D0
VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00H0
C4a<00<0000003<c<`0c<c<0200c<c<01@00003oooooooooooooool0000003Sooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@00000oooooooo
oooooooo?@00000@01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`00
0000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo0P00000409VIV@03o`00002c/k<0/k>c
00D0/k>c3Ol000060;>c/`03o`00002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<01@00
003oooooooooooooool0000003Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1L
ooooo`Co00005?ooool000Wooooo00@00000oooooooooooooooo?P00000?01TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT3o`0001D0/k>c0_l0000609VIV@03o`00001oOgl0
Ogmo00<0Ogmo00<00000o`00001VIVH0101VIVH00`000000C4a<04a<C00404a<C00300000?l00000
<c<c00X0<c<c00<00000ooooooooool00_ooool00`00003oooooooooo`0hooooo`;o00007_ooool0
0ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@00000oooooooooooooooo?P00000?
01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP03
06IVIP03o`00001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`0@
0;>c/`;o00001`2IVIT2000000@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C005
04a<C0030000000c<c<0<c<c00X0<c<c00<00000ooooooooool00_ooool00`00003oooooooooo`0j
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001cooooo0009oooo
o`0400000?ooooooooooooooocl000003`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00@0VIVI0ol0000=0;>c/`;o00001`2IVIT2000000D0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6Oooool00oooool0
0`00003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3
o`00023ooooo0009ooooo`0400000?ooooooooooooooocl000003`0I6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`04
07moO`030000002IVIT0VIVI00H0VIVI3Ol0000809VIV@03o`00001oOgl0Ogmo00@0Ogmo00?o0000
06IVIP1VIVH0101VIVH00ol00000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00?o0000
01TI6@0I6AT01?ooool00`00003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0COooool4o`0002?ooooo0009ooooo`0400000?oooooooooooooood0000003`0I6AT0
0`000000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<0P00000406IVIP030000001oOgl0
Ogmo00@0Ogmo00<00000o`0000000000602IVIT2000000H0Ogmo00<0000006IVIP1VIVH0101VIVH2
000000L0C4a<00?o000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@04ooooo`0300000?oooooo
oooo03gooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo1?l0000Wooooo`002Oooool01000
003ooooooooooooooom1000000l06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C004
04a<C0030000001VIVH0IVIV0080IVIV00?o00000000001oOgl01P1oOgl2000001<0VIVI0`000007
07moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0:
03<c<`040000000I6AT06ATI01TI6@Cooooo00<00000ooooooooool0?oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Gooooo1?l0000[ooooo`002Oooool01000003ooooooooooooo
oom2000000h06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00<0IVIV0P00000707moO`<000003@2IVIT3000000P0Ogmo0P00000606IVIP03o`00001<
C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0201TI6@Cooooo00<0
0000ooooooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo0ol0
000_ooooo`002Oooool01000003ooooooooooooooom3000000h06ATI00<0000003<c<`0c<c<01P0c
<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV0P00000807moO`d000002@1o
Ogl00ol00000000006IVIP0506IVIP8000001`1<C4`2000000/0<c<c00<00000o`00000I6AT0100I
6AT4ooooo`0300000?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0oooooo`Co0000<_ooool000Wooooo00@00000oooooooooooooooo@`00000>01TI6@030000000c
<c<0<c<c00H0<c<c00?o000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001o
Ogl0Ogmo01T0Ogmo0P00000706IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02`0c
<c<00`0000006ATI01TI6@0401TI6@Cooooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o
0000ooooooooool0>oooool4o`0003Kooooo0009ooooo`0400000?oooooooooooooood@000003P0I
6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1V
IVH3000001@0Ogmo1000000706IVIP800000201<C4`00`000000<c<c03<c<`0;03<c<`030000000I
6AT06ATI00D06ATI1?ooool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=oooool4o`0003[ooooo0009ooooo`0400000?oooooooooooooood@000003`0I
6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<0P00000806IVIP<000003P1o
Ogl3000000X0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0;03<c<`030000000I
6AT06ATI00H06ATI1?ooool00`00003oooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<oooool4o`0003kooooo0009ooooo`0400000?oooooooooooooood@0000000?o
00000000000I6AT03@0I6AT00ol00000<c<c03<c<`0603<c<`8000001`1<C4`2000000T0IVIV00<0
0000o`00000000002P0000000ol00000IVIV06IVIP0806IVIP<00000201<C4`2000000`0<c<c0P00
000901TI6@Cooooo00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo033ooooo0ol00012ooooo`002Oooool01000003ooooooooooooooom6000000l06ATI00<0
000003<c<`0c<c<01`0c<c<2000000L0C4a<0`00000K06IVIP<000002P1<C4`00`000000<c<c03<c
<`0:03<c<`8000002`0I6AT4ooooo`0300000?oooooooooo04Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wooooo00@00000ooooooooooooooooA`00
000?01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`01`1<C4`3000001D0IVIV0`00
000;04a<C0800000300c<c<00ol000006ATI01TI6@0;01TI6@Cooooo00<00000ooooooooool0B?oo
ool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0400000?oooooo
ooooooooodT000003P0I6AT00ol00000000003<c<`0803<c<`03o`0000000000C4a<00T0C4a<00@0
0000o`000000000000003@1VIVH200000003o`0000000000C4a<00/0C4a<00?o00000000000c<c<0
300c<c<00`0000006ATI01TI6@0<01TI6@Cooooo00<00000ooooooooool0B_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`002Oooool01000003ooooooooo
oooooom:000000l06ATI00<0000003<c<`0c<c<0200c<c<2000000`0C4a<3@00000>04a<C0800000
3P0c<c<00`0000006ATI01TI6@0=01TI6@Cooooo00<00000ooooooooool0Boooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001Aooooo`002Oooool01000003ooooooooo
oooooom:000001006ATI00<0000003<c<`0c<c<02@0c<c<200000240C4a<1000000>03<c<`800000
400I6AT4ooooo`0300000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`Co0000E?ooool000Wooooo00@00000ooooooooooooooooB`00000@01TI6@030000
000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0701<C4`00ol00000000003<c<`0@03<c<`030000
000I6AT06ATI01006ATI1?ooool00`00003oooooooooo`1=ooooo`;o00002?ooool00ol0003ooooo
ooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000ooooooooooooooooB`0000000ol000006ATI
01TI6@0>01TI6@030000000c<c<0<c<c00X0<c<c00?o00000000000000000P00000D04a<C0H00000
3`0c<c<200000003o`00000I6AT06ATI01406ATI1?ooool00`00003oooooooooo`1?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0005cooooo0009ooooo`0400000?oo
ooooooooooooodh000003`0I6AT00ol0000000000000000>03<c<`L000001P1<C4`700000180<c<c
0`00000F01TI6@Cooooo00<00000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01;ooooo0ol0001Pooooo`002Oooool01000003ooooooooooooooom?000001406ATI
0P00000C03<c<`H00000600c<c<00`0000006ATI01TI6@0G01TI6@Cooooo00<00000ooooooooool0
DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`002Ooo
ool01000003ooooooooooooooom?00000003o`00000I6AT06ATI01006ATI00?o00000000000c<c<0
:`0c<c<200000003o`00000I6AT06ATI01P06ATI1?ooool00`00003oooooooooo`1Booooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000Ioooool000Wooooo00@00000oooooooooooooooo
DP00000B01TI6@<000009P0c<c<3000001d06ATI1?ooool00`00003oooooooooo`1Dooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0001[ooooo`002Oooool01000003ooooooooooooooomC000001@0
6ATI1000000N03<c<`@00000800I6AT4ooooo`0300000?oooooooooo05Gooooo00?o0000ooooool0
00001Oooool3o`0006oooooo0009ooooo`0400000?oooooooooooooooe<0000000?o00000000000I
6AT05@0I6AT4000001D0<c<c00?o00000000000000000P00000T01TI6@Cooooo00<00000oooooooo
ool0E_ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooo
ooooEP00000I01TI6@H000001P0c<c<:000002L06ATI0P000003ooooo`0300000?oooooooooo05Oo
oooo0_l0001fooooo`002Oooool01000003ooooooooooooooomH000001d06ATI1P00000`01TI6@80
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooomJ000004h0
6ATI1@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooe`0
0000B@0I6AT8000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
ooooG@00001401TI6@`000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooo
oooooooooomP000003h06ATI3`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooof40000000?o0000000000000000=@0I6ATD000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000ooooooooooooooooI`00000]01TI6@@0000000?o000000000000
00004P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooof/0
00008P0I6ATP000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
ooooLP00000D01TI6BL000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooo
oooooooooomh00000003o`000000000000000080000000?o0000000000000000;@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo0<oooooo0009oooookH00000dOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool000Wooooo]_l0000AoooookKo00002_ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01kooooo0P000010ooooo`D000003Oooool300000003o`000?oooooooooo013ooooo00<00000o`00
0?l000006Oooool2o`00000300000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`0L0?ooo`800000A`3oool4000000H0oooo0`00000E0?ooo`030000003oool0oooo00<0
oooo6_oo]/42000000OookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01X0oooo
0P00001=0?ooo`H000005@3oool3000000H0oooo7?oo]/400`00003ookK1oonf`@04oonf`@;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0I0?ooo`030000003oool0oooo06H0oooo0P00
00090?ooo`?ookK13P0000000ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100?ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01L0oooo0P00000M0?ooo``00000?P3oool0
0`00003o00000?ooo`080?ooo`@0000000?o0000oonf`Ooo]/403Ooo]/45000000OookK100<00000
o`00000000000_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool05@3oool20000
01P0oooo1`00000<0?ooo`L00000=03oool3000000P0oooo0`0000020?oooaOookK100<00000oonf
`Ooo]/401ooo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo
08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`@000006P3oool7000002`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`WookK11000000;oonf`@<000001ooo]/401000003oooooooooool0000:
ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo01<0oooo00?o00000?ooo`3oool04P3oool3000002D0oooo0`00000V0?oo
o`0300000?l00000000000P0oooo00<00000o`00000000001P3oool2oonf`@0300000?l000000000
00@000001?oo]/4300000003o`0000000000000000SookK100?o0000oonf`Ooo]/401Ooo]/400`00
003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo0180oooo00<000000?ooo`3oool0403oool3000002/0
oooo0`00000R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool40000017o
okK10P000007oonf`@0300000?oo]/7ookK100CookK10_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo0140oooo00<000000?ooo`3oool03`3oool200000340oooo00<000000?ooo`3oool0
7@3oool2000000T0oooo0P0000050?ooo`<000000P3ooolEoonf`@<000001Ooo]/400`00003ookK1
oonf`@03oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
ool>oonf`@Ko003o3ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0380oooo0`00000J0?ooo`8000002@3o
ool2000000H0oooo00<000000?ooo`3oool00`3oool5oonf`@/000002?oo]/400ol0003ookK1oonf
`@03oonf`@0300000?oo]/7ookK100;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?ooo`2=0?ooo`[ookK11?l00?l6oonf`@?o003o3?oo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool03P3oool200000100oooo00<00000o`00003oool05`3oool4
000001`0oooo00Co00000000000000000000503oool3000000P0oooo0P0000060?ooo`8000001P3o
ool2oonf`@0300000?l00000000000_ookK100Co000000000000000000001Ooo]/42000000CookK1
0P000002oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
ool6oonf`@Co003o3Ooo]/42o`00o`[ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool200000180oooo200000040?ooo`L000006@3o
ool3000000h0oooo0`00000:0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`@000004_oo
]/43000000CookK100<00000oonf`Ooo]/400ooo]/401@00003ookK1oooooooooooo000000[ooooo
0009ooooo`03o`000?ooool0oooo08d0oooo1Ooo]/400ol00?oookK1oonf`@0Aoonf`@03o`00oooo
]/7ookK100OookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00d0oooo00<0
00000?ooo`3oool0303oool2000000h0oooo1P00000C0?ooo`L000005@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`8000001@3oool300000080oooo1Ooo
]/4<000000KookK100<00000oonf`Ooo]/400_oo]/400ol0003ookK1oonf`@03oonf`@0400000?oo
ooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo0ooo]/42o`00oaGookK100?o
003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo0P00000P0?ooo`03o`000000
0000000001<0oooo3000000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`03oonf`@0000000000008000003?oo]/42000000GookK100?o
0000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@03o`000?oooooo000000[ooooo0009
ooooo`03o`000?ooool0oooo08d0oooo0_oo]/400ol00?oookK1oonf`@0Foonf`@03o`00oooo]/7o
okK100GookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`8000009@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00003o00000?ooo`03
0?ooo`80000000?o0000oonf`Ooo]/404?oo]/42000000?ookK10P000003oonf`@0300000?oo]/7o
okK100?ookK100?o0000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0C03oool:o`00
ocL0oooo0_oo]/400ol00?oookK1oonf`@0Goonf`@03o`00oooo]/7ookK100CookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`090?ooo`<00000:03oool3000002@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`800000103oool200000080oooo1Ooo]/48000000SookK100<00000oonf
`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000CookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`170?ooo`Go003o2P3oool5o`00oc80oooo00?ookK1o`00
oooo]/406_oo]/400ol00?oookK1oonf`@03oonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0C0?ooo`@000005@3oool00`00003o00000?ooo`0P0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo0_oo]/43000000SookK110000005oonf`@0300000?oo]/7ookK100;ookK100D00000oonf
`Ooo]/7ookK1o`000003oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3oool0;03oool5o`00oa@0oooo0_l00?lD0?ooo`;o003o<03oool00ol00?oookK1oonf`@0Koonf
`@03o`00oooo]/7ookK100;ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00T0oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`080?ooo`03o`0000000000oooo
00d0oooo200000040?ooo`L00000403oool2000001`0oooo00<00000o`00000000001@3oool00ol0
000000000?ooo`020?ooo`0300000?l00000oooo00@0oooo00<000000?ooo`3oool00P3oool30000
00oookK10P000004oonf`@03o`000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK100000002
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool09`3oool5o`00
o`D0oooo1Ol00?l>0?ooo`;o003o5`3oool2o`00obd0oooo00?o003ooonf`Ooo]/407?oo]/400ol0
0?oookK1oonf`@02oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`080?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`<000004`3oool4000000h0oooo0P00000I0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`0300000?l00000oooo0080oooo0P0000000`3o
oooookK1oonf`@03oonf`@P000001_oo]/42000000?ookK100D00000oonf`Ooo]/7ookK100000003
oonf`@0300000?oo]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3oool08`3oool4o`00o`l0oooo0ol00?l80?ooo`?o003o6`3oool2o`00obP0oooo1Ol00?lMoonf
`@03o`00oooo]/7ookK100;ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo1000000J0?ooo`<000003@3oool2000001H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000000`3oool2oonf
`@<000002?oo]/43000000GookK100Go0000oonf`Ooo]/7ookK100000003oonf`@0600000?oo]/7o
okK1oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`0R0?ooo`03o`00o`3oool0oooo01@0oooo0_l00?l50?ooo`03o`00o`3oool0oooo01h0oooo0_l0
0?lR0?ooo`Co003o0P3oool00ol00?l0oooooonf`@05o`00oaWookK100Co003ooonf`Ooo]/7ookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`03o`0000000000oooo00L0oooo0`00000Q0?ooo`<00000
303oool00ol0000000000000000A0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`03o`00
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<00000
3_oo]/400ol0003ookK1oonf`@03oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003o
okK1oonf`Ooo]/40000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
ool08@3oool00ol00?l0oooo0?ooo`0G0?ooo`05o`00o`3oool0oooo0?ooool00?l08`3oool00ol0
0?l0oooo0?ooo`0M0?ooo`;o003o1P3oool00ol00?l0oooooonf`@05oonf`@?o003o5ooo]/400ol0
0?oookK1oonf`@02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool01P3oool00ol0
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`060?ooo`03o`00003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3ooooo000000@0oooo00<000000?oooooo]/404?oo]/400`00003ookK1oonf`@02
oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool07`3oool2o`00oa/0oooo00?o
003o0?ooool00?l09@3oool00ol00?l0oooo0?ooo`0J0?ooo`;o003o1`3oool00ol00?l0oooo0?oo
o`09oonf`@;o003o5_oo]/401Ol00?oookK1oooooooooooo0000017ooooo00?o0000ooooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool2000000/0oooo4000000>0?ooo`8000003@3oool3000000X0oooo0P0000090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00_oo]/4;000000GookK100<00000oonf`Ooo]/400_oo]/401@00003o
okK1oonf`Ooo]/40000000;ookK100<00000oonf`Ooo]/400_oo]/400`00003oooooo`00000:oooo
o`002Oooool00ol0003ooooo0?ooo`0N0?ooo`03o`00o`3oool0oooo01`0oooo0_l00?lU0?ooo`03
o`00o`3oool0oooo01X0oooo00?o003o0?ooo`3oool01P3oool00ol00?l0oooo0?ooo`0;oonf`@03
o`00oooo]/7ookK101?ookK100Go003ooonf`Oooooooooooo`00000Aooooo`03o`000?ooool0oooo
00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool00ol0000000000?ooo`0?0?ooo`<000003@3oool20000
00h0oooo0P0000060?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`060000003oool0oooo0?oooooo]/400000
2ooo]/400`00003o0000oonf`@03oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003o
okK1oonf`Ooo]/40000000?ookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3o
ool07@3oool00ol00?l0oooo0?ooo`0M0?ooo`;o003o9P3oool00ol00?l0oooo0?ooo`0H0?ooo`03
o`00o`3oool0oooo00L0oooo00?o003o0?ooo`3oool03?oo]/400ol00?oookK1oonf`@0Boonf`@05
o`00oooo]/7oooooooooool000004Oooool00ol0003ooooo0?ooo`040?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01P3oool00ol00000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<00000o`00003oool0503oool4000000/0oooo0P00000>0?ooo`H000002`3oool00`00
0000oooo0?ooo`020?ooo`06o`00003oool0oooo0?ooool0000000000`3oool00`000000oooo0?oo
o`020?ooo`04o`00003oool0oooo0?ooo`8000003_oo]/400`00003ookK1oonf`@02oonf`@05o`00
0000003ookK1oonf`@0000000ooo]/401@00003ookK1oonf`Ol00000000000;ookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0L0?ooo`03o`00o`3oool0oooo01d0
oooo00Co003o0?ooo`3ooooo003o9P3oool00ol00?l0oooo0?ooo`0F0?ooo`03o`00o`3oool0oooo
00L0oooo00Co003o0?ooo`3oool0oooo3?oo]/400ol00?oookK1oonf`@0Coonf`@04o`00oooooooo
ooooo`00017ooooo00?o0000ooooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00003o00000?ooo`070?ooo`<000006`3o
ool2000000/0oooo00<000000?ooo`3oool06`3oool00ol00000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00ol00000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`00
0000oooo4?oo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000?ookK100D00000
oonf`Ooo]/7ookK100000002oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool06`3oool00ol00?l0oooo0?ooo`0M0?ooo`03o`00o`3oool0oooo0080oooo00?o003o
0?ooo`3oool0903oool00ol00?l0oooo0?ooo`0D0?ooo`03o`00o`3oool0oooo00P0oooo00Co003o
0?ooo`3oool0oooo3Ooo]/401?l00?l0000000000000000Aoonf`@04o`00ooooooooooooo`00017o
oooo00?o0000ooooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`800000803oool2000000X0
oooo0P00000J0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`05oonf`@Oo00001Ooo]/40
0ol0003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000?ookK100@00000oonf`Ooo]/400000
0_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01X0oooo00?o
003o0?ooo`3oool07@3oool00ol00?l0oooo0?ooo`040?ooo`03o`00o`3oool0oooo02@0oooo00?o
003o0?ooo`3oool04P3oool00ol00?l0oooo0?ooo`090?ooo`04o`00o`3oool0oooo0?ooo`gookK1
1@00000@oonf`@04o`00ooooooooooooo`00017ooooo00?o0000ooooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`03o`00003oool0oooo00/0oooo0P0000000ol00000000000000003000000l0
oooo00?o00000000003oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00Go00000?oo
o`3oool0oooo000000030?ooo`;ookK10ol00007oonf`@03o`000?oo]/7ookK100?ookK100D00000
oonf`Ooo]/7ookK100000003oonf`@0400000?oo]/7ookK1000000;ookK100<00000oonf`Ooo]/40
0_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0J0?ooo`03o`00o`3o
ool0oooo01d0oooo00?o003o0?ooo`3oool0103oool00ol00?l0oooo0?ooo`0T0?ooo`03o`00o`3o
ool0oooo0180oooo00?o003o0?ooo`3oool02@3oool01?l00?l0oooo0?ooo`3oool=oonf`@D00000
4?oo]/401?l00?ooooooooooool0000Aooooo`03o`000?ooool0oooo0080oooo00?o00000?ooo`3o
ool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00?o00000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`@00000203oool6000000/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`03oonf`Ol0003ookK100WookK100?o0000oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo
]/40000000?ookK100@00000oonf`Ooo]/4000000_oo]/400`00003ookK1oonf`@02ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01T0oooo00?o003o0?ooo`3oool07@3o
ool00ol00?l0oooo0?ooo`060?ooo`03o`00o`3oool0oooo02@0oooo00?o003o0?ooo`3oool0403o
ool00ol00?l0oooo0?ooo`0:0?ooo`04o`00o`3oool0oooo0?ooo`gookK11@00000@oonf`@04o`00
ooooooooooooo`00017ooooo00?o0000ooooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo0`00000B0?ooo`8000002P3oool2000000T0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00ol0003ookK1oonf`@0:
oonf`@03o`000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK100000003oonf`@0400000?oo
]/7ookK1000000;ookK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`0H0?ooo`03o`00o`3oool0oooo01h0oooo00?o003o0?ooo`3oool01P3o
ool00ol00?l0oooo0?ooo`0T0?ooo`03o`00o`3oool0oooo00l0oooo00?o003o0?ooo`3oool02`3o
ool01?l00?l0oooo0?ooo`3oool>oonf`@<000004?oo]/401Ol00?oookK1oooooooooooo0000017o
oooo00Go0000ooooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05@3oool2000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03o`000?oo]/7ookK100_ookK100?o
0000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000;ookK100@00000oonf`Ooo]/40
00000ooo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo01P0
oooo00?o003o0?ooo`3oool07P3oool00ol00?l0oooo0?ooo`060?ooo`03o`00o`3oool0oooo02@0
oooo00?o003o0?ooo`3oool03`3oool00ol00?l0oooo0?ooo`0;0?ooo`04o`00o`3oool0oooo0?oo
oa3ookK100?o003ooonf`Ooo]/403_oo]/401Ol00?oookK1oooooooooooo0000017ooooo00Go0000
ooooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P00000J0?ooo`03o`000000
0000000000P0oooo00?o00000?ooo`3oool01`3oool200000140oooo00?o00000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00?o0000oonf`Ooo]/403?oo]/400ol0003ookK1oonf`@02oonf`@05
00000?oo]/7ookK1oonf`@0000000_oo]/401000003ookK1oonf`@000003oonf`@0500000?oo]/7o
ooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool05`3oool00ol00?l0oooo0?ooo`0N
0?ooo`03o`00o`3oool0oooo00P0oooo00?o003o0?ooo`3oool0903oool00ol00?l0oooo0?ooo`0=
0?ooo`03o`00o`3oool0oooo00`0oooo00Co003o0?ooo`3oool0oooo4Ooo]/400ol00?oookK1oonf
`@0=oonf`@05o`00oooo]/7oooooooooool000004Oooool01Ol0003ooooo0?ooo`3oool0000000/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool2000001l0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00?o0000oonf`Ooo]/403?oo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7o
okK1oonf`@0000000_oo]/401000003ookK1oonf`@000003oonf`@0500000?oo]/7oooooooooool0
00002_ooool000Wooooo00?o0000ooooo`3oool05P3oool00ol00?l0oooo0?ooo`0N0?ooo`03o`00
o`3oool0oooo00T0oooo00?o003o0?ooo`3oool0903oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00
o`3oool0oooo00`0oooo00Co003o0?ooo`3oool0oooo4Ooo]/400ol00?oookK1oonf`@0=oonf`@05
o`00oooo]/7oooooooooool000004Oooool01?l0003ooooo0?ooo`00000;0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02P3oool8000000h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00?o00000?oooooo]/403Ooo]/400ol0003ookK1oonf`@02oonf`@050000
0?oo]/7ookK1oonf`@0000000_oo]/401000003ookK1oonf`@000002oonf`@0300000?oo]/7ookK1
00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool05P3oool00ol00?l0
oooo0?ooo`0N0?ooo`03o`00o`3oool0oooo00X0oooo00?o003o0?ooo`3oool0903oool00ol00?l0
oooo0?ooo`0<0?ooo`03o`00o`3oool0oooo00d0oooo00?o003o0?ooo`3oool04Ooo]/400ol00?oo
okK1oonf`@0=oonf`@05o`00oooo]/7oooooooooool000004Oooool01?l0003ooooo0?ooo`00000;
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01`3oool01000003o0000o`000000
00080?ooo`@0000000?o00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0ooooo`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00ol00000oooooonf`@0=oonf`@03o`000?oo]/7ookK100;ookK100D00000oonf`Ooo
]/7ookK100000002oonf`@0400000?oo]/7ookK1000000;ookK100<00000oonf`Ooo]/400_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0F0?ooo`03o`00o`3oool0oooo
00T0oooo5?oo]/400ol00?oookK1oonf`@0;oonf`@03o`00oooo]/7ookK102CookK100?o003ooonf
`Ooo]/402ooo]/400ol00?oookK1oonf`@0>oonf`@03o`00oooo]/7ookK101;ookK100?o003ooonf
`Ooo]/402ooo]/400ol00?oookK1oonf`@02ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
o`3oool000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100KookK100<00000
oonf`Ooo]/403_oo]/42000000WookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@08
oonf`@0300000?oo]/7ookK100[ookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02
oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000CookK1
00?o0000oonf`Ooo]/403Ooo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@00
00000_oo]/401000003ookK1oonf`@000002oonf`@0300000?oo]/7ookK100;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool05P3oool00ol00?l0oooo0?ooo`090?oooaCo
okK100Co003ooonf`Ooo]/7ookK11Ol00?l6oonf`@03o`00oooo]/7ookK102CookK100?o003ooonf
`Ooo]/402_oo]/400ol00?oookK1oonf`@0?oonf`@<000004Ooo]/400ol00?oookK1oonf`@0;oonf
`@03o`00oooo]/7ookK100;ooooo00?o0000ooooooooool03oooool01?l0003ooooo0?ooo`00000;
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003ooooookK100CookK100<00000oonf`Ooo]/401Ooo]/42000001?ookK10P000008
oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/402?oo]/42000000WookK100<00000
oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000ooo
]/401@00003ookK1oonf`Ooo]/40000000CookK100?o0000oonf`Ooo]/403Ooo]/400ol0003ookK1
oonf`@02oonf`@0400000?oo]/7ookK1000000?ookK100@00000oonf`Ooo]/4000000_oo]/400`00
003ookK1oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01H0
oooo00?o003o0?ooo`3oool02@3ooolDoonf`@Co003o1Ooo]/45o`00o`03oonf`Ol00?oookK102Go
okK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0>oonf`@D000004?oo]/400ol00?oo
okK1oonf`@0;oonf`@03o`00oooo]/7ookK100;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003ooooookK100?ookK100<00000oonf`Ooo]/401Ooo]/400`00003o
okK1oonf`@0Eoonf`@8000001ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Wo
okK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100;o
okK100D00000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`@0000001Ooo]/40
0ol0003ookK1oonf`@0<oonf`@05o`000?oo]/7ookK1oonf`@0000000ooo]/401000003ookK1oonf
`@000002oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/42ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo01H0oooo00?o003o0?ooo`3oool02@3ooolAoonf`@Co003o
3Ooo]/43o`00obGookK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0>oonf`@D00000
4?oo]/400ol00?oookK1oonf`@0:oonf`@04o`00oooo]/7ookK1oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00CookK100?o0000oonf`Ooo
]/401?oo]/400`00003ookK1oonf`@0Hoonf`@03o`000?oo]/7ookK100GookK100?o000000000?oo
]/401_oo]/400`00003ookK1oonf`@09oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf`Ooo
]/401ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00
003ookK1oonf`Ooo]/40000000GookK100?o0000oonf`Ooo]/402_oo]/42o`0000?ookK100D00000
o`000?oo]/7ookK1o`000003oonf`@04o`000?oo]/7ookK1o`0000;ookK100@00000o`000?oo]/7o
okK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0E0?ooo`03o`00
o`3oool0oooo00X0oooo3ooo]/42o`00o`;ookK100?o003ooonf`Ooo]/403_oo]/43o`00ob?ookK1
00?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0>oonf`@D000004?oo]/400ol00?oookK1
oonf`@09oonf`@03o`00oooo]/7ookK100;ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00?o00000?ooo`3oool01?oo]/400`00003ookK1oonf`@04oonf`@030000
0?oo]/7ookK101WookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@05oonf`@030000
0?oo]/7ookK100[ookK10P000003oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/40
0_oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/7ookK100000005oonf
`@03o`000?oo]/7ookK100WookK100?o0000oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo]/40
000000;ookK100D00000oonf`Ooo]/7ookK100000002oonf`@0700000?oo]/7ookK1oonf`@00003o
ooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0E0?ooo`03o`00o`3oool0oooo00X0oooo
2_oo]/43000000;o003o1?oo]/400ol00?oookK1oonf`@0>oonf`@03o`00oooo]/7ookK100;o003o
1Ooo]/43000001WookK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0?oonf`@<00000
4Ooo]/400ol00?oookK1oonf`@09oonf`@03o`00oooo]/7ookK100;ookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0000000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00ooo]/400`00003ookK1
oonf`@04oonf`@0300000?oo]/7ookK101_ookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1
oonf`@05oonf`@0300000?oo]/7ookK100_ookK100<00000oonf`@0000002_oo]/400`00003ookK1
oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/401@00003ookK1oonf`Ooo]/400000
00GookK10ol00006oonf`@;o00001Ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100L00000
oonf`Ooo]/7ookK100000?oo]/40000000CookK100<00000ooooool000002_ooool000Wooooo00?o
0000ooooo`3oool05@3oool00ol00?l0oooo0?ooo`0:0?ooo`WookK11@000005oonf`@03o`00oooo
]/7ookK100kookK100?o003ooonf`Ooo]/400_oo]/401?l00?oookK1oonf`Ooo]/45000001SookK1
00?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK100kookK1
00?o003ooonf`Ooo]/402?oo]/400ol00?oookK1oonf`@03oonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0000000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`;ookK100<00000oonf`Ooo
]/401?oo]/400`00003ookK1oonf`@07oonf`@/000002ooo]/400`00003ookK1oonf`@05oonf`@03
00000?oo]/7ookK100CookK100<00000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@09oonf`@03
00000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/401Ol0003ookK1oonf`Ooo]/400000
00CookK100<00000oonf`Ooo]/401Ooo]/46o`0000KookK100Go0000oonf`Ooo]/7ookK100000003
oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/401@00003ookK1oonf`Ooo]/40000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool05@3oool00ol00?l0oooo0?oo
o`0:0?ooo`WookK11@000005oonf`@03o`00oooo]/7ookK100kookK100?o003ooonf`Ooo]/400ooo
]/400ol00?oookK1oonf`@05000001SookK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf
`@0Coonf`@;o003o3_oo]/400ol00?oookK1oonf`@07oonf`@03o`00oooo]/7ookK100CookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/40
2Ooo]/400`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/40
1?oo]/400`00003ookK1oonf`@0Hoonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0_oo]/401@00003ookK1oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/403ooo]/42000000Co
okK100D00000oonf`Ooo]/7ookK100000003oonf`@0400000?oo]/7ookK1000000?ookK100@00000
oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool05@3oool00ol00?l0oooo0?ooo`0:
0?ooo`WookK11@000005oonf`@03o`00oooo]/7ookK100kookK100?o003ooonf`Ooo]/401?oo]/40
0ol00?oookK100000004000001SookK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0E
oonf`@;o003o2ooo]/400ol00?oookK1oonf`@07oonf`@03o`00oooo]/7ookK100GookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0_oo
]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/402_oo
]/400`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401Ooo
]/400`00003ookK1oonf`@0Goonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo
]/401@00003ookK1oonf`Ooo]/40000000CookK10P00000=oonf`@8000001Ooo]/401@00003ookK1
oonf`Ooo]/40000000?ookK100@00000oonf`Ooo]/4000000ooo]/401@00003ookK1oooooooooooo
000000[ooooo0009ooooo`03o`000?ooool0oooo01D0oooo00?o003o0?ooo`3oool02P3oool9oonf
`@04o`00o`0000000000000000OookK100?o003ooonf`Ooo]/403?oo]/400ol00?oookK1oonf`@06
oonf`@03o`00oooo]/400000008000006Ooo]/400ol00?oookK1oonf`@0;oonf`@03o`00oooo]/7o
okK101KookK100?o003ooonf`Ooo]/402?oo]/400ol00?oookK1oonf`@05oonf`@;o003o2?oo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`03oonf`@00003ookK100CookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@0<
oonf`@03o`000?oo]/7ookK100OookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@04
oonf`@0300000?oo]/7ookK101SookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/42000000[ookK100?o0000
oonf`Ooo]/401?oo]/400ol0003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000?ookK100H0
0000oonf`Ooo]/7ookK100000?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0oooo01D0oooo00?o003o0?ooo`3oool02P3oool8oonf`@03o`00oooo]/7ookK100WookK1
00?o003ooonf`Ooo]/403?oo]/400ol00?oookK1oonf`@07oonf`@03o`00oooo]/7ookK101[ookK1
00?o003ooonf`Ooo]/402ooo]/400ol00?oookK1oonf`@0Goonf`@03o`00oooo]/7ookK100KookK1
00?o003ooonf`Ooo]/401Ooo]/400ol00?oookK1oonf`@08oonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00ol00000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00?ookK100000?oo]/40
1?oo]/400ol0003ookK1oonf`@06oonf`@0300000?oo]/7ookK100kookK100<00000oonf`Ooo]/40
1ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/40
2ooo]/42000000_ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@030000
0?oo]/7ookK100;ookK10P000005oonf`@<000000_oo]/45000000GookK10P000003oonf`@050000
0?l0003ookK1oonf`@0000000ooo]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0E0?ooo`03o`00o`3oool0oooo00X0
oooo1ooo]/400ol00?oookK1oonf`@0:oonf`@03o`00oooo]/7ookK100cookK100?o003ooonf`Ooo
]/402?oo]/400ol00?oookK1oonf`@0Ioonf`@03o`00oooo]/7ookK100_ookK100?o003ooonf`Ooo
]/405ooo]/44o`00o`GookK100?o003ooonf`Ooo]/401Ol00?l;oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00?ookK100000?oo
]/401?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100kookK100<00000oonf`Ooo
]/401ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo
]/402ooo]/400`00003ookK10000000:oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo
]/400_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100GookK10P000008oonf`@80
00001?oo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/401000
003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
01D0oooo00?o003o0?ooo`3oool02P3oool7oonf`@03o`00oooo]/7ookK100[ookK100?o003ooonf
`Ooo]/403?oo]/400ol00?oookK1oonf`@08oonf`@03o`00oooo]/7ookK101WookK100?o003ooonf
`Ooo]/402ooo]/400ol00?oookK1oonf`@0Koonf`@So003o4?oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03oonf`@00003ookK1
00CookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@0@oonf`@0300000?oo]/7ookK1
00KookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1
00[ookK100D00000oonf`Ooo]/7ookK10000000:oonf`@0300000?oo]/7ookK100?ookK100<00000
oonf`Ooo]/400_oo]/400`00003ookK1oonf`@04oonf`@8000003Ooo]/42000000GookK100<00000
oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000?ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0F0?ooo`03o`00o`3oool0
oooo00T0oooo1_oo]/400ol00?oookK1oonf`@0;oonf`@03o`00oooo]/7ookK100cookK100?o003o
oonf`Ooo]/402Ooo]/400ol00?oookK1oonf`@0Hoonf`@03o`00oooo]/7ookK100cookK100?o003o
oonf`Ooo]/407_oo]/400ol00?oookK1oonf`@0Aoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00?ookK100000?oo]/401?oo]/40
0`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1017ookK100<00000oonf`Ooo]/401ooo]/40
0`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/402Ooo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/400ooo]/40
0`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/402Ooo]/40
0ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/40
1000003ookK1oonf`@000004oonf`@03o`000?oooooo000000[ooooo0009ooooo`03o`000?ooool0
oooo01H0oooo00?o003o0?ooo`3oool02@3oool5oonf`@03o`00oooo]/7ookK100gookK100?o003o
oonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0:oonf`@03o`00oooo]/7ookK101OookK100?o003o
oonf`Ooo]/403_oo]/400ol00?oookK1oonf`@0Loonf`@03o`00oooo]/7ookK101;ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0ooo]/400000oonf`@04oonf`@0300000?oo]/7ookK100CookK100?o0000oonf`Ooo]/404_oo]/40
0`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401?oo]/40
0`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100CookK100?o000000000?oo]/401ooo]/42
000000CookK10P000004oonf`@8000001_oo]/400`00003o000000000008000000GookK10P000003
oonf`@8000000ooo]/42000000?ookK100<00000oonf`Ooo]/400_oo]/400`00003oooooo`00000:
ooooo`002Oooool00ol0003ooooo0?ooo`0G0?ooo`03o`00o`3oool0oooo00P0oooo1?oo]/400ol0
0?oookK1oonf`@0>oonf`@03o`00oooo]/7ookK100[ookK100?o003ooonf`Ooo]/402ooo]/400ol0
0?oookK1oonf`@0Foonf`@03o`00oooo]/7ookK100oookK100?o003ooonf`Ooo]/406_oo]/400ol0
0?oookK1oonf`@0Coonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00?ookK100000?oo]/401?oo]/400`00003ookK1oonf`@04oonf
`@0300000?oo]/7ookK101;ookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@04oonf
`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@06oonf
`@8000002?oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK10`00000@oonf
`@<000000ooo]/42000000CookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf
`@0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo01L0oooo00?o003o0?oo
o`3oool0203oool4oonf`@03o`00oooo]/7ookK100kookK100?o003ooonf`Ooo]/402_oo]/400ol0
0?oookK1oonf`@0<oonf`@03o`00oooo]/7ookK101GookK100?o003ooonf`Ooo]/404?oo]/400ol0
0?oookK1oonf`@0Ioonf`@03o`00oooo]/7ookK101?ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00ooo]/400000oonf`@04oonf
`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/404_oo]/400`00003ookK1oonf`@06oonf
`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@07oonf
`@0300000?oo]/7ookK100WookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100GookK10`00000:oonf`@<000001Ooo]/400ol0003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/400_oo]/401@00003ookK1oooooooooooo
000000[ooooo0009ooooo`03o`000?ooool0oooo01P0oooo00?o003o0?ooo`3oool01`3oool4oonf
`@03o`00oooo]/7ookK100kookK100?o003ooonf`Ooo]/402Ooo]/400ol00?oookK1oonf`@0=oonf
`@03o`00oooo]/7ookK101CookK100?o003ooonf`Ooo]/404_oo]/400ol00?oookK1oonf`@0Foonf
`@;o003o5_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`03oonf`@00003ookK100CookK100<00000oonf`Ooo]/401?oo]/400`00
003o0000oonf`@0Boonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401?oo]/400`00
003ookK1oonf`@04oonf`@0300000?oo]/7ookK100KookK100<00000o`000?oo]/402ooo]/400`00
003ookK1oonf`@06oonf`@03o`000?oo]/7ookK100?ookK100<00000o`00000000001ooo]/401000
003o0000000000000002oonf`@<0000000?o0000oonf`Ooo]/401?oo]/42000000GookK100?o0000
oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0603oool00ol00?l0oooo0?ooo`070?oo
o`?ookK100?o003ooonf`Ooo]/404?oo]/400ol00?oookK1oonf`@08oonf`@03o`00oooo]/7ookK1
00gookK100?o003ooonf`Ooo]/405?oo]/400ol00?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK1
01CookK100?o003ooonf`Ooo]/405_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00?o00000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`03oonf`@00003ookK100CookK100<00000oonf
`Ooo]/401Ooo]/400`00003ookK1oonf`@0Aoonf`@0300000?oo]/7ookK100KookK100<00000oonf
`Ooo]/401?oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100KookK100<00000oonf
`Ooo]/403?oo]/400ol0003ookK1oonf`@06oonf`@0300000?oo]/7ookK100GookK100<00000oonf
`Ooo]/402?oo]/42000000SookK10P000005oonf`@8000001?oo]/400`00003ookK1oonf`@02oonf
`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3oool0603oool00ol00?l0oooo0?ooo`070?ooo`?ookK100?o003ooonf`Ooo]/404?oo]/400ol0
0?oookK1oonf`@08oonf`@03o`00oooo]/7ookK100kookK100?o003ooonf`Ooo]/404ooo]/400ol0
0?oookK1oonf`@0Doonf`@;o003o4ooo]/400ol00?oookK1oonf`@0Goonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00?ookK10000
0?oo]/401?oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK1017ookK100<00000oonf
`Ooo]/401_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100CookK100<00000oonf
`Ooo]/401_oo]/400`00003ookK1oonf`@0>oonf`@0300000?oo]/7ookK100KookK10P000006oonf
`@<000003ooo]/42000000GookK10P000005oonf`@0300000?oo]/7ookK100?ookK100@00000oonf
`Ooo]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0I0?oo
o`03o`00o`3oool0oooo00H0oooo0ooo]/400ol00?oookK1oonf`@0Aoonf`@03o`00oooo]/7ookK1
00KookK100?o003ooonf`Ooo]/403ooo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK1
01OookK10ol00?l=oonf`@?o003o6_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`3oool2oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/401_oo]/400`00003ookK1oonf`@0?oonf`@0300000?oo]/7ookK100KookK100<00000
oonf`Ooo]/401?oo]/400ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100KookK100<00000
oonf`Ooo]/403ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100KookK10`00000:
oonf`@8000001_oo]/400ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100?ookK100<00000
oonf`Ooo]/400_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
01T0oooo00?o003o0?ooo`3oool01P3oool3oonf`@03o`00oooo]/7ookK1017ookK100?o003ooonf
`Ooo]/401Ooo]/400ol00?oookK1oonf`@0@oonf`@03o`00oooo]/7ookK101;ookK100?o003ooonf
`Ooo]/406_oo]/44o`00o`KookK10ol00?lMoonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`;ookK100<00000oonf`Ooo]/400ooo]/40
0ol0003ookK1oonf`@05oonf`@0300000?oo]/7ookK100oookK100<00000oonf`Ooo]/401_oo]/40
0`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401Ooo]/40
0`00003ookK1oonf`@0Aoonf`@0300000?l00000000000OookK100<00000o`00000000002?oo]/48
00000003o`000000003ookK100KookK10P000004oonf`@8000001Ooo]/400ol0003ookK1oonf`@03
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool06P3oool00ol0
0?l0oooo0?ooo`050?ooo`?ookK100?o003ooonf`Ooo]/404_oo]/400ol00?oookK1oonf`@03oonf
`@03o`00oooo]/7ookK1017ookK100?o003ooonf`Ooo]/404Ooo]/400ol00?oookK1oonf`@0Ooonf
`@Ko003o8?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`3oool2oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401_oo]/40
0`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/401?oo]/40
0`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/405?oo]/40
0`00003ookK1oonf`@07oonf`@8000004ooo]/44000000CookK10P000005oonf`@8000001_oo]/40
0`00003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0K0?ooo`03o`00o`3oool0oooo
00@0oooo0P000?l00ol00?l0003o0000o`0?0000o`GookK100?o003ooonf`Ooo]/400_oo]/400ol0
0?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK100oookK100?o003ooonf`Ooo]/40A_oo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03oonf
`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401_oo]/42000000cookK100?o0000oonf
`Ooo]/401ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100CookK100<00000oonf
`Ooo]/401Ooo]/400ol0003ookK1oonf`@0Foonf`@<000002?oo]/43000000gookK10`000007oonf
`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401Ooo]/401000003oooooooooool0000:
ooooo`002Oooool00ol0003ooooo0?ooo`0L0?ooo`03o`00o`3oool0oooo00<0003o0_oo]/400ol0
0?oookK1oonf`@0?oonf`@<0003o0_oo]/4300000003oonf`Ol00?oookK101CookK100?o003ooonf
`Ooo]/403ooo]/400ol00?oookK1oonf`@16oonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`03o`00003oool0oooo00?ookK100<00000oonf`Ooo]/401?oo]/400`00
003ookK1oonf`@07oonf`@8000002?oo]/42000000WookK100<00000oonf`Ooo]/401Ooo]/400`00
003ookK1oonf`@04oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/406Ooo]/400`00
003ookK1oonf`@08oonf`@@0000000?o00000000000000001P000007oonf`@80000000?o0000oonf
`Ooo]/401?oo]/400ol0003ookK1oonf`@05oonf`@0500000?oo]/7oooooooooool000002_ooool0
00Wooooo00?o0000ooooo`3oool06P3oool50000o`<0oooo0_oo]/400ol00?oookK1oonf`@0Boonf
`@030000o`000000000000<000005_oo]/400ol00?oookK1oonf`@0=oonf`@;o003oBOoo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`0000002`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03oonf
`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/402Ooo]/48000000_ookK100<00000oonf
`Ooo]/401Ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100GookK100<00000oonf
`Ooo]/406Ooo]/400ol0000000000000000Koonf`@0300000?oo]/7ookK100GookK10P000007oonf
`@0300000?oo]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
ool05`3oool30000o`D0oooo00?o003o0?ooo`3oool00_oo]/400ol00?oookK1oonf`@0Coonf`@D0
000000<0003ooonf`Ooo]/404ooo]/400ol00?oookK1oonf`@0<oonf`@03o`00oooo]/7ookK104Wo
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oooooo
]/400ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK101[ookK100<00000oonf`Ooo
]/401Ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo
]/407Ooo]/44000001CookK10`000007oonf`@0300000?oo]/7ookK100KookK100@00000oonf`Ooo
]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0E0?ooo`80
003o2@3oool2o`00o`;ookK100?o003ooonf`Ooo]/404_oo]/400ol00?l000000000000300000003
oonf`@000?l0003o01?ookK100?o003ooonf`Ooo]/402ooo]/400ol00?oookK1oonf`@1:oonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0000000<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003ooooookK100?o
okK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@0Hoonf`@03o`000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK1027o
okK10P00000?oonf`@<000002Ooo]/400ol0003ookK1oonf`@07oonf`@0400000?oo]/7ookK1oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool04`3oool20000o`d0
oooo0ol00?lCoonf`@03o`00oooo]/7ookK100<0000000CookK1o`00oooo]/7ookK10`000?l@oonf
`@03o`00oooo]/7ookK100[ookK100?o003ooonf`Ooo]/40Booo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK1
00GookK100<00000oonf`Ooo]/405_oo]/42000000KookK100<00000o`000?oo]/401Ooo]/400ol0
003ookK1oonf`@05oonf`@0300000?oo]/7ookK100_ookK10P0000000ol000000000000000040000
013ookK100?o00000000000000002`0000000ol0003ookK1oonf`@08oonf`@8000002?oo]/420000
00CookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0B0?ooo`03
o`00o`3oool0oooo00d0oooo0_oo]/42o`00o`oookK10ol00?l8oonf`@?o003o0_oo]/420000o`ko
okK100?o003ooonf`Ooo]/402?oo]/42o`00odkookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
o`00003oool0oooo00<0oooo00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@06oonf`@03
o`000000003ookK101CookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@04oonf`@03
00000?oo]/7ookK100KookK100<00000oonf`Ooo]/402Ooo]/42000000WookK10`00000Soonf`@<0
00002Ooo]/400`00003ookK1oonf`@04oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool04@3oool20000o`l0oooo0_oo]/400ol00?oookK1o`00o`02o`00o`OookK1
1Ol00?l>oonf`@05o`00oooo]/7ookK1oonf`@000?l03Ooo]/400ol00?oookK1oonf`@06oonf`@;o
003oD?oo]/42ooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3oool00000303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
003ookK1oonf`@03oonf`@0300000?oo]/7ookK100OookK10P00000Aoonf`@8000002?oo]/400`00
003ookK1oonf`@05oonf`@0300000?oo]/7ookK100GookK100?o0000oonf`Ooo]/402?oo]/420000
00kookK11000000Noonf`@0300000?oo]/7ookK100WookK100<00000oonf`Ooo]/401Ooo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00l0oooo0P000?lA0?ooo`?o
okK100Co003ooonf`Ooo]/7ookK11ol00?lDoonf`@05o`00oooo]/7ookK1oonf`@000?l02ooo]/40
0ol00?oookK1oonf`@06oonf`@03o`00oooo]/7ookK1053ookK10_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooool0oooo000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00?ookK1o`000?oo]/401?oo]/400`00003o0000oonf
`@08oonf`@8000003Ooo]/42000000WookK100?o0000oonf`Ooo]/401Ooo]/400`00003ookK1oonf
`@05oonf`@0300000?oo]/7ookK100SookK100<00000oonf`Ooo]/404_oo]/43000001SookK10P00
00000ol0003ookK1oonf`@08oonf`@8000002?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo00h0oooo00<0003o0?ooo`3oool04@3oool3oonf`@03o`00oooo]/7o
okK101gookK10_l00?l2oonf`@80003o2Ooo]/400ol00?oookK1oonf`@04oonf`@;o003oDooo]/42
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooo`3oool00000303oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00ooo]/400000oonf
`@06oonf`@0300000?oo]/7ookK100SookK10P000009oonf`@8000002_oo]/400`00003ookK1oonf
`@06oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1oonf
`@0Eoonf`@@000004Ooo]/43000000cookK100<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00`0oooo0P000?lD0?ooo`?ookK100?o003o
oonf`Ooo]/407ooo]/42o`00o`;ookK100<0003ooonf`Ooo]/401_oo]/401?l00?oookK1oonf`Ooo
]/43o`00oeGookK10_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooool0oooo000000`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
0_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100WookK12@00000;oonf`@030000
0?oo]/7ookK100KookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@08oonf`@030000
0?oo]/7ookK101[ookK110000009oonf`@@000003_oo]/400`00003ookK1oonf`@09oonf`@;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool02P3oool20000oaH0oooo1?oo
]/400ol00?oookK1oonf`@0Poonf`@?o003o00<0003oo`00ool00?l02Ol00?mHoonf`@;ooooo00?o
0000ooooooooool03oooool01Ol0003ooooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`?ookK100<00000oonf`Ooo
]/401Ooo]/400`00003ookK1oonf`@0Koonf`@0300000?oo]/7ookK100KookK100?o0000oonf`Ooo
]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK101oookK12@00000Aoonf`@03
00000?oo]/7ookK100[ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`090?ooo`030000o`3oool0oooo01H0oooo1?oo]/400ol00?oookK1oonf`@0Toonf`@030000
oooo]/7ookK100?ookK100?o003ooonf`Ooo]/40F_oo]/42ooooo`03o`000?oooooooooo00oooooo
00Go0000ooooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`04oonf`@0300000?oo]/7ookK100GookK100?o000000000?oo
]/405ooo]/4200000003o`000?oo]/7ookK100GookK10P000008oonf`@03o`000?oo]/7ookK100Oo
okK100?o0000oonf`Ooo]/40>?oo]/42000000gookK10_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?ooo`080?ooo`030000o`3oool0oooo01`0oooo00?o003o0?ooo`3oool0
903oool00`000?l0oooo0?ooo`020?ooo`03o`00o`3oool0oooo03L0oooo8ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00Go0000ooooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00L0
oooo00?o00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo0P00000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo4_oo]/42000000oookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`080?ooo`030000o`3oool0oooo01`0oooo
00?o003o0?ooo`3oool09@3oool010000?l0oooo0?ooool00?lj0?ooob?ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`800000403oool3000000T0oooo00?o00000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02D0oooo4Ooo]/400`00003ookK1oonf`@0?oonf`@;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool01`3oool00`000?l0oooo
0?ooo`0M0?ooo`03o`00o`3oool0oooo02H0oooo00<0003o0?ooool00?l0>P3ooolSoonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<00000o`0000000000203oool4000000T0oooo0`00000;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?oooa3ookK100?o0000oonf`Ooo]/40
4?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00H0oooo00<0
003o0?ooo`3oool07`3oool00ol00?l0oooo0?ooo`0V0?ooo`03o`00o`000?l0oooo03T0oooo8ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool00P3oool00`000000oooo0?oo
o`0<0?ooo`03o`00003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00ol00000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo2@00000=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`oookK100<00000oonf`Ooo]/404Ooo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00D0oooo00<0003o
0?ooo`3oool08@3oool00ol00?l0oooo0?ooo`0T0?ooo`04o`00o`3oool0oooo0000ocT0oooo8ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool00P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`8000007@3oool2000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0W0?ooo`kookK100<00000oonf`Ooo]/404_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo00@0oooo00<0003o0?ooo`3oool08`3oool00ol00?l0oooo0?ooo`0R
0?ooo`05o`00o`3oool0oooo0?ooo`000?l0>@3ooolSoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603o
ool2000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`gookK100<0
0000oonf`Ooo]/404ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo00<0oooo00<0003o0?ooo`3oool09@3oool00ol00?l0oooo0?ooo`0P0?ooo`03o`00o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0=P3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool0
0ol00000oooo0?ooo`060?ooo`0300000?l00000oooo00P0oooo0P00000F0?ooo`8000002`3oool0
0ol00000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo3?oo]/400`00003ookK1oonf`@0D
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool00P3oool00`00
0?l0oooo0?ooo`0W0?ooo`03o`00o`3oool0oooo01d0oooo0_l00?l70?ooo`030000o`3oool0oooo
03D0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool00`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`800000403oool4000000/0oooo0P00000=0?ooo`030000003oool0oooo
02P0oooo3?oo]/400`00003ookK1oonf`@0Doonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool00P3oool00`000?l0oooo0?ooo`0X0?ooo`03o`00o`3oool0oooo01/0
oooo00?o003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0e0?ooob?ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool7000000H0
oooo0`00000>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:@3oool;oonf`@03
00000?oo]/7ookK101GookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooo
0?ooo`3oool0003o02`0oooo0_l00?lJ0?ooo`03o`00o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool0=03ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`050?ooo`03
0000003oool0oooo00`0oooo00<00000o`00003oool0203oool00`00003o00000?ooo`070?ooo`03
00000?l00000000000l0oooo1P00000@0?ooo`03o`00003oool0oooo00`0oooo00<000000?ooo`3o
ool0:P3oool;oonf`@0300000?oo]/7ookK101GookK10_ooool00ol0003oooooooooo`08ooooo`00
2Oooool01?l0003ooooo0?ooo`000?l_0?ooo`03o`00o`3oool0oooo01D0oooo0_l00?l=0?ooo`03
0000o`3oool0oooo03<0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0P0?ooo`8000003`3oool00`000000oooo0?ooo`0Z0?ooo`_o
okK100<00000oonf`Ooo]/405Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0003o0340oooo00?o003o0?ooo`3oool04`3oool00ol00?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo0380oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool2000001l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`cookK1
00<00000oonf`Ooo]/405?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0380oooo1?l00?l>0?ooo`?o003o4P3oool00`000?l0oooo0?ooo`0a0?ooob?ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`090?ooo`8000002`3oool00`000000oooo0?ooo`0I0?ooo`<000004@3o
ool00`000000oooo0?ooo`0[0?ooo`cookK100<00000oonf`Ooo]/405?oo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo03H0oooo1Ol00?l60?ooo`?o003o5@3oool0
0`000?l0oooo0?ooo`0a0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo00H0oooo00<000000?ooo`3oool03P3oool00`00003o00000?ooo`0:0?ooo`030000003oool0
oooo00T0oooo1000000D0?ooo`<00000503oool00ol00000oooo0?ooo`0[0?ooo`gookK100<00000
oonf`Ooo]/404ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
03/0oooo1_l00?lI0?ooo`030000o`3oool0oooo0300oooo8ooo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0303oool7000000T0oooo1000000G0?ooo`030000003oool0oooo
02/0oooo3_oo]/400ol0003ookK1oonf`@0Boonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0FP3oool00`000?l0oooo0?ooo`0`0?ooob?ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0:0?ooo`8000004`3oool9000001/0oooo00<000000?ooo`3oool03@3ooolF000000P0
oooo3ooo]/400`00003ookK1oonf`@0Aoonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool0FP3oool00`000?l0oooo0?ooo`0`0?oooa?ookK13ol00?l01?oo]/7ooooo
ooooool0000Aooooo`03o`000?ooool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01`3oool7000001H0
oooo100000001?l00000oooo0?ooo`3oool@oonf`@0300000?oo]/7ookK1013ookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`1K0?ooo`030000o`3oool0oooo02l0
oooo3ooo]/44o`00o`oookK10_l00?l00ooooooo0000ooooo`0@ooooo`03o`000?ooool0oooo00P0
oooo00<000000?ooo`3oool0403oool2000000`0oooo0`00000b0?ooo`03o`0000000000000000L0
00008@3oool3000000030?oooooo]/7ookK100oookK10P00000@oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0G03oool00ol00?l0oooo0?ooo`0^0?ooo`gookK1
0_l00?lDoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`090?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0303oool3000005d0oooo1000000@oonf`@030000
0?oo]/7ookK100gookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`1L0?ooo`030000o`3oool0oooo02h0oooo2ooo]/42o`00oaKookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo00X0oooo00?o00000?ooo`3oool04@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo05/0oooo0ooo]/42000000oookK100<00000oonf`Ooo]/403?oo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo05d0oooo00<0003o
0?ooo`3oool0;@3oool8oonf`@?o003o6?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo1000000N
0?ooo`H00000=@3oool5oonf`@8000003_oo]/400`00003ookK1oonf`@0;oonf`@;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0G@3oool00`000?l0oooo0?ooo`0]0?oo
o`KookK10_l00?lKoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0:0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool700000100oooo1`0000050?oo
o`030000003oool0oooo01`0oooo3`0000080?ooo`OookK10P00000<oonf`@0300000?oo]/7ookK1
00_ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`1M0?ooo`03
0000o`3oool0oooo02d0oooo1Ooo]/400ol00?oookK1oonf`@0Koonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool05`3oool@000000d0oooo00<000000?ooo`3oool0503oool7000000l0oooo100000040?ooo`Wo
okK100<00000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@0:oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0GP3oool00`000?l0oooo0?ooo`0/0?ooo`CookK1
00?o003ooonf`Ooo]/407?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
2`3oool00`000000oooo0?ooo`0D0?ooo`800000=03oool00`000000oooo0?ooo`0B0?ooo`03o`00
00000000oooo01T0oooo0P0000020?ooo`[ookK100?o0000oonf`Ooo]/402_oo]/400`00003ookK1
oonf`@09oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0GP3o
ool00`000?l0oooo0?ooo`0/0?ooo`?ookK100?o003ooonf`Ooo]/407Ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0303oool00ol00000oooo0?ooo`0E0?ooo`800000<`3o
ool00`000000oooo0?ooo`0?0?ooo`0300000?l00000oooo01d0oooo10000009oonf`@8000002ooo
]/400`00003o0000oonf`@08oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool0GP3oool00`000?l0oooo0?ooo`0/0?ooo`;ookK100?o003ooonf`Ooo]/407_oo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool03@3oool00`000000oooo0?ooo`0F
0?ooo`800000<@3oool00`000000oooo0?ooo`0<0?ooo`<000008P3oool2oonf`@0300000?oo]/7o
okK100SookK100<00000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@06oonf`@;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0G`3oool00`000?l0oooo0?ooo`0[0?oo
o`03oonf`Ol00?oookK1023ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool?000000P0oooo0ooo]/42000000WookK100?o0000oonf
`Ooo]/402_oo]/400`00003ookK1oonf`@05oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0G`3oool00`000?l0oooo0?ooo`0[0?ooo`03oonf`Ol00?oookK1023o
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00l0oooo00<000000?ooo`3o
ool05`3oool4000002X0oooo00<00000o`00003oool02P3oool00`00003o00000000000:0?ooo`D0
00003`3oool01000003o00000000000000040?ooo`GookK10P000008oonf`@0300000?oo]/7ookK1
00[ookK100<00000oonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo05l0oooo00<0003o0?ooo`3oool0:`3oool00ol00?oookK1oonf`@0Poonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0?0?ooo`030000003oool0oooo01/0
oooo0`00000W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00003o
00000?ooo`0G0?ooo`8000000P3oool7oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo
]/402_oo]/400`00003ookK1oonf`@04oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool0H03oool00`000?l0oooo0?ooo`0L0?ooo`_o003o0P3oool00ol00?oookK1
oonf`@0Qoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0@0?ooo`030000
003oool0oooo01d0oooo0`00000T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool3000001`0oooo0P000007oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/40
2_oo]/400`00003ookK1oonf`@03oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool0H03oool00`000?l0oooo0?ooo`0I0?ooo`?o003o2`3oool3o`00ob?ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0140oooo00?o00000?ooo`3oool07`3o
ool300000200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo3P0000090?ooo`03o`000?oo]/7ookK100GookK100<00000oonf`Ooo]/401_oo
]/400ol0003ookK1oonf`@0:oonf`@0300000?oo]/7ookK100;ookK10_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`1P0?ooo`030000o`3oool0oooo01H0oooo0ol00?l>
0?ooo`03o`00o`3oool0oooo00;o003o8Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`D000006`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00?o00000000003oool01P3oool4000000h0oooo10000005
0?ooo`03oonf`@000000000000KookK100?o000000000?oo]/401_oo]/400`00003ookK1oonf`@0:
oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool0H03oool00`000?l0oooo0?ooo`0D0?ooo`;o003o4@3oool00ol00?l0oooo0?ooo`02
oonf`@;o003o7ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04P3oool0
0`000000oooo0?ooo`0V0?ooo`<00000603oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool3000001H0oooo00<000000?ooo`3oool00P3oool3
oonf`@8000001_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100WookK100Co0000
oonf`Ooo]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`1P
0?ooo`030000o`3oool0oooo01<0oooo00?o003o0?ooo`3oool0403oool01?l00?l0oooo0?ooo`3o
ool4oonf`@03o`00oooo]/7ookK101cookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo01<0oooo00<000000?ooo`3oool0:03oool4000001<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603o
ool3000000030?oooooo]/7ookK100?ookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf
`@05oonf`@0300000?oo]/7ookK100WookK100<00000oonf`Ooo]/400_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`1P0?ooo`030000o`3oool0oooo00X0oooo2Ol00?lB
0?ooo`03o`00o`3oool0oooo0080oooo1Ooo]/400ol00?oookK1oonf`@0Koonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`0D0?ooo`800000;03oool00`00003o00000000000@
0?ooo`030000003oool0oooo00H0oooo00?o00000?ooo`3oool0103oool00ol0000000000?ooo`04
0?ooo`03o`0000000000oooo00L0oooo00<00000o`0000000000200000000ol00000oooo0?ooo`08
0?ooo`03o`000?oo]/7ookK100CookK100?o0000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@05
oonf`@0300000?oo]/7ookK100WookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool0
0ol0003ooooo0?ooo`0R0?ooockookK100<0003ooonf`Ooo]/401?oo]/46o`00o`OookK100Co003o
oonf`Ol00?oo003o3ooo]/400ol00?oookK1oonf`@09oonf`@03o`00oooo]/7ookK101[ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01H0oooo00<000000?ooo`3oool02@3o
oolSoonf`@0300000?oo]/7ookK100gookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf
`@04oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401Ooo]/43000000cookK10`00
0008oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf
`@05oonf`@0300000?oo]/7ookK100WookK100D00000oonf`Oooooooooooo`00000:ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?ooockookK100<0003ooonf`Ooo]/400ooo]/400ol00?oookK1oonf
`@0:oonf`@03o`00oooo]/7ookK100;ookK10_l00?l=oonf`@03o`00oooo]/7ookK100WookK100?o
003ooonf`Ooo]/406_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool05`3o
ool00`000000oooo0?ooo`080?ooobCookK100<00000oonf`Ooo]/403?oo]/400`00003ookK1oonf
`@05oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf
`@04oonf`@8000004_oo]/43000000KookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf
`@04oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/402Ooo]/401000003ooooooooo
ool0000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooockookK100@0003ooonf`Ooo]/7ookK1
0_l00?l=oonf`@03o`00oooo]/7ookK100CookK10_l00?l:oonf`@03o`00oooo]/7ookK100_ookK1
00?o003ooonf`Ooo]/406Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
603oool00ol00000oooo0?ooo`070?ooobCookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1
oonf`@06oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1
oonf`@03oonf`@8000005ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK1
00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100WookK1
00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool08P3oool8oonf`@<00000
=?oo]/400`000?oookK1o`00o`0>oonf`@03o`00oooo]/7ookK100OookK100?o003ooonf`Ooo]/40
1ooo]/400ol00?oookK1oonf`@0;oonf`@03o`00oooo]/7ookK101WookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo01P0oooo0P0000080?ooobGookK100<00000oonf`Ooo]/40
2_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/40
0ooo]/400ol0003ookK1oonf`@03oonf`@0300000?oo]/7ookK100SookK120000008oonf`@800000
1Ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/40
1Ooo]/400`00003ookK1oonf`@09oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?oo
ool0oooo0280oooo1ooo]/45000003?ookK100<0003oo`00oooo]/403_oo]/400ol00?oookK1oonf
`@08oonf`@03o`00oooo]/7ookK100KookK100?o003ooonf`Ooo]/403?oo]/400ol00?oookK1oonf
`@0Hoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0J0?ooo`030000003o
ool0oooo00D0oooo9Ooo]/400`00003ookK1oonf`@0:oonf`@03o`000?oo]/7ookK100CookK100?o
0000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<0
0000o`000?oo]/401ooo]/43000000SookK10`000007oonf`@0300000?oo]/7ookK100;ookK100<0
0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100GookK100<0
0000oonf`Ooo]/402Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo0280oooo1ooo]/45000003?ookK100<0003ooonf`Ooo]/403Ooo]/400ol00?oookK1oonf`@0:
oonf`@03o`00oooo]/7ookK100CookK100?o003ooonf`Ooo]/403_oo]/400ol00?oookK1oonf`@0G
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0K0?ooo`03o`00003oool0
oooo00@0oooo9_oo]/400`00003ookK1oonf`@09oonf`@0300000?oo]/7ookK100CookK100<00000
oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/401Ooo]/43000000kookK10P000006oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/400ooo]/400ol0003ookK1oonf`@03oonf`@0300000?oo]/7ookK100GookK100<00000
oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
0280oooo1ooo]/45000003;ookK100?o003o0000oooo]/403_oo]/400ol00?oookK1oonf`@0:oonf
`@03o`00oooo]/7ookK100CookK100?o003ooonf`Ooo]/403_oo]/400ol00?oookK1oonf`@0Goonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0L0?ooo`800000103ooolWoonf
`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@04oonf
`@8000004ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK100<00000oonf
`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100CookK100<00000oonf
`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280
oooo2?oo]/43000003;ookK100?o003ooonf`@000?l03_oo]/400ol00?oookK1oonf`@0<oonf`@03
o`00oooo]/7ookK100?ookK100?o003ooonf`Ooo]/403ooo]/400ol00?oookK1oonf`@0Foonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0N0?ooo`040000003oool0oooo0?oo
obOookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1
00?ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK1
00?ookK100?o0000oonf`Ooo]/404ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1
00;ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK1
00CookK100<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0280oooo??oo]/400ol00?oookK10000o`0?oonf`@03o`00oooo]/7ookK100go
okK100Go003ooonf`Ooo]/7ookK1o`00o`0Boonf`@03o`00oooo]/7ookK101KookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0oooo0P0000000`3ooooookK1oonf`@0Uoonf
`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf
`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100OookK11Ol00009oonf`@0300000?oo]/7ookK100CookK100<00000oonf
`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf
`Ooo]/401?oo]/400`00003ookK1oonf`@08oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool08P3ooolkoonf`@04o`00oooo]/7ookK10000o`kookK100?o003ooonf
`Ooo]/403ooo]/401?l00?oookK1oonf`Ol00?lCoonf`@03o`00oooo]/7ookK101GookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0240oooo00<00000oonf`Ooo]/409Ooo]/40
0`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/40
0`00003ookK1oonf`@05oonf`@?o00001Ooo]/43o`0000OookK100<00000oonf`Ooo]/400ooo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/40
0`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooc_ookK100Co003ooonf`Ooo]/40003o3_oo]/40
0ol00?oookK1oonf`@0?oonf`@04o`00oooo]/7ookK1o`00oa?ookK100?o003ooonf`Ooo]/405Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool2000002GookK100?o
0000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100?o
0000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<0
0000oonf`Ooo]/401Ooo]/400ol0003ookK1oonf`@09oonf`@03o`000?oo]/7ookK100GookK100<0
0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<0
0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100OookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooc[ookK100Go003o
oonf`Ooo]/7ookK10000o`0>oonf`@03o`00oooo]/7ookK100oookK100Co003ooonf`Ooo]/7o003o
4ooo]/400ol00?oookK1oonf`@0Eoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`0R0?ooo`;ookK10P00000Soonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/40
0ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0_oo]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100CookK100?o0000oonf`Ooo]/40
2ooo]/400ol0003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/40
0_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/40
1?oo]/400`00003ookK1oonf`@07oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool08P3oooljoonf`@05o`00oooo]/7ookK1oonf`@000?l03_oo]/400ol00?oookK1
oonf`@0@oonf`@<000004ooo]/400ol00?oookK1oonf`@0Eoonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`0R0?ooo`CookK10`00000Qoonf`@0300000?oo]/7ookK100KookK1
00<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK1
00?o0000oonf`Ooo]/403Ooo]/400ol0003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK1
00<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3oool08P3oooljoonf`@05o`00oooo]/7ookK1oonf`@000?l0
3_oo]/400ol00?oookK1oonf`@0?oonf`@D000004_oo]/400ol00?oookK1oonf`@0Eoonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0R0?ooo`OookK100?o0000oonf`Ooo]/40
7_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0_oo]/400`00003ookK1oonf`@03oonf`@03o`000?oo]/7ookK100oookK100?o0000oonf`Ooo]/40
0ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/40
1_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo>Ooo
]/400ol00?oookK1oonf`@02oonf`@030000oooo]/7ookK100cookK100?o003ooonf`Ooo]/403ooo
]/45000001;ookK100?o003ooonf`Ooo]/405Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3oool08P3oool7oonf`@<000007_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@03o`000?oo
]/7ookK100oookK100?o0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo
]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo0280oooo>Ooo]/400ol00?oookK1oonf`@02oonf`@030000oooo]/7o
okK100cookK100?o003ooonf`Ooo]/403ooo]/45000001;ookK100?o003ooonf`Ooo]/402ooo]/43
000000OookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0280oooo2_oo]/43
000001_ookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7o
okK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7o
okK100;ookK100<00000oonf`Ooo]/400ooo]/400ol0003ookK1oonf`@0?oonf`@03o`000?oo]/7o
okK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7o
okK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7o
okK100KookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oo
ocWookK100?o003ooonf`Ooo]/400_oo]/400`000?oookK1oonf`@0<oonf`@03o`00oooo]/7ookK1
013ookK10`00000Coonf`@03o`00oooo]/7ookK100[ookK11@000006oonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`0R0?ooo`gookK100<00000oonf`Ooo]/406?oo]/400`00
003ookK1oonf`@06oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00
003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/400`00003ookK1oonf`@03
oonf`@03o`000?oo]/7ookK1017ookK100?o0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo>Ooo]/401Ol00?oookK1oonf`Ooo]/40
003o00oookK100?o003ooonf`Ooo]/404Ooo]/42o`00oa?ookK100?o003ooonf`Ooo]/402_oo]/45
000000KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0280oooo3_oo]/40
0ol0000000000000000Goonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/400_oo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK10000
0004oonf`@0300000?oo]/7ookK100?ookK100?o0000oonf`Ooo]/404Ooo]/400ol0003ookK1oonf
`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf
`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf
`@06oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oooli
oonf`@05o`00oooo]/7ookK1oonf`@000?l03_oo]/43000001;ookK10_l00?lCoonf`@03o`00oooo
]/7ookK100[ookK11@000006oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`0R0?oooa7ookK100<00000oonf`Ooo]/405?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0500000?oo
]/7ookK1oonf`@0000001?oo]/400`00003ookK1oonf`@03oonf`@03o`000?oo]/7ookK1017ookK1
00?o0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0280oooo>Ooo]/401Ol00?oookK1oonf`Ooo]/40003o00gookK11@00000Aoonf`@;o003o
4ooo]/400ol00?oookK1oonf`@0;oonf`@<000001ooo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool08P3ooolBoonf`@0300000?oo]/7ookK101?ookK100<00000oonf`Ooo]/40
1_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0_oo]/401@00003ookK1oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/400ooo]/400ol0003o
okK1oonf`@0@oonf`@03o`000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@05oonf`@0300000?oo]/7ookK100KookK10_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?ooo`0R0?ooocWookK100Go003ooonf`Ooo]/7ookK10000o`0=oonf`@D0
00004Ooo]/42o`00oa?ookK100?o003ooonf`Ooo]/405Ooo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool08P3ooolCoonf`@0300000?oo]/7ookK101?ookK100<00000oonf`Ooo
]/401Ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo
]/400_oo]/401@00003ookK1oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/400ooo]/400ol0
003ookK1oonf`@0@oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00
003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400`00
003ookK1oonf`@04oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?ooo`0R0?ooocWookK100Co003ooonf`Ooo]/40003o3_oo]/450000
017ookK10_l00?lBoonf`@03o`00oooo]/7ookK101KookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo0280oooo5?oo]/42000001?ookK100<00000oonf`Ooo]/401Ooo]/400`00
003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/401@00
003ookK1oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/400ooo]/42o`00013ookK100?o0000
oonf`Ooo]/401?oo]/400ol0003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100CookK100<00000
oonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
0280oooo>Ooo]/401?l00?oookK1oonf`@000?l?oonf`@<000004ooo]/400ol00?oookK1oonf`@0@
oonf`@03o`00oooo]/7ookK101KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo0280oooo5_oo]/400`00003ookK1oonf`@0@oonf`@0300000?oo]/7ookK100GookK100<00000
oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100Go0000
oonf`Ooo]/7ookK100000004oonf`@0300000?oo]/7ookK100GookK100?o0000oonf`Ooo]/402ooo
]/42o`0000KookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo
]/7ookK100OookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R
0?ooocWookK100?o003ooonf`@000?l04ooo]/400ol00?oookK1oonf`@0@oonf`@03o`00oooo]/7o
okK100oookK100?o003ooonf`Ooo]/405ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool08P3ooolFoonf`@0300000?oo]/7ookK1017ookK100<00000oonf`Ooo]/401?oo]/40
0`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK10000
0004oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/401Ooo]/400ol0003ookK1oonf
`@09oonf`@03o`000?oo]/7ookK100KookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf
`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400ol0003ookK1oonf
`@04oonf`@0300000?oo]/7ookK100SookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?ooo`0R0?ooocWookK100?o003ooonf`@000?l04ooo]/400ol00?oookK1oonf`@0@
oonf`@03o`00oooo]/7ookK100oookK100?o003ooonf`Ooo]/405ooo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool08P3ooolGoonf`@0300000?oo]/7ookK1013ookK100<00000
oonf`Ooo]/401?oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000GookK100<00000oonf`Ooo]/401Ooo
]/42o`0000KookK10ol00008oonf`@0300000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/400ooo
]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401?oo
]/400`00003ookK1oonf`@08oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool08P3ooolioonf`@03o`00o`000?oookK101CookK100?o003ooonf`Ooo]/403_oo]/42
o`00oa3ookK100?o003ooonf`Ooo]/406?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool08P3ooolGoonf`@0300000?oo]/7ookK1013ookK100<00000oonf`Ooo]/401?oo]/40
0`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/40
1@00003ookK1oonf`Ooo]/40000000GookK100<00000oonf`Ooo]/401ooo]/46o`0000[ookK100<0
0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0500000?oo]/7ookK1oonf`@000000
1_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100SookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooc[ookK100<0003ooonf`Ooo]/404ooo
]/400ol00?oookK1oonf`@0>oonf`@03o`00oooo]/7o003o00oookK100?o003ooonf`Ooo]/406?oo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3ooolHoonf`@0300000?oo
]/7ookK100oookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo
]/7ookK100?ookK100D00000oonf`Ooo]/7ookK100000004oonf`@0300000?oo]/7ookK100?ookK1
00<00000oonf`Ooo]/405Ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0280oooo>_oo]/400`000?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK100kookK100?o
003ooonf`Ol00?l03_oo]/400ol00?oookK1oonf`@0Ioonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0R0?oooaWookK100?o0000oonf`Ooo]/403ooo]/400`00003ookK1oonf
`@04oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf
`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf
`@0Coonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf
`@02oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf
`@09oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oooli
oonf`@030000ool00?oookK101GookK10_l00?l=oonf`@04o`00oooo]/7ookK1o`00o`cookK10_l0
0?lLoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0R0?oooa[ookK100<0
0000oonf`Ooo]/403_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK100<0
0000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100?o
0000oonf`Ooo]/400ooo]/430000013ookK10P000005oonf`@8000001?oo]/400`00003ookK1oonf
`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf
`@09oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oooli
oonf`@030000ool00?oookK101OookK100?o003ooonf`Ooo]/402_oo]/401?l00?oookK1oonf`Ol0
0?l;oonf`@03o`00oooo]/7ookK101cookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo0280oooo6_oo]/400`00003ookK1oonf`@0>oonf`@0300000?oo]/7ookK100CookK100<0
0000oonf`Ooo]/401?oo]/401Ol0003ookK1oonf`Ooo]/40000000GookK100<00000oonf`Ooo]/40
0ooo]/400`00003ookK1oonf`@05oonf`@@000002Ooo]/43000000GookK10P000005oonf`@030000
0?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@05oonf`@030000
0?oo]/7ookK100WookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool08P3o
oolhoonf`@040000oooo]/7ookK1o`00oaSookK100?o003ooonf`Ooo]/402?oo]/400ol00?oookK1
oonf`@02oonf`@03o`00oooo]/7ookK100OookK100?o003ooonf`Ooo]/407Ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool08P3ooolKoonf`@0300000?oo]/7ookK100kookK1
00<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100SookK1
2@000007oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1
oonf`@03oonf`@03o`000?oo]/7ookK100GookK100<00000oonf`Ooo]/402_oo]/400`00003ooooo
o`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooocSookK100D0003ooonf`Ooo]/7ookK1
o`00o`0Hoonf`@03o`00oooo]/7ookK100OookK100?o003ooonf`Ooo]/400_oo]/400ol00?oookK1
oonf`@06oonf`@03o`00oooo]/7ookK101kookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo0280oooo7?oo]/400`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK1
00?o0000oonf`Ooo]/400ooo]/42000001KookK10P000006oonf`@03o`000?oo]/7ookK100?ookK1
00<00000o`000?oo]/401?oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100[ookK1
00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool08P3ooolhoonf`@050000
oooo]/7ookK1oonf`Ol00?l06Ooo]/42o`00o`KookK100?o003ooonf`Ooo]/400ooo]/400ol00?oo
okK1oonf`@05oonf`@03o`00oooo]/7ookK101oookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo0280oooo7?oo]/400`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100Go
okK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@03o`000?oo]/7ookK100?o
okK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@0Aoonf`@8000001ooo]/42000000Co
okK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Wo
okK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0000o`0R0?ooocOo
okK100<0003ooonf`Ooo]/400ooo]/400ol00?oookK1oonf`@0Hoonf`@?o003o0ooo]/400ol00?oo
okK1oonf`@04oonf`@03o`00oooo]/7ookK100;ookK10_l00?lRoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`0R0?oooagookK100<00000oonf`Ooo]/403Ooo]/400`00003o
okK1oonf`@05oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003o
okK1oonf`@03oonf`@0300000?oo]/7ookK100CookK10`00000=oonf`@<000001ooo]/42000000Go
okK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Wo
okK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0000o`0R0?ooocKookK100<0003ooonf`Ooo]/401Ooo]/400ol00?oookK1oonf`@0Joonf`@?o003o
1ooo]/400ol00?oookK1o`00o`02o`00obCookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo0280oooo7Ooo]/400`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK1
00<00000oonf`Ooo]/401_oo]/47000000?ookK10`000009oonf`@03o`000?oo]/7ookK100CookK1
00?o0000oonf`Ooo]/401?oo]/400ol0003ookK1oonf`@06oonf`@0300000?oo]/7ookK100WookK1
00Co0000oonf`Ooo]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool01?l0003ooooo
0?ooo`000?lQ0?ooocGookK100<0003ooonf`Ooo]/401ooo]/42o`00oa_ookK100?o003ooonf`Ol0
0?l02?l00?lWoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0R0?oooako
okK100<00000oonf`Ooo]/403Ooo]/400`00003ookK1oonf`@05oonf`@03o`000?oo]/7ookK100?o
okK100<00000o`000?oo]/401?oo]/400`00003ookK1oonf`@03oonf`@@000002ooo]/43000000[o
okK10P000006oonf`@8000001Ooo]/42000000OookK100?o0000oonf`Ooo]/402_oo]/401000003o
okK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooool0oooo0?oo
o`000?l0E03oool00`000?l0oooo0?ooo`0:0?ooo`03o`00o`3oool0oooo01H0oooo0_l00?l;0?oo
o`04o`00o`3oool0oooo0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo0400oooo00<000000?ooo`3oool03@3oool00ol00000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00ol0000000000?ooo`060?ooo`030000003oool0
oooo0180oooo0`0000060?ooo`03oonf`@00003ookK100GookK100<00000oonf`Ooo]/401_oo]/40
0`00003ookK1oonf`@0:oonf`@0300000?oo]/7ookK100;ookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`020?ooo`030000o`3oool0oooo0500oooo00<0003o0?oo
o`3oool0303oool00ol00?l0oooo0?ooo`0C0?ooo`;o003o3P3oool00ol00?l0oooo0?ooo`0Soonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`110?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool3000000d0oooo100000080?ooo`8000001_oo]/400ol0
003ookK1oonf`@06oonf`@0300000?oo]/7ookK100[ookK100<00000oonf`Ooo]/400ooo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0080oooo00<0003o0?ooo`3o
ool0D03oool00`000?l0oooo0?ooo`0=0?ooo`;o003o4P3oool00ol00?l0oooo0?ooo`0>0?ooo`03
o`00o`3oool0oooo02?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0480
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo0P0000050?ooo`800000203oool400000003o`0000000000000000@0000000?o00000000003o
ool02@3oool00ol0000000000?ooo`05oonf`@8000002?oo]/400ol0003ookK1oonf`@0:oonf`@03
00000?oo]/7ookK100CookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`030?ooo`030000o`3oool0oooo04h0oooo00<0003o0?ooo`3oool0403oool3o`00o``0oooo
0ol00?lB0?ooo`03o`00o`3ooooookK102;ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo0480oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`03o`00
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool2000001/0oooo0P0000030?ooo`CookK1
00<00000oonf`Ooo]/401_oo]/42000000cookK100<00000oonf`Ooo]/401Ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00@0oooo00<0003o0?ooo`3oool0C@3o
ool00`000?l0oooo0?ooo`0C0?ooo`Co003o0`3oool5o`00oaH0oooo00?o003ooonf`Ooo]/408Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0@`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`<00000503oool4000000D0oooo0_oo]/42000000SookK100<00000oonf`Ooo]/402ooo
]/400`00003ookK1oonf`@06oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool01@3oool00`000?l0oooo0?ooo`1:0?ooo`80003o6P3oool3o`00oa`0oooo00?o003o
oonf`Ooo]/408?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0A03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`<000003P3oool3000000T0oooo00?ookK100000?oo]/402?oo]/40
0`00003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`060?ooo`030000o`3oool0oooo04P0oooo00<0003o0?oo
o`3oool0>@3oool00ooo]/7o003ooonf`@0Poonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`150?ooo`03o`00003oool0oooo00d0oooo00?o00000?ooo`3oool01P3oool00`00
003o00000?ooo`060?ooo`03o`0000000000oooo00T0oooo00<00000o`00000000002@0000000ol0
000000000?ooo`090?ooo`<000002?oo]/42000000gookK100<00000oonf`Ooo]/402?oo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00L0oooo00<0003o0?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`0j0?ooo`03oonf`Ol00?oookK1023ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo04H0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`00000L0?ooo`<000000P3oool8oonf`@03
00000?oo]/7ookK100cookK100<00000oonf`Ooo]/402Ooo]/42ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo00P0oooo00<0003o0?ooo`3oool0A03oool00`000?l0oooo
0?ooo`0k0?ooo`;ookK10_l00?lOoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`170?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`@000005`3oool00`000000oooo0?ooo`030?ooo`KookK10P00000>oonf`@030000
0?oo]/7ookK100[ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`090?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3oool0?03oool4oonf`@;o003o7Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0B03oool00`000000oooo0?oo
o`0=0?ooo`03o`0000000000oooo00L0oooo00<00000o`00000000002`3oool3000000d0oooo0`00
00001?l0000000000000000000060?ooo`CookK10P00000=oonf`@80000000?o0000oonf`Ooo]/40
2ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00X0oooo00<0
003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`0m0?ooo`KookK100?o003ooonf`Ooo]/406_oo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0B03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool=000000d0oooo0_oo
]/42000000kookK100<00000oonf`Ooo]/403_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo00/0oooo0P000?ln0?ooo`80003o@03oool7oonf`@;o003o6_oo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0B@3oool200000100oooo00<00000
0?ooo`3oool0203oool3000002<0oooo0`00000>oonf`@8000004Ooo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo00d0oooo0P000?lk0?ooo`030000o`3oool0oooo
0400oooo2Ooo]/42o`00oaSookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
04/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`8000007`3oool20000
00030?oooooo]/7ookK100gookK100<00000oonf`Ooo]/404Ooo]/42ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0oooo00l0oooo0P000?lg0?ooo`80003o@`3oool;oonf`@03
o`00oooo]/7ookK101GookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo04`0
oooo00?o00000?ooo`3oool03P3oool2000000`0oooo1@00000H0?ooo`8000000`3oool=oonf`@80
00005?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0140oooo
00<0003o0?ooo`3oool0<P3oool20000odD0oooo3?oo]/43o`00oaCookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo04d0oooo0P00000@0?ooo`8000003`3oool3000000d0oooo
200000050?ooo`_ookK10P00000Foonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool04P3oool20000oc00oooo0P000?m70?ooo`oookK11Ol00?l?oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`1?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool=000000d0oooo2Ooo]/42000001SookK10_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`0D0?ooo`80003o;03oool20000odT0oooo5?oo]/45
o`00o`?ookK12?l00?l00ooooooo0000ooooo`0@ooooo`03o`000?ooool0oooo0500oooo00?o0000
0?ooo`3oool03`3oool01000003o000000000000000W0?ooo`GookK10P0000000ol000000000oonf
`@0Ioonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool05P3oool2
0000obT0oooo00<0003o0?ooo`3oool0B@3ooolIoonf`@?o003o1ooo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool0D03oool2000001@0oooo0P00000U0?ooo`;ookK10`00000N
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0603oool30000
ob<0oooo0`000?m<0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
0580oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0P0?ooo`@000008Ooo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01/0oooo0`000?lM0?ooo`<0
003oC`3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo0`00000L0?ooo`<000000P3ooolSoonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool07P3oool50000oaD0oooo0`000?mB0?ooob?ookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo05@0oooo00?o00000000003oool0
5@3oool200000003o`00000000000000008000004@3oool4000000D0oooo8ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo02<0oooo1@000?l80?ooo`P0003oE@3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`1F0?ooo`030000003o
ool0oooo01X0oooo4@0000090?ooob7ookK10`0000000ooooooo0000ooooo`09ooooo`002Oooool0
0ol0003ooooo0?ooo`0X0?ooo`P0003oG@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`1G0?ooo`<00000<`3ooolNoonf`@<000000_oo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0FP3oool00`00003o00000?ooo`0`0?oooa[ookK110000005oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`1K0?ooo`<00000;`3ooolGoonf`@<0
00002Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo
8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0GP3oool4000002/0oooo
4ooo]/44000000cookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0680oooo0P00
000Y0?oooa3ookK10`00000@oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`1T
0?ooo`8000009`3oool<oonf`@@000004ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0IP3oool3000002@0oooo1Ooo]/47000001OookK10_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo06T0oooo1`00000M0?ooo`;ookK10`00000Noonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`1`0?ooo`X000001`3oool>0000027ookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo07X0oooo00?o00000000000000001000000<0?ooob?ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Ooooonfo`00017ooooo]_l0000:ooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AntiPolygonalAllPlot[poly, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.80269 .98077 m
.78846 .96922 L
.78115 .96154 L
.76923 .94723 L
.76598 .94231 L
.75471 .92308 L
.75 .91365 L
.74628 .90385 L
.73929 .88462 L
.73217 .86538 L
.73077 .86193 L
.72437 .84615 L
.71154 .82823 L
.71107 .82692 L
.69231 .81368 L
.67308 .81003 L
.65385 .81414 L
.63462 .82224 L
.62412 .82692 L
.61538 .83063 L
.59615 .83778 L
.57692 .84328 L
.56343 .84615 L
.55769 .84649 L
.53846 .84728 L
.51923 .84616 L
.51916 .84615 L
.5 .84248 L
.48077 .83686 L
.46154 .83039 L
.45231 .82692 L
.44231 .82471 L
.42308 .82197 L
.40385 .82363 L
.386 .82692 L
.38462 .82776 L
.36538 .83159 L
.34615 .83437 L
.32692 .83522 L
.30769 .83375 L
.28846 .82992 L
.27768 .82692 L
.26923 .82324 L
.25 .81282 L
.24213 .80769 L
.23077 .79829 L
.22093 .78846 L
.21154 .77714 L
.20638 .76923 L
.19594 .75 L
.19231 .7417 L
.18928 .73077 L
.1855 .71154 L
.18419 .69231 L
.18545 .67308 L
.18919 .65385 L
.19231 .64255 L
.19578 .63462 L
.20616 .61538 L
.21154 .60712 L
.22061 .59615 L
.23077 .58597 L
.24164 .57692 L
.25 .57145 L
.26923 .561 L
.27671 .55769 L
.28846 .55439 L
.30769 .55054 L
.32692 .54906 L
.34615 .54993 L
.36538 .55276 L
.38462 .55668 L
.38714 .55769 L
.40385 .56096 L
.42308 .56292 L
.44231 .56049 L
.45517 .55769 L
.46154 .55497 L
.48077 .54862 L
.5 .5429 L
.51923 .53894 L
.52264 .53846 L
.53846 .53753 L
.55769 .53767 L
.57189 .53846 L
.57692 .53907 L
.59615 .54191 L
.61538 .54419 L
.63462 .5429 L
.64559 .53846 L
.65385 .53364 L
.66497 .51923 L
.67209 .5 L
.67212 .48077 L
.66302 .46154 L
.65385 .45332 L
.63462 .44715 L
.61538 .44603 L
.59615 .44564 L
.57692 .44467 L
.55769 .44301 L
.54942 .44231 L
.53846 .44 L
.51923 .43581 L
.5 .43222 L
.48077 .42962 L
.46154 .42748 L
.44231 .42511 L
.42771 .42308 L
.42308 .42202 L
.40385 .41767 L
.38462 .4155 L
.36538 .41777 L
.34644 .42308 L
.34615 .42325 L
.32692 .42715 L
.30769 .43023 L
.28846 .43083 L
.26923 .42847 L
.25 .42383 L
.24716 .42308 L
.23077 .41406 L
.2158 .40385 L
.21154 .39999 L
.19785 .38462 L
.19231 .37706 L
.1866 .36538 L
.17884 .34615 L
.17446 .32692 L
.17363 .30769 L
.17633 .28846 L
.18259 .26923 L
.19153 .25 L
.19231 .24848 L
.20652 .23077 L
.21154 .22581 L
.22967 .21154 L
.23077 .211 L
.25 .2023 L
.26923 .19614 L
.28846 .19335 L
.30769 .19365 L
.32692 .19633 L
.34615 .19979 L
.36538 .20122 L
.38462 .19839 L
.40385 .19244 L
.40424 .19231 L
.42308 .18774 L
.44231 .18383 L
.46154 .18141 L
.48077 .18008 L
.5 .17892 L
.51923 .17712 L
.53846 .17467 L
.55003 .17308 L
.55769 .17258 L
.57692 .17173 L
.59615 .17225 L
.60547 .17308 L
.61538 .17472 L
.63462 .17928 L
.65385 .18476 L
.67308 .18942 L
.69231 .1907 L
.71154 .18577 L
.73076 .17308 L
.73077 .17307 L
.74633 .15385 L
.75 .14435 L
.75289 .13462 L
.75661 .11538 L
.76 .09615 L
.7645 .07692 L
.76923 .06114 L
.77081 .05769 L
.78135 .03846 L
.78846 .02781 L
.79607 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.80269 .98077 m
.78846 .96922 L
.78115 .96154 L
.76923 .94723 L
.76598 .94231 L
.75471 .92308 L
.75 .91365 L
.74628 .90385 L
.73929 .88462 L
.73217 .86538 L
.73077 .86193 L
.72437 .84615 L
.71154 .82823 L
.71107 .82692 L
.69231 .81368 L
.67308 .81003 L
.65385 .81414 L
.63462 .82224 L
.62412 .82692 L
.61538 .83063 L
.59615 .83778 L
.57692 .84328 L
.56343 .84615 L
.55769 .84649 L
.53846 .84728 L
.51923 .84616 L
.51916 .84615 L
.5 .84248 L
.48077 .83686 L
.46154 .83039 L
.45231 .82692 L
.44231 .82471 L
.42308 .82197 L
.40385 .82363 L
.386 .82692 L
.38462 .82776 L
.36538 .83159 L
.34615 .83437 L
.32692 .83522 L
.30769 .83375 L
.28846 .82992 L
.27768 .82692 L
.26923 .82324 L
.25 .81282 L
.24213 .80769 L
.23077 .79829 L
.22093 .78846 L
.21154 .77714 L
.20638 .76923 L
.19594 .75 L
Mistroke
.19231 .7417 L
.18928 .73077 L
.1855 .71154 L
.18419 .69231 L
.18545 .67308 L
.18919 .65385 L
.19231 .64255 L
.19578 .63462 L
.20616 .61538 L
.21154 .60712 L
.22061 .59615 L
.23077 .58597 L
.24164 .57692 L
.25 .57145 L
.26923 .561 L
.27671 .55769 L
.28846 .55439 L
.30769 .55054 L
.32692 .54906 L
.34615 .54993 L
.36538 .55276 L
.38462 .55668 L
.38714 .55769 L
.40385 .56096 L
.42308 .56292 L
.44231 .56049 L
.45517 .55769 L
.46154 .55497 L
.48077 .54862 L
.5 .5429 L
.51923 .53894 L
.52264 .53846 L
.53846 .53753 L
.55769 .53767 L
.57189 .53846 L
.57692 .53907 L
.59615 .54191 L
.61538 .54419 L
.63462 .5429 L
.64559 .53846 L
.65385 .53364 L
.66497 .51923 L
.67209 .5 L
.67212 .48077 L
.66302 .46154 L
.65385 .45332 L
.63462 .44715 L
.61538 .44603 L
.59615 .44564 L
.57692 .44467 L
Mistroke
.55769 .44301 L
.54942 .44231 L
.53846 .44 L
.51923 .43581 L
.5 .43222 L
.48077 .42962 L
.46154 .42748 L
.44231 .42511 L
.42771 .42308 L
.42308 .42202 L
.40385 .41767 L
.38462 .4155 L
.36538 .41777 L
.34644 .42308 L
.34615 .42325 L
.32692 .42715 L
.30769 .43023 L
.28846 .43083 L
.26923 .42847 L
.25 .42383 L
.24716 .42308 L
.23077 .41406 L
.2158 .40385 L
.21154 .39999 L
.19785 .38462 L
.19231 .37706 L
.1866 .36538 L
.17884 .34615 L
.17446 .32692 L
.17363 .30769 L
.17633 .28846 L
.18259 .26923 L
.19153 .25 L
.19231 .24848 L
.20652 .23077 L
.21154 .22581 L
.22967 .21154 L
.23077 .211 L
.25 .2023 L
.26923 .19614 L
.28846 .19335 L
.30769 .19365 L
.32692 .19633 L
.34615 .19979 L
.36538 .20122 L
.38462 .19839 L
.40385 .19244 L
.40424 .19231 L
.42308 .18774 L
.44231 .18383 L
Mistroke
.46154 .18141 L
.48077 .18008 L
.5 .17892 L
.51923 .17712 L
.53846 .17467 L
.55003 .17308 L
.55769 .17258 L
.57692 .17173 L
.59615 .17225 L
.60547 .17308 L
.61538 .17472 L
.63462 .17928 L
.65385 .18476 L
.67308 .18942 L
.69231 .1907 L
.71154 .18577 L
.73076 .17308 L
.73077 .17307 L
.74633 .15385 L
.75 .14435 L
.75289 .13462 L
.75661 .11538 L
.76 .09615 L
.7645 .07692 L
.76923 .06114 L
.77081 .05769 L
.78135 .03846 L
.78846 .02781 L
.79607 .01923 L
Mfstroke
.2 g
.98077 .92749 m
.96969 .94231 L
.96154 .95055 L
.94771 .96154 L
.94231 .96498 L
.92308 .97407 L
.90385 .97901 L
.88462 .9805 L
.86538 .9788 L
.84615 .97364 L
.82692 .96433 L
.82255 .96154 L
.80769 .94978 L
.80029 .94231 L
.78846 .92716 L
.78596 .92308 L
.77628 .90385 L
.76939 .88462 L
.76923 .88409 L
.76487 .86538 L
.76094 .84615 L
.75604 .82692 L
.75 .8119 L
.7479 .80769 L
.73384 .78846 L
.73077 .78527 L
.71231 .76923 L
.71154 .76876 L
.69231 .75926 L
.67308 .76039 L
.65661 .76923 L
.65385 .77109 L
.63462 .78494 L
.62942 .78846 L
.61538 .79741 L
.59615 .80735 L
.59542 .80769 L
.57692 .81399 L
.55769 .81794 L
.53846 .81913 L
.51923 .81756 L
.5 .81337 L
.48259 .80769 L
.48077 .80695 L
.46154 .79877 L
.44231 .79185 L
.42308 .7895 L
.40385 .79252 L
.38462 .79835 L
.36538 .80405 L
.34816 .80769 L
.34615 .80784 L
.32692 .80885 L
.3112 .80769 L
.30769 .80713 L
.28846 .80196 L
.26923 .79316 L
.26145 .78846 L
.25 .77948 L
.23974 .76923 L
.23077 .75782 L
.22604 .75 L
.21724 .73077 L
.21214 .71154 L
.21154 .70762 L
.21058 .69231 L
.21154 .67663 L
.21208 .67308 L
.21712 .65385 L
.22584 .63462 L
.23077 .62644 L
.23943 .61538 L
.25 .60478 L
.26093 .59615 L
.26923 .5911 L
.28846 .58229 L
.30769 .57712 L
.30885 .57692 L
.32692 .57544 L
.34615 .57647 L
.35179 .57692 L
.36538 .58026 L
.38462 .58606 L
.40385 .59206 L
.42308 .59534 L
.44231 .5933 L
.46154 .58662 L
.48077 .57855 L
.48483 .57692 L
.5 .5721 L
.51923 .56783 L
.53846 .56604 L
.55769 .56679 L
.57692 .5699 L
.59615 .575 L
.60179 .57692 L
.61538 .58174 L
.63462 .58851 L
.65385 .59158 L
.67308 .5845 L
.68264 .57692 L
.69231 .56384 L
.69685 .55769 L
.70959 .53846 L
.71154 .53575 L
.72023 .51923 L
.7265 .5 L
.7264 .48077 L
.72033 .46154 L
.71154 .44431 L
.71009 .44231 L
.69576 .42308 L
.69231 .41997 L
.67308 .40974 L
.65385 .40953 L
.63462 .41287 L
.61538 .41635 L
.59615 .41844 L
.57692 .41854 L
.55769 .41669 L
.53846 .41351 L
.51923 .41015 L
.5 .40764 L
.48077 .40603 L
.46154 .40451 L
.45496 .40385 L
.44231 .40178 L
.42308 .39738 L
.40385 .39249 L
.38462 .39011 L
.36538 .39301 L
.34615 .39982 L
.33537 .40385 L
.32692 .40606 L
.30769 .40969 L
.28846 .41037 L
.26923 .40763 L
.255 .40385 L
.25 .40105 L
.23077 .38869 L
.22597 .38462 L
.21154 .36791 L
.21003 .36538 L
.20088 .34615 L
.19584 .32692 L
.19489 .30769 L
.19799 .28846 L
.20523 .26923 L
.21154 .25759 L
.21743 .25 L
.23077 .2368 L
.23871 .23077 L
.25 .22482 L
.26923 .21772 L
.28846 .21456 L
.30769 .21501 L
.32692 .21838 L
.34615 .22307 L
.36538 .22608 L
.38462 .22427 L
.40385 .21811 L
.42254 .21154 L
.42308 .2114 L
.44231 .20714 L
.46154 .20478 L
.48077 .20388 L
.5 .20342 L
.51923 .20235 L
.53846 .2004 L
.55769 .19837 L
.57692 .19748 L
.59615 .19864 L
.61538 .20229 L
.63462 .20839 L
.64239 .21154 L
.65385 .21687 L
.67308 .22634 L
.684 .23077 L
.69231 .23312 L
.71154 .23242 L
.71647 .23077 L
.73077 .22356 L
.74837 .21154 L
.75 .21025 L
.76923 .19365 L
.77042 .19231 L
.78203 .17308 L
.78493 .15385 L
.78477 .13462 L
.78474 .11538 L
.78639 .09615 L
.78846 .08206 L
.79078 .07692 L
.79915 .05769 L
.80769 .04423 L
.81254 .03846 L
.82692 .02521 L
.83565 .01923 L
.98077 .01923 L
F
0 g
.98077 .92749 m
.96969 .94231 L
.96154 .95055 L
.94771 .96154 L
.94231 .96498 L
.92308 .97407 L
.90385 .97901 L
.88462 .9805 L
.86538 .9788 L
.84615 .97364 L
.82692 .96433 L
.82255 .96154 L
.80769 .94978 L
.80029 .94231 L
.78846 .92716 L
.78596 .92308 L
.77628 .90385 L
.76939 .88462 L
.76923 .88409 L
.76487 .86538 L
.76094 .84615 L
.75604 .82692 L
.75 .8119 L
.7479 .80769 L
.73384 .78846 L
.73077 .78527 L
.71231 .76923 L
.71154 .76876 L
.69231 .75926 L
.67308 .76039 L
.65661 .76923 L
.65385 .77109 L
.63462 .78494 L
.62942 .78846 L
.61538 .79741 L
.59615 .80735 L
.59542 .80769 L
.57692 .81399 L
.55769 .81794 L
.53846 .81913 L
.51923 .81756 L
.5 .81337 L
.48259 .80769 L
.48077 .80695 L
.46154 .79877 L
.44231 .79185 L
.42308 .7895 L
.40385 .79252 L
.38462 .79835 L
.36538 .80405 L
Mistroke
.34816 .80769 L
.34615 .80784 L
.32692 .80885 L
.3112 .80769 L
.30769 .80713 L
.28846 .80196 L
.26923 .79316 L
.26145 .78846 L
.25 .77948 L
.23974 .76923 L
.23077 .75782 L
.22604 .75 L
.21724 .73077 L
.21214 .71154 L
.21154 .70762 L
.21058 .69231 L
.21154 .67663 L
.21208 .67308 L
.21712 .65385 L
.22584 .63462 L
.23077 .62644 L
.23943 .61538 L
.25 .60478 L
.26093 .59615 L
.26923 .5911 L
.28846 .58229 L
.30769 .57712 L
.30885 .57692 L
.32692 .57544 L
.34615 .57647 L
.35179 .57692 L
.36538 .58026 L
.38462 .58606 L
.40385 .59206 L
.42308 .59534 L
.44231 .5933 L
.46154 .58662 L
.48077 .57855 L
.48483 .57692 L
.5 .5721 L
.51923 .56783 L
.53846 .56604 L
.55769 .56679 L
.57692 .5699 L
.59615 .575 L
.60179 .57692 L
.61538 .58174 L
.63462 .58851 L
.65385 .59158 L
.67308 .5845 L
Mistroke
.68264 .57692 L
.69231 .56384 L
.69685 .55769 L
.70959 .53846 L
.71154 .53575 L
.72023 .51923 L
.7265 .5 L
.7264 .48077 L
.72033 .46154 L
.71154 .44431 L
.71009 .44231 L
.69576 .42308 L
.69231 .41997 L
.67308 .40974 L
.65385 .40953 L
.63462 .41287 L
.61538 .41635 L
.59615 .41844 L
.57692 .41854 L
.55769 .41669 L
.53846 .41351 L
.51923 .41015 L
.5 .40764 L
.48077 .40603 L
.46154 .40451 L
.45496 .40385 L
.44231 .40178 L
.42308 .39738 L
.40385 .39249 L
.38462 .39011 L
.36538 .39301 L
.34615 .39982 L
.33537 .40385 L
.32692 .40606 L
.30769 .40969 L
.28846 .41037 L
.26923 .40763 L
.255 .40385 L
.25 .40105 L
.23077 .38869 L
.22597 .38462 L
.21154 .36791 L
.21003 .36538 L
.20088 .34615 L
.19584 .32692 L
.19489 .30769 L
.19799 .28846 L
.20523 .26923 L
.21154 .25759 L
.21743 .25 L
Mistroke
.23077 .2368 L
.23871 .23077 L
.25 .22482 L
.26923 .21772 L
.28846 .21456 L
.30769 .21501 L
.32692 .21838 L
.34615 .22307 L
.36538 .22608 L
.38462 .22427 L
.40385 .21811 L
.42254 .21154 L
.42308 .2114 L
.44231 .20714 L
.46154 .20478 L
.48077 .20388 L
.5 .20342 L
.51923 .20235 L
.53846 .2004 L
.55769 .19837 L
.57692 .19748 L
.59615 .19864 L
.61538 .20229 L
.63462 .20839 L
.64239 .21154 L
.65385 .21687 L
.67308 .22634 L
.684 .23077 L
.69231 .23312 L
.71154 .23242 L
.71647 .23077 L
.73077 .22356 L
.74837 .21154 L
.75 .21025 L
.76923 .19365 L
.77042 .19231 L
.78203 .17308 L
.78493 .15385 L
.78477 .13462 L
.78474 .11538 L
.78639 .09615 L
.78846 .08206 L
.79078 .07692 L
.79915 .05769 L
.80769 .04423 L
.81254 .03846 L
.82692 .02521 L
.83565 .01923 L
Mfstroke
.3 g
.98077 .8757 m
.97937 .88462 L
.97343 .90385 L
.96264 .92308 L
.96154 .92458 L
.94433 .94231 L
.94231 .94384 L
.92308 .95499 L
.90385 .96109 L
.90144 .96154 L
.88462 .96297 L
.86897 .96154 L
.86538 .96085 L
.84615 .95452 L
.82692 .94318 L
.82577 .94231 L
.80769 .92401 L
.807 .92308 L
.79552 .90385 L
.78846 .88551 L
.78822 .88462 L
.78406 .86538 L
.78165 .84615 L
.77975 .82692 L
.77635 .80769 L
.76923 .78972 L
.7685 .78846 L
.75418 .76923 L
.75 .76467 L
.73579 .75 L
.73077 .74508 L
.71727 .73077 L
.71154 .72599 L
.69404 .71154 L
.69231 .71087 L
.67543 .71154 L
.67308 .71344 L
.65748 .73077 L
.65385 .7354 L
.64061 .75 L
.63462 .75749 L
.62193 .76923 L
.61538 .77464 L
.59615 .7871 L
.59367 .78846 L
.57692 .7953 L
.55769 .80001 L
.53846 .80142 L
.51923 .79963 L
.5 .79472 L
.48382 .78846 L
.48077 .78701 L
.46154 .77731 L
.44293 .76923 L
.44231 .76903 L
.42308 .76667 L
.41029 .76923 L
.40385 .77131 L
.38462 .77897 L
.36538 .78597 L
.36037 .78846 L
.34615 .79038 L
.32692 .79165 L
.30769 .78962 L
.30074 .78846 L
.28846 .78363 L
.26923 .77285 L
.26441 .76923 L
.25 .75484 L
.24636 .75 L
.2356 .73077 L
.23077 .71881 L
.22967 .71154 L
.22782 .69231 L
.2296 .67308 L
.23077 .66518 L
.23544 .65385 L
.24611 .63462 L
.25 .62942 L
.26397 .61538 L
.26923 .61141 L
.28846 .60063 L
.2991 .59615 L
.30769 .59466 L
.32692 .59262 L
.34615 .59392 L
.36151 .59615 L
.36538 .59834 L
.38462 .60543 L
.40385 .61326 L
.4102 .61538 L
.42308 .61816 L
.44231 .61612 L
.44456 .61538 L
.46154 .60807 L
.48077 .59849 L
.48578 .59615 L
.5 .59077 L
.51923 .58581 L
.53846 .58385 L
.55769 .58492 L
.57692 .58897 L
.59615 .5959 L
.59672 .59615 L
.61538 .60595 L
.62947 .61538 L
.63462 .61851 L
.65385 .63205 L
.65802 .63462 L
.67308 .63774 L
.6815 .63462 L
.69231 .62045 L
.69619 .61538 L
.70723 .59615 L
.71154 .5883 L
.71875 .57692 L
.73077 .55931 L
.73194 .55769 L
.7464 .53846 L
.75 .5346 L
.75986 .51923 L
.76774 .5 L
.76603 .48077 L
.75663 .46154 L
.75 .45033 L
.74418 .44231 L
.73138 .42308 L
.73077 .42215 L
.71904 .40385 L
.71154 .39373 L
.70371 .38462 L
.69231 .37687 L
.67308 .37696 L
.65385 .38427 L
.65289 .38462 L
.63462 .39193 L
.61538 .3978 L
.59615 .40115 L
.57692 .40184 L
.55769 .4002 L
.53846 .3971 L
.51923 .39394 L
.5 .3918 L
.48077 .39057 L
.46154 .38914 L
.44231 .38636 L
.43376 .38462 L
.42308 .38155 L
.40385 .37569 L
.38462 .37268 L
.36538 .37638 L
.3462 .38462 L
.34615 .38467 L
.32692 .39203 L
.30769 .39666 L
.28846 .39749 L
.26923 .39407 L
.25 .38601 L
.24752 .38462 L
.23077 .37068 L
.2263 .36538 L
.21484 .34615 L
.21154 .33727 L
.20932 .32692 L
.20836 .30769 L
.21147 .28846 L
.21154 .28816 L
.22011 .26923 L
.23077 .2548 L
.23562 .25 L
.25 .23963 L
.26923 .23114 L
.27049 .23077 L
.28846 .22795 L
.30769 .22846 L
.32155 .23077 L
.32692 .23217 L
.34615 .23825 L
.36538 .24298 L
.38462 .2419 L
.40385 .23506 L
.41432 .23077 L
.42308 .22756 L
.44231 .22233 L
.46154 .21967 L
.48077 .21896 L
.5 .21894 L
.51923 .2183 L
.53846 .21658 L
.55769 .21463 L
.57692 .21386 L
.59615 .21541 L
.61538 .21996 L
.63462 .22783 L
.64012 .23077 L
.65385 .23935 L
.66753 .25 L
.67308 .25373 L
.69231 .2668 L
.71154 .26877 L
.73077 .25806 L
.742 .25 L
.75 .24299 L
.76592 .23077 L
.76923 .22835 L
.78846 .21432 L
.79184 .21154 L
.80769 .19388 L
.80845 .19231 L
.81093 .17308 L
.80769 .15446 L
.80757 .15385 L
.80399 .13462 L
.80228 .11538 L
.80347 .09615 L
.80769 .07863 L
.80831 .07692 L
.81839 .05769 L
.82692 .04715 L
.83661 .03846 L
.84615 .0324 L
.86538 .02468 L
.88462 .02209 L
.90385 .02416 L
.92308 .03128 L
.93471 .03846 L
.94231 .04515 L
.9527 .05769 L
.96154 .07418 L
.96243 .07692 L
.96682 .09615 L
.96685 .11538 L
.96292 .13462 L
.96154 .13919 L
.95523 .15385 L
.94444 .17308 L
.94231 .17659 L
.93313 .19231 L
.92776 .21154 L
.93324 .23077 L
.94231 .24732 L
.94486 .25 L
.9567 .26923 L
.96154 .27826 L
.96615 .28846 L
.97262 .30769 L
.97616 .32692 L
.97695 .34615 L
.97508 .36538 L
.97052 .38462 L
.96319 .40385 L
.96154 .40741 L
.95312 .42308 L
.94231 .43986 L
.94064 .44231 L
.92687 .46154 L
.92308 .46409 L
.91503 .48077 L
.91006 .5 L
.91466 .51923 L
.92308 .53693 L
.92553 .53846 L
.938 .55769 L
.94231 .56472 L
.94924 .57692 L
.95819 .59615 L
.96154 .60493 L
.96453 .61538 L
.96824 .63462 L
.9694 .65385 L
.96816 .67308 L
.9648 .69231 L
.96154 .70596 L
.9601 .71154 L
.95565 .73077 L
.9539 .75 L
.95662 .76923 L
.96154 .78727 L
.96298 .78846 L
.97037 .80769 L
.97658 .82692 L
.98047 .84615 L
.98077 .84868 L
F
0 g
.98077 .8757 m
.97937 .88462 L
.97343 .90385 L
.96264 .92308 L
.96154 .92458 L
.94433 .94231 L
.94231 .94384 L
.92308 .95499 L
.90385 .96109 L
.90144 .96154 L
.88462 .96297 L
.86897 .96154 L
.86538 .96085 L
.84615 .95452 L
.82692 .94318 L
.82577 .94231 L
.80769 .92401 L
.807 .92308 L
.79552 .90385 L
.78846 .88551 L
.78822 .88462 L
.78406 .86538 L
.78165 .84615 L
.77975 .82692 L
.77635 .80769 L
.76923 .78972 L
.7685 .78846 L
.75418 .76923 L
.75 .76467 L
.73579 .75 L
.73077 .74508 L
.71727 .73077 L
.71154 .72599 L
.69404 .71154 L
.69231 .71087 L
.67543 .71154 L
.67308 .71344 L
.65748 .73077 L
.65385 .7354 L
.64061 .75 L
.63462 .75749 L
.62193 .76923 L
.61538 .77464 L
.59615 .7871 L
.59367 .78846 L
.57692 .7953 L
.55769 .80001 L
.53846 .80142 L
.51923 .79963 L
.5 .79472 L
Mistroke
.48382 .78846 L
.48077 .78701 L
.46154 .77731 L
.44293 .76923 L
.44231 .76903 L
.42308 .76667 L
.41029 .76923 L
.40385 .77131 L
.38462 .77897 L
.36538 .78597 L
.36037 .78846 L
.34615 .79038 L
.32692 .79165 L
.30769 .78962 L
.30074 .78846 L
.28846 .78363 L
.26923 .77285 L
.26441 .76923 L
.25 .75484 L
.24636 .75 L
.2356 .73077 L
.23077 .71881 L
.22967 .71154 L
.22782 .69231 L
.2296 .67308 L
.23077 .66518 L
.23544 .65385 L
.24611 .63462 L
.25 .62942 L
.26397 .61538 L
.26923 .61141 L
.28846 .60063 L
.2991 .59615 L
.30769 .59466 L
.32692 .59262 L
.34615 .59392 L
.36151 .59615 L
.36538 .59834 L
.38462 .60543 L
.40385 .61326 L
.4102 .61538 L
.42308 .61816 L
.44231 .61612 L
.44456 .61538 L
.46154 .60807 L
.48077 .59849 L
.48578 .59615 L
.5 .59077 L
.51923 .58581 L
.53846 .58385 L
Mistroke
.55769 .58492 L
.57692 .58897 L
.59615 .5959 L
.59672 .59615 L
.61538 .60595 L
.62947 .61538 L
.63462 .61851 L
.65385 .63205 L
.65802 .63462 L
.67308 .63774 L
.6815 .63462 L
.69231 .62045 L
.69619 .61538 L
.70723 .59615 L
.71154 .5883 L
.71875 .57692 L
.73077 .55931 L
.73194 .55769 L
.7464 .53846 L
.75 .5346 L
.75986 .51923 L
.76774 .5 L
.76603 .48077 L
.75663 .46154 L
.75 .45033 L
.74418 .44231 L
.73138 .42308 L
.73077 .42215 L
.71904 .40385 L
.71154 .39373 L
.70371 .38462 L
.69231 .37687 L
.67308 .37696 L
.65385 .38427 L
.65289 .38462 L
.63462 .39193 L
.61538 .3978 L
.59615 .40115 L
.57692 .40184 L
.55769 .4002 L
.53846 .3971 L
.51923 .39394 L
.5 .3918 L
.48077 .39057 L
.46154 .38914 L
.44231 .38636 L
.43376 .38462 L
.42308 .38155 L
.40385 .37569 L
.38462 .37268 L
Mistroke
.36538 .37638 L
.3462 .38462 L
.34615 .38467 L
.32692 .39203 L
.30769 .39666 L
.28846 .39749 L
.26923 .39407 L
.25 .38601 L
.24752 .38462 L
.23077 .37068 L
.2263 .36538 L
.21484 .34615 L
.21154 .33727 L
.20932 .32692 L
.20836 .30769 L
.21147 .28846 L
.21154 .28816 L
.22011 .26923 L
.23077 .2548 L
.23562 .25 L
.25 .23963 L
.26923 .23114 L
.27049 .23077 L
.28846 .22795 L
.30769 .22846 L
.32155 .23077 L
.32692 .23217 L
.34615 .23825 L
.36538 .24298 L
.38462 .2419 L
.40385 .23506 L
.41432 .23077 L
.42308 .22756 L
.44231 .22233 L
.46154 .21967 L
.48077 .21896 L
.5 .21894 L
.51923 .2183 L
.53846 .21658 L
.55769 .21463 L
.57692 .21386 L
.59615 .21541 L
.61538 .21996 L
.63462 .22783 L
.64012 .23077 L
.65385 .23935 L
.66753 .25 L
.67308 .25373 L
.69231 .2668 L
.71154 .26877 L
Mistroke
.73077 .25806 L
.742 .25 L
.75 .24299 L
.76592 .23077 L
.76923 .22835 L
.78846 .21432 L
.79184 .21154 L
.80769 .19388 L
.80845 .19231 L
.81093 .17308 L
.80769 .15446 L
.80757 .15385 L
.80399 .13462 L
.80228 .11538 L
.80347 .09615 L
.80769 .07863 L
.80831 .07692 L
.81839 .05769 L
.82692 .04715 L
.83661 .03846 L
.84615 .0324 L
.86538 .02468 L
.88462 .02209 L
.90385 .02416 L
.92308 .03128 L
.93471 .03846 L
.94231 .04515 L
.9527 .05769 L
.96154 .07418 L
.96243 .07692 L
.96682 .09615 L
.96685 .11538 L
.96292 .13462 L
.96154 .13919 L
.95523 .15385 L
.94444 .17308 L
.94231 .17659 L
.93313 .19231 L
.92776 .21154 L
.93324 .23077 L
.94231 .24732 L
.94486 .25 L
.9567 .26923 L
.96154 .27826 L
.96615 .28846 L
.97262 .30769 L
.97616 .32692 L
.97695 .34615 L
.97508 .36538 L
.97052 .38462 L
Mistroke
.96319 .40385 L
.96154 .40741 L
.95312 .42308 L
.94231 .43986 L
.94064 .44231 L
.92687 .46154 L
.92308 .46409 L
.91503 .48077 L
.91006 .5 L
.91466 .51923 L
.92308 .53693 L
.92553 .53846 L
.938 .55769 L
.94231 .56472 L
.94924 .57692 L
.95819 .59615 L
.96154 .60493 L
.96453 .61538 L
.96824 .63462 L
.9694 .65385 L
.96816 .67308 L
.9648 .69231 L
.96154 .70596 L
.9601 .71154 L
.95565 .73077 L
.9539 .75 L
.95662 .76923 L
.96154 .78727 L
.96298 .78846 L
.97037 .80769 L
.97658 .82692 L
.98047 .84615 L
.98077 .84868 L
Mfstroke
.4 g
.53846 .22966 m
.55769 .22779 L
.57692 .22712 L
.59615 .22901 L
.60638 .23077 L
.61538 .23445 L
.63462 .2444 L
.64233 .25 L
.65385 .26 L
.66114 .26923 L
.67308 .28451 L
.67496 .28846 L
.68275 .30769 L
.6822 .32692 L
.67308 .34287 L
.66946 .34615 L
.65385 .36216 L
.64909 .36538 L
.63462 .37464 L
.61538 .38287 L
.61341 .38462 L
.59615 .38727 L
.57692 .3884 L
.55769 .38692 L
.54164 .38462 L
.53846 .38393 L
.51923 .38093 L
.5 .37916 L
.48077 .37835 L
.46154 .37706 L
.44231 .37391 L
.42308 .3683 L
.41683 .36538 L
.40385 .36131 L
.38462 .35739 L
.36538 .36195 L
.35516 .36538 L
.34615 .37189 L
.32692 .38099 L
.31575 .38462 L
.30769 .38625 L
.28846 .38712 L
.2732 .38462 L
.26923 .3834 L
.25 .37359 L
.24012 .36538 L
.23077 .35421 L
.22642 .34615 L
.21993 .32692 L
.21873 .30769 L
.22266 .28846 L
.23077 .2712 L
.23246 .26923 L
.25 .25188 L
.2523 .25 L
.26923 .24228 L
.28846 .23833 L
.30769 .239 L
.32692 .24362 L
.34382 .25 L
.34615 .25088 L
.36538 .25752 L
.38462 .25734 L
.40314 .25 L
.40385 .24966 L
.42308 .24074 L
.44231 .23458 L
.46154 .23163 L
.48077 .23107 L
.5 .23143 L
.51923 .23116 L
.52537 .23077 L
F
0 g
.53846 .22966 m
.55769 .22779 L
.57692 .22712 L
.59615 .22901 L
.60638 .23077 L
.61538 .23445 L
.63462 .2444 L
.64233 .25 L
.65385 .26 L
.66114 .26923 L
.67308 .28451 L
.67496 .28846 L
.68275 .30769 L
.6822 .32692 L
.67308 .34287 L
.66946 .34615 L
.65385 .36216 L
.64909 .36538 L
.63462 .37464 L
.61538 .38287 L
.61341 .38462 L
.59615 .38727 L
.57692 .3884 L
.55769 .38692 L
.54164 .38462 L
.53846 .38393 L
.51923 .38093 L
.5 .37916 L
.48077 .37835 L
.46154 .37706 L
.44231 .37391 L
.42308 .3683 L
.41683 .36538 L
.40385 .36131 L
.38462 .35739 L
.36538 .36195 L
.35516 .36538 L
.34615 .37189 L
.32692 .38099 L
.31575 .38462 L
.30769 .38625 L
.28846 .38712 L
.2732 .38462 L
.26923 .3834 L
.25 .37359 L
.24012 .36538 L
.23077 .35421 L
.22642 .34615 L
.21993 .32692 L
.21873 .30769 L
Mistroke
.22266 .28846 L
.23077 .2712 L
.23246 .26923 L
.25 .25188 L
.2523 .25 L
.26923 .24228 L
.28846 .23833 L
.30769 .239 L
.32692 .24362 L
.34382 .25 L
.34615 .25088 L
.36538 .25752 L
.38462 .25734 L
.40314 .25 L
.40385 .24966 L
.42308 .24074 L
.44231 .23458 L
.46154 .23163 L
.48077 .23107 L
.5 .23143 L
.51923 .23116 L
.52537 .23077 L
.53846 .22966 L
Mfstroke
.5 g
.28846 .24733 m
.30769 .24811 L
.31635 .25 L
.32692 .2535 L
.34615 .26273 L
.35827 .26923 L
.36538 .2715 L
.38462 .27178 L
.39527 .26923 L
.40385 .26392 L
.42308 .2529 L
.42891 .25 L
.44231 .24577 L
.46154 .24248 L
.48077 .24204 L
.5 .24276 L
.51923 .24283 L
.53846 .24139 L
.55769 .23943 L
.57692 .23881 L
.59615 .24118 L
.61538 .24787 L
.61964 .25 L
.63462 .2605 L
.64284 .26923 L
.65385 .2852 L
.65479 .28846 L
.65896 .30769 L
.65662 .32692 L
.65385 .33524 L
.64641 .34615 L
.63462 .3581 L
.6234 .36538 L
.61538 .36918 L
.59615 .37496 L
.57692 .37661 L
.55769 .37517 L
.53846 .37206 L
.51923 .36917 L
.5 .36778 L
.48077 .36739 L
.46154 .36628 L
.45496 .36538 L
.44231 .36284 L
.42308 .35615 L
.40385 .34684 L
.4024 .34615 L
.38462 .34304 L
.36686 .34615 L
.36538 .34704 L
.34615 .36031 L
.33777 .36538 L
.32692 .37094 L
.30769 .37706 L
.28846 .37811 L
.26923 .37368 L
.25333 .36538 L
.25 .36228 L
.23663 .34615 L
.23077 .33312 L
.2291 .32692 L
.22779 .30769 L
.23077 .29244 L
.23218 .28846 L
.24406 .26923 L
.25 .26337 L
.26923 .25175 L
.27439 .25 L
F
0 g
.28846 .24733 m
.30769 .24811 L
.31635 .25 L
.32692 .2535 L
.34615 .26273 L
.35827 .26923 L
.36538 .2715 L
.38462 .27178 L
.39527 .26923 L
.40385 .26392 L
.42308 .2529 L
.42891 .25 L
.44231 .24577 L
.46154 .24248 L
.48077 .24204 L
.5 .24276 L
.51923 .24283 L
.53846 .24139 L
.55769 .23943 L
.57692 .23881 L
.59615 .24118 L
.61538 .24787 L
.61964 .25 L
.63462 .2605 L
.64284 .26923 L
.65385 .2852 L
.65479 .28846 L
.65896 .30769 L
.65662 .32692 L
.65385 .33524 L
.64641 .34615 L
.63462 .3581 L
.6234 .36538 L
.61538 .36918 L
.59615 .37496 L
.57692 .37661 L
.55769 .37517 L
.53846 .37206 L
.51923 .36917 L
.5 .36778 L
.48077 .36739 L
.46154 .36628 L
.45496 .36538 L
.44231 .36284 L
.42308 .35615 L
.40385 .34684 L
.4024 .34615 L
.38462 .34304 L
.36686 .34615 L
.36538 .34704 L
Mistroke
.34615 .36031 L
.33777 .36538 L
.32692 .37094 L
.30769 .37706 L
.28846 .37811 L
.26923 .37368 L
.25333 .36538 L
.25 .36228 L
.23663 .34615 L
.23077 .33312 L
.2291 .32692 L
.22779 .30769 L
.23077 .29244 L
.23218 .28846 L
.24406 .26923 L
.25 .26337 L
.26923 .25175 L
.27439 .25 L
.28846 .24733 L
Mfstroke
.6 g
.26923 .26081 m
.28846 .25561 L
.30769 .25656 L
.32692 .26308 L
.3375 .26923 L
.34615 .27394 L
.36169 .28846 L
.36538 .29229 L
.38462 .3051 L
.39716 .28846 L
.40385 .27741 L
.41827 .26923 L
.42308 .26558 L
.44231 .25642 L
.46154 .25269 L
.48077 .25236 L
.5 .25349 L
.51923 .25392 L
.53846 .25258 L
.55769 .25056 L
.57692 .25001 L
.59615 .25287 L
.61538 .26121 L
.62568 .26923 L
.63462 .27755 L
.6393 .28846 L
.64394 .30769 L
.64069 .32692 L
.63462 .34215 L
.62794 .34615 L
.61538 .35569 L
.59615 .36315 L
.57692 .36534 L
.55769 .364 L
.53846 .36082 L
.51923 .35799 L
.5 .35697 L
.48077 .35701 L
.46154 .35601 L
.44231 .35196 L
.42779 .34615 L
.42308 .34413 L
.40385 .33036 L
.4008 .32692 L
.38462 .3099 L
.36585 .32692 L
.36538 .32786 L
.34671 .34615 L
.34615 .34788 L
.32692 .36159 L
.31821 .36538 L
.30769 .36855 L
.28846 .36975 L
.27092 .36538 L
.26923 .36469 L
.25 .35053 L
.24666 .34615 L
.23764 .32692 L
.23609 .30769 L
.24129 .28846 L
.25 .27424 L
.25516 .26923 L
F
0 g
.26923 .26081 m
.28846 .25561 L
.30769 .25656 L
.32692 .26308 L
.3375 .26923 L
.34615 .27394 L
.36169 .28846 L
.36538 .29229 L
.38462 .3051 L
.39716 .28846 L
.40385 .27741 L
.41827 .26923 L
.42308 .26558 L
.44231 .25642 L
.46154 .25269 L
.48077 .25236 L
.5 .25349 L
.51923 .25392 L
.53846 .25258 L
.55769 .25056 L
.57692 .25001 L
.59615 .25287 L
.61538 .26121 L
.62568 .26923 L
.63462 .27755 L
.6393 .28846 L
.64394 .30769 L
.64069 .32692 L
.63462 .34215 L
.62794 .34615 L
.61538 .35569 L
.59615 .36315 L
.57692 .36534 L
.55769 .364 L
.53846 .36082 L
.51923 .35799 L
.5 .35697 L
.48077 .35701 L
.46154 .35601 L
.44231 .35196 L
.42779 .34615 L
.42308 .34413 L
.40385 .33036 L
.4008 .32692 L
.38462 .3099 L
.36585 .32692 L
.36538 .32786 L
.34671 .34615 L
.34615 .34788 L
.32692 .36159 L
Mistroke
.31821 .36538 L
.30769 .36855 L
.28846 .36975 L
.27092 .36538 L
.26923 .36469 L
.25 .35053 L
.24666 .34615 L
.23764 .32692 L
.23609 .30769 L
.24129 .28846 L
.25 .27424 L
.25516 .26923 L
.26923 .26081 L
Mfstroke
.4 g
.30769 .60874 m
.32692 .60631 L
.34615 .60787 L
.36538 .61314 L
.37126 .61538 L
.38462 .62172 L
.40385 .63199 L
.40933 .63462 L
.42308 .63899 L
.44231 .63687 L
.44761 .63462 L
.46154 .62666 L
.48018 .61538 L
.48077 .61503 L
.5 .60587 L
.51923 .60011 L
.53846 .59792 L
.55769 .59928 L
.57692 .60426 L
.59615 .61313 L
.59988 .61538 L
.61538 .62684 L
.62294 .63462 L
.63462 .64826 L
.63623 .65385 L
.64381 .67308 L
.64554 .69231 L
.64141 .71154 L
.63462 .72953 L
.63347 .73077 L
.61942 .75 L
.61538 .75449 L
.59774 .76923 L
.59615 .77027 L
.57692 .78021 L
.55769 .78575 L
.53846 .7874 L
.51923 .78536 L
.5 .77965 L
.48077 .77045 L
.47874 .76923 L
.46154 .75872 L
.44641 .75 L
.44231 .74824 L
.42308 .74583 L
.40934 .75 L
.40385 .75257 L
.38462 .76267 L
.37057 .76923 L
.36538 .77118 L
.34615 .77641 L
.32692 .77796 L
.30769 .77553 L
.28921 .76923 L
.28846 .76854 L
.26923 .75523 L
.264 .75 L
.25069 .73077 L
.25 .73018 L
.24378 .71154 L
.24156 .69231 L
.2437 .67308 L
.25 .65423 L
.25051 .65385 L
.26367 .63462 L
.26923 .62902 L
.28846 .61572 L
.28881 .61538 L
F
0 g
.30769 .60874 m
.32692 .60631 L
.34615 .60787 L
.36538 .61314 L
.37126 .61538 L
.38462 .62172 L
.40385 .63199 L
.40933 .63462 L
.42308 .63899 L
.44231 .63687 L
.44761 .63462 L
.46154 .62666 L
.48018 .61538 L
.48077 .61503 L
.5 .60587 L
.51923 .60011 L
.53846 .59792 L
.55769 .59928 L
.57692 .60426 L
.59615 .61313 L
.59988 .61538 L
.61538 .62684 L
.62294 .63462 L
.63462 .64826 L
.63623 .65385 L
.64381 .67308 L
.64554 .69231 L
.64141 .71154 L
.63462 .72953 L
.63347 .73077 L
.61942 .75 L
.61538 .75449 L
.59774 .76923 L
.59615 .77027 L
.57692 .78021 L
.55769 .78575 L
.53846 .7874 L
.51923 .78536 L
.5 .77965 L
.48077 .77045 L
.47874 .76923 L
.46154 .75872 L
.44641 .75 L
.44231 .74824 L
.42308 .74583 L
.40934 .75 L
.40385 .75257 L
.38462 .76267 L
.37057 .76923 L
.36538 .77118 L
Mistroke
.34615 .77641 L
.32692 .77796 L
.30769 .77553 L
.28921 .76923 L
.28846 .76854 L
.26923 .75523 L
.264 .75 L
.25069 .73077 L
.25 .73018 L
.24378 .71154 L
.24156 .69231 L
.2437 .67308 L
.25 .65423 L
.25051 .65385 L
.26367 .63462 L
.26923 .62902 L
.28846 .61572 L
.28881 .61538 L
.30769 .60874 L
Mfstroke
.7 g
.28846 .26372 m
.30769 .2649 L
.31991 .26923 L
.32692 .2722 L
.34452 .28846 L
.34615 .29059 L
.35351 .30769 L
.34678 .32692 L
.34615 .33238 L
.3341 .34615 L
.32692 .35187 L
.30769 .36048 L
.28846 .36183 L
.26923 .35589 L
.25614 .34615 L
.25 .33606 L
.2461 .32692 L
.24426 .30769 L
.25 .28942 L
.25042 .28846 L
.26923 .26981 L
.27062 .26923 L
F
0 g
.28846 .26372 m
.30769 .2649 L
.31991 .26923 L
.32692 .2722 L
.34452 .28846 L
.34615 .29059 L
.35351 .30769 L
.34678 .32692 L
.34615 .33238 L
.3341 .34615 L
.32692 .35187 L
.30769 .36048 L
.28846 .36183 L
.26923 .35589 L
.25614 .34615 L
.25 .33606 L
.2461 .32692 L
.24426 .30769 L
.25 .28942 L
.25042 .28846 L
.26923 .26981 L
.27062 .26923 L
.28846 .26372 L
s
.8 g
.26923 .27856 m
.28846 .27151 L
.30769 .27272 L
.32692 .28315 L
.33136 .28846 L
.34061 .30769 L
.33724 .32692 L
.32692 .34047 L
.31952 .34615 L
.30769 .35195 L
.28846 .35368 L
.26981 .34615 L
.26923 .34575 L
.25405 .32692 L
.25216 .30769 L
.25929 .28846 L
F
0 g
.26923 .27856 m
.28846 .27151 L
.30769 .27272 L
.32692 .28315 L
.33136 .28846 L
.34061 .30769 L
.33724 .32692 L
.32692 .34047 L
.31952 .34615 L
.30769 .35195 L
.28846 .35368 L
.26981 .34615 L
.26923 .34575 L
.25405 .32692 L
.25216 .30769 L
.25929 .28846 L
.26923 .27856 L
s
.5 g
.51923 .61277 m
.53846 .61034 L
.55769 .61198 L
.57446 .61538 L
.57692 .61791 L
.59615 .62912 L
.60271 .63462 L
.61538 .64863 L
.61843 .65385 L
.62647 .67308 L
.6286 .69231 L
.62525 .71154 L
.6167 .73077 L
.61538 .73305 L
.60125 .75 L
.59615 .75453 L
.57692 .76669 L
.57436 .76923 L
.55769 .77312 L
.53846 .77501 L
.51923 .7727 L
.50514 .76923 L
.5 .76612 L
.48077 .755 L
.47436 .75 L
.46154 .74004 L
.45103 .73077 L
.44231 .7272 L
.42308 .72382 L
.40655 .73077 L
.40385 .73291 L
.38462 .74713 L
.37999 .75 L
.36538 .75775 L
.34615 .76407 L
.32692 .76591 L
.30769 .76306 L
.28846 .7546 L
.28167 .75 L
.26923 .73757 L
.26465 .73077 L
.25627 .71154 L
.25366 .69231 L
.25617 .67308 L
.26443 .65385 L
.26923 .64667 L
.28121 .63462 L
.28846 .62966 L
.30769 .6212 L
.32692 .61836 L
.34615 .62021 L
.36538 .62656 L
.38039 .63462 L
.38462 .63727 L
.40385 .65164 L
.4066 .65385 L
.42308 .66112 L
.44231 .65811 L
.4518 .65385 L
.46154 .64536 L
.47546 .63462 L
.48077 .6305 L
.5 .6194 L
.50784 .61538 L
F
0 g
.51923 .61277 m
.53846 .61034 L
.55769 .61198 L
.57446 .61538 L
.57692 .61791 L
.59615 .62912 L
.60271 .63462 L
.61538 .64863 L
.61843 .65385 L
.62647 .67308 L
.6286 .69231 L
.62525 .71154 L
.6167 .73077 L
.61538 .73305 L
.60125 .75 L
.59615 .75453 L
.57692 .76669 L
.57436 .76923 L
.55769 .77312 L
.53846 .77501 L
.51923 .7727 L
.50514 .76923 L
.5 .76612 L
.48077 .755 L
.47436 .75 L
.46154 .74004 L
.45103 .73077 L
.44231 .7272 L
.42308 .72382 L
.40655 .73077 L
.40385 .73291 L
.38462 .74713 L
.37999 .75 L
.36538 .75775 L
.34615 .76407 L
.32692 .76591 L
.30769 .76306 L
.28846 .7546 L
.28167 .75 L
.26923 .73757 L
.26465 .73077 L
.25627 .71154 L
.25366 .69231 L
.25617 .67308 L
.26443 .65385 L
.26923 .64667 L
.28121 .63462 L
.28846 .62966 L
.30769 .6212 L
.32692 .61836 L
Mistroke
.34615 .62021 L
.36538 .62656 L
.38039 .63462 L
.38462 .63727 L
.40385 .65164 L
.4066 .65385 L
.42308 .66112 L
.44231 .65811 L
.4518 .65385 L
.46154 .64536 L
.47546 .63462 L
.48077 .6305 L
.5 .6194 L
.50784 .61538 L
.51923 .61277 L
Mfstroke
.9 g
.28846 .27996 m
.30769 .28208 L
.31709 .28846 L
.32692 .30066 L
.32925 .30769 L
.32692 .32402 L
.32546 .32692 L
.30769 .3421 L
.28846 .34431 L
.26923 .33356 L
.26391 .32692 L
.26069 .30769 L
.26923 .29195 L
.27277 .28846 L
F
0 g
.28846 .27996 m
.30769 .28208 L
.31709 .28846 L
.32692 .30066 L
.32925 .30769 L
.32692 .32402 L
.32546 .32692 L
.30769 .3421 L
.28846 .34431 L
.26923 .33356 L
.26391 .32692 L
.26069 .30769 L
.26923 .29195 L
.27277 .28846 L
.28846 .27996 L
s
.6 g
.30769 .63327 m
.32692 .62986 L
.34615 .63209 L
.35781 .63462 L
.36538 .63973 L
.38393 .65385 L
.38462 .65409 L
.39818 .67308 L
.40385 .68659 L
.40441 .69231 L
.40385 .69796 L
.39809 .71154 L
.38462 .73041 L
.38369 .73077 L
.36538 .74459 L
.35676 .75 L
.34615 .75219 L
.32692 .7544 L
.30769 .75099 L
.30394 .75 L
.28846 .74073 L
.27854 .73077 L
.26923 .71517 L
.26836 .71154 L
.26523 .69231 L
.26824 .67308 L
.26923 .66885 L
.27826 .65385 L
.28846 .64352 L
.30274 .63462 L
F
0 g
.30769 .63327 m
.32692 .62986 L
.34615 .63209 L
.35781 .63462 L
.36538 .63973 L
.38393 .65385 L
.38462 .65409 L
.39818 .67308 L
.40385 .68659 L
.40441 .69231 L
.40385 .69796 L
.39809 .71154 L
.38462 .73041 L
.38369 .73077 L
.36538 .74459 L
.35676 .75 L
.34615 .75219 L
.32692 .7544 L
.30769 .75099 L
.30394 .75 L
.28846 .74073 L
.27854 .73077 L
.26923 .71517 L
.26836 .71154 L
.26523 .69231 L
.26824 .67308 L
.26923 .66885 L
.27826 .65385 L
.28846 .64352 L
.30274 .63462 L
.30769 .63327 L
s
1 g
.28846 .29237 m
.30769 .29574 L
.31631 .30769 L
.31082 .32692 L
.30769 .32957 L
.28846 .33307 L
.27824 .32692 L
.2732 .30769 L
F
0 g
.28846 .29237 m
.30769 .29574 L
.31631 .30769 L
.31082 .32692 L
.30769 .32957 L
.28846 .33307 L
.27824 .32692 L
.2732 .30769 L
.28846 .29237 L
s
.7 g
.30769 .64548 m
.32692 .64127 L
.34615 .64403 L
.36509 .65385 L
.36538 .65414 L
.38096 .67308 L
.38462 .68292 L
.38562 .69231 L
.38462 .70147 L
.38083 .71154 L
.36538 .73032 L
.36497 .73077 L
.34615 .74025 L
.32692 .74299 L
.30769 .73876 L
.2928 .73077 L
.28846 .72694 L
.28063 .71154 L
.27673 .69231 L
.28048 .67308 L
.28846 .65721 L
.29244 .65385 L
F
0 g
.30769 .64548 m
.32692 .64127 L
.34615 .64403 L
.36509 .65385 L
.36538 .65414 L
.38096 .67308 L
.38462 .68292 L
.38562 .69231 L
.38462 .70147 L
.38083 .71154 L
.36538 .73032 L
.36497 .73077 L
.34615 .74025 L
.32692 .74299 L
.30769 .73876 L
.2928 .73077 L
.28846 .72694 L
.28063 .71154 L
.27673 .69231 L
.28048 .67308 L
.28846 .65721 L
.29244 .65385 L
.30769 .64548 L
s
.8 g
.30769 .65725 m
.32692 .65401 L
.34615 .65585 L
.36491 .67308 L
.36538 .67576 L
.36985 .69231 L
.36538 .70854 L
.36484 .71154 L
.34615 .72841 L
.32692 .73044 L
.30769 .72689 L
.29298 .71154 L
.28921 .69231 L
.2928 .67308 L
F
0 g
.30769 .65725 m
.32692 .65401 L
.34615 .65585 L
.36491 .67308 L
.36538 .67576 L
.36985 .69231 L
.36538 .70854 L
.36484 .71154 L
.34615 .72841 L
.32692 .73044 L
.30769 .72689 L
.29298 .71154 L
.28921 .69231 L
.2928 .67308 L
.30769 .65725 L
s
.9 g
.32692 .67032 m
.33736 .67308 L
.34615 .67964 L
.35335 .69231 L
.34615 .70463 L
.33649 .71154 L
.32692 .71373 L
.32071 .71154 L
.30769 .69692 L
.30679 .69231 L
.30769 .68736 L
.31986 .67308 L
F
0 g
.32692 .67032 m
.33736 .67308 L
.34615 .67964 L
.35335 .69231 L
.34615 .70463 L
.33649 .71154 L
.32692 .71373 L
.32071 .71154 L
.30769 .69692 L
.30679 .69231 L
.30769 .68736 L
.31986 .67308 L
.32692 .67032 L
s
.7 g
.44231 .26829 m
.46154 .26324 L
.48077 .26299 L
.5 .26479 L
.51923 .26575 L
.53846 .26425 L
.55769 .26178 L
.57692 .26122 L
.59615 .26517 L
.60653 .26923 L
.61538 .27435 L
.62446 .28846 L
.62978 .30769 L
.62546 .32692 L
.61538 .34282 L
.60878 .34615 L
.59615 .35081 L
.57692 .35406 L
.55769 .35265 L
.53846 .34895 L
.52131 .34615 L
.51923 .34602 L
.5 .34567 L
.48077 .3461 L
.46154 .34547 L
.44231 .34157 L
.42308 .32807 L
.42235 .32692 L
.41295 .30769 L
.41778 .28846 L
.42308 .28135 L
.43991 .26923 L
F
0 g
.44231 .26829 m
.46154 .26324 L
.48077 .26299 L
.5 .26479 L
.51923 .26575 L
.53846 .26425 L
.55769 .26178 L
.57692 .26122 L
.59615 .26517 L
.60653 .26923 L
.61538 .27435 L
.62446 .28846 L
.62978 .30769 L
.62546 .32692 L
.61538 .34282 L
.60878 .34615 L
.59615 .35081 L
.57692 .35406 L
.55769 .35265 L
.53846 .34895 L
.52131 .34615 L
.51923 .34602 L
.5 .34567 L
.48077 .3461 L
.46154 .34547 L
.44231 .34157 L
.42308 .32807 L
.42235 .32692 L
.41295 .30769 L
.41778 .28846 L
.42308 .28135 L
.43991 .26923 L
.44231 .26829 L
s
.8 g
.44231 .28306 m
.46154 .27579 L
.48077 .27562 L
.5 .27846 L
.51923 .27592 L
.53846 .27446 L
.55769 .2721 L
.57692 .27186 L
.59615 .27715 L
.60833 .28846 L
.61453 .30769 L
.6093 .32692 L
.59615 .33902 L
.57692 .34333 L
.55769 .342 L
.53846 .3374 L
.51923 .33316 L
.5 .33337 L
.48077 .33528 L
.46154 .33432 L
.44458 .32692 L
.44231 .3255 L
.42897 .30769 L
.43517 .28846 L
F
0 g
.44231 .28306 m
.46154 .27579 L
.48077 .27562 L
.5 .27846 L
.51923 .27592 L
.53846 .27446 L
.55769 .2721 L
.57692 .27186 L
.59615 .27715 L
.60833 .28846 L
.61453 .30769 L
.6093 .32692 L
.59615 .33902 L
.57692 .34333 L
.55769 .342 L
.53846 .3374 L
.51923 .33316 L
.5 .33337 L
.48077 .33528 L
.46154 .33432 L
.44458 .32692 L
.44231 .3255 L
.42897 .30769 L
.43517 .28846 L
.44231 .28306 L
s
.6 g
.5 .6326 m
.51923 .62466 L
.53846 .62185 L
.55769 .62384 L
.57692 .63114 L
.58296 .63462 L
.59615 .64558 L
.60266 .65385 L
.61208 .67308 L
.61472 .69231 L
.61145 .71154 L
.60184 .73077 L
.59615 .73823 L
.58279 .75 L
.57692 .75356 L
.55769 .76131 L
.53846 .76354 L
.51923 .76084 L
.5 .75294 L
.495 .75 L
.48077 .73911 L
.47341 .73077 L
.46154 .71634 L
.45987 .71154 L
.45497 .69231 L
.46024 .67308 L
.46154 .66955 L
.47416 .65385 L
.48077 .64642 L
.49649 .63462 L
F
0 g
.5 .6326 m
.51923 .62466 L
.53846 .62185 L
.55769 .62384 L
.57692 .63114 L
.58296 .63462 L
.59615 .64558 L
.60266 .65385 L
.61208 .67308 L
.61472 .69231 L
.61145 .71154 L
.60184 .73077 L
.59615 .73823 L
.58279 .75 L
.57692 .75356 L
.55769 .76131 L
.53846 .76354 L
.51923 .76084 L
.5 .75294 L
.495 .75 L
.48077 .73911 L
.47341 .73077 L
.46154 .71634 L
.45987 .71154 L
.45497 .69231 L
.46024 .67308 L
.46154 .66955 L
.47416 .65385 L
.48077 .64642 L
.49649 .63462 L
.5 .6326 L
s
.9 g
.46154 .29619 m
.48077 .29585 L
.49097 .30769 L
.48077 .31346 L
.46154 .31256 L
.45646 .30769 L
F
0 g
.46154 .29619 m
.48077 .29585 L
.49097 .30769 L
.48077 .31346 L
.46154 .31256 L
.45646 .30769 L
.46154 .29619 L
s
.7 g
.53846 .63327 m
.55297 .63462 L
.55769 .6357 L
.57692 .6447 L
.58722 .65385 L
.59615 .66474 L
.59858 .67308 L
.60187 .69231 L
.5983 .71154 L
.59615 .7188 L
.58706 .73077 L
.57692 .74008 L
.55769 .74946 L
.55565 .75 L
.53846 .75214 L
.52311 .75 L
.51923 .74894 L
.5 .73935 L
.49027 .73077 L
.48077 .72136 L
.47752 .71154 L
.47363 .69231 L
.47789 .67308 L
.48077 .6648 L
.49117 .65385 L
.5 .64622 L
.51923 .63652 L
.52688 .63462 L
F
0 g
.53846 .63327 m
.55297 .63462 L
.55769 .6357 L
.57692 .6447 L
.58722 .65385 L
.59615 .66474 L
.59858 .67308 L
.60187 .69231 L
.5983 .71154 L
.59615 .7188 L
.58706 .73077 L
.57692 .74008 L
.55769 .74946 L
.55565 .75 L
.53846 .75214 L
.52311 .75 L
.51923 .74894 L
.5 .73935 L
.49027 .73077 L
.48077 .72136 L
.47752 .71154 L
.47363 .69231 L
.47789 .67308 L
.48077 .6648 L
.49117 .65385 L
.5 .64622 L
.51923 .63652 L
.52688 .63462 L
.53846 .63327 L
s
.8 g
.51923 .64925 m
.53846 .64496 L
.55769 .64824 L
.57214 .65385 L
.57692 .6584 L
.58495 .67308 L
.5892 .69231 L
.58494 .71154 L
.57692 .72656 L
.57253 .73077 L
.55769 .73701 L
.53846 .74048 L
.51923 .73631 L
.50707 .73077 L
.5 .72577 L
.49258 .71154 L
.48806 .69231 L
.49305 .67308 L
.5 .66029 L
.50861 .65385 L
F
0 g
.51923 .64925 m
.53846 .64496 L
.55769 .64824 L
.57214 .65385 L
.57692 .6584 L
.58495 .67308 L
.5892 .69231 L
.58494 .71154 L
.57692 .72656 L
.57253 .73077 L
.55769 .73701 L
.53846 .74048 L
.51923 .73631 L
.50707 .73077 L
.5 .72577 L
.49258 .71154 L
.48806 .69231 L
.49305 .67308 L
.5 .66029 L
.50861 .65385 L
.51923 .64925 L
s
.9 g
.51923 .66246 m
.53846 .65666 L
.55769 .66091 L
.57184 .67308 L
.57616 .69231 L
.57208 .71154 L
.55769 .72474 L
.53846 .72887 L
.51923 .72368 L
.5076 .71154 L
.50229 .69231 L
.50839 .67308 L
F
0 g
.51923 .66246 m
.53846 .65666 L
.55769 .66091 L
.57184 .67308 L
.57616 .69231 L
.57208 .71154 L
.55769 .72474 L
.53846 .72887 L
.51923 .72368 L
.5076 .71154 L
.50229 .69231 L
.50839 .67308 L
.51923 .66246 L
s
1 g
.53846 .68149 m
.5511 .69231 L
.53846 .70395 L
.52776 .69231 L
F
0 g
.53846 .68149 m
.5511 .69231 L
.53846 .70395 L
.52776 .69231 L
.53846 .68149 L
s
.9 g
.55769 .2949 m
.57692 .29336 L
.59103 .30769 L
.57692 .32184 L
.55769 .31947 L
.53978 .30769 L
F
0 g
.55769 .2949 m
.57692 .29336 L
.59103 .30769 L
.57692 .32184 L
.55769 .31947 L
.53978 .30769 L
.55769 .2949 L
s
.4 g
.82692 .5082 m
.84615 .5063 L
.8652 .51923 L
.86538 .51943 L
.88462 .53692 L
.88859 .53846 L
.90385 .55362 L
.90784 .55769 L
.92305 .57692 L
.92308 .57696 L
.93437 .59615 L
.9421 .61538 L
.94231 .61552 L
.94654 .63462 L
.94793 .65385 L
.94649 .67308 L
.94259 .69231 L
.94231 .69342 L
.93706 .71154 L
.93183 .73077 L
.93006 .75 L
.93437 .76923 L
.94231 .78755 L
.94335 .78846 L
.9532 .80769 L
.96113 .82692 L
.96154 .82722 L
.96601 .84615 L
.9674 .86538 L
.96492 .88462 L
.96154 .89797 L
.95786 .90385 L
.94437 .92308 L
.94231 .9252 L
.92308 .93935 L
.91996 .94231 L
.90385 .94653 L
.88462 .94869 L
.86538 .94628 L
.85064 .94231 L
.84615 .93884 L
.82692 .92456 L
.82546 .92308 L
.81132 .90385 L
.80769 .89728 L
.80326 .88462 L
.79906 .86538 L
.79756 .84615 L
.79767 .82692 L
.79769 .80769 L
.79469 .78846 L
.78846 .77402 L
.7847 .76923 L
.76923 .75176 L
.76748 .75 L
.75 .73167 L
.74922 .73077 L
.73421 .71154 L
.73077 .70668 L
.72391 .69231 L
.71737 .67308 L
.71577 .65385 L
.71857 .63462 L
.72466 .61538 L
.73077 .60142 L
.73375 .59615 L
.74627 .57692 L
.75 .57211 L
.76268 .55769 L
.76923 .55143 L
.78358 .53846 L
.78846 .53572 L
.80769 .52085 L
.80951 .51923 L
F
0 g
.82692 .5082 m
.84615 .5063 L
.8652 .51923 L
.86538 .51943 L
.88462 .53692 L
.88859 .53846 L
.90385 .55362 L
.90784 .55769 L
.92305 .57692 L
.92308 .57696 L
.93437 .59615 L
.9421 .61538 L
.94231 .61552 L
.94654 .63462 L
.94793 .65385 L
.94649 .67308 L
.94259 .69231 L
.94231 .69342 L
.93706 .71154 L
.93183 .73077 L
.93006 .75 L
.93437 .76923 L
.94231 .78755 L
.94335 .78846 L
.9532 .80769 L
.96113 .82692 L
.96154 .82722 L
.96601 .84615 L
.9674 .86538 L
.96492 .88462 L
.96154 .89797 L
.95786 .90385 L
.94437 .92308 L
.94231 .9252 L
.92308 .93935 L
.91996 .94231 L
.90385 .94653 L
.88462 .94869 L
.86538 .94628 L
.85064 .94231 L
.84615 .93884 L
.82692 .92456 L
.82546 .92308 L
.81132 .90385 L
.80769 .89728 L
.80326 .88462 L
.79906 .86538 L
.79756 .84615 L
.79767 .82692 L
.79769 .80769 L
Mistroke
.79469 .78846 L
.78846 .77402 L
.7847 .76923 L
.76923 .75176 L
.76748 .75 L
.75 .73167 L
.74922 .73077 L
.73421 .71154 L
.73077 .70668 L
.72391 .69231 L
.71737 .67308 L
.71577 .65385 L
.71857 .63462 L
.72466 .61538 L
.73077 .60142 L
.73375 .59615 L
.74627 .57692 L
.75 .57211 L
.76268 .55769 L
.76923 .55143 L
.78358 .53846 L
.78846 .53572 L
.80769 .52085 L
.80951 .51923 L
.82692 .5082 L
Mfstroke
.4 g
.88462 .03574 m
.90385 .03822 L
.90519 .03846 L
.92308 .04701 L
.93564 .05769 L
.94231 .06577 L
.94781 .07692 L
.95302 .09615 L
.95296 .11538 L
.94804 .13462 L
.94231 .14722 L
.93809 .15385 L
.92308 .17184 L
.92225 .17308 L
.90385 .1872 L
.8998 .19231 L
.88812 .21154 L
.90033 .23077 L
.90385 .23698 L
.91741 .25 L
.92308 .25688 L
.93274 .26923 L
.94231 .28457 L
.9443 .28846 L
.952 .30769 L
.95618 .32692 L
.95712 .34615 L
.9549 .36538 L
.94948 .38462 L
.94231 .40085 L
.94063 .40385 L
.92794 .42308 L
.92308 .42906 L
.91102 .44231 L
.90385 .44874 L
.8895 .46154 L
.88462 .46271 L
.86538 .47909 L
.86281 .48077 L
.84615 .49047 L
.82692 .48678 L
.81842 .48077 L
.80769 .47263 L
.794 .46154 L
.78846 .45568 L
.77433 .44231 L
.76923 .43657 L
.75799 .42308 L
.75 .41193 L
.74488 .40385 L
.73431 .38462 L
.73077 .37804 L
.72706 .36538 L
.71931 .34615 L
.71733 .32692 L
.72364 .30769 L
.73077 .29511 L
.7371 .28846 L
.75 .27224 L
.75299 .26923 L
.76923 .25423 L
.77458 .25 L
.78846 .24046 L
.80487 .23077 L
.80769 .22947 L
.82692 .22124 L
.83716 .21154 L
.84615 .20609 L
.84726 .19231 L
.84615 .19002 L
.83617 .17308 L
.82692 .15486 L
.82647 .15385 L
.81961 .13462 L
.81644 .11538 L
.81734 .09615 L
.82306 .07692 L
.82692 .06886 L
.83555 .05769 L
.84615 .04842 L
.86538 .03884 L
.86667 .03846 L
F
0 g
.88462 .03574 m
.90385 .03822 L
.90519 .03846 L
.92308 .04701 L
.93564 .05769 L
.94231 .06577 L
.94781 .07692 L
.95302 .09615 L
.95296 .11538 L
.94804 .13462 L
.94231 .14722 L
.93809 .15385 L
.92308 .17184 L
.92225 .17308 L
.90385 .1872 L
.8998 .19231 L
.88812 .21154 L
.90033 .23077 L
.90385 .23698 L
.91741 .25 L
.92308 .25688 L
.93274 .26923 L
.94231 .28457 L
.9443 .28846 L
.952 .30769 L
.95618 .32692 L
.95712 .34615 L
.9549 .36538 L
.94948 .38462 L
.94231 .40085 L
.94063 .40385 L
.92794 .42308 L
.92308 .42906 L
.91102 .44231 L
.90385 .44874 L
.8895 .46154 L
.88462 .46271 L
.86538 .47909 L
.86281 .48077 L
.84615 .49047 L
.82692 .48678 L
.81842 .48077 L
.80769 .47263 L
.794 .46154 L
.78846 .45568 L
.77433 .44231 L
.76923 .43657 L
.75799 .42308 L
.75 .41193 L
.74488 .40385 L
Mistroke
.73431 .38462 L
.73077 .37804 L
.72706 .36538 L
.71931 .34615 L
.71733 .32692 L
.72364 .30769 L
.73077 .29511 L
.7371 .28846 L
.75 .27224 L
.75299 .26923 L
.76923 .25423 L
.77458 .25 L
.78846 .24046 L
.80487 .23077 L
.80769 .22947 L
.82692 .22124 L
.83716 .21154 L
.84615 .20609 L
.84726 .19231 L
.84615 .19002 L
.83617 .17308 L
.82692 .15486 L
.82647 .15385 L
.81961 .13462 L
.81644 .11538 L
.81734 .09615 L
.82306 .07692 L
.82692 .06886 L
.83555 .05769 L
.84615 .04842 L
.86538 .03884 L
.86667 .03846 L
.88462 .03574 L
Mfstroke
.5 g
.80769 .55445 m
.82692 .54933 L
.84615 .54961 L
.86538 .55538 L
.87094 .55769 L
.88462 .56699 L
.89611 .57692 L
.90385 .58562 L
.91146 .59615 L
.92124 .61538 L
.92308 .61739 L
.92669 .63462 L
.92839 .65385 L
.92666 .67308 L
.92308 .69006 L
.92186 .69231 L
.91485 .71154 L
.90755 .73077 L
.90418 .75 L
.91035 .76923 L
.92308 .7883 L
.92337 .78846 L
.93699 .80769 L
.94231 .8169 L
.94701 .82692 L
.95302 .84615 L
.95476 .86538 L
.95189 .88462 L
.94331 .90385 L
.94231 .90546 L
.92533 .92308 L
.92308 .92457 L
.90385 .93345 L
.88462 .93606 L
.86538 .93318 L
.84615 .92406 L
.84467 .92308 L
.82692 .90512 L
.82608 .90385 L
.81658 .88462 L
.81219 .86538 L
.81144 .84615 L
.81335 .82692 L
.81667 .80769 L
.81892 .78846 L
.8146 .76923 L
.80769 .75779 L
.79861 .75 L
.78846 .74074 L
.77735 .73077 L
.76923 .72256 L
.75994 .71154 L
.75 .69642 L
.74804 .69231 L
.74123 .67308 L
.73899 .65385 L
.74101 .63462 L
.74709 .61538 L
.75 .60876 L
.75755 .59615 L
.76923 .5815 L
.77364 .57692 L
.78846 .56491 L
.79938 .55769 L
F
0 g
.80769 .55445 m
.82692 .54933 L
.84615 .54961 L
.86538 .55538 L
.87094 .55769 L
.88462 .56699 L
.89611 .57692 L
.90385 .58562 L
.91146 .59615 L
.92124 .61538 L
.92308 .61739 L
.92669 .63462 L
.92839 .65385 L
.92666 .67308 L
.92308 .69006 L
.92186 .69231 L
.91485 .71154 L
.90755 .73077 L
.90418 .75 L
.91035 .76923 L
.92308 .7883 L
.92337 .78846 L
.93699 .80769 L
.94231 .8169 L
.94701 .82692 L
.95302 .84615 L
.95476 .86538 L
.95189 .88462 L
.94331 .90385 L
.94231 .90546 L
.92533 .92308 L
.92308 .92457 L
.90385 .93345 L
.88462 .93606 L
.86538 .93318 L
.84615 .92406 L
.84467 .92308 L
.82692 .90512 L
.82608 .90385 L
.81658 .88462 L
.81219 .86538 L
.81144 .84615 L
.81335 .82692 L
.81667 .80769 L
.81892 .78846 L
.8146 .76923 L
.80769 .75779 L
.79861 .75 L
.78846 .74074 L
.77735 .73077 L
Mistroke
.76923 .72256 L
.75994 .71154 L
.75 .69642 L
.74804 .69231 L
.74123 .67308 L
.73899 .65385 L
.74101 .63462 L
.74709 .61538 L
.75 .60876 L
.75755 .59615 L
.76923 .5815 L
.77364 .57692 L
.78846 .56491 L
.79938 .55769 L
.80769 .55445 L
Mfstroke
.5 g
.82692 .24426 m
.84615 .2413 L
.86538 .24348 L
.88397 .25 L
.88462 .25038 L
.90385 .26472 L
.90867 .26923 L
.92308 .28737 L
.92376 .28846 L
.93324 .30769 L
.93825 .32692 L
.93935 .34615 L
.93672 .36538 L
.93016 .38462 L
.92308 .39802 L
.91909 .40385 L
.90385 .42125 L
.90197 .42308 L
.88462 .43595 L
.87455 .44231 L
.86538 .44494 L
.84615 .44856 L
.82692 .44683 L
.81288 .44231 L
.80769 .43971 L
.78846 .42652 L
.78444 .42308 L
.76923 .40625 L
.76745 .40385 L
.75584 .38462 L
.75 .37177 L
.74832 .36538 L
.7448 .34615 L
.74556 .32692 L
.75 .30977 L
.75089 .30769 L
.76215 .28846 L
.76923 .27957 L
.77988 .26923 L
.78846 .26253 L
.80769 .25124 L
.80908 .25 L
F
0 g
.82692 .24426 m
.84615 .2413 L
.86538 .24348 L
.88397 .25 L
.88462 .25038 L
.90385 .26472 L
.90867 .26923 L
.92308 .28737 L
.92376 .28846 L
.93324 .30769 L
.93825 .32692 L
.93935 .34615 L
.93672 .36538 L
.93016 .38462 L
.92308 .39802 L
.91909 .40385 L
.90385 .42125 L
.90197 .42308 L
.88462 .43595 L
.87455 .44231 L
.86538 .44494 L
.84615 .44856 L
.82692 .44683 L
.81288 .44231 L
.80769 .43971 L
.78846 .42652 L
.78444 .42308 L
.76923 .40625 L
.76745 .40385 L
.75584 .38462 L
.75 .37177 L
.74832 .36538 L
.7448 .34615 L
.74556 .32692 L
.75 .30977 L
.75089 .30769 L
.76215 .28846 L
.76923 .27957 L
.77988 .26923 L
.78846 .26253 L
.80769 .25124 L
.80908 .25 L
.82692 .24426 L
s
.6 g
.82692 .57379 m
.84615 .57426 L
.85629 .57692 L
.86538 .58079 L
.88462 .59491 L
.88586 .59615 L
.89974 .61538 L
.90385 .62104 L
.90678 .63462 L
.90894 .65385 L
.9067 .67308 L
.90385 .68582 L
.90039 .69231 L
.89004 .71154 L
.88462 .71791 L
.8779 .73077 L
.86538 .73975 L
.84615 .74166 L
.82692 .73746 L
.81263 .73077 L
.80769 .7278 L
.78846 .71323 L
.78664 .71154 L
.77109 .69231 L
.76923 .69057 L
.76263 .67308 L
.75972 .65385 L
.76186 .63462 L
.76923 .61551 L
.76929 .61538 L
.78336 .59615 L
.78846 .59147 L
.80769 .57921 L
.81358 .57692 L
F
0 g
.82692 .57379 m
.84615 .57426 L
.85629 .57692 L
.86538 .58079 L
.88462 .59491 L
.88586 .59615 L
.89974 .61538 L
.90385 .62104 L
.90678 .63462 L
.90894 .65385 L
.9067 .67308 L
.90385 .68582 L
.90039 .69231 L
.89004 .71154 L
.88462 .71791 L
.8779 .73077 L
.86538 .73975 L
.84615 .74166 L
.82692 .73746 L
.81263 .73077 L
.80769 .7278 L
.78846 .71323 L
.78664 .71154 L
.77109 .69231 L
.76923 .69057 L
.76263 .67308 L
.75972 .65385 L
.76186 .63462 L
.76923 .61551 L
.76929 .61538 L
.78336 .59615 L
.78846 .59147 L
.80769 .57921 L
.81358 .57692 L
.82692 .57379 L
s
.6 g
.82692 .26375 m
.84615 .26134 L
.86538 .26421 L
.88065 .26923 L
.88462 .27311 L
.90214 .28846 L
.90385 .29044 L
.91457 .30769 L
.92076 .32692 L
.9221 .34615 L
.9189 .36538 L
.91063 .38462 L
.90385 .39476 L
.89573 .40385 L
.88462 .41273 L
.86538 .42251 L
.86365 .42308 L
.84615 .42618 L
.82692 .42422 L
.82289 .42308 L
.80769 .41628 L
.79121 .40385 L
.78846 .40092 L
.77617 .38462 L
.76923 .37122 L
.7676 .36538 L
.76398 .34615 L
.76523 .32692 L
.76923 .31352 L
.77184 .30769 L
.78536 .28846 L
.78846 .28529 L
.80769 .27127 L
.8118 .26923 L
F
0 g
.82692 .26375 m
.84615 .26134 L
.86538 .26421 L
.88065 .26923 L
.88462 .27311 L
.90214 .28846 L
.90385 .29044 L
.91457 .30769 L
.92076 .32692 L
.9221 .34615 L
.9189 .36538 L
.91063 .38462 L
.90385 .39476 L
.89573 .40385 L
.88462 .41273 L
.86538 .42251 L
.86365 .42308 L
.84615 .42618 L
.82692 .42422 L
.82289 .42308 L
.80769 .41628 L
.79121 .40385 L
.78846 .40092 L
.77617 .38462 L
.76923 .37122 L
.7676 .36538 L
.76398 .34615 L
.76523 .32692 L
.76923 .31352 L
.77184 .30769 L
.78536 .28846 L
.78846 .28529 L
.80769 .27127 L
.8118 .26923 L
.82692 .26375 L
s
.7 g
.80769 .6051 m
.82692 .59801 L
.84615 .5987 L
.86538 .60779 L
.87384 .61538 L
.88425 .63462 L
.88462 .63598 L
.8873 .65385 L
.88462 .67081 L
.88402 .67308 L
.87425 .69231 L
.86538 .70055 L
.84615 .70967 L
.82692 .70887 L
.80769 .7 L
.79795 .69231 L
.78846 .67994 L
.78603 .67308 L
.78183 .65385 L
.78478 .63462 L
.78846 .6264 L
.79495 .61538 L
F
0 g
.80769 .6051 m
.82692 .59801 L
.84615 .5987 L
.86538 .60779 L
.87384 .61538 L
.88425 .63462 L
.88462 .63598 L
.8873 .65385 L
.88462 .67081 L
.88402 .67308 L
.87425 .69231 L
.86538 .70055 L
.84615 .70967 L
.82692 .70887 L
.80769 .7 L
.79795 .69231 L
.78846 .67994 L
.78603 .67308 L
.78183 .65385 L
.78478 .63462 L
.78846 .6264 L
.79495 .61538 L
.80769 .6051 L
s
.7 g
.82692 .28328 m
.84615 .28066 L
.86538 .28466 L
.87551 .28846 L
.88462 .2965 L
.89391 .30769 L
.90222 .32692 L
.90385 .33777 L
.9039 .34615 L
.90385 .34691 L
.89983 .36538 L
.88804 .38462 L
.88462 .38819 L
.86538 .40104 L
.85645 .40385 L
.84615 .40536 L
.83055 .40385 L
.82692 .40289 L
.80769 .39282 L
.79883 .38462 L
.78846 .36847 L
.78742 .36538 L
.78295 .34615 L
.78476 .32692 L
.78846 .3168 L
.79332 .30769 L
.80769 .29276 L
.81497 .28846 L
F
0 g
.82692 .28328 m
.84615 .28066 L
.86538 .28466 L
.87551 .28846 L
.88462 .2965 L
.89391 .30769 L
.90222 .32692 L
.90385 .33777 L
.9039 .34615 L
.90385 .34691 L
.89983 .36538 L
.88804 .38462 L
.88462 .38819 L
.86538 .40104 L
.85645 .40385 L
.84615 .40536 L
.83055 .40385 L
.82692 .40289 L
.80769 .39282 L
.79883 .38462 L
.78846 .36847 L
.78742 .36538 L
.78295 .34615 L
.78476 .32692 L
.78846 .3168 L
.79332 .30769 L
.80769 .29276 L
.81497 .28846 L
.82692 .28328 L
s
.8 g
.82692 .30735 m
.84615 .30311 L
.86129 .30769 L
.86538 .31017 L
.88097 .32692 L
.88302 .34615 L
.87695 .36538 L
.86538 .37649 L
.84615 .38261 L
.82692 .37941 L
.81275 .36538 L
.80769 .35567 L
.80535 .34615 L
.80769 .32888 L
.80846 .32692 L
.82632 .30769 L
F
0 g
.82692 .30735 m
.84615 .30311 L
.86129 .30769 L
.86538 .31017 L
.88097 .32692 L
.88302 .34615 L
.87695 .36538 L
.86538 .37649 L
.84615 .38261 L
.82692 .37941 L
.81275 .36538 L
.80769 .35567 L
.80535 .34615 L
.80769 .32888 L
.80846 .32692 L
.82632 .30769 L
.82692 .30735 L
s
.8 g
.82692 .63381 m
.84392 .63462 L
.84615 .63606 L
.85434 .65385 L
.84615 .66959 L
.82692 .67135 L
.81516 .65385 L
.82533 .63462 L
F
0 g
.82692 .63381 m
.84392 .63462 L
.84615 .63606 L
.85434 .65385 L
.84615 .66959 L
.82692 .67135 L
.81516 .65385 L
.82533 .63462 L
.82692 .63381 L
s
.6 g
.86538 .77762 m
.88462 .78171 L
.89636 .78846 L
.90385 .79403 L
.9199 .80769 L
.92308 .81233 L
.93303 .82692 L
.9405 .84615 L
.94231 .85735 L
.9426 .86538 L
.94231 .86979 L
.93926 .88462 L
.92833 .90385 L
.92308 .90924 L
.90385 .92062 L
.89343 .92308 L
.88462 .92374 L
.87661 .92308 L
.86538 .92035 L
.84615 .90877 L
.84123 .90385 L
.82948 .88462 L
.82692 .8765 L
.82476 .86538 L
.82473 .84615 L
.82692 .83355 L
.8286 .82692 L
.836 .80769 L
.84615 .79357 L
.84913 .78846 L
F
0 g
.86538 .77762 m
.88462 .78171 L
.89636 .78846 L
.90385 .79403 L
.9199 .80769 L
.92308 .81233 L
.93303 .82692 L
.9405 .84615 L
.94231 .85735 L
.9426 .86538 L
.94231 .86979 L
.93926 .88462 L
.92833 .90385 L
.92308 .90924 L
.90385 .92062 L
.89343 .92308 L
.88462 .92374 L
.87661 .92308 L
.86538 .92035 L
.84615 .90877 L
.84123 .90385 L
.82948 .88462 L
.82692 .8765 L
.82476 .86538 L
.82473 .84615 L
.82692 .83355 L
.8286 .82692 L
.836 .80769 L
.84615 .79357 L
.84913 .78846 L
.86538 .77762 L
s
.5 g
.86538 .05215 m
.88462 .04828 L
.90385 .05138 L
.91965 .05769 L
.92308 .06245 L
.93409 .07692 L
.94046 .09615 L
.94031 .11538 L
.93411 .13462 L
.92308 .15059 L
.92106 .15385 L
.90385 .16524 L
.88462 .1716 L
.86538 .16855 L
.84615 .15425 L
.84572 .15385 L
.8341 .13462 L
.82937 .11538 L
.83003 .09615 L
.83691 .07692 L
.84615 .06428 L
.85245 .05769 L
F
0 g
.86538 .05215 m
.88462 .04828 L
.90385 .05138 L
.91965 .05769 L
.92308 .06245 L
.93409 .07692 L
.94046 .09615 L
.94031 .11538 L
.93411 .13462 L
.92308 .15059 L
.92106 .15385 L
.90385 .16524 L
.88462 .1716 L
.86538 .16855 L
.84615 .15425 L
.84572 .15385 L
.8341 .13462 L
.82937 .11538 L
.83003 .09615 L
.83691 .07692 L
.84615 .06428 L
.85245 .05769 L
.86538 .05215 L
s
.7 g
.88462 .8063 m
.89023 .80769 L
.90385 .81456 L
.91846 .82692 L
.92308 .83279 L
.9273 .84615 L
.93021 .86538 L
.92558 .88462 L
.92308 .89077 L
.91116 .90385 L
.90385 .90675 L
.88462 .91112 L
.86538 .90648 L
.85884 .90385 L
.84615 .89038 L
.84332 .88462 L
.83743 .86538 L
.83824 .84615 L
.84567 .82692 L
.84615 .82612 L
.86538 .80817 L
.86661 .80769 L
F
0 g
.88462 .8063 m
.89023 .80769 L
.90385 .81456 L
.91846 .82692 L
.92308 .83279 L
.9273 .84615 L
.93021 .86538 L
.92558 .88462 L
.92308 .89077 L
.91116 .90385 L
.90385 .90675 L
.88462 .91112 L
.86538 .90648 L
.85884 .90385 L
.84615 .89038 L
.84332 .88462 L
.83743 .86538 L
.83824 .84615 L
.84567 .82692 L
.84615 .82612 L
.86538 .80817 L
.86661 .80769 L
.88462 .8063 L
s
.6 g
.86538 .06555 m
.88462 .06074 L
.90385 .06454 L
.92112 .07692 L
.92308 .08395 L
.92763 .09615 L
.92737 .11538 L
.92308 .1269 L
.92056 .13462 L
.90385 .14812 L
.88462 .15364 L
.86538 .14933 L
.84816 .13462 L
.84615 .12698 L
.84256 .11538 L
.84305 .09615 L
.84615 .08732 L
.85027 .07692 L
F
0 g
.86538 .06555 m
.88462 .06074 L
.90385 .06454 L
.92112 .07692 L
.92308 .08395 L
.92763 .09615 L
.92737 .11538 L
.92308 .1269 L
.92056 .13462 L
.90385 .14812 L
.88462 .15364 L
.86538 .14933 L
.84816 .13462 L
.84615 .12698 L
.84256 .11538 L
.84305 .09615 L
.84615 .08732 L
.85027 .07692 L
.86538 .06555 L
s
.8 g
.88462 .8266 m
.88648 .82692 L
.90385 .83232 L
.91323 .84615 L
.91805 .86538 L
.90987 .88462 L
.90385 .8903 L
.88462 .89799 L
.86538 .89001 L
.8591 .88462 L
.84954 .86538 L
.851 .84615 L
.86538 .83209 L
.87686 .82692 L
F
0 g
.88462 .8266 m
.88648 .82692 L
.90385 .83232 L
.91323 .84615 L
.91805 .86538 L
.90987 .88462 L
.90385 .8903 L
.88462 .89799 L
.86538 .89001 L
.8591 .88462 L
.84954 .86538 L
.851 .84615 L
.86538 .83209 L
.87686 .82692 L
.88462 .8266 L
s
.7 g
.88462 .07613 m
.89131 .07692 L
.90385 .08329 L
.91554 .09615 L
.91488 .11538 L
.90385 .12764 L
.89211 .13462 L
.88462 .13601 L
.87674 .13462 L
.86538 .12749 L
.85581 .11538 L
.85622 .09615 L
.86538 .08497 L
.87968 .07692 L
F
0 g
.88462 .07613 m
.89131 .07692 L
.90385 .08329 L
.91554 .09615 L
.91488 .11538 L
.90385 .12764 L
.89211 .13462 L
.88462 .13601 L
.87674 .13462 L
.86538 .12749 L
.85581 .11538 L
.85622 .09615 L
.86538 .08497 L
.87968 .07692 L
.88462 .07613 L
s
.1 g
.98077 .08071 m
.9798 .07692 L
.97211 .05769 L
.96154 .04179 L
.95868 .03846 L
.94231 .02369 L
.93573 .01923 L
.98077 .01923 L
F
0 g
.98077 .08071 m
.9798 .07692 L
.97211 .05769 L
.96154 .04179 L
.95868 .03846 L
.94231 .02369 L
.93573 .01923 L
s
.1 g
.98077 .58067 m
.97922 .57692 L
.97049 .55769 L
.96154 .53915 L
.96124 .53846 L
.95372 .51923 L
.9508 .5 L
.95407 .48077 L
.96154 .46196 L
.96221 .46154 L
.97231 .44231 L
.98077 .42552 L
F
0 g
.98077 .58067 m
.97922 .57692 L
.97049 .55769 L
.96154 .53915 L
.96124 .53846 L
.95372 .51923 L
.9508 .5 L
.95407 .48077 L
.96154 .46196 L
.96221 .46154 L
.97231 .44231 L
.98077 .42552 L
s
.1 g
.98077 .26155 m
.9748 .25 L
.96504 .23077 L
.96154 .22146 L
.95943 .21154 L
.96103 .19231 L
.96154 .19046 L
.96766 .17308 L
.97506 .15385 L
.98062 .13462 L
.98077 .13392 L
F
0 g
.98077 .26155 m
.9748 .25 L
.96504 .23077 L
.96154 .22146 L
.95943 .21154 L
.96103 .19231 L
.96154 .19046 L
.96766 .17308 L
.97506 .15385 L
.98062 .13462 L
.98077 .13392 L
s
.98077 .97 m
.96766 .98077 L
.98077 .98077 L
F
.98077 .97 m
.96766 .98077 L
s
.98077 .02545 m
.97546 .01923 L
.98077 .01923 L
F
.98077 .02545 m
.97546 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.663 .741 .908 r
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56654 Mtetra
.5035 .56654 .50935 .57245 .51999 .56925 .51417 .56333 Mtetra
.51417 .56333 .51999 .56925 .53068 .56605 .52489 .56011 Mtetra
.663 .742 .908 r
.52489 .56011 .53068 .56605 .54141 .56283 .53564 .55687 Mtetra
.53564 .55687 .54141 .56283 .55218 .5596 .54644 .55362 Mtetra
.54644 .55362 .55218 .5596 .56299 .55636 .55728 .55035 Mtetra
.55728 .55035 .56299 .55636 .57385 .5531 .56816 .54707 Mtetra
.664 .742 .908 r
.56816 .54707 .57385 .5531 .58474 .54983 .57909 .54378 Mtetra
.57909 .54378 .58474 .54983 .59568 .54655 .59006 .54047 Mtetra
.59006 .54047 .59568 .54655 .60667 .54326 .60107 .53715 Mtetra
.60107 .53715 .60667 .54326 .61769 .53995 .61213 .53382 Mtetra
.663 .742 .908 r
.61213 .53382 .61769 .53995 .62876 .53663 .62323 .53048 Mtetra
.62323 .53048 .62876 .53663 .63988 .5333 .63437 .52713 Mtetra
.663 .742 .909 r
.63437 .52713 .63988 .5333 .65104 .52995 .64556 .52376 Mtetra
.64556 .52376 .65104 .52995 .66224 .52659 .65679 .52039 Mtetra
.65679 .52039 .66224 .52659 .67349 .52322 .66807 .517 Mtetra
.663 .743 .909 r
.66807 .517 .67349 .52322 .68478 .51984 .6794 .5136 Mtetra
.6794 .5136 .68478 .51984 .69612 .51644 .69077 .51018 Mtetra
.69077 .51018 .69612 .51644 .7075 .51302 .70218 .50674 Mtetra
.664 .743 .909 r
.70218 .50674 .7075 .51302 .71893 .5096 .71364 .50328 Mtetra
.71364 .50328 .71893 .5096 .73041 .50615 .72515 .49981 Mtetra
.663 .743 .909 r
.72515 .49981 .73041 .50615 .74193 .5027 .73671 .49633 Mtetra
.73671 .49633 .74193 .5027 .7535 .49925 .74831 .49286 Mtetra
.661 .742 .91 r
.74831 .49286 .7535 .49925 .76512 .4958 .75996 .48941 Mtetra
.658 .742 .912 r
.75996 .48941 .76512 .4958 .77679 .49239 .77167 .48604 Mtetra
.652 .742 .916 r
.77167 .48604 .77679 .49239 .78851 .48909 .78344 .48285 Mtetra
.637 .741 .924 r
.78344 .48285 .78851 .48909 .80031 .48602 .7953 .48006 Mtetra
.605 .739 .939 r
.7953 .48006 .80031 .48602 .8122 .48339 .80727 .478 Mtetra
.536 .732 .965 r
.80727 .478 .8122 .48339 .82421 .48151 .81942 .47718 Mtetra
.379 .699 .983 r
.81942 .47718 .82421 .48151 .83639 .48069 .8318 .47813 Mtetra
.018 .538 .861 r
.8318 .47813 .83639 .48069 .84876 .48117 .84447 .48122 Mtetra
.429 0 0 r
.84447 .48122 .84876 .48117 .86134 .48288 .85746 .48635 Mtetra
.603 .085 0 r
.85746 .48635 .86134 .48288 .87408 .48529 .87068 .49267 Mtetra
.616 .175 .181 r
.87068 .49267 .87408 .48529 .88689 .48739 .88398 .49852 Mtetra
.573 .185 .269 r
.88398 .49852 .88689 .48739 .89963 .48796 .89712 .50184 Mtetra
.502 .15 .302 r
.89712 .50184 .89963 .48796 .91214 .48594 .90988 .50086 Mtetra
.406 .08 .296 r
.90988 .50086 .91214 .48594 .92435 .48088 .9221 .49485 Mtetra
.279 0 .247 r
.9221 .49485 .92435 .48088 .93628 .47315 .93382 .48441 Mtetra
.099 0 .133 r
.93382 .48441 .93628 .47315 .94801 .46377 .94519 .47125 Mtetra
0 0 0 r
.94519 .47125 .94801 .46377 .9597 .45398 .95646 .45746 Mtetra
.542 .827 .486 r
.95646 .45746 .9597 .45398 .97148 .44482 .96785 .44473 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.663 .741 .908 r
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56383 Mtetra
.48695 .56383 .49287 .56975 .5035 .56654 .49761 .56061 Mtetra
.663 .742 .908 r
.49761 .56061 .5035 .56654 .51417 .56333 .50831 .55738 Mtetra
.663 .742 .909 r
.50831 .55738 .51417 .56333 .52489 .56011 .51905 .55414 Mtetra
.51905 .55414 .52489 .56011 .53564 .55687 .52983 .55089 Mtetra
.52983 .55089 .53564 .55687 .54644 .55362 .54066 .54762 Mtetra
.663 .743 .909 r
.54066 .54762 .54644 .55362 .55728 .55035 .55153 .54434 Mtetra
.55153 .54434 .55728 .55035 .56816 .54707 .56244 .54104 Mtetra
.664 .743 .909 r
.56244 .54104 .56816 .54707 .57909 .54378 .5734 .53772 Mtetra
.5734 .53772 .57909 .54378 .59006 .54047 .58439 .53439 Mtetra
.58439 .53439 .59006 .54047 .60107 .53715 .59543 .53104 Mtetra
.59543 .53104 .60107 .53715 .61213 .53382 .60652 .52768 Mtetra
.663 .743 .909 r
.60652 .52768 .61213 .53382 .62323 .53048 .61765 .52432 Mtetra
.61765 .52432 .62323 .53048 .63437 .52713 .62883 .52095 Mtetra
.663 .743 .91 r
.62883 .52095 .63437 .52713 .64556 .52376 .64005 .51758 Mtetra
.662 .744 .91 r
.64005 .51758 .64556 .52376 .65679 .52039 .65131 .5142 Mtetra
.662 .744 .911 r
.65131 .5142 .65679 .52039 .66807 .517 .66262 .51081 Mtetra
.663 .745 .911 r
.66262 .51081 .66807 .517 .6794 .5136 .67398 .5074 Mtetra
.663 .746 .912 r
.67398 .5074 .6794 .5136 .69077 .51018 .68538 .50396 Mtetra
.68538 .50396 .69077 .51018 .70218 .50674 .69683 .50049 Mtetra
.664 .746 .911 r
.69683 .50049 .70218 .50674 .71364 .50328 .70832 .497 Mtetra
.70832 .497 .71364 .50328 .72515 .49981 .71986 .49349 Mtetra
.664 .745 .911 r
.71986 .49349 .72515 .49981 .73671 .49633 .73145 .48998 Mtetra
.663 .745 .911 r
.73145 .48998 .73671 .49633 .74831 .49286 .74308 .48648 Mtetra
.66 .744 .912 r
.74308 .48648 .74831 .49286 .75996 .48941 .75477 .48304 Mtetra
.655 .743 .914 r
.75477 .48304 .75996 .48941 .77167 .48604 .76652 .47972 Mtetra
.645 .742 .92 r
.76652 .47972 .77167 .48604 .78344 .48285 .77834 .4767 Mtetra
.621 .739 .931 r
.77834 .4767 .78344 .48285 .7953 .48006 .79026 .47428 Mtetra
.567 .732 .952 r
.79026 .47428 .7953 .48006 .80727 .478 .80234 .47298 Mtetra
.441 .703 .977 r
.80234 .47298 .80727 .478 .81942 .47718 .81465 .47353 Mtetra
.124 .572 .921 r
.81465 .47353 .81942 .47718 .8318 .47813 .82728 .47676 Mtetra
.403 0 0 r
.82728 .47676 .8318 .47813 .84447 .48122 .84032 .48322 Mtetra
.671 .142 0 r
.84032 .48322 .84447 .48122 .85746 .48635 .85381 .49277 Mtetra
.712 .267 .193 r
.85381 .49277 .85746 .48635 .87068 .49267 .86763 .50415 Mtetra
.683 .295 .305 r
.86763 .50415 .87068 .49267 .88398 .49852 .88155 .51486 Mtetra
.624 .275 .359 r
.88155 .51486 .88398 .49852 .89712 .50184 .89521 .52177 Mtetra
.543 .225 .379 r
.89521 .52177 .89712 .50184 .90988 .50086 .90826 .52215 Mtetra
.44 .148 .372 r
.90826 .52215 .90988 .50086 .9221 .49485 .92049 .51487 Mtetra
.307 .039 .332 r
.92049 .51487 .9221 .49485 .93382 .48441 .93193 .50088 Mtetra
.134 0 .245 r
.93193 .50088 .93382 .48441 .94519 .47125 .94283 .48282 Mtetra
0 0 .074 r
.94283 .48282 .94519 .47125 .95646 .45746 .95355 .46383 Mtetra
0 0 0 r
.95355 .46383 .95646 .45746 .96785 .44473 .96443 .44652 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.663 .741 .908 r
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .5611 Mtetra
.47035 .5611 .47634 .56704 .48695 .56383 .48099 .55788 Mtetra
.663 .742 .909 r
.48099 .55788 .48695 .56383 .49761 .56061 .49168 .55465 Mtetra
.662 .742 .909 r
.49168 .55465 .49761 .56061 .50831 .55738 .5024 .55142 Mtetra
.662 .743 .91 r
.5024 .55142 .50831 .55738 .51905 .55414 .51317 .54818 Mtetra
.662 .744 .911 r
.51317 .54818 .51905 .55414 .52983 .55089 .52398 .54494 Mtetra
.662 .745 .911 r
.52398 .54494 .52983 .55089 .54066 .54762 .53484 .54168 Mtetra
.662 .746 .912 r
.53484 .54168 .54066 .54762 .55153 .54434 .54574 .53839 Mtetra
.663 .747 .912 r
.54574 .53839 .55153 .54434 .56244 .54104 .55668 .53508 Mtetra
.664 .747 .912 r
.55668 .53508 .56244 .54104 .5734 .53772 .56766 .53173 Mtetra
.56766 .53173 .5734 .53772 .58439 .53439 .57869 .52836 Mtetra
.57869 .52836 .58439 .53439 .59543 .53104 .58976 .52497 Mtetra
.664 .746 .911 r
.58976 .52497 .59543 .53104 .60652 .52768 .60087 .52158 Mtetra
.663 .745 .912 r
.60087 .52158 .60652 .52768 .61765 .52432 .61203 .5182 Mtetra
.662 .745 .912 r
.61203 .5182 .61765 .52432 .62883 .52095 .62324 .51483 Mtetra
.661 .746 .913 r
.62324 .51483 .62883 .52095 .64005 .51758 .63449 .51148 Mtetra
.66 .747 .914 r
.63449 .51148 .64005 .51758 .65131 .5142 .64579 .50813 Mtetra
.66 .749 .916 r
.64579 .50813 .65131 .5142 .66262 .51081 .65714 .50477 Mtetra
.661 .751 .917 r
.65714 .50477 .66262 .51081 .67398 .5074 .66853 .50137 Mtetra
.662 .753 .918 r
.66853 .50137 .67398 .5074 .68538 .50396 .67996 .49792 Mtetra
.663 .754 .918 r
.67996 .49792 .68538 .50396 .69683 .50049 .69144 .49442 Mtetra
.664 .754 .917 r
.69144 .49442 .69683 .50049 .70832 .497 .70297 .49088 Mtetra
.665 .753 .916 r
.70297 .49088 .70832 .497 .71986 .49349 .71454 .4873 Mtetra
.665 .752 .915 r
.71454 .4873 .71986 .49349 .73145 .48998 .72616 .48372 Mtetra
.663 .75 .915 r
.72616 .48372 .73145 .48998 .74308 .48648 .73783 .48018 Mtetra
.659 .748 .916 r
.73783 .48018 .74308 .48648 .75477 .48304 .74955 .47674 Mtetra
.652 .746 .919 r
.74955 .47674 .75477 .48304 .76652 .47972 .76134 .47349 Mtetra
.636 .743 .926 r
.76134 .47349 .76652 .47972 .77834 .4767 .77321 .47067 Mtetra
.6 .737 .941 r
.77321 .47067 .77834 .4767 .79026 .47428 .78521 .46869 Mtetra
.517 .718 .964 r
.78521 .46869 .79026 .47428 .80234 .47298 .79739 .46827 Mtetra
.308 .644 .968 r
.79739 .46827 .80234 .47298 .81465 .47353 .80988 .47038 Mtetra
0 .367 .761 r
.80988 .47038 .81465 .47353 .82728 .47676 .82278 .47616 Mtetra
.629 .065 0 r
.82278 .47616 .82728 .47676 .84032 .48322 .83623 .48639 Mtetra
.762 .283 .101 r
.83623 .48639 .84032 .48322 .85381 .49277 .85025 .50089 Mtetra
.765 .351 .265 r
.85025 .50089 .85381 .49277 .86763 .50415 .86473 .51795 Mtetra
.725 .354 .347 r
.86473 .51795 .86763 .50415 .88155 .51486 .87933 .53414 Mtetra
.658 .32 .389 r
.87933 .53414 .88155 .51486 .89521 .52177 .89357 .54509 Mtetra
.564 .255 .404 r
.89357 .54509 .89521 .52177 .90826 .52215 .90694 .54699 Mtetra
.438 .16 .393 r
.90694 .54699 .90826 .52215 .92049 .51487 .91918 .53823 Mtetra
.277 .031 .349 r
.91918 .53823 .92049 .51487 .93193 .50088 .9303 .52019 Mtetra
.07 0 .258 r
.9303 .52019 .93193 .50088 .94283 .48282 .94066 .49654 Mtetra
0 0 .091 r
.94066 .49654 .94283 .48282 .95355 .46383 .95077 .47171 Mtetra
0 0 0 r
.95077 .47171 .95355 .46383 .96443 .44652 .96108 .44927 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55837 Mtetra
.663 .741 .909 r
.45369 .55837 .45975 .56432 .47035 .5611 .46432 .55514 Mtetra
.662 .742 .909 r
.46432 .55514 .47035 .5611 .48099 .55788 .47499 .55192 Mtetra
.661 .742 .91 r
.47499 .55192 .48099 .55788 .49168 .55465 .4857 .5487 Mtetra
.66 .743 .912 r
.4857 .5487 .49168 .55465 .5024 .55142 .49645 .54551 Mtetra
.659 .745 .913 r
.49645 .54551 .5024 .55142 .51317 .54818 .50725 .54232 Mtetra
.659 .747 .915 r
.50725 .54232 .51317 .54818 .52398 .54494 .51809 .53914 Mtetra
.659 .75 .918 r
.51809 .53914 .52398 .54494 .53484 .54168 .52897 .53593 Mtetra
.66 .753 .919 r
.52897 .53593 .53484 .54168 .54574 .53839 .5399 .53268 Mtetra
.661 .756 .92 r
.5399 .53268 .54574 .53839 .55668 .53508 .55087 .52937 Mtetra
.663 .757 .92 r
.55087 .52937 .55668 .53508 .56766 .53173 .56189 .52598 Mtetra
.665 .757 .919 r
.56189 .52598 .56766 .53173 .57869 .52836 .57294 .52255 Mtetra
.665 .756 .918 r
.57294 .52255 .57869 .52836 .58976 .52497 .58404 .51909 Mtetra
.664 .754 .917 r
.58404 .51909 .58976 .52497 .60087 .52158 .59519 .51564 Mtetra
.662 .752 .917 r
.59519 .51564 .60087 .52158 .61203 .5182 .60638 .51225 Mtetra
.66 .752 .918 r
.60638 .51225 .61203 .5182 .62324 .51483 .61762 .50891 Mtetra
.657 .753 .921 r
.61762 .50891 .62324 .51483 .63449 .51148 .62891 .50564 Mtetra
.655 .756 .924 r
.62891 .50564 .63449 .51148 .64579 .50813 .64024 .50239 Mtetra
.655 .76 .927 r
.64024 .50239 .64579 .50813 .65714 .50477 .65163 .49912 Mtetra
.656 .765 .93 r
.65163 .49912 .65714 .50477 .66853 .50137 .66305 .4958 Mtetra
.659 .769 .931 r
.66305 .4958 .66853 .50137 .67996 .49792 .67453 .49237 Mtetra
.662 .772 .931 r
.67453 .49237 .67996 .49792 .69144 .49442 .68604 .48881 Mtetra
.666 .772 .929 r
.68604 .48881 .69144 .49442 .70297 .49088 .6976 .48516 Mtetra
.668 .77 .926 r
.6976 .48516 .70297 .49088 .71454 .4873 .7092 .48145 Mtetra
.667 .766 .924 r
.7092 .48145 .71454 .4873 .72616 .48372 .72085 .47774 Mtetra
.665 .761 .922 r
.72085 .47774 .72616 .48372 .73783 .48018 .73255 .47409 Mtetra
.659 .757 .922 r
.73255 .47409 .73783 .48018 .74955 .47674 .7443 .47061 Mtetra
.648 .752 .925 r
.7443 .47061 .74955 .47674 .76134 .47349 .75613 .46743 Mtetra
.625 .747 .934 r
.75613 .46743 .76134 .47349 .77321 .47067 .76806 .46482 Mtetra
.576 .735 .951 r
.76806 .46482 .77321 .47067 .78521 .46869 .78013 .4633 Mtetra
.458 .699 .971 r
.78013 .4633 .78521 .46869 .79739 .46827 .79242 .46375 Mtetra
.163 .564 .932 r
.79242 .46375 .79739 .46827 .80988 .47038 .80507 .46739 Mtetra
0 .185 .6 r
.80507 .46739 .80988 .47038 .82278 .47616 .81823 .4756 Mtetra
.722 .19 0 r
.81823 .4756 .82278 .47616 .83623 .48639 .83206 .48937 Mtetra
.809 .349 .138 r
.83206 .48937 .83623 .48639 .85025 .50089 .84658 .50851 Mtetra
.807 .396 .27 r
.84658 .50851 .85025 .50089 .86473 .51795 .86166 .53088 Mtetra
.767 .39 .341 r
.86166 .53088 .86473 .51795 .87933 .53414 .87689 .55219 Mtetra
.693 .344 .379 r
.87689 .55219 .87933 .53414 .89357 .54509 .89165 .56691 Mtetra
.576 .257 .391 r
.89165 .56691 .89357 .54509 .90694 .54699 .90533 .57017 Mtetra
.402 .122 .37 r
.90533 .57017 .90694 .54699 .91918 .53823 .91756 .55993 Mtetra
.162 0 .301 r
.91756 .55993 .91918 .53823 .9303 .52019 .92838 .53796 Mtetra
0 0 .168 r
.92838 .53796 .9303 .52019 .94066 .49654 .93825 .50899 Mtetra
0 0 0 r
.93825 .50899 .94066 .49654 .95077 .47171 .9478 .47863 Mtetra
.733 .787 .299 r
.9478 .47863 .95077 .47171 .96108 .44927 .9576 .45135 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.663 .741 .908 r
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56209 Mtetra
.41588 .56209 .42206 .56802 .43256 .56481 .42641 .55886 Mtetra
.42641 .55886 .43256 .56481 .44311 .56159 .43698 .55562 Mtetra
.663 .741 .909 r
.43698 .55562 .44311 .56159 .45369 .55837 .44759 .55239 Mtetra
.662 .742 .909 r
.44759 .55239 .45369 .55837 .46432 .55514 .45825 .54917 Mtetra
.66 .742 .911 r
.45825 .54917 .46432 .55514 .47499 .55192 .46894 .54598 Mtetra
.658 .744 .913 r
.46894 .54598 .47499 .55192 .4857 .5487 .47968 .54284 Mtetra
.655 .746 .917 r
.47968 .54284 .4857 .5487 .49645 .54551 .49046 .53976 Mtetra
.652 .75 .922 r
.49046 .53976 .49645 .54551 .50725 .54232 .50128 .53674 Mtetra
.65 .756 .927 r
.50128 .53674 .50725 .54232 .51809 .53914 .51215 .53373 Mtetra
.65 .763 .932 r
.51215 .53373 .51809 .53914 .52897 .53593 .52306 .5307 Mtetra
.652 .771 .936 r
.52306 .5307 .52897 .53593 .5399 .53268 .53402 .52756 Mtetra
.657 .777 .938 r
.53402 .52756 .5399 .53268 .55087 .52937 .54503 .52428 Mtetra
.662 .781 .937 r
.54503 .52428 .55087 .52937 .56189 .52598 .55607 .52085 Mtetra
.666 .781 .935 r
.55607 .52085 .56189 .52598 .57294 .52255 .56716 .51729 Mtetra
.668 .778 .932 r
.56716 .51729 .57294 .52255 .58404 .51909 .57829 .51369 Mtetra
.666 .773 .929 r
.57829 .51369 .58404 .51909 .59519 .51564 .58947 .51013 Mtetra
.661 .768 .929 r
.58947 .51013 .59519 .51564 .60638 .51225 .6007 .50671 Mtetra
.654 .766 .932 r
.6007 .50671 .60638 .51225 .61762 .50891 .61197 .50345 Mtetra
.647 .768 .937 r
.61197 .50345 .61762 .50891 .62891 .50564 .6233 .50036 Mtetra
.641 .774 .944 r
.6233 .50036 .62891 .50564 .64024 .50239 .63468 .49736 Mtetra
.638 .783 .951 r
.63468 .49736 .64024 .50239 .65163 .49912 .64611 .49434 Mtetra
.641 .795 .956 r
.64611 .49434 .65163 .49912 .66305 .4958 .65758 .4912 Mtetra
.648 .805 .959 r
.65758 .4912 .66305 .4958 .67453 .49237 .66909 .48783 Mtetra
.657 .811 .957 r
.66909 .48783 .67453 .49237 .68604 .48881 .68064 .4842 Mtetra
.667 .812 .953 r
.68064 .4842 .68604 .48881 .6976 .48516 .69223 .48034 Mtetra
.673 .806 .947 r
.69223 .48034 .6976 .48516 .7092 .48145 .70386 .47634 Mtetra
.674 .797 .94 r
.70386 .47634 .7092 .48145 .72085 .47774 .71553 .47234 Mtetra
.67 .786 .935 r
.71553 .47234 .72085 .47774 .73255 .47409 .72725 .46845 Mtetra
.661 .775 .934 r
.72725 .46845 .73255 .47409 .7443 .47061 .73904 .46484 Mtetra
.644 .765 .936 r
.73904 .46484 .7443 .47061 .75613 .46743 .75091 .46166 Mtetra
.613 .755 .946 r
.75091 .46166 .75613 .46743 .76806 .46482 .76289 .45924 Mtetra
.548 .736 .963 r
.76289 .45924 .76806 .46482 .78013 .4633 .77503 .45815 Mtetra
.395 .678 .974 r
.77503 .45815 .78013 .4633 .79242 .46375 .78742 .45934 Mtetra
.042 .486 .885 r
.78742 .45934 .79242 .46375 .80507 .46739 .80021 .4642 Mtetra
.469 0 0 r
.80021 .4642 .80507 .46739 .81823 .4756 .81357 .47425 Mtetra
.752 .235 0 r
.81357 .47425 .81823 .4756 .83206 .48937 .82766 .49062 Mtetra
.835 .373 .103 r
.82766 .49062 .83206 .48937 .84658 .50851 .84254 .51308 Mtetra
.845 .418 .217 r
.84254 .51308 .84658 .50851 .86166 .53088 .85805 .5392 Mtetra
.816 .41 .28 r
.85805 .5392 .86166 .53088 .87689 .55219 .87371 .56408 Mtetra
.741 .351 .312 r
.87371 .56408 .87689 .55219 .89165 .56691 .88884 .58136 Mtetra
.581 .214 .31 r
.88884 .58136 .89165 .56691 .90533 .57017 .90273 .58542 Mtetra
.262 0 .24 r
.90273 .58542 .90533 .57017 .91756 .55993 .91495 .57395 Mtetra
0 0 .065 r
.91495 .57395 .91756 .55993 .92838 .53796 .92558 .549 Mtetra
0 0 0 r
.92558 .549 .92838 .53796 .93825 .50899 .93511 .5161 Mtetra
.845 .815 .331 r
.93511 .5161 .93825 .50899 .9478 .47863 .94428 .4817 Mtetra
.949 .887 .487 r
.94428 .4817 .9478 .47863 .9576 .45135 .95374 .45092 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.663 .741 .908 r
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56209 .40966 .55611 Mtetra
.40966 .55611 .41588 .56209 .42641 .55886 .42021 .55286 Mtetra
.663 .741 .909 r
.42021 .55286 .42641 .55886 .43698 .55562 .43081 .54962 Mtetra
.661 .742 .91 r
.43081 .54962 .43698 .55562 .44759 .55239 .44145 .5464 Mtetra
.659 .742 .911 r
.44145 .5464 .44759 .55239 .45825 .54917 .45213 .54323 Mtetra
.655 .744 .915 r
.45213 .54323 .45825 .54917 .46894 .54598 .46285 .54016 Mtetra
.649 .746 .92 r
.46285 .54016 .46894 .54598 .47968 .54284 .47361 .53721 Mtetra
.642 .752 .929 r
.47361 .53721 .47968 .54284 .49046 .53976 .48441 .53442 Mtetra
.633 .761 .939 r
.48441 .53442 .49046 .53976 .50128 .53674 .49526 .53178 Mtetra
.626 .774 .952 r
.49526 .53178 .50128 .53674 .51215 .53373 .50616 .5292 Mtetra
.622 .79 .963 r
.50616 .5292 .51215 .53373 .52306 .5307 .5171 .52657 Mtetra
.625 .809 .97 r
.5171 .52657 .52306 .5307 .53402 .52756 .5281 .52373 Mtetra
.636 .824 .973 r
.5281 .52373 .53402 .52756 .54503 .52428 .53914 .52056 Mtetra
.651 .834 .97 r
.53914 .52056 .54503 .52428 .55607 .52085 .55022 .51702 Mtetra
.665 .834 .964 r
.55022 .51702 .55607 .52085 .56716 .51729 .56135 .51321 Mtetra
.671 .826 .958 r
.56135 .51321 .56716 .51729 .57829 .51369 .57251 .5093 Mtetra
.668 .814 .953 r
.57251 .5093 .57829 .51369 .58947 .51013 .58372 .50551 Mtetra
.657 .803 .953 r
.58372 .50551 .58947 .51013 .6007 .50671 .59498 .50201 Mtetra
.639 .796 .958 r
.59498 .50201 .6007 .50671 .61197 .50345 .6063 .49892 Mtetra
.618 .796 .967 r
.6063 .49892 .61197 .50345 .6233 .50036 .61767 .4962 Mtetra
.598 .806 .979 r
.61767 .4962 .6233 .50036 .63468 .49736 .62911 .4937 Mtetra
.583 .823 .99 r
.62911 .4937 .63468 .49736 .64611 .49434 .6406 .49121 Mtetra
.581 .845 .995 r
.6406 .49121 .64611 .49434 .65758 .4912 .65213 .48845 Mtetra
.594 .866 .994 r
.65213 .48845 .65758 .4912 .66909 .48783 .6637 .48522 Mtetra
.621 .882 .989 r
.6637 .48522 .66909 .48783 .68064 .4842 .67529 .48145 Mtetra
.652 .886 .983 r
.67529 .48145 .68064 .4842 .69223 .48034 .6869 .47719 Mtetra
.675 .877 .974 r
.6869 .47719 .69223 .48034 .70386 .47634 .69855 .47263 Mtetra
.685 .857 .965 r
.69855 .47263 .70386 .47634 .71553 .47234 .71023 .46803 Mtetra
.681 .833 .956 r
.71023 .46803 .71553 .47234 .72725 .46845 .72197 .46364 Mtetra
.667 .81 .952 r
.72197 .46364 .72725 .46845 .73904 .46484 .73378 .45969 Mtetra
.642 .79 .953 r
.73378 .45969 .73904 .46484 .75091 .46166 .74568 .45641 Mtetra
.599 .771 .962 r
.74568 .45641 .75091 .46166 .76289 .45924 .75771 .45411 Mtetra
.516 .741 .976 r
.75771 .45411 .76289 .45924 .77503 .45815 .76991 .45335 Mtetra
.333 .66 .973 r
.76991 .45335 .77503 .45815 .78742 .45934 .78239 .45508 Mtetra
0 .432 .845 r
.78239 .45508 .78742 .45934 .80021 .4642 .79527 .46065 Mtetra
.49 0 0 r
.79527 .46065 .80021 .4642 .81357 .47425 .80874 .47162 Mtetra
.738 .225 0 r
.80874 .47162 .81357 .47425 .82766 .49062 .82296 .48909 Mtetra
.83 .356 0 r
.82296 .48909 .82766 .49062 .84254 .51308 .83798 .51277 Mtetra
.857 .403 .08 r
.83798 .51277 .84254 .51308 .85805 .5392 .85363 .54012 Mtetra
.849 .392 .099 r
.85363 .54012 .85805 .5392 .87371 .56408 .86943 .56602 Mtetra
.784 .294 .047 r
.86943 .56602 .87371 .56408 .88884 .58136 .88467 .58386 Mtetra
.464 0 0 r
.88467 .58386 .88884 .58136 .90273 .58542 .89863 .58783 Mtetra
.662 .934 .658 r
.89863 .58783 .90273 .58542 .91495 .57395 .91085 .57555 Mtetra
.964 .924 .591 r
.91085 .57555 .91495 .57395 .92558 .549 .92143 .54926 Mtetra
.995 .871 .556 r
.92143 .54926 .92558 .549 .93511 .5161 .93088 .51474 Mtetra
.997 .851 .566 r
.93088 .51474 .93511 .5161 .94428 .4817 .93995 .47874 Mtetra
.99 .849 .607 r
.93995 .47874 .94428 .4817 .95374 .45092 .94932 .44658 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.663 .741 .908 r
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55009 Mtetra
.40339 .55009 .40966 .55611 .42021 .55286 .41397 .54684 Mtetra
.661 .741 .909 r
.41397 .54684 .42021 .55286 .43081 .54962 .42459 .5436 Mtetra
.659 .742 .911 r
.42459 .5436 .43081 .54962 .44145 .5464 .43526 .54043 Mtetra
.653 .743 .915 r
.43526 .54043 .44145 .5464 .45213 .54323 .44596 .53739 Mtetra
.644 .745 .922 r
.44596 .53739 .45213 .54323 .46285 .54016 .4567 .53456 Mtetra
.63 .75 .934 r
.4567 .53456 .46285 .54016 .47361 .53721 .46748 .53203 Mtetra
.609 .76 .951 r
.46748 .53203 .47361 .53721 .48441 .53442 .47831 .52985 Mtetra
.58 .776 .972 r
.47831 .52985 .48441 .53442 .49526 .53178 .48918 .52801 Mtetra
.546 .798 .991 r
.48918 .52801 .49526 .53178 .50616 .5292 .5001 .52633 Mtetra
.514 .824 1 r
.5001 .52633 .50616 .5292 .5171 .52657 .51108 .52454 Mtetra
.5 .851 .993 r
.51108 .52454 .5171 .52657 .5281 .52373 .52212 .5223 Mtetra
.519 .88 .981 r
.52212 .5223 .5281 .52373 .53914 .52056 .53321 .51937 Mtetra
.567 .906 .976 r
.53321 .51937 .53914 .52056 .55022 .51702 .54434 .51566 Mtetra
.62 .918 .978 r
.54434 .51566 .55022 .51702 .56135 .51321 .5555 .51136 Mtetra
.655 .912 .979 r
.5555 .51136 .56135 .51321 .57251 .5093 .56671 .50682 Mtetra
.659 .89 .981 r
.56671 .50682 .57251 .5093 .58372 .50551 .57795 .50252 Mtetra
.637 .865 .985 r
.57795 .50252 .58372 .50551 .59498 .50201 .58925 .49885 Mtetra
.591 .845 .993 r
.58925 .49885 .59498 .50201 .6063 .49892 .60062 .496 Mtetra
.524 .832 1 r
.60062 .496 .6063 .49892 .61767 .4962 .61205 .49395 Mtetra
.437 .82 .989 r
.61205 .49395 .61767 .4962 .62911 .4937 .62356 .49239 Mtetra
.347 .802 .943 r
.62356 .49239 .62911 .4937 .6406 .49121 .63513 .49085 Mtetra
.291 .786 .873 r
.63513 .49085 .6406 .49121 .65213 .48845 .64674 .48882 Mtetra
.302 .797 .824 r
.64674 .48882 .65213 .48845 .6637 .48522 .65838 .48588 Mtetra
.382 .845 .828 r
.65838 .48588 .6637 .48522 .67529 .48145 .67002 .48185 Mtetra
.502 .909 .875 r
.67002 .48185 .67529 .48145 .6869 .47719 .68166 .47686 Mtetra
.612 .948 .929 r
.68166 .47686 .6869 .47719 .69855 .47263 .69331 .47126 Mtetra
.676 .945 .961 r
.69331 .47126 .69855 .47263 .71023 .46803 .70499 .46555 Mtetra
.693 .912 .971 r
.70499 .46555 .71023 .46803 .72197 .46364 .71672 .4602 Mtetra
.677 .87 .972 r
.71672 .4602 .72197 .46364 .73378 .45969 .72854 .45558 Mtetra
.641 .833 .974 r
.72854 .45558 .73378 .45969 .74568 .45641 .74047 .45197 Mtetra
.581 .799 .982 r
.74047 .45197 .74568 .45641 .75771 .45411 .75254 .44967 Mtetra
.473 .752 .991 r
.75254 .44967 .75771 .45411 .76991 .45335 .7648 .44914 Mtetra
.261 .645 .964 r
.7648 .44914 .76991 .45335 .78239 .45508 .77734 .45118 Mtetra
0 .398 .809 r
.77734 .45118 .78239 .45508 .79527 .46065 .79027 .45698 Mtetra
.476 0 0 r
.79027 .45698 .79527 .46065 .80874 .47162 .80377 .46788 Mtetra
.684 .172 0 r
.80377 .46788 .80874 .47162 .82296 .48909 .81796 .4848 Mtetra
.764 .284 0 r
.81796 .4848 .82296 .48909 .83798 .51277 .8329 .5074 Mtetra
.765 .304 0 r
.8329 .5074 .83798 .51277 .85363 .54012 .8484 .53316 Mtetra
.662 .214 0 r
.8484 .53316 .85363 .54012 .86943 .56602 .86402 .55722 Mtetra
0 .113 .661 r
.86402 .55722 .86943 .56602 .88467 .58386 .8791 .57337 Mtetra
.461 .563 .872 r
.8791 .57337 .88467 .58386 .89863 .58783 .89295 .57622 Mtetra
.787 .701 .77 r
.89295 .57622 .89863 .58783 .91085 .57555 .90518 .56361 Mtetra
.883 .726 .682 r
.90518 .56361 .91085 .57555 .92143 .54926 .91585 .53776 Mtetra
.918 .736 .641 r
.91585 .53776 .92143 .54926 .93088 .51474 .92548 .50416 Mtetra
.932 .747 .631 r
.92548 .50416 .93088 .51474 .93995 .47874 .93476 .46924 Mtetra
.933 .762 .647 r
.93476 .46924 .93995 .47874 .94932 .44658 .94432 .43802 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55985 .3655 .55385 Mtetra
.663 .741 .908 r
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .54731 Mtetra
.38651 .54731 .39285 .55335 .40339 .55009 .39708 .54404 Mtetra
.662 .741 .909 r
.39708 .54404 .40339 .55009 .41397 .54684 .40768 .54078 Mtetra
.659 .741 .911 r
.40768 .54078 .41397 .54684 .42459 .5436 .41833 .53759 Mtetra
.654 .742 .914 r
.41833 .53759 .42459 .5436 .43526 .54043 .42902 .53453 Mtetra
.643 .743 .922 r
.42902 .53453 .43526 .54043 .44596 .53739 .43974 .53173 Mtetra
.623 .747 .935 r
.43974 .53173 .44596 .53739 .4567 .53456 .4505 .52936 Mtetra
.587 .753 .957 r
.4505 .52936 .4567 .53456 .46748 .53203 .46129 .52761 Mtetra
.524 .763 .984 r
.46129 .52761 .46748 .53203 .47831 .52985 .47213 .52657 Mtetra
.411 .763 .995 r
.47213 .52657 .47831 .52985 .48918 .52801 .48302 .52619 Mtetra
.234 .719 .928 r
.48302 .52619 .48918 .52801 .5001 .52633 .49397 .52617 Mtetra
.052 .619 .751 r
.49397 .52617 .5001 .52633 .51108 .52454 .50498 .52594 Mtetra
.03 0 0 r
.50498 .52594 .51108 .52454 .52212 .5223 .51607 .52484 Mtetra
0 0 0 r
.51607 .52484 .52212 .5223 .53321 .51937 .52721 .52236 Mtetra
.52721 .52236 .53321 .51937 .54434 .51566 .5384 .51834 Mtetra
.309 .776 .653 r
.5384 .51834 .54434 .51566 .5555 .51136 .54962 .51312 Mtetra
.468 .887 .787 r
.54962 .51312 .5555 .51136 .56671 .50682 .56088 .50744 Mtetra
.546 .929 .887 r
.56088 .50744 .56671 .50682 .57795 .50252 .57217 .50217 Mtetra
.522 .909 .937 r
.57217 .50217 .57795 .50252 .58925 .49885 .58351 .49809 Mtetra
.398 .842 .932 r
.58351 .49809 .58925 .49885 .60062 .496 .59493 .49559 Mtetra
.177 .709 .832 r
.59493 .49559 .60062 .496 .61205 .49395 .60644 .4946 Mtetra
.077 0 0 r
.60644 .4946 .61205 .49395 .62356 .49239 .61805 .49459 Mtetra
.238 0 0 r
.61805 .49459 .62356 .49239 .63513 .49085 .62973 .49466 Mtetra
.278 0 0 r
.62973 .49466 .63513 .49085 .64674 .48882 .64145 .49386 Mtetra
.231 0 0 r
.64145 .49386 .64674 .48882 .65838 .48588 .65318 .4914 Mtetra
.117 0 0 r
.65318 .4914 .65838 .48588 .67002 .48185 .66488 .48696 Mtetra
0 0 0 r
.66488 .48696 .67002 .48185 .68166 .47686 .67655 .48073 Mtetra
.67655 .48073 .68166 .47686 .69331 .47126 .68818 .47338 Mtetra
.528 .906 .738 r
.68818 .47338 .69331 .47126 .70499 .46555 .69983 .46579 Mtetra
.657 .97 .892 r
.69983 .46579 .70499 .46555 .71672 .4602 .71154 .45877 Mtetra
.678 .946 .96 r
.71154 .45877 .71672 .4602 .72854 .45558 .72334 .45294 Mtetra
.635 .893 .986 r
.72334 .45294 .72854 .45558 .74047 .45197 .73528 .44868 Mtetra
.549 .836 .998 r
.73528 .44868 .74047 .45197 .75254 .44967 .74739 .44621 Mtetra
.404 .761 .994 r
.74739 .44621 .75254 .44967 .7648 .44914 .7597 .44583 Mtetra
.156 .617 .931 r
.7597 .44583 .7648 .44914 .77734 .45118 .7723 .44807 Mtetra
0 .361 .747 r
.7723 .44807 .77734 .45118 .79027 .45698 .78527 .45376 Mtetra
.472 0 0 r
.78527 .45376 .79027 .45698 .80377 .46788 .79873 .46386 Mtetra
.62 .1 0 r
.79873 .46386 .80377 .46788 .81796 .4848 .81279 .47899 Mtetra
.642 .166 0 r
.81279 .47899 .81796 .4848 .8329 .5074 .82747 .49865 Mtetra
0 0 .456 r
.82747 .49865 .8329 .5074 .8484 .53316 .8426 .52056 Mtetra
0 .095 .651 r
.8426 .52056 .8484 .53316 .86402 .55722 .85779 .54046 Mtetra
.269 .345 .757 r
.85779 .54046 .86402 .55722 .8791 .57337 .87248 .55305 Mtetra
.562 .497 .74 r
.87248 .55305 .8791 .57337 .89295 .57622 .88609 .55386 Mtetra
.712 .572 .696 r
.88609 .55386 .89295 .57622 .90518 .56361 .89832 .54123 Mtetra
.79 .615 .663 r
.89832 .54123 .90518 .56361 .91585 .53776 .90921 .51715 Mtetra
.835 .645 .646 r
.90921 .51715 .91585 .53776 .92548 .50416 .91921 .48645 Mtetra
.861 .672 .644 r
.91921 .48645 .92548 .50416 .93476 .46924 .92892 .45468 Mtetra
.875 .698 .66 r
.92892 .45468 .93476 .46924 .94432 .43802 .93888 .42622 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.663 .741 .908 r
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .54731 .38013 .54123 Mtetra
.662 .741 .909 r
.38013 .54123 .38651 .54731 .39708 .54404 .39072 .53795 Mtetra
.66 .741 .91 r
.39072 .53795 .39708 .54404 .40768 .54078 .40135 .53471 Mtetra
.656 .741 .913 r
.40135 .53471 .40768 .54078 .41833 .53759 .41202 .53159 Mtetra
.645 .742 .919 r
.41202 .53159 .41833 .53759 .42902 .53453 .42272 .52872 Mtetra
.624 .743 .932 r
.42272 .52872 .42902 .53453 .43974 .53173 .43346 .52634 Mtetra
.581 .745 .955 r
.43346 .52634 .43974 .53173 .4505 .52936 .44423 .52475 Mtetra
.488 .742 .984 r
.44423 .52475 .4505 .52936 .46129 .52761 .45503 .52427 Mtetra
.281 .694 .971 r
.45503 .52427 .46129 .52761 .47213 .52657 .46586 .52511 Mtetra
0 .485 .734 r
.46586 .52511 .47213 .52657 .48302 .52619 .47676 .52717 Mtetra
.397 0 0 r
.47676 .52717 .48302 .52619 .49397 .52617 .48772 .52987 Mtetra
.483 0 0 r
.48772 .52987 .49397 .52617 .50498 .52594 .49877 .53222 Mtetra
.462 0 .063 r
.49877 .53222 .50498 .52594 .51607 .52484 .50991 .53302 Mtetra
.386 0 .088 r
.50991 .53302 .51607 .52484 .52721 .52236 .52113 .5313 Mtetra
.265 0 .045 r
.52113 .5313 .52721 .52236 .5384 .51834 .53241 .52677 Mtetra
.104 0 0 r
.53241 .52677 .5384 .51834 .54962 .51312 .5437 .52004 Mtetra
0 0 0 r
.5437 .52004 .54962 .51312 .56088 .50744 .55502 .51241 Mtetra
.55502 .51241 .56088 .50744 .57217 .50217 .56636 .50548 Mtetra
.56636 .50548 .57217 .50217 .58351 .49809 .57776 .50061 Mtetra
.048 0 0 r
.57776 .50061 .58351 .49809 .59493 .49559 .58925 .49852 Mtetra
.327 0 0 r
.58925 .49852 .59493 .49559 .60644 .4946 .60085 .49909 Mtetra
.486 0 0 r
.60085 .49909 .60644 .4946 .61805 .49459 .61259 .50139 Mtetra
.529 .075 .119 r
.61259 .50139 .61805 .49459 .62973 .49466 .62441 .50392 Mtetra
.506 .09 .186 r
.62441 .50392 .62973 .49466 .64145 .49386 .63629 .50501 Mtetra
.441 .052 .203 r
.63629 .50501 .64145 .49386 .65318 .4914 .64814 .5033 Mtetra
.34 0 .176 r
.64814 .5033 .65318 .4914 .66488 .48696 .65992 .49821 Mtetra
.198 0 .097 r
.65992 .49821 .66488 .48696 .67655 .48073 .6716 .49009 Mtetra
.002 0 0 r
.6716 .49009 .67655 .48073 .68818 .47338 .68321 .48004 Mtetra
0 0 0 r
.68321 .48004 .68818 .47338 .69983 .46579 .6948 .46952 Mtetra
.497 .85 .593 r
.6948 .46952 .69983 .46579 .71154 .45877 .70644 .45992 Mtetra
.623 .959 .826 r
.70644 .45992 .71154 .45877 .72334 .45294 .7182 .45219 Mtetra
.605 .941 .942 r
.7182 .45219 .72334 .45294 .73528 .44868 .73013 .44684 Mtetra
.488 .865 .98 r
.73013 .44684 .73528 .44868 .74739 .44621 .74227 .44402 Mtetra
.283 .742 .952 r
.74227 .44402 .74739 .44621 .7597 .44583 .75465 .44377 Mtetra
0 .541 .826 r
.75465 .44377 .7597 .44583 .7723 .44807 .76731 .44623 Mtetra
.306 0 0 r
.76731 .44623 .7723 .44807 .78527 .45376 .78031 .45177 Mtetra
.509 0 0 r
.78031 .45177 .78527 .45376 .79873 .46386 .79372 .46083 Mtetra
.596 .051 0 r
.79372 .46083 .79873 .46386 .81279 .47899 .80761 .47362 Mtetra
.55 .057 0 r
.80761 .47362 .81279 .47899 .82747 .49865 .82196 .48945 Mtetra
0 .074 .63 r
.82196 .48945 .82747 .49865 .8426 .52056 .83662 .50633 Mtetra
.117 .277 .752 r
.83662 .50633 .8426 .52056 .85779 .54046 .85127 .52083 Mtetra
.426 .418 .747 r
.85127 .52083 .85779 .54046 .87248 .55305 .86546 .52884 Mtetra
.596 .495 .709 r
.86546 .52884 .87248 .55305 .88609 .55386 .87877 .52703 Mtetra
.693 .542 .677 r
.87877 .52703 .88609 .55386 .89832 .54123 .89096 .51434 Mtetra
.753 .577 .658 r
.89096 .51434 .89832 .54123 .90921 .51715 .90211 .49255 Mtetra
.793 .607 .649 r
.90211 .49255 .90921 .51715 .91921 .48645 .91256 .46559 Mtetra
.821 .636 .653 r
.91256 .46559 .91921 .48645 .92892 .45468 .9228 .43791 Mtetra
.838 .668 .672 r
.9228 .43791 .92892 .45468 .93888 .42622 .93325 .41303 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53842 Mtetra
.36312 .53842 .36958 .54452 .38013 .54123 .37369 .53511 Mtetra
.662 .741 .909 r
.37369 .53511 .38013 .54123 .39072 .53795 .38431 .53182 Mtetra
.658 .741 .911 r
.38431 .53182 .39072 .53795 .40135 .53471 .39497 .52862 Mtetra
.65 .741 .916 r
.39497 .52862 .40135 .53471 .41202 .53159 .40566 .52561 Mtetra
.632 .74 .926 r
.40566 .52561 .41202 .53159 .42272 .52872 .41638 .52304 Mtetra
.593 .739 .945 r
.41638 .52304 .42272 .52872 .43346 .52634 .42712 .52128 Mtetra
.501 .73 .975 r
.42712 .52128 .43346 .52634 .44423 .52475 .43789 .52083 Mtetra
.264 .662 .967 r
.43789 .52083 .44423 .52475 .45503 .52427 .44867 .52223 Mtetra
.232 0 0 r
.44867 .52223 .45503 .52427 .46586 .52511 .45949 .52583 Mtetra
.581 .024 0 r
.45949 .52583 .46586 .52511 .47676 .52717 .47036 .53146 Mtetra
.654 .188 .133 r
.47036 .53146 .47676 .52717 .48772 .52987 .48133 .53821 Mtetra
.636 .227 .252 r
.48133 .53821 .48772 .52987 .49877 .53222 .49241 .5444 Mtetra
.582 .208 .298 r
.49241 .5444 .49877 .53222 .50991 .53302 .50362 .54801 Mtetra
.5 .148 .3 r
.50362 .54801 .50991 .53302 .52113 .5313 .51493 .54742 Mtetra
.39 .052 .267 r
.51493 .54742 .52113 .5313 .53241 .52677 .52631 .54214 Mtetra
.254 0 .194 r
.52631 .54214 .53241 .52677 .5437 .52004 .53771 .53313 Mtetra
.113 0 .083 r
.53771 .53313 .5437 .52004 .55502 .51241 .54911 .52258 Mtetra
.029 0 0 r
.54911 .52258 .55502 .51241 .56636 .50548 .56052 .5131 Mtetra
.099 0 0 r
.56052 .5131 .56636 .50548 .57776 .50061 .57198 .50692 Mtetra
.329 0 0 r
.57198 .50692 .57776 .50061 .58925 .49852 .58355 .50522 Mtetra
.53 .074 .115 r
.58355 .50522 .58925 .49852 .60085 .49909 .59527 .50783 Mtetra
.613 .197 .231 r
.59527 .50783 .60085 .49909 .61259 .50139 .60716 .51329 Mtetra
.618 .237 .299 r
.60716 .51329 .61259 .50139 .62441 .50392 .61917 .51922 Mtetra
.58 .225 .332 r
.61917 .51922 .62441 .50392 .63629 .50501 .63123 .52293 Mtetra
.51 .176 .336 r
.63123 .52293 .63629 .50501 .64814 .5033 .64324 .52227 Mtetra
.412 .093 .313 r
.64324 .52227 .64814 .5033 .65992 .49821 .65512 .51629 Mtetra
.28 0 .255 r
.65512 .51629 .65992 .49821 .6716 .49009 .66682 .5055 Mtetra
.108 0 .149 r
.66682 .5055 .6716 .49009 .68321 .48004 .67838 .49167 Mtetra
0 0 0 r
.67838 .49167 .68321 .48004 .6948 .46952 .68988 .47709 Mtetra
.68988 .47709 .6948 .46952 .70644 .45992 .70143 .46387 Mtetra
.523 .858 .582 r
.70143 .46387 .70644 .45992 .7182 .45219 .71312 .45348 Mtetra
.541 .923 .803 r
.71312 .45348 .7182 .45219 .73013 .44684 .72503 .44658 Mtetra
.387 .846 .886 r
.72503 .44658 .73013 .44684 .74227 .44402 .73719 .44323 Mtetra
.105 .654 .818 r
.73719 .44323 .74227 .44402 .75465 .44377 .74964 .44314 Mtetra
.211 0 0 r
.74964 .44314 .75465 .44377 .76731 .44623 .76238 .44603 Mtetra
.445 0 0 r
.76238 .44603 .76731 .44623 .78031 .45177 .77544 .45169 Mtetra
.574 0 0 r
.77544 .45169 .78031 .45177 .79372 .46083 .78885 .45999 Mtetra
.624 .059 0 r
.78885 .45999 .79372 .46083 .80761 .47362 .8026 .47064 Mtetra
.565 .014 0 r
.8026 .47064 .80761 .47362 .82196 .48945 .81665 .48277 Mtetra
0 .187 .702 r
.81665 .48277 .82196 .48945 .83662 .50633 .83086 .49465 Mtetra
.237 .401 .824 r
.83086 .49465 .83662 .50633 .85127 .52083 .84498 .50366 Mtetra
.506 .489 .772 r
.84498 .50366 .85127 .52083 .86546 .52884 .85868 .50691 Mtetra
.633 .529 .718 r
.85868 .50691 .86546 .52884 .87877 .52703 .87168 .50224 Mtetra
.704 .556 .684 r
.87168 .50224 .87877 .52703 .89096 .51434 .88382 .48919 Mtetra
.75 .581 .666 r
.88382 .48919 .89096 .51434 .90211 .49255 .89518 .46935 Mtetra
.784 .607 .661 r
.89518 .46935 .90211 .49255 .91256 .46559 .90604 .44579 Mtetra
.808 .636 .668 r
.90604 .44579 .91256 .46559 .9228 .43791 .91676 .42192 Mtetra
.825 .668 .689 r
.91676 .42192 .9228 .43791 .93325 .41303 .92766 .4004 Mtetra
.663 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54173 .34605 .5356 Mtetra
.34605 .5356 .35259 .54173 .36312 .53842 .35661 .53227 Mtetra
.35661 .53227 .36312 .53842 .37369 .53511 .36721 .52895 Mtetra
.661 .741 .909 r
.36721 .52895 .37369 .53511 .38431 .53182 .37786 .52566 Mtetra
.656 .741 .912 r
.37786 .52566 .38431 .53182 .39497 .52862 .38853 .52251 Mtetra
.643 .74 .919 r
.38853 .52251 .39497 .52862 .40566 .52561 .39924 .51966 Mtetra
.614 .737 .933 r
.39924 .51966 .40566 .52561 .41638 .52304 .40998 .51748 Mtetra
.546 .728 .959 r
.40998 .51748 .41638 .52304 .42712 .52128 .42072 .51651 Mtetra
.362 .681 .978 r
.42072 .51651 .42712 .52128 .43789 .52083 .43147 .51754 Mtetra
0 .423 .782 r
.43147 .51754 .43789 .52083 .44867 .52223 .44222 .52138 Mtetra
.615 .051 0 r
.44222 .52138 .44867 .52223 .45949 .52583 .453 .52857 Mtetra
.735 .273 .153 r
.453 .52857 .45949 .52583 .47036 .53146 .46383 .53887 Mtetra
.731 .335 .298 r
.46383 .53887 .47036 .53146 .48133 .53821 .47477 .55092 Mtetra
.692 .333 .361 r
.47477 .55092 .48133 .53821 .49241 .5444 .48587 .56217 Mtetra
.63 .295 .385 r
.48587 .56217 .49241 .5444 .50362 .54801 .49714 .56951 Mtetra
.543 .226 .38 r
.49714 .56951 .50362 .54801 .51493 .54742 .50857 .57042 Mtetra
.427 .125 .347 r
.50857 .57042 .51493 .54742 .52631 .54214 .52008 .56412 Mtetra
.285 0 .284 r
.52008 .56412 .52631 .54214 .53771 .53313 .53161 .55208 Mtetra
.145 0 .193 r
.53161 .55208 .53771 .53313 .54911 .52258 .54312 .53761 Mtetra
.078 0 .104 r
.54312 .53761 .54911 .52258 .56052 .5131 .55462 .52468 Mtetra
.181 0 .077 r
.55462 .52468 .56052 .5131 .57198 .50692 .56615 .51664 Mtetra
.424 .012 .151 r
.56615 .51664 .57198 .50692 .58355 .50522 .57782 .51524 Mtetra
.603 .201 .254 r
.57782 .51524 .58355 .50522 .59527 .50783 .58967 .52025 Mtetra
.666 .292 .327 r
.58967 .52025 .59527 .50783 .60716 .51329 .60173 .52957 Mtetra
.661 .312 .37 r
.60173 .52957 .60716 .51329 .61917 .51922 .61395 .53971 Mtetra
.617 .288 .39 r
.61395 .53971 .61917 .51922 .63123 .52293 .62623 .54671 Mtetra
.541 .23 .39 r
.62623 .54671 .63123 .52293 .64324 .52227 .63842 .54736 Mtetra
.433 .14 .366 r
.63842 .54736 .64324 .52227 .65512 .51629 .65041 .54024 Mtetra
.288 .014 .311 r
.65041 .54024 .65512 .51629 .66682 .5055 .66214 .52612 Mtetra
.105 0 .215 r
.66214 .52612 .66682 .5055 .67838 .49167 .67364 .50755 Mtetra
0 0 .062 r
.67364 .50755 .67838 .49167 .68988 .47709 .68504 .48789 Mtetra
0 0 0 r
.68504 .48789 .68988 .47709 .70143 .46387 .69647 .47019 Mtetra
.69647 .47019 .70143 .46387 .71312 .45348 .70807 .45649 Mtetra
.503 .872 .651 r
.70807 .45649 .71312 .45348 .72503 .44658 .71994 .44768 Mtetra
.29 .784 .749 r
.71994 .44768 .72503 .44658 .73719 .44323 .73213 .44368 Mtetra
.073 0 0 r
.73213 .44368 .73719 .44323 .74964 .44314 .74466 .44389 Mtetra
.38 0 0 r
.74466 .44389 .74964 .44314 .76238 .44603 .75752 .44752 Mtetra
.549 0 0 r
.75752 .44752 .76238 .44603 .77544 .45169 .77068 .45379 Mtetra
.625 .083 0 r
.77068 .45379 .77544 .45169 .78885 .45999 .78413 .46197 Mtetra
.65 .112 0 r
.78413 .46197 .78885 .45999 .8026 .47064 .79783 .47126 Mtetra
.619 .055 0 r
.79783 .47126 .8026 .47064 .81665 .48277 .81168 .48055 Mtetra
.394 0 0 r
.81168 .48055 .81665 .48277 .83086 .49465 .82556 .4883 Mtetra
.233 .552 .931 r
.82556 .4883 .83086 .49465 .84498 .50366 .83926 .49259 Mtetra
.581 .618 .853 r
.83926 .49259 .84498 .50366 .85868 .50691 .85256 .49156 Mtetra
.694 .614 .762 r
.85256 .49156 .85868 .50691 .87168 .50224 .86527 .48404 Mtetra
.747 .616 .713 r
.86527 .48404 .87168 .50224 .88382 .48919 .87733 .47013 Mtetra
.78 .627 .69 r
.87733 .47013 .88382 .48919 .89518 .46935 .88883 .45132 Mtetra
.805 .646 .684 r
.88883 .45132 .89518 .46935 .90604 .44579 .89998 .43005 Mtetra
.824 .671 .693 r
.89998 .43005 .90604 .44579 .91676 .42192 .91105 .40886 Mtetra
.836 .702 .715 r
.91105 .40886 .91676 .42192 .92766 .4004 .9223 .38975 Mtetra
.663 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52943 Mtetra
.33948 .52943 .34605 .5356 .35661 .53227 .35006 .52608 Mtetra
.662 .741 .909 r
.35006 .52608 .35661 .53227 .36721 .52895 .36069 .52274 Mtetra
.66 .741 .91 r
.36069 .52274 .36721 .52895 .37786 .52566 .37135 .51946 Mtetra
.653 .74 .914 r
.37135 .51946 .37786 .52566 .38853 .52251 .38205 .51636 Mtetra
.635 .738 .922 r
.38205 .51636 .38853 .52251 .39924 .51966 .39278 .5137 Mtetra
.593 .732 .94 r
.39278 .5137 .39924 .51966 .40998 .51748 .40352 .51195 Mtetra
.484 .707 .968 r
.40352 .51195 .40998 .51748 .42072 .51651 .41426 .51189 Mtetra
.168 .58 .936 r
.41426 .51189 .42072 .51651 .43147 .51754 .42499 .51458 Mtetra
.463 0 0 r
.42499 .51458 .43147 .51754 .44222 .52138 .43569 .52117 Mtetra
.757 .26 .042 r
.43569 .52117 .44222 .52138 .453 .52857 .4464 .53241 Mtetra
.795 .381 .266 r
.4464 .53241 .453 .52857 .46383 .53887 .45715 .54802 Mtetra
.774 .407 .36 r
.45715 .54802 .46383 .53887 .47477 .55092 .46804 .56612 Mtetra
.73 .39 .403 r
.46804 .56612 .47477 .55092 .48587 .56217 .47914 .58318 Mtetra
.664 .341 .418 r
.47914 .58318 .48587 .56217 .49714 .56951 .49047 .59485 Mtetra
.566 .26 .408 r
.49047 .59485 .49714 .56951 .50857 .57042 .50202 .5975 Mtetra
.428 .139 .37 r
.50202 .5975 .50857 .57042 .52008 .56412 .51368 .59 Mtetra
.252 0 .296 r
.51368 .59 .52008 .56412 .53161 .55208 .52537 .57442 Mtetra
.077 0 .196 r
.52537 .57442 .53161 .55208 .54312 .53761 .53702 .55538 Mtetra
.003 0 .11 r
.53702 .55538 .54312 .53761 .55462 .52468 .54862 .53841 Mtetra
.147 0 .107 r
.54862 .53841 .55462 .52468 .56615 .51664 .56024 .52809 Mtetra
.45 .058 .203 r
.56024 .52809 .56615 .51664 .57782 .51524 .572 .52683 Mtetra
.643 .259 .302 r
.572 .52683 .57782 .51524 .58967 .52025 .58398 .53436 Mtetra
.703 .343 .362 r
.58398 .53436 .58967 .52025 .60173 .52957 .59621 .54784 Mtetra
.695 .355 .396 r
.59621 .54784 .60173 .52957 .61395 .53971 .60865 .56257 Mtetra
.646 .323 .411 r
.60865 .56257 .61395 .53971 .62623 .54671 .62115 .57319 Mtetra
.558 .253 .406 r
.62115 .57319 .62623 .54671 .63842 .54736 .63354 .57531 Mtetra
.427 .142 .376 r
.63354 .57531 .63842 .54736 .65041 .54024 .64565 .56693 Mtetra
.243 0 .31 r
.64565 .56693 .65041 .54024 .66214 .52612 .65741 .5491 Mtetra
.01 0 .196 r
.65741 .5491 .66214 .52612 .67364 .50755 .66886 .52532 Mtetra
0 0 .03 r
.66886 .52532 .67364 .50755 .68504 .48789 .68015 .50012 Mtetra
0 0 0 r
.68015 .50012 .68504 .48789 .69647 .47019 .69147 .47755 Mtetra
.597 .808 .401 r
.69147 .47755 .69647 .47019 .70807 .45649 .70299 .46031 Mtetra
.561 .881 .606 r
.70299 .46031 .70807 .45649 .71994 .44768 .71483 .44949 Mtetra
.261 .754 .676 r
.71483 .44949 .71994 .44768 .73213 .44368 .72706 .4449 Mtetra
.194 0 0 r
.72706 .4449 .73213 .44368 .74466 .44389 .73968 .44561 Mtetra
.489 0 0 r
.73968 .44561 .74466 .44389 .75752 .44752 .75268 .45033 Mtetra
.614 .082 0 r
.75268 .45033 .75752 .44752 .77068 .45379 .76599 .45776 Mtetra
.657 .154 .039 r
.76599 .45776 .77068 .45379 .78413 .46197 .77956 .46657 Mtetra
.659 .165 .066 r
.77956 .46657 .78413 .46197 .79783 .47126 .79329 .47549 Mtetra
.625 .117 .02 r
.79329 .47549 .79783 .47126 .81168 .48055 .80707 .48313 Mtetra
.507 0 0 r
.80707 .48313 .81168 .48055 .82556 .4883 .82076 .48803 Mtetra
0 .547 .708 r
.82076 .48803 .82556 .4883 .83926 .49259 .83418 .48875 Mtetra
.648 .87 .982 r
.83418 .48875 .83926 .49259 .85256 .49156 .8472 .4842 Mtetra
.801 .794 .845 r
.8472 .4842 .85256 .49156 .86527 .48404 .85969 .474 Mtetra
.834 .744 .764 r
.85969 .474 .86527 .48404 .87733 .47013 .87165 .45872 Mtetra
.85 .727 .728 r
.87165 .45872 .87733 .47013 .88883 .45132 .88319 .43987 Mtetra
.861 .73 .716 r
.88319 .43987 .88883 .45132 .89998 .43005 .89449 .41947 Mtetra
.869 .745 .723 r
.89449 .41947 .89998 .43005 .91105 .40886 .90577 .39954 Mtetra
.871 .767 .745 r
.90577 .39954 .91105 .40886 .9223 .38975 .91722 .38156 Mtetra
.663 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52943 .33285 .52321 Mtetra
.33285 .52321 .33948 .52943 .35006 .52608 .34346 .51984 Mtetra
.662 .741 .909 r
.34346 .51984 .35006 .52608 .36069 .52274 .35411 .51648 Mtetra
.659 .74 .91 r
.35411 .51648 .36069 .52274 .37135 .51946 .3648 .51321 Mtetra
.65 .739 .915 r
.3648 .51321 .37135 .51946 .38205 .51636 .37552 .51017 Mtetra
.627 .735 .925 r
.37552 .51017 .38205 .51636 .39278 .5137 .38627 .50767 Mtetra
.572 .724 .945 r
.38627 .50767 .39278 .5137 .40352 .51195 .39702 .50633 Mtetra
.421 .678 .969 r
.39702 .50633 .40352 .51195 .41426 .51189 .40775 .50711 Mtetra
0 .454 .858 r
.40775 .50711 .41426 .51189 .42499 .51458 .41845 .51137 Mtetra
.629 .072 0 r
.41845 .51137 .42499 .51458 .43569 .52117 .42909 .52056 Mtetra
.817 .356 .128 r
.42909 .52056 .43569 .52117 .4464 .53241 .43972 .53564 Mtetra
.835 .44 .3 r
.43972 .53564 .4464 .53241 .45715 .54802 .45039 .55632 Mtetra
.814 .454 .375 r
.45039 .55632 .45715 .54802 .46804 .56612 .46121 .58025 Mtetra
.771 .431 .41 r
.46121 .58025 .46804 .56612 .47914 .58318 .47227 .60294 Mtetra
.7 .373 .42 r
.47227 .60294 .47914 .58318 .49047 .59485 .48365 .6188 Mtetra
.584 .27 .403 r
.48365 .6188 .49047 .59485 .50202 .5975 .4953 .62316 Mtetra
.394 .101 .345 r
.4953 .62316 .50202 .5975 .51368 .59 .50712 .61448 Mtetra
.122 0 .227 r
.50712 .61448 .51368 .59 .52537 .57442 .51898 .59541 Mtetra
0 0 .072 r
.51898 .59541 .52537 .57442 .53702 .55538 .53077 .5719 Mtetra
0 0 0 r
.53077 .5719 .53702 .55538 .54862 .53841 .54249 .55095 Mtetra
.54249 .55095 .54862 .53841 .56024 .52809 .55421 .53834 Mtetra
.431 .021 .159 r
.55421 .53834 .56024 .52809 .572 .52683 .56605 .53707 Mtetra
.678 .284 .292 r
.56605 .53707 .572 .52683 .58398 .53436 .57814 .54682 Mtetra
.743 .376 .357 r
.57814 .54682 .58398 .53436 .59621 .54784 .59052 .56411 Mtetra
.735 .386 .39 r
.59052 .56411 .59621 .54784 .60865 .56257 .60314 .5831 Mtetra
.68 .346 .402 r
.60314 .5831 .60865 .56257 .62115 .57319 .61584 .59712 Mtetra
.571 .254 .391 r
.61584 .59712 .62115 .57319 .63354 .57531 .62841 .6006 Mtetra
.386 .095 .343 r
.62841 .6006 .63354 .57531 .64565 .56693 .64064 .59105 Mtetra
.102 0 .234 r
.64064 .59105 .64565 .56693 .65741 .5491 .65245 .56977 Mtetra
0 0 .057 r
.65245 .56977 .65741 .5491 .66886 .52532 .66388 .54115 Mtetra
0 0 0 r
.66388 .54115 .66886 .52532 .68015 .50012 .67509 .51083 Mtetra
.729 .81 .339 r
.67509 .51083 .68015 .50012 .69147 .47755 .68633 .48386 Mtetra
.798 .911 .516 r
.68633 .48386 .69147 .47755 .70299 .46031 .69779 .46347 Mtetra
.718 .959 .686 r
.69779 .46347 .70299 .46031 .71483 .44949 .70963 .45097 Mtetra
.331 .806 .733 r
.70963 .45097 .71483 .44949 .72706 .4449 .72191 .44607 Mtetra
.25 0 0 r
.72191 .44607 .72706 .4449 .73968 .44561 .73465 .44753 Mtetra
.555 0 0 r
.73465 .44753 .73968 .44561 .75268 .45033 .7478 .45367 Mtetra
.659 .146 .011 r
.7478 .45367 .75268 .45033 .76599 .45776 .76129 .46269 Mtetra
.683 .201 .099 r
.76129 .46269 .76599 .45776 .77956 .46657 .77503 .47279 Mtetra
.669 .202 .135 r
.77503 .47279 .77956 .46657 .79329 .47549 .78888 .48223 Mtetra
.621 .154 .122 r
.78888 .48223 .79329 .47549 .80707 .48313 .80269 .48933 Mtetra
.516 .03 .039 r
.80269 .48933 .80707 .48313 .82076 .48803 .81632 .4926 Mtetra
.248 0 0 r
.81632 .4926 .82076 .48803 .83418 .48875 .82961 .4909 Mtetra
.395 .825 .666 r
.82961 .4909 .83418 .48875 .8472 .4842 .84245 .48365 Mtetra
.851 .995 .832 r
.84245 .48365 .8472 .4842 .85969 .474 .85478 .47103 Mtetra
.929 .919 .783 r
.85478 .47103 .85969 .474 .87165 .45872 .86665 .454 Mtetra
.935 .866 .746 r
.86665 .454 .87165 .45872 .88319 .43987 .87816 .43419 Mtetra
.932 .843 .734 r
.87816 .43419 .88319 .43987 .89449 .41947 .8895 .41344 Mtetra
.925 .839 .741 r
.8895 .41344 .89449 .41947 .90577 .39954 .90085 .39348 Mtetra
.912 .843 .763 r
.90085 .39348 .90577 .39954 .91722 .38156 .91237 .37551 Mtetra
.663 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .52321 .32617 .51694 Mtetra
.32617 .51694 .33285 .52321 .34346 .51984 .33681 .51355 Mtetra
.662 .741 .909 r
.33681 .51355 .34346 .51984 .35411 .51648 .34749 .51018 Mtetra
.658 .74 .911 r
.34749 .51018 .35411 .51648 .3648 .51321 .3582 .5069 Mtetra
.648 .738 .915 r
.3582 .5069 .3648 .51321 .37552 .51017 .36895 .50389 Mtetra
.622 .732 .926 r
.36895 .50389 .37552 .51017 .38627 .50767 .37971 .50151 Mtetra
.557 .715 .946 r
.37971 .50151 .38627 .50767 .39702 .50633 .39048 .50045 Mtetra
.379 .649 .963 r
.39048 .50045 .39702 .50633 .40775 .50711 .40121 .50185 Mtetra
0 .371 .807 r
.40121 .50185 .40775 .50711 .41845 .51137 .41188 .50724 Mtetra
.681 .145 0 r
.41188 .50724 .41845 .51137 .42909 .52056 .42247 .51831 Mtetra
.849 .398 .125 r
.42247 .51831 .42909 .52056 .43972 .53564 .43303 .5362 Mtetra
.872 .476 .281 r
.43303 .5362 .43972 .53564 .45039 .55632 .44361 .5606 Mtetra
.859 .491 .351 r
.44361 .5606 .45039 .55632 .46121 .58025 .45435 .58882 Mtetra
.824 .468 .381 r
.45435 .58882 .46121 .58025 .47227 .60294 .46538 .61569 Mtetra
.755 .401 .383 r
.46538 .61569 .47227 .60294 .48365 .6188 .47677 .63468 Mtetra
.606 .251 .342 r
.47677 .63468 .48365 .6188 .4953 .62316 .4885 .64029 Mtetra
.253 0 .197 r
.4885 .64029 .4953 .62316 .50712 .61448 .50045 .63072 Mtetra
0 0 0 r
.50045 .63072 .50712 .61448 .51898 .59541 .51246 .60903 Mtetra
.707 .806 .341 r
.51246 .60903 .51898 .59541 .53077 .5719 .52439 .58216 Mtetra
.791 .882 .458 r
.52439 .58216 .53077 .5719 .54249 .55095 .53622 .55821 Mtetra
.581 .839 .481 r
.53622 .55821 .54249 .55095 .55421 .53834 .54803 .54382 Mtetra
.299 0 0 r
.54803 .54382 .55421 .53834 .56605 .53707 .55994 .54244 Mtetra
.721 .276 .196 r
.55994 .54244 .56605 .53707 .57814 .54682 .5721 .55371 Mtetra
.798 .4 .298 r
.5721 .55371 .57814 .54682 .59052 .56411 .58458 .57369 Mtetra
.792 .413 .338 r
.58458 .57369 .59052 .56411 .60314 .5831 .59732 .59574 Mtetra
.733 .36 .345 r
.59732 .59574 .60314 .5831 .61584 .59712 .61016 .6122 Mtetra
.584 .216 .311 r
.61016 .6122 .61584 .59712 .62841 .6006 .62286 .61668 Mtetra
.228 0 .18 r
.62286 .61668 .62841 .6006 .64064 .59105 .6352 .60629 Mtetra
0 0 0 r
.6352 .60629 .64064 .59105 .65245 .56977 .64706 .58254 Mtetra
.769 .81 .329 r
.64706 .58254 .65245 .56977 .66388 .54115 .65851 .55049 Mtetra
.915 .882 .458 r
.65851 .55049 .66388 .54115 .67509 .51083 .66972 .51662 Mtetra
.958 .914 .553 r
.66972 .51662 .67509 .51083 .68633 .48386 .68094 .48665 Mtetra
.953 .95 .659 r
.68094 .48665 .68633 .48386 .69779 .46347 .6924 .46426 Mtetra
.867 .995 .803 r
.6924 .46426 .69779 .46347 .70963 .45097 .70427 .45088 Mtetra
.483 .898 .894 r
.70427 .45088 .70963 .45097 .72191 .44607 .71663 .44617 Mtetra
.245 0 0 r
.71663 .44617 .72191 .44607 .73465 .44753 .7295 .44867 Mtetra
.593 .03 0 r
.7295 .44867 .73465 .44753 .7478 .45367 .74281 .45643 Mtetra
.693 .18 .01 r
.74281 .45643 .7478 .45367 .76129 .46269 .75649 .46726 Mtetra
.709 .228 .102 r
.75649 .46726 .76129 .46269 .77503 .47279 .77041 .479 Mtetra
.685 .22 .142 r
.77041 .479 .77503 .47279 .78888 .48223 .78442 .48951 Mtetra
.625 .165 .14 r
.78442 .48951 .78888 .48223 .80269 .48933 .79835 .49686 Mtetra
.508 .044 .087 r
.79835 .49686 .80269 .48933 .81632 .4926 .81201 .49945 Mtetra
.27 0 0 r
.81201 .49945 .81632 .4926 .82961 .4909 .82527 .49626 Mtetra
0 0 0 r
.82527 .49626 .82961 .4909 .84245 .48365 .83802 .48703 Mtetra
.701 .927 .603 r
.83802 .48703 .84245 .48365 .85478 .47103 .85025 .47232 Mtetra
.91 .974 .684 r
.85025 .47232 .85478 .47103 .86665 .454 .86202 .45343 Mtetra
.96 .943 .698 r
.86202 .45343 .86665 .454 .87816 .43419 .87347 .43212 Mtetra
.966 .916 .708 r
.87347 .43212 .87816 .43419 .8895 .41344 .88477 .41024 Mtetra
.957 .901 .727 r
.88477 .41024 .8895 .41344 .90085 .39348 .89611 .3894 Mtetra
.938 .892 .757 r
.89611 .3894 .90085 .39348 .91237 .37551 .90762 .37071 Mtetra
.663 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51355 .33011 .50721 Mtetra
.662 .741 .909 r
.33011 .50721 .33681 .51355 .34749 .51018 .34081 .50382 Mtetra
.658 .74 .911 r
.34081 .50382 .34749 .51018 .3582 .5069 .35155 .50052 Mtetra
.647 .737 .915 r
.35155 .50052 .3582 .5069 .36895 .50389 .36233 .49751 Mtetra
.62 .73 .925 r
.36233 .49751 .36895 .50389 .37971 .50151 .37311 .49516 Mtetra
.553 .709 .944 r
.37311 .49516 .37971 .50151 .39048 .50045 .38389 .49419 Mtetra
.376 .635 .956 r
.38389 .49419 .39048 .50045 .40121 .50185 .39463 .4958 Mtetra
0 .365 .819 r
.39463 .4958 .40121 .50185 .41188 .50724 .4053 .50161 Mtetra
.641 .122 0 r
.4053 .50161 .41188 .50724 .42247 .51831 .41587 .51338 Mtetra
.852 .393 .036 r
.41587 .51338 .42247 .51831 .43303 .5362 .42639 .53233 Mtetra
.9 .489 .198 r
.42639 .53233 .43303 .5362 .44361 .5606 .43692 .55813 Mtetra
.906 .516 .263 r
.43692 .55813 .44361 .5606 .45435 .58882 .4476 .58798 Mtetra
.892 .5 .273 r
.4476 .58798 .45435 .58882 .46538 .61569 .45858 .61645 Mtetra
.844 .418 .219 r
.45858 .61645 .46538 .61569 .47677 .63468 .46997 .63663 Mtetra
.595 .058 0 r
.46997 .63663 .47677 .63468 .4885 .64029 .48174 .64271 Mtetra
.727 .989 .817 r
.48174 .64271 .4885 .64029 .50045 .63072 .49377 .63276 Mtetra
.963 .921 .714 r
.49377 .63276 .50045 .63072 .51246 .60903 .50588 .61004 Mtetra
.972 .871 .678 r
.50588 .61004 .51246 .60903 .52439 .58216 .51792 .58183 Mtetra
.96 .868 .703 r
.51792 .58183 .52439 .58216 .53622 .55821 .52984 .55668 Mtetra
.908 .908 .809 r
.52984 .55668 .53622 .55821 .54803 .54382 .54172 .54155 Mtetra
.405 .81 .981 r
.54172 .54155 .54803 .54382 .55994 .54244 .55368 .54006 Mtetra
.69 .147 0 r
.55368 .54006 .55994 .54244 .5721 .55371 .56587 .55183 Mtetra
.846 .387 .088 r
.56587 .55183 .5721 .55371 .58458 .57369 .57836 .57275 Mtetra
.859 .415 .143 r
.57836 .57275 .58458 .57369 .59732 .59574 .59113 .59588 Mtetra
.806 .33 .083 r
.59113 .59588 .59732 .59574 .61016 .6122 .60402 .61322 Mtetra
.48 0 0 r
.60402 .61322 .61016 .6122 .62286 .61668 .61678 .61807 Mtetra
.765 .996 .833 r
.61678 .61807 .62286 .61668 .6352 .60629 .6292 .60741 Mtetra
.971 .916 .689 r
.6292 .60741 .6352 .60629 .64706 .58254 .64114 .58282 Mtetra
.984 .859 .634 r
.64114 .58282 .64706 .58254 .65851 .55049 .65265 .54964 Mtetra
.981 .839 .628 r
.65265 .54964 .65851 .55049 .66972 .51662 .66393 .51467 Mtetra
.972 .842 .655 r
.66393 .51467 .66972 .51662 .68094 .48665 .67522 .4839 Mtetra
.951 .864 .718 r
.67522 .4839 .68094 .48665 .6924 .46426 .68675 .46121 Mtetra
.883 .905 .839 r
.68675 .46121 .6924 .46426 .70427 .45088 .69871 .44809 Mtetra
.597 .883 .992 r
.69871 .44809 .70427 .45088 .71663 .44617 .71117 .4442 Mtetra
0 .419 .722 r
.71117 .4442 .71663 .44617 .7295 .44867 .72416 .448 Mtetra
.595 .021 0 r
.72416 .448 .7295 .44867 .74281 .45643 .73763 .45737 Mtetra
.713 .185 0 r
.73763 .45737 .74281 .45643 .75649 .46726 .75148 .46996 Mtetra
.732 .231 .04 r
.75148 .46996 .75649 .46726 .77041 .479 .76558 .48332 Mtetra
.705 .215 .08 r
.76558 .48332 .77041 .479 .78442 .48951 .77975 .49506 Mtetra
.632 .143 .073 r
.77975 .49506 .78442 .48951 .79835 .49686 .7938 .50301 Mtetra
.482 0 .009 r
.7938 .50301 .79835 .49686 .81201 .49945 .80754 .50546 Mtetra
.183 0 0 r
.80754 .50546 .81201 .49945 .82527 .49626 .82082 .50143 Mtetra
0 0 0 r
.82082 .50143 .82527 .49626 .83802 .48703 .83355 .49083 Mtetra
.73 .924 .577 r
.83355 .49083 .83802 .48703 .85025 .47232 .84573 .47448 Mtetra
.906 .962 .638 r
.84573 .47448 .85025 .47232 .86202 .45343 .85744 .4539 Mtetra
.96 .945 .66 r
.85744 .4539 .86202 .45343 .87347 .43212 .86883 .43102 Mtetra
.971 .925 .68 r
.86883 .43102 .87347 .43212 .88477 .41024 .88008 .40777 Mtetra
.966 .911 .708 r
.88008 .40777 .88477 .41024 .89611 .3894 .89138 .38576 Mtetra
.948 .9 .744 r
.89138 .38576 .89611 .3894 .90762 .37071 .90285 .36608 Mtetra
.663 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50721 .32336 .50083 Mtetra
.662 .741 .909 r
.32336 .50083 .33011 .50721 .34081 .50382 .33409 .4974 Mtetra
.658 .74 .91 r
.33409 .4974 .34081 .50382 .35155 .50052 .34486 .49408 Mtetra
.648 .737 .914 r
.34486 .49408 .35155 .50052 .36233 .49751 .35566 .49102 Mtetra
.622 .729 .923 r
.35566 .49102 .36233 .49751 .37311 .49516 .36647 .48859 Mtetra
.561 .706 .938 r
.36647 .48859 .37311 .49516 .38389 .49419 .37728 .4875 Mtetra
.409 .637 .949 r
.37728 .4875 .38389 .49419 .39463 .4958 .38804 .48886 Mtetra
.05 .422 .867 r
.38804 .48886 .39463 .4958 .4053 .50161 .39873 .49425 Mtetra
0 .005 .525 r
.39873 .49425 .4053 .50161 .41587 .51338 .40932 .50534 Mtetra
.766 .308 0 r
.40932 .50534 .41587 .51338 .42639 .53233 .41984 .5233 Mtetra
.861 .439 0 r
.41984 .5233 .42639 .53233 .43692 .55813 .43037 .5478 Mtetra
.877 .474 .024 r
.43037 .5478 .43692 .55813 .4476 .58798 .44104 .57615 Mtetra
.817 .419 0 r
.44104 .57615 .4476 .58798 .45858 .61645 .45201 .60315 Mtetra
0 0 .469 r
.45201 .60315 .45858 .61645 .46997 .63663 .46337 .62222 Mtetra
.376 .446 .805 r
.46337 .62222 .46997 .63663 .48174 .64271 .47513 .62782 Mtetra
.724 .627 .749 r
.47513 .62782 .48174 .64271 .49377 .63276 .48718 .61814 Mtetra
.819 .668 .696 r
.48718 .61814 .49377 .63276 .50588 .61004 .49933 .59627 Mtetra
.849 .684 .678 r
.49933 .59627 .50588 .61004 .51792 .58183 .51142 .56915 Mtetra
.846 .693 .691 r
.51142 .56915 .51792 .58183 .52984 .55668 .5234 .54496 Mtetra
.798 .689 .744 r
.5234 .54496 .52984 .55668 .54172 .54155 .53531 .53034 Mtetra
.596 .617 .843 r
.53531 .53034 .54172 .54155 .55368 .54006 .54728 .52877 Mtetra
0 .244 .756 r
.54728 .52877 .55368 .54006 .56587 .55183 .55945 .5399 Mtetra
0 0 .461 r
.55945 .5399 .56587 .55183 .57836 .57275 .57191 .55976 Mtetra
0 0 .44 r
.57191 .55976 .57836 .57275 .59113 .59588 .58462 .58173 Mtetra
0 .112 .662 r
.58462 .58173 .59113 .59588 .60402 .61322 .59746 .59814 Mtetra
.436 .476 .803 r
.59746 .59814 .60402 .61322 .61678 .61807 .61021 .60264 Mtetra
.728 .629 .748 r
.61021 .60264 .61678 .61807 .6292 .60741 .62265 .59234 Mtetra
.832 .676 .69 r
.62265 .59234 .6292 .60741 .64114 .58282 .63467 .56879 Mtetra
.873 .696 .66 r
.63467 .56879 .64114 .58282 .65265 .54964 .64631 .5371 Mtetra
.89 .712 .654 r
.64631 .5371 .65265 .54964 .66393 .51467 .65772 .50381 Mtetra
.892 .729 .672 r
.65772 .50381 .66393 .51467 .67522 .4839 .66915 .47472 Mtetra
.877 .751 .72 r
.66915 .47472 .67522 .4839 .68675 .46121 .68083 .4536 Mtetra
.817 .777 .815 r
.68083 .4536 .68675 .46121 .69871 .44809 .69291 .44194 Mtetra
.6 .759 .955 r
.69291 .44194 .69871 .44809 .71117 .4442 .7055 .43945 Mtetra
0 .456 .861 r
.7055 .43945 .71117 .4442 .72416 .448 .71861 .44465 Mtetra
.519 0 0 r
.71861 .44465 .72416 .448 .73763 .45737 .7322 .45543 Mtetra
.687 .145 0 r
.7322 .45543 .73763 .45737 .75148 .46996 .74618 .46939 Mtetra
.725 .195 0 r
.74618 .46939 .75148 .46996 .76558 .48332 .76041 .484 Mtetra
.7 .164 0 r
.76041 .484 .76558 .48332 .77975 .49506 .7747 .49671 Mtetra
.605 .047 0 r
.7747 .49671 .77975 .49506 .7938 .50301 .78886 .50522 Mtetra
.363 0 0 r
.78886 .50522 .7938 .50301 .80754 .50546 .80268 .50774 Mtetra
0 0 0 r
.80268 .50774 .80754 .50546 .82082 .50143 .81601 .50328 Mtetra
.685 .964 .737 r
.81601 .50328 .82082 .50143 .83355 .49083 .82876 .49183 Mtetra
.897 .984 .72 r
.82876 .49183 .83355 .49083 .84573 .47448 .84093 .47436 Mtetra
.958 .947 .691 r
.84093 .47436 .84573 .47448 .85744 .4539 .85262 .45257 Mtetra
.974 .916 .679 r
.85262 .45257 .85744 .4539 .86883 .43102 .86398 .42849 Mtetra
.973 .897 .686 r
.86398 .42849 .86883 .43102 .88008 .40777 .87521 .40415 Mtetra
.963 .885 .706 r
.87521 .40415 .88008 .40777 .89138 .38576 .88649 .38117 Mtetra
.945 .876 .737 r
.88649 .38117 .89138 .38576 .90285 .36608 .89795 .36065 Mtetra
.663 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49787 Mtetra
.30585 .49787 .31267 .50427 .32336 .50083 .31656 .49439 Mtetra
.662 .741 .909 r
.31656 .49439 .32336 .50083 .33409 .4974 .32732 .49094 Mtetra
.659 .74 .91 r
.32732 .49094 .33409 .4974 .34486 .49408 .33811 .48756 Mtetra
.65 .737 .913 r
.33811 .48756 .34486 .49408 .35566 .49102 .34894 .48442 Mtetra
.628 .729 .92 r
.34894 .48442 .35566 .49102 .36647 .48859 .35979 .48183 Mtetra
.578 .707 .931 r
.35979 .48183 .36647 .48859 .37728 .4875 .37063 .4804 Mtetra
.463 .65 .94 r
.37063 .4804 .37728 .4875 .38804 .48886 .38143 .48113 Mtetra
.218 .5 .904 r
.38143 .48113 .38804 .48886 .39873 .49425 .39217 .48536 Mtetra
0 .208 .73 r
.39217 .48536 .39873 .49425 .40932 .50534 .40283 .49458 Mtetra
0 0 .486 r
.40283 .49458 .40932 .50534 .41984 .5233 .41341 .50976 Mtetra
0 0 .361 r
.41341 .50976 .41984 .5233 .43037 .5478 .424 .5306 Mtetra
0 0 .394 r
.424 .5306 .43037 .5478 .44104 .57615 .43471 .55473 Mtetra
0 0 .543 r
.43471 .55473 .44104 .57615 .45201 .60315 .44569 .57763 Mtetra
.218 .233 .663 r
.44569 .57763 .45201 .60315 .46337 .62222 .45703 .59361 Mtetra
.506 .413 .684 r
.45703 .59361 .46337 .62222 .47513 .62782 .46876 .59793 Mtetra
.654 .506 .671 r
.46876 .59793 .47513 .62782 .48718 .61814 .48076 .58906 Mtetra
.728 .556 .658 r
.48076 .58906 .48718 .61814 .49933 .59627 .49287 .56966 Mtetra
.761 .583 .656 r
.49287 .56966 .49933 .59627 .51142 .56915 .50495 .54572 Mtetra
.764 .594 .668 r
.50495 .54572 .51142 .56915 .5234 .54496 .51694 .52433 Mtetra
.723 .584 .699 r
.51694 .52433 .5234 .54496 .53531 .53034 .52886 .51131 Mtetra
.593 .52 .742 r
.52886 .51131 .53531 .53034 .54728 .52877 .54082 .50969 Mtetra
.326 .356 .74 r
.54082 .50969 .54728 .52877 .55945 .5399 .55294 .51916 Mtetra
.1 .192 .674 r
.55294 .51916 .55945 .5399 .57191 .55976 .5653 .53623 Mtetra
.123 .187 .658 r
.5653 .53623 .57191 .55976 .58462 .58173 .57789 .55508 Mtetra
.319 .301 .682 r
.57789 .55508 .58462 .58173 .59746 .59814 .59061 .56901 Mtetra
.521 .425 .686 r
.59061 .56901 .59746 .59814 .61021 .60264 .60328 .57251 Mtetra
.657 .509 .671 r
.60328 .57251 .61021 .60264 .62265 .59234 .61571 .56311 Mtetra
.737 .562 .656 r
.61571 .56311 .62265 .59234 .63467 .56879 .6278 .54219 Mtetra
.783 .596 .648 r
.6278 .54219 .63467 .56879 .64631 .5371 .63958 .51424 Mtetra
.808 .622 .651 r
.63958 .51424 .64631 .5371 .65772 .50381 .65118 .48502 Mtetra
.816 .644 .669 r
.65118 .48502 .65772 .50381 .66915 .47472 .66281 .4597 Mtetra
.802 .664 .711 r
.66281 .4597 .66915 .47472 .68083 .4536 .67466 .44169 Mtetra
.743 .676 .786 r
.67466 .44169 .68083 .4536 .69291 .44194 .6869 .43242 Mtetra
.56 .642 .888 r
.6869 .43242 .69291 .44194 .7055 .43945 .69961 .43167 Mtetra
.127 .443 .879 r
.69961 .43167 .7055 .43945 .71861 .44465 .71281 .43813 Mtetra
0 .135 .646 r
.71281 .43813 .71861 .44465 .7322 .45543 .72648 .44988 Mtetra
.542 .038 0 r
.72648 .44988 .7322 .45543 .74618 .46939 .74053 .46459 Mtetra
.594 .077 0 r
.74053 .46459 .74618 .46939 .76041 .484 .75483 .47979 Mtetra
.54 .006 0 r
.75483 .47979 .76041 .484 .7747 .49671 .76918 .49292 Mtetra
0 .211 .638 r
.76918 .49292 .7747 .49671 .78886 .50522 .7834 .50166 Mtetra
.127 .603 .918 r
.7834 .50166 .78886 .50522 .80268 .50774 .79727 .50419 Mtetra
.632 .883 .987 r
.79727 .50419 .80268 .50774 .81601 .50328 .81065 .49953 Mtetra
.854 .917 .873 r
.81065 .49953 .81601 .50328 .82876 .49183 .82343 .48771 Mtetra
.925 .89 .778 r
.82343 .48771 .82876 .49183 .84093 .47436 .83564 .46975 Mtetra
.948 .865 .724 r
.83564 .46975 .84093 .47436 .85262 .45257 .84736 .44743 Mtetra
.954 .848 .7 r
.84736 .44743 .85262 .45257 .86398 .42849 .85876 .42284 Mtetra
.951 .839 .697 r
.85876 .42284 .86398 .42849 .87521 .40415 .87003 .39802 Mtetra
.942 .835 .709 r
.87003 .39802 .87521 .40415 .88649 .38117 .88134 .37462 Mtetra
.927 .833 .733 r
.88134 .37462 .88649 .38117 .89795 .36065 .89283 .35374 Mtetra
.663 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49787 .29897 .49141 Mtetra
.29897 .49141 .30585 .49787 .31656 .49439 .30971 .48791 Mtetra
.662 .741 .908 r
.30971 .48791 .31656 .49439 .32732 .49094 .32049 .48442 Mtetra
.66 .74 .909 r
.32049 .48442 .32732 .49094 .33811 .48756 .33132 .48099 Mtetra
.653 .737 .911 r
.33132 .48099 .33811 .48756 .34894 .48442 .34217 .47774 Mtetra
.636 .73 .916 r
.34217 .47774 .34894 .48442 .35979 .48183 .35305 .47493 Mtetra
.598 .712 .923 r
.35305 .47493 .35979 .48183 .37063 .4804 .36394 .47305 Mtetra
.519 .668 .93 r
.36394 .47305 .37063 .4804 .38143 .48113 .3748 .47288 Mtetra
.368 .568 .915 r
.3748 .47288 .38143 .48113 .39217 .48536 .38561 .47551 Mtetra
.139 .389 .841 r
.38561 .47551 .39217 .48536 .40283 .49458 .39636 .4821 Mtetra
0 .191 .718 r
.39636 .4821 .40283 .49458 .41341 .50976 .40705 .49342 Mtetra
0 .087 .635 r
.40705 .49342 .41341 .50976 .424 .5306 .41775 .50919 Mtetra
0 .109 .625 r
.41775 .50919 .424 .5306 .43471 .55473 .42855 .52749 Mtetra
.203 .211 .645 r
.42855 .52749 .43471 .55473 .44569 .57763 .43958 .54475 Mtetra
.398 .322 .655 r
.43958 .54475 .44569 .57763 .45703 .59361 .45092 .55651 Mtetra
.537 .408 .652 r
.45092 .55651 .45703 .59361 .46876 .59793 .46258 .5591 Mtetra
.627 .467 .646 r
.46258 .5591 .46876 .59793 .48076 .58906 .4745 .55133 Mtetra
.682 .506 .642 r
.4745 .55133 .48076 .58906 .49287 .56966 .48653 .53531 Mtetra
.71 .532 .645 r
.48653 .53531 .49287 .56966 .50495 .54572 .49855 .51574 Mtetra
.714 .543 .657 r
.49855 .51574 .50495 .54572 .51694 .52433 .51051 .49822 Mtetra
.681 .534 .68 r
.51051 .49822 .51694 .52433 .52886 .51131 .52241 .48739 Mtetra
.589 .487 .706 r
.52241 .48739 .52886 .51131 .54082 .50969 .53434 .48569 Mtetra
.437 .39 .708 r
.53434 .48569 .54082 .50969 .55294 .51916 .54639 .49284 Mtetra
.324 .304 .681 r
.54639 .49284 .55294 .51916 .5653 .53623 .55863 .50602 Mtetra
.339 .296 .664 r
.55863 .50602 .5653 .53623 .57789 .55508 .57108 .52054 Mtetra
.437 .349 .658 r
.57108 .52054 .57789 .55508 .59061 .56901 .58364 .53103 Mtetra
.544 .413 .653 r
.58364 .53103 .59061 .56901 .60328 .57251 .59618 .53315 Mtetra
.628 .468 .646 r
.59618 .53315 .60328 .57251 .61571 .56311 .60857 .52496 Mtetra
.687 .51 .641 r
.60857 .52496 .61571 .56311 .6278 .54219 .62071 .50761 Mtetra
.727 .542 .641 r
.62071 .50761 .6278 .54219 .63958 .51424 .63263 .48471 Mtetra
.751 .568 .648 r
.63263 .48471 .63958 .51424 .65118 .48502 .64443 .46095 Mtetra
.758 .589 .668 r
.64443 .46095 .65118 .48502 .66281 .4597 .65627 .44061 Mtetra
.742 .605 .706 r
.65627 .44061 .66281 .4597 .67466 .44169 .66832 .42657 Mtetra
.68 .608 .767 r
.66832 .42657 .67466 .44169 .6869 .43242 .68071 .4201 Mtetra
.521 .564 .84 r
.68071 .4201 .6869 .43242 .69961 .43167 .69352 .42108 Mtetra
.214 .421 .848 r
.69352 .42108 .69961 .43167 .71281 .43813 .70679 .42844 Mtetra
0 .225 .746 r
.70679 .42844 .71281 .43813 .72648 .44988 .72049 .44051 Mtetra
0 .109 .657 r
.72049 .44051 .72648 .44988 .74053 .46459 .73454 .45521 Mtetra
0 .107 .655 r
.73454 .45521 .74053 .46459 .75483 .47979 .74882 .4702 Mtetra
0 .21 .735 r
.74882 .4702 .75483 .47979 .76918 .49292 .76317 .48306 Mtetra
.136 .395 .846 r
.76317 .48306 .76918 .49292 .7834 .50166 .77738 .49155 Mtetra
.445 .579 .894 r
.77738 .49155 .7834 .50166 .79727 .50419 .79127 .4939 Mtetra
.668 .688 .86 r
.79127 .4939 .79727 .50419 .81065 .49953 .80467 .48916 Mtetra
.791 .734 .8 r
.80467 .48916 .81065 .49953 .82343 .48771 .81751 .47738 Mtetra
.854 .752 .75 r
.81751 .47738 .82343 .48771 .83564 .46975 .82979 .45959 Mtetra
.887 .76 .717 r
.82979 .45959 .83564 .46975 .84736 .44743 .8416 .43753 Mtetra
.903 .766 .701 r
.8416 .43753 .84736 .44743 .85876 .42284 .8531 .41325 Mtetra
.909 .772 .698 r
.8531 .41325 .85876 .42284 .87003 .39802 .86447 .38875 Mtetra
.907 .779 .709 r
.86447 .38875 .87003 .39802 .88134 .37462 .87588 .36566 Mtetra
.897 .785 .729 r
.87588 .36566 .88134 .37462 .89283 .35374 .88747 .34504 Mtetra
.663 .741 .908 r
.28131 .48844 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48791 .30281 .48137 Mtetra
.30281 .48137 .30971 .48791 .32049 .48442 .31362 .47785 Mtetra
.661 .74 .909 r
.31362 .47785 .32049 .48442 .33132 .48099 .32447 .47436 Mtetra
.656 .738 .91 r
.32447 .47436 .33132 .48099 .34217 .47774 .33536 .471 Mtetra
.644 .732 .913 r
.33536 .471 .34217 .47774 .35305 .47493 .34628 .46796 Mtetra
.618 .718 .917 r
.34628 .46796 .35305 .47493 .36394 .47305 .35721 .46559 Mtetra
.567 .685 .92 r
.35721 .46559 .36394 .47305 .3748 .47288 .36813 .46446 Mtetra
.477 .619 .912 r
.36813 .46446 .3748 .47288 .38561 .47551 .37903 .46537 Mtetra
.351 .508 .874 r
.37903 .46537 .38561 .47551 .39636 .4821 .38988 .46916 Mtetra
.238 .38 .804 r
.38988 .46916 .39636 .4821 .40705 .49342 .40071 .47636 Mtetra
.206 .296 .735 r
.40071 .47636 .40705 .49342 .41775 .50919 .41154 .48675 Mtetra
.265 .283 .692 r
.41154 .48675 .41775 .50919 .42855 .52749 .42246 .49892 Mtetra
.369 .318 .669 r
.42246 .49892 .42855 .52749 .43958 .54475 .43356 .51028 Mtetra
.472 .368 .655 r
.43356 .51028 .43958 .54475 .45092 .55651 .44491 .51765 Mtetra
.555 .415 .646 r
.44491 .51765 .45092 .55651 .46258 .5591 .45652 .51843 Mtetra
.615 .455 .641 r
.45652 .51843 .46258 .5591 .4745 .55133 .46834 .51181 Mtetra
.657 .485 .64 r
.46834 .51181 .4745 .55133 .48653 .53531 .48026 .49929 Mtetra
.68 .507 .646 r
.48026 .49929 .48653 .53531 .49855 .51574 .4922 .48426 Mtetra
.683 .519 .658 r
.4922 .48426 .49855 .51574 .51051 .49822 .50411 .47075 Mtetra
.657 .514 .677 r
.50411 .47075 .51051 .49822 .52241 .48739 .51597 .46215 Mtetra
.589 .48 .697 r
.51597 .46215 .52241 .48739 .53434 .48569 .52787 .46025 Mtetra
.491 .417 .7 r
.52787 .46025 .53434 .48569 .54639 .49284 .53985 .46485 Mtetra
.424 .361 .683 r
.53985 .46485 .54639 .49284 .55863 .50602 .55199 .47382 Mtetra
.432 .351 .665 r
.55199 .47382 .55863 .50602 .57108 .52054 .56428 .48368 Mtetra
.49 .377 .653 r
.56428 .48368 .57108 .52054 .58364 .53103 .57669 .49051 Mtetra
.557 .416 .645 r
.57669 .49051 .58364 .53103 .59618 .53315 .5891 .49114 Mtetra
.615 .453 .64 r
.5891 .49114 .59618 .53315 .60857 .52496 .60143 .4842 Mtetra
.66 .486 .638 r
.60143 .4842 .60857 .52496 .62071 .50761 .61362 .47057 Mtetra
.692 .513 .641 r
.61362 .47057 .62071 .50761 .63263 .48471 .62566 .45298 Mtetra
.711 .537 .652 r
.62566 .45298 .63263 .48471 .64443 .46095 .63764 .43497 Mtetra
.715 .557 .673 r
.63764 .43497 .64443 .46095 .65627 .44061 .64967 .4198 Mtetra
.695 .569 .709 r
.64967 .4198 .65627 .44061 .66832 .42657 .66189 .40977 Mtetra
.631 .565 .762 r
.66189 .40977 .66832 .42657 .68071 .4201 .67441 .40594 Mtetra
.491 .519 .814 r
.67441 .40594 .68071 .4201 .69352 .42108 .6873 .40829 Mtetra
.271 .412 .821 r
.6873 .40829 .69352 .42108 .70679 .42844 .70058 .41601 Mtetra
.071 .289 .775 r
.70058 .41601 .70679 .42844 .72049 .44051 .71425 .4277 Mtetra
0 .225 .738 r
.71425 .4277 .72049 .44051 .73454 .45521 .72824 .44158 Mtetra
.03 .24 .743 r
.72824 .44158 .73454 .45521 .74882 .4702 .74245 .45558 Mtetra
.165 .317 .773 r
.74245 .45558 .74882 .4702 .76317 .48306 .75672 .4675 Mtetra
.345 .419 .795 r
.75672 .4675 .76317 .48306 .77738 .49155 .77086 .47524 Mtetra
.515 .513 .792 r
.77086 .47524 .77738 .49155 .79127 .4939 .78472 .47718 Mtetra
.644 .582 .77 r
.78472 .47718 .79127 .4939 .80467 .48916 .79813 .47243 Mtetra
.733 .628 .742 r
.79813 .47243 .80467 .48916 .81751 .47738 .81102 .46106 Mtetra
.79 .659 .718 r
.81102 .46106 .81751 .47738 .82979 .45959 .8234 .44402 Mtetra
.827 .681 .701 r
.8234 .44402 .82979 .45959 .8416 .43753 .83535 .42295 Mtetra
.85 .698 .693 r
.83535 .42295 .8416 .43753 .8531 .41325 .84701 .39979 Mtetra
.863 .714 .695 r
.84701 .39979 .8531 .41325 .86447 .38875 .85855 .3764 Mtetra
.868 .728 .706 r
.85855 .3764 .86447 .38875 .87588 .36566 .87013 .35433 Mtetra
.864 .742 .726 r
.87013 .35433 .87588 .36566 .88747 .34504 .88188 .33458 Mtetra
.663 .741 .908 r
.27431 .48191 .28131 .48844 .29204 .48491 .28506 .47836 Mtetra
.28506 .47836 .29204 .48491 .30281 .48137 .29585 .47479 Mtetra
.29585 .47479 .30281 .48137 .31362 .47785 .30669 .47123 Mtetra
.662 .74 .908 r
.30669 .47123 .31362 .47785 .32447 .47436 .31757 .46768 Mtetra
.658 .739 .909 r
.31757 .46768 .32447 .47436 .33536 .471 .32849 .46422 Mtetra
.651 .734 .911 r
.32849 .46422 .33536 .471 .34628 .46796 .33944 .46097 Mtetra
.634 .724 .912 r
.33944 .46097 .34628 .46796 .35721 .46559 .35042 .45815 Mtetra
.603 .701 .913 r
.35042 .45815 .35721 .46559 .36813 .46446 .36141 .45617 Mtetra
.551 .657 .906 r
.36141 .45617 .36813 .46446 .37903 .46537 .37239 .45553 Mtetra
.48 .584 .882 r
.37239 .45553 .37903 .46537 .38988 .46916 .38335 .45679 Mtetra
.414 .496 .834 r
.38335 .45679 .38988 .46916 .40071 .47636 .39431 .46031 Mtetra
.387 .423 .776 r
.39431 .46031 .40071 .47636 .41154 .48675 .40528 .46592 Mtetra
.407 .388 .726 r
.40528 .46592 .41154 .48675 .42246 .49892 .41633 .47268 Mtetra
.458 .388 .69 r
.41633 .47268 .42246 .49892 .43356 .51028 .42752 .47886 Mtetra
.517 .407 .668 r
.42752 .47886 .43356 .51028 .44491 .51765 .43889 .48239 Mtetra
.57 .433 .655 r
.43889 .48239 .44491 .51765 .45652 .51843 .45046 .48159 Mtetra
.612 .459 .65 r
.45046 .48159 .45652 .51843 .46834 .51181 .46219 .47595 Mtetra
.644 .482 .65 r
.46219 .47595 .46834 .51181 .48026 .49929 .47402 .46646 Mtetra
.662 .502 .656 r
.47402 .46646 .48026 .49929 .4922 .48426 .48587 .45535 Mtetra
.665 .514 .67 r
.48587 .45535 .4922 .48426 .50411 .47075 .49772 .4453 Mtetra
.645 .514 .689 r
.49772 .4453 .50411 .47075 .51597 .46215 .50955 .43857 Mtetra
.594 .491 .706 r
.50955 .43857 .51597 .46215 .52787 .46025 .52142 .43636 Mtetra
.527 .448 .709 r
.52142 .43636 .52787 .46025 .53985 .46485 .53335 .43852 Mtetra
.484 .408 .695 r
.53335 .43852 .53985 .46485 .55199 .47382 .5454 .4436 Mtetra
.488 .395 .676 r
.5454 .4436 .55199 .47382 .56428 .48368 .55758 .44921 Mtetra
.523 .406 .661 r
.55758 .44921 .56428 .48368 .57669 .49051 .56985 .4527 Mtetra
.568 .428 .651 r
.56985 .4527 .57669 .49051 .5891 .49114 .58215 .45196 Mtetra
.61 .454 .646 r
.58215 .45196 .5891 .49114 .60143 .4842 .59443 .44611 Mtetra
.644 .479 .645 r
.59443 .44611 .60143 .4842 .61362 .47057 .60663 .4358 Mtetra
.669 .502 .651 r
.60663 .4358 .61362 .47057 .62566 .45298 .61877 .42293 Mtetra
.683 .523 .664 r
.61877 .42293 .62566 .45298 .63764 .43497 .63089 .41 Mtetra
.682 .541 .687 r
.63089 .41 .63764 .43497 .64967 .4198 .64308 .39939 Mtetra
.658 .551 .722 r
.64308 .39939 .64967 .4198 .66189 .40977 .65544 .39278 Mtetra
.594 .542 .767 r
.65544 .39278 .66189 .40977 .67441 .40594 .66806 .39102 Mtetra
.472 .498 .804 r
.66806 .39102 .67441 .40594 .6873 .40829 .68098 .39415 Mtetra
.314 .416 .806 r
.68098 .39415 .6873 .40829 .70058 .41601 .69424 .4016 Mtetra
.193 .335 .78 r
.69424 .4016 .70058 .41601 .71425 .4277 .70784 .41227 Mtetra
.159 .298 .757 r
.70784 .41227 .71425 .4277 .72824 .44158 .72173 .42469 Mtetra
.208 .312 .752 r
.72173 .42469 .72824 .44158 .74245 .45558 .7358 .43708 Mtetra
.309 .361 .754 r
.7358 .43708 .74245 .45558 .75672 .4675 .74994 .44751 Mtetra
.428 .423 .752 r
.74994 .44751 .75672 .4675 .77086 .47524 .76398 .45413 Mtetra
.538 .483 .742 r
.76398 .45413 .77086 .47524 .78472 .47718 .77777 .45548 Mtetra
.628 .533 .727 r
.77777 .45548 .78472 .47718 .79813 .47243 .79117 .45078 Mtetra
.697 .572 .711 r
.79117 .45078 .79813 .47243 .81102 .46106 .80412 .44008 Mtetra
.747 .604 .698 r
.80412 .44008 .81102 .46106 .8234 .44402 .81662 .42423 Mtetra
.784 .63 .69 r
.81662 .42423 .8234 .44402 .83535 .42295 .82874 .40471 Mtetra
.809 .652 .688 r
.82874 .40471 .83535 .42295 .84701 .39979 .8406 .38327 Mtetra
.825 .672 .693 r
.8406 .38327 .84701 .39979 .85855 .3764 .85236 .36162 Mtetra
.833 .691 .706 r
.85236 .36162 .85855 .3764 .87013 .35433 .86415 .34112 Mtetra
.834 .709 .726 r
.86415 .34112 .87013 .35433 .88188 .33458 .8761 .32273 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47836 .27802 .47175 Mtetra
.663 .741 .908 r
.27802 .47175 .28506 .47836 .29585 .47479 .28884 .46816 Mtetra
.28884 .46816 .29585 .47479 .30669 .47123 .29971 .46456 Mtetra
.662 .741 .908 r
.29971 .46456 .30669 .47123 .31757 .46768 .31062 .46097 Mtetra
.66 .739 .909 r
.31062 .46097 .31757 .46768 .32849 .46422 .32157 .45742 Mtetra
.656 .736 .909 r
.32157 .45742 .32849 .46422 .33944 .46097 .33256 .45399 Mtetra
.646 .729 .91 r
.33256 .45399 .33944 .46097 .35042 .45815 .34358 .45082 Mtetra
.628 .714 .909 r
.34358 .45082 .35042 .45815 .36141 .45617 .35462 .44816 Mtetra
.598 .685 .903 r
.35462 .44816 .36141 .45617 .37239 .45553 .36568 .4463 Mtetra
.559 .638 .885 r
.36568 .4463 .37239 .45553 .38335 .45679 .37674 .4456 Mtetra
.519 .576 .852 r
.37674 .4456 .38335 .45679 .39431 .46031 .38781 .44625 Mtetra
.495 .514 .806 r
.38781 .44625 .39431 .46031 .40528 .46592 .39892 .44816 Mtetra
.497 .471 .758 r
.39892 .44816 .40528 .46592 .41633 .47268 .41008 .45073 Mtetra
.52 .452 .72 r
.41008 .45073 .41633 .47268 .42752 .47886 .42135 .45295 Mtetra
.552 .451 .694 r
.42135 .45295 .42752 .47886 .43889 .48239 .43275 .45354 Mtetra
.586 .462 .678 r
.43275 .45354 .43889 .48239 .45046 .48159 .4443 .45154 Mtetra
.616 .478 .671 r
.4443 .45154 .45046 .48159 .46219 .47595 .45597 .44662 Mtetra
.639 .496 .671 r
.45597 .44662 .46219 .47595 .47402 .46646 .46772 .43941 Mtetra
.654 .513 .679 r
.46772 .43941 .47402 .46646 .48587 .45535 .47951 .43125 Mtetra
.656 .526 .694 r
.47951 .43125 .48587 .45535 .49772 .4453 .49131 .42377 Mtetra
.641 .53 .713 r
.49131 .42377 .49772 .4453 .50955 .43857 .50312 .41836 Mtetra
.604 .517 .73 r
.50312 .41836 .50955 .43857 .52142 .43636 .51497 .41576 Mtetra
.558 .488 .732 r
.51497 .41576 .52142 .43636 .53335 .43852 .52688 .41587 Mtetra
.529 .456 .718 r
.52688 .41587 .53335 .43852 .5454 .4436 .53887 .41776 Mtetra
.529 .439 .698 r
.53887 .41776 .5454 .4436 .55758 .44921 .55097 .41994 Mtetra
.551 .44 .68 r
.55097 .41994 .55758 .44921 .56985 .4527 .56315 .42075 Mtetra
.581 .451 .668 r
.56315 .42075 .56985 .4527 .58215 .45196 .57537 .4189 Mtetra
.611 .468 .663 r
.57537 .4189 .58215 .45196 .59443 .44611 .58761 .41387 Mtetra
.636 .487 .663 r
.58761 .41387 .59443 .44611 .60663 .4358 .59982 .40613 Mtetra
.654 .506 .67 r
.59982 .40613 .60663 .4358 .61877 .42293 .61203 .39693 Mtetra
.664 .525 .685 r
.61203 .39693 .61877 .42293 .63089 .41 .62425 .38795 Mtetra
.658 .541 .71 r
.62425 .38795 .63089 .41 .64308 .39939 .63656 .38081 Mtetra
.63 .548 .744 r
.63656 .38081 .64308 .39939 .65544 .39278 .64902 .37669 Mtetra
.566 .537 .782 r
.64902 .37669 .65544 .39278 .66806 .39102 .66168 .37623 Mtetra
.464 .496 .807 r
.66168 .37623 .66806 .39102 .68098 .39415 .67461 .37954 Mtetra
.35 .431 .804 r
.67461 .37954 .68098 .39415 .69424 .4016 .68783 .3862 Mtetra
.275 .374 .783 r
.68783 .3862 .69424 .4016 .70784 .41227 .70133 .39539 Mtetra
.264 .348 .763 r
.70133 .39539 .70784 .41227 .72173 .42469 .71508 .40595 Mtetra
.307 .356 .75 r
.71508 .40595 .72173 .42469 .7358 .43708 .729 .41637 Mtetra
.383 .388 .741 r
.729 .41637 .7358 .43708 .74994 .44751 .74299 .42503 Mtetra
.469 .43 .731 r
.74299 .42503 .74994 .44751 .76398 .45413 .7569 .43033 Mtetra
.551 .472 .72 r
.7569 .43033 .76398 .45413 .77777 .45548 .77061 .43102 Mtetra
.62 .512 .709 r
.77061 .43102 .77777 .45548 .79117 .45078 .784 .42639 Mtetra
.677 .546 .698 r
.784 .42639 .79117 .45078 .80412 .44008 .797 .4165 Mtetra
.721 .575 .69 r
.797 .4165 .80412 .44008 .81662 .42423 .80963 .40209 Mtetra
.755 .601 .686 r
.80963 .40209 .81662 .42423 .82874 .40471 .82193 .38443 Mtetra
.78 .625 .688 r
.82193 .38443 .82874 .40471 .8406 .38327 .83401 .36505 Mtetra
.797 .647 .695 r
.83401 .36505 .8406 .38327 .85236 .36162 .846 .34545 Mtetra
.807 .668 .709 r
.846 .34545 .85236 .36162 .86415 .34112 .85803 .32685 Mtetra
.81 .688 .73 r
.85803 .32685 .86415 .34112 .8761 .32273 .8702 .31007 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.663 .741 .908 r
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46456 .29267 .45785 Mtetra
.29267 .45785 .29971 .46456 .31062 .46097 .30361 .45421 Mtetra
.662 .74 .908 r
.30361 .45421 .31062 .46097 .32157 .45742 .31459 .45059 Mtetra
.659 .738 .908 r
.31459 .45059 .32157 .45742 .33256 .45399 .32561 .44703 Mtetra
.654 .734 .908 r
.32561 .44703 .33256 .45399 .34358 .45082 .33667 .44362 Mtetra
.644 .724 .907 r
.33667 .44362 .34358 .45082 .35462 .44816 .34777 .44047 Mtetra
.628 .706 .902 r
.34777 .44047 .35462 .44816 .36568 .4463 .35889 .43776 Mtetra
.607 .676 .89 r
.35889 .43776 .36568 .4463 .37674 .4456 .37003 .43569 Mtetra
.583 .635 .868 r
.37003 .43569 .37674 .4456 .38781 .44625 .3812 .43437 Mtetra
.566 .587 .834 r
.3812 .43437 .38781 .44625 .39892 .44816 .3924 .43373 Mtetra
.561 .546 .795 r
.3924 .43373 .39892 .44816 .41008 .45073 .40366 .43344 Mtetra
.568 .518 .759 r
.40366 .43344 .41008 .45073 .42135 .45295 .415 .43295 Mtetra
.584 .505 .732 r
.415 .43295 .42135 .45295 .43275 .45354 .42644 .43155 Mtetra
.605 .505 .714 r
.42644 .43155 .43275 .45354 .4443 .45154 .43798 .42871 Mtetra
.625 .513 .706 r
.43798 .42871 .4443 .45154 .45597 .44662 .44962 .42427 Mtetra
.642 .526 .707 r
.44962 .42427 .45597 .44662 .46772 .43941 .46133 .41857 Mtetra
.653 .541 .715 r
.46133 .41857 .46772 .43941 .47951 .43125 .47308 .41236 Mtetra
.654 .556 .731 r
.47308 .41236 .47951 .43125 .49131 .42377 .48486 .40656 Mtetra
.643 .563 .75 r
.48486 .40656 .49131 .42377 .50312 .41836 .49666 .40195 Mtetra
.618 .557 .764 r
.49666 .40195 .50312 .41836 .51497 .41576 .50851 .39894 Mtetra
.587 .537 .766 r
.50851 .39894 .51497 .41576 .52688 .41587 .52041 .39748 Mtetra
.567 .511 .752 r
.52041 .39748 .52688 .41587 .53887 .41776 .53238 .39702 Mtetra
.565 .492 .731 r
.53238 .39702 .53887 .41776 .55097 .41994 .54443 .3967 Mtetra
.577 .484 .712 r
.54443 .3967 .55097 .41994 .56315 .42075 .55655 .39557 Mtetra
.596 .486 .699 r
.55655 .39557 .56315 .42075 .57537 .4189 .56873 .3929 Mtetra
.617 .495 .692 r
.56873 .3929 .57537 .4189 .58761 .41387 .58094 .38843 Mtetra
.635 .509 .693 r
.58094 .38843 .58761 .41387 .59982 .40613 .59317 .38246 Mtetra
.647 .525 .701 r
.59317 .38246 .59982 .40613 .61203 .39693 .60543 .3758 Mtetra
.651 .542 .718 r
.60543 .3758 .61203 .39693 .62425 .38795 .61773 .36953 Mtetra
.641 .556 .743 r
.61773 .36953 .62425 .38795 .63656 .38081 .63011 .36469 Mtetra
.609 .561 .775 r
.63011 .36469 .63656 .38081 .64902 .37669 .64263 .36211 Mtetra
.548 .547 .805 r
.64263 .36211 .64902 .37669 .66168 .37623 .65532 .36225 Mtetra
.463 .508 .82 r
.65532 .36225 .66168 .37623 .67461 .37954 .66824 .36524 Mtetra
.38 .455 .813 r
.66824 .36524 .67461 .37954 .68783 .3862 .6814 .3708 Mtetra
.331 .41 .792 r
.6814 .3708 .68783 .3862 .70133 .39539 .6948 .37835 Mtetra
.328 .387 .771 r
.6948 .37835 .70133 .39539 .71508 .40595 .70842 .38695 Mtetra
.364 .39 .754 r
.70842 .38695 .71508 .40595 .729 .41637 .72219 .39539 Mtetra
.424 .411 .741 r
.72219 .39539 .729 .41637 .74299 .42503 .73602 .40228 Mtetra
.492 .442 .729 r
.73602 .40228 .74299 .42503 .7569 .43033 .74981 .40629 Mtetra
.559 .476 .718 r
.74981 .40629 .7569 .43033 .77061 .43102 .76344 .40634 Mtetra
.618 .509 .707 r
.76344 .40634 .77061 .43102 .784 .42639 .77682 .40183 Mtetra
.668 .539 .699 r
.77682 .40183 .784 .42639 .797 .4165 .78988 .39278 Mtetra
.708 .567 .693 r
.78988 .39278 .797 .4165 .80963 .40209 .80262 .37981 Mtetra
.74 .592 .692 r
.80262 .37981 .80963 .40209 .82193 .38443 .8151 .36402 Mtetra
.764 .616 .695 r
.8151 .36402 .82193 .38443 .83401 .36505 .8274 .3467 Mtetra
.781 .638 .704 r
.8274 .3467 .83401 .36505 .846 .34545 .83962 .32916 Mtetra
.791 .66 .719 r
.83962 .32916 .846 .34545 .85803 .32685 .85188 .31245 Mtetra
.794 .681 .74 r
.85188 .31245 .85803 .32685 .8702 .31007 .86427 .2973 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.663 .741 .908 r
.27467 .45475 .28178 .46148 .29267 .45785 .28559 .45108 Mtetra
.28559 .45108 .29267 .45785 .30361 .45421 .29655 .44741 Mtetra
.29655 .44741 .30361 .45421 .31459 .45059 .30756 .44374 Mtetra
.661 .74 .908 r
.30756 .44374 .31459 .45059 .32561 .44703 .31861 .44009 Mtetra
.659 .737 .908 r
.31861 .44009 .32561 .44703 .33667 .44362 .32971 .4365 Mtetra
.654 .732 .906 r
.32971 .4365 .33667 .44362 .34777 .44047 .34085 .43305 Mtetra
.646 .721 .903 r
.34085 .43305 .34777 .44047 .35889 .43776 .35202 .42981 Mtetra
.635 .703 .896 r
.35202 .42981 .35889 .43776 .37003 .43569 .36322 .42689 Mtetra
.622 .678 .882 r
.36322 .42689 .37003 .43569 .3812 .43437 .37446 .42434 Mtetra
.611 .646 .86 r
.37446 .42434 .3812 .43437 .3924 .43373 .38575 .42212 Mtetra
.606 .613 .832 r
.38575 .42212 .3924 .43373 .40366 .43344 .39708 .42008 Mtetra
.607 .586 .804 r
.39708 .42008 .40366 .43344 .415 .43295 .40848 .41792 Mtetra
.614 .568 .779 r
.40848 .41792 .415 .43295 .42644 .43155 .41996 .41529 Mtetra
.625 .561 .763 r
.41996 .41529 .42644 .43155 .43798 .42871 .43151 .41193 Mtetra
.638 .563 .755 r
.43151 .41193 .43798 .42871 .44962 .42427 .44314 .40775 Mtetra
.649 .572 .755 r
.44314 .40775 .44962 .42427 .46133 .41857 .45483 .40294 Mtetra
.656 .585 .764 r
.45483 .40294 .46133 .41857 .47308 .41236 .46656 .39788 Mtetra
.657 .599 .778 r
.46656 .39788 .47308 .41236 .48486 .40656 .47834 .39305 Mtetra
.649 .608 .794 r
.47834 .39305 .48486 .40656 .49666 .40195 .49015 .38885 Mtetra
.633 .606 .805 r
.49015 .38885 .49666 .40195 .50851 .39894 .50201 .38549 Mtetra
.614 .592 .805 r
.50201 .38549 .50851 .39894 .52041 .39748 .51392 .38294 Mtetra
.6 .571 .793 r
.51392 .38294 .52041 .39748 .53238 .39702 .52589 .38091 Mtetra
.597 .551 .774 r
.52589 .38091 .53238 .39702 .54443 .3967 .53793 .37894 Mtetra
.603 .538 .755 r
.53793 .37894 .54443 .3967 .55655 .39557 .55003 .37653 Mtetra
.614 .534 .741 r
.55003 .37653 .55655 .39557 .56873 .3929 .56219 .37331 Mtetra
.627 .538 .734 r
.56219 .37331 .56873 .3929 .58094 .38843 .5744 .36916 Mtetra
.638 .547 .735 r
.5744 .36916 .58094 .38843 .59317 .38246 .58664 .36429 Mtetra
.645 .56 .744 r
.58664 .36429 .59317 .38246 .60543 .3758 .59893 .35921 Mtetra
.644 .574 .762 r
.59893 .35921 .60543 .3758 .61773 .36953 .61128 .35458 Mtetra
.629 .585 .786 r
.61128 .35458 .61773 .36953 .63011 .36469 .62372 .35107 Mtetra
.594 .585 .812 r
.62372 .35107 .63011 .36469 .64263 .36211 .63628 .34925 Mtetra
.538 .568 .834 r
.63628 .34925 .64263 .36211 .65532 .36225 .64899 .34949 Mtetra
.467 .532 .841 r
.64899 .34949 .65532 .36225 .66824 .36524 .66189 .35191 Mtetra
.402 .486 .831 r
.66189 .35191 .66824 .36524 .6814 .3708 .67499 .35635 Mtetra
.364 .445 .811 r
.67499 .35635 .6814 .3708 .6948 .37835 .68831 .36238 Mtetra
.362 .423 .79 r
.68831 .36238 .6948 .37835 .70842 .38695 .70182 .36926 Mtetra
.392 .421 .772 r
.70182 .36926 .70842 .38695 .72219 .39539 .71547 .37599 Mtetra
.443 .437 .757 r
.71547 .37599 .72219 .39539 .73602 .40228 .72918 .38141 Mtetra
.503 .462 .744 r
.72918 .38141 .73602 .40228 .74981 .40629 .74288 .38438 Mtetra
.565 .493 .733 r
.74288 .38438 .74981 .40629 .76344 .40634 .75645 .38394 Mtetra
.62 .523 .722 r
.75645 .38394 .76344 .40634 .77682 .40183 .76982 .37958 Mtetra
.668 .552 .714 r
.76982 .37958 .77682 .40183 .78988 .39278 .78294 .37128 Mtetra
.708 .579 .709 r
.78294 .37128 .78988 .39278 .80262 .37981 .79579 .35957 Mtetra
.739 .604 .707 r
.79579 .35957 .80262 .37981 .8151 .36402 .80842 .34537 Mtetra
.762 .627 .711 r
.80842 .34537 .8151 .36402 .8274 .3467 .82091 .32981 Mtetra
.778 .649 .72 r
.82091 .32981 .8274 .3467 .83962 .32916 .83333 .31401 Mtetra
.787 .67 .735 r
.83333 .31401 .83962 .32916 .85188 .31245 .84579 .2989 Mtetra
.788 .69 .756 r
.84579 .2989 .85188 .31245 .86427 .2973 .85837 .28512 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.663 .741 .908 r
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .44741 .28944 .44056 Mtetra
.28944 .44056 .29655 .44741 .30756 .44374 .30047 .43685 Mtetra
.663 .74 .908 r
.30047 .43685 .30756 .44374 .31861 .44009 .31156 .43314 Mtetra
.661 .739 .908 r
.31156 .43314 .31861 .44009 .32971 .4365 .32269 .42945 Mtetra
.659 .736 .907 r
.32269 .42945 .32971 .4365 .34085 .43305 .33386 .42581 Mtetra
.655 .731 .905 r
.33386 .42581 .34085 .43305 .35202 .42981 .34507 .42227 Mtetra
.65 .721 .901 r
.34507 .42227 .35202 .42981 .36322 .42689 .35633 .41887 Mtetra
.644 .707 .893 r
.35633 .41887 .36322 .42689 .37446 .42434 .36762 .41563 Mtetra
.638 .688 .881 r
.36762 .41563 .37446 .42434 .38575 .42212 .37896 .41255 Mtetra
.634 .667 .864 r
.37896 .41255 .38575 .42212 .39708 .42008 .39036 .40953 Mtetra
.634 .647 .845 r
.39036 .40953 .39708 .42008 .40848 .41792 .4018 .40645 Mtetra
.638 .632 .828 r
.4018 .40645 .40848 .41792 .41996 .41529 .41331 .40313 Mtetra
.644 .624 .815 r
.41331 .40313 .41996 .41529 .43151 .41193 .42489 .39946 Mtetra
.651 .622 .808 r
.42489 .39946 .43151 .41193 .44314 .40775 .43653 .3954 Mtetra
.657 .628 .809 r
.43653 .3954 .44314 .40775 .45483 .40294 .44822 .39105 Mtetra
.661 .637 .816 r
.44822 .39105 .45483 .40294 .46656 .39788 .45996 .38659 Mtetra
.661 .648 .827 r
.45996 .38659 .46656 .39788 .47834 .39305 .47175 .38225 Mtetra
.656 .656 .838 r
.47175 .38225 .47834 .39305 .49015 .38885 .48358 .37822 Mtetra
.646 .655 .845 r
.48358 .37822 .49015 .38885 .50201 .38549 .49545 .37459 Mtetra
.635 .646 .844 r
.49545 .37459 .50201 .38549 .51392 .38294 .50738 .37135 Mtetra
.627 .63 .835 r
.50738 .37135 .51392 .38294 .52589 .38091 .51937 .36837 Mtetra
.624 .613 .82 r
.51937 .36837 .52589 .38091 .53793 .37894 .53142 .36542 Mtetra
.626 .6 .804 r
.53142 .36542 .53793 .37894 .55003 .37653 .54353 .36226 Mtetra
.632 .593 .793 r
.54353 .36226 .55003 .37653 .56219 .37331 .5557 .35872 Mtetra
.639 .593 .787 r
.5557 .35872 .56219 .37331 .5744 .36916 .56791 .35476 Mtetra
.645 .599 .789 r
.56791 .35476 .5744 .36916 .58664 .36429 .58018 .35052 Mtetra
.646 .609 .797 r
.58018 .35052 .58664 .36429 .59893 .35921 .5925 .3463 Mtetra
.64 .619 .813 r
.5925 .3463 .59893 .35921 .61128 .35458 .60489 .34252 Mtetra
.62 .624 .833 r
.60489 .34252 .61128 .35458 .62372 .35107 .61737 .33966 Mtetra
.584 .619 .853 r
.61737 .33966 .62372 .35107 .63628 .34925 .62995 .33811 Mtetra
.531 .599 .867 r
.62995 .33811 .63628 .34925 .64899 .34949 .64268 .3382 Mtetra
.468 .563 .869 r
.64268 .3382 .64899 .34949 .66189 .35191 .65557 .34005 Mtetra
.409 .519 .858 r
.65557 .34005 .66189 .35191 .67499 .35635 .66864 .3436 Mtetra
.371 .48 .84 r
.66864 .3436 .67499 .35635 .68831 .36238 .6819 .34851 Mtetra
.364 .457 .822 r
.6819 .34851 .68831 .36238 .70182 .36926 .69534 .35419 Mtetra
.389 .454 .807 r
.69534 .35419 .70182 .36926 .71547 .37599 .70892 .35977 Mtetra
.437 .468 .794 r
.70892 .35977 .71547 .37599 .72918 .38141 .72257 .36425 Mtetra
.5 .495 .783 r
.72257 .36425 .72918 .38141 .74288 .38438 .73622 .36658 Mtetra
.567 .528 .772 r
.73622 .36658 .74288 .38438 .75645 .38394 .74977 .36591 Mtetra
.628 .561 .76 r
.74977 .36591 .75645 .38394 .76982 .37958 .76316 .36174 Mtetra
.681 .592 .75 r
.76316 .36174 .76982 .37958 .78294 .37128 .77633 .35402 Mtetra
.723 .62 .742 r
.77633 .35402 .78294 .37128 .79579 .35957 .78928 .3432 Mtetra
.755 .644 .738 r
.78928 .3432 .79579 .35957 .80842 .34537 .80204 .3301 Mtetra
.778 .665 .739 r
.80204 .3301 .80842 .34537 .82091 .32981 .81466 .31572 Mtetra
.792 .685 .747 r
.81466 .31572 .82091 .32981 .83333 .31401 .82724 .30107 Mtetra
.797 .702 .76 r
.82724 .30107 .83333 .31401 .84579 .2989 .83985 .28702 Mtetra
.795 .718 .779 r
.83985 .28702 .84579 .2989 .85837 .28512 .85257 .27414 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .43741 Mtetra
.663 .741 .908 r
.27124 .43741 .27844 .44427 .28944 .44056 .28226 .43367 Mtetra
.28226 .43367 .28944 .44056 .30047 .43685 .29333 .42992 Mtetra
.29333 .42992 .30047 .43685 .31156 .43314 .30444 .42616 Mtetra
.662 .74 .908 r
.30444 .42616 .31156 .43314 .32269 .42945 .3156 .42241 Mtetra
.661 .739 .908 r
.3156 .42241 .32269 .42945 .33386 .42581 .32681 .41867 Mtetra
.659 .736 .907 r
.32681 .41867 .33386 .42581 .34507 .42227 .33806 .41498 Mtetra
.656 .732 .905 r
.33806 .41498 .34507 .42227 .35633 .41887 .34935 .41135 Mtetra
.653 .726 .902 r
.34935 .41135 .35633 .41887 .36762 .41563 .36069 .4078 Mtetra
.651 .717 .897 r
.36069 .4078 .36762 .41563 .37896 .41255 .37207 .40431 Mtetra
.649 .706 .889 r
.37207 .40431 .37896 .41255 .39036 .40953 .38351 .40083 Mtetra
.65 .696 .879 r
.38351 .40083 .39036 .40953 .4018 .40645 .395 .39729 Mtetra
.653 .686 .869 r
.395 .39729 .4018 .40645 .41331 .40313 .40654 .39361 Mtetra
.657 .68 .861 r
.40654 .39361 .41331 .40313 .42489 .39946 .41814 .38974 Mtetra
.66 .678 .856 r
.41814 .38974 .42489 .39946 .43653 .3954 .4298 .38569 Mtetra
.663 .68 .856 r
.4298 .38569 .43653 .3954 .44822 .39105 .44151 .38153 Mtetra
.664 .685 .86 r
.44151 .38153 .44822 .39105 .45996 .38659 .45327 .37734 Mtetra
.663 .692 .867 r
.45327 .37734 .45996 .38659 .47175 .38225 .46508 .37322 Mtetra
.659 .696 .874 r
.46508 .37322 .47175 .38225 .48358 .37822 .47694 .36925 Mtetra
.653 .697 .878 r
.47694 .36925 .48358 .37822 .49545 .37459 .48884 .36547 Mtetra
.648 .692 .877 r
.48884 .36547 .49545 .37459 .50738 .37135 .5008 .36187 Mtetra
.643 .682 .872 r
.5008 .36187 .50738 .37135 .51937 .36837 .51282 .35839 Mtetra
.641 .67 .863 r
.51282 .35839 .51937 .36837 .53142 .36542 .52489 .35494 Mtetra
.641 .661 .854 r
.52489 .35494 .53142 .36542 .54353 .36226 .53702 .35143 Mtetra
.643 .655 .847 r
.53702 .35143 .54353 .36226 .5557 .35872 .5492 .34778 Mtetra
.647 .655 .844 r
.5492 .34778 .5557 .35872 .56791 .35476 .56145 .34397 Mtetra
.649 .66 .847 r
.56145 .34397 .56791 .35476 .58018 .35052 .57374 .34006 Mtetra
.647 .667 .855 r
.57374 .34006 .58018 .35052 .5925 .3463 .5861 .33626 Mtetra
.637 .672 .867 r
.5861 .33626 .5925 .3463 .60489 .34252 .59853 .33285 Mtetra
.615 .672 .881 r
.59853 .33285 .60489 .34252 .61737 .33966 .61103 .33018 Mtetra
.577 .661 .895 r
.61103 .33018 .61737 .33966 .62995 .33811 .62365 .32864 Mtetra
.523 .636 .903 r
.62365 .32864 .62995 .33811 .64268 .3382 .63639 .32852 Mtetra
.457 .597 .903 r
.63639 .32852 .64268 .3382 .65557 .34005 .64928 .33 Mtetra
.39 .552 .894 r
.64928 .33 .65557 .34005 .66864 .3436 .66235 .33307 Mtetra
.338 .51 .88 r
.66235 .33307 .66864 .3436 .6819 .34851 .6756 .33746 Mtetra
.316 .485 .868 r
.6756 .33746 .6819 .34851 .69534 .35419 .68903 .34265 Mtetra
.33 .484 .861 r
.68903 .34265 .69534 .35419 .70892 .35977 .7026 .34784 Mtetra
.382 .507 .86 r
.7026 .34784 .70892 .35977 .72257 .36425 .71625 .35206 Mtetra
.462 .549 .859 r
.71625 .35206 .72257 .36425 .73622 .36658 .7299 .35431 Mtetra
.554 .599 .853 r
.7299 .35431 .73622 .36658 .74977 .36591 .74348 .35373 Mtetra
.64 .645 .839 r
.74348 .35373 .74977 .36591 .76316 .36174 .75692 .3498 Mtetra
.711 .682 .82 r
.75692 .3498 .76316 .36174 .77633 .35402 .77015 .34244 Mtetra
.763 .71 .802 r
.77015 .34244 .77633 .35402 .78928 .3432 .78318 .33204 Mtetra
.798 .73 .789 r
.78318 .33204 .78928 .3432 .80204 .3301 .79602 .31937 Mtetra
.818 .744 .782 r
.79602 .31937 .80204 .3301 .81466 .31572 .80874 .30541 Mtetra
.827 .755 .784 r
.80874 .30541 .81466 .31572 .82724 .30107 .82141 .29114 Mtetra
.826 .763 .793 r
.82141 .29114 .82724 .30107 .83985 .28702 .83411 .27741 Mtetra
.816 .768 .808 r
.83411 .27741 .83985 .28702 .85257 .27414 .84691 .2648 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .43741 .26399 .43049 Mtetra
.26399 .43049 .27124 .43741 .28226 .43367 .27504 .42672 Mtetra
.663 .741 .908 r
.27504 .42672 .28226 .43367 .29333 .42992 .28613 .42294 Mtetra
.28613 .42294 .29333 .42992 .30444 .42616 .29727 .41915 Mtetra
.29727 .41915 .30444 .42616 .3156 .42241 .30846 .41536 Mtetra
.661 .74 .909 r
.30846 .41536 .3156 .42241 .32681 .41867 .31969 .4116 Mtetra
.659 .74 .909 r
.31969 .4116 .32681 .41867 .33806 .41498 .33097 .40787 Mtetra
.656 .739 .911 r
.33097 .40787 .33806 .41498 .34935 .41135 .34229 .40422 Mtetra
.653 .738 .912 r
.34229 .40422 .34935 .41135 .36069 .4078 .35366 .40064 Mtetra
.651 .738 .913 r
.35366 .40064 .36069 .4078 .37207 .40431 .36507 .39709 Mtetra
.652 .737 .912 r
.36507 .39709 .37207 .40431 .38351 .40083 .37654 .39352 Mtetra
.656 .736 .909 r
.37654 .39352 .38351 .40083 .395 .39729 .38807 .38982 Mtetra
.661 .734 .904 r
.38807 .38982 .395 .39729 .40654 .39361 .39965 .38594 Mtetra
.666 .731 .898 r
.39965 .38594 .40654 .39361 .41814 .38974 .41129 .38188 Mtetra
.668 .728 .894 r
.41129 .38188 .41814 .38974 .4298 .38569 .42298 .37772 Mtetra
.668 .725 .892 r
.42298 .37772 .4298 .38569 .44151 .38153 .43472 .37354 Mtetra
.666 .725 .893 r
.43472 .37354 .44151 .38153 .45327 .37734 .44651 .36942 Mtetra
.662 .727 .897 r
.44651 .36942 .45327 .37734 .46508 .37322 .45834 .36542 Mtetra
.658 .729 .902 r
.45834 .36542 .46508 .37322 .47694 .36925 .47023 .36153 Mtetra
.654 .731 .906 r
.47023 .36153 .47694 .36925 .48884 .36547 .48217 .35774 Mtetra
.651 .731 .907 r
.48217 .35774 .48884 .36547 .5008 .36187 .49416 .35401 Mtetra
.649 .727 .906 r
.49416 .35401 .5008 .36187 .51282 .35839 .5062 .35036 Mtetra
.646 .723 .904 r
.5062 .35036 .51282 .35839 .52489 .35494 .51831 .34678 Mtetra
.644 .719 .903 r
.51831 .34678 .52489 .35494 .53702 .35143 .53047 .34324 Mtetra
.643 .719 .903 r
.53047 .34324 .53702 .35143 .5492 .34778 .54269 .3397 Mtetra
.645 .723 .906 r
.54269 .3397 .5492 .34778 .56145 .34397 .55497 .3361 Mtetra
.646 .731 .911 r
.55497 .3361 .56145 .34397 .57374 .34006 .5673 .33243 Mtetra
.645 .738 .917 r
.5673 .33243 .57374 .34006 .5861 .33626 .5797 .32878 Mtetra
.634 .74 .924 r
.5797 .32878 .5861 .33626 .59853 .33285 .59216 .3254 Mtetra
.61 .733 .932 r
.59216 .3254 .59853 .33285 .61103 .33018 .6047 .32264 Mtetra
.568 .713 .94 r
.6047 .32264 .61103 .33018 .62365 .32864 .61735 .32092 Mtetra
.504 .679 .944 r
.61735 .32092 .62365 .32864 .63639 .32852 .63011 .32062 Mtetra
.42 .631 .942 r
.63011 .32062 .63639 .32852 .64928 .33 .64303 .32198 Mtetra
.324 .574 .931 r
.64303 .32198 .64928 .33 .66235 .33307 .65613 .32506 Mtetra
.23 .518 .913 r
.65613 .32506 .66235 .33307 .6756 .33746 .66942 .32961 Mtetra
.16 .479 .897 r
.66942 .32961 .6756 .33746 .68903 .34265 .68288 .33511 Mtetra
.135 .474 .895 r
.68288 .33511 .68903 .34265 .7026 .34784 .6965 .34075 Mtetra
.173 .515 .915 r
.6965 .34075 .7026 .34784 .71625 .35206 .71021 .34549 Mtetra
.282 .603 .952 r
.71021 .34549 .71625 .35206 .7299 .35431 .72394 .34827 Mtetra
.445 .716 .982 r
.72394 .34827 .7299 .35431 .74348 .35373 .7376 .34815 Mtetra
.614 .812 .976 r
.7376 .34815 .74348 .35373 .75692 .3498 .75112 .34452 Mtetra
.743 .865 .937 r
.75112 .34452 .75692 .3498 .77015 .34244 .76442 .33725 Mtetra
.822 .882 .888 r
.76442 .33725 .77015 .34244 .78318 .33204 .77751 .32674 Mtetra
.863 .881 .849 r
.77751 .32674 .78318 .33204 .79602 .31937 .7904 .31377 Mtetra
.88 .873 .826 r
.7904 .31377 .79602 .31937 .80874 .30541 .80316 .29937 Mtetra
.881 .863 .818 r
.80316 .29937 .80874 .30541 .82141 .29114 .81586 .28461 Mtetra
.87 .851 .821 r
.81586 .28461 .82141 .29114 .83411 .27741 .82858 .27038 Mtetra
.851 .838 .833 r
.82858 .27038 .83411 .27741 .84691 .2648 .8414 .25732 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.663 .741 .908 r
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42294 .27888 .41591 Mtetra
.27888 .41591 .28613 .42294 .29727 .41915 .29004 .41211 Mtetra
.661 .741 .909 r
.29004 .41211 .29727 .41915 .30846 .41536 .30126 .40832 Mtetra
.659 .741 .911 r
.30126 .40832 .30846 .41536 .31969 .4116 .31252 .4046 Mtetra
.654 .742 .915 r
.31252 .4046 .31969 .4116 .33097 .40787 .32381 .40101 Mtetra
.647 .745 .921 r
.32381 .40101 .33097 .40787 .34229 .40422 .33515 .39759 Mtetra
.638 .751 .93 r
.33515 .39759 .34229 .40422 .35366 .40064 .34653 .39436 Mtetra
.633 .761 .94 r
.34653 .39436 .35366 .40064 .36507 .39709 .35795 .3912 Mtetra
.634 .775 .948 r
.35795 .3912 .36507 .39709 .37654 .39352 .36944 .38794 Mtetra
.645 .79 .951 r
.36944 .38794 .37654 .39352 .38807 .38982 .38099 .38435 Mtetra
.662 .799 .948 r
.38099 .38435 .38807 .38982 .39965 .38594 .39261 .38033 Mtetra
.676 .798 .94 r
.39261 .38033 .39965 .38594 .41129 .38188 .4043 .37593 Mtetra
.681 .79 .932 r
.4043 .37593 .41129 .38188 .42298 .37772 .41604 .37139 Mtetra
.677 .778 .926 r
.41604 .37139 .42298 .37772 .43472 .37354 .42783 .36694 Mtetra
.668 .768 .925 r
.42783 .36694 .43472 .37354 .44651 .36942 .43965 .36276 Mtetra
.657 .764 .928 r
.43965 .36276 .44651 .36942 .45834 .36542 .45152 .35888 Mtetra
.648 .766 .935 r
.45152 .35888 .45834 .36542 .47023 .36153 .46344 .3552 Mtetra
.644 .772 .941 r
.46344 .3552 .47023 .36153 .48217 .35774 .47541 .3516 Mtetra
.641 .779 .947 r
.47541 .3516 .48217 .35774 .49416 .35401 .48744 .348 Mtetra
.638 .783 .951 r
.48744 .348 .49416 .35401 .5062 .35036 .49952 .34444 Mtetra
.632 .785 .955 r
.49952 .34444 .5062 .35036 .51831 .34678 .51167 .341 Mtetra
.622 .788 .961 r
.51167 .341 .51831 .34678 .53047 .34324 .52387 .33772 Mtetra
.613 .795 .969 r
.52387 .33772 .53047 .34324 .54269 .3397 .53613 .33457 Mtetra
.609 .808 .977 r
.53613 .33457 .54269 .3397 .55497 .3361 .54846 .33136 Mtetra
.611 .824 .982 r
.54846 .33136 .55497 .3361 .5673 .33243 .56085 .32794 Mtetra
.617 .836 .984 r
.56085 .32794 .5673 .33243 .5797 .32878 .57329 .3243 Mtetra
.616 .837 .984 r
.57329 .3243 .5797 .32878 .59216 .3254 .5858 .32064 Mtetra
.596 .821 .986 r
.5858 .32064 .59216 .3254 .6047 .32264 .59838 .31744 Mtetra
.549 .787 .987 r
.59838 .31744 .6047 .32264 .61735 .32092 .61105 .31527 Mtetra
.465 .734 .986 r
.61105 .31527 .61735 .32092 .63011 .32062 .62385 .3147 Mtetra
.34 .659 .972 r
.62385 .3147 .63011 .32062 .64303 .32198 .63681 .31611 Mtetra
.178 .562 .934 r
.63681 .31611 .64303 .32198 .65613 .32506 .64996 .3196 Mtetra
0 .451 .863 r
.64996 .3196 .65613 .32506 .66942 .32961 .66332 .32493 Mtetra
0 .349 .77 r
.66332 .32493 .66942 .32961 .68288 .33511 .67687 .33152 Mtetra
0 .286 .682 r
.67687 .33152 .68288 .33511 .6965 .34075 .6906 .33842 Mtetra
.302 0 0 r
.6906 .33842 .6965 .34075 .71021 .34549 .70444 .34445 Mtetra
.24 0 0 r
.70444 .34445 .71021 .34549 .72394 .34827 .7183 .34837 Mtetra
.068 0 0 r
.7183 .34837 .72394 .34827 .7376 .34815 .73209 .34906 Mtetra
.205 .729 .734 r
.73209 .34906 .7376 .34815 .75112 .34452 .74571 .34579 Mtetra
.498 .9 .782 r
.74571 .34579 .75112 .34452 .76442 .33725 .7591 .33837 Mtetra
.713 .982 .792 r
.7591 .33837 .76442 .33725 .77751 .32674 .77224 .32721 Mtetra
.835 .999 .787 r
.77224 .32721 .77751 .32674 .7904 .31377 .78515 .31321 Mtetra
.893 .987 .788 r
.78515 .31321 .7904 .31377 .80316 .29937 .79789 .29754 Mtetra
.913 .966 .798 r
.79789 .29754 .80316 .29937 .81586 .28461 .81056 .28142 Mtetra
.909 .941 .815 r
.81056 .28142 .81586 .28461 .82858 .27038 .82325 .26588 Mtetra
.888 .912 .836 r
.82325 .26588 .82858 .27038 .8414 .25732 .83604 .25166 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.663 .741 .908 r
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41267 Mtetra
.26041 .41267 .26775 .41972 .27888 .41591 .27156 .40884 Mtetra
.662 .741 .909 r
.27156 .40884 .27888 .41591 .29004 .41211 .28276 .40504 Mtetra
.658 .741 .911 r
.28276 .40504 .29004 .41211 .30126 .40832 .29399 .40132 Mtetra
.651 .742 .917 r
.29399 .40132 .30126 .40832 .31252 .4046 .30526 .3978 Mtetra
.636 .745 .927 r
.30526 .3978 .31252 .4046 .32381 .40101 .31656 .39464 Mtetra
.613 .752 .944 r
.31656 .39464 .32381 .40101 .33515 .39759 .32788 .39196 Mtetra
.579 .767 .968 r
.32788 .39196 .33515 .39759 .34653 .39436 .33923 .38978 Mtetra
.542 .793 .991 r
.33923 .38978 .34653 .39436 .35795 .3912 .35063 .38783 Mtetra
.521 .829 1 r
.35063 .38783 .35795 .3912 .36944 .38794 .3621 .3856 Mtetra
.54 .87 .993 r
.3621 .3856 .36944 .38794 .38099 .38435 .37368 .38251 Mtetra
.6 .905 .984 r
.37368 .38251 .38099 .38435 .39261 .38033 .38536 .3783 Mtetra
.663 .917 .977 r
.38536 .3783 .39261 .38033 .4043 .37593 .39713 .37314 Mtetra
.696 .901 .97 r
.39713 .37314 .4043 .37593 .41604 .37139 .40895 .36764 Mtetra
.692 .869 .965 r
.40895 .36764 .41604 .37139 .42783 .36694 .42081 .36246 Mtetra
.666 .84 .966 r
.42081 .36246 .42783 .36694 .43965 .36276 .43268 .35803 Mtetra
.632 .823 .974 r
.43268 .35803 .43965 .36276 .45152 .35888 .44459 .35438 Mtetra
.603 .823 .984 r
.44459 .35438 .45152 .35888 .46344 .3552 .45654 .35121 Mtetra
.584 .836 .993 r
.45654 .35121 .46344 .3552 .47541 .3516 .46854 .34814 Mtetra
.574 .852 .996 r
.46854 .34814 .47541 .3516 .48744 .348 .48061 .34495 Mtetra
.562 .863 .996 r
.48061 .34495 .48744 .348 .49952 .34444 .49275 .3417 Mtetra
.535 .863 .995 r
.49275 .3417 .49952 .34444 .51167 .341 .50494 .33861 Mtetra
.488 .855 .988 r
.50494 .33861 .51167 .341 .52387 .33772 .51719 .33587 Mtetra
.427 .84 .968 r
.51719 .33587 .52387 .33772 .53613 .33457 .52952 .33342 Mtetra
.379 .829 .932 r
.52952 .33342 .53613 .33457 .54846 .33136 .54191 .33088 Mtetra
.37 .834 .898 r
.54191 .33088 .54846 .33136 .56085 .32794 .55436 .32782 Mtetra
.408 .858 .888 r
.55436 .32782 .56085 .32794 .57329 .3243 .56687 .324 Mtetra
.466 .888 .908 r
.56687 .324 .57329 .3243 .5858 .32064 .57943 .31965 Mtetra
.503 .897 .944 r
.57943 .31965 .5858 .32064 .59838 .31744 .59206 .31543 Mtetra
.481 .866 .975 r
.59206 .31543 .59838 .31744 .61105 .31527 .60477 .31228 Mtetra
.381 .788 .982 r
.60477 .31228 .61105 .31527 .62385 .3147 .6176 .31107 Mtetra
.196 .656 .942 r
.6176 .31107 .62385 .3147 .63681 .31611 .6306 .31241 Mtetra
0 .473 .829 r
.6306 .31241 .63681 .31611 .64996 .3196 .64382 .3165 Mtetra
0 .273 .646 r
.64382 .3165 .64996 .3196 .66332 .32493 .65727 .32304 Mtetra
.478 0 0 r
.65727 .32304 .66332 .32493 .67687 .33152 .67095 .3313 Mtetra
.565 0 0 r
.67095 .3313 .67687 .33152 .6906 .33842 .68484 .34013 Mtetra
.576 .011 0 r
.68484 .34013 .6906 .33842 .70444 .34445 .69885 .3481 Mtetra
.524 0 0 r
.69885 .3481 .70444 .34445 .7183 .34837 .71289 .35367 Mtetra
.407 0 0 r
.71289 .35367 .7183 .34837 .73209 .34906 .72685 .35549 Mtetra
.218 0 0 r
.72685 .35549 .73209 .34906 .74571 .34579 .74061 .35263 Mtetra
0 0 0 r
.74061 .35263 .74571 .34579 .7591 .33837 .75409 .34484 Mtetra
.75409 .34484 .7591 .33837 .77224 .32721 .76727 .33259 Mtetra
.594 .85 .495 r
.76727 .33259 .77224 .32721 .78515 .31321 .78017 .31692 Mtetra
.772 .942 .599 r
.78017 .31692 .78515 .31321 .79789 .29754 .79287 .29925 Mtetra
.872 .979 .684 r
.79287 .29925 .79789 .29754 .81056 .28142 .80546 .28102 Mtetra
.913 .981 .751 r
.80546 .28102 .81056 .28142 .82325 .26588 .81806 .26349 Mtetra
.913 .96 .804 r
.81806 .26349 .82325 .26588 .83604 .25166 .83077 .24752 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.663 .741 .908 r
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41267 .25301 .40557 Mtetra
.662 .741 .909 r
.25301 .40557 .26041 .41267 .27156 .40884 .26419 .40174 Mtetra
.659 .741 .911 r
.26419 .40174 .27156 .40884 .28276 .40504 .27541 .39798 Mtetra
.65 .741 .916 r
.27541 .39798 .28276 .40504 .29399 .40132 .28665 .39445 Mtetra
.631 .742 .928 r
.28665 .39445 .29399 .40132 .30526 .3978 .29792 .39141 Mtetra
.589 .745 .951 r
.29792 .39141 .30526 .3978 .31656 .39464 .30918 .38922 Mtetra
.5 .747 .983 r
.30918 .38922 .31656 .39464 .32788 .39196 .32042 .38822 Mtetra
.316 .721 .979 r
.32042 .38822 .32788 .39196 .33923 .38978 .33167 .3884 Mtetra
.038 .598 .803 r
.33167 .3884 .33923 .38978 .35063 .38783 .34295 .38916 Mtetra
.131 0 0 r
.34295 .38916 .35063 .38783 .3621 .3856 .35436 .38926 Mtetra
.098 0 0 r
.35436 .38926 .3621 .3856 .37368 .38251 .36594 .38738 Mtetra
0 0 0 r
.36594 .38738 .37368 .38251 .38536 .3783 .37772 .38283 Mtetra
.37772 .38283 .38536 .3783 .39713 .37314 .38963 .37605 Mtetra
.549 .922 .774 r
.38963 .37605 .39713 .37314 .40895 .36764 .40161 .36847 Mtetra
.634 .962 .897 r
.40161 .36847 .40895 .36764 .42081 .36246 .41358 .36168 Mtetra
.595 .931 .956 r
.41358 .36168 .42081 .36246 .43268 .35803 .42553 .35666 Mtetra
.48 .873 .965 r
.42553 .35666 .43268 .35803 .44459 .35438 .43748 .35344 Mtetra
.335 .806 .915 r
.43748 .35344 .44459 .35438 .45654 .35121 .44946 .35132 Mtetra
.218 .741 .816 r
.44946 .35132 .45654 .35121 .46854 .34814 .46151 .34934 Mtetra
.157 .694 .716 r
.46151 .34934 .46854 .34814 .48061 .34495 .47363 .34693 Mtetra
0 0 0 r
.47363 .34693 .48061 .34495 .49275 .3417 .48583 .34415 Mtetra
.48583 .34415 .49275 .3417 .50494 .33861 .49809 .3415 Mtetra
.043 0 0 r
.49809 .3415 .50494 .33861 .51719 .33587 .51042 .33948 Mtetra
.147 0 0 r
.51042 .33948 .51719 .33587 .52952 .33342 .52281 .33803 Mtetra
.198 0 0 r
.52281 .33803 .52952 .33342 .54191 .33088 .53529 .33648 Mtetra
.175 0 0 r
.53529 .33648 .54191 .33088 .55436 .32782 .54784 .33387 Mtetra
.084 0 0 r
.54784 .33387 .55436 .32782 .56687 .324 .56043 .32961 Mtetra
0 0 0 r
.56043 .32961 .56687 .324 .57943 .31965 .57307 .3239 Mtetra
.57307 .3239 .57943 .31965 .59206 .31543 .58574 .31775 Mtetra
.283 .768 .68 r
.58574 .31775 .59206 .31543 .60477 .31228 .59848 .31264 Mtetra
.23 .75 .794 r
.59848 .31264 .60477 .31228 .6176 .31107 .61135 .31001 Mtetra
.019 .588 .779 r
.61135 .31001 .6176 .31107 .6306 .31241 .62439 .3108 Mtetra
.266 0 0 r
.62439 .3108 .6306 .31241 .64382 .3165 .63768 .31531 Mtetra
.497 0 0 r
.63768 .31531 .64382 .3165 .65727 .32304 .65123 .32316 Mtetra
.625 .062 0 r
.65123 .32316 .65727 .32304 .67095 .3313 .66506 .3334 Mtetra
.671 .136 0 r
.66506 .3334 .67095 .3313 .68484 .34013 .67912 .34457 Mtetra
.659 .149 .019 r
.67912 .34457 .68484 .34013 .69885 .3481 .69333 .35489 Mtetra
.603 .113 .063 r
.69333 .35489 .69885 .3481 .71289 .35367 .70758 .36246 Mtetra
.5 .031 .071 r
.70758 .36246 .71289 .35367 .72685 .35549 .72173 .3656 Mtetra
.341 0 .04 r
.72173 .3656 .72685 .35549 .74061 .35263 .73564 .36319 Mtetra
.116 0 0 r
.73564 .36319 .74061 .35263 .75409 .34484 .74923 .35488 Mtetra
0 0 0 r
.74923 .35488 .75409 .34484 .76727 .33259 .76245 .3412 Mtetra
.76245 .3412 .76727 .33259 .78017 .31692 .77533 .32343 Mtetra
.672 .85 .441 r
.77533 .32343 .78017 .31692 .79287 .29925 .78795 .30326 Mtetra
.824 .937 .568 r
.78795 .30326 .79287 .29925 .80546 .28102 .80045 .28244 Mtetra
.903 .973 .672 r
.80045 .28244 .80546 .28102 .81806 .26349 .81294 .26245 Mtetra
.926 .972 .753 r
.81294 .26245 .81806 .26349 .83077 .24752 .82554 .24433 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.663 .741 .908 r
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40228 Mtetra
.2344 .40228 .24188 .40941 .25301 .40557 .24556 .39842 Mtetra
.661 .741 .91 r
.24556 .39842 .25301 .40557 .26419 .40174 .25676 .3946 Mtetra
.654 .741 .913 r
.25676 .3946 .26419 .40174 .27541 .39798 .26799 .39097 Mtetra
.635 .74 .924 r
.26799 .39097 .27541 .39798 .28665 .39445 .27923 .3878 Mtetra
.588 .737 .946 r
.27923 .3878 .28665 .39445 .29792 .39141 .29046 .38566 Mtetra
.461 .72 .981 r
.29046 .38566 .29792 .39141 .30918 .38922 .30162 .3853 Mtetra
.097 .583 .905 r
.30162 .3853 .30918 .38922 .32042 .38822 .31269 .38742 Mtetra
.435 0 0 r
.31269 .38742 .32042 .38822 .33167 .3884 .3237 .39203 Mtetra
.596 .087 .011 r
.3237 .39203 .33167 .3884 .34295 .38916 .33474 .39788 Mtetra
.57 .128 .162 r
.33474 .39788 .34295 .38916 .35436 .38926 .34598 .40242 Mtetra
.47 .067 .193 r
.34598 .40242 .35436 .38926 .36594 .38738 .35754 .40283 Mtetra
.31 0 .145 r
.35754 .40283 .36594 .38738 .37772 .38283 .36946 .39767 Mtetra
.092 0 .02 r
.36946 .39767 .37772 .38283 .38963 .37605 .38163 .38789 Mtetra
0 0 0 r
.38163 .38789 .38963 .37605 .40161 .36847 .39387 .37644 Mtetra
.39387 .37644 .40161 .36847 .41358 .36168 .40606 .36663 Mtetra
.40606 .36663 .41358 .36168 .42553 .35666 .41813 .36049 Mtetra
.062 0 0 r
.41813 .36049 .42553 .35666 .43748 .35344 .43012 .35805 Mtetra
.287 0 0 r
.43012 .35805 .43748 .35344 .44946 .35132 .44213 .3578 Mtetra
.36 0 0 r
.44213 .3578 .44946 .35132 .46151 .34934 .45422 .35774 Mtetra
.349 0 0 r
.45422 .35774 .46151 .34934 .47363 .34693 .46641 .35656 Mtetra
.325 0 .019 r
.46641 .35656 .47363 .34693 .48583 .34415 .4787 .35427 Mtetra
.332 0 .039 r
.4787 .35427 .48583 .34415 .49809 .3415 .49106 .3519 Mtetra
.378 0 .072 r
.49106 .3519 .49809 .3415 .51042 .33948 .50348 .35051 Mtetra
.426 0 .114 r
.50348 .35051 .51042 .33948 .52281 .33803 .51598 .3502 Mtetra
.436 .018 .146 r
.51598 .3502 .52281 .33803 .53529 .33648 .52857 .34986 Mtetra
.394 0 .151 r
.52857 .34986 .53529 .33648 .54784 .33387 .54124 .34774 Mtetra
.302 0 .118 r
.54124 .34774 .54784 .33387 .56043 .32961 .55395 .34264 Mtetra
.168 0 .038 r
.55395 .34264 .56043 .32961 .57307 .3239 .56668 .33464 Mtetra
.014 0 0 r
.56668 .33464 .57307 .3239 .58574 .31775 .57942 .32528 Mtetra
0 0 0 r
.57942 .32528 .58574 .31775 .59848 .31264 .5922 .31687 Mtetra
.5922 .31687 .59848 .31264 .61135 .31001 .60508 .31161 Mtetra
.074 0 0 r
.60508 .31161 .61135 .31001 .62439 .3108 .61816 .31095 Mtetra
.368 0 0 r
.61816 .31095 .62439 .3108 .63768 .31531 .6315 .31532 Mtetra
.581 .006 0 r
.6315 .31532 .63768 .31531 .65123 .32316 .64514 .32422 Mtetra
.685 .147 0 r
.64514 .32422 .65123 .32316 .66506 .3334 .6591 .33636 Mtetra
.717 .207 .015 r
.6591 .33636 .66506 .3334 .67912 .34457 .67334 .34991 Mtetra
.701 .212 .082 r
.67334 .34991 .67912 .34457 .69333 .35489 .68775 .36266 Mtetra
.643 .17 .115 r
.68775 .36266 .69333 .35489 .70758 .36246 .70221 .37232 Mtetra
.538 .081 .116 r
.70221 .37232 .70758 .36246 .72173 .3656 .71656 .37684 Mtetra
.371 0 .079 r
.71656 .37684 .72173 .3656 .73564 .36319 .73063 .37486 Mtetra
.126 0 0 r
.73063 .37486 .73564 .36319 .74923 .35488 .74432 .36595 Mtetra
0 0 0 r
.74432 .36595 .74923 .35488 .76245 .3412 .75758 .35073 Mtetra
.75758 .35073 .76245 .3412 .77533 .32343 .77044 .3307 Mtetra
.705 .846 .417 r
.77044 .3307 .77533 .32343 .78795 .30326 .783 .30787 Mtetra
.848 .924 .535 r
.783 .30787 .78795 .30326 .80045 .28244 .79539 .28429 Mtetra
.921 .958 .634 r
.79539 .28429 .80045 .28244 .81294 .26245 .80777 .26171 Mtetra
.943 .962 .717 r
.80777 .26171 .81294 .26245 .82554 .24433 .82027 .24134 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.663 .741 .908 r
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40228 .22685 .3951 Mtetra
.662 .741 .909 r
.22685 .3951 .2344 .40228 .24556 .39842 .23804 .39122 Mtetra
.658 .741 .911 r
.23804 .39122 .24556 .39842 .25676 .3946 .24926 .38744 Mtetra
.646 .739 .917 r
.24926 .38744 .25676 .3946 .26799 .39097 .2605 .384 Mtetra
.61 .735 .935 r
.2605 .384 .26799 .39097 .27923 .3878 .27173 .38143 Mtetra
.502 .716 .968 r
.27173 .38143 .27923 .3878 .29046 .38566 .28287 .3807 Mtetra
.131 .573 .924 r
.28287 .3807 .29046 .38566 .30162 .3853 .29385 .38321 Mtetra
.552 0 0 r
.29385 .38321 .30162 .3853 .31269 .38742 .30462 .39021 Mtetra
.739 .272 .14 r
.30462 .39021 .31269 .38742 .3237 .39203 .31522 .40179 Mtetra
.726 .331 .301 r
.31522 .40179 .3237 .39203 .33474 .39788 .32583 .41569 Mtetra
.662 .304 .355 r
.32583 .41569 .33474 .39788 .34598 .40242 .33676 .4273 Mtetra
.557 .223 .357 r
.33676 .4273 .34598 .40242 .35754 .40283 .34826 .43142 Mtetra
.404 .09 .315 r
.34826 .43142 .35754 .40283 .36946 .39767 .36039 .42531 Mtetra
.204 0 .224 r
.36039 .42531 .36946 .39767 .38163 .38789 .37295 .41076 Mtetra
.005 0 .092 r
.37295 .41076 .38163 .38789 .39387 .37644 .38562 .3932 Mtetra
0 0 0 r
.38562 .3932 .39387 .37644 .40606 .36663 .39813 .37867 Mtetra
.095 0 0 r
.39813 .37867 .40606 .36663 .41813 .36049 .41037 .3708 Mtetra
.381 0 .069 r
.41037 .3708 .41813 .36049 .43012 .35805 .42242 .36962 Mtetra
.519 .098 .181 r
.42242 .36962 .43012 .35805 .44213 .3578 .43445 .37233 Mtetra
.53 .135 .238 r
.43445 .37233 .44213 .3578 .45422 .35774 .44657 .37519 Mtetra
.487 .113 .256 r
.44657 .37519 .45422 .35774 .46641 .35656 .45885 .37569 Mtetra
.44 .08 .255 r
.45885 .37569 .46641 .35656 .4787 .35427 .47127 .37372 Mtetra
.428 .07 .253 r
.47127 .37372 .4787 .35427 .49106 .3519 .48377 .37111 Mtetra
.457 .095 .262 r
.48377 .37111 .49106 .3519 .50348 .35051 .49633 .3699 Mtetra
.494 .132 .279 r
.49633 .3699 .50348 .35051 .51598 .3502 .50896 .37055 Mtetra
.5 .142 .29 r
.50896 .37055 .51598 .3502 .52857 .34986 .52169 .37141 Mtetra
.457 .108 .284 r
.52169 .37141 .52857 .34986 .54124 .34774 .53451 .36967 Mtetra
.361 .024 .252 r
.53451 .36967 .54124 .34774 .55395 .34264 .54738 .36317 Mtetra
.219 0 .182 r
.54738 .36317 .55395 .34264 .56668 .33464 .56024 .35185 Mtetra
.05 0 .067 r
.56024 .35185 .56668 .33464 .57942 .32528 .57306 .33787 Mtetra
0 0 0 r
.57306 .33787 .57942 .32528 .5922 .31687 .58588 .32464 Mtetra
.58588 .32464 .5922 .31687 .60508 .31161 .59878 .31539 Mtetra
.018 0 0 r
.59878 .31539 .60508 .31161 .61816 .31095 .61186 .31216 Mtetra
.356 0 0 r
.61186 .31216 .61816 .31095 .6315 .31532 .62523 .31556 Mtetra
.599 .029 0 r
.62523 .31556 .6315 .31532 .64514 .32422 .63895 .32488 Mtetra
.709 .177 0 r
.63895 .32488 .64514 .32422 .6591 .33636 .65302 .33846 Mtetra
.744 .237 .011 r
.65302 .33846 .6591 .33636 .67334 .34991 .6674 .35403 Mtetra
.731 .238 .065 r
.6674 .35403 .67334 .34991 .68775 .36266 .68199 .36893 Mtetra
.674 .187 .085 r
.68199 .36893 .68775 .36266 .70221 .37232 .69663 .38045 Mtetra
.557 .076 .069 r
.69663 .38045 .70221 .37232 .71656 .37684 .71116 .38621 Mtetra
.346 0 .004 r
.71116 .38621 .71656 .37684 .73063 .37486 .72538 .3846 Mtetra
.014 0 0 r
.72538 .3846 .73063 .37486 .74432 .36595 .73917 .37511 Mtetra
0 0 0 r
.73917 .37511 .74432 .36595 .75758 .35073 .75248 .35846 Mtetra
.668 .831 .406 r
.75248 .35846 .75758 .35073 .77044 .3307 .76533 .33636 Mtetra
.838 .908 .501 r
.76533 .33636 .77044 .3307 .783 .30787 .77784 .3111 Mtetra
.922 .936 .576 r
.77784 .3111 .783 .30787 .79539 .28429 .79016 .28501 Mtetra
.958 .943 .642 r
.79016 .28501 .79539 .28429 .80777 .26171 .80245 .26008 Mtetra
.961 .938 .705 r
.80245 .26008 .80777 .26171 .82027 .24134 .81487 .23767 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.663 .741 .908 r
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .3951 .21925 .38785 Mtetra
.661 .741 .909 r
.21925 .38785 .22685 .3951 .23804 .39122 .23046 .38397 Mtetra
.655 .74 .912 r
.23046 .38397 .23804 .39122 .24926 .38744 .2417 .38026 Mtetra
.635 .737 .922 r
.2417 .38026 .24926 .38744 .2605 .384 .25295 .37707 Mtetra
.572 .726 .946 r
.25295 .37707 .2605 .384 .27173 .38143 .26413 .37526 Mtetra
.352 .657 .97 r
.26413 .37526 .27173 .38143 .28287 .3807 .27516 .37635 Mtetra
.36 0 0 r
.27516 .37635 .28287 .3807 .29385 .38321 .28589 .38253 Mtetra
.781 .295 .068 r
.28589 .38253 .29385 .38321 .30462 .39021 .29623 .39584 Mtetra
.81 .416 .306 r
.29623 .39584 .30462 .39021 .31522 .40179 .30625 .41647 Mtetra
.774 .423 .39 r
.30625 .41647 .31522 .40179 .32583 .41569 .31626 .44097 Mtetra
.707 .378 .418 r
.31626 .44097 .32583 .41569 .33676 .4273 .32673 .46199 Mtetra
.597 .285 .412 r
.32673 .46199 .33676 .4273 .34826 .43142 .33811 .47108 Mtetra
.426 .135 .366 r
.33811 .47108 .34826 .43142 .36039 .42531 .35051 .46374 Mtetra
.191 0 .27 r
.35051 .46374 .36039 .42531 .37295 .41076 .36361 .44286 Mtetra
0 0 .144 r
.36361 .44286 .37295 .41076 .38562 .3932 .37686 .4173 Mtetra
0 0 .062 r
.37686 .4173 .38562 .3932 .39813 .37867 .38979 .3967 Mtetra
.176 0 .111 r
.38979 .3967 .39813 .37867 .41037 .3708 .40225 .38677 Mtetra
.483 .098 .233 r
.40225 .38677 .41037 .3708 .42242 .36962 .41436 .38746 Mtetra
.595 .224 .309 r
.41436 .38746 .42242 .36962 .43445 .37233 .42637 .3942 Mtetra
.588 .236 .34 r
.42637 .3942 .43445 .37233 .44657 .37519 .43852 .40093 Mtetra
.531 .195 .343 r
.43852 .40093 .44657 .37519 .45885 .37569 .45092 .40345 Mtetra
.469 .144 .332 r
.45092 .40345 .45885 .37569 .47127 .37372 .4635 .40143 Mtetra
.444 .12 .322 r
.4635 .40143 .47127 .37372 .48377 .37111 .47619 .39779 Mtetra
.469 .14 .324 r
.47619 .39779 .48377 .37111 .49633 .3699 .48892 .39595 Mtetra
.51 .175 .335 r
.48892 .39595 .49633 .3699 .50896 .37055 .50171 .39702 Mtetra
.52 .185 .34 r
.50171 .39702 .50896 .37055 .52169 .37141 .5146 .39878 Mtetra
.473 .145 .329 r
.5146 .39878 .52169 .37141 .53451 .36967 .5276 .39711 Mtetra
.362 .047 .291 r
.5276 .39711 .53451 .36967 .54738 .36317 .54065 .38871 Mtetra
.185 0 .212 r
.54065 .38871 .54738 .36317 .56024 .35185 .55366 .37322 Mtetra
0 0 .085 r
.55366 .37322 .56024 .35185 .57306 .33787 .56659 .35354 Mtetra
0 0 0 r
.56659 .35354 .57306 .33787 .58588 .32464 .57946 .33434 Mtetra
.57946 .33434 .58588 .32464 .59878 .31539 .59238 .31999 Mtetra
.59238 .31999 .59878 .31539 .61186 .31216 .60547 .31323 Mtetra
.216 0 0 r
.60547 .31323 .61186 .31216 .62523 .31556 .61885 .31479 Mtetra
.556 0 0 r
.61885 .31479 .62523 .31556 .63895 .32488 .6326 .32373 Mtetra
.7 .159 0 r
.6326 .32373 .63895 .32488 .65302 .33846 .64674 .338 Mtetra
.749 .23 0 r
.64674 .338 .65302 .33846 .6674 .35403 .66122 .35486 Mtetra
.745 .229 0 r
.66122 .35486 .6674 .35403 .68199 .36893 .67593 .37125 Mtetra
.689 .16 0 r
.67593 .37125 .68199 .36893 .69663 .38045 .69071 .3841 Mtetra
.542 0 0 r
.69071 .3841 .69663 .38045 .71116 .38621 .70536 .39075 Mtetra
.2 0 0 r
.70536 .39075 .71116 .38621 .72538 .3846 .7197 .38939 Mtetra
0 0 0 r
.7197 .38939 .72538 .3846 .73917 .37511 .73358 .37946 Mtetra
.747 .936 .598 r
.73358 .37946 .73917 .37511 .75248 .35846 .74695 .36174 Mtetra
.903 .953 .609 r
.74695 .36174 .75248 .35846 .76533 .33636 .75982 .33809 Mtetra
.959 .936 .616 r
.75982 .33809 .76533 .33636 .77784 .3111 .77233 .31102 Mtetra
.977 .92 .635 r
.77233 .31102 .77784 .3111 .79016 .28501 .78462 .28307 Mtetra
.978 .909 .666 r
.78462 .28307 .79016 .28501 .80245 .26008 .79688 .25641 Mtetra
.965 .899 .706 r
.79688 .25641 .80245 .26008 .81487 .23767 .80926 .2325 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.663 .741 .908 r
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .3845 Mtetra
.20039 .3845 .20808 .39177 .21925 .38785 .21158 .38055 Mtetra
.66 .741 .909 r
.21158 .38055 .21925 .38785 .23046 .38397 .22282 .37666 Mtetra
.652 .739 .914 r
.22282 .37666 .23046 .38397 .2417 .38026 .23408 .37301 Mtetra
.623 .734 .926 r
.23408 .37301 .2417 .38026 .25295 .37707 .24533 .37009 Mtetra
.529 .71 .954 r
.24533 .37009 .25295 .37707 .26413 .37526 .25647 .36903 Mtetra
.166 .553 .93 r
.25647 .36903 .26413 .37526 .27516 .37635 .26737 .37196 Mtetra
.637 .086 0 r
.26737 .37196 .27516 .37635 .28589 .38253 .27782 .38186 Mtetra
.849 .417 .199 r
.27782 .38186 .28589 .38253 .29623 .39584 .2877 .4016 Mtetra
.851 .485 .357 r
.2877 .4016 .29623 .39584 .30625 .41647 .29709 .43155 Mtetra
.817 .478 .416 r
.29709 .43155 .30625 .41647 .31626 .44097 .3064 .46709 Mtetra
.752 .428 .436 r
.3064 .46709 .31626 .44097 .32673 .46199 .31633 .49803 Mtetra
.633 .321 .425 r
.31633 .49803 .32673 .46199 .33811 .47108 .32756 .51243 Mtetra
.411 .122 .361 r
.32756 .51243 .33811 .47108 .35051 .46374 .34025 .50383 Mtetra
.062 0 .215 r
.34025 .50383 .35051 .46374 .36361 .44286 .35394 .47635 Mtetra
0 0 .04 r
.35394 .47635 .36361 .44286 .37686 .4173 .36782 .44256 Mtetra
0 0 0 r
.36782 .44256 .37686 .4173 .38979 .3967 .38122 .41594 Mtetra
.132 0 .1 r
.38122 .41594 .38979 .3967 .40225 .38677 .3939 .40429 Mtetra
.535 .158 .273 r
.3939 .40429 .40225 .38677 .41436 .38746 .40603 .40741 Mtetra
.646 .286 .346 r
.40603 .40741 .41436 .38746 .42637 .3942 .41801 .41883 Mtetra
.628 .285 .369 r
.41801 .41883 .42637 .3942 .43852 .40093 .43017 .42988 Mtetra
.554 .225 .364 r
.43017 .42988 .43852 .40093 .45092 .40345 .44267 .43445 Mtetra
.467 .149 .343 r
.44267 .43445 .45092 .40345 .4635 .40143 .45545 .43194 Mtetra
.422 .108 .325 r
.45545 .43194 .4635 .40143 .47619 .39779 .46836 .42652 Mtetra
.449 .126 .325 r
.46836 .42652 .47619 .39779 .48892 .39595 .48129 .42322 Mtetra
.505 .171 .335 r
.48129 .42322 .48892 .39595 .50171 .39702 .49425 .42395 Mtetra
.522 .186 .339 r
.49425 .42395 .50171 .39702 .5146 .39878 .5073 .42606 Mtetra
.466 .135 .321 r
.5073 .42606 .5146 .39878 .5276 .39711 .52048 .42412 Mtetra
.311 0 .264 r
.52048 .42412 .5276 .39711 .54065 .38871 .53371 .41357 Mtetra
.045 0 .144 r
.53371 .41357 .54065 .38871 .55366 .37322 .5469 .39373 Mtetra
0 0 0 r
.5469 .39373 .55366 .37322 .56659 .35354 .55995 .36819 Mtetra
.55995 .36819 .56659 .35354 .57946 .33434 .5729 .34284 Mtetra
.679 .865 .469 r
.5729 .34284 .57946 .33434 .59238 .31999 .58585 .32316 Mtetra
.616 .936 .718 r
.58585 .32316 .59238 .31999 .60547 .31323 .59894 .31248 Mtetra
.146 .687 .823 r
.59894 .31248 .60547 .31323 .61885 .31479 .61232 .31164 Mtetra
.387 0 0 r
.61232 .31164 .61885 .31479 .6326 .32373 .62607 .31946 Mtetra
.609 .071 0 r
.62607 .31946 .6326 .32373 .64674 .338 .64023 .33352 Mtetra
.681 .161 0 r
.64023 .33352 .64674 .338 .66122 .35486 .65474 .35072 Mtetra
.676 .151 0 r
.65474 .35072 .66122 .35486 .67593 .37125 .6695 .36768 Mtetra
.586 .035 0 r
.6695 .36768 .67593 .37125 .69071 .3841 .68434 .38109 Mtetra
.306 0 0 r
.68434 .38109 .69071 .3841 .70536 .39075 .69907 .38811 Mtetra
.316 .772 .952 r
.69907 .38811 .70536 .39075 .7197 .38939 .71349 .38685 Mtetra
.788 .966 .919 r
.71349 .38685 .7197 .38939 .73358 .37946 .72745 .3767 Mtetra
.927 .939 .789 r
.72745 .3767 .73358 .37946 .74695 .36174 .74088 .35845 Mtetra
.963 .899 .712 r
.74088 .35845 .74695 .36174 .75982 .33809 .75381 .33406 Mtetra
.972 .873 .678 r
.75381 .33406 .75982 .33809 .77233 .31102 .76636 .30613 Mtetra
.971 .858 .67 r
.76636 .30613 .77233 .31102 .78462 .28307 .7787 .27731 Mtetra
.963 .85 .682 r
.7787 .27731 .78462 .28307 .79688 .25641 .79099 .24982 Mtetra
.948 .846 .708 r
.79099 .24982 .79688 .25641 .80926 .2325 .80341 .22519 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.663 .741 .908 r
.18146 .38114 .18924 .38844 .20039 .3845 .19263 .37716 Mtetra
.19263 .37716 .20039 .3845 .21158 .38055 .20385 .37319 Mtetra
.66 .74 .91 r
.20385 .37319 .21158 .38055 .22282 .37666 .21512 .36929 Mtetra
.649 .738 .914 r
.21512 .36929 .22282 .37666 .23408 .37301 .2264 .36567 Mtetra
.615 .73 .928 r
.2264 .36567 .23408 .37301 .24533 .37009 .23766 .36292 Mtetra
.498 .693 .956 r
.23766 .36292 .24533 .37009 .25647 .36903 .24878 .36239 Mtetra
.046 .464 .881 r
.24878 .36239 .25647 .36903 .26737 .37196 .25958 .3666 Mtetra
.721 .2 0 r
.25958 .3666 .26737 .37196 .27782 .38186 .26982 .37913 Mtetra
.885 .471 .218 r
.26982 .37913 .27782 .38186 .2877 .4016 .27934 .40343 Mtetra
.891 .53 .353 r
.27934 .40343 .2877 .4016 .29709 .43155 .28821 .44007 Mtetra
.868 .528 .404 r
.28821 .44007 .29709 .43155 .3064 .46709 .29696 .48362 Mtetra
.817 .481 .419 r
.29696 .48362 .3064 .46709 .31633 .49803 .30645 .52184 Mtetra
.692 .353 .396 r
.30645 .52184 .31633 .49803 .32756 .51243 .31753 .54018 Mtetra
.315 0 .255 r
.31753 .54018 .32756 .51243 .34025 .50383 .33045 .53072 Mtetra
0 0 0 r
.33045 .53072 .34025 .50383 .35394 .47635 .34462 .49855 Mtetra
.789 .824 .35 r
.34462 .49855 .35394 .47635 .36782 .44256 .359 .45905 Mtetra
.779 .856 .41 r
.359 .45905 .36782 .44256 .38122 .41594 .37276 .42859 Mtetra
0 0 0 r
.37276 .42859 .38122 .41594 .3939 .40429 .38559 .41645 Mtetra
.583 .166 .217 r
.38559 .41645 .3939 .40429 .40603 .40741 .39771 .42226 Mtetra
.707 .326 .324 r
.39771 .42226 .40603 .40741 .41801 .41883 .40962 .43796 Mtetra
.679 .315 .348 r
.40962 .43796 .41801 .41883 .43017 .42988 .42176 .45276 Mtetra
.576 .221 .331 r
.42176 .45276 .43017 .42988 .44267 .43445 .43436 .45895 Mtetra
.43 .089 .284 r
.43436 .45895 .44267 .43445 .45545 .43194 .44732 .4557 Mtetra
.338 .003 .24 r
.44732 .4557 .45545 .43194 .46836 .42652 .46043 .44827 Mtetra
.375 .025 .237 r
.46043 .44827 .46836 .42652 .48129 .42322 .47354 .44312 Mtetra
.471 .103 .258 r
.47354 .44312 .48129 .42322 .49425 .42395 .48665 .44296 Mtetra
.507 .131 .262 r
.48665 .44296 .49425 .42395 .5073 .42606 .49984 .44485 Mtetra
.416 .043 .22 r
.49984 .44485 .5073 .42606 .52048 .42412 .51316 .44236 Mtetra
.112 0 .082 r
.51316 .44236 .52048 .42412 .53371 .41357 .52656 .42996 Mtetra
0 0 0 r
.52656 .42996 .53371 .41357 .5469 .39373 .53991 .40664 Mtetra
.776 .848 .396 r
.53991 .40664 .5469 .39373 .55995 .36819 .5531 .37648 Mtetra
.915 .919 .533 r
.5531 .37648 .55995 .36819 .5729 .34284 .56614 .34626 Mtetra
.947 .955 .662 r
.56614 .34626 .5729 .34284 .58585 .32316 .57914 .32224 Mtetra
.881 .973 .839 r
.57914 .32224 .58585 .32316 .59894 .31248 .59225 .30817 Mtetra
.558 .84 .997 r
.59225 .30817 .59894 .31248 .61232 .31164 .60562 .30493 Mtetra
0 .416 .852 r
.60562 .30493 .61232 .31164 .62607 .31946 .61935 .31116 Mtetra
0 .103 .629 r
.61935 .31116 .62607 .31946 .64023 .33352 .63347 .32419 Mtetra
0 0 .544 r
.63347 .32419 .64023 .33352 .65474 .35072 .64796 .3407 Mtetra
0 .029 .581 r
.64796 .3407 .65474 .35072 .6695 .36768 .66269 .35719 Mtetra
0 .186 .716 r
.66269 .35719 .6695 .36768 .68434 .38109 .67753 .37027 Mtetra
.188 .44 .869 r
.67753 .37027 .68434 .38109 .69907 .38811 .69226 .37709 Mtetra
.552 .649 .899 r
.69226 .37709 .69907 .38811 .71349 .38685 .70671 .37575 Mtetra
.761 .738 .832 r
.70671 .37575 .71349 .38685 .72745 .3767 .72072 .36564 Mtetra
.856 .764 .761 r
.72072 .36564 .72745 .3767 .74088 .35845 .73423 .34753 Mtetra
.899 .772 .713 r
.73423 .34753 .74088 .35845 .75381 .33406 .74726 .32336 Mtetra
.918 .775 .687 r
.74726 .32336 .75381 .33406 .76636 .30613 .75991 .29567 Mtetra
.926 .779 .679 r
.75991 .29567 .76636 .30613 .7787 .27731 .77236 .2671 Mtetra
.924 .784 .687 r
.77236 .2671 .7787 .27731 .79099 .24982 .78476 .23985 Mtetra
.916 .79 .707 r
.78476 .23985 .79099 .24982 .80341 .22519 .79727 .21542 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.663 .741 .908 r
.17361 .37377 .18146 .38114 .19263 .37716 .18482 .36977 Mtetra
.18482 .36977 .19263 .37716 .20385 .37319 .19607 .36577 Mtetra
.66 .74 .91 r
.19607 .36577 .20385 .37319 .21512 .36929 .20735 .36183 Mtetra
.649 .738 .914 r
.20735 .36183 .21512 .36929 .2264 .36567 .21866 .3582 Mtetra
.613 .727 .927 r
.21866 .3582 .2264 .36567 .23766 .36292 .22994 .35546 Mtetra
.495 .685 .951 r
.22994 .35546 .23766 .36292 .24878 .36239 .24107 .35502 Mtetra
.065 .454 .882 r
.24107 .35502 .24878 .36239 .25958 .3666 .25186 .35949 Mtetra
.687 .182 0 r
.25186 .35949 .25958 .3666 .26982 .37913 .26204 .37257 Mtetra
.899 .482 .148 r
.26204 .37257 .26982 .37913 .27934 .40343 .27144 .39785 Mtetra
.93 .561 .289 r
.27144 .39785 .27934 .40343 .28821 .44007 .28014 .43595 Mtetra
.93 .576 .332 r
.28014 .43595 .28821 .44007 .29696 .48362 .28868 .48127 Mtetra
.916 .549 .316 r
.28868 .48127 .29696 .48362 .30645 .52184 .298 .52113 Mtetra
.832 .38 .148 r
.298 .52113 .30645 .52184 .31753 .54018 .30902 .5404 Mtetra
.775 .981 .909 r
.30902 .5404 .31753 .54018 .33045 .53072 .32202 .53086 Mtetra
.964 .844 .676 r
.32202 .53086 .33045 .53072 .34462 .49855 .33637 .49791 Mtetra
.965 .813 .643 r
.33637 .49791 .34462 .49855 .359 .45905 .35094 .4577 Mtetra
.956 .838 .687 r
.35094 .4577 .359 .45905 .37276 .42859 .36482 .42731 Mtetra
.834 .952 .894 r
.36482 .42731 .37276 .42859 .38559 .41645 .37767 .41641 Mtetra
.602 .037 0 r
.37767 .41641 .38559 .41645 .39771 .42226 .38973 .42444 Mtetra
.803 .35 .164 r
.38973 .42444 .39771 .42226 .40962 .43796 .40157 .44271 Mtetra
.772 .327 .193 r
.40157 .44271 .40962 .43796 .42176 .45276 .41369 .4595 Mtetra
.6 .119 .084 r
.41369 .4595 .42176 .45276 .43436 .45895 .42633 .46639 Mtetra
.137 0 0 r
.42633 .46639 .43436 .45895 .44732 .4557 .43941 .4625 Mtetra
0 0 0 r
.43941 .4625 .44732 .4557 .46043 .44827 .45265 .45365 Mtetra
.45265 .45365 .46043 .44827 .47354 .44312 .46589 .44708 Mtetra
.168 0 0 r
.46589 .44708 .47354 .44312 .48665 .44296 .47909 .44594 Mtetra
.296 0 0 r
.47909 .44594 .48665 .44296 .49984 .44485 .49236 .44726 Mtetra
0 0 0 r
.49236 .44726 .49984 .44485 .51316 .44236 .50576 .44422 Mtetra
.814 1 .811 r
.50576 .44422 .51316 .44236 .52656 .42996 .51926 .43084 Mtetra
.965 .925 .705 r
.51926 .43084 .52656 .42996 .53991 .40664 .53273 .40595 Mtetra
.979 .867 .657 r
.53273 .40595 .53991 .40664 .5531 .37648 .54604 .37374 Mtetra
.97 .843 .66 r
.54604 .37374 .5531 .37648 .56614 .34626 .55918 .34129 Mtetra
.944 .835 .705 r
.55918 .34129 .56614 .34626 .57914 .32224 .57224 .3151 Mtetra
.872 .82 .795 r
.57224 .3151 .57914 .32224 .59225 .30817 .58538 .29905 Mtetra
.671 .735 .898 r
.58538 .29905 .59225 .30817 .60562 .30493 .59875 .29399 Mtetra
.299 .501 .886 r
.59875 .29399 .60562 .30493 .61935 .31116 .61244 .29852 Mtetra
0 .265 .769 r
.61244 .29852 .61935 .31116 .63347 .32419 .62651 .30991 Mtetra
0 .169 .704 r
.62651 .30991 .63347 .32419 .64796 .3407 .64091 .32484 Mtetra
0 .195 .714 r
.64091 .32484 .64796 .3407 .66269 .35719 .65556 .33988 Mtetra
.161 .299 .758 r
.65556 .33988 .66269 .35719 .67753 .37027 .67031 .3518 Mtetra
.381 .427 .784 r
.67031 .3518 .67753 .37027 .69226 .37709 .68499 .35788 Mtetra
.568 .532 .775 r
.68499 .35788 .69226 .37709 .70671 .37575 .69943 .35631 Mtetra
.697 .601 .745 r
.69943 .35631 .70671 .37575 .72072 .36564 .71347 .34652 Mtetra
.777 .644 .715 r
.71347 .34652 .72072 .36564 .73423 .34753 .72706 .32921 Mtetra
.826 .672 .692 r
.72706 .32921 .73423 .34753 .74726 .32336 .74021 .30618 Mtetra
.856 .692 .679 r
.74021 .30618 .74726 .32336 .75991 .29567 .75302 .27982 Mtetra
.872 .709 .677 r
.75302 .27982 .75991 .29567 .77236 .2671 .76563 .2526 Mtetra
.879 .725 .686 r
.76563 .2526 .77236 .2671 .78476 .23985 .77821 .2266 Mtetra
.877 .739 .706 r
.77821 .2266 .78476 .23985 .79727 .21542 .79089 .20324 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.663 .741 .908 r
.16571 .36635 .17361 .37377 .18482 .36977 .17694 .36231 Mtetra
.17694 .36231 .18482 .36977 .19607 .36577 .18821 .35828 Mtetra
.66 .74 .909 r
.18821 .35828 .19607 .36577 .20735 .36183 .19953 .3543 Mtetra
.65 .737 .913 r
.19953 .3543 .20735 .36183 .21866 .3582 .21087 .35059 Mtetra
.619 .727 .923 r
.21087 .35059 .21866 .3582 .22994 .35546 .22219 .34768 Mtetra
.521 .687 .943 r
.22219 .34768 .22994 .35546 .24107 .35502 .23337 .34685 Mtetra
.2 .513 .913 r
.23337 .34685 .24107 .35502 .25186 .35949 .24424 .35043 Mtetra
0 0 .513 r
.24424 .35043 .25186 .35949 .26204 .37257 .25455 .36177 Mtetra
.835 .411 0 r
.25455 .36177 .26204 .37257 .27144 .39785 .26413 .38404 Mtetra
.912 .538 .104 r
.26413 .38404 .27144 .39785 .28014 .43595 .27307 .41774 Mtetra
.907 .561 .091 r
.27307 .41774 .28014 .43595 .28868 .48127 .28186 .45781 Mtetra
.724 .429 0 r
.28186 .45781 .28868 .48127 .298 .52113 .29138 .49289 Mtetra
.122 .16 .629 r
.29138 .49289 .298 .52113 .30902 .5404 .30247 .50962 Mtetra
.643 .5 .673 r
.30247 .50962 .30902 .5404 .32202 .53086 .31538 .50083 Mtetra
.776 .587 .644 r
.31538 .50083 .32202 .53086 .33637 .49791 .32954 .47142 Mtetra
.813 .618 .638 r
.32954 .47142 .33637 .49791 .35094 .4577 .34391 .43586 Mtetra
.803 .629 .666 r
.34391 .43586 .35094 .4577 .36482 .42731 .35762 .40954 Mtetra
.69 .598 .749 r
.35762 .40954 .36482 .42731 .37767 .41641 .37036 .4012 Mtetra
.14 .312 .777 r
.37036 .4012 .37767 .41641 .38973 .42444 .38237 .41021 Mtetra
0 0 .491 r
.38237 .41021 .38973 .42444 .40157 .44271 .39416 .42836 Mtetra
0 .003 .578 r
.39416 .42836 .40157 .44271 .41369 .4595 .40626 .4446 Mtetra
.277 .41 .817 r
.40626 .4446 .41369 .4595 .42633 .46639 .41891 .45101 Mtetra
.63 .601 .802 r
.41891 .45101 .42633 .46639 .43941 .4625 .43199 .44687 Mtetra
.711 .637 .772 r
.43199 .44687 .43941 .4625 .45265 .45365 .44527 .43783 Mtetra
.679 .62 .783 r
.44527 .43783 .45265 .45365 .46589 .44708 .45852 .43088 Mtetra
.575 .564 .804 r
.45852 .43088 .46589 .44708 .47909 .44594 .47173 .42914 Mtetra
.514 .523 .803 r
.47173 .42914 .47909 .44594 .49236 .44726 .485 .42981 Mtetra
.608 .568 .783 r
.485 .42981 .49236 .44726 .50576 .44422 .49841 .42642 Mtetra
.745 .633 .736 r
.49841 .42642 .50576 .44422 .51926 .43084 .51193 .41329 Mtetra
.827 .671 .689 r
.51193 .41329 .51926 .43084 .53273 .40595 .52545 .38922 Mtetra
.865 .689 .663 r
.52545 .38922 .53273 .40595 .54604 .37374 .53883 .35815 Mtetra
.875 .7 .662 r
.53883 .35815 .54604 .37374 .55918 .34129 .55206 .32672 Mtetra
.86 .705 .688 r
.55206 .32672 .55918 .34129 .57224 .3151 .56519 .30108 Mtetra
.805 .695 .743 r
.56519 .30108 .57224 .3151 .58538 .29905 .57837 .2849 Mtetra
.668 .637 .81 r
.57837 .2849 .58538 .29905 .59875 .29399 .59174 .27899 Mtetra
.434 .5 .828 r
.59174 .27899 .59875 .29399 .61244 .29852 .60539 .282 Mtetra
.223 .347 .78 r
.60539 .282 .61244 .29852 .62651 .30991 .61937 .29139 Mtetra
.149 .273 .737 r
.61937 .29139 .62651 .30991 .64091 .32484 .63366 .30409 Mtetra
.199 .283 .726 r
.63366 .30409 .64091 .32484 .65556 .33988 .64818 .31698 Mtetra
.316 .341 .728 r
.64818 .31698 .65556 .33988 .67031 .3518 .66281 .32711 Mtetra
.45 .414 .727 r
.66281 .32711 .67031 .3518 .68499 .35788 .67739 .33206 Mtetra
.567 .481 .716 r
.67739 .33206 .68499 .35788 .69943 .35631 .69177 .3302 Mtetra
.659 .535 .701 r
.69177 .3302 .69943 .35631 .71347 .34652 .70583 .32098 Mtetra
.726 .576 .687 r
.70583 .32098 .71347 .34652 .72706 .32921 .7195 .30502 Mtetra
.773 .609 .676 r
.7195 .30502 .72706 .32921 .74021 .30618 .7328 .28387 Mtetra
.805 .636 .671 r
.7328 .28387 .74021 .30618 .75302 .27982 .74579 .25967 Mtetra
.827 .659 .674 r
.74579 .25967 .75302 .27982 .76563 .2526 .75862 .23465 Mtetra
.838 .68 .686 r
.75862 .23465 .76563 .2526 .77821 .2266 .77141 .21069 Mtetra
.841 .699 .706 r
.77141 .21069 .77821 .2266 .79089 .20324 .78429 .1891 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.663 .741 .908 r
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .3548 Mtetra
.16899 .3548 .17694 .36231 .18821 .35828 .1803 .35072 Mtetra
.661 .74 .909 r
.1803 .35072 .18821 .35828 .19953 .3543 .19165 .34669 Mtetra
.653 .738 .912 r
.19165 .34669 .19953 .3543 .21087 .35059 .20303 .34286 Mtetra
.63 .729 .919 r
.20303 .34286 .21087 .35059 .22219 .34768 .21439 .33966 Mtetra
.56 .697 .932 r
.21439 .33966 .22219 .34768 .23337 .34685 .22566 .33809 Mtetra
.363 .587 .929 r
.22566 .33809 .23337 .34685 .24424 .35043 .23668 .33997 Mtetra
0 .262 .771 r
.23668 .33997 .24424 .35043 .25455 .36177 .24727 .3479 Mtetra
0 0 .44 r
.24727 .3479 .25455 .36177 .26413 .38404 .25728 .36434 Mtetra
0 0 .288 r
.25728 .36434 .26413 .38404 .27307 .41774 .26678 .38958 Mtetra
0 0 .365 r
.26678 .38958 .27307 .41774 .28186 .45781 .27618 .41958 Mtetra
.017 .033 .532 r
.27618 .41958 .28186 .45781 .29138 .49289 .28619 .44556 Mtetra
.399 .284 .606 r
.28619 .44556 .29138 .49289 .30247 .50962 .29745 .45741 Mtetra
.594 .419 .615 r
.29745 .45741 .30247 .50962 .31538 .50083 .31016 .44985 Mtetra
.684 .487 .614 r
.31016 .44985 .31538 .50083 .32954 .47142 .32387 .4267 Mtetra
.718 .519 .619 r
.32387 .4267 .32954 .47142 .34391 .43586 .33775 .39914 Mtetra
.706 .523 .639 r
.33775 .39914 .34391 .43586 .35762 .40954 .3511 .37914 Mtetra
.609 .477 .675 r
.3511 .37914 .35762 .40954 .37036 .4012 .36365 .3736 Mtetra
.373 .334 .686 r
.36365 .3736 .37036 .4012 .38237 .41021 .37562 .38191 Mtetra
.189 .207 .648 r
.37562 .38191 .38237 .41021 .39416 .42836 .38743 .39726 Mtetra
.285 .258 .653 r
.38743 .39726 .39416 .42836 .40626 .4446 .39954 .41059 Mtetra
.469 .372 .663 r
.39954 .41059 .40626 .4446 .41891 .45101 .41214 .41548 Mtetra
.583 .445 .659 r
.41214 .41548 .41891 .45101 .43199 .44687 .42516 .41149 Mtetra
.623 .473 .657 r
.42516 .41149 .43199 .44687 .44527 .43783 .43834 .40343 Mtetra
.608 .465 .662 r
.43834 .40343 .44527 .43783 .45852 .43088 .45152 .39717 Mtetra
.561 .437 .668 r
.45152 .39717 .45852 .43088 .47173 .42914 .46467 .39528 Mtetra
.537 .421 .668 r
.46467 .39528 .47173 .42914 .485 .42981 .47787 .39535 Mtetra
.578 .447 .665 r
.47787 .39535 .485 .42981 .49841 .42642 .49121 .39189 Mtetra
.656 .498 .657 r
.49121 .39189 .49841 .42642 .51193 .41329 .50468 .38006 Mtetra
.726 .546 .647 r
.50468 .38006 .51193 .41329 .52545 .38922 .51817 .35887 Mtetra
.77 .581 .643 r
.51817 .35887 .52545 .38922 .53883 .35815 .53157 .33165 Mtetra
.792 .606 .65 r
.53157 .33165 .53883 .35815 .55206 .32672 .54485 .30405 Mtetra
.788 .62 .673 r
.54485 .30405 .55206 .32672 .56519 .30108 .55804 .28135 Mtetra
.747 .617 .714 r
.55804 .28135 .56519 .30108 .57837 .2849 .57127 .26672 Mtetra
.648 .579 .763 r
.57127 .26672 .57837 .2849 .59174 .27899 .58464 .26088 Mtetra
.488 .49 .785 r
.58464 .26088 .59174 .27899 .60539 .282 .59825 .2627 Mtetra
.343 .388 .764 r
.59825 .2627 .60539 .282 .61937 .29139 .61214 .26998 Mtetra
.288 .333 .735 r
.61214 .26998 .61937 .29139 .63366 .30409 .6263 .28013 Mtetra
.317 .331 .717 r
.6263 .28013 .63366 .30409 .64818 .31698 .64067 .29047 Mtetra
.393 .364 .708 r
.64067 .29047 .64818 .31698 .66281 .32711 .65514 .29853 Mtetra
.482 .411 .7 r
.65514 .29853 .66281 .32711 .67739 .33206 .66961 .30225 Mtetra
.565 .458 .691 r
.66961 .30225 .67739 .33206 .69177 .3302 .68393 .30019 Mtetra
.637 .502 .682 r
.68393 .30019 .69177 .3302 .70583 .32098 .698 .29183 Mtetra
.694 .541 .675 r
.698 .29183 .70583 .32098 .7195 .30502 .71176 .27759 Mtetra
.738 .574 .67 r
.71176 .27759 .7195 .30502 .7328 .28387 .7252 .25875 Mtetra
.771 .603 .67 r
.7252 .25875 .7328 .28387 .74579 .25967 .73839 .23716 Mtetra
.794 .628 .676 r
.73839 .23716 .74579 .25967 .75862 .23465 .75144 .21476 Mtetra
.807 .652 .689 r
.75144 .21476 .75862 .23465 .77141 .21069 .76446 .19324 Mtetra
.812 .674 .71 r
.76446 .19324 .77141 .21069 .78429 .1891 .77756 .17376 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.663 .741 .908 r
.1497 .35133 .15773 .35887 .16899 .3548 .16098 .34722 Mtetra
.16098 .34722 .16899 .3548 .1803 .35072 .17232 .34311 Mtetra
.662 .741 .909 r
.17232 .34311 .1803 .35072 .19165 .34669 .1837 .33902 Mtetra
.657 .739 .91 r
.1837 .33902 .19165 .34669 .20303 .34286 .19512 .33506 Mtetra
.641 .732 .914 r
.19512 .33506 .20303 .34286 .21439 .33966 .20654 .33152 Mtetra
.598 .709 .922 r
.20654 .33152 .21439 .33966 .22566 .33809 .21791 .32909 Mtetra
.49 .643 .924 r
.21791 .32909 .22566 .33809 .23668 .33997 .22912 .32902 Mtetra
.271 .477 .876 r
.22912 .32902 .23668 .33997 .24727 .3479 .24004 .33306 Mtetra
.013 .227 .735 r
.24004 .33306 .24727 .3479 .25728 .36434 .25057 .34285 Mtetra
0 .081 .616 r
.25057 .34285 .25728 .36434 .26678 .38958 .26077 .35851 Mtetra
.086 .111 .59 r
.26077 .35851 .26678 .38958 .27618 .41958 .27092 .37724 Mtetra
.302 .223 .598 r
.27092 .37724 .27618 .41958 .28619 .44556 .28151 .39315 Mtetra
.472 .327 .603 r
.28151 .39315 .28619 .44556 .29745 .45741 .29299 .39962 Mtetra
.579 .4 .604 r
.29299 .39962 .29745 .45741 .31016 .44985 .30547 .39328 Mtetra
.64 .447 .606 r
.30547 .39328 .31016 .44985 .32387 .4267 .31865 .37677 Mtetra
.666 .474 .615 r
.31865 .37677 .32387 .4267 .33775 .39914 .33195 .35758 Mtetra
.653 .476 .632 r
.33195 .35758 .33775 .39914 .3511 .37914 .34489 .34387 Mtetra
.578 .439 .655 r
.34489 .34387 .3511 .37914 .36365 .3736 .35727 .34035 Mtetra
.442 .353 .66 r
.35727 .34035 .36365 .3736 .37562 .38191 .36925 .34649 Mtetra
.366 .294 .642 r
.36925 .34649 .37562 .38191 .38743 .39726 .38114 .35735 Mtetra
.417 .316 .633 r
.38114 .35735 .38743 .39726 .39954 .41059 .3933 .36642 Mtetra
.506 .369 .629 r
.3933 .36642 .39954 .41059 .41214 .41548 .40585 .3692 Mtetra
.568 .409 .626 r
.40585 .3692 .41214 .41548 .42516 .41149 .41874 .36552 Mtetra
.591 .426 .627 r
.41874 .36552 .42516 .41149 .43834 .40343 .43177 .35899 Mtetra
.581 .422 .631 r
.43177 .35899 .43834 .40343 .45152 .39717 .44482 .35391 Mtetra
.553 .405 .634 r
.44482 .35391 .45152 .39717 .46467 .39528 .45785 .35207 Mtetra
.54 .397 .634 r
.45785 .35207 .46467 .39528 .47787 .39535 .47095 .35154 Mtetra
.567 .414 .633 r
.47095 .35154 .47787 .39535 .49121 .39189 .48418 .34811 Mtetra
.62 .451 .632 r
.48418 .34811 .49121 .39189 .50468 .38006 .49755 .33815 Mtetra
.673 .49 .631 r
.49755 .33815 .50468 .38006 .51817 .35887 .51096 .32093 Mtetra
.712 .525 .634 r
.51096 .32093 .51817 .35887 .53157 .33165 .52433 .29903 Mtetra
.734 .551 .645 r
.52433 .29903 .53157 .33165 .54485 .30405 .53762 .27682 Mtetra
.735 .569 .668 r
.53762 .27682 .54485 .30405 .55804 .28135 .55085 .25841 Mtetra
.704 .572 .704 r
.55085 .25841 .55804 .28135 .57127 .26672 .56411 .24632 Mtetra
.628 .548 .745 r
.56411 .24632 .57127 .26672 .58464 .26088 .5775 .24116 Mtetra
.513 .488 .766 r
.5775 .24116 .58464 .26088 .59825 .2627 .59107 .24206 Mtetra
.411 .417 .756 r
.59107 .24206 .59825 .2627 .61214 .26998 .60487 .24732 Mtetra
.368 .373 .734 r
.60487 .24732 .61214 .26998 .6263 .28013 .6189 .25491 Mtetra
.384 .365 .715 r
.6189 .25491 .6263 .28013 .64067 .29047 .63312 .26276 Mtetra
.434 .383 .702 r
.63312 .26276 .64067 .29047 .65514 .29853 .64746 .26891 Mtetra
.496 .414 .693 r
.64746 .26891 .65514 .29853 .66961 .30225 .66182 .27167 Mtetra
.561 .452 .687 r
.66182 .27167 .66961 .30225 .68393 .30019 .6761 .26977 Mtetra
.622 .491 .682 r
.6761 .26977 .68393 .30019 .698 .29183 .69019 .26259 Mtetra
.676 .53 .678 r
.69019 .26259 .698 .29183 .71176 .27759 .70403 .25031 Mtetra
.721 .564 .677 r
.70403 .25031 .71176 .27759 .7252 .25875 .71762 .23388 Mtetra
.755 .595 .679 r
.71762 .23388 .7252 .25875 .73839 .23716 .73099 .21483 Mtetra
.778 .621 .686 r
.73099 .21483 .73839 .23716 .75144 .21476 .74424 .1949 Mtetra
.791 .644 .7 r
.74424 .1949 .75144 .21476 .76446 .19324 .75747 .17567 Mtetra
.795 .666 .721 r
.75747 .17567 .76446 .19324 .77756 .17376 .77079 .15821 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.663 .741 .908 r
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34311 .16428 .33543 Mtetra
.662 .741 .908 r
.16428 .33543 .17232 .34311 .1837 .33902 .17569 .33128 Mtetra
.659 .739 .909 r
.17569 .33128 .1837 .33902 .19512 .33506 .18714 .32721 Mtetra
.65 .735 .911 r
.18714 .32721 .19512 .33506 .20654 .33152 .19862 .32337 Mtetra
.626 .72 .914 r
.19862 .32337 .20654 .33152 .21791 .32909 .21008 .32019 Mtetra
.572 .682 .915 r
.21008 .32019 .21791 .32909 .22912 .32902 .22147 .3184 Mtetra
.47 .594 .894 r
.22147 .3184 .22912 .32902 .24004 .33306 .2327 .31905 Mtetra
.347 .455 .829 r
.2327 .31905 .24004 .33306 .25057 .34285 .24372 .32308 Mtetra
.289 .336 .738 r
.24372 .32308 .25057 .34285 .26077 .35851 .25455 .33054 Mtetra
.334 .3 .671 r
.25455 .33054 .26077 .35851 .27092 .37724 .26538 .33972 Mtetra
.426 .324 .636 r
.26538 .33972 .27092 .37724 .28151 .39315 .2765 .34719 Mtetra
.512 .366 .62 r
.2765 .34719 .28151 .39315 .29299 .39962 .28817 .34915 Mtetra
.577 .407 .614 r
.28817 .34915 .29299 .39962 .30547 .39328 .30046 .34372 Mtetra
.62 .439 .616 r
.30046 .34372 .30547 .39328 .31865 .37677 .31319 .33253 Mtetra
.638 .461 .626 r
.31319 .33253 .31865 .37677 .33195 .35758 .32601 .32 Mtetra
.626 .465 .644 r
.32601 .32 .33195 .35758 .34489 .34387 .33861 .31099 Mtetra
.569 .44 .664 r
.33861 .31099 .34489 .34387 .35727 .34035 .35088 .30832 Mtetra
.485 .386 .668 r
.35088 .30832 .35727 .34035 .36925 .34649 .36292 .31157 Mtetra
.447 .35 .653 r
.36292 .31157 .36925 .34649 .38114 .35735 .37494 .31758 Mtetra
.476 .357 .637 r
.37494 .31758 .38114 .35735 .3933 .36642 .38716 .32226 Mtetra
.527 .383 .628 r
.38716 .32226 .3933 .36642 .40585 .3692 .39968 .32285 Mtetra
.564 .405 .624 r
.39968 .32285 .40585 .3692 .41874 .36552 .41244 .31937 Mtetra
.579 .416 .625 r
.41244 .31937 .41874 .36552 .43177 .35899 .42532 .31422 Mtetra
.571 .413 .628 r
.42532 .31422 .43177 .35899 .44482 .35391 .43823 .31015 Mtetra
.552 .402 .631 r
.43823 .31015 .44482 .35391 .45785 .35207 .45115 .30822 Mtetra
.545 .397 .631 r
.45115 .30822 .45785 .35207 .47095 .35154 .46415 .30698 Mtetra
.565 .41 .63 r
.46415 .30698 .47095 .35154 .48418 .34811 .47727 .30353 Mtetra
.604 .437 .629 r
.47727 .30353 .48418 .34811 .49755 .33815 .49051 .2954 Mtetra
.644 .468 .631 r
.49051 .2954 .49755 .33815 .51096 .32093 .50383 .28218 Mtetra
.677 .498 .637 r
.50383 .28218 .51096 .32093 .52433 .29903 .51714 .2657 Mtetra
.696 .524 .651 r
.51714 .2657 .52433 .29903 .53762 .27682 .53041 .24902 Mtetra
.697 .544 .676 r
.53041 .24902 .53762 .27682 .55085 .25841 .54367 .23508 Mtetra
.672 .552 .71 r
.54367 .23508 .55085 .25841 .56411 .24632 .55695 .22571 Mtetra
.613 .538 .746 r
.55695 .22571 .56411 .24632 .5775 .24116 .57034 .22139 Mtetra
.528 .497 .765 r
.57034 .22139 .5775 .24116 .59107 .24206 .58388 .22153 Mtetra
.453 .445 .759 r
.58388 .22153 .59107 .24206 .60487 .24732 .59761 .22499 Mtetra
.418 .407 .741 r
.59761 .22499 .60487 .24732 .6189 .25491 .61154 .23036 Mtetra
.421 .393 .723 r
.61154 .23036 .6189 .25491 .63312 .26276 .62564 .2362 Mtetra
.45 .4 .71 r
.62564 .2362 .63312 .26276 .64746 .26891 .63988 .24109 Mtetra
.495 .422 .704 r
.63988 .24109 .64746 .26891 .66182 .27167 .65417 .24365 Mtetra
.55 .456 .702 r
.65417 .24365 .66182 .27167 .6761 .26977 .66845 .24264 Mtetra
.61 .499 .702 r
.66845 .24264 .6761 .26977 .69019 .26259 .6826 .23718 Mtetra
.671 .545 .702 r
.6826 .23718 .69019 .26259 .70403 .25031 .69655 .227 Mtetra
.724 .587 .702 r
.69655 .227 .70403 .25031 .71762 .23388 .71027 .21269 Mtetra
.763 .622 .703 r
.71027 .21269 .71762 .23388 .73099 .21483 .7238 .19557 Mtetra
.787 .648 .708 r
.7238 .19557 .73099 .21483 .74424 .1949 .7372 .17733 Mtetra
.797 .667 .72 r
.7372 .17733 .74424 .1949 .75747 .17567 .75059 .15961 Mtetra
.795 .682 .74 r
.75059 .15961 .75747 .17567 .77079 .15821 .76405 .14353 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.663 .741 .908 r
.14477 .33188 .15291 .33958 .16428 .33543 .15616 .32769 Mtetra
.15616 .32769 .16428 .33543 .17569 .33128 .16761 .32349 Mtetra
.661 .74 .908 r
.16761 .32349 .17569 .33128 .18714 .32721 .1791 .31932 Mtetra
.657 .737 .909 r
.1791 .31932 .18714 .32721 .19862 .32337 .19062 .31527 Mtetra
.645 .729 .91 r
.19062 .31527 .19862 .32337 .21008 .32019 .20217 .31155 Mtetra
.619 .707 .908 r
.20217 .31155 .21008 .32019 .22147 .3184 .21369 .30853 Mtetra
.572 .66 .896 r
.21369 .30853 .22147 .3184 .2327 .31905 .22516 .30677 Mtetra
.513 .58 .86 r
.22516 .30677 .2327 .31905 .24372 .32308 .23654 .30675 Mtetra
.471 .491 .797 r
.23654 .30675 .24372 .32308 .25455 .33054 .24784 .30847 Mtetra
.471 .43 .731 r
.24784 .30847 .25455 .33054 .26538 .33972 .25917 .31104 Mtetra
.504 .411 .683 r
.25917 .31104 .26538 .33972 .2765 .34719 .27068 .31271 Mtetra
.548 .418 .656 r
.27068 .31271 .2765 .34719 .28817 .34915 .28251 .31156 Mtetra
.587 .437 .645 r
.28251 .31156 .28817 .34915 .30046 .34372 .29468 .30669 Mtetra
.615 .458 .646 r
.29468 .30669 .30046 .34372 .31319 .33253 .30711 .29896 Mtetra
.628 .476 .657 r
.30711 .29896 .31319 .33253 .32601 .32 .31961 .29069 Mtetra
.618 .484 .677 r
.31961 .29069 .32601 .32 .33861 .31099 .332 .28445 Mtetra
.578 .471 .696 r
.332 .28445 .33861 .31099 .35088 .30832 .34423 .28169 Mtetra
.525 .438 .699 r
.34423 .28169 .35088 .30832 .36292 .31157 .35636 .28214 Mtetra
.503 .409 .682 r
.35636 .28214 .36292 .31157 .37494 .31758 .36852 .284 Mtetra
.519 .404 .662 r
.36852 .284 .37494 .31758 .38716 .32226 .38082 .28503 Mtetra
.548 .413 .649 r
.38082 .28503 .38716 .32226 .39968 .32285 .39332 .28372 Mtetra
.57 .423 .643 r
.39332 .28372 .39968 .32285 .41244 .31937 .40599 .2802 Mtetra
.578 .429 .643 r
.40599 .2802 .41244 .31937 .42532 .31422 .41876 .27587 Mtetra
.571 .427 .646 r
.41876 .27587 .42532 .31422 .43823 .31015 .43157 .2723 Mtetra
.559 .419 .648 r
.43157 .2723 .43823 .31015 .45115 .30822 .44442 .26998 Mtetra
.555 .416 .647 r
.44442 .26998 .45115 .30822 .46415 .30698 .45734 .26792 Mtetra
.571 .425 .644 r
.45734 .26792 .46415 .30698 .47727 .30353 .47037 .2643 Mtetra
.599 .444 .643 r
.47037 .2643 .47727 .30353 .49051 .2954 .48351 .25763 Mtetra
.63 .469 .645 r
.48351 .25763 .49051 .2954 .50383 .28218 .49673 .24771 Mtetra
.656 .495 .654 r
.49673 .24771 .50383 .28218 .51714 .2657 .50998 .23574 Mtetra
.672 .52 .67 r
.50998 .23574 .51714 .2657 .53041 .24902 .52323 .22371 Mtetra
.672 .541 .696 r
.52323 .22371 .53041 .24902 .54367 .23508 .53649 .21354 Mtetra
.651 .552 .73 r
.53649 .21354 .54367 .23508 .55695 .22571 .54979 .20643 Mtetra
.604 .545 .761 r
.54979 .20643 .55695 .22571 .57034 .22139 .56318 .20277 Mtetra
.54 .516 .778 r
.56318 .20277 .57034 .22139 .58388 .22153 .5767 .20226 Mtetra
.481 .475 .774 r
.5767 .20226 .58388 .22153 .59761 .22499 .59038 .20426 Mtetra
.444 .439 .758 r
.59038 .20426 .59761 .22499 .61154 .23036 .60424 .20803 Mtetra
.43 .417 .743 r
.60424 .20803 .61154 .23036 .62564 .2362 .61827 .21275 Mtetra
.436 .412 .734 r
.61827 .21275 .62564 .2362 .63988 .24109 .63246 .21753 Mtetra
.461 .428 .735 r
.63246 .21753 .63988 .24109 .65417 .24365 .64677 .22117 Mtetra
.511 .468 .746 r
.64677 .22117 .65417 .24365 .66845 .24264 .66111 .22224 Mtetra
.587 .532 .76 r
.66111 .22224 .66845 .24264 .6826 .23718 .67538 .21929 Mtetra
.679 .608 .769 r
.67538 .21929 .6826 .23718 .69655 .227 .68948 .21139 Mtetra
.761 .674 .766 r
.68948 .21139 .69655 .227 .71027 .21269 .70334 .19863 Mtetra
.815 .715 .754 r
.70334 .19863 .71027 .21269 .7238 .19557 .71697 .18227 Mtetra
.839 .733 .748 r
.71697 .18227 .7238 .19557 .7372 .17733 .73045 .16428 Mtetra
.839 .737 .752 r
.73045 .16428 .7372 .17733 .75059 .15961 .7439 .14665 Mtetra
.823 .735 .767 r
.7439 .14665 .75059 .15961 .76405 .14353 .75744 .13079 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.663 .741 .908 r
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32349 .15946 .31565 Mtetra
.15946 .31565 .16761 .32349 .1791 .31932 .17098 .31141 Mtetra
.66 .739 .908 r
.17098 .31141 .1791 .31932 .19062 .31527 .18255 .30721 Mtetra
.655 .735 .908 r
.18255 .30721 .19062 .31527 .20217 .31155 .19415 .30315 Mtetra
.644 .723 .906 r
.19415 .30315 .20217 .31155 .21369 .30853 .20578 .2994 Mtetra
.623 .699 .899 r
.20578 .2994 .21369 .30853 .22516 .30677 .2174 .29621 Mtetra
.596 .656 .879 r
.2174 .29621 .22516 .30677 .23654 .30675 .22901 .29378 Mtetra
.571 .597 .84 r
.22901 .29378 .23654 .30675 .24784 .30847 .24062 .29213 Mtetra
.561 .542 .791 r
.24062 .29213 .24784 .30847 .25917 .31104 .25227 .29085 Mtetra
.568 .506 .746 r
.25227 .29085 .25917 .31104 .27068 .31271 .26402 .28914 Mtetra
.586 .492 .715 r
.26402 .28914 .27068 .31271 .28251 .31156 .27596 .28617 Mtetra
.607 .495 .7 r
.27596 .28617 .28251 .31156 .29468 .30669 .28808 .28155 Mtetra
.624 .507 .7 r
.28808 .28155 .29468 .30669 .30711 .29896 .30035 .2757 Mtetra
.632 .523 .712 r
.30035 .2757 .30711 .29896 .31961 .29069 .31267 .26969 Mtetra
.625 .534 .732 r
.31267 .26969 .31961 .29069 .332 .28445 .32497 .2647 Mtetra
.599 .53 .749 r
.32497 .2647 .332 .28445 .34423 .28169 .33722 .26141 Mtetra
.568 .508 .748 r
.33722 .26141 .34423 .28169 .35636 .28214 .34945 .25966 Mtetra
.553 .482 .73 r
.34945 .25966 .35636 .28214 .36852 .284 .36172 .25855 Mtetra
.559 .466 .706 r
.36172 .25855 .36852 .284 .38082 .28503 .3741 .25698 Mtetra
.573 .462 .689 r
.3741 .25698 .38082 .28503 .39332 .28372 .38662 .25426 Mtetra
.585 .464 .681 r
.38662 .25426 .39332 .28372 .40599 .2802 .39925 .2505 Mtetra
.588 .465 .68 r
.39925 .2505 .40599 .2802 .41876 .27587 .41196 .24644 Mtetra
.582 .463 .682 r
.41196 .24644 .41876 .27587 .43157 .2723 .42471 .24285 Mtetra
.574 .458 .683 r
.42471 .24285 .43157 .2723 .44442 .26998 .43752 .23992 Mtetra
.572 .454 .68 r
.43752 .23992 .44442 .26998 .45734 .26792 .4504 .23703 Mtetra
.584 .459 .676 r
.4504 .23703 .45734 .26792 .47037 .2643 .46338 .23313 Mtetra
.604 .471 .673 r
.46338 .23313 .47037 .2643 .48351 .25763 .47646 .22741 Mtetra
.627 .49 .675 r
.47646 .22741 .48351 .25763 .49673 .24771 .48962 .21981 Mtetra
.647 .512 .685 r
.48962 .21981 .49673 .24771 .50998 .23574 .50282 .21106 Mtetra
.658 .536 .703 r
.50282 .21106 .50998 .23574 .52323 .22371 .51605 .20236 Mtetra
.657 .557 .73 r
.51605 .20236 .52323 .22371 .53649 .21354 .52931 .19485 Mtetra
.639 .57 .761 r
.52931 .19485 .53649 .21354 .54979 .20643 .54263 .18929 Mtetra
.601 .567 .788 r
.54263 .18929 .54979 .20643 .56318 .20277 .55603 .18598 Mtetra
.551 .544 .801 r
.55603 .18598 .56318 .20277 .5767 .20226 .56954 .1849 Mtetra
.498 .508 .798 r
.56954 .1849 .5767 .20226 .59038 .20426 .58319 .18591 Mtetra
.448 .467 .787 r
.58319 .18591 .59038 .20426 .60424 .20803 .59701 .18889 Mtetra
.403 .432 .776 r
.59701 .18889 .60424 .20803 .61827 .21275 .61102 .19369 Mtetra
.362 .408 .775 r
.61102 .19369 .61827 .21275 .63246 .21753 .62524 .19985 Mtetra
.338 .412 .791 r
.62524 .19985 .63246 .21753 .64677 .22117 .63964 .20627 Mtetra
.358 .468 .835 r
.63964 .20627 .64677 .22117 .66111 .22224 .65415 .21099 Mtetra
.467 .607 .907 r
.65415 .21099 .66111 .22224 .67538 .21929 .66863 .21162 Mtetra
.667 .798 .945 r
.66863 .21162 .67538 .21929 .68948 .21139 .68293 .20621 Mtetra
.837 .909 .887 r
.68293 .20621 .68948 .21139 .70334 .19863 .69692 .19426 Mtetra
.912 .92 .808 r
.69692 .19426 .70334 .19863 .71697 .18227 .7106 .17711 Mtetra
.931 .895 .771 r
.7106 .17711 .71697 .18227 .73045 .16428 .72406 .15741 Mtetra
.917 .862 .77 r
.72406 .15741 .73045 .16428 .7439 .14665 .73748 .13796 Mtetra
.882 .826 .788 r
.73748 .13796 .7439 .14665 .75744 .13079 .75099 .12073 Mtetra
.664 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.663 .741 .908 r
.13974 .31203 .14799 .31989 .15946 .31565 .15124 .30774 Mtetra
.15124 .30774 .15946 .31565 .17098 .31141 .1628 .30345 Mtetra
.662 .74 .908 r
.1628 .30345 .17098 .31141 .18255 .30721 .1744 .29916 Mtetra
.66 .738 .908 r
.1744 .29916 .18255 .30721 .19415 .30315 .18605 .29492 Mtetra
.656 .733 .906 r
.18605 .29492 .19415 .30315 .20578 .2994 .19774 .29078 Mtetra
.648 .722 .902 r
.19774 .29078 .20578 .2994 .2174 .29621 .20946 .28685 Mtetra
.637 .701 .892 r
.20946 .28685 .2174 .29621 .22901 .29378 .2212 .28321 Mtetra
.625 .669 .872 r
.2212 .28321 .22901 .29378 .24062 .29213 .23298 .27986 Mtetra
.617 .633 .844 r
.23298 .27986 .24062 .29213 .25227 .29085 .24481 .27665 Mtetra
.617 .601 .813 r
.24481 .27665 .25227 .29085 .26402 .28914 .25671 .27325 Mtetra
.622 .582 .787 r
.25671 .27325 .26402 .28914 .27596 .28617 .26872 .26936 Mtetra
.632 .576 .774 r
.26872 .26936 .27596 .28617 .28808 .28155 .28084 .26482 Mtetra
.641 .582 .773 r
.28084 .26482 .28808 .28155 .30035 .2757 .29304 .25981 Mtetra
.645 .595 .783 r
.29304 .25981 .30035 .2757 .31267 .26969 .3053 .25477 Mtetra
.64 .605 .799 r
.3053 .25477 .31267 .26969 .32497 .2647 .31758 .25019 Mtetra
.625 .604 .81 r
.31758 .25019 .32497 .2647 .33722 .26141 .32987 .24633 Mtetra
.608 .589 .806 r
.32987 .24633 .33722 .26141 .34945 .25966 .34219 .24312 Mtetra
.598 .565 .788 r
.34219 .24312 .34945 .25966 .36172 .25855 .35456 .24017 Mtetra
.598 .545 .766 r
.35456 .24017 .36172 .25855 .3741 .25698 .367 .237 Mtetra
.603 .533 .749 r
.367 .237 .3741 .25698 .38662 .25426 .37955 .23334 Mtetra
.608 .528 .739 r
.37955 .23334 .38662 .25426 .39925 .2505 .39218 .22925 Mtetra
.608 .526 .737 r
.39218 .22925 .39925 .2505 .41196 .24644 .40487 .22511 Mtetra
.603 .523 .737 r
.40487 .22511 .41196 .24644 .42471 .24285 .41762 .22123 Mtetra
.597 .518 .736 r
.41762 .22123 .42471 .24285 .43752 .23992 .43043 .21765 Mtetra
.596 .513 .731 r
.43043 .21765 .43752 .23992 .4504 .23703 .44331 .21402 Mtetra
.603 .512 .724 r
.44331 .21402 .4504 .23703 .46338 .23313 .45627 .2098 Mtetra
.617 .519 .72 r
.45627 .2098 .46338 .23313 .47646 .22741 .46932 .2046 Mtetra
.633 .532 .722 r
.46932 .2046 .47646 .22741 .48962 .21981 .48244 .19842 Mtetra
.646 .55 .732 r
.48244 .19842 .48962 .21981 .50282 .21106 .49562 .19167 Mtetra
.654 .571 .75 r
.49562 .19167 .50282 .21106 .51605 .20236 .50884 .18501 Mtetra
.651 .591 .774 r
.50884 .18501 .51605 .20236 .52931 .19485 .52211 .17909 Mtetra
.634 .602 .8 r
.52211 .17909 .52931 .19485 .54263 .18929 .53545 .17438 Mtetra
.603 .599 .82 r
.53545 .17438 .54263 .18929 .55603 .18598 .54886 .17115 Mtetra
.559 .578 .83 r
.54886 .17115 .55603 .18598 .56954 .1849 .56237 .16964 Mtetra
.501 .54 .829 r
.56237 .16964 .56954 .1849 .58319 .18591 .57602 .17015 Mtetra
.423 .489 .823 r
.57602 .17015 .58319 .18591 .59701 .18889 .58984 .17321 Mtetra
.311 .423 .815 r
.58984 .17321 .59701 .18889 .61102 .19369 .60388 .17929 Mtetra
.152 .345 .802 r
.60388 .17929 .61102 .19369 .62524 .19985 .61819 .18838 Mtetra
0 .264 .772 r
.61819 .18838 .62524 .19985 .63964 .20627 .63277 .19929 Mtetra
0 .226 .708 r
.63277 .19929 .63964 .20627 .65415 .21099 .64753 .2093 Mtetra
.283 0 0 r
.64753 .2093 .65415 .21099 .66863 .21162 .6623 .21464 Mtetra
.001 0 0 r
.6623 .21464 .66863 .21162 .68293 .20621 .67684 .21197 Mtetra
0 0 0 r
.67684 .21197 .68293 .20621 .69692 .19426 .69098 .20002 Mtetra
.724 .906 .538 r
.69098 .20002 .69692 .19426 .7106 .17711 .70466 .18044 Mtetra
.892 .955 .611 r
.70466 .18044 .7106 .17711 .72406 .15741 .71803 .15699 Mtetra
.953 .953 .692 r
.71803 .15699 .72406 .15741 .73748 .13796 .73131 .13371 Mtetra
.941 .917 .762 r
.73131 .13371 .73748 .13796 .75099 .12073 .74471 .11347 Mtetra
.664 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.663 .741 .908 r
.14296 .29978 .15124 .30774 .1628 .30345 .15454 .29544 Mtetra
.15454 .29544 .1628 .30345 .1744 .29916 .16618 .29109 Mtetra
.662 .74 .908 r
.16618 .29109 .1744 .29916 .18605 .29492 .17786 .28675 Mtetra
.661 .738 .907 r
.17786 .28675 .18605 .29492 .19774 .29078 .1896 .28242 Mtetra
.658 .733 .905 r
.1896 .28242 .19774 .29078 .20946 .28685 .20138 .27816 Mtetra
.654 .724 .901 r
.20138 .27816 .20946 .28685 .2212 .28321 .2132 .27398 Mtetra
.65 .711 .892 r
.2132 .27398 .2212 .28321 .23298 .27986 .22507 .26989 Mtetra
.646 .693 .879 r
.22507 .26989 .23298 .27986 .24481 .27665 .237 .26583 Mtetra
.646 .675 .864 r
.237 .26583 .24481 .27665 .25671 .27325 .24898 .26169 Mtetra
.648 .662 .85 r
.24898 .26169 .25671 .27325 .26872 .26936 .26104 .25738 Mtetra
.651 .656 .842 r
.26104 .25738 .26872 .26936 .28084 .26482 .27318 .25283 Mtetra
.655 .658 .841 r
.27318 .25283 .28084 .26482 .29304 .25981 .28538 .24812 Mtetra
.656 .665 .847 r
.28538 .24812 .29304 .25981 .3053 .25477 .29763 .24341 Mtetra
.653 .671 .855 r
.29763 .24341 .3053 .25477 .31758 .25019 .30993 .23887 Mtetra
.645 .67 .859 r
.30993 .23887 .31758 .25019 .32987 .24633 .32227 .2346 Mtetra
.637 .659 .855 r
.32227 .2346 .32987 .24633 .34219 .24312 .33465 .23056 Mtetra
.632 .642 .842 r
.33465 .23056 .34219 .24312 .35456 .24017 .34709 .22661 Mtetra
.631 .625 .826 r
.34709 .22661 .35456 .24017 .367 .237 .3596 .22256 Mtetra
.632 .613 .813 r
.3596 .22256 .367 .237 .37955 .23334 .37218 .21833 Mtetra
.632 .606 .805 r
.37218 .21833 .37955 .23334 .39218 .22925 .38482 .21396 Mtetra
.631 .601 .802 r
.38482 .21396 .39218 .22925 .40487 .22511 .39754 .20959 Mtetra
.627 .597 .8 r
.39754 .20959 .40487 .22511 .41762 .22123 .4103 .20535 Mtetra
.623 .591 .797 r
.4103 .20535 .41762 .22123 .43043 .21765 .42313 .20123 Mtetra
.622 .584 .79 r
.42313 .20123 .43043 .21765 .44331 .21402 .43603 .19705 Mtetra
.626 .58 .783 r
.43603 .19705 .44331 .21402 .45627 .2098 .44901 .19255 Mtetra
.634 .582 .778 r
.44901 .19255 .45627 .2098 .46932 .2046 .46205 .18757 Mtetra
.644 .59 .779 r
.46205 .18757 .46932 .2046 .48244 .19842 .47517 .18213 Mtetra
.651 .603 .788 r
.47517 .18213 .48244 .19842 .49562 .19167 .48835 .17645 Mtetra
.654 .619 .802 r
.48835 .17645 .49562 .19167 .50884 .18501 .50158 .17087 Mtetra
.649 .633 .821 r
.50158 .17087 .50884 .18501 .52211 .17909 .51488 .16574 Mtetra
.635 .64 .838 r
.51488 .16574 .52211 .17909 .53545 .17438 .52823 .16136 Mtetra
.608 .634 .852 r
.52823 .16136 .53545 .17438 .54886 .17115 .54167 .15805 Mtetra
.564 .612 .859 r
.54167 .15805 .54886 .17115 .56237 .16964 .55519 .15624 Mtetra
.491 .569 .862 r
.55519 .15624 .56237 .16964 .57602 .17015 .56885 .15668 Mtetra
.361 .494 .858 r
.56885 .15668 .57602 .17015 .58984 .17321 .58269 .16046 Mtetra
.128 .363 .823 r
.58269 .16046 .58984 .17321 .60388 .17929 .59679 .16869 Mtetra
0 .15 .687 r
.59679 .16869 .60388 .17929 .61819 .18838 .61123 .18174 Mtetra
.578 .075 0 r
.61123 .18174 .61819 .18838 .63277 .19929 .62602 .19828 Mtetra
.708 .17 0 r
.62602 .19828 .63277 .19929 .64753 .2093 .64108 .21463 Mtetra
.634 .112 0 r
.64108 .21463 .64753 .2093 .6623 .21464 .65619 .22541 Mtetra
.386 0 .011 r
.65619 .22541 .6623 .21464 .67684 .21197 .67101 .22556 Mtetra
0 0 0 r
.67101 .22556 .67684 .21197 .69098 .20002 .68529 .21298 Mtetra
.68529 .21298 .69098 .20002 .70466 .18044 .69897 .18977 Mtetra
.758 .846 .396 r
.69897 .18977 .70466 .18044 .71803 .15699 .71219 .1611 Mtetra
.918 .928 .553 r
.71219 .1611 .71803 .15699 .73131 .13371 .72528 .13261 Mtetra
.963 .941 .686 r
.72528 .13261 .73131 .13371 .74471 .11347 .7385 .10824 Mtetra
.664 .741 .908 r
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.663 .741 .908 r
.14622 .28737 .15454 .29544 .16618 .29109 .15788 .28298 Mtetra
.15788 .28298 .16618 .29109 .17786 .28675 .1696 .27857 Mtetra
.663 .74 .908 r
.1696 .27857 .17786 .28675 .1896 .28242 .18137 .27416 Mtetra
.662 .738 .907 r
.18137 .27416 .1896 .28242 .20138 .27816 .19319 .26974 Mtetra
.661 .735 .905 r
.19319 .26974 .20138 .27816 .2132 .27398 .20507 .26534 Mtetra
.659 .73 .902 r
.20507 .26534 .2132 .27398 .22507 .26989 .217 .26095 Mtetra
.658 .723 .897 r
.217 .26095 .22507 .26989 .237 .26583 .22898 .25656 Mtetra
.658 .716 .891 r
.22898 .25656 .237 .26583 .24898 .26169 .24101 .25213 Mtetra
.659 .71 .886 r
.24101 .25213 .24898 .26169 .26104 .25738 .25311 .24763 Mtetra
.66 .707 .882 r
.25311 .24763 .26104 .25738 .27318 .25283 .26528 .24305 Mtetra
.661 .708 .882 r
.26528 .24305 .27318 .25283 .28538 .24812 .2775 .23841 Mtetra
.661 .71 .884 r
.2775 .23841 .28538 .24812 .29763 .24341 .28977 .23377 Mtetra
.659 .712 .887 r
.28977 .23377 .29763 .24341 .30993 .23887 .3021 .22917 Mtetra
.656 .711 .888 r
.3021 .22917 .30993 .23887 .32227 .2346 .31448 .22465 Mtetra
.653 .705 .885 r
.31448 .22465 .32227 .2346 .33465 .23056 .32692 .22019 Mtetra
.651 .695 .878 r
.32692 .22019 .33465 .23056 .34709 .22661 .33941 .21575 Mtetra
.65 .685 .87 r
.33941 .21575 .34709 .22661 .3596 .22256 .35197 .21127 Mtetra
.65 .677 .863 r
.35197 .21127 .3596 .22256 .37218 .21833 .36459 .20672 Mtetra
.65 .672 .858 r
.36459 .20672 .37218 .21833 .38482 .21396 .37727 .20213 Mtetra
.648 .668 .855 r
.37727 .20213 .38482 .21396 .39754 .20959 .39001 .19754 Mtetra
.646 .663 .853 r
.39001 .19754 .39754 .20959 .4103 .20535 .40281 .19301 Mtetra
.643 .658 .849 r
.40281 .19301 .4103 .20535 .42313 .20123 .41568 .18851 Mtetra
.643 .651 .843 r
.41568 .18851 .42313 .20123 .43603 .19705 .42861 .18396 Mtetra
.645 .646 .837 r
.42861 .18396 .43603 .19705 .44901 .19255 .44161 .17926 Mtetra
.649 .645 .833 r
.44161 .17926 .44901 .19255 .46205 .18757 .45467 .17434 Mtetra
.653 .649 .833 r
.45467 .17434 .46205 .18757 .47517 .18213 .46781 .16922 Mtetra
.656 .657 .839 r
.46781 .16922 .47517 .18213 .48835 .17645 .48101 .16402 Mtetra
.656 .666 .848 r
.48101 .16402 .48835 .17645 .50158 .17087 .49426 .1589 Mtetra
.65 .674 .859 r
.49426 .1589 .50158 .17087 .51488 .16574 .50758 .15406 Mtetra
.638 .675 .869 r
.50758 .15406 .51488 .16574 .52823 .16136 .52097 .14972 Mtetra
.613 .666 .877 r
.52097 .14972 .52823 .16136 .54167 .15805 .53443 .14624 Mtetra
.566 .641 .884 r
.53443 .14624 .54167 .15805 .55519 .15624 .54798 .14423 Mtetra
.472 .589 .89 r
.54798 .14423 .55519 .15624 .56885 .15668 .56166 .1448 Mtetra
.277 .48 .877 r
.56166 .1448 .56885 .15668 .58269 .16046 .57553 .14952 Mtetra
0 .256 .767 r
.57553 .14952 .58269 .16046 .59679 .16869 .58969 .16 Mtetra
0 0 .476 r
.58969 .16 .59679 .16869 .61123 .18174 .60424 .17699 Mtetra
.75 .252 0 r
.60424 .17699 .61123 .18174 .62602 .19828 .61922 .19899 Mtetra
.793 .298 .002 r
.61922 .19899 .62602 .19828 .64108 .21463 .63456 .22142 Mtetra
.712 .223 .081 r
.63456 .22142 .64108 .21463 .65619 .22541 .64997 .23731 Mtetra
.464 .001 .068 r
.64997 .23731 .65619 .22541 .67101 .22556 .66505 .24 Mtetra
0 0 0 r
.66505 .24 .67101 .22556 .68529 .21298 .67948 .22655 Mtetra
.67948 .22655 .68529 .21298 .69897 .18977 .69315 .19953 Mtetra
.825 .854 .397 r
.69315 .19953 .69897 .18977 .71219 .1611 .70626 .16555 Mtetra
.944 .906 .522 r
.70626 .16555 .71219 .1611 .72528 .13261 .71917 .13183 Mtetra
.977 .92 .641 r
.71917 .13183 .72528 .13261 .7385 .10824 .73224 .10329 Mtetra
.664 .741 .908 r
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28298 .14952 .2748 Mtetra
.663 .741 .908 r
.14952 .2748 .15788 .28298 .1696 .27857 .16127 .27035 Mtetra
.16127 .27035 .1696 .27857 .18137 .27416 .17307 .26588 Mtetra
.663 .74 .908 r
.17307 .26588 .18137 .27416 .19319 .26974 .18493 .2614 Mtetra
.663 .739 .907 r
.18493 .2614 .19319 .26974 .20507 .26534 .19684 .2569 Mtetra
.662 .738 .906 r
.19684 .2569 .20507 .26534 .217 .26095 .20881 .25239 Mtetra
.662 .736 .904 r
.20881 .25239 .217 .26095 .22898 .25656 .22083 .24786 Mtetra
.662 .733 .903 r
.22083 .24786 .22898 .25656 .24101 .25213 .2329 .24331 Mtetra
.662 .731 .901 r
.2329 .24331 .24101 .25213 .25311 .24763 .24504 .23873 Mtetra
.663 .73 .9 r
.24504 .23873 .25311 .24763 .26528 .24305 .25723 .23411 Mtetra
.25723 .23411 .26528 .24305 .2775 .23841 .26948 .22946 Mtetra
.663 .731 .9 r
.26948 .22946 .2775 .23841 .28977 .23377 .28179 .22479 Mtetra
.662 .731 .901 r
.28179 .22479 .28977 .23377 .3021 .22917 .29416 .22013 Mtetra
.661 .73 .901 r
.29416 .22013 .3021 .22917 .31448 .22465 .30658 .21547 Mtetra
.66 .728 .899 r
.30658 .21547 .31448 .22465 .32692 .22019 .31906 .21082 Mtetra
.659 .723 .896 r
.31906 .21082 .32692 .22019 .33941 .21575 .33159 .20615 Mtetra
.659 .719 .893 r
.33159 .20615 .33941 .21575 .35197 .21127 .34419 .20147 Mtetra
.659 .715 .89 r
.34419 .20147 .35197 .21127 .36459 .20672 .35685 .19675 Mtetra
.658 .712 .888 r
.35685 .19675 .36459 .20672 .37727 .20213 .36957 .19201 Mtetra
.657 .709 .886 r
.36957 .19201 .37727 .20213 .39001 .19754 .38235 .18727 Mtetra
.656 .706 .884 r
.38235 .18727 .39001 .19754 .40281 .19301 .39519 .18254 Mtetra
.655 .702 .881 r
.39519 .18254 .40281 .19301 .41568 .18851 .40809 .1778 Mtetra
.655 .698 .878 r
.40809 .1778 .41568 .18851 .42861 .18396 .42106 .17303 Mtetra
.656 .694 .874 r
.42106 .17303 .42861 .18396 .44161 .17926 .43409 .16818 Mtetra
.657 .693 .872 r
.43409 .16818 .44161 .17926 .45467 .17434 .44719 .16324 Mtetra
.659 .694 .872 r
.44719 .16324 .45467 .17434 .46781 .16922 .46036 .15823 Mtetra
.659 .697 .874 r
.46036 .15823 .46781 .16922 .48101 .16402 .47358 .15318 Mtetra
.658 .701 .879 r
.47358 .15318 .48101 .16402 .49426 .1589 .48687 .1482 Mtetra
.653 .703 .884 r
.48687 .1482 .49426 .1589 .50758 .15406 .50023 .1434 Mtetra
.642 .701 .889 r
.50023 .1434 .50758 .15406 .52097 .14972 .51365 .13896 Mtetra
.618 .69 .894 r
.51365 .13896 .52097 .14972 .53443 .14624 .52714 .13527 Mtetra
.568 .663 .902 r
.52714 .13527 .53443 .14624 .54798 .14423 .54072 .13307 Mtetra
.458 .603 .908 r
.54072 .13307 .54798 .14423 .56166 .1448 .55443 .13368 Mtetra
.217 .464 .88 r
.55443 .13368 .56166 .1448 .57553 .14952 .56832 .13896 Mtetra
0 .182 .711 r
.56832 .13896 .57553 .14952 .58969 .16 .58251 .15091 Mtetra
.588 .129 0 r
.58251 .15091 .58969 .16 .60424 .17699 .59712 .17047 Mtetra
.767 .294 0 r
.59712 .17047 .60424 .17699 .61922 .19899 .61221 .19605 Mtetra
.811 .329 0 r
.61221 .19605 .61922 .19899 .63456 .22142 .6277 .22251 Mtetra
.754 .24 0 r
.6277 .22251 .63456 .22142 .64997 .23731 .6433 .24182 Mtetra
.434 0 0 r
.6433 .24182 .64997 .23731 .66505 .24 .65857 .2462 Mtetra
.495 .82 .513 r
.65857 .2462 .66505 .24 .67948 .22655 .67312 .23215 Mtetra
.901 .923 .536 r
.67312 .23215 .67948 .22655 .69315 .19953 .68683 .20256 Mtetra
.977 .895 .541 r
.68683 .20256 .69315 .19953 .70626 .16555 .69991 .16502 Mtetra
.993 .879 .579 r
.69991 .16502 .70626 .16555 .71917 .13183 .71277 .12781 Mtetra
.983 .874 .646 r
.71277 .12781 .71917 .13183 .73224 .10329 .72578 .09651 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.663 .741 .908 r
.15286 .26207 .16127 .27035 .17307 .26588 .1647 .25756 Mtetra
.1647 .25756 .17307 .26588 .18493 .2614 .17659 .25302 Mtetra
.17659 .25302 .18493 .2614 .19684 .2569 .18853 .24847 Mtetra
.663 .74 .907 r
.18853 .24847 .19684 .2569 .20881 .25239 .20053 .2439 Mtetra
.20053 .2439 .20881 .25239 .22083 .24786 .21259 .23931 Mtetra
.663 .739 .906 r
.21259 .23931 .22083 .24786 .2329 .24331 .2247 .2347 Mtetra
.2247 .2347 .2329 .24331 .24504 .23873 .23687 .23006 Mtetra
.663 .738 .906 r
.23687 .23006 .24504 .23873 .25723 .23411 .2491 .2254 Mtetra
.2491 .2254 .25723 .23411 .26948 .22946 .26138 .22071 Mtetra
.26138 .22071 .26948 .22946 .28179 .22479 .27372 .21601 Mtetra
.27372 .21601 .28179 .22479 .29416 .22013 .28612 .21129 Mtetra
.28612 .21129 .29416 .22013 .30658 .21547 .29858 .20655 Mtetra
.662 .737 .905 r
.29858 .20655 .30658 .21547 .31906 .21082 .3111 .2018 Mtetra
.662 .735 .904 r
.3111 .2018 .31906 .21082 .33159 .20615 .32367 .19703 Mtetra
.662 .734 .903 r
.32367 .19703 .33159 .20615 .34419 .20147 .33631 .19224 Mtetra
.662 .732 .902 r
.33631 .19224 .34419 .20147 .35685 .19675 .34901 .18743 Mtetra
.662 .731 .901 r
.34901 .18743 .35685 .19675 .36957 .19201 .36177 .1826 Mtetra
.661 .729 .9 r
.36177 .1826 .36957 .19201 .38235 .18727 .37458 .17775 Mtetra
.661 .728 .899 r
.37458 .17775 .38235 .18727 .39519 .18254 .38747 .17289 Mtetra
.66 .726 .897 r
.38747 .17289 .39519 .18254 .40809 .1778 .40041 .16802 Mtetra
.66 .723 .896 r
.40041 .16802 .40809 .1778 .42106 .17303 .41341 .16312 Mtetra
.66 .721 .894 r
.41341 .16312 .42106 .17303 .43409 .16818 .42649 .15818 Mtetra
.661 .72 .893 r
.42649 .15818 .43409 .16818 .44719 .16324 .43962 .15319 Mtetra
.43962 .15319 .44719 .16324 .46036 .15823 .45282 .14817 Mtetra
.661 .721 .894 r
.45282 .14817 .46036 .15823 .47358 .15318 .46608 .14314 Mtetra
.659 .722 .895 r
.46608 .14314 .47358 .15318 .48687 .1482 .47941 .13815 Mtetra
.655 .721 .897 r
.47941 .13815 .48687 .1482 .50023 .1434 .4928 .13327 Mtetra
.646 .717 .9 r
.4928 .13327 .50023 .1434 .51365 .13896 .50626 .12869 Mtetra
.624 .706 .904 r
.50626 .12869 .51365 .13896 .52714 .13527 .51979 .12476 Mtetra
.575 .679 .911 r
.51979 .12476 .52714 .13527 .54072 .13307 .53341 .12227 Mtetra
.463 .617 .916 r
.53341 .12227 .54072 .13307 .55443 .13368 .54713 .12258 Mtetra
.224 .471 .883 r
.54713 .12258 .55443 .13368 .56832 .13896 .56104 .12764 Mtetra
0 .196 .724 r
.56104 .12764 .56832 .13896 .58251 .15091 .57522 .13951 Mtetra
0 0 .476 r
.57522 .13951 .58251 .15091 .59712 .17047 .58981 .15921 Mtetra
.658 .234 0 r
.58981 .15921 .59712 .17047 .61221 .19605 .60489 .18518 Mtetra
.677 .247 0 r
.60489 .18518 .61221 .19605 .6277 .22251 .62037 .21219 Mtetra
0 0 .473 r
.62037 .21219 .6277 .22251 .6433 .24182 .63598 .23207 Mtetra
.202 .507 .91 r
.63598 .23207 .6433 .24182 .65857 .2462 .6513 .23685 Mtetra
.833 .817 .834 r
.6513 .23685 .65857 .2462 .67312 .23215 .66593 .22291 Mtetra
.944 .81 .682 r
.66593 .22291 .67312 .23215 .68683 .20256 .67975 .19315 Mtetra
.963 .795 .627 r
.67975 .19315 .68683 .20256 .69991 .16502 .69294 .1553 Mtetra
.962 .793 .625 r
.69294 .1553 .69991 .16502 .71277 .12781 .7059 .11775 Mtetra
.948 .798 .661 r
.7059 .11775 .71277 .12781 .72578 .09651 .71901 .0862 Mtetra
.664 .741 .908 r
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25756 .15625 .24917 Mtetra
.15625 .24917 .1647 .25756 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24847 .18015 .24 Mtetra
.663 .741 .908 r
.18015 .24 .18853 .24847 .20053 .2439 .19218 .23538 Mtetra
.19218 .23538 .20053 .2439 .21259 .23931 .20427 .23075 Mtetra
.20427 .23075 .21259 .23931 .2247 .2347 .21642 .22609 Mtetra
.663 .741 .907 r
.21642 .22609 .2247 .2347 .23687 .23006 .22862 .22141 Mtetra
.22862 .22141 .23687 .23006 .2491 .2254 .24088 .21671 Mtetra
.24088 .21671 .2491 .2254 .26138 .22071 .2532 .21198 Mtetra
.2532 .21198 .26138 .22071 .27372 .21601 .26557 .20723 Mtetra
.26557 .20723 .27372 .21601 .28612 .21129 .27801 .20246 Mtetra
.663 .74 .907 r
.27801 .20246 .28612 .21129 .29858 .20655 .2905 .19767 Mtetra
.2905 .19767 .29858 .20655 .3111 .2018 .30306 .19286 Mtetra
.30306 .19286 .3111 .2018 .32367 .19703 .31567 .18803 Mtetra
.663 .739 .906 r
.31567 .18803 .32367 .19703 .33631 .19224 .32835 .18318 Mtetra
.663 .738 .906 r
.32835 .18318 .33631 .19224 .34901 .18743 .34108 .1783 Mtetra
.34108 .1783 .34901 .18743 .36177 .1826 .35388 .1734 Mtetra
.663 .737 .905 r
.35388 .1734 .36177 .1826 .37458 .17775 .36673 .16849 Mtetra
.36673 .16849 .37458 .17775 .38747 .17289 .37965 .16355 Mtetra
.662 .736 .904 r
.37965 .16355 .38747 .17289 .40041 .16802 .39264 .15859 Mtetra
.662 .735 .903 r
.39264 .15859 .40041 .16802 .41341 .16312 .40568 .15361 Mtetra
.662 .734 .903 r
.40568 .15361 .41341 .16312 .42649 .15818 .41879 .1486 Mtetra
.662 .733 .902 r
.41879 .1486 .42649 .15818 .43962 .15319 .43197 .14356 Mtetra
.43197 .14356 .43962 .15319 .45282 .14817 .44521 .1385 Mtetra
.44521 .1385 .45282 .14817 .46608 .14314 .45851 .13343 Mtetra
.661 .733 .903 r
.45851 .13343 .46608 .14314 .47941 .13815 .47188 .12838 Mtetra
.658 .731 .904 r
.47188 .12838 .47941 .13815 .4928 .13327 .48531 .1234 Mtetra
.65 .727 .905 r
.48531 .1234 .4928 .13327 .50626 .12869 .49881 .11865 Mtetra
.632 .717 .908 r
.49881 .11865 .50626 .12869 .51979 .12476 .51238 .11445 Mtetra
.588 .693 .914 r
.51238 .11445 .51979 .12476 .53341 .12227 .52603 .11153 Mtetra
.491 .636 .918 r
.52603 .11153 .53341 .12227 .54713 .12258 .53978 .11112 Mtetra
.294 .507 .893 r
.53978 .11112 .54713 .12258 .56104 .12764 .55368 .11502 Mtetra
0 .282 .782 r
.55368 .11502 .56104 .12764 .57522 .13951 .56783 .1251 Mtetra
0 .053 .619 r
.56783 .1251 .57522 .13951 .58981 .15921 .58234 .1423 Mtetra
0 0 .528 r
.58234 .1423 .58981 .15921 .60489 .18518 .59728 .16518 Mtetra
0 0 .56 r
.59728 .16518 .60489 .18518 .62037 .21219 .6126 .18901 Mtetra
.053 .175 .674 r
.6126 .18901 .62037 .21219 .63598 .23207 .62806 .20642 Mtetra
.446 .414 .73 r
.62806 .20642 .63598 .23207 .6513 .23685 .64329 .21026 Mtetra
.693 .559 .698 r
.64329 .21026 .6513 .23685 .66593 .22291 .65796 .19726 Mtetra
.808 .627 .656 r
.65796 .19726 .66593 .22291 .67975 .19315 .67193 .17001 Mtetra
.86 .664 .635 r
.67193 .17001 .67975 .19315 .69294 .1553 .68536 .1354 Mtetra
.883 .691 .639 r
.68536 .1354 .69294 .1553 .7059 .11775 .69858 .10099 Mtetra
.885 .717 .668 r
.69858 .10099 .7059 .11775 .71901 .0862 .71193 .07195 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23075 .19588 .22212 Mtetra
.19588 .22212 .20427 .23075 .21642 .22609 .20806 .21742 Mtetra
.20806 .21742 .21642 .22609 .22862 .22141 .2203 .2127 Mtetra
.2203 .2127 .22862 .22141 .24088 .21671 .23259 .20796 Mtetra
.23259 .20796 .24088 .21671 .2532 .21198 .24494 .20319 Mtetra
.24494 .20319 .2532 .21198 .26557 .20723 .25735 .1984 Mtetra
.25735 .1984 .26557 .20723 .27801 .20246 .26982 .19359 Mtetra
.663 .741 .908 r
.26982 .19359 .27801 .20246 .2905 .19767 .28235 .18875 Mtetra
.28235 .18875 .2905 .19767 .30306 .19286 .29494 .1839 Mtetra
.29494 .1839 .30306 .19286 .31567 .18803 .30759 .17902 Mtetra
.30759 .17902 .31567 .18803 .32835 .18318 .32031 .17411 Mtetra
.663 .741 .907 r
.32031 .17411 .32835 .18318 .34108 .1783 .33308 .16919 Mtetra
.663 .74 .907 r
.33308 .16919 .34108 .1783 .35388 .1734 .34591 .16424 Mtetra
.34591 .16424 .35388 .1734 .36673 .16849 .35881 .15926 Mtetra
.35881 .15926 .36673 .16849 .37965 .16355 .37177 .15427 Mtetra
.663 .739 .907 r
.37177 .15427 .37965 .16355 .39264 .15859 .38479 .14925 Mtetra
.663 .739 .906 r
.38479 .14925 .39264 .15859 .40568 .15361 .39788 .14421 Mtetra
.39788 .14421 .40568 .15361 .41879 .1486 .41103 .13914 Mtetra
.663 .738 .906 r
.41103 .13914 .41879 .1486 .43197 .14356 .42424 .13405 Mtetra
.42424 .13405 .43197 .14356 .44521 .1385 .43752 .12894 Mtetra
.43752 .12894 .44521 .1385 .45851 .13343 .45087 .12381 Mtetra
.662 .737 .906 r
.45087 .12381 .45851 .13343 .47188 .12838 .46428 .11869 Mtetra
.66 .736 .906 r
.46428 .11869 .47188 .12838 .48531 .1234 .47775 .11361 Mtetra
.654 .733 .907 r
.47775 .11361 .48531 .1234 .49881 .11865 .4913 .10869 Mtetra
.639 .724 .909 r
.4913 .10869 .49881 .11865 .51238 .11445 .5049 .10421 Mtetra
.605 .704 .914 r
.5049 .10421 .51238 .11445 .52603 .11153 .51859 .10074 Mtetra
.532 .657 .916 r
.51859 .10074 .52603 .11153 .53978 .11112 .53236 .09929 Mtetra
.391 .558 .899 r
.53236 .09929 .53978 .11112 .55368 .11502 .54627 .10133 Mtetra
.189 .394 .833 r
.54627 .10133 .55368 .11502 .56783 .1251 .56037 .10836 Mtetra
.019 .225 .732 r
.56037 .10836 .56783 .1251 .58234 .1423 .57477 .12111 Mtetra
0 .144 .665 r
.57477 .12111 .58234 .1423 .59728 .16518 .58951 .1384 Mtetra
.1 .174 .654 r
.58951 .1384 .59728 .16518 .6126 .18901 .60457 .15638 Mtetra
.3 .275 .663 r
.60457 .15638 .6126 .18901 .62806 .20642 .61977 .16917 Mtetra
.493 .385 .66 r
.61977 .16917 .62806 .20642 .64329 .21026 .63483 .17112 Mtetra
.632 .47 .645 r
.63483 .17112 .64329 .21026 .65796 .19726 .64949 .15966 Mtetra
.721 .531 .633 r
.64949 .15966 .65796 .19726 .67193 .17001 .66363 .1368 Mtetra
.776 .577 .63 r
.66363 .1368 .67193 .17001 .68536 .1354 .67737 .10799 Mtetra
.808 .616 .643 r
.67737 .10799 .68536 .1354 .69858 .10099 .69094 .07924 Mtetra
.821 .653 .675 r
.69094 .07924 .69858 .10099 .71193 .07195 .70462 .05473 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .1839 .28676 .17486 Mtetra
.28676 .17486 .29494 .1839 .30759 .17902 .29944 .16993 Mtetra
.29944 .16993 .30759 .17902 .32031 .17411 .31219 .16499 Mtetra
.31219 .16499 .32031 .17411 .33308 .16919 .325 .16001 Mtetra
.663 .741 .908 r
.325 .16001 .33308 .16919 .34591 .16424 .33788 .15502 Mtetra
.33788 .15502 .34591 .16424 .35881 .15926 .35081 .15 Mtetra
.35081 .15 .35881 .15926 .37177 .15427 .36381 .14495 Mtetra
.36381 .14495 .37177 .15427 .38479 .14925 .37687 .13988 Mtetra
.663 .741 .907 r
.37687 .13988 .38479 .14925 .39788 .14421 .39 .13479 Mtetra
.663 .74 .907 r
.39 .13479 .39788 .14421 .41103 .13914 .40319 .12967 Mtetra
.40319 .12967 .41103 .13914 .42424 .13405 .41644 .12453 Mtetra
.41644 .12453 .42424 .13405 .43752 .12894 .42976 .11936 Mtetra
.42976 .11936 .43752 .12894 .45087 .12381 .44315 .11418 Mtetra
.662 .74 .907 r
.44315 .11418 .45087 .12381 .46428 .11869 .4566 .10899 Mtetra
.661 .739 .907 r
.4566 .10899 .46428 .11869 .47775 .11361 .47012 .10382 Mtetra
.657 .736 .908 r
.47012 .10382 .47775 .11361 .4913 .10869 .48371 .09875 Mtetra
.647 .73 .909 r
.48371 .09875 .4913 .10869 .5049 .10421 .49736 .09399 Mtetra
.623 .714 .911 r
.49736 .09399 .5049 .10421 .51859 .10074 .51108 .08994 Mtetra
.573 .679 .912 r
.51108 .08994 .51859 .10074 .53236 .09929 .52489 .08735 Mtetra
.482 .608 .9 r
.52489 .08735 .53236 .09929 .54627 .10133 .5388 .08727 Mtetra
.357 .493 .858 r
.5388 .08727 .54627 .10133 .56037 .10836 .55287 .09077 Mtetra
.252 .368 .788 r
.55287 .09077 .56037 .10836 .57477 .12111 .56715 .09837 Mtetra
.231 .294 .722 r
.56715 .09837 .57477 .12111 .58951 .1384 .5817 .10916 Mtetra
.298 .29 .682 r
.5817 .10916 .58951 .1384 .60457 .15638 .59649 .12039 Mtetra
.409 .331 .658 r
.59649 .12039 .60457 .15638 .61977 .16917 .61142 .12786 Mtetra
.518 .387 .642 r
.61142 .12786 .61977 .16917 .63483 .17112 .62629 .12761 Mtetra
.607 .441 .632 r
.62629 .12761 .63483 .17112 .64949 .15966 .64091 .11784 Mtetra
.673 .488 .628 r
.64091 .11784 .64949 .15966 .66363 .1368 .65521 .09997 Mtetra
.72 .531 .634 r
.65521 .09997 .66363 .1368 .67737 .10799 .66925 .07779 Mtetra
.752 .572 .653 r
.66925 .07779 .67737 .10799 .69094 .07924 .68319 .05558 Mtetra
.769 .615 .688 r
.68319 .05558 .69094 .07924 .70462 .05473 .69721 .03633 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16499 .30401 .15578 Mtetra
.30401 .15578 .31219 .16499 .325 .16001 .31685 .15077 Mtetra
.31685 .15077 .325 .16001 .33788 .15502 .32977 .14572 Mtetra
.32977 .14572 .33788 .15502 .35081 .15 .34274 .14066 Mtetra
.34274 .14066 .35081 .15 .36381 .14495 .35578 .13556 Mtetra
.35578 .13556 .36381 .14495 .37687 .13988 .36888 .13045 Mtetra
.36888 .13045 .37687 .13988 .39 .13479 .38204 .12531 Mtetra
.663 .741 .908 r
.38204 .12531 .39 .13479 .40319 .12967 .39527 .12014 Mtetra
.39527 .12014 .40319 .12967 .41644 .12453 .40857 .11495 Mtetra
.40857 .11495 .41644 .12453 .42976 .11936 .42193 .10973 Mtetra
.42193 .10973 .42976 .11936 .44315 .11418 .43536 .10449 Mtetra
.43536 .10449 .44315 .11418 .4566 .10899 .44886 .09924 Mtetra
.662 .74 .908 r
.44886 .09924 .4566 .10899 .47012 .10382 .46242 .09399 Mtetra
.66 .738 .908 r
.46242 .09399 .47012 .10382 .48371 .09875 .47605 .0888 Mtetra
.653 .734 .909 r
.47605 .0888 .48371 .09875 .49736 .09399 .48975 .08378 Mtetra
.638 .723 .909 r
.48975 .08378 .49736 .09399 .51108 .08994 .50351 .07922 Mtetra
.607 .699 .908 r
.50351 .07922 .51108 .08994 .52489 .08735 .51735 .07559 Mtetra
.553 .65 .899 r
.51735 .07559 .52489 .08735 .5388 .08727 .53128 .07357 Mtetra
.479 .572 .871 r
.53128 .07357 .5388 .08727 .55287 .09077 .54534 .07384 Mtetra
.412 .479 .819 r
.54534 .07384 .55287 .09077 .56715 .09837 .55955 .07672 Mtetra
.389 .407 .758 r
.55955 .07672 .56715 .09837 .5817 .10916 .57395 .0816 Mtetra
.416 .377 .707 r
.57395 .0816 .5817 .10916 .59649 .12039 .58853 .08671 Mtetra
.475 .383 .672 r
.58853 .08671 .59649 .12039 .61142 .12786 .60323 .08939 Mtetra
.54 .409 .651 r
.60323 .08939 .61142 .12786 .62629 .12761 .61793 .08716 Mtetra
.599 .442 .641 r
.61793 .08716 .62629 .12761 .64091 .11784 .63252 .07888 Mtetra
.648 .478 .64 r
.63252 .07888 .64091 .11784 .65521 .09997 .64694 .06544 Mtetra
.686 .516 .651 r
.64694 .06544 .65521 .09997 .66925 .07779 .66123 .04922 Mtetra
.714 .557 .675 r
.66123 .04922 .66925 .07779 .68319 .05558 .67548 .03292 Mtetra
.731 .603 .713 r
.67548 .03292 .68319 .05558 .69721 .03633 .68981 .01849 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.8096 .25758 m
.8354 .24906 L
.8612 .24842 L
.887 .25542 L
.90829 .2678 L
.9128 .27224 L
.92936 .2936 L
.9386 .31848 L
.9388 .3194 L
.94057 .3452 L
.9386 .35806 L
.93487 .371 L
.91953 .3968 L
.9128 .40397 L
.887 .42096 L
.88268 .4226 L
.8612 .42799 L
.8354 .42733 L
.81842 .4226 L
.8096 .41895 L
.7838 .39913 L
.78178 .3968 L
.76614 .371 L
.76045 .3452 L
.76211 .3194 L
.7718 .2936 L
.7838 .27653 L
.79286 .2678 L
.8096 .25758 L
s
.8612 .81878 m
.887 .81153 L
.9128 .81394 L
.9386 .83 L
.9433 .8354 L
.9565 .8612 L
.95728 .887 L
.94659 .9128 L
.9386 .92302 L
.9128 .93769 L
.90837 .9386 L
.887 .94027 L
.87757 .9386 L
.8612 .93352 L
.83834 .9128 L
.8354 .90489 L
.8292 .887 L
.83005 .8612 L
.8354 .84731 L
.84068 .8354 L
.8612 .81878 L
s
.5258 .62894 m
.5516 .62827 L
.55526 .629 L
.5774 .63691 L
.59711 .6548 L
.6032 .6675 L
.60795 .6806 L
.60918 .7064 L
.6032 .7257 L
.60062 .7322 L
.5774 .75593 L
.57234 .758 L
.5516 .76522 L
.5258 .76455 L
.50846 .758 L
.5 .75414 L
.47992 .7322 L
.4742 .71679 L
.47179 .7064 L
.47302 .6806 L
.4742 .67641 L
.48385 .6548 L
.5 .63914 L
.52554 .629 L
.5258 .62894 L
s
.5516 .24949 m
.5774 .24207 L
.6032 .24371 L
.629 .25839 L
.63647 .2678 L
.64741 .2936 L
.6464 .3194 L
.63208 .3452 L
.629 .34855 L
.6032 .36473 L
.5774 .36677 L
.5516 .35797 L
.53573 .3452 L
.5258 .32379 L
.52443 .3194 L
.52331 .2936 L
.5258 .2842 L
.53196 .2678 L
.5516 .24949 L
s
.2678 .25966 m
.2936 .25528 L
.3194 .2659 L
.32233 .2678 L
.34148 .2936 L
.34242 .3194 L
.32958 .3452 L
.3194 .35341 L
.2936 .36351 L
.2678 .35949 L
.25015 .3452 L
.242 .33377 L
.23638 .3194 L
.23782 .2936 L
.242 .28445 L
.2558 .2678 L
.2678 .25966 L
s
.8612 .04396 m
.887 .03648 L
.9128 .03856 L
.9386 .05758 L
.94112 .0614 L
.95185 .0872 L
.94926 .113 L
.9386 .13092 L
.93095 .1388 L
.9128 .15031 L
.887 .1534 L
.8612 .14346 L
.85416 .1388 L
.83717 .113 L
.83563 .0872 L
.84316 .0614 L
.8612 .04396 L
s
.8096 .56625 m
.8354 .56101 L
.8612 .56299 L
.887 .57286 L
.89488 .5774 L
.9128 .59351 L
.91987 .6032 L
.93187 .629 L
.93551 .6548 L
.93217 .6806 L
.9206 .7064 L
.9128 .71725 L
.89655 .7322 L
.887 .73785 L
.8612 .7477 L
.8354 .74967 L
.8096 .74445 L
.78536 .7322 L
.7838 .73043 L
.76156 .7064 L
.758 .69989 L
.75011 .6806 L
.74663 .6548 L
.75042 .629 L
.758 .6108 L
.76223 .6032 L
.7838 .58017 L
.78639 .5774 L
.8096 .56625 L
s
.2936 .63678 m
.3194 .63049 L
.3452 .63349 L
.371 .65064 L
.37449 .6548 L
.3878 .6806 L
.38874 .7064 L
.37834 .7322 L
.371 .74214 L
.3452 .75756 L
.34336 .758 L
.3194 .76108 L
.30381 .758 L
.2936 .75485 L
.26862 .7322 L
.2678 .7296 L
.25878 .7064 L
.25979 .6806 L
.2678 .66219 L
.27076 .6548 L
.2936 .63678 L
s
.4226 .24998 m
.4484 .24343 L
.4742 .24671 L
.49743 .2678 L
.5 .27178 L
.50794 .2936 L
.50459 .3194 L
.5 .32821 L
.48454 .3452 L
.4742 .35173 L
.4484 .35657 L
.4226 .34765 L
.41808 .3452 L
.3982 .3194 L
.3968 .30819 L
.39655 .2936 L
.3968 .29181 L
.40305 .2678 L
.4226 .24998 L
s
0 g
.03 w
.85055 .33827 Mdot
.89297 .8761 Mdot
.5404 .6966 Mdot
.58493 .30399 Mdot
.28869 .30911 Mdot
.89332 .09465 Mdot
.8411 .65534 Mdot
.32358 .6959 Mdot
.45193 .3 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.53922 .68505 m
.55211 .69608 L
.53922 .70795 L
.5283 .69608 L
.53922 .68505 L
s
.28431 .2883 m
.30392 .29174 L
.3127 .30392 L
.30711 .32353 L
.30392 .32623 L
.28431 .32979 L
.27389 .32353 L
.26875 .30392 L
.28431 .2883 L
s
.51961 .66565 m
.53922 .65973 L
.55882 .66406 L
.57325 .67647 L
.57765 .69608 L
.57349 .71569 L
.55882 .72915 L
.53922 .73336 L
.51961 .72807 L
.50775 .71569 L
.50233 .69608 L
.50856 .67647 L
.51961 .66565 L
s
.32353 .67366 m
.33418 .67647 L
.34314 .68317 L
.35047 .69608 L
.34314 .70865 L
.33329 .71569 L
.32353 .71792 L
.3172 .71569 L
.30392 .70078 L
.303 .69608 L
.30392 .69103 L
.31633 .67647 L
.32353 .67366 L
s
.55882 .29087 m
.57843 .28931 L
.59281 .30392 L
.57843 .31834 L
.55882 .31593 L
.54056 .30392 L
.55882 .29087 L
s
.46078 .29219 m
.48039 .29184 L
.49079 .30392 L
.48039 .30981 L
.46078 .30888 L
.45561 .30392 L
.46078 .29219 L
s
.28431 .27564 m
.30392 .27781 L
.31351 .28431 L
.32353 .29675 L
.3259 .30392 L
.32353 .32057 L
.32204 .32353 L
.30392 .339 L
.28431 .34126 L
.26471 .3303 L
.25928 .32353 L
.256 .30392 L
.26471 .28787 L
.26832 .28431 L
.28431 .27564 L
s
.89216 .83301 m
.89406 .83333 L
.91176 .83883 L
.92133 .85294 L
.92624 .87255 L
.91791 .89216 L
.91176 .89795 L
.89216 .90579 L
.87255 .89765 L
.86614 .89216 L
.8564 .87255 L
.85788 .85294 L
.87255 .8386 L
.88425 .83333 L
.89216 .83301 L
s
.30392 .66034 m
.32353 .65703 L
.34314 .65891 L
.36226 .67647 L
.36275 .67921 L
.3673 .69608 L
.36275 .71263 L
.36219 .71569 L
.34314 .73289 L
.32353 .73495 L
.30392 .73134 L
.28892 .71569 L
.28508 .69608 L
.28874 .67647 L
.30392 .66034 L
s
.51961 .65217 m
.53922 .6478 L
.55882 .65114 L
.57356 .65686 L
.57843 .66151 L
.58662 .67647 L
.59095 .69608 L
.58661 .71569 L
.57843 .731 L
.57395 .73529 L
.55882 .74166 L
.53922 .74519 L
.51961 .74094 L
.50721 .73529 L
.5 .7302 L
.49243 .71569 L
.48783 .69608 L
.49292 .67647 L
.5 .66343 L
.50878 .65686 L
.51961 .65217 L
s
.83333 .63643 m
.85066 .63725 L
.85294 .63873 L
.86129 .65686 L
.85294 .67292 L
.83333 .67471 L
.82134 .65686 L
.83171 .63725 L
.83333 .63643 L
s
.83333 .30358 m
.85294 .29925 L
.86838 .30392 L
.87255 .30645 L
.88844 .32353 L
.89053 .34314 L
.88434 .36275 L
.87255 .37407 L
.85294 .38031 L
.83333 .37705 L
.81888 .36275 L
.81373 .35284 L
.81133 .34314 L
.81373 .32553 L
.81451 .32353 L
.83272 .30392 L
.83333 .30358 L
s
.44118 .2788 m
.46078 .27139 L
.48039 .27122 L
.5 .27411 L
.51961 .27152 L
.53922 .27004 L
.55882 .26764 L
.57843 .26739 L
.59804 .27278 L
.61045 .28431 L
.61677 .30392 L
.61144 .32353 L
.59804 .33587 L
.57843 .34025 L
.55882 .33891 L
.53922 .33421 L
.51961 .32989 L
.5 .3301 L
.48039 .33205 L
.46078 .33107 L
.44349 .32353 L
.44118 .32208 L
.42758 .30392 L
.4339 .28431 L
.44118 .2788 L
s
.26471 .27422 m
.28431 .26703 L
.30392 .26826 L
.32353 .2789 L
.32805 .28431 L
.33749 .30392 L
.33405 .32353 L
.32353 .33735 L
.31598 .34314 L
.30392 .34905 L
.28431 .35081 L
.2653 .34314 L
.26471 .34272 L
.24923 .32353 L
.2473 .30392 L
.25457 .28431 L
.26471 .27422 L
s
.89216 .81231 m
.89789 .81373 L
.91176 .82073 L
.92667 .83333 L
.93137 .83931 L
.93568 .85294 L
.93865 .87255 L
.93392 .89216 L
.93137 .89843 L
.91923 .91176 L
.91176 .91472 L
.89216 .91918 L
.87255 .91445 L
.86588 .91176 L
.85294 .89803 L
.85005 .89216 L
.84405 .87255 L
.84488 .85294 L
.85244 .83333 L
.85294 .83252 L
.87255 .81422 L
.8738 .81373 L
.89216 .81231 L
s
.30392 .64834 m
.32353 .64404 L
.34314 .64685 L
.36245 .65686 L
.36275 .65716 L
.37862 .67647 L
.38235 .68651 L
.38337 .69608 L
.38235 .70542 L
.37849 .71569 L
.36275 .73484 L
.36232 .73529 L
.34314 .74496 L
.32353 .74775 L
.30392 .74345 L
.28873 .73529 L
.28431 .73139 L
.27632 .71569 L
.27235 .69608 L
.27617 .67647 L
.28431 .66029 L
.28837 .65686 L
.30392 .64834 L
s
.53922 .63588 m
.55401 .63725 L
.55882 .63836 L
.57843 .64754 L
.58893 .65686 L
.59804 .66797 L
.60051 .67647 L
.60386 .69608 L
.60023 .71569 L
.59804 .72309 L
.58877 .73529 L
.57843 .74479 L
.55882 .75435 L
.55675 .7549 L
.53922 .75708 L
.52356 .7549 L
.51961 .75383 L
.5 .74404 L
.49008 .73529 L
.48039 .7257 L
.47708 .71569 L
.47311 .69608 L
.47745 .67647 L
.48039 .66803 L
.491 .65686 L
.5 .64909 L
.51961 .6392 L
.5274 .63725 L
.53922 .63588 L
s
.81373 .60716 m
.83333 .59993 L
.85294 .60063 L
.87255 .6099 L
.88117 .61765 L
.89178 .63725 L
.89216 .63864 L
.89489 .65686 L
.89216 .67416 L
.89155 .67647 L
.88159 .69608 L
.87255 .70449 L
.85294 .71378 L
.83333 .71296 L
.81373 .70392 L
.80379 .69608 L
.79412 .68346 L
.79164 .67647 L
.78735 .65686 L
.79036 .63725 L
.79412 .62888 L
.80073 .61765 L
.81373 .60716 L
s
.83333 .27903 m
.85294 .27636 L
.87255 .28044 L
.88288 .28431 L
.89216 .29251 L
.90164 .30392 L
.91011 .32353 L
.91176 .33459 L
.91182 .34314 L
.91176 .34391 L
.90767 .36275 L
.89565 .38235 L
.89216 .38599 L
.87255 .3991 L
.86344 .40196 L
.85294 .4035 L
.83703 .40196 L
.83333 .40099 L
.81373 .39072 L
.80469 .38235 L
.79412 .36589 L
.79306 .36275 L
.7885 .34314 L
.79034 .32353 L
.79412 .31321 L
.79907 .30392 L
.81373 .28869 L
.82115 .28431 L
.83333 .27903 L
s
.44118 .26374 m
.46078 .25859 L
.48039 .25834 L
.5 .26018 L
.51961 .26116 L
.53922 .25963 L
.55882 .25711 L
.57843 .25654 L
.59804 .26056 L
.60862 .26471 L
.61765 .26992 L
.6269 .28431 L
.63232 .30392 L
.62792 .32353 L
.61765 .33973 L
.61091 .34314 L
.59804 .34788 L
.57843 .3512 L
.55882 .34976 L
.53922 .34599 L
.52173 .34314 L
.51961 .343 L
.5 .34264 L
.48039 .34308 L
.46078 .34244 L
.44118 .33847 L
.42157 .3247 L
.42082 .32353 L
.41125 .30392 L
.41617 .28431 L
.42157 .27706 L
.43873 .26471 L
.44118 .26374 L
s
.28431 .25909 m
.30392 .26029 L
.31638 .26471 L
.32353 .26774 L
.34147 .28431 L
.34314 .28649 L
.35063 .30392 L
.34377 .32353 L
.34314 .32909 L
.33084 .34314 L
.32353 .34896 L
.30392 .35775 L
.28431 .35913 L
.26471 .35306 L
.25136 .34314 L
.2451 .33284 L
.24112 .32353 L
.23924 .30392 L
.2451 .2853 L
.24553 .28431 L
.26471 .2653 L
.26613 .26471 L
.28431 .25909 L
s
.89216 .06782 m
.89898 .06863 L
.91176 .07512 L
.92369 .08824 L
.92301 .10784 L
.91176 .12034 L
.8998 .12745 L
.89216 .12887 L
.88413 .12745 L
.87255 .12019 L
.86279 .10784 L
.8632 .08824 L
.87255 .07683 L
.88712 .06863 L
.89216 .06782 L
s
.87255 .78307 m
.89216 .78723 L
.90413 .79412 L
.91176 .79979 L
.92813 .81373 L
.93137 .81846 L
.94152 .83333 L
.94913 .85294 L
.95098 .86436 L
.95128 .87255 L
.95098 .87704 L
.94787 .89216 L
.93673 .91176 L
.93137 .91726 L
.91176 .92887 L
.90114 .93137 L
.89216 .93205 L
.88399 .93137 L
.87255 .92859 L
.85294 .91678 L
.84792 .91176 L
.83594 .89216 L
.83333 .88389 L
.83113 .87255 L
.83109 .85294 L
.83333 .84009 L
.83504 .83333 L
.84259 .81373 L
.85294 .79932 L
.85598 .79412 L
.87255 .78307 L
s
.5 .6352 m
.51961 .6271 L
.53922 .62423 L
.55882 .62627 L
.57843 .63371 L
.58459 .63725 L
.59804 .64844 L
.60467 .65686 L
.61427 .67647 L
.61697 .69608 L
.61363 .71569 L
.60384 .73529 L
.59804 .7429 L
.58441 .7549 L
.57843 .75854 L
.55882 .76643 L
.53922 .7687 L
.51961 .76595 L
.5 .7579 L
.4949 .7549 L
.48039 .7438 L
.47289 .73529 L
.46078 .72058 L
.45909 .71569 L
.45409 .69608 L
.45946 .67647 L
.46078 .67287 L
.47365 .65686 L
.48039 .64929 L
.49642 .63725 L
.5 .6352 L
s
.30392 .63588 m
.32353 .63241 L
.34314 .63468 L
.35502 .63725 L
.36275 .64247 L
.38165 .65686 L
.38235 .65712 L
.39619 .67647 L
.40196 .69025 L
.40254 .69608 L
.40196 .70184 L
.39609 .71569 L
.38235 .73493 L
.38141 .73529 L
.36275 .74938 L
.35395 .7549 L
.34314 .75713 L
.32353 .75939 L
.30392 .75591 L
.3001 .7549 L
.28431 .74545 L
.2742 .73529 L
.26471 .71939 L
.26382 .71569 L
.26062 .69608 L
.2637 .67647 L
.26471 .67216 L
.27391 .65686 L
.28431 .64634 L
.29887 .63725 L
.30392 .63588 L
s
.83333 .57524 m
.85294 .57572 L
.86327 .57843 L
.87255 .58237 L
.89216 .59677 L
.89343 .59804 L
.90758 .61765 L
.91176 .62342 L
.91475 .63725 L
.91696 .65686 L
.91467 .67647 L
.91176 .68947 L
.90824 .69608 L
.89768 .71569 L
.89216 .72218 L
.88531 .73529 L
.87255 .74445 L
.85294 .7464 L
.83333 .74212 L
.81876 .73529 L
.81373 .73227 L
.79412 .71741 L
.79226 .71569 L
.77641 .69608 L
.77451 .6943 L
.76778 .67647 L
.76481 .65686 L
.76699 .63725 L
.77451 .61777 L
.77457 .61765 L
.78892 .59804 L
.79412 .59326 L
.81373 .58076 L
.81973 .57843 L
.83333 .57524 L
s
.83333 .25912 m
.85294 .25666 L
.87255 .25959 L
.88811 .26471 L
.89216 .26866 L
.91003 .28431 L
.91176 .28633 L
.9227 .30392 L
.92901 .32353 L
.93038 .34314 L
.92711 .36275 L
.91868 .38235 L
.91176 .39269 L
.90349 .40196 L
.89216 .41102 L
.87255 .42099 L
.87078 .42157 L
.85294 .42474 L
.83333 .42274 L
.82922 .42157 L
.81373 .41463 L
.79692 .40196 L
.79412 .39898 L
.78158 .38235 L
.77451 .3687 L
.77285 .36275 L
.76916 .34314 L
.77043 .32353 L
.77451 .30987 L
.77717 .30392 L
.79095 .28431 L
.79412 .28108 L
.81373 .26678 L
.81792 .26471 L
.83333 .25912 L
s
.26471 .25612 m
.28431 .25081 L
.30392 .25179 L
.32353 .25843 L
.33431 .26471 L
.34314 .26951 L
.35898 .28431 L
.36275 .28822 L
.38235 .30128 L
.39514 .28431 L
.40196 .27305 L
.41667 .26471 L
.42157 .26098 L
.44118 .25165 L
.46078 .24784 L
.48039 .24751 L
.5 .24865 L
.51961 .24909 L
.53922 .24773 L
.55882 .24567 L
.57843 .24511 L
.59804 .24802 L
.61765 .25652 L
.62814 .26471 L
.63725 .27319 L
.64203 .28431 L
.64676 .30392 L
.64345 .32353 L
.63725 .33906 L
.63045 .34314 L
.61765 .35286 L
.59804 .36047 L
.57843 .3627 L
.55882 .36134 L
.53922 .35809 L
.51961 .3552 L
.5 .35417 L
.48039 .35421 L
.46078 .35318 L
.44118 .34905 L
.42638 .34314 L
.42157 .34108 L
.40196 .32703 L
.39885 .32353 L
.38235 .30617 L
.36322 .32353 L
.36275 .32448 L
.34371 .34314 L
.34314 .34489 L
.32353 .35888 L
Mistroke
.31464 .36275 L
.30392 .36598 L
.28431 .36719 L
.26643 .36275 L
.26471 .36204 L
.2451 .3476 L
.24169 .34314 L
.2325 .32353 L
.23092 .30392 L
.23622 .28431 L
.2451 .26982 L
.25036 .26471 L
.26471 .25612 L
Mfstroke
.87255 .05703 m
.89216 .05212 L
.91176 .056 L
.92937 .06863 L
.93137 .07579 L
.93602 .08824 L
.93575 .10784 L
.93137 .11958 L
.92881 .12745 L
.91176 .14122 L
.89216 .14685 L
.87255 .14246 L
.85499 .12745 L
.85294 .11967 L
.84928 .10784 L
.84978 .08824 L
.85294 .07923 L
.85714 .06863 L
.87255 .05703 L
s
.51961 .61499 m
.53922 .6125 L
.55882 .61417 L
.57592 .61765 L
.57843 .62023 L
.59804 .63165 L
.60472 .63725 L
.61765 .65155 L
.62075 .65686 L
.62895 .67647 L
.63112 .69608 L
.62771 .71569 L
.61899 .73529 L
.61765 .73762 L
.60324 .7549 L
.59804 .75952 L
.57843 .77192 L
.57582 .77451 L
.55882 .77848 L
.53922 .7804 L
.51961 .77805 L
.50524 .77451 L
.5 .77133 L
.48039 .76 L
.47386 .7549 L
.46078 .74474 L
.45007 .73529 L
.44118 .73166 L
.42157 .72821 L
.40472 .73529 L
.40196 .73748 L
.38235 .75197 L
.37764 .7549 L
.36275 .7628 L
.34314 .76925 L
.32353 .77112 L
.30392 .76821 L
.28431 .75959 L
.27739 .7549 L
.26471 .74223 L
.26003 .73529 L
.25149 .71569 L
.24883 .69608 L
.25139 .67647 L
.25981 .65686 L
.26471 .64955 L
.27692 .63725 L
.28431 .6322 L
.30392 .62358 L
.32353 .62068 L
Mistroke
.34314 .62257 L
.36275 .62905 L
.37804 .63725 L
.38235 .63996 L
.40196 .65461 L
.40477 .65686 L
.42157 .66428 L
.44118 .66121 L
.45086 .65686 L
.46078 .64821 L
.47497 .63725 L
.48039 .63306 L
.5 .62175 L
.508 .61765 L
.51961 .61499 L
Mfstroke
.81373 .55552 m
.83333 .5503 L
.85294 .55058 L
.87255 .55647 L
.87821 .55882 L
.89216 .5683 L
.90388 .57843 L
.91176 .5873 L
.91952 .59804 L
.9295 .61765 L
.93137 .61969 L
.93506 .63725 L
.93679 .65686 L
.93503 .67647 L
.93137 .69379 L
.93014 .69608 L
.92298 .71569 L
.91554 .73529 L
.9121 .7549 L
.91839 .77451 L
.93137 .79395 L
.93167 .79412 L
.94556 .81373 L
.95098 .82312 L
.95578 .83333 L
.96191 .85294 L
.96368 .87255 L
.96075 .89216 L
.95201 .91176 L
.95098 .91341 L
.93367 .93137 L
.93137 .93289 L
.91176 .94195 L
.89216 .94461 L
.87255 .94167 L
.85294 .93238 L
.85143 .93137 L
.83333 .91306 L
.83247 .91176 L
.82278 .89216 L
.81831 .87255 L
.81755 .85294 L
.81949 .83333 L
.82287 .81373 L
.82518 .79412 L
.82077 .77451 L
.81373 .76285 L
.80447 .7549 L
.79412 .74546 L
.78278 .73529 L
Mistroke
.77451 .72692 L
.76503 .71569 L
.7549 .70027 L
.7529 .69608 L
.74596 .67647 L
.74368 .65686 L
.74573 .63725 L
.75194 .61765 L
.7549 .61089 L
.7626 .59804 L
.77451 .5831 L
.779 .57843 L
.79412 .56618 L
.80525 .55882 L
.81373 .55552 L
Mfstroke
.83333 .23924 m
.85294 .23623 L
.87255 .23845 L
.8915 .2451 L
.89216 .24548 L
.91176 .26011 L
.91668 .26471 L
.93137 .2832 L
.93207 .28431 L
.94174 .30392 L
.94684 .32353 L
.94797 .34314 L
.94528 .36275 L
.9386 .38235 L
.93137 .39602 L
.92731 .40196 L
.91176 .41971 L
.90985 .42157 L
.89216 .43469 L
.88189 .44118 L
.87255 .44386 L
.85294 .44755 L
.83333 .44579 L
.81902 .44118 L
.81373 .43853 L
.79412 .42508 L
.79002 .42157 L
.77451 .40441 L
.77269 .40196 L
.76086 .38235 L
.7549 .36926 L
.75319 .36275 L
.7496 .34314 L
.75038 .32353 L
.7549 .30604 L
.7558 .30392 L
.7673 .28431 L
.77451 .27525 L
.78537 .26471 L
.79412 .25787 L
.81373 .24636 L
.81514 .2451 L
.83333 .23924 L
s
.28431 .24238 m
.30392 .24318 L
.31274 .2451 L
.32353 .24867 L
.34314 .25808 L
.35549 .26471 L
.36275 .26702 L
.38235 .2673 L
.39322 .26471 L
.40196 .25929 L
.42157 .24806 L
.42751 .2451 L
.44118 .24079 L
.46078 .23743 L
.48039 .23698 L
.5 .23772 L
.51961 .23779 L
.53922 .23632 L
.55882 .23432 L
.57843 .23369 L
.59804 .23611 L
.61765 .24293 L
.62198 .2451 L
.63725 .2558 L
.64564 .26471 L
.65686 .28099 L
.65783 .28431 L
.66208 .30392 L
.65969 .32353 L
.65686 .33201 L
.64928 .34314 L
.63725 .35531 L
.62582 .36275 L
.61765 .36662 L
.59804 .37251 L
.57843 .3742 L
.55882 .37273 L
.53922 .36955 L
.51961 .3666 L
.5 .36519 L
.48039 .36479 L
.46078 .36365 L
.45408 .36275 L
.44118 .36015 L
.42157 .35333 L
.40196 .34384 L
.40049 .34314 L
.38235 .33997 L
.36425 .34314 L
.36275 .34404 L
Mistroke
.34314 .35757 L
.33459 .36275 L
.32353 .36841 L
.30392 .37464 L
.28431 .37572 L
.26471 .37121 L
.24849 .36275 L
.2451 .35958 L
.23146 .34314 L
.22549 .32985 L
.22379 .32353 L
.22245 .30392 L
.22549 .28837 L
.22693 .28431 L
.23904 .26471 L
.2451 .25873 L
.26471 .24688 L
.26996 .2451 L
.28431 .24238 L
Mfstroke
.87255 .04337 m
.89216 .03942 L
.91176 .04259 L
.92788 .04902 L
.93137 .05387 L
.9426 .06863 L
.94909 .08824 L
.94894 .10784 L
.94262 .12745 L
.93137 .14373 L
.92932 .14706 L
.91176 .15868 L
.89216 .16516 L
.87255 .16205 L
.85294 .14747 L
.8525 .14706 L
.84065 .12745 L
.83583 .10784 L
.8365 .08824 L
.84352 .06863 L
.85294 .05574 L
.85936 .04902 L
.87255 .04337 L
s
.30392 .61087 m
.32353 .60839 L
.34314 .60999 L
.36275 .61536 L
.36874 .61765 L
.38235 .62411 L
.40196 .63458 L
.40755 .63725 L
.42157 .64172 L
.44118 .63956 L
.44658 .63725 L
.46078 .62915 L
.47979 .61765 L
.48039 .61729 L
.5 .60795 L
.51961 .60208 L
.53922 .59984 L
.55882 .60123 L
.57843 .6063 L
.59804 .61535 L
.60184 .61765 L
.61765 .62932 L
.62535 .63725 L
.63725 .65117 L
.6389 .65686 L
.64663 .67647 L
.6484 .69608 L
.64418 .71569 L
.63725 .73403 L
.63608 .73529 L
.62176 .7549 L
.61765 .75948 L
.59965 .77451 L
.59804 .77557 L
.57843 .78571 L
.55882 .79136 L
.53922 .79304 L
.51961 .79095 L
.5 .78513 L
.48039 .77576 L
.47832 .77451 L
.46078 .76379 L
.44536 .7549 L
.44118 .75311 L
.42157 .75065 L
.40756 .7549 L
.40196 .75752 L
.38235 .76782 L
.36803 .77451 L
.36275 .7765 L
Mistroke
.34314 .78183 L
.32353 .78341 L
.30392 .78093 L
.28507 .77451 L
.28431 .77381 L
.26471 .76024 L
.25937 .7549 L
.2458 .73529 L
.2451 .73469 L
.23875 .71569 L
.23649 .69608 L
.23867 .67647 L
.2451 .65726 L
.24562 .65686 L
.25904 .63725 L
.26471 .63155 L
.28431 .61799 L
.28467 .61765 L
.30392 .61087 L
Mfstroke
.83333 .50836 m
.85294 .50642 L
.87236 .51961 L
.87255 .51982 L
.89216 .53765 L
.89621 .53922 L
.91176 .55467 L
.91584 .55882 L
.93135 .57843 L
.93137 .57847 L
.94289 .59804 L
.95077 .61765 L
.95098 .61779 L
.95529 .63725 L
.95671 .65686 L
.95525 .67647 L
.95127 .69608 L
.95098 .69722 L
.94563 .71569 L
.9403 .73529 L
.9385 .7549 L
.94288 .77451 L
.95098 .79318 L
.95204 .79412 L
.96209 .81373 L
.97017 .83333 L
.97059 .83363 L
.97515 .85294 L
.97656 .87255 L
.97404 .89216 L
.97059 .90577 L
.96684 .91176 L
.95309 .93137 L
.95098 .93354 L
.93137 .94796 L
.92819 .95098 L
.91176 .95529 L
.89216 .95749 L
.87255 .95503 L
.85751 .95098 L
.85294 .94745 L
.83333 .93289 L
.83184 .93137 L
.81742 .91176 L
.81373 .90507 L
.8092 .89216 L
.80492 .87255 L
.8034 .85294 L
.8035 .83333 L
.80353 .81373 L
Mistroke
.80047 .79412 L
.79412 .77939 L
.79028 .77451 L
.77451 .7567 L
.77273 .7549 L
.7549 .73621 L
.75411 .73529 L
.7388 .71569 L
.73529 .71073 L
.7283 .69608 L
.72163 .67647 L
.72 .65686 L
.72286 .63725 L
.72906 .61765 L
.73529 .60341 L
.73833 .59804 L
.7511 .57843 L
.7549 .57353 L
.76783 .55882 L
.77451 .55244 L
.78914 .53922 L
.79412 .53642 L
.81373 .52126 L
.81558 .51961 L
.83333 .50836 L
Mfstroke
.53922 .22436 m
.55882 .22245 L
.57843 .22177 L
.59804 .22369 L
.60846 .22549 L
.61765 .22925 L
.63725 .23939 L
.64512 .2451 L
.65686 .25529 L
.6643 .26471 L
.67647 .28029 L
.67839 .28431 L
.68633 .30392 L
.68578 .32353 L
.67647 .33979 L
.67278 .34314 L
.65686 .35946 L
.65201 .36275 L
.63725 .37218 L
.61765 .38057 L
.61563 .38235 L
.59804 .38506 L
.57843 .38621 L
.55882 .38471 L
.54245 .38235 L
.53922 .38166 L
.51961 .37859 L
.5 .37679 L
.48039 .37596 L
.46078 .37465 L
.44118 .37144 L
.42157 .36572 L
.4152 .36275 L
.40196 .35859 L
.38235 .35459 L
.36275 .35924 L
.35232 .36275 L
.34314 .36938 L
.32353 .37866 L
.31214 .38235 L
.30392 .38401 L
.28431 .38491 L
.26876 .38235 L
.26471 .38111 L
.2451 .37111 L
.23502 .36275 L
.22549 .35135 L
.22106 .34314 L
.21444 .32353 L
.21322 .30392 L
Mistroke
.21722 .28431 L
.22549 .26671 L
.22721 .26471 L
.2451 .24701 L
.24744 .2451 L
.26471 .23723 L
.28431 .2332 L
.30392 .23389 L
.32353 .23859 L
.34076 .2451 L
.34314 .24599 L
.36275 .25277 L
.38235 .25258 L
.40124 .2451 L
.40196 .24475 L
.42157 .23566 L
.44118 .22937 L
.46078 .22637 L
.48039 .2258 L
.5 .22617 L
.51961 .22589 L
.52586 .22549 L
.53922 .22436 L
Mfstroke
.89216 .02664 m
.91176 .02917 L
.91314 .02941 L
.93137 .03813 L
.94418 .04902 L
.95098 .05725 L
.95659 .06863 L
.9619 .08824 L
.96184 .10784 L
.95682 .12745 L
.95098 .1403 L
.94668 .14706 L
.93137 .16541 L
.93053 .16667 L
.91176 .18107 L
.90764 .18627 L
.89573 .20588 L
.90818 .22549 L
.91176 .23182 L
.92559 .2451 L
.93137 .25211 L
.94122 .26471 L
.95098 .28034 L
.95301 .28431 L
.96086 .30392 L
.96513 .32353 L
.96608 .34314 L
.96382 .36275 L
.95829 .38235 L
.95098 .39891 L
.94927 .40196 L
.93633 .42157 L
.93137 .42767 L
.91908 .44118 L
.91176 .44773 L
.89713 .46078 L
.89216 .46198 L
.87255 .47868 L
.86992 .48039 L
.85294 .49028 L
.83333 .48652 L
.82467 .48039 L
.81373 .47209 L
.79977 .46078 L
.79412 .45482 L
.77971 .44118 L
.77451 .43533 L
.76305 .42157 L
.7549 .4102 L
.74969 .40196 L
Mistroke
.73891 .38235 L
.73529 .37565 L
.73151 .36275 L
.72361 .34314 L
.7216 .32353 L
.72803 .30392 L
.73529 .2911 L
.74175 .28431 L
.7549 .26778 L
.75795 .26471 L
.77451 .24941 L
.77997 .2451 L
.79412 .23537 L
.81085 .22549 L
.81373 .22417 L
.83333 .21577 L
.84377 .20588 L
.85294 .20032 L
.85407 .18627 L
.85294 .18394 L
.84276 .16667 L
.83333 .1481 L
.83287 .14706 L
.82588 .12745 L
.82264 .10784 L
.82356 .08824 L
.8294 .06863 L
.83333 .06041 L
.84213 .04902 L
.85294 .03957 L
.87255 .0298 L
.87385 .02941 L
.89216 .02664 L
Mfstroke
.9902 .88307 m
.98877 .89216 L
.98271 .91176 L
.97171 .93137 L
.97059 .93291 L
.95304 .95098 L
.95098 .95254 L
.93137 .96391 L
.91176 .97013 L
.90931 .97059 L
.89216 .97204 L
.8762 .97059 L
.87255 .96989 L
.85294 .96343 L
.83333 .95187 L
.83216 .95098 L
.81373 .93232 L
.81302 .93137 L
.80132 .91176 L
.79412 .89307 L
.79387 .89216 L
.78963 .87255 L
.78717 .85294 L
.78523 .83333 L
.78176 .81373 L
.77451 .7954 L
.77376 .79412 L
.75917 .77451 L
.7549 .76986 L
.74041 .7549 L
.73529 .74988 L
.72153 .73529 L
.71569 .73042 L
.69785 .71569 L
.69608 .715 L
.67887 .71569 L
.67647 .71763 L
.66057 .73529 L
.65686 .74001 L
.64336 .7549 L
.63725 .76254 L
.62432 .77451 L
.61765 .78003 L
.59804 .79272 L
.59551 .79412 L
.57843 .80109 L
.55882 .80589 L
.53922 .80733 L
.51961 .8055 L
.5 .8005 L
Mistroke
.48351 .79412 L
.48039 .79263 L
.46078 .78275 L
.44182 .77451 L
.44118 .7743 L
.42157 .7719 L
.40853 .77451 L
.40196 .77663 L
.38235 .78444 L
.36275 .79158 L
.35763 .79412 L
.34314 .79607 L
.32353 .79737 L
.30392 .7953 L
.29684 .79412 L
.28431 .78919 L
.26471 .7782 L
.25979 .77451 L
.2451 .75983 L
.24139 .7549 L
.23041 .73529 L
.22549 .7231 L
.22437 .71569 L
.22248 .69608 L
.2243 .67647 L
.22549 .66842 L
.23026 .65686 L
.24113 .63725 L
.2451 .63196 L
.25934 .61765 L
.26471 .61359 L
.28431 .6026 L
.29516 .59804 L
.30392 .59651 L
.32353 .59444 L
.34314 .59576 L
.35879 .59804 L
.36275 .60027 L
.38235 .6075 L
.40196 .61548 L
.40844 .61765 L
.42157 .62048 L
.44118 .61839 L
.44348 .61765 L
.46078 .61019 L
.48039 .60042 L
.4855 .59804 L
.5 .59255 L
.51961 .5875 L
.53922 .58549 L
Mistroke
.55882 .58658 L
.57843 .59071 L
.59804 .59778 L
.59862 .59804 L
.61765 .60803 L
.63201 .61765 L
.63725 .62083 L
.65686 .63464 L
.66112 .63725 L
.67647 .64044 L
.68506 .63725 L
.69608 .62282 L
.70003 .61765 L
.71129 .59804 L
.71569 .59003 L
.72304 .57843 L
.73529 .56047 L
.73649 .55882 L
.75124 .53922 L
.7549 .53527 L
.76496 .51961 L
.77299 .5 L
.77125 .48039 L
.76166 .46078 L
.7549 .44935 L
.74897 .44118 L
.73591 .42157 L
.73529 .42063 L
.72334 .40196 L
.71569 .39164 L
.7077 .38235 L
.69608 .37446 L
.67647 .37455 L
.65686 .382 L
.65588 .38235 L
.63725 .38981 L
.61765 .3958 L
.59804 .39921 L
.57843 .39991 L
.55882 .39824 L
.53922 .39509 L
.51961 .39186 L
.5 .38968 L
.48039 .38843 L
.46078 .38697 L
.44118 .38414 L
.43247 .38235 L
.42157 .37923 L
.40196 .37326 L
.38235 .37019 L
Mistroke
.36275 .37395 L
.34319 .38235 L
.34314 .38241 L
.32353 .38991 L
.30392 .39463 L
.28431 .39548 L
.26471 .39199 L
.2451 .38378 L
.24257 .38235 L
.22549 .36815 L
.22094 .36275 L
.20925 .34314 L
.20588 .33408 L
.20362 .32353 L
.20264 .30392 L
.20581 .28431 L
.20588 .284 L
.21462 .26471 L
.22549 .24999 L
.23044 .2451 L
.2451 .23453 L
.26471 .22586 L
.26599 .22549 L
.28431 .22262 L
.30392 .22313 L
.31805 .22549 L
.32353 .22692 L
.34314 .23312 L
.36275 .23794 L
.38235 .23684 L
.40196 .22986 L
.41264 .22549 L
.42157 .22222 L
.44118 .21689 L
.46078 .21418 L
.48039 .21345 L
.5 .21343 L
.51961 .21277 L
.53922 .21102 L
.55882 .20903 L
.57843 .20825 L
.59804 .20983 L
.61765 .21446 L
.63725 .22249 L
.64287 .22549 L
.65686 .23424 L
.67082 .2451 L
.67647 .2489 L
.69608 .26223 L
.71569 .26424 L
Mistroke
.73529 .25331 L
.74675 .2451 L
.7549 .23795 L
.77114 .22549 L
.77451 .22302 L
.79412 .20872 L
.79756 .20588 L
.81373 .18788 L
.81449 .18627 L
.81703 .16667 L
.81373 .14769 L
.8136 .14706 L
.80995 .12745 L
.80821 .10784 L
.80942 .08824 L
.81373 .07037 L
.81436 .06863 L
.82464 .04902 L
.83333 .03828 L
.84321 .02941 L
.85294 .02323 L
.87255 .01536 L
.89216 .01272 L
.91176 .01483 L
.93137 .02209 L
.94324 .02941 L
.95098 .03623 L
.96158 .04902 L
.97059 .06583 L
.9715 .06863 L
.97597 .08824 L
.976 .10784 L
.97199 .12745 L
.97059 .13212 L
.96416 .14706 L
.95315 .16667 L
.95098 .17024 L
.94162 .18627 L
.93614 .20588 L
.94174 .22549 L
.95098 .24236 L
.95358 .2451 L
.96565 .26471 L
.97059 .27391 L
.97529 .28431 L
.98188 .30392 L
.98549 .32353 L
.9863 .34314 L
.98439 .36275 L
.97974 .38235 L
Mistroke
.97228 .40196 L
.97059 .4056 L
.96201 .42157 L
.95098 .43868 L
.94928 .44118 L
.93524 .46078 L
.93137 .46339 L
.92317 .48039 L
.9181 .5 L
.92279 .51961 L
.93137 .53766 L
.93387 .53922 L
.94659 .55882 L
.95098 .56599 L
.95805 .57843 L
.96717 .59804 L
.97059 .60698 L
.97364 .61765 L
.97742 .63725 L
.97861 .65686 L
.97734 .67647 L
.97392 .69608 L
.97059 .71 L
.96912 .71569 L
.96459 .73529 L
.9628 .7549 L
.96557 .77451 L
.97059 .7929 L
.97206 .79412 L
.97959 .81373 L
.98593 .83333 L
.98989 .85294 L
.9902 .85551 L
Mfstroke
.9902 .58226 m
.98862 .57843 L
.97971 .55882 L
.97059 .53992 L
.97028 .53922 L
.96261 .51961 L
.95964 .5 L
.96297 .48039 L
.97059 .46121 L
.97127 .46078 L
.98157 .44118 L
.9902 .42406 L
s
.9902 .25687 m
.98411 .2451 L
.97415 .22549 L
.97059 .21599 L
.96844 .20588 L
.97007 .18627 L
.97059 .18439 L
.97683 .16667 L
.98437 .14706 L
.99004 .12745 L
.9902 .12674 L
s
.9902 .07249 m
.98921 .06863 L
.98136 .04902 L
.97059 .0328 L
.96768 .02941 L
.95098 .01435 L
.94427 .0098 L
s
.9902 .93587 m
.9789 .95098 L
.97059 .95938 L
.95648 .97059 L
.95098 .97409 L
.93137 .98337 L
.91176 .9884 L
.89216 .98992 L
.87255 .98819 L
.85294 .98293 L
.83333 .97344 L
.82888 .97059 L
.81373 .9586 L
.80618 .95098 L
.79412 .93554 L
.79157 .93137 L
.78169 .91176 L
.77467 .89216 L
.77451 .89163 L
.77006 .87255 L
.76605 .85294 L
.76106 .83333 L
.7549 .81802 L
.75276 .81373 L
.73843 .79412 L
.73529 .79086 L
.71647 .77451 L
.71569 .77403 L
.69608 .76434 L
.67647 .7655 L
.65969 .77451 L
.65686 .7764 L
.63725 .79052 L
.63195 .79412 L
.61765 .80324 L
.59804 .81338 L
.59729 .81373 L
.57843 .82014 L
.55882 .82417 L
.53922 .82538 L
.51961 .82379 L
.5 .81951 L
.48224 .81373 L
.48039 .81297 L
.46078 .80463 L
.44118 .79757 L
.42157 .79518 L
.40196 .79826 L
.38235 .8042 L
.36275 .81001 L
Mistroke
.34519 .81373 L
.34314 .81387 L
.32353 .81491 L
.3075 .81373 L
.30392 .81315 L
.28431 .80788 L
.26471 .79891 L
.25678 .79412 L
.2451 .78496 L
.23464 .77451 L
.22549 .76287 L
.22067 .7549 L
.2117 .73529 L
.2065 .71569 L
.20588 .71169 L
.2049 .69608 L
.20588 .68009 L
.20643 .67647 L
.21157 .65686 L
.22047 .63725 L
.22549 .62892 L
.23432 .61765 L
.2451 .60683 L
.25624 .59804 L
.26471 .59289 L
.28431 .5839 L
.30392 .57863 L
.3051 .57843 L
.32353 .57692 L
.34314 .57797 L
.34888 .57843 L
.36275 .58183 L
.38235 .58774 L
.40196 .59386 L
.42157 .59721 L
.44118 .59513 L
.46078 .58832 L
.48039 .58009 L
.48453 .57843 L
.5 .57351 L
.51961 .56916 L
.53922 .56734 L
.55882 .5681 L
.57843 .57127 L
.59804 .57647 L
.60378 .57843 L
.61765 .58335 L
.63725 .59024 L
.65686 .59338 L
.67647 .58616 L
Mistroke
.68623 .57843 L
.69608 .56509 L
.70071 .55882 L
.7137 .53922 L
.71569 .53645 L
.72455 .51961 L
.73094 .5 L
.73084 .48039 L
.72465 .46078 L
.71569 .44322 L
.71421 .44118 L
.6996 .42157 L
.69608 .4184 L
.67647 .40797 L
.65686 .40776 L
.63725 .41116 L
.61765 .41471 L
.59804 .41684 L
.57843 .41695 L
.55882 .41506 L
.53922 .41181 L
.51961 .40838 L
.5 .40582 L
.48039 .40419 L
.46078 .40263 L
.45408 .40196 L
.44118 .39985 L
.42157 .39536 L
.40196 .39038 L
.38235 .38795 L
.36275 .39091 L
.34314 .39786 L
.33214 .40196 L
.32353 .40422 L
.30392 .40792 L
.28431 .40861 L
.26471 .40582 L
.2502 .40196 L
.2451 .39911 L
.22549 .38651 L
.2206 .38235 L
.20588 .36532 L
.20434 .36275 L
.19502 .34314 L
.18987 .32353 L
.1889 .30392 L
.19207 .28431 L
.19945 .26471 L
.20588 .25284 L
.21189 .2451 L
Mistroke
.22549 .23164 L
.23359 .22549 L
.2451 .21943 L
.26471 .21219 L
.28431 .20896 L
.30392 .20942 L
.32353 .21286 L
.34314 .21764 L
.36275 .22071 L
.38235 .21887 L
.40196 .21258 L
.42103 .20588 L
.42157 .20574 L
.44118 .2014 L
.46078 .19899 L
.48039 .19808 L
.5 .19761 L
.51961 .19652 L
.53922 .19453 L
.55882 .19246 L
.57843 .19155 L
.59804 .19273 L
.61765 .19645 L
.63725 .20268 L
.64518 .20588 L
.65686 .21132 L
.67647 .22097 L
.68761 .22549 L
.69608 .22789 L
.71569 .22717 L
.72072 .22549 L
.73529 .21814 L
.75324 .20588 L
.7549 .20457 L
.77451 .18764 L
.77572 .18627 L
.78756 .16667 L
.79052 .14706 L
.79035 .12745 L
.79033 .10784 L
.792 .08824 L
.79412 .07387 L
.79648 .06863 L
.80501 .04902 L
.81373 .03529 L
.81867 .02941 L
.83333 .0159 L
.84223 .0098 L
Mfstroke
.9902 .97922 m
.97683 .9902 L
s
.9902 .01615 m
.98478 .0098 L
s
.80862 .9902 m
.79412 .97842 L
.78666 .97059 L
.77451 .956 L
.77119 .95098 L
.7597 .93137 L
.7549 .92176 L
.75111 .91176 L
.74398 .89216 L
.73672 .87255 L
.73529 .86903 L
.72877 .85294 L
.71569 .83467 L
.71521 .83333 L
.69608 .81983 L
.67647 .81611 L
.65686 .8203 L
.63725 .82856 L
.62656 .83333 L
.61765 .83712 L
.59804 .8444 L
.57843 .85001 L
.56467 .85294 L
.55882 .85329 L
.53922 .85409 L
.51961 .85295 L
.51954 .85294 L
.5 .8492 L
.48039 .84346 L
.46078 .83686 L
.45138 .83333 L
.44118 .83107 L
.42157 .82828 L
.40196 .82998 L
.38376 .83333 L
.38235 .83419 L
.36275 .83809 L
.34314 .84093 L
.32353 .8418 L
.30392 .84029 L
.28431 .83639 L
.27332 .83333 L
.26471 .82958 L
.2451 .81895 L
.23707 .81373 L
.22549 .80413 L
.21546 .79412 L
.20588 .78258 L
.20062 .77451 L
.18998 .7549 L
Mistroke
.18627 .74644 L
.18319 .73529 L
.17933 .71569 L
.178 .69608 L
.17928 .67647 L
.18309 .65686 L
.18627 .64534 L
.18981 .63725 L
.20039 .61765 L
.20588 .60922 L
.21513 .59804 L
.22549 .58765 L
.23658 .57843 L
.2451 .57285 L
.26471 .56219 L
.27233 .55882 L
.28431 .55546 L
.30392 .55153 L
.32353 .55002 L
.34314 .55091 L
.36275 .5538 L
.38235 .5578 L
.38493 .55882 L
.40196 .56216 L
.42157 .56416 L
.44118 .56168 L
.45429 .55882 L
.46078 .55605 L
.48039 .54958 L
.5 .54374 L
.51961 .5397 L
.52308 .53922 L
.53922 .53827 L
.55882 .53841 L
.5733 .53922 L
.57843 .53984 L
.59804 .54273 L
.61765 .54505 L
.63725 .54374 L
.64844 .53922 L
.65686 .5343 L
.6682 .51961 L
.67546 .5 L
.67549 .48039 L
.66621 .46078 L
.65686 .45241 L
.63725 .44611 L
.61765 .44497 L
.59804 .44457 L
.57843 .44359 L
Mistroke
.55882 .44189 L
.55039 .44118 L
.53922 .43882 L
.51961 .43455 L
.5 .43089 L
.48039 .42824 L
.46078 .42606 L
.44118 .42364 L
.42629 .42157 L
.42157 .42049 L
.40196 .41605 L
.38235 .41384 L
.36275 .41615 L
.34343 .42157 L
.34314 .42174 L
.32353 .42572 L
.30392 .42886 L
.28431 .42947 L
.26471 .42707 L
.2451 .42233 L
.24221 .42157 L
.22549 .41238 L
.21023 .40196 L
.20588 .39803 L
.19192 .38235 L
.18627 .37465 L
.18046 .36275 L
.17255 .34314 L
.16807 .32353 L
.16723 .30392 L
.16998 .28431 L
.17637 .26471 L
.18548 .2451 L
.18627 .24355 L
.20077 .22549 L
.20588 .22044 L
.22437 .20588 L
.22549 .20533 L
.2451 .19647 L
.26471 .19018 L
.28431 .18733 L
.30392 .18764 L
.32353 .19038 L
.34314 .19391 L
.36275 .19536 L
.38235 .19248 L
.40196 .18641 L
.40236 .18627 L
.42157 .18161 L
.44118 .17763 L
Mistroke
.46078 .17516 L
.48039 .17381 L
.5 .17263 L
.51961 .17079 L
.53922 .16829 L
.55101 .16667 L
.55882 .16616 L
.57843 .16529 L
.59804 .16583 L
.60754 .16667 L
.61765 .16834 L
.63725 .17299 L
.65686 .17858 L
.67647 .18333 L
.69608 .18464 L
.71569 .1796 L
.73529 .16667 L
.73529 .16666 L
.75116 .14706 L
.7549 .13738 L
.75785 .12745 L
.76164 .10784 L
.76509 .08824 L
.76968 .06863 L
.77451 .05253 L
.77612 .04902 L
.78687 .02941 L
.79412 .01855 L
.80187 .0098 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo08gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`D000001_ooool2o`0000Gooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon;00000003o`00000I6AT06ATI00<06ATI00<00000o`00000c<c<00`0c<c<3000000D0C4a<0`00
000503<c<`03o`00000I6AT06ATI00<06ATI00Go0000oooooooooooooooo0000003Aooooo`002Ooo
ool01000003ooooooooooooooon;000000D06ATI00@0000003<c<`0c<c<0<c<c0`00000;04a<C0<0
00000`0c<c<00ol000006ATI01TI6@0201TI6@Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000ooooooooooooooooRP00000501TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`00`00
003o00000000000500000003o`0000000000000000<0C4a<00Go000003<c<`0c<c<0<c<co`000003
01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooRP000004
01TI6@03o`00000c<c<0<c<c0080<c<c00@0000004a<C01<C4`000002`1VIVH01@000000C4a<04a<
C01<C4`0000000<0<c<c00?o000001TI6@0I6AT01?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003ooooooooooooooon9000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C003
0000001VIVH0IVIV0080IVIV1ol0000206IVIP040000001<C4`0C4a<000000<0<c<c00?o000001TI
6@0I6AT01?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon90000
00@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH0IVIV00?o00001`1oOgl0
1?l00000IVIV06IVIP00000204a<C0060000000c<c<0<c<c03<c<ol000006ATI1?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon8000000D06ATI00@0000003<c<`0c
<c<000000P1<C4`010000000IVIV06IVI_l0000307moO`Go00000`1oOgl2o`00000506IVI_l00000
C4a<04a<C00000000`0c<c<00ol0003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooohP000001@0I6AT010000000<c<c03<c<`00000204a<C0030000
001VIVKo00000080Ogmo0_l0000509VIV@;o00000P1oOgl01_l00000IVIV06IVIP000000C4a<0000
00<0<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
oooooooooooooon7000000D06ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIVo`000002
07moO`03o`00002IVIT0VIVI00L0VIVI0_l00000101oOgoo000006IVIP00000204a<C0050000000c
<c<0<c<c03<c<ol000000oooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooon7000000@06ATI00@0000003<c<`0c<c<000000P1<C4`00ol00000IVIVo`00000207moO`04
o`00002IVIT0VIVI09VIV@Go0000102IVIT01Ol00000Ogmoo`00001VIVH000000080C4a<00@00000
03<c<`0c<c?o00000oooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon7000000@06ATI00Co000003<c<`0c<c<000000P1<C4`00`000000IVIVo`00000207moO`04o`00
002IVIT0VIVIo`0000D0/k>c00Wo000009VIV@2IVIT0VIVIo`00001oOgoo000006IVIP0000000P1<
C4`010000000<c<c03<c<ol00003ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooohL00000100I6AT010000000<c<c03<c<`00000204a<C0050000001VIVKo000007mo
Ool000000P2IVIT00ol00000/k>c0;>c/`050;>c/`08o`00002IVIT0VIVIo`00001oOgoo000006IV
IP00000204a<C0030000000c<c<0<c<c00Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000ooooooooooooooooQP00000401TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVI_l0
00000P1oOgl01?l00000VIVI09VIVOl000080;>c/`08o`00002IVIT0VIVIo`00001oOgoo000006IV
IP00000204a<C0030000000c<c?ooooo00?ooooo00<00000ooooooooool0Roooool2o`0004;ooooo
0009ooooo`0400000?ooooooooooooooohH00000100I6AT010000000<c<c03<c<`00000204a<C005
0000001VIVKo000007moOol000000P2IVIT00ol00000/k>c0;>c/`080;>c/`07o`00002IVIWo0000
07moOol00000IVIV0000000204a<C0030000000c<c?ooooo00?ooooo00<00000ooooooooool0R?oo
ool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?ooooooooooooooohH00000100I
6AT010000000<c<c03<c<`00000204a<C0050000001VIVKo000007moOol000000P2IVIT00ol00000
/k>c0;>c/`080;>c/`07o`00002IVIWo000007moOol00000IVIV0000000204a<C0030000000c<c?o
oooo00?ooooo00<00000ooooooooool0Q_ooool2o`0000Cooooo0_l00011ooooo`002Oooool01000
003ooooooooooooooon6000000@06ATI00@0000003<c<`0c<c<000000P1<C4`01@000000IVIVo`00
001oOgoo00000080VIVI00?o00000;>c/`2c/k<01`2c/k<02?l00000VIVI09VIVOl00000Ogmoo`00
001VIVH000000P1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo08?ooooo0ol00006
ooooo`03o`000?oooooo0000043ooooo0009ooooo`0400000?ooooooooooooooohH00000100I6AT0
10000000<c<c03<c<`00000204a<C0050000001VIVKo000007moOol000000P2IVIT00ol00000/k>c
0;>c/`070;>c/`08o`00002IVIT0VIVIo`00001oOgoo000006IVIP00000204a<C0030000000c<c?o
oooo00?ooooo00<00000ooooooooool0P?ooool3o`0000Wooooo00?o0000ooooool00000@?ooool0
00Wooooo00@00000ooooooooooooooooQP00000401TI6@040000000c<c<0<c<c00000080C4a<00D0
000006IVI_l00000Ogmoo`00000209VIV@03o`00002c/k<0/k>c00H0/k>c00Wo000009VIV@2IVIT0
VIVIo`00001oOgoo000006IVIP0000000P1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooo
oooo07kooooo0_l0000;ooooo`050;^J]_l0003oooooooooool00000?oooool000Wooooo00@00000
ooooooooooooooooQ@00000501TI6@040000000c<c<0<c<c00000080C4a<00H0000006IVIP1VIVKo
000007moOol0000209VIV@?o00000`2c/k<2o`0000<0VIVI00Go000007moOol00000IVIV00000002
04a<C0030000000c<c<0<c<c00Cooooo00<00000ooooooooool0Noooool3o`0000cooooo0P2kV[H0
1Ol0003ooooooooooooooooo000003kooooo0009ooooo`0400000?ooooooooooooooohD000001@0I
6AT010000000<c<c03<c<`00000204a<C0060000001VIVH0IVIVo`00001oOgoo00001@2IVIT00ol0
0000/k>co`00000409VIV@06o`00001oOgl0Ogmoo`00001VIVH000000P1<C4`01?l00000<c<c03<c
<ol00003ooooo`0300000?oooooooooo07Wooooo0_l0000>ooooo`<0^iZf00Go0000oooooooooooo
ooooo`00000nooooo`002Oooool01000003ooooooooooooooon5000000D06ATI00@0000003<c<`0c
<c<000000P1<C4`010000000IVIV06IVI_l0000207moO`03o`00002IVIT0VIVI00<0VIVI00?o0000
09VIV@2IVIT00P2IVIT01ol00000Ogmo07moO`1oOgoo000006IVIP0000000P1<C4`010000000<c<c
03<c<ol00003ooooo`0300000?oooooooooo07Kooooo0ol0000@ooooo`040;J>[02kV[H0^iZfo`00
00Cooooo00?o0000ooooooooool0>oooool000Wooooo00@00000ooooooooooooooooQ@00000501TI
6@040000000c<c<0<c<c00000080C4a<00D0000006IVIP1VIVH0IVIVo`00000207moO`03o`00002I
VIT0VIVI00H0VIVI00Oo000007moO`1oOgl0Ogmoo`00001VIVH0000000<0C4a<00@0000003<c<`0c
<c?o00000oooool00`00003oooooooooo`1dooooo`;o00004_ooool20;J>[080^iZf00?o00000<BM
/?ooool00_ooool00ol0003oooooooooo`0kooooo`002Oooool01000003ooooooooooooooon50000
00D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIVo`0000<0Ogmo0ol0
000309VIV@;o00000`1oOgl01?l00000IVIV06IVI_l0000204a<C0040000000c<c<0<c<co`0000Co
oooo00<00000ooooooooool0LOooool3o`0001?ooooo102fSZ`00`2kV[Ko00000<BM/004ooooo`03
o`000?oooooooooo03[ooooo0009ooooo`0400000?oooooooooooooooh@000001P0I6AT01@000000
<c<c03<c<`0c<c<000000080C4a<00D00000o`00001VIVH0IVIVo`00000507moO`?o0000101oOgl2
o`000080IVIV00@0000004a<C01<C4`000000P0c<c<00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo06kooooo0ol0000Eooooo`030:n4YP2fSZ`0]Xj/0080]Xj/00<0a9f`o`000034WK001Ooo
ool00ol0003oooooooooo`0iooooo`002Oooool01000003ooooooooooooooon3000000L06ATI00D0
000003<c<`0c<c<0<c<c0000000304a<C0050000001VIVH0IVIV06IVI_l000002@1oOgl2o`0000<0
IVIV00D0000004a<C01<C4`0C4a<0000000203<c<`03o`000?oooooooooo00;ooooo00<00000oooo
ooooool0K?ooool2o`0001Oooooo0`2_Q:H30;J>[080a9f`00?o00000=:W[?ooool00oooool00ol0
003oooooooooo`0iooooo`002Oooool01000003ooooooooooooooon2000000L06ATI00<0000003<c
<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00?o000007moO`1oOgl0101oOgl2
o`0000@0IVIV00D0000004a<C01<C4`0C4a<0000000203<c<`03o`00000I6AWooooo00?ooooo00<0
0000ooooooooool0JOooool3o`0001Oooooo00<0YGZS0:n4YP2_Q:H00P2_Q:H20;J>[080`9:W00@0
a9f`o`00003BYj`0dZN/1?ooool00ol0003oooooooooo`0hooooo`002Oooool01000003ooooooooo
oooooomP00000003o`0000000000000000L0000000?o00000000000000005000000801TI6@030000
000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000406IVIPKo0000101VIVH2000000<0
C4a<00Ko000003<c<`0c<c<0<c<co`00000I6AT4ooooo`0300000?oooooooooo06Oooooo0_l00005
ooooo`0408fViP1jT]h0NY;N07ZBgP80JG[A3_ooool30:EjX`<0[hBV00H0]Xj/0<2BY`30TZL0`9:W
0<BM/?l000020=:W[0Gooooo00?o0000ooooooooool0=oooool000Wooooo00@00000oooooooooooo
ooooG`00000<01TI6AD000002@0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<
C00000003@1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00?o000001TI
6Oooool00oooool00`00003oooooooooo`1Tooooo`?o00000_ooool0102S^NP0Vk;X09^bj02K/^P3
08fViP80NY;N0P1YN]4306=X`P[ooooo102UNZ<30:n4YP@0`9:W00D0dZN/o`00003BYj`0dZN/0>:g
Z`04ooooo`03o`000?oooooooooo03Oooooo0009ooooo`0400000?oooooooooooooooeD000006@0I
6ATA000000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV00T0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0203<c<`03o`00000I
6AWooooo00?ooooo00<00000ooooooooool0H_ooool2o`0000?ooooo00@0Yk_X0:>ij02S^NP0XkWX
0`2K/^P208fViP<0NY;N0P1YN]4206=X`P80JV2d1oooool00`2ILJ@0YGZS0:EjX`020:EjX`<0[hBV
00L0^8NR0<2BY`30TZL0`9:W0=:W[?l00000dZN/0080h[N[1Oooool00ol0003oooooooooo`0foooo
o`002Oooool01000003ooooooooooooooom;000002L06ATI3000000:01TI6@030000000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@04ooooo`0300000?oooooooooo
05oooooo0ol00002ooooo`80Z;cX0`2W^nP00`2S^NP0WkKY09nfj@0209:]j@<0Ni_V0P1KO]/206Uj
d@80HfS20P1ZH;@307UR[0<0RVRV0`2ILJ@40:EjX`030:n4YP2hQj80^8NR0080`9:W0P3>WJ@01?l0
0000h[N[0>:gZ`3R]j/6ooooo`03o`000?oooooooooo03Gooooo0009ooooo`0400000?oooooooooo
ooooodL00000<P0I6AT2000000`06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C004
04a<C003o`00001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`02
03<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0GOooool2o`0000?ooooo00<0ZKgX
0:Rlj02X_>P00P2X_>P00`2W^nP0YK[X09nfj@0309nfj@80TZgY0`1kVnH0101KO]/0@5k9041Nb@10
G/T206=X`P80JV2d0P1iHZ`308YXYP<0VG6T102UNZ<00`2_Q:H0^8NR0;R7XP020<2BY`80cYfT00Go
00000>:gZ`3R]j/0h[N[0?;<Z@05ooooo`03o`000?oooooooooo03Gooooo0009ooooo`0400000?oo
ooooooooooooobl00000200I6AT=000001P06ATI3`00000K01TI6@030000000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@04ooooo`0300000?oooooooooo05[ooooo
0ol00002ooooo`D0ZKgX0`2X_>P30:Fjj080WkKY00@0V[CY08RXjP28Z>X0R:SZ0P1TS^H01P0`I=D0
FgkK041Nb@10G/T0>d^h06=X`P80JV2d0`1iHZ`208YXYP<0VG6T102UNZ<40;R7XP040<2BY`3>WJ@0
cYfTo`000080h[N[0P3bc:T00`3kgjGoooooooooo`03ooooo`03o`000?oooooooooo03Cooooo0009
ooooo`0400000?ooooooooooooooob/000004`0I6AT2000000h06ATI3P00000?03<c<`<000005`0I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<0P00000806IVIP030000001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00P0c<c<01?l000006ATI01TI6@0I6AT4ooooo`030000
0?oooooooooo05Oooooo0ol00003ooooo`L0ZKgX102X_>P00`2U^^P0XkWX0:>ij00309Zdj@<0R:SZ
0P1TS^H00`0`I=D0@5k9041Nb@0203];^080JV2d0`1iHZ`308YXYP<0VG6T0P2UNZ<00`2/O:00^8NR
0;R7XP020;R7XP<0cYfT00?o00000>:gZ`3R]j/00P3bc:T00`3kgjD0n^^T0?[[Y004ooooo`03o`00
0?oooooooooo03?ooooo0009ooooo`0400000?ooooooooooooooobP000007`0I6AT00`00003o0000
0000000400000200<c<c00@00000o`000000000000004@0I6AT00ol00000000003<c<`0503<c<`03
0000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c0080<c<c00Co000001TI6@0I6AT06ATI1?ooool00`00003oooooooooo`1Eoooo
o`;o00000oooool;0:Vmj080Z;cX00<0Yk_X0:>ij02S^NP00P2S^NP00`2J]>T0U[7Y09Jaj@0207fR
j`80Bh7T00D0<6CE00@i^`04>K/0@5k903];^00204a:[P0306YP]01iHZ`0NF:/00<0RVRV0`2ILJ@0
0`2UNZ<0[7bP0:alX0040;R7XP<0cYfT00Co00000>:`X`3R]j/0l/bY0P3kgjD20?[[Y0050?K`[ooo
ooooooooooooool00000=Oooool000Wooooo00@00000oooooooooooooooo9@00000701TI6@/00000
3`0I6AT00`000000<c<c03<c<`0C03<c<`l000001`0c<c<2000000h06ATI00<0000003<c<`0c<c<0
1@0c<c<00`00003o000004a<C00604a<C0030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0203<c<`04o`00000I6AT06ATI01TI6@Cooooo00<00000oooooooo
ool0D_ooool3o`0000?ooooo302Y_NP30:Rli`80Yk_X0P2S^NP00`2Q]nP0U[7Y09Jaj@0209Jaj@80
OJ;[0P1;PN@00`00B<P013Vk00@i^`0203];^080C4Z^0`1iHZ`208YXYP80VG6T00<0Vg2Q0:alX02/
O:000P2/O:030;R7XP80cYfT00<0h[2So`00003R/:<00P3bc:T01P3kgjD0n^^T0?[[Y03jjj@0m_2_
0?3Z``?ooooo00?o0000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo90000006
01TI6@8000002`0c<c<7000000H06ATI0P00000503<c<a4000003`1<C4`3000000H0<c<c0P00000;
01TI6@030000000c<c<0<c<c00@0<c<c0P00000704a<C08000002`1VIVH00`000000C4a<04a<C003
04a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT01?ooool00`00003oooooooooo`1@
ooooo`;o00001?ooool<0:Vmj080ZKcW0P2X_>L00`2X^nL0Y[[W0:Jji`020:Jji`80XKOX0P2F/NT0
0`2C[NT0MYgZ07JMjP0303UhhP040018b004>K/002BZ03];^080C4Z^0`1XE:P208YXYP0309UaY02K
L:40Vg2Q00@0[7bP0P2hQj820<JCX@070<jMY03R/:?o00000>:`X`3fbil0l/bY0?_OY@020?[[Y003
0?K`[`3`j/<0l>[300?ooooo00?o0000ooooooooool0<_ooool000Wooooo00@00000oooooooooooo
oooo8`00000501TI6@8000001@0c<c<7000000P0<c<c1P00000403<c<`<00000501<C4`8000000L0
C4a<00<00000o`00000c<c<01@0c<c<2000000L06ATI0P00000603<c<`030000001<C4`0C4a<00D0
C4a<0P00000=06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<00P0c<c<00ol00000
6ATI01TI6@04ooooo`0300000?oooooooooo04gooooo0ol00003ooooo`X0ZKgX1P2Y_>L20:Vki`<0
Z;_W0P2V^^L00`2U]nH0WkCW09ndi`0409>]j@80MYgZ0P0iN>801000<[T013Vk000TZP009:X204a:
[P<0J5BX0P24Hj@409]`X@<0[7bP00L0^8NR0<JCX@36Tj40aY>Q0<jMY03R/:?o00000080m/^O00@0
o^6D0?_OY@3jjj@0m_2_0P3`j/<20>7Cb@?ooooo00?o0000ooooooooool0<Oooool000Wooooo00@0
0000oooooooooooooooo8@0000000ol000006ATI01TI6@0301TI6@040000000c<c<0<c<c03<c<`@0
00001`1<C4`01?l00000000000000000000<03<c<`8000001P1<C4`<00000003o`00000000000000
00800000201VIVH300000003o`00001<C4`0C4a<00<0C4a<0P00000603<c<`03o`00000000000000
0080000000?o00000000000c<c<01P0c<c<00`00003o000004a<C00404a<C0800000401VIVH00ol0
0000C4a<04a<C00304a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT01?ooool00`00
003oooooooooo`1;ooooo`;o00001?ooool:0:Vmj0H0ZKcW00<0ZK_V0:Vki`2Y^nL00P2Y^nL00`2X
^nL0YkSU0:Nhi@030:FgiP80WkCW0P2C[NT0102AZNH0MI[X07FJj01eV^P203Mfh@05000b^@04>K/0
02BZ000TZP1<BZh00`1XE:P208ASY0@0Vg2Q0`2/O:00102hQj80aY>Q0<JCX@36Tj420>:`X`08o`00
003fbil0m/^O0?kQU03aihD0jnf=0??c/@3`j/<30>7Cb@Cooooo00?o0000ooooooooool0<?ooool0
00Wooooo00@00000oooooooooooooooo8P00000301TI6@0400000?l00000<c<c03<c<`800000101<
C4`8000000<0C4a<1000000603<c<`8000001@1<C4`300000140IVIV2000000406IVIP<00000101<
C4`200000140<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0@06IVIP800000101<
C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0B?oo
ool3o`0000?ooooo2P2Y_NP20:Vmi`D0ZKcW102Y^nH20:Vki`030:Rhi@2W^>D0YkSU0080YkSU00<0
YKOV0:Bch`2N/>@00P2N/>@3096YiP<0MI[X00<0=gKQ000^]P003Ih00P009:X204a:[P80J5BX0`24
Hj@309]`X@<0[7bP1036Tj420>:`X`08o`00003fbil0m/^O0?kQU03aihD0jnf=0??c/@3Zg<D30>7C
b@050=:la?ooooooooooooooool00000<_ooool000Wooooo00@00000oooooooooooooooo8@000003
01TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`3000000P0IVIV0`00000404a<C0H000000`1<
C4`4000000<0IVIV4@00000807moO`@000000`1VIVH00`00003o000004a<C00304a<C0030000000c
<c<0<c<c00`0<c<c0P00000504a<C0800000101VIVH;o`0000H0IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AWooooo00?ooooo00<00000ooooooooool0AOoo
ool3o`0000;ooooo302Y_NP50:Vmi`030:Vli`2Y^nH0ZK_V00@0ZK_V0P2Y^>@30:Rhi@80YkSU00@0
Yk?R0:Bch`2T/n<0Y;?S0`2N/>@00`2AZNH0T:CR07RFh`0207RFh`80AW[P00D002jf000TZP009:X0
6BbW04a:[P0206QDZ0<0Q6>T0`2KL:430:alX00;0;R7XP36Tj40aY>Q0<JCX@3LZJ80h[2So`00003f
bil0o^6D0?7WQ@3[kHd00P3clk420>[La@030>7Cb@3B_<@0d[c400Cooooo00?o0000ooooooooool0
;oooool000Wooooo00@00000oooooooooooooooo8000000301TI6@050000000c<c<0<c<c03<c<`00
00000P1<C4`200000080IVIV1P0000000ol0000000000000000306IVIP03o`0000000000000000L0
C4a<0`00000306IVIP@000004@1oOgl8000000@0Ogmo00?o00000000000000000P1VIVH00`000000
C4a<04a<C00204a<C003o`00000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`00`1<C4`2000000@0
IVIV0_l0000;07moO`;o00001@1VIVH01P000000C4a<04a<C01<C4co0000000000@0<c<c00?o0000
ooooooooool00_ooool00`00003oooooooooo`13ooooo`;o00000_ooool>0:Vmj0D0ZKgW00<0ZK_W
0:VkiP2Y^nH00`2Y^nH50:Vhi0030:Rhi@2X/n40Yk?R00<0Yk?R00<0Y;?S0:>/gP2S[=h00P2LZ^03
092ThP<0N9KS00<0AW[P0011a00007T00P009:X0100I;:L0J5BX06QDZ01XE:P208ASY0@0Vg2Q00<0
[7bP0;R7XP2hQj800P36Tj420=bYXP070>:`Xol00000m/^O0?kQU03aihD0jnf=0??c/@030>[La@<0
d[c400<0bjjmooooooooool00_ooool00ol0003oooooooooo`0^ooooo`002Oooool01000003ooooo
oooooooooolP000000<06ATI00@0000003<c<`0c<c?o00000P1<C4`01_l00000IVIV06IVIP00003o
000007moO`@00000101oOgl2000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0206IVIP0300000?l00000Ogmo01@00000202IVIT4000000<0Ogmo00@0000006IVIP1VIVH00000
101<C4`2000000T0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP;o0000
3P1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
0P0c<c<00ol0003oooooooooo`02ooooo`0300000?oooooooooo043ooooo0ol00002oooooa40ZKgX
00<0ZKgW0:Vli`2Y_>L00`2Y^nL20:VkiPH0ZKST00@0Z;;O0:Rch@2X/n40Z;?Q0P2W/n800`2V[=/0
XjcN0:>/gP020:>/gP80W:[P00<0T:CR092Lf`1mTM`00P1mTM`205anf`050011a00007T002BZ01T/
Y`1<AZT00P1XE:P208ASY0@0Vg2Q00<0[7bP0;R7XP2hQj800P36Tj420=bYXP070?K;X?l00000m/^O
0?kQU03aihD0jnf=0??c/@020>[La@80e[c000<0d[c40<^^_@3;[[d01?ooool00ol0003ooooooooo
o`0^ooooo`002Oooool01000003ooooooooooooooolO000000<06ATI00P0000003<c<`0c<c<0<c<c
0000001<C4`0000006IVIPD00000102IVIT400000080Ogmo0P00000306IVIPD000000`1VIVH20000
0080Ogmo00<0000009VIV@2IVIT04P2IVIT8o`0000@0VIVI00D0000007moO`1oOgl0Ogmo00000002
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<2000000D0C4a<00<00000
06IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0507moO`Co00001P1oOgl00ol00000IVIV06IVIP02
06IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<01Ol0003ooooooooooooo
ool00000043ooooo0_l00003oooooa80ZKgX1@2Y_>L00`2Y^nL0Z;ST0:Rhi0040:Vhi080Z;7O0`2X
/]l00`2X/n40Yj[I0:NZf@030:J/f`80XjcN00<0XZ?F09^RfP2KX]X00`2@W=/307fAg080G7kK00H0
85cB0000Q`0I;:L06BbW04a6Z@1XE:P308ASY080Vg2Q00<0XGRU0;R7XP2hQj800P2hQj802`36Tj40
g:VR0=bYXP3fbj3o00000?kQU03aihD0`]QU0>CdW03^iLD0j]c500<0e[c00`3;[[d5ooooo`03o`00
0?oooooooooo02gooooo0009ooooo`0400000?oooooooooooooooal000000`0I6AT02P000000<c<c
03<c<`000000C4a<0000001VIVH0000007moO`00000309VIV@Oo000000<0VIVI0000000000000P1o
Ogl2000000P0IVIV00D0000007moO`1oOgl0Ogmo0000000409VIVA7o0000202c/k<3o`000080VIVI
00@0000007moO`1oOgl000000`1VIVH00`000000C4a<04a<C00304a<C0<000000P0c<c<00`000000
C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV0_l0000507moO`?o0000102IVIT3o`0000@0
Ogmo00?o000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0000000@0<c<c1?ooool00`00
003oooooooooo`0kooooo`?o00000_oooolC0:Vmj0H0ZKcW0P2X^ND30:Rhi0030:Vhi02X/Ml0Z;7O
00<0Z;7O00<0Z;;O0:NXeP2WZ]T00`2WZ]T00`2V[=/0YZ;B0::SeP030::SeP80Vj;J0`2@W=/207fA
g0<0G7kK00<085cB01T/Y`0I;:L00P1<AZT308ASY00309]`X@2QN:D0XGRU00@0^8NR0`3LZJ801`3f
bj3o00000?[URP3CfVD0`]QU0>CdW03^iLD00`3F_<020<bZ^080bjjm00<0bjZhooooooooool00ooo
ool00ol0003oooooooooo`0/ooooo`002Oooool01000003ooooooooooooooolN000000<06ATI00/0
000003<c<`0c<c<0000004a<C0000000IVIVo`00001oOgl0000009VIV@0<o`00000309VIV@000000
00000080Ogmo00?o0000000000000000100000001Ol00000Ogmo07moO`00003o00000080VIVI0ol0
000A0;>c/`So00000`2c/k<00ol00000VIVI09VIV@020000000307moO`000000IVIV0080IVIV00<0
000004a<C01<C4`01@1<C4`2000000H0C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07mo
O`0207moO`?o00002P2IVIT00ol00000Ogmo07moO`0207moO`03o`00001VIVH0IVIV0080IVIV00D0
000004a<C01<C4`0C4a<o`00000303<c<`Cooooo00<00000ooooooooool0>Oooool2o`0000?ooooo
402Y_NP60:Vli`80ZK[V102X^ND20:Nbh080Yk7O1@2X/Ml0102WY]D0YjSF0:NXeP2WZ=H20:NZf@04
0:NNc@2VX]80YZ;B0:JRdP<0XZ?F00<0Vj;J09ZId@2?Tm@00P2?Tm@2082:e0<0K7gB00<0Cfc@0000
S`0I;:L00P1<AZT307iRZ0<0XGRU102hQj820=bYXP80m/^P00Co00000?[URP32f6D0i?BL0P3^iLD0
0`3F^kl0e[c00<bZ^0020<bZ^0040<^^_@3;Z[P0bjZh0<^Z^0Cooooo00?o0000ooooooooool0;?oo
ool000Wooooo00@00000oooooooooooooooo7P00000301TI6@0<0000000c<c<0<c<c0000001<C4`0
000006IVIP00003o000009VIVOl00000/k>c0_l000070<c<c003o`00002c/k?o00000080VIVI00<0
000007moO`1oOgl01`1oOgl2000000<0VIVI00Co00000;>c/`2c/k<0/k>c4Ol000080<c<c0;o0000
0P2c/k<01?l00000VIVI09VIV@2IVIT2000000<0IVIV00<0000004a<C01<C4`0301<C4`00`000000
IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT0302IVIT2o`0000<0
Ogmo00Go000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0<c<c00Cooooo00<00000oooo
ooooool0=_ooool3o`0000?ooooo402Y_NP60:Vli`D0ZK[V00<0Z;WU0:Nch@2W/^000`2W/^020:Na
g`030:Rag`2VYMD0YZGE00<0YjKE00<0YjSF0:JJb@2WW/d00`2WW/d20:JRdP80XZ?F00@0XY[<09ZI
d@2JVM40VYWA0`2?Tm@2082:e0<0K7gB00<000270000S`0I;:L00P1<AZT207iRZ0@0XGRU0`2hQj82
0=bYXP80m/^P00Go00000<;HI@32f6D0jN_>0>kUa@020=Jk_`@0c:Zh103;Z[P5ooooo`03o`000?oo
oooooooo02_ooooo0009ooooo`0400000?oooooooooooooooad000000`0I6AT03@000000<c<c03<c
<`000000C4a<0000001VIVH0000007moO`00003o00000;>c/ol000000P3<c<`6o`000080c<c<00?o
00000;>c/ol000000P2IVIT00`000000Ogmo07moO`0607moO`050000002IVIT0VIVI09VIVOl00000
0P2c/k<2o`0001/0c<c<00Co00000;>c/`2c/k?o00000P2IVIT00`000000Ogmo0000000306IVIP03
0000001<C4`0C4a<00X0C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`03
o`00002IVIT0VIVI0080VIVI1ol0000609VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH01@00
0000C4a<04a<C01<C4`000000080<c<c1?ooool00`00003oooooooooo`0cooooo`?o00001?ooool?
0:Vmj080ZKgW102Y_>L20:VkiPD0ZK[V00@0YkCR0:Nch@2W/n40Yk?Q0P2W/^000`2TY]L0YJGF0:FU
eP040:JUe@030:NVe@2TUlL0YY[90080YY[90`2WW/d00`2VX]80YYO60:JGaP030::Jc0<0VYWA0P2?
Tm@3082:e080K7gB00<0Cfc@0000S`0008l00P1<AZT207iRZ0@0XGRU0P2hQj820<jPY`050=bYXP3f
bj00m/^Po`00000000000P3Yjlh30=Jk_`050<VU]@3<Z[P0c:Zh0<bZ^03:Y;<00P3;Z[P20<n/]@Co
oooo00?o0000ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo7@00000301TI6@0=
0000000c<c<0000004a<C0000000IVIV0000001oOgl00000o`00002c/k?o00000<c<c002o`0000H0
i^KV00Ko00000<c<c03<c<co00000;>c/ol0000209VIV@03o`00001oOgl0Ogmo00@0Ogmo00D00000
09VIV@2IVIT0VIVIo`0000020;>c/`03o`00003<c<`0c<c<01`0c<c<00Co00000;>c/`2c/k?o0000
0P2IVIT00`000000Ogmo0000000306IVIP030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH0
0P1VIVH01?l00000Ogmo07moO`1oOgl2o`0000<0VIVI0_l000070;>c/`?o0000102IVIT01Ol00000
Ogmo07moO`1oOgoo00000080IVIV00?o00000000001<C4`00P1<C4`00`000000<c<cooooo`03oooo
o`0300000?oooooooooo037ooooo0_l00004oooooa80ZKgX0`2Y_NL00`2Y_>L0ZK_V0:VkiP030:Vk
iP030:VjiP2X]N80Z;GR00<0YkCR00<0Yk?Q0:BXf@2TY]L00`2TY]L20:FUeP80YZGE00@0XYC70:BG
a`2TUlL0Y9O70`2VV/T00`2WW/d0Yi:o0:JGaP030:JGaP030::Jc02STL80VI790080VI790P2=Rld3
07n2c080LWO900D0Ifk60000S`0008l03Bb/04a6Z@0307iRZ0<0XGRU00@0^8NR0<jPY`3>X:L0cZ2W
0P3fbj00103jiHX00000o`00003Yjlh20=2g`@050=Jk_`39YKD0bJFe0<VU]@3<Z[P00P3:Y;<0103;
Z[P0cjbe0<n/]@3?[;D5ooooo`03o`000?oooooooooo02[ooooo0009ooooo`0400000?oooooooooo
oooooad000000`0I6AT03P000000<c<c0000001<C4`0000006IVI_l00000Ogmo00000?l00000/k>c
o`00003<c<co00000P3Vi^H3o`0000<0i^KV00?o00000<c<c?l000000P2c/k<00ol00000VIVI09VI
V@02000000@0Ogmo00D0000009VIV@2IVIT0VIVIo`0000020;>c/`03o`00003<c<`0c<c<01<0c<c<
1?l000050<c<c004o`00002c/k<0/k>co`000080VIVI00<0000007moO`0000000`1VIVH00`000000
C4a<04a<C00704a<C003o`00001VIVH0IVIV00<0IVIV00Go000007moO`1oOgl0Ogmoo`00000309VI
V@03o`00002c/k<0/k>c00X0/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`05o`00001VIVH0
IVIV06IVIP0000000`1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo02kooooo0ol0
0002oooooaL0ZKgX00<0ZKgW0:Vki`2Y^nH0102Y^nH00`2X]^<0Z;GR0:RehP020:RehP030:NdhP2U
ZMX0Y:SI0080Y:SI0`2TY]L00`2UYMH0X9C80::Da`030::Da`80Y9O70P2VV/T0102US;/0Yi:o0:NB
_`2WT[l20:JGaP040:R>^P2STL80Xi720:>A`P<0VI790P2=Rld307n2c004079gb@1WK/H0Ifk60000
S`803Bb/00<0C4JY07iRZ01nHZP00`2QN:D0102hQj80cZ2W0<jPY`3>X:L20?K;X0030?[URP3Fj>?o
000000<0d;O100@0e[^o0<VU]@39YKD0bJFe0`3:Y;<40<n/]@030=Nb]?oooooooooo00?ooooo00?o
0000ooooooooool0:Oooool000Wooooo00@00000oooooooooooooooo7@00000301TI6@0@0000000c
<c<0000004a<C0000000IVIV0000001oOgl00000o`00002c/k?o00000<c<c?l00000i^KVo`0000<0
oooo0_l000020>KViP05o`00003<c<co00000;>c/ol00000102IVIT20000000307moO`000000VIVI
00<0VIVI00Co00000;>c/`2c/k?o0000103<c<`4o`0000`0c<c<00?o00000>KViP3Vi^H00P3Vi^H0
0ol00000c<c<0<c<c0020<c<c004o`00002c/k<0/k>co`000080VIVI00<0000007moO`0000000`1V
IVH00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV0080IVIV00Go000007moO`1oOgl0Ogmo
o`00000309VIV@03o`00002c/k<0/k>c00`0/k>c00Co000009VIV@2IVIWo0000101oOgl01?l00000
IVIV06IVIP00000304a<C0030000000c<c?ooooo00?ooooo00<00000ooooooooool0;?ooool2o`00
00?ooooo602Y_NP20:Vli`80ZK_W0P2Y^nH0102X]n<0Z;KS0:Rfh`2X]^<20:RehP040:F[fP2UZMX0
YJWJ0:FYfP<0Y:SI00<0Y:KG09nEbP2PU<P00P2PU<P30::Da`030:BGa`2RR;P0YHbk00<0YHbk0P2W
T[l00`2VUlH0Z8jj0:R>^P030:>A`P<0VI790P2=Rld307n2c080LWO90P1WK/H00`0008l03Bb/00d/
[00207iRZ080XGRU00<0/Hnb0<jPY`3>X:L00P3>X:L01@3acjh0m/^P0=KXh`3Fj>?o000000<0d;O1
1039YKD30<ZT/`030<jV/03?[;D0cjbe0080ek:d1Oooool00ol0003oooooooooo`0Yooooo`002Ooo
ool01000003ooooooooooooooolM000000806ATI00D0000003<c<`0c<c<0000004a<C00200000009
07moO`00003o00000;>c/ol00000c<c<o`00003Vi^Ko000000D0oooo00Ko00000>KViP3Vi^Ko0000
0<c<c?l000020;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000009VIV@2IVIT00P2IVIT01?l00000
/k>c0;>c/ol000050<c<c005o`00003Vi^H0i^KV0>KVi_l000002P3<c<`00ol00000i^KV0>KViP04
0>KViP03o`00003<c<`0c<c<0080c<c<00Ko00000;>c/`2c/k?o000009VIV@00000207moO`050000
001VIVH0IVIV06IVIP0000001`1<C4`00`000000IVIV06IVIP0306IVIP05o`00001oOgl0Ogmo07mo
Ool000000P2IVIT00ol00000/k>c0;>c/`050;>c/`Co00001@2c/k<01?l00000VIVI09VIVOl00003
07moO`05o`00001VIVH0IVIV06IVIP0000000`1<C4`00`00003oooooooooo`02ooooo`0300000?oo
oooooooo02Wooooo0ol00002oooooaH0ZKgX1P2Y_>L00`2X^ND0Z;ST0:Rhi0020:Rhi080Z;OS00<0
Z;KS0:J/f`2V[=/00`2UZmX00`2UZMX0X9S<09nGc00209nGc0<0WiG:0`2PU<P00`2RU<L0WHBh0::8
^0020::8^0<0YHbk00<0Yi:o0:R9/`2XS[X00`2XS[X20:>A`P<0VX_20P2:Q<L307]iaP80LG320P1W
K/H00`0008l03Bb/00d/[002079Y^P030:5hY@2aSk80/Hnb00<0cZ2W0P3acjh0103Vk8T0e^SS0<:/
a?l000030=2g`@030<>O/`39YKD0bJFe0080aij_00D0bZBc0<jV/03>Y[00cZJ`0<n/]@020=Nb]0Ko
oooo00?o0000ooooooooool0:?ooool000Wooooo00@00000oooooooooooooooo7@00000201TI6@05
0000000c<c<0<c<c0000001<C4`00P000000101oOgl00000o`00002c/k<2o`0000030>KVi_l00000
oooo00H0oooo00So00000>KViP3Vi^Ko00000<c<c?l00000/k>co`0000@0VIVI0P00000409VIV@04
o`00002c/k<0/k>co`0000@0c<c<00?o00000>KViP3Vi^H00P3Vi^H2o`0000P0c<c<0_l000060>KV
iP;o00000`3<c<`01_l00000/k>c0;>c/ol00000VIVI00000080Ogmo00D0000006IVIP1VIVH0IVIV
0000000704a<C0030000001VIVH0IVIV0080IVIV00Go000007moO`1oOgl0Ogmoo`00000209VIV@03
o`00002c/k<0/k>c00<0/k>c0ol000040<c<c003o`00002c/k<0/k>c00<0/k>c00Co000009VIV@2I
VIWo00000`1oOgl01?l00000IVIV06IVIP00000304a<C00300000?oooooooooo00;ooooo00<00000
ooooooooool09oooool2o`0000?ooooo5P2Y_NP60:Vli`040:RjiP2X^ND0Z;WU0:Rii@80Z;ST00<0
YZoN0:J]g02V[M`0102V[=/00`2UZmX0XIW=0:2Hc0020:2Hc0<0WiO<0P2OULX20:2Db00309Z3^@2M
Q;P0WHBh00<0XXRh0`2US;/30:R9/`<0Z8jj00<0Xi720:J=^P2VSKX00`2JRl8208Z4a`80NgW60P1a
L<8306iZ_P803Bb/0P1bJKX40;6?/P050<jPY`3acjh0lLn^0?7?[P0000000P32[<@00ol00000`Zc4
0=2g`@020<>O/`050<VU]@37WZl0aij_0<NN[`3:Y;<00`3>Y[030=Nb]0030>2m]?oooooooooo00Co
oooo00?o0000ooooooooool09oooool000Wooooo00@00000oooooooooooooooo7@00000201TI6@05
0000000c<c<0<c<c0000001<C4`00P000000101oOgl00000o`00002c/k<2o`0000030>KVi_l00000
oooo00H0oooo00So00000>KViP3Vi^Ko00000<c<c?l00000/k>co`0000<0VIVI00@0000007moO`1o
Ogl000000`2IVIT01?l00000/k>c0;>c/ol000050<c<c0Co0000303<c<`00ol00000i^KV0>KViP02
0>KViP03o`00003<c<`0c<c<00<0c<c<00Ko00000;>c/`2c/k?o000009VIV@00000207moO`050000
001VIVH0IVIV06IVIP0000001`1<C4`00`000000IVIV06IVIP0206IVIP04o`00001oOgl0Ogmoo`00
00<0VIVI00?o00000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0060<c<c003o`00002c/k<0/k>c
0080/k>c00Co000009VIV@2IVIWo00000`1oOgl01?l00000IVIV06IVIP00000304a<C00300000?oo
oooooooo00;ooooo00<00000ooooooooool09?ooool3o`0000?ooooo5P2Y_NP50:Vli`80ZK[V0`2X
^^H00`2X^ND0Y[7P0:Jah0030:J_gP80YZgL0P2V[=/0102QVlh0XIW=0:6Ic@2QVLd30:2Hc00409nG
c02HQ;`0V8>k09R3^`<0VX>i0`2MQ;P30::8^0030:F<^`2UPjl0Z8Vc0080Z8Vc0`2XS[X30:J=^P<0
VX_20`2:Q<L207]iaP80LG320P1^J[h00`1_JK/03Bb/00d/[002079Y^P<0/Hnb00@0cZ2W0?7?[P3a
cjh0i^b90P2]Vl@00`32[<Co00000;VF/`030<>O/`@0aij_103>Y[00103F[Zl0ek:d0>2m]03P_K@6
ooooo`03o`000?oooooooooo02Oooooo0009ooooo`0400000?oooooooooooooooad000000`0I6AT0
1P000000<c<c0000001<C4`0000006IVIP80000000L0VIVIo`000?l00000c<c<o`00003Vi^Ko0000
00D0oooo00So00000>KViP3Vi^Ko00000<c<c?l00000/k>co`0000<0VIVI00<0000007moO`1oOgl0
0P1oOgl01@000000VIVI09VIV@2IVIWo00000080/k>c00?o00000<c<c03<c<`04`3<c<`4o`0000D0
c<c<00Co00000;>c/`2c/k?o00000P2IVIT010000000Ogmo07moO`00000306IVIP030000001<C4`0
C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0VIVI00Go
00000;>c/`2c/k<0/k>co`00000:0<c<c003o`00002c/k<0/k>c0080/k>c00Co000009VIV@2IVIWo
00000`1oOgl01?l00000IVIV06IVIP00000304a<C00500000?ooooooooooooooo`0000009?ooool2
o`0000Cooooo5@2Y_NP60:Vli`80ZK_V0`2Y^^H00`2X^^H0YkCR0:NdhP030:Jah0030:J_gP2QWm<0
XIc@0080XIc@0`2QVlh20:6Ic@80X9S<00<0VXFl09R4_02HQ;`00P2HPk/409Z3^@80WHBh0P2RR;P0
102POJ`0YH>_0:F3[`2UPjl30:R9/`030:R>^P2/R[80YXfj00<0YXfj00<0VX_209b9_P27Ol<00P27
Ol<207=a`P80LG320P1^J[h206mY^`0300d/[01bJKX0LVVj00<0/Hnb00@0eM7E0?7?[P3acjh0i^b9
0P2]Vl@01032[<Co00000;VF/`2iU[<20<>O/`040<6H[@37WZl0aij_0<NN[`<0cZJ`0P3F[Zl0103G
/[@0h;fd0>2m]03Zb[@6ooooo`03o`000?oooooooooo02Kooooo0009ooooo`0400000?oooooooooo
oooooad000000`0I6AT01P000000<c<c0000001<C4`0000006IVIP80000000H0VIVIo`000?l00000
c<c<o`00003Vi^H2o`0000@0oooo00So00000>KViP3Vi^Ko00000<c<c?l00000/k>co`000080VIVI
00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@02o`000080/k>c0_l0000L0<c<c004o`00
002c/k<0/k>co`000080VIVI00@0000007moO`1oOgl000000`1VIVH00`000000C4a<04a<C00404a<
C0030000001VIVH0IVIV0080IVIV00Co000007moO`1oOgoo00000`2IVIT01Ol00000/k>c0;>c/`2c
/k?o000000`0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@05o`00001oOgl0Ogmo07moOol0
00000P1VIVH01@000000C4a<04a<C01<C4`0000000?ooooo00<00000ooooooooool07oooool3o`00
0003ooooo`2Y_NP0ZKgX01H0ZKgX1P2Y_>L50:VkiP030:VjiP2W]^<0YkCR00<0YkCR00<0Y[7P0:6T
e`2QWm<00P2QWm<30:6Ld080XI_>00<0XIW=09^6_02JQK`00P2JQK`309R4_080V8>k0`2JPkT00`2M
Q;P0VWR/0:1m[0020:1m[0<0YH>_0P2XRK<0102/QJ/0[8Zb0:b:/P2/R[820:J=^P030:b=]@2LRKh0
W8Vn00<0Qgo30P1cLL8306]X_@80KVZn0P1_JK/2079Y^P<0/Hnb0P3EdMD01P3acjh0[I_40:fKa02]
Vl@0^IJco`000080^IJc00<0`inc0<6H[@31V:d00P37WZl20<^P[@040<jV/03F[Zl0eZj_0=J^[`80
h;fd0P3Zb[@00`3bf;Goooooooooo`04ooooo`03o`000?oooooooooo02Gooooo0009ooooo`040000
0?oooooooooooooooad000000`0I6AT02@000000<c<c0000001<C4`0000006IVI_l00000000009VI
V@02o`000080c<c<0_l000000`3Vi^Ko0000o`000003o`0000070>KVi_l00000c<c<0<c<c?l00000
/k>co`00000209VIV@030000001oOgl0Ogmo00@0Ogmo00?o00000000002IVIT00P2IVIT01?l00000
/k>c0;>c/`2c/k<2o`0000D0c<c<2?l0000<0<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT0
10000000Ogmo07moO`00000306IVIP030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1V
IVH01?l00000Ogmo07moOol0000309VIV@05o`00002c/k<0/k>c0;>c/ol00000303<c<`01Ol00000
/k>c0;>c/`2c/k?o00000080VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP050000001<C4`0
C4a<04a<C00000000oooool00`00003oooooooooo`0Looooo`?o00000_oooolH0:Vmj080ZKgW0P2Y
_>L40:VjiP030:VkiP2Y]N80ZKGR00<0Z;KS0P2W]^<20:NdhP040:>XfP2QY=L0XJCG0:6Te`80XIoC
0P2QW=000`2JR;l0VhNm09^7_@0309^6_0<0VXFl0P2HQ;`209R3^`80VX>i00<0UGF]09Yh[02JN:`0
102POJ`20:F3[`030:R9/`2/QJ/0[8F[00<0[8Zb00<0YXfj0:b=]@2/SKD00`2LRKh308Mo``0407=a
`P1[J;d0JfRm06]X_@80JfBi0P1_JK/303>1j0040;6?/P3EdMD0eM7E0=GAe@80UXS200@0[I_40:^;
/`2iU[?o00000P2iU[<40<6H[@040<NN[`3;X:d0bj2]0<jV/0<0eZj_00H0hKV_0>2m]03Zb[@0j/Zd
0?;H]@3gi[@5ooooo`03o`000?oooooooooo02Gooooo0009ooooo`0400000?oooooooooooooooad0
00000`0I6AT030000000<c<c0000001<C4`0000006IVIP000000Ogmo00000?l00000/k>co`0000<0
c<c<00?o00000>KViP3Vi^H00`3Vi^H01_l00000c<c<0<c<c?l00000/k>co`000080VIVI00<00000
07moO`1oOgl01`1oOgl200000080VIVI00?o00000;>c/`2c/k<00P2c/k<5o`0000P0/k>c0ol00006
0<c<c0?o00000`2c/k<01?l00000VIVI09VIV@00000207moO`050000001VIVH0IVIV06IVIP000000
1`1<C4`00`000000IVIV06IVIP0206IVIP04o`00001oOgl0Ogmoo`0000<0VIVI00Go00000;>c/`2c
/k<0/k>co`00000<0<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01Ol00000Ogmo07moO`1o
Ogoo00000080IVIV00D0000004a<C01<C4`0C4a<00000003ooooo`0300000?oooooooooo01[ooooo
0_l00003oooooaL0ZKgX102Y_NL20:VkiP@0ZK[V0P2Y]N430:VehP030:Rfh`2WZmX0YJ_K0080YJ_K
0`2SZ=X20:6Te`030:6Od`2IRl@0VXRo0080VXRo0`2KQkd209^6_0<0VXFl0P2HQ;`00`2HPk/0TWB^
09Ee[@0209Ee[@80VWR/102POJ`20:F3[`@0[8F[0P2/R[840:b=]@80W8Vn0`27Ol<207=a`P80JfRm
0P1[I;T307=V]@80<h7X0`3EdMD209J8`P0709ao/`2[Rk<0Zh^c0:^;/ol00000^IJc0;R@[@040<6H
[@<0bj2]0`3F[Zl20>6i[`060>2m]03Zb[@0l]Re0?;H]@3gi[@0m_2d1Oooool00ol0003ooooooooo
o`0Tooooo`002Oooool01000003ooooooooooooooolM000000<06ATI00<0000003<c<`0000000P1<
C4`01@000000IVIV00000000003o00000080/k>c00Co00000<c<c03<c<`0c<c<1Ol000020<c<c003
o`00002c/k?o00000080VIVI00@0000007moO`1oOgl0Ogmo1@00000407moO`030000002IVIT0VIVI
00?o00004@2c/k<6o`0000D0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`050000001VIVH0
IVIV06IVI_l000001`1<C4`00`000000IVIV06IVIP0206IVIP04o`00001oOgl0Ogmoo`0000<0VIVI
00Go00000;>c/`2c/k<0/k>co`00000=0<c<c004o`00002c/k<0/k>co`0000<0VIVI00Co000007mo
O`1oOgoo00000P1VIVH01@000000C4a<04a<C01<C4`0000000?ooooo00<00000ooooooooool05ooo
ool3o`0000?ooooo6P2Y_NP00`2Y_NL0ZK_W0:Vki`030:VkiP030:VjiP2X]>40ZKGQ00<0ZKGQ00<0
ZKGR0:NZf02WZmX00P2WZmX30:F[f`040:>XfP2KU/h0VI3909V@b@<0VH_40`2JR;l209^7_@<0VhJl
00@0VXFl09Af[P2BMJh0TWF^0`2BM:h209Ee[@<0VWR/0`2POJ`00`2UPjl0YgjW0:MnY`030:b5Z`03
0:b:/P2bRjd0/X^]00<0[8fe00<0W8Vn0:2<_P23O<@00P23O<@206UZ`@<0JfRm0P1[I;T207=V]@80
OVbd00<0S7Bc0=GAe@2<M;<00`2LOk<20:^;/`;o00000`2hT:d30<6H[@<0bj2]00<0djR/0=J^[`3F
[Zl00P3Q^Jl00`3/b:l0j/Zd0?;H]@020?OV]0030?K`]03am[L0kOS000Cooooo00?o0000oooooooo
ool08oooool000Wooooo00@00000oooooooooooooooo7@00000301TI6@0:0000000c<c<0<c<c0000
001<C4`0000006IVIP000000Ogmo000000Ko00001@3<c<`2o`0000030;>c/ol00000VIVI00800000
00@0Ogmo00000000000000001@1VIVH200000080Ogmo00?o00000000000000000`2IVITAo`0000T0
/k>c0_l0000209VIV@8000000P1oOgl01@000000IVIV06IVIP1VIVH0000000P0C4a<00<0000006IV
IP1VIVH00P1VIVH01?l00000Ogmo07moOol0000309VIV@05o`00002c/k<0/k>c0;>c/ol000003@3<
c<`01?l00000/k>c0;>c/ol0000309VIV@04o`00001oOgl0Ogmoo`000080IVIV00D0000004a<C01<
C4`0C4a<00000003ooooo`0300000?oooooooooo01Kooooo0_l00003oooooa/0ZKgX00<0ZKcW0:Vk
i`2Y^nL00P2Y^nL00`2Y^nH0Z;GR0:Rdh@020:Rdh@80ZKGQ00H0YjSG0:NZf02WZ]P0Yj[H0:N[fP2S
V/`309nJc`<0ViK>0P2IT<T209V;a0<0VXRo00<0VhNm09Ef[P2FMjh00P2FMjh209Af[P80TWF^0`2B
M:h309Ee[@80VWR/0P2POJ`0102QN:D0YgjW0:MnY`2WOZL30:b5Z`<0/X^]0`2/SKD30:2<_P80Pgc4
0P1YJ/4305iO^`80JfBi0P1cI[D307i/]080S7Bc0P2LOk<3o`0000030:^;/ol00000^92]0080^92]
0P31V:d20<FJZ`050<^P[@3CZ:`0djR/0=>X[03F[Zl00P3Q^Jl0103/b:l0l]Re0?;H]@3gi[@20?K`
]0030?7f]`3]n<00jOG=00?ooooo00?o0000ooooooooool08oooool000Wooooo00@00000oooooooo
oooooooo7@00000301TI6@040000000c<c<0<c<c00000080C4a<00?o00000000001oOgl00P1oOgl0
1@000000VIVIo`000?l00000/k>c00Go000000<0/k>co`000?l000000P00000207moO`030000001V
IVH0IVIV00P0IVIV0P00000307moO`L000003@2IVIT9o`00000409VIV@0000000000000000<0Ogmo
00D0000006IVIP1VIVH0IVIV0000000904a<C0030000001VIVH0IVIV0080IVIV00Co000007moO`1o
Ogoo00000`2IVIT01Ol00000/k>c0;>c/`2c/k?o000000d0c<c<00Co00000;>c/`2c/k?o00000`2I
VIT01?l00000Ogmo07moOol0000206IVIP050000001<C4`0C4a<04a<C00000000oooool00`00003o
ooooooooo`0Fooooo`03o`00002Y_NP0ZKgX01/0ZKgX102Y_>L20:Vki`80Z;OT0P2X]N800`2X]>40
YZOG0:JWe`030:NXe`030:NZf02UV<P0Xi[<0080Xi[<0`2OV/l209^FcP80VI390`2IRl@0102JR;l0
TWJ`09Ef[P2EMZh309Ig[P<0U7J^0P2BMJh2099d[P<0UGF]0P2JN:`00`2POJ`0XGRU0:5hY@030:Mn
Y`<0[8F[102bRjd00`2/SKD0]9:d0;BB]0030:2<_P80Pgc40P1YJ/4205iO^`80HUfg0`1cI[D207i/
]00408ad/ol0003o0000o`000080W7nc0P2[Rk<01@2]Qjgo00000;R@[@2hT:d0`IR]00<0aIZ[00@0
bj2]0=>X[03CZ:`0djR/0P3Q^Jl20>c8[`050?KI[P3bf;D0mnJd0?K`]03am[L00P3]n<000`3YmLd0
hnWFooooo`02ooooo`03o`000?oooooooooo02;ooooo0009ooooo`0400000?oooooooooooooooah0
00000`0I6AT010000000<c<c03<c<`00000204a<C08000000`1oOgl010000000VIVI09VIVOl00002
0;>c/`Co000000@0VIVIo`00001oOgl0Ogmo0P00000406IVIPL000000P1VIVH3000000L0Ogmo3@00
000909VIV@030000001oOgl0Ogmo0080Ogmo0P00000306IVIP030000001<C4`0C4a<00T0C4a<00D0
000006IVIP1VIVH0IVIVo`00000307moO`04o`00002IVIT0VIVIo`0000<0/k>c00?o00000<c<c03<
c<`02P3<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00Co000007moO`1oOgoo00000`1VIVH0
10000000C4a<04a<C0000004ooooo`0300000?oooooooooo01Kooooo00?o00000:Vmj02Y_NP06`2Y
_NP00`2Y_>L0Z;[V0:RjiP030:Rii@030:Rgi02U[=d0YJWI0080YJWI0`2VYmL00`2WZ=L0Y9C50:FH
b0020:FHb0<0Xi[<00@0Wi[?09V7_`2AP[l0TH:o0P2=NkX308mg]080TWJ`0P2EMZh409Ig[P80U7J^
0P2BMJh3099d[P80UGF]00<0VWR/09UaY02QN:D00P2QN:D40:MnY`030:b5Z`2bQZH0/XJV00<0/X^]
0`2dT[@20:2<_P030:FD``1lOLP0O7g80080JF[10P1NGk/3069M]`80LfJe0ol0000208ad/`<0W7nc
00H0Zh^c0:f7[@2]Qjd0^92]o`00002hT:d40<FJZ`@0djR/00<0gkF]0>6i[`3/b:l00P3ffJh01P3j
j:X0mO6T0>_eXP3am[L0kOS00>Wec@80hnWF00@0fMKEoooooooooooo00009?ooool000Wooooo00@0
0000oooooooooooooooo7`00000301TI6@040000000c<c<0<c<c00000080C4a<0P0000000ol00000
000007moO`03000000;o00000`2IVIT20000000307moO`00000000000080IVIV00Co000000000000
000000001`1<C4`2000000<0IVIV1`00000=07moO`T000000`1oOgl2000000<0IVIV00<00000o`00
001<C4`02`1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00Co000009VIV@2IVIWo0000102c
/k<00ol00000c<c<0<c<c0080<c<c0;o00000`2c/k<01?l00000VIVI09VIVOl0000207moO`05o`00
001VIVH0IVIV06IVIP0000000P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo01Ko
oooo00?o00000:Vmj02Y_NP06P2Y_NP20:Vli`<0Z;[V00<0Z;WU0:Fah@2U[=d00P2U[=d30:FYf@03
0:JWe`2QTlH0Y9C50080Y9C50`2UV<P0102SV/`0WhRk09V7_`2IQkl20962_`<0SG^j0P2?Mk@3099f
/080UGJ^0`2FMjh209Af[P80TWF^0`2BM:h0102EMJd0TVbT09UaY02ILJ@40:5hY@<0YgjW0`2bQZH2
0;:;[@040;bAZ`2dT[@0]9:d0;BB]0<0YIC30P1lOLP305MS``80GUnk00@0HUfgo`000?l0003o0000
0`1nK;@208ad/`80W7nc00@0Wgf^0:f7[@2]Qjd0[HN]0P2hT:d00ol00000_9:[0<FJZ`020<FJZ`<0
djR/0P3O]Jd20>c8[`80m]V^00L0n^RZ0?GaY03[mJ80ioV/0>Wk`03Xl=00hnWF0080fMKE0oooool0
0ol0003oooooooooo`0Qooooo`002Oooool01000003ooooooooooooooolO000000<06ATI00Oo0000
03<c<`0c<c<0<c<co`00001<C4`0000000<0IVIV00@0000007moO`1oOgl0Ogmo1@0000000`1oOgl0
00000000000206IVIP800000101<C4`5000000@0C4a<0`00000706IVIPd000002P1oOgl2000000@0
IVIV00<0000004a<C01<C4`0301<C4`00`000000IVIV06IVIP0206IVIP04o`00001oOgl0Ogmoo`00
00<0VIVI00?o00000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0060<c<c003o`00002c/k<0/k>c
00<0/k>c00Co000009VIV@2IVIWo00000P1oOgl01Ol00000IVIV06IVIP1VIVH000000080C4a<00<0
0000ooooooooool00_ooool00`00003oooooooooo`0Eooooo`04o`000?oooooooooooooooaP0ZKgX
0P2Y_>P30:Vli`030:RjiP2V]^@0YK7Q0080YK7Q0P2U[=d20:FYf@0409nDb@2QTlH0XI?60:6CaP80
Y9C50P2UV<P00`2QQKH0WhRk09n8^`0309V7_`80TH:o0P2=NkX308mg]080TWJ`0P2EMZh309Ig[P04
09Af[P2BKJD0Sf^U08m[Y@<0SVZU0P2BK:@309UaY0<0XGRU0P2WOZL01@2]Oj<0/XJV0;:6YP2bQZH0
/X^]00<0_96[0P2dT[@0102oWKH0YIC30:FD``2UU<<207amb080Ef?30ol000000`1RGKL0Kf:c06mR
/`0307iY/@80Sg>_0`2OOJh40:f7[@030;R@[Ol00000_9:[0080aIZ[0P3>XZ/02@3CZ:`0gkF]0=ne
[@3O]Jd0kLN]0>c8[`3ffJh0n^RZ0?GaY0020>_eXP050>Oi[03Ynl00j?3@0=kIdP3Ie]D00P3@a<h3
ooooo`03o`000?oooooooooo023ooooo0009ooooo`0400000?ooooooooooooooob0000000`0I6AT0
1P000000<c<c03<c<`0c<c<0000004a<C0<0000000<0IVIV0000000000001`00000206IVIP800000
0`1<C4`3000000D0<c<c0`00000404a<C0L000003@1VIVH:000000<0IVIV0`00000504a<C0D00000
1P1<C4`01@000000IVIV06IVIP1VIVKo00000080Ogmo00Go000009VIV@2IVIT0VIVIo`0000050;>c
/`03o`00003<c<`0c<c<00<0c<c<0_l000050;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl0
1Ol00000IVIV06IVIP1VIVH000000080C4a<00<00000ooooooooool00_ooool00`00003ooooooooo
o`0Eooooo`04o`000?oooooooooooooooaP0ZKgX00<0ZKcX0:Rki`2X^nL00`2W^NH20:Jfi0030:Fa
h@2MX]P0WIW@0080WIW@0`2OU<T20:6CaP030:BDa@2OPK<0XHFf0080XHFf0`2OR;/209V7_`80TH:o
0P2=NkX308mg]080TWJ`0P2EMZh209Ig[P0309=]Y02BKJD0TVfU0080Sf^U0`2>JZD2099/Y0<0VG6T
0`2QN:D00`2WOZL0[GnS0:eoX`030;:6YP@0_96[00<0]9:d0;nM]P2oWKH00`2UU<<0101lOLSo0000
o`000?l0000204UE_0<0HUfg0P1_H[<207iY/@<0Sg>_0`2OOJh30:f7[@80_9:[00?o00000;bBZ`35
VZ/00P3>XZ/00`3CZ:`0gkF]0=ne[@020>g7[@070?SKZ`3ffJh0n^RZ0?GaY03[mJ80ioV/0>Wk`002
0>S`d0040=kIdP3@a<h0d<C>0=34cP?ooooo00?o0000ooooooooool08?ooool000Wooooo00@00000
oooooooooooooooo8000000401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`2000000P0IVIV
0P00000304a<C003o`0000000000<c<c00X0<c<c0`00000804a<C0X000003P1VIVH00ol000000000
04a<C00504a<C08000001@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV
00Co000007moO`1oOgoo00000`2IVIT00ol00000/k>c0;>c/`030;>c/`Go00001`2c/k<01?l00000
VIVI09VIVOl0000207moO`05o`00001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<cooooo`03
ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00_oooolF0:Vmj080ZKcX0`2X^nL0
0`2W^NH0Xk?T09n[g`0209n[g`80WJ;H0`2MVM0209nDb@030:6CaP2KO[<0Wh6c0080Wh6c0`2QQKH2
09n8^`0409V7_`2CN;80QW2b08I`/P<0P6R^0P2?Mk@0102BM[00S6VV095/Y02AK:@309=]Y080TVfU
0`2?JjD208iZY@<0TVbT0P2ILJ@30:5hY@@0[GnS0P2bQZH0102kSJD0_96[0;bAZ`2lTJ/40;nM]P?o
00000P1_Om<00`0iF<L0Ef?304UE_002055D]`03069M]`1_H[<0Kf:c0080OVVa0`2?Ljl309mm[P80
[HN]00D0/HZ/0;bBZ`2lTZ/0_9:[o`0000030<jRZ`<0gkF]0P3]ajd0203hfj/0n^^R0?[XZP3elJ@0
d^nA0=oj[`3Yml`0j?3@0P3NfM80103C`l/0d<C>0<^ga`3;]lL3ooooo`03o`000?oooooooooo01oo
oooo0009ooooo`0400000?ooooooooooooooob400000100I6AT01000003o000003<c<`0c<c<30000
000304a<C?l00000000000H0000000Co000004a<C01<C4`0C4a<0`00000?03<c<`0300000?l00000
000000D000002P1<C4`00`00003o00000000000<000000D0C4a<0P00000803<c<`800000101<C4`0
1@000000IVIV06IVIP1VIVKo00000080Ogmo00Co000009VIV@2IVIT0VIVI0_l0000=0;>c/`?o0000
0P2IVIT2o`000080Ogmo00Go000006IVIP1VIVH0IVIV0000000204a<C0030000000c<c?ooooo00?o
oooo00<00000ooooooooool05Oooool00ol0003oooooooooo`04oooooaD0ZKgX0P2Y_>P00`2X^nL0
YKSV0:>ci0020:>ci0<0Wj_O0P2MX]P0102MVM00TH6n09Im]`2FOKL209]n/`<0Wh6c0`2QQKH0102O
R;/0WW^]09=h/P2CN;8308I`/P80P6R^0P24IjT208aYYP80TFbT0`2CKJ@3099]Y@80Sf^U0`2>JZD2
099/Y0<0VG6T0P2QN:D40:eoX`030;:6YP2kSJD0^hfU00<0_96[00@0_iffo`000?l0003o00000`2[
Xll306mod`0303UHa`19EK`0BEFl0080DEBg0P1_H[<307iY/@80Sg>_0`2OOJh0102]Qjd0/HZ/0;6:
[02aRZ`30;bBZ`05o`00003>XZ/0cZ:[0=^a[@3O]Jd00P3]ajd20?SKZ`050?[[XP3/ki<0fNb80=oj
[`3Yml`00P3Qg=400`3NfM80dl?;0=?3b`030<^ga`Cooooo00?o0000ooooooooool07_ooool000Wo
oooo00@00000oooooooooooooooo8P00000501TI6@030000000c<c<0<c<c0080<c<c1000000604a<
C0<00000100c<c<;000000/0<c<c2P00000@04a<C0@00000300c<c<01@000000C4a<04a<C01<C4`0
000000<0IVIV00Go000007moO`1oOgl0Ogmoo`00000409VIV@;o00002P2c/k<00ol00000VIVI09VI
V@0209VIV@03o`00001oOgl0Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIV0000000204a<C0030000
000c<c?ooooo00?ooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`05oooooa<0ZKgX
00@0Z;cX0:Nki`2W^nL0Yk_W0P2U^>H00`2S/n@0V:OQ09:He`0209:He`80Sh[:0P2APKh209Im]`<0
Vgjc0`2OPK<0102QQKH0X7VX09ik[@2NNjd309=h/P80QW2b0P20J:h208AWZ@80S6VV0`2AK:@309=]
Y080TVfU0P2?JjD308iZY@80TVbT0`2ILJ@00`2QN:D0Y7NQ0:eoX`030:eoX`030;:6YP2kSJD0^hfU
0080_96[0_l000020;nM]P80c[6n00<0Zj??0:^li@2[_>D00P1<P>800`0iF<L09TFl02I5_002055D
]`<0I5fe0P1nJK4308mc[`0309mm[P2SP:h0/HZ/00<0/HZ/0P2lTZ/00`35Vjgo00000<jRZ`020=^a
[@040=ne[@3]ajd0kLN]0?SKZ`80n^^R00<0k>nC0=oj[`3Yml`00P3Qg=401P3C`LP0dl?;0=?3b`3C
`l/0c;?20<^ga`80bK310oooool00ol0003oooooooooo`0Nooooo`002Oooool01000003ooooooooo
oooooolS000000D06ATI00<0000003<c<`0c<c<01@0c<c<6000000@0<c<c0`00000;01TI6@@00000
4@0c<c<7000000H0C4a<0`00000@03<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0
IVIVo`00000307moO`03o`00002IVIT0VIVI00<0VIVI0_l000070;>c/`03o`00002IVIT0VIVI00<0
VIVI00Go000007moO`1oOgl0Ogmoo`00000306IVIP040000001<C4`0C4a<00000080<c<c1?ooool0
0`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo4@2Y_NP30:Rlj0030:Nki`2T^NL0
Y;WW0080Wk;V0P2HYn4309:He`80Sh[:0P2APKh209Im]`80Vgjc0P2OPK<00`2MMJD0X7VX0:1iZ003
09ik[@80TgRb0P26L;82081X[P80Q6NY0P2<JJH3095/Y0<0TffT0P2BKJD308m[Y@80SVZU0P2BK:@2
09UaY00409Y_X@2TMj40Y7NQ0:AgX@<0[GnS0P2kSJD3o`000080bIj/00@0_iff0<ja_P3>/Kh0c[6n
102[_>D00`1<P>8004?403UHa`0202I5_004055D]`1TGKD0I5fe06AM]@80NfVc0P2?Ljl0102@MK00
Xh2^0:>0[P2SP:h30;6:[0050;bBZ`35Vjd0aI^]0<FK[Ol000000P3K/Jd02P3[aZl0kLN]0>g7[@3h
fj/0n^^R0>c_T`3Ik8P0i?c90>7Od`3Qg=430=?1b0030=?3b`3</l80c;?200<0bK311?ooool00ol0
003oooooooooo`0Mooooo`002Oooool01000003ooooooooooooooolS00000003o`00000000006ATI
00<06ATI00@00000o`000000000000002`0c<c<2000001806ATI1`00000A03<c<`H00000500c<c<0
0`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVI_l000000`1oOgl2o`0000D0VIVI1ol0
000509VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH01@000000C4a<04a<C01<C4co00000080
<c<c1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo4@2Y_NP0102X_>P0
YkcX0:Nlj02W_>P20:Bii`80Wk;V0P2HYn4209:He`80Sh[:0P2APKh209Im]`80Vgjc00<0Wh6c09ee
Y@2MMJD00`2PNJP209ik[@80TgRb0`26L;82081X[P80Q6NY0P2<JJH2095/Y0<0TffT0P2BKJD308m[
Y@80SVZU00<0TVbT091XX@2JKj400P2JKj430:AgX@80[GnS0ol000020;^=Y@<0bIj/00D0g;B`0<ja
_P3>/Kh0c[6n0=oAb`020:^li@0408kGo`00J]X006[J0013a0809TFl00@0<TRi055D]`1TGKD0I5fe
0P1kJK<3091e/0<0Xh2^0`2aRZ`40<FK[@030<jRZol00000fk6]0080jlJ_0P3hfj/01@3jjj80k>nC
0<GaV@3To<T0hMoC00<0dl7800D0bZno0<bc`P3</l80c;?20<V[_0020<V``@030<^^_Ooooooooooo
00;ooooo00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooooooooooo9P00000701TI
6@/000006`0I6AT:000001@0<c<c1`00000603<c<`030000001<C4`0C4a<0080C4a<00D0000006IV
IP1VIVH0IVIVo`00000507moO`03o`00002IVIT0VIVI00d0VIVI00Go000007moO`1oOgl0Ogmoo`00
000406IVIP050000001<C4`0C4a<04a<C00000000P0c<c<4ooooo`0300000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool=0:Vmj0<0Z;gX0P2W_>P00`2U^^P0W[CX09jdj00209:Xi@80PiCL
0P1hOL`207Q^^`80PFV^00@0UWfg08a[Y`2FKjD0UVnU0`2MMJD30:1iZ080WW^]0P2AL:T307aRZ`04
079IY`20J:h0Q6NY08AWZ@80S6VV0`2AK:@209=]Y003099]Y@2BJJ00SFJQ0080SFJQ0P2;IJ42091X
X@<0VVnQ0P2TMj43o`0000030;J6XP2kSJD0^hfU0080^hfU0`39WZ`20=bd/0040<ja_P3OdL/0gm7;
0>7ieP<0S]Oo00@006[J000JX@00:k@09TFl0P0bB;T306AM]@80NfVc0P2@MK030:>0[P<0/HZ/00@0
^I>_0<FK[@35Vjd0aI^]0P3K/Jd02?l00000jlJ_0>_6[`3hgjd0mNnM0=KXP02df6X0i?c90P3Qgm<0
0`3A_/P0dl780<Z__`020<Z__`040<bc`P39Zk`0bJ^l0<V``@80bjjm1?ooool00ol0003ooooooooo
o`0Looooo`002Oooool01000003ooooooooooooooolX000001P06ATI1@00000H01TI6@L000001P0c
<c<7000000L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0050000001V
IVH0IVIV06IVI_l000001@1oOgl2o`0000X0VIVI0ol0000307moO`03o`00001VIVH0IVIV0080IVIV
00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool>0:Vmj0030:Rmj02X_>P0Z;cX00<0YK[X0P2N]>P209:Xi@80PiCL
00<0N7g<07Q^^`1hK[/00P21JJh208a[Y`80UVnU102MMJD20:1iZ00309ik[@2PMj@0TG2Y0080TG2Y
0P1lHZ/2079IY`80Q6NY0P2<JJH3095/Y00409=]Y02DJYl0TVVP099YX0<0SFJQ0P2;IJ43091XX@06
09Y_XOl0003o0000o`00002TMj40[GnS0`2fQZ820;^=Y@80bY^V00H0bIj/0=bd/03L];00g;B`0?7E
]03OdL/20>7ieP0909g_]`1kgOT0S<Wl08c9o01g^o`001ZQ000[]00VAK`0<TRi0080D5Nj00<0I5fe
07]Y/`1kJK<00`2@MK030:>0[P030;6:[02iTjl0^I>_00<0aI^]00<0djba0=^a[Ol000000P3[aZl0
1P3hgjd0mNnM0=KXP03EolT0g>7I0>7Od`80dKk8103:[kl30<V[_0<0bjjm00<0ck2jooooooooool0
0_ooool00ol0003oooooooooo`0Kooooo`002Oooool01000003ooooooooooooooolY000001@06ATI
3@00000J01TI6@H000003`0I6AT00`000000<c<c03<c<`0403<c<`050000001<C4`0C4a<04a<C000
0000101VIVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI00D0VIVI0_l0000507moO`03
o`00001VIVH0IVIV00<0IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`Cooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`l0ZKgX0P2X_>P0102U^^P0X;SY09:^jP2B[^X2
07RHi080F7CD0P1hOL`00`1hK[/0PFV^085Y[P0208a[Y`80UVnU102MMJD20:1iZ080X7NT0`2AL:T2
07aRZ`80LUVW0P1iFj<208IRX080TFbT00<0T6NO09AZW`2DJYl00P2BJJ0308eVX@80RfFQ00@0T6RQ
o`000?l0003o00000P2JKj420:AgX@@0]XJR00D0^hfU0<ZKYP3:VjH0bY^V0<VN[0030=bd/0040?7E
]03bm:T0hOWF09SBo080W;_^0P2A]_02086]l@0409/B0000:k@0<TRi0398^@80D5Nj0P1kJK<3091e
/080Xh2^00@0Z8Rc0;VC[`2iTjl0^I>_0P35Vjd20=>//@070=^a[@3[aZoo00000?SO[@3ekid0e^R0
0=Gob@020=cQf@<0dKk800D0ajZm0<Z__`3:[kl0bZno0<NV^0020<V[_0030<ZX^03;[[d0ck2j0080
ck2j1?ooool00ol0003oooooooooo`0Jooooo`002Oooool01000003oooooooooooooool/000000X0
6ATI4`0000000ol00000000000000007000002L06ATI00?o000003<c<`0c<c<00`0c<c<00ol00000
C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV0_l0000507moO`So00001@1oOgl2o`0000@0
IVIV00Go000004a<C01<C4`0C4a<0000000403<c<`05o`000?ooooooooooooooo`0000005_ooool0
0ol0003oooooooooo`0=ooooo``0ZKgX00@0Z;gX0:Jlj@2V_>T0Y[cY0P2P^>T209:^jP80N9ST00<0
F7CD04UF_019E[`00P1hK[/01021JJh0S6^W08a[Y`2<JjL209I_Y@<0WGFU00<0X7VX0:=fX02PMj@0
0P2PMj@2095`Z@<0O6:[00<0LUVW07UKX`1iFj<00P26HZ03091WW`80U6ZO0P2BJJ0308eVX@?o0000
0P2@J:4309Y_X@80Y7NQ102fQZ80102kSJD0bY^V0<ZKYP3:VjH30=bd/080lMFd00<0l_BY0:gMN02R
_N`00`2L^nh2096fl080PJga00<002^d000a]P0bB;T00P1@EkX307=Y^P80T7F`00<0Xh2^0:R8/`2X
R;<0102iTjl00`35Vjd0djba0=>//@020>_6[`030?SO[Ol00000e^R00080d^7S00@0g>7I0<bjb@3<
^/T0dKk80`37Z[d0103:[kl0ajJh0<NV^039Zk`20<ZX^0@0ck2j1?ooool00ol0003oooooooooo`0J
ooooo`002Oooool01000003ooooooooooooooomI000002406ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl03P1oOgl0
0ol00000IVIV06IVIP0306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<0
1Ol0003oooooooooooooool0000001Kooooo00?o0000ooooooooool03Oooool<0:Vmj080Z;gX00<0
Y[cY0:Bkj@2T^nT00`2I]N`01`1mY>`0AG[P00<j_01HM=@0BEJl05E<Z`1hK[/00P21JJh208a[Y`80
UVnU0P2MMJD00`2NL9d0XgJP0:=fX0030:1gY0<0TG2Y0P1lHZ/00`1bFJL0NE^S07UKX`0208IRX0<0
T6NO0P2DJYl2099YX0?o000000<0SFJQ08]UX@2;IJ400P2@J:4309Y_X@030:AgX@2/OJ40[7fQ00<0
]XJR103:VjH0103O/jT0g;B`0?7E]03aeK@20?;dZ@030::mk02S[=d0WJcQ0080WJcQ0`2CZND208FR
i`04000[]000<KH0D5Nj051G^P<0LfVj0P2ANkL40:R8/`<0^I>_0`3C[;401`3VaKH0jlJ_0?SO[Ol0
000000000=;Qh`33]Ld00`3<^/T40<NZ_@<0ajJh0`3:Z;P00`3>ZkD0ck2j0<n`^P020=Fe^@Cooooo
00?o0000ooooooooool06Oooool000Wooooo00@00000ooooooooooooooooG@00000N01TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP03o`00
001oOgl0Ogmo00/0Ogmo0_l0000506IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
0P0c<c<00ol0003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool0
3oooool<0:Vmj0<0Z;gX0P2T^nT01`2I]N`0Sk;^05bFk@1LU^d0AG[P00<j_019E[`00P1EC:/2085Y
[P80S6^W0P2FKjD00`2MMJD0WW2M09i`W@030:=fX080X7NT0`2AL:T207aRZ`80LUVW00<0NE^S08IR
X026HZ000`2@Iil01@2DJYoo0000o`000?l00000TVVP00<0SFJQ0P2;IJ43091XX@80VVnQ0`2/OJ43
0;J6XP<0bY^V0P3O/jT01@3L];00lMFd0?;dZ@3bm:T0YJ[J00<0XjcM0`2M[>401@2CZND0UIkJ08NI
g@27VMd0Mi3N0080036f0P1@EkX207=Y^P<0TG^g0`2XR;<20;VC[`80aZBg00L0djba0>K5]P3VaKH0
m^Jf0>OcV`2[e6Oo000000<0`kG=00<0c;[90<6T_031Y;`00P37Z[d20<>P]P80ajJh00D0aj>d0<ZX
^03>ZkD0cZ^e0<n`^P030=Fe^@Cooooo00?o0000ooooooooool06Oooool000Wooooo00@00000oooo
ooooooooooooI000000H01TI6@0300000?l00000<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`0
0ol00000000006IVIP0306IVIPCo00001`1oOgl2o`0000D0IVIV0P00000404a<C0030000000c<c<0
<c<c00<0<c<c00?o0000ooooooooool00_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooo
oooo017ooooo2`2Y_NP00`2X_NP0YkcY0:6jj`020:6jj`80Sk;^00<0G9K]0013a@00@lD00P19E[`0
0`1EC:/0KE:R06eBXP0208a[Y`0309I_Y@2CJ9d0WW2M0080WW2M0`2SMZ020:1gY0<0Tg2W0P1aFZP2
079IY`80NE^S00<0QV:P091WW`2@Iil00_l0000209AZW`80TVVP0`2=IZ4208]UX@<0T6RQ00<0VVnQ
09icX@2/OJ400P2/OJ420;J6XP80aIBT0P3:VjH20=ncZ@040?SGZ03aeK@0j^^800000080YJ[J00<0
XjcM0:>Nd02SW]000P2NWmD309FNfP80QiWM00@000ND000a]P0YC<80D5Nj0`1cJKX2095k]`<0Z8Rc
00D0^I>_0<JT]`36Y;L0aZBg0=>//@020>K5]P070?KV]P3Wli/0]ZkA0<>ecOl00000`kG=0;VN_@03
0<6T_0050<NZ_@33X;H0`j2f0<>P]P37Y[P00P37Xk@00`3:Z;P0cZ^e0<j[]@030=Fe^@80gKfi1?oo
ool00ol0003oooooooooo`0Hooooo`002Oooool01000003ooooooooooooooomb000000/06ATI00<0
000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0IVIV1ol0
000606IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<00`0c<c<00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool;0:Vmj080YkcY00@0
XK[[09jjk02N^^`0W[[/0P25[o401000@lD00cZl04UF_01EC:/206eBXP80PefN0P2CJ9d309i`W@<0
XgJP0P2PMj@309=`Y`80LEZX00@0GD^T079IY`1iFj<0NE^S0ol00002091WW`80U6ZO0P2BJJ0308eV
X@80RfFQ0P2@J:400`2AJJ80WW>Q09icX@040:amX@040;J6XP35U:@0aIBT0<ZKYP<0gk>Y00H0n=NX
0>[[R03ZjhP0YZSH0:FZfP2UVl`40:>Nd080WYoE00P0UIkJ09REc`29TMD0RI7E07N8e`001i@0036f
02U<`P<0LfVj0P2ANkL30:R8/`@0aZBg0P3VaKH00`3fi[H0io>K0:_DI`020;J^d@040<>ecOl00000
^Ijm0;VN_@80`JBl1033X;H30<NS]0<0cZ^e00<0eK2d0=Fe^@3M_KT00P3M_KT00`3Ub;[ooooooooo
o`02ooooo`03o`000?oooooooooo01Oooooo0009ooooo`0400000?ooooooooooooooog<000002P0I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH04@1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI6Oooool00ooo
ool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo2@2Y_NP20:Rmj0<0Y[cY00P0
W[[/09bjk@1n[o<0OZoc011dh@00@lD001BM05E<Z`80KE:R0P23GIh209=XW@@0WW2M0P2SMZ000`2P
Mj@0YgVQ0:MiX@0209=`Y`80LEZX00@0GD^To`000?l0003o00000P26HZ03091WW`80U6ZO00<0TVVP
09A/X@2=Ij800P2=Ij8208YUXP<0TFVR0P2NLj440:amX@040;J6XP35U:@0aIBT0<ZKYP80gk>Y0P3h
ejP00`3ZjhP0YIW90:FIb@030:FKc080Xik@00<0Y9;30:6Eb@2QULT00`2HULl208VAe@0307N8e`00
1i@0:Dc200<0HFg80`2ANkL00`2XR;<0/YVn0;:I_P020<JT]`80fl?200@0i/Ff0?KV]P3Wli/0XjGF
0P2f[]401@2iW[go00000;VN_@2iW[d0`JBl0080_IZd0P33X;H20<>M/@80aj>d00@0c:Fa0<j[]@3E
/;@0eK2d0`3M_KT20>G8^PCooooo00?o0000ooooooooool05oooool000Wooooo00@00000oooooooo
ooooooooM000000:01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`0101<C4`00`00
0000IVIV06IVIP0@06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<00`0c<c<00ol0
00006ATIooooo`03ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool80:Vm
j0<0Z;gX0`2V_>T209bjk@80OZoc00D047CQ0000L01EC:/0EDb[06eBXP0208=MWP80TfRM102NL9d2
0:=fX0<0YgVQ0P2CL:L3o`00000305e;Y01ZD:80JU2R0080QV:P0`2@Iil0102DJYl0UffP09A/X@2D
K:4308eWXP80RVFR0`2AJJ8309icX@<0[7fQ0`35U:@30=ncZ@040?SGZ03ZjhP000000:>Gb@80YIW9
00<0YI_<0:F?_P2TT/<00`2TT/<20:6Eb@80V9G?0`29TMD00`1gR=L002ng000_]`02065]b0<0THS6
0`2bVKh01P36Y;L0fl?20=_3`P3K`l80kO390?KV]P80XjGF00H0]ZkA0:jG_`2^Ukl0^Ijmo`00002i
W[d30;fJ]0050<>P]P33WK40`ifa0<>M/@37Xk@00P3<YK401@3>ZkD0eK2d0=F`]03N^[@0gKfi00<0
iLRj00<0lN2looooooooool00_ooool00ol0003oooooooooo`0Fooooo`002Oooool01000003ooooo
oooooooooome000000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00`0IVIV0P0000000ol00000C4a<04a<C00304a<C00300000?l00000<c<c00@0
<c<c00?o000001TI6@0I6AT01?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01Go
oooo202Y_NP30:Rmj080Y[cY0`2M^^d207nam0040000L00F79L0EDb[06eBXP80PefN0`2CJ9d309i`
W@80XgJP0P2WNJ43o`00000409=`Y`1aFZP0LEZX05e;Y080JU2R0P21GZ42091WW`03095XX02GKJ00
UffP00<0U6bQ0P2=Ij8208YUXP<0TFVR0`2NLj430:amX@<0aIBT00D0gK2Y0=ncZ@3O/jT0n=NX0>[[
R0020:>Gb@030:FIb@2SS;`0YHnn0080YHnn0`2TT/<0102QULT0Y8jn09^?aP2KSlH308b<cP80MX;A
0P00;kL2065]b0<0THS60P2bVKh01P32_=@0fl?20=_3`P3K`l80kO390;o_V@80X8o2102^Ukl00`2i
W[go00000;fJ]0020;fJ]0@0`ifa0`3<YK420=F`]080g[Zd0`3Ub;X00`3]eK/0lN2l0?;V_P04oooo
o`03o`000?oooooooooo01Gooooo0009ooooo`0400000?ooooooooooooooogD000002@0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH02P1VIVH00`00
0000C4a<04a<C00604a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01?ooool00`00
003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo202Y_NP30:Rmj080Y[cY00D0WK[]09nk
k@2O^nd0Wk_]08Nem00201HLU`80KE:R0P23GIh209=XW@<0WW2M00@0XgJPo`000?l0003o00000P2W
NJ4209=`Y`80LEZX00<0GD^T06Y@XP1ZD:800P21GZ43095XX080UffP0`2DK:4208eWXP80RVFR102A
JJ8209icX@80[7fQ00<0^H^U0<FDY035U:@00`3M/:T20?SGZ0030:6Gb`2SUlT0X8Vk00<0Xhbl0`2U
Skh00`2TT/<0YXZg0:B>_P020:B>_P80Vho60`2<S<h207J2d@03065dd00`L=h0<73N00<0THS600D0
/YVn0<:le032_=@0`[cD0=_3`P020>g`b@040967a@2PSl80X8o20:2?`P80[YNo00@0Zhff0;FD]@2e
U;Go00000P2mV[@01@2mUk40`ifa0<>M/@33WK40ain`0080c:Fa00L0djba0=F`]03N^[@0g[Zd0>S7
]@3Ub;X0kMFk0080lN2l00<0l^Jn0?3T`Oooool00_ooool00ol0003oooooooooo`0Eooooo`002Ooo
ool01000003ooooooooooooooomf000000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00504a<C08000002@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00@0<c<c
00Co000001TI6@0I6AT06ATI1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01So
oooo202Y_NP30:Rmj0<0Y[gY00D0Wk_]0::lk02B^O80001`01HLU`0206eBXP80PefN0P2CJ9d0102N
L9go0000o`000?l000020:YiW@<0YgVQ00@0Tg2W09]j[01OEJl0GeF_0P1MBj@00`1ZD:80PEjQ085N
X@03095XX080UffP0`2DK:4308eWXP80RVFR0`2AJJ8209icX@050:amX@2iRjD0^H^U0;V;Y@35U:@0
0`3M/:T00`3jgJP0a]UU09f8_@030:29^`80Xhbl0P2USkh0102UQ[<0YXZg0:J:]`2VR[L20:B>_P03
09^?aP2QS;h0T8W80080T8W80P1fO/h2065dd004031`gP2=Y^H0SJKV08fViP<0`[cD0P39mn/0103]
l<T0THO50967a@2AQlD20:2?`P030:jG_`2[SKH0Zhff0080]IBe00Co00000;fJ]02mUk40_INa0P33
WK420<NO/0030<bU/@3C[;40djba0080g[Zd0P3XakD00`3aeKD0kMFk0?7P_0020?;V_P030?3T`@3Y
el?ooooo00;ooooo00?o0000ooooooooool05?ooool000Wooooo00@00000ooooooooooooooooM`00
000801TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01P1<C4`2000000D0IVIV0P00
000804a<C0030000000c<c<0<c<c00D0<c<c00Co000001TI6@0I6AT06ATI1?ooool00`00003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Wooooo2@2Y_NP20:Rmj0030:Jmj@2W_NT0YkgY0080X[c/
00@0T[Wb01HLU`1=>IT0KE:R0P23GIh3o`00000309i`W@2SLY/0ZWVM0080ZWVM0`2WNJ4209]j[080
GeF_0P1MBj@0101ZD:80PEjQ085NX@21GZ42095XX0<0UffP0P2DK:4308eWXP80RVFR0`2AJJ8209ic
X@@0^H^U00D0aIBT0=f`Z@3M/:T0gK2Y0?[MZ00309f8_@80X8Vk00<0Xhbl0::2/@2UQ[<00P2UQ[<3
0:J:]`030:B>_P2XR[D0XHbn0080XHbn0`2@RLP01@1fO/h0FFk=05U^c@1DJ<X0CP0000<0SJKV00<0
`[cD0<Wgj`39mn/00P20M[h30967a@030:2?`P2NQKP0Zhff00<0Zhff0P2eU;D01Ol00000_INa0;fG
/@2mUk40`ifa0080ain`0`3C[;40203L][40g[Zd0>S7]@3XakD0lMFe0?KR]03ah;`0l^Jn0P3`i<40
0`3Yel?oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo0009ooooo`0400000?oooooooooo
ooooogL00000200I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00P0C4a<0`000000
0`1VIVH0000004a<C00904a<C0030000000c<c<0<c<c00D0<c<c00Co000001TI6@0I6AT06ATI1?oo
ool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo2`2Y_NP00`2W_NT0Z;gY0:Fm
jP020:FmjP0301HLU`1=>IT0CCVI00;o00000P2CJ9d00`2NL9d0Xg:K0:=bV`030:YiW@80YgVQ00L0
]8FS09]j[02KNZ`0VgZ/05mE[`0`=:D0GD^T0080JU2R0P21GZ43095XX080UffP0`2DK:4208eWXP80
RVFR0`2AJJ800`2NLj40YgnX0:MoZ0030;V;Y@<0gK2Y00<0n]fX0<KII@2JRL400P2MR;d00`2PRK/0
WGja0::2/@020::2/@<0YHJc0P2VR[L30:R:]@<0XHbn0P2@RLP207IncP0505U^c@16GlP0AUo805AX
bP1CHlD00P1@aO<01039mn/0LFo1081f_P20M[h3091n^`<0WXFh0`2[SKH0102eU;D0]I6a0;fG/Ol0
00020;fG/@<0ain`00@0cjJ`0=>//@3L][40g;Ja0P3XakD20?7E]@040?KR]03gjKD0l^Jn0?3T`@80
jMO300D0g/Bnooooooooooooooooo`00000Eooooo`002Oooool01000003ooooooooooooooomg0000
00P06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00;04a<C0030000001<C4`0C4a<
00T0C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0201TI6@Cooooo00<00000oooo
ooooool04_ooool00ol0003oooooooooo`0Looooo`X0ZKgX0P2X_NT00`2U_NX0YkgYo`000002o`00
0080N5>J00<0TfRM09AVVP2SLY/00P2SLY/30:YiW@040:MiX@2dQJ<0]8FS0;B5X`80VgZ/0P1OEJl0
0`0`=:D0JU2R06Y@XP02085NX@<0TFRP0P2GKJ0309A/X@80SFNR0P2:IJ82095YXP0409=bZP2WOjP0
YgnX0:MoZ0<0^H^U0`3M/:T01@3jgJP0VXW109Z9`@2MR;d0V7bb0080WGja0`2RP[430:F6/`030:J:
]`2YQZl0Z8Ze0080Z8Ze0P2QS;h00`2XSKP0V8[409R:a00207Qoc@80D6[>0P16GlP0101CHlD0GF?1
05eS`@1MHl42075_`@80P7Jn0P2@O[/309j5^0<0Zhff0`2eTK401@2mUk7o00000<6I[`31VJl0ain`
0080cjJ`00H0djba0=bf/@3L][40j<Fb0>S7]@3aeKD20?KR]0040?OY]@3di[X0k=Jm0>WG``80g/Bn
1?ooool00ol0003oooooooooo`0Booooo`002Oooool01000003ooooooooooooooomg000000P06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00G04a<C0030000000c<c<0<c<c00@0<c<c
00?o000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool0
7?ooool;0:Vmj0?o000000<0001M01HLU`1=>IT00P1hDiX209AVVP@0Xg:K0P2ZNId40;B5X`80VgZ/
0P1OEJl00`0`=:D0B4:W06Y@XP02085NX@<0TFRP0P2GKJ0209A/X@0309]gZ@2?Kj/0Sfn[0080RF^[
0`2CLZX30:MoZ0<0^H^U00@0dj^`0=f`Z@3jgJP0n]fX0P2CNkH209Ql/P<0WGja0P2RP[430:F6/`<0
ZHJ_0P2XR[D40:R=^080V8[40P1hOld2051ZcP0304IOb013FL<0Df?50080GF?10P1/JKd2081f_P<0
T7jk0`2NQKP00`2[SKH0ZhVb0;FA/@020;FA/@050;fG/Ol00000`IV_0<6I[`37Wk000P3?Y[020=bf
/@80j<Fb00<0lmJb0?7E]@3fh[@00P3gjKD00`3di[X0k=Jm0=k4_P020=k4_P050=Jc]ooooooooooo
ooooool000005?ooool000Wooooo00@00000ooooooooooooooooM`00000801TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`05`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT0
6ATI00806ATI1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo1`2Y_NP3
o`0000@0ZKgX00@05QbG04diV@1hDiX0N5>J0P2DIYX40:=bV`80ZWVM102dQJ<01@2KNZ`0/9Vo02=?
aP0SClH0<3BU0080B4:W0`21GZ42095XX080UffP0`2KMjT208m_Z`<0RF^[0P2CLZX40:MoZ0060;V;
Y@3CZk00dj^`0=f`Z@3jgJP0T7fk0P2CNkH309Ql/P80WGja0`2RP[400`2UQ[<0Yh6[0:V6[`020:V6
[`030:R:]@2^RZl0[XZ_00<0Z8fh0P2HR/@207Qoc@80D6[>00<0<EG704IOb013FL<00`1MHl40101/
JKd0OG6j07ea^P1mLKX2091n^`80WXFh00@0WX:d0:^9/P2[RK80ZhVb0P2eTK420<6I[`03o`000031
VJl0cjJ`0080cjJ`00T0fK:a0=bf/@3XaK80j<Fb0??F/P3iiJl0m^:d0?OY]@3di[X00P3/e[d0103N
_[T0g/Bn0=Jc]`3F/kL4ooooo`03o`000?oooooooooo017ooooo0009ooooo`0400000?oooooooooo
ooooogH000002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00P0C4a<1P00000:
04a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooo
oooo017ooooo00?o0000ooooooooool07oooool30:Vmj0?o00001`2Y_NP0100F79L0CCVI07QCVP1h
DiX209AVVP@0Xg:K00<0ZWVM0;N4WP2dQJ<00`2dQJ<30;2I_`0402=?aP0`=:D0B4:W04Q2Y`<0N5nY
0P2AJ:000`2GKJ00WgVX09miZ00209]gZ@80Sfn[0`29Jj/309=bZP<0YgnX00<0^H^U0=>[/03CZk00
0P3gk;@2091m^`80Tg^f0P2HO;8209en/@80XX:a00@0XWbY0:N1Z`2WPJ/0Yh6[0P2YQZl30:j:[`<0
Z8fh0P2QT<<207f4d0<0AFWB00<0<EG704=I``1>Fkl00P1>Fkl0101/JKd0OG6j07ea^P1mLKX208mi
]`<0WX:d0`2[RK800`2eTK40^9>`0;RC/0020<6I[`03o`00003?Y[00cjJ`0080fK:a00T0g;Ja0>S5
/P3ce[80lmJb0?WU[`3hk:h0mnZe0?CV^P3/e[d00P3N_[T30=Jc]`030=>[/?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool000Wooooo00@00000ooooooooooooooooMP00000801TI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01P1<C4`2000000H0IVIV00<0000004a<C01<C4`0
1`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00806ATI1?ooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01oooooo0ol0000:0:Vmj0040000G@1=>IT0N5>J07QCVP80
U6JJ102SLY/00`2ZNId0]hBN0;N4WP030;B5X`030<fQZP2`VKl0/9Vo0080eO?T00<0<3BU04Q2Y`1h
GjT00P1hGjT209EaZ0<0WgVX0`2KMjT208m_Z`80RF^[0`2CLZX20:MoZ0040;jR_03CZk00dj^`0=>[
/080mnbd0P2@OK/209=k]P80V7bb00<0WGja09agZ@2RO:T00P2RO:T30:N1Z`80ZHJ_102^RZl00`2X
SKP0/I6e0;6A]@020:6@``80OHC@0P15JM800`0aELL0:4c102Q<`@0204iK_`04069S_@1/JKd0OG6j
07ea^P80SgVg102NP[@20:^9/P<0^9>`0P31VJl00`38XK3o00000<nV/0020=Vb/@80j<Fb00L0lmJb
0?WU[`3iiJl0n>b^0?OZ]@3^ek/0k=Jm0080g[ji00@0dZ^a0=Jc]`3CZk00dj^`1?ooool00ol0003o
ooooooooo`0@ooooo`002Oooool01000003ooooooooooooooome000000T06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00L0IVIV0P00000704a<C003
0000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooooooo017o
oooo00?o0000ooooooooool07?ooool3o`0000;ooooo2`2Y_NP0100005d0CCVI04diV@1hDiX309AV
VP<0Xg:K00<0ZWVM0;N4WP2gQ9h00P2dQJ<20<fQZP050;2I_`3Eln@0eO?T09bUg00`=:D00P18@ZL2
07QOZ@80UG6X0`2ONJP309]gZ@80Sfn[0`29Jj/209=bZP050:MoZ02nX[`0_Z:l0;jR_03CZk000P3g
k;@00`27M;L0Qg2b08M`/P0208e`[P80U7>[0`2LMjT30:9lZ@80Yh6[00<0ZHJ_0:j5Z@2^QJT00`2^
RZl30;6A]@030:6@``2^Vl@0QI3G0080QI3G00<0=V_I04EYdP0aELL00P0XC<400`1>Fkl0HV>m069S
_@0307ea^P80SgVg0`2NP[@00`2[RK80[H^b0;RC/0030;RC/0040<6I[`38XK3o00000<nV/080fK:a
00D0ilBc0>S5/P3ce[80nNF_0?S/[P020?OZ]@030>kG^`3N_[T0g[ji0080dZ^a0`3CZk000`3FZjco
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo0009ooooo`0400000?ooooooooooooooogD0
00002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1V
IVH02P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I
6AT00P0I6AT4ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool06Oooool3o`0000Ko
oooo2P2Y_NP00`0005d010R804diV@0207QCVP80U6JJ0`2SLY/30;N4WP060;B5X`3=XJX0cJ6Z0<fQ
ZP3deZl0eO?T0`2LYM`204Q2Y`80N5nY0P2ELJP409miZ080VgNY0P2?Kj/308U[Z`0309=bZP2KTLP0
_Z:l00<0_Z:l00@0dj^`0?O/]027M;L0QgBg0P27L;8208e`[P80U7>[0`2LMjT30:9lZ@80Yh6[0`2^
QJT20:j:[`040;N>[02aTKD0/I6e0;6A]@<0[Y_40`25T=L01`0fJmT04TW602Q<`@0XC<40=Do004iK
_`1RHkd00`1hK[/208mi]`80WX:d00@0WX>e0:f;/P2]Rk80[H^b0`2hTk030<RQ/009o`00003I/[40
ilBc0>O4/`3dfK<0lmJb0?WU[`3hk:h0mnZe0080k]Nk00H0g;Zg0=jn^@3BZk40dZ^a0<jRZ`3CZk02
0=J[[0?ooooo0ol0000@ooooo`002Oooool01000003ooooooooooooooomd000000T06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00`0IVIV00<00000
04a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`04o`00000I6AT06ATI01TI6@Cooooo00<0
0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`?o00002_ooool:0:Vmj00400@8R01=
>IT0N5>J07QCVP80U6JJ0`2SLY/30;N4WP070;B5X`3=XJX0cJ6Z0<fQZP3deZl0am]X09n]h@0209bU
g00309^Le018@ZL0N5nY0080N5nY0P2ELJP309miZ00409]gZ@2]W/P0Ti3=09>@c@<0PhG=0`2KTLP3
0;jR_0030=3oc`2>O;/0SWbk0080QgBg0P27L;800`2=L:h0U7>[09AcZ`0309agZ@<0XWbY00<0Yh6[
0:^0YP2^QJT00P2^QJT0102^RZl0]hj/0;N>[02gSZ`20;6A]@030;fJ]02^Vl@0[Y_400<0SjCS0P0P
LN42000i_00402Q<`@0eCl00HV>m069S_@80N6jk0P2=N;P309j3]@<0[H^b0P2hTk020;nJ/P80b:6`
00X0djjco`00003Wa;<0ilBc0?CI/`3ijZd0mO6X0?Ga/P3gj[D0k]Nk0P3L^[L20=:[/@80cZ:[00@0
dj^`0=J[[03FZj`0gk:X0_l00002ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oo
ooooooooooooof<0000000?o00000000000000002`0000000ol00000000001TI6@0801TI6@03o`00
00000000<c<c00@0<c<c00?o00000000001<C4`0101<C4`00ol00000000006IVIP0?06IVIP03o`00
00000000C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@04ooooo`030000
0?oooooooooo017ooooo00?o0000ooooooooool05?ooool2o`0000oooooo202Y_NP0100005d0CCVI
07QCVP1hDiX209AVVP80Xg:K00@0[gbM0;N4WP2gQ9h0]hBN0`3=XJX20?CF[`040<OKJ02EX]h0T9KE
092Fe@80Sh_;00<0B4:W07QOZ@1hGjT00P2ELJP209miZ0040;JSa@2]W/P0[Ik80:fNb080Ti3=0`23
QLd309^Ab0030;jR_03@oll0QW:e0080QW:e0P1kJ;4208M`/P80SG2^0P2DLj/309agZ@80XWbY0`2[
P:H20:j5Z@@0]hj/00@0/I6e0;fJ]02mV[@0[Y_40P2n[LT308nTh`05021ah@00>Kh003Vl000i_00e
Cl000P1?G<4207Q^^`<0SGRh0`2NPkD20:f;/P050;RC/02oV[80_iZb0;nJ/P38XK000P3C[[<02@3W
a;?o00000?CI/`3dfK<0nNZ]0?GaZ03elK80kmfn0>kG^`020=bj]`040<jU[`3BZk40cZ:[0<jRZ`80
eZ^/0P3O/ZP4ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooooeX0
000000?o000001TI6@0I6AT01`0I6AT<000000`06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV0140IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0403<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool04?ooool00ol0003o
ooooooooo`0Booooo`?o00004_ooool70:Vmj0040000G@0428P0N5>J07QCVP80U6JJ00<0Xg:K0:ml
W@2_O9d00`2gQ9h01P3@WZ<0cJ6Z0<fQZP3deZl0am]X09^]h`80UJ;N0P2@U]D0102?Rl/0002C07QO
Z@1hGjT209EaZ00409miZ02fXlD0]Z?50;JSa@80[Ik80`2CT<d208>5c@80Vi7800@0000009Qm]02H
OK@0V7fd0P26L[D207]X/@80O6F]0P2=L:h209AcZ`<0W7NY00<0XWbY0:AjY@2[P:H00P2[P:H20:j5
Z@040;J9YP2gSZ`0]hj/0;N>[0<0_IZd0`2n[LT00`3Aa]00VL;d09W2m00209SRo@8001^X00@0=Do0
04mL`@1?G<40Cec10P1hK[/208eh^0<0WX>e0P2]Rk840;nJ/P<0djjc00D0hl:go`00003dfK<0nNZ]
0?GaZ0020?Ga/P030>oM_P3L^[L0g;Zg0080cZF_00D0dZ^a0<jRZ`3>XZ/0dZ:W0=J[[0020=nbZ005
0>k3YOooooooooooooooool000004?ooool000Wooooo00@00000ooooooooooooooooE@00000V01TI
6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0506IV
IPL000001`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI
6@0I6AT01?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo0ol0000Foooo
o`L0ZKgX00<010R806I8V`1hDiX00P2DIYX01@2SLY/0[gbM0:mlW@2_O9d0]hBN0080d9jS0P3=XJX0
0`3deZl0am]X08nShP0208BCfP80OX?>0P1oN<8204IXd@0309EaZ02QVLd0]Z?500<0]Z?500<0[Ik8
0:=nZ`2SOZ/00`2WPjd20:N6/@<0YH>`0P2HOK@308Ib]@0307]X/@1lIJd0O6F]0080QFNY0P2DLj/2
09agZ@0309adY@2TNZD0Y7ZU00<0Zh2V00<0[XFY0;J9YP2fRJH00`2gSZ`01@32UZ/0_IZd0;fJ]03=
ZKH0_Zg90080dLK@00D0h^OF09SRo@2Hh_d0NnGT08[/c@02000KZ00303E?`01?G<40Cec10080KFc0
0P2=N;P309j3]@030:f;/P2bT[H0/Y:f00<0_iZb00T0bZRg0=>^/`3S`[L0hl:g0?;M^Ol00000nNZ]
0?GaZ03elK800P3_gKh0103I^[X0g;Zg0<jU[`3>YJl20<jRZ`80dZ:W00T0eZ^/0=nbZ03^`jD0k/>U
0?gIVoooool00000ooooool000003oooool000Wooooo00@00000oooooooooooooooo=P00000401TI
6AP00000:@0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH0101VIVH00ol00000000007moO`0607moO`030000001VIVH0IVIV00D0IVIV00?o000004a<
C01<C4`00`1<C4`00`000000<c<c03<c<`0303<c<`03o`00000I6AWooooo00?ooooo00<00000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`?o00006_ooool60:Vmj00500@8R01VB9/0ITRK
09AVVP2HJid0102_O9d0102gQ9h0d9jS0=2NX`3@WZ<20?CF[`0309V_i`2?Xn80Sj?R0080Q9?J0P1n
Plh00`1oN<80QG>h04IXd@030:6Ic@<0]Z?500@0WGZ[0:=nZ`2SOZ/0Xgj[0P2WPjd00`2WQ[40ZX>[
0:F3/0020:F3/0<0V7fd0P26L[D00`1kJ;40O6F]07aU[@0208EWZ@80TFfV0`2LM:D30:AjY@80Zh2V
0`2fRJH20;N>[080`YJ[00<0_IZd0<fY]P3=ZKH00`3Aa]00103RimH0gOk=08oQV`2OmM<20:gbm@04
08X90007?Kh0Cec104mL`@80KFc00`29Nkd00`2NPkD0X8Rj0;:B]P020;:B]P80_iZb0P3:Z;L02@3C
[[<0hl:g0>?2]`3bgKT0mO:`o`00003XnJl0kN_80>oM_P020=Vj^P<0cZF_00@0b9^Y0<jRZ`3BXZL0
dZ:W0P3O/ZP20>k3Y@050?gIV`2kbD`00000ooooool000003oooool000Wooooo00@00000oooooooo
oooooooo;`00000B01TI6@h00000:`0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<
00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`00003o000007moO`0907moO`03o`00000000000000
00D0IVIV00<0000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0203<c<`03o`00000I6AWooooo
00?ooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool50:Vm
j00300@8R01VB9/0ITRK0080V6^M102_O9d01`2gQ9h0d9jS0=2NX`3@WZ<0mm2T0<WBF@2J/nT00P2=
Z>L01@1jUN40JGkE06=/aP1SK<H0OgS20080QG>h00D0AVSA0:6Ic@2QVLd0XIW=0;JSa@0309ejZ`80
Xgj[0P2WPjd30:Z3Z`80YH>`0P2HOK@00`2FN[80OFZc07eZ/`0207]X/@0307aU[@25IjT0QFNY0080
TFfV0`2LM:D30:AjY@80Zh2V102fRJH00`2gSZ`0`YJ[0<:FZ`030<fY]P060>30^03Aa]00h^OF0=gn
c@2HcVH0Z?ST0P2ajOP00`2]g_P0Z/oc0:[?l`0202YAa@0304mL`@1]K<00RG^m0080RG^m0P2PR;X4
0;:B]P030;nJ/P3:Z;L0bZRg0080hl:g0P3bgKT0103el[3o00000>Si[`3]jlP30=Vj^P050<NP/03>
YJl0b9^Y0<RKZ@3>XZ/00P3BXZL00`3L[:@0gk:X0>k3Y@020?gIV`0400000?ooooooooooo`0000oo
oooo0009ooooo`0400000?ooooooooooooooobd0000000?o000001TI6@0I6AT05@0I6AT600000140
6ATI1000000I01TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`010000000
IVIV06IVIP1VIVH2000000l0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<
C0030000000c<c<0<c<c0080<c<c00?o000001TI6Oooool00oooool00`00003oooooooooo`0@oooo
o`03o`000?oooooooooo00Kooooo0ol0000Rooooo`@0ZKgX00<0^Fd006I8V`1VB9/00P2HJid40:ml
W@@0d9jS00<0mm2T096_j`2A[n/00P1jW^T205V2g`0406Une@1SK<H0J6>i07mh`P80QG>h0P2QVLd2
09If[@<0WGZ[0P2SOZ/00`2WPjd0ZH2W0:Z3Z`020:Z3Z`030:F3/02XPjd0UWZb0080UWZb0P1mJ[<0
1@1/G:h0NfRa07aU[@1lIJd0QFNY00<0TFfV0`2LM:D20:AjY@030:^0YP2aPj@0]XVV00<0]XVV0`32
UZ/01`3@Y:/0cJVf0>30^03P`;P0lmfg0??cZ03<jH@00P2]lOH0102ajOP0[]Gd0:kEm02Zco<20:W6
k`80:U750P1]K<0308Uk_@80X8Rj0P2bT[H03P2kX;d0bZRg0<ZX]`3:Z;L0f/2o0>?2]`3bgKT0mO:`
0>OfX`3XnJoo00000>g[b03E_/<0fKZj0P37X;000`3>YJl0b9^Y0<RKZ@020=:RY`80g:bT0P3^`jD0
0`3mfI/0^lU<ooooo`02ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooo
ooooob/00000;@0I6AT4000000@0<c<c1`00000A01TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH000000180Ogmo0P00000406IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo013ooooo00?o0000ooooooooool00oooool3o`0002Kooooo102Y_NP0100428P0ITRK09Q[
W@2HJid40:mlW@<0d9jS00<0mm2T0<WBF@2N]nX00P2A[n/207ZNj@0305V2g`0lHLd0?67=0080J6>i
0P25LkP208ec/@80UWJ]0`2MNZ/00`2SOZ/0Y7^V0:V0Y`020:V0Y`80ZX>[0`2XPjd309Ij/P0307eZ
/`1/G:h0K5b^0080O6F]0P25IjT2095]YP<0W7BU0P2TNZD30;63Y0<0]XVV0P32UZ/20=2TZ`050<fY
]P3P`;P0h<2h0??M]`3cljP00P2]lOH00`2_foL0[]Gd0:kEm0020:_9k`040:W6k`2X`N`0Z<7/02YA
a@80F6_;0`29Nkd20:28^P050;:B]P2kX;d0^j2m0;^P_@3:Z;L00P3J`;l0203/hlL0l]fi0?Gb/03W
mZ<0fOkD0>g[b?l00000eKk30`37X;030<RKZ@80dZ:W0P3L[:@20>k3Y@030?gIV`0001Oooooo00;o
oooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo:00000000ol00000
6ATI01TI6@0701TI6@T0000000?o00000000000000005P0I6AT4000000l0<c<c00@00000o`000000
00000000300I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00?o00000000
001VIVH00P1VIVH00`000000Ogmo07moO`0407moO`Wo00001P1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<01Ol0003oooooooooooooool0
0000017ooooo00Co0000oooooooooooooooo0ol0000[ooooo`80ZKgX00<010R806I8V`2HJid00P2H
Jid30:mlW@<0d9jS00@0mm2T0::jjP2I]^`0VKK/0P24Znh01P1NTNX08f?G02=Se`0lHLd0Hfc606QS
^@80MF>`0P2=Lk4309If[@0409ejZ`2LMJH0Y7^V0:AkYP<0ZH2W0P2ZPj/30:R3[@<0UWZb0P1mJ[<0
0`1/G:h0KUVZ07aU[@0208EWZ@80TFfV0`2LM:D20:AjY@<0/H>T0P2fRJH20<2AY@030<:FZ`3@Y:/0
d:B[0080h<2h00<0lmfg0??cZ03<jH@00P2/c_820:c<l080ZlW_0P2Z`^`01@2X`NcoZ;oZojJnj`0Z
DLD0F6_;00<0Ph?:0P2TU<D40;^P_@<0f/2o00D0k>?70>Gk^02jk9<0fOkD0<g;f0020=Fn``04o`00
0037X;00aj2`0<NP/080b9^Y0P3;VjH0103BXZL0g:bT0=b/Y03^_j420?gIV`Cooooo00?o0000oooo
ooooool03Oooool000Wooooo00@00000oooooooooooooooo:000000701TI6@<00000300c<c<30000
01406ATI00<00000o`00000c<c<05P0c<c<3000000T06ATI00<0000003<c<`0c<c<0100c<c<00`00
0000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVI_l000001@1oOgl2o`0000T0VIVI0_l00004
07moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`02
03<c<`05o`000?ooooooooooooooo`0000004Oooool4o`0002oooooo00@0ZKgX0;U]001VB9/0ITRK
0P2HJid20:mlW@80aYJT00@0d9jS0?O@Y039dUT0X;[[0`2C]>h01`1fY_00=goW03Moi`0SHmL0032g
03aQc@1XHkT00P1eHk0208AXZ`<0TFjW0P2LMJH30:AkYP80ZH2W00<0ZX>[0:j4Z02^Q:P00`2XPjd2
09Ij/P80OFZc00<0K5b^06iIZP1^FJX00P25IjT3095]YP80W7BU00<0Y7ZU0:QlX`2aPj@00P2aPj@0
1@2fRJH0`96U0<2AY@30TJD0`YJ[0080d:B[00H0i;Z/0>30^03cgKL0lo>X0:[?l`2/c_820:_5k@80
Z/C/0P2Z`^`01OnY_n[oZ;oZojRoj_nX_n[oY[k[0080F6_;0`23PlX20:BDa@<0^j2m00H0b[_<0=[0
_`3/hlL0k>?70>Gk^03Io]@30<g;f0040=Fn`ol00000_iff0<NP/080_iBZ00<0b9^Y0<^KYP3;VjH0
0P3L[:@20>joX@030?oIT?oooooooooo00?ooooo00?o0000ooooooooool03Oooool000Wooooo00@0
0000oooooooooooooooo9`00000701TI6@030000000c<c<0<c<c0100<c<c1000000901TI6@@00000
1P0c<c<<000000X0<c<c1000000201TI6@<000001P0c<c<00`000000C4a<04a<C00204a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0;09VIV@03o`00
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0000000@0
<c<c1?ooool00`00003oooooooooo`0?ooooo`;o0000<Oooool0102Y_NP0^Fd006I8V`1VB9/209Q[
W@80[gbM0P36UZ@00`3@WZ<0mm2T0:Jlj@020:2jj`0;09>dkP2?]?00J:?b06RSlP0gOnL003Fj02=S
e`00<;L0@dRa06QS^@1eHk000P24J:/3095^Y`80W7FV0`2TNjH20:V0Y`<0[XBX0P2XPjd00`2^R:h0
UWbd09Il]00206mS]@0306aL[P1^FJX0KUVZ0080OF2W0`2AKJH00`2LM:D0WG>S0:QlX`020:QlX`80
/H>T1030TJD20=2TZ`80i;Z/00<0n=NW0?GYS@2jceH00P2ZaNd00`2[aNgoZ/3Zoj[0jP02oj[0jP03
ojVoj_nY_^WoZKkY00?oZ;kY00?oYkkY029Uf00RIMP00P23PlX30:BDa@060;^P_@3:^l`0b[_<0=[Z
g`3/hlL0iO^h0P2Ug_/20<g;f0050;6M``2oWKH0_iffo`000037X;000P2oU:X00`38VjT0bi^V0<^K
YP020=b/Y080k[nQ00<0omV@ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`002Oooool0
1000003ooooooooooooooolV000000H06ATI0P00000803<c<`L00000200c<c<3000000<06ATI0`00
000703<c<`<00000301<C4`3000000/0<c<c0P00000903<c<`030000001<C4`0C4a<0080C4a<00D0
000006IVIP1VIVH0IVIV0000000407moO`03o`00002IVIT0VIVI00d0VIVI00?o000007moO`1oOgl0
0P1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00@0000003<c<`0c<c<0<c<c1?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo00<0ZKgX06I8V`1VB9/00P2HJid01P2_
O9d0aYJT0<JFY036UZ@0d9jS0?O@Y0<0YKcY0P2O^^`0202?]?00J:?b06RSlP0<K=d003Fj000`]`0d
Bk`0@dRa0P1eHk0208AXZ`80TFjW0`2LMJH20:AkYP030:V0Y`2^PJD0[XBX0080[XBX00<0Z8>]0:j8
[P2^R:h00P2FO;@206mS]@80K5b^00<0KUVZ07ePY`1mH:L00`2>JZD209ecX`<0Z7bS0P2aPj@01P2j
RZ@0`96U0<2AY@30TJD0cYnV0=2TZ`80i;Z/00@0n=NW0?GYS@2YaNh0Z/G]0_nY`NX00onZ`>[oZKkY
ojVnj@03ojVnj@;oZKkX0_nY_NP2ojRmj@03000fX`1aU>@0LICT00@0Zk3L00D0b[_<0=[Zg`3Jj]l0
[oJl03^=kP0209BNfP@0/Ig30P2oWKH00ol00000_iBZ0;nDZP030<^KYP050=FUY@3L[:@0k[nQ0?oI
T03Hd5@01_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolU0000
00D06ATI0P00000503<c<`D000001`1<C4`00ol0000000000000000803<c<`<000001`0c<c<00`00
003o00000000000704a<C0P000000`1<C4`300000180<c<c00<0000004a<C01<C4`00P1<C4`01@00
0000IVIV06IVIP1VIVH0000000@0Ogmo00?o000009VIV@2IVIT00`2IVIT7o`0000D0VIVI00?o0000
07moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00Co000003<c<`0c<c<0<c<c
1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo02oooooo00D07bRQ06I8V`2HJid0
V6^M0:mlW@030<JFY0040?KH[@000000Z;gX0:Flj@80YKcZ0P2N^^`208fel@80H:;d00D0001l000`
]`13B;40GU6[07ES/00208AXZ`<0TFjW0P2LMJH20:AkYP<0[X6U0P2^Q:P40:j8[P80UWbd00@0Kf>e
059=[P1/G:h0KUVZ0P1mH:L308iZY@80WG>S0`2XO:<00`2aPj@0^XZT0;Z:Y0020<2AY@80cYnV00D0
d:B[0>Bj[03hejL0mNV=0;[?EP02ojW1j`03ojW1j_nY_^WoZKkY00?oZKkY0onY_^P7ooooo`80LICT
0P2[/=`20:7Ro0030=[Zg`2_m[`0?6KB0080?6KB0P2DW]X30;6M``060;nM]P2dSZl0_iBZo`00002o
U:X0`9>X0P3;VjH0103EYJD0k[nQ0>joX@3ofI07ooooo`03o`000?oooooooooo00cooooo0009oooo
o`0400000?ooooooooooooooob@000001@0I6AT00`000000<c<c03<c<`0303<c<`8000003`1<C4`2
000000l0<c<c00<0000004a<C01<C4`0101<C4`4000000P0IVIV0P00000404a<C0030000000c<c<0
<c<c00l0<c<c00D0000004a<C01<C4`0C4a<o`00000406IVIP050000001oOgl0Ogmo07moOol00000
102IVIT2o`0000L0/k>c00?o000009VIV@2IVIT00`2IVIT01Ol00000Ogmo07moO`1oOgl0000000<0
IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool0;_ooool0102iK@007bRQ09Q[W@2TOj`40<JFY0040?KH[@2Y_NP0Z;gY
0:Rmj@<0YKcZ0P2O^nd208jglP80HJKf00@0001l000FXP13B;40GU6[0P24J:/3095^Y`80W7FV0P2T
NjH30:j1Y@80[XBX00@0]X^X0:j8[P2^R:h0[XR^0P2FO;@206mS]@03059=[P1^FJX0KUVZ0080OF2W
0P2>JZD309ecX`80Z7bS00<0/H>T0;Z:Y02jRZ@00P30TJD20<jOYP80i;Z/00<0n=NW0?GYSOnY_^T0
1?nY_^T5ojVnj0[ooooo0P0PV^/20:7Ro00400000?ooooooooooooooo`80?6KB0P21OLD20;6M``05
0::7]`2dSZl0]8j_0;B>[ol000000P30TjP20<^KYP040=FUY@3^_j40k[nQ0?oIT0Oooooo00?o0000
ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo8`00000501TI6@030000000c<c<0
<c<c00<0<c<c00@0000004a<C01<C4`0C4a<3000000404a<C0<000002@0c<c<3000000@0C4a<0`00
000406IVIP@000001P1VIVH2000000<0C4a<0`00000=03<c<`030000001<C4`0C4a<0080C4a<00D0
000006IVIP1VIVH0IVIV0000000307moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<0
202c/k<2o`0000@0VIVI00Go000007moO`1oOgl0Ogmo0000000306IVIP050000001<C4`0C4a<04a<
C00000000P0c<c<4ooooo`0300000?oooooooooo01Cooooo0_l0000_ooooo`0301lXX@2TOj`0Y7n/
00<0aYJT00<0m]R]0000002Y_NP00`2X_NT00`2U_>X0Y[gZ0:2lk0020:2lk080T[Wa00D0Jjgh0000
O0005Z80@dRa05iAZ`0207QNY`0308AXZ`2AKZL0TFjW0080W7FV00<0Y7^V0:QlX`2^PJD00P2^PJD0
0`2^Q:P0]X^X0;J;Z0030:j8[P0709Il]02GQKd0De^m06mS]@1BCJh0ET^Y06iIZP0207ePY`80SVZU
0`2MLj<20:QlX`@0^XZT00P0`96U0<jOYP3>WjH0hkJW0>Bj[03hejL0mNV=ojVnj@GoZKkX5_ooool2
01e6`00303aVdP21OLD0XXNg0080XXNg0`2dSZl0102oU:[o00000<2CZ03;VjH20=FUY@030>^lY03o
fI00f=1D00Oooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo8@00
00000ol000006ATI01TI6@0301TI6@030000000c<c<0<c<c0080<c<c00Co00000000001<C4`0C4a<
0P00000<06IVIP04o`00000000000000000000<0C4a<00Co000000000000000000000P0c<c<30000
00@0C4a<0`00000206IVIPD00000101oOgl400000006o`00001VIVH0IVIV06IVI_l000000000101<
C4`00ol00000<c<c03<c<`0903<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV
o`00000307moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<02`2c/k<00ol00000VIVI
09VIV@0209VIV@05o`00001oOgl0Ogmo07moOol000000P1VIVH01@000000C4a<04a<C01<C4`00000
0080<c<c1?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00@07bRQ0:Ao
[02TOj`0Y7n/0P36UZ@01@3ff:d0ZKgX0:Vmj02Y_NP0Z;gY0080Z;gX0P2V_NX00`2P_>`0X[c/0::l
k00209Nkl00407^dm`0007`001^O05iAZ`<0N5jW0P2AKZL00`2LMJH0WGBT0:QlX`020:QlX`80[X6U
0`2fRjP30:j8[P80UhFm0P1CFkd00`1BCJh0ET^Y05I;Z@0207ePY`<0SVZU0P2MLj<20:QlX`040:n2
Y02jRZ@0^XZT0;Z:Y080cYnV0P3S]ZL00`3keZ00mNV=ojVnj004ojVnj1Wooooo0P0MA/02085ma@<0
XXNg0P2dSZl20<2CZ007o`000030TjP0eJFU0=FUY@3[_:@0o]j>00000007ooooo`03o`000?oooooo
oooo00cooooo0009ooooo`0400000?ooooooooooooooob8000001@0I6AT01@000000<c<c03<c<`0c
<c<0000000<0C4a<00@0000006IVIP1VIVH0IVIV2`00000406IVIP8000001@1<C4`2000000H0C4a<
00@0000006IVIP1VIVH0IVIV0P00000=07moO`800000101VIVH00`000000C4a<04a<C00204a<C080
0000200c<c<00ol00000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl00ol0
0000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00/0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol0
0000Ogmo07moO`1oOgl000000080IVIV00D0000004a<C01<C4`0C4a<0000000203<c<`Cooooo00<0
0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`0501lXX@2TOj`0Y7n/0:Ao[036UZ@0
0P3ff:d40:Vmj0<0Z;gX0P2W_NT00`2R_>`0Y;g[0:Bmj`0209flkP0408^jm@005Z80@dRa05iAZ`80
N5jW0P2>JZD209edY0<0Z7bS0P2^PJD40;J;Z0030:j8[P2iUK80^IFb0080UhFm00@0De^m059=[P1B
CJh0ET^Y0P1_FJP00`1mH:L0SVZU08iZY@0209ecX`030:QlX`2_PZ@0[h:T00<0^XZT0P3>WjH20>>f
Y`030?_FX03ZhGGoZKkX01gooooo0P0MA/0206e[_`<0XXNg00<0]8j_0;6:[@2aRZd00P30TjP01Ol0
0000eJFU0=FUY@3[_:@0o]j>00Sooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooo
oooooooooooo8P00000401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`00`000000IVIV06IV
IP02000000/0Ogmo0P00000406IVIP030000001<C4`0C4a<00P0C4a<0P00000306IVIP040000001o
Ogl0Ogmo07moO`co00000P1oOgl2000000<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`05
o`00002IVIT0VIVI09VIVOl000003`2c/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00@00000
06IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo01Sooooo00?o
0000ooooooooool0:oooool01P0O::40Y7n/0:Ao[036UZ@0m]R]000000D0ZKgX00H0Z;gX0:Vmj02Y
_NP0ZKgX0:Nmj@2T_N/30:JmjP040:6mk@0005`001^O05iAZ`80N5jW0P2>JZD209edY0<0Z7bS00<0
[X6U0;F8Y@2fRjP00`2fRjP30;VE/P80UhFm00@0De^m01Ta[01BCJh0ET^Y0`1_FJP208iZY@80WG>S
0`2_PZ@20;Z:Y080b9RU00@0cYnV0>>fY`3S]ZL0nmJP8?ooool01P0MA/00KF^o06e[_`1]Jkl0XXNg
09Qn]@<0/HZ]0P30TjP01Ol00000bYfY0>^lY03[_:@0000000Wooooo00?o0000ooooooooool02ooo
ool000Wooooo00@00000oooooooooooooooo8@00000501TI6@040000000c<c<0<c<c000000<0C4a<
00@0000006IVIP1VIVH000001@1oOgl7o`0000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000
C4a<04a<C00604a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00_l0000<09VIV@05
o`00001oOgl0Ogmo07moOol000000`1VIVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00?o0000
09VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`0=0;>c/`03o`00002IVIT0VIVI0080VIVI00Go0000
07moO`1oOgl0Ogmo0000000206IVIP060000001<C4`0C4a<04a<C0000000<c<c1?ooool00`00003o
ooooooooo`0Iooooo`;o0000:oooool01@0O::40Y7n/0:Ao[036nnSooooo00/0ZKgX0P2X_NT01P2V
_NX0YkgY0:Nmj@2U_N/001^O05iAZ`80N5jW0P2>JZD309edY080Z7bS00<0[X6U0;F8Y@2eR:D00`2f
RjP30;VE/P80V9gG00<003k105=K_@0I<J`00P1FBjT206mIZ080RfVW00<0WG>S0:1gY@2_PZ@00`2_
PZ@00`2jRZ@0b9RU0<RHY@020>>fY`030?_FX03ZhGGooooo01oooooo00@0`dd001e6`01]Jkl0KF^o
0P2HO[D30;6:[@80`9>X00D0bYfYo`00003[_:@0jkbT00000009ooooo`03o`000?oooooooooo00_o
oooo0009ooooo`0400000?ooooooooooooooob400000100I6AT01@000000<c<c03<c<`0c<c?o0000
0080C4a<00Co000006IVIP1VIVKo00000P1oOgl4o`0000L0VIVI00Ko000007moO`1oOgl0Ogmoo`00
0000000306IVIP<000000P1<C4`00`00003o00000000000406IVIP03o`00001oOgl0Ogmo00;o0000
0P2IVIT:o`000080VIVI0_l0000207moO`050000001VIVH0IVIV06IVIP0000001@1<C4`300000003
o`0000000000C4a<00D0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`05o`00002IVIT0VIVI
09VIVOl000001P2c/k<5o`0000H0/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`040000001V
IVH0IVIV000000<0C4a<00<0000003<c<oooool00oooool00`00003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Wooooo00<0Y7n/0<Kkj?ooool00_ooool:0:Vmj0<0Z;gX00H0YkgY0:Rmj@2X_NT0
001L03<fY@1NDJ/207QNY`80SVZU0P2MM:@20:QlX`<0]HRU0P2fRjP20<>HZ`80^IFb00D0c;2n09RM
e`2HWML003k101Ta[00205I;Z@80KeVX0P2;JJL20:1gY@@0[h:T00<0^XZT0<RHY@38V:D00P3S]ZL0
0`3keZ00j^5eooooo`0Pooooo`03000HYP1]Jkl0KF^o00<0V7je0`2aRZd01@30TjP0bYfY0<ZMZOl0
0000o]j>00[ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo7`00
00000ol000006ATI01TI6@0301TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP04
0000001oOgoo0000o`0000@0VIVI1?l0000409VIV@;o00000`1oOgl00`000000IVIV06IVIP0306IV
IP8000001P1VIVH010000000Ogmo07moOol0000209VIV@;o00002P2c/k<01Ol00000VIVI09VIV@2I
VIWo00000080Ogmo00D0000006IVIP1VIVH0IVIV0000000?04a<C0050000001VIVH0IVIV06IVIP00
00000`1oOgl01Ol00000VIVI09VIV@2IVIWo000000H0/k>c00Go00000<c<c03<c<`0c<c<o`000006
0;>c/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl010000000IVIV06IVIP00000304a<C0030000
000c<c?ooooo00?ooooo00<00000ooooooooool07?ooool00ol0003oooooooooo`0^ooooo`X0ZKgX
00P0Z;gX0:Vmj02Y_NP0Z;gY0:Vmj02X_NT001^O03<fY@80N5jW0P2>JZD209edY080Z7bS0`2eR:D0
1@2fRjP0`iR[0<>HZ`33V:/0^IFb0080c;2n00H0j>S?06O?nonY_nT06C6/01l_Z01FBjT206mIZ080
RfVW0`2PMjD30:n2Y0<0b9RU00<0gk:X0>>fY`3keZ008_ooool0102Y=P00A5S104AH`@1]Jkl209Qn
]@80/HZ]00H0]Y:b0<ZMZ@3:WJT0bYfY0>:i[_l0000:ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`0400000?ooooooooooooooob000000100I6AT01`000000<c<c03<c<`0c<c<0000004a<C000
00000P1VIVH00`000000Ogmoo`00000309VIV@?o0000102c/k<4o`000080VIVI00Go000007moO`1o
Ogl0Ogmo0000000:06IVIP8000000P1oOgl01?l00000VIVI09VIVOl000020;>c/`go00000P2IVIT0
1?l00000Ogmo07moOol0000306IVIP03o`00001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH00P1V
IVH010000000Ogmo07moOol0000309VIV@03o`00002c/k<0/k>c00@0/k>c00?o00000<c<c03<c<`0
0`3<c<`00ol00000/k>c0;>c/`030;>c/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl010000000
IVIV06IVIP00000304a<C0030000000c<c?ooooo00?ooooo00<00000ooooooooool07Oooool00ol0
003oooooooooo`0^ooooo`l0ZKgX00@0001T03<fY@1UDZL0N5jW0P2>JZD209edY0030:QlX`2^PJ@0
]HRU0080]HRU1033V:/30<b`_P070>SXconY_^SoZKkXojVnj00I<J`07bnX05I;Z@0206mIZ00408]Y
Y`2PMjD0X7NU0:1gY@<0[h:T0P38V:D20=nbZ0030?_FX03ZhGGooooo02;ooooo00<001RV04AH`@14
F<400P2HO[D00`2aRZd0]Y:b0;JB/P020<ZMZ@80h[V^00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolO000000@06ATI00L0000003<c<`0c
<c<0<c<c0000001<C4`000000080IVIV00?o000007moOol000000P2IVIT2o`0000<0/k>c1?l00004
0;>c/`03o`00002IVIT0VIVI00;o00000P1oOgl00ol0000000000000000506IVIP8000000`1oOgl0
1Ol00000VIVI09VIVOl00000/k>c00;o00002`3<c<`00ol00000/k>co`00000209VIV@04o`00001o
Ogl0Ogmo00000080IVIV00<0000004a<C01<C4`02`1<C4`00`000000IVIV06IVIP0206IVIP040000
001oOgl0Ogmoo`0000<0VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c0040<c<c003
o`00002c/k<0/k>c00<0/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`040000001VIVH0IVIV
000000<0C4a<00<0000003<c<oooool00oooool00`00003oooooooooo`0Nooooo`;o0000;oooool?
0:Vmj00303<fY@1UDZL0IE:W0080SVZU00<0WGBT0:1gY@2^PJ@00P2^PJ@20;F8Y@070<:EY`33V:/0
`iR[0<>HZ`3H/K00c;2n0>SXc`04ojVmj0030000MP0O;jP07bnX0080KeVX0P2;JJL20:1gY@80[h:T
0P2lSjL01038V:D0gk:X0=nbZ03kfj8Uooooo`80A5S10P2?Okd40;JB/P050<ZMZ@3R^Jh0h[V^oooo
ool000002Oooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolO0000
00@06ATI00L0000003<c<`0c<c<0<c<c0000001<C4`000000080IVIV00D0000007moOol00000VIVI
o`0000030;>c/`;o0000103<c<`2o`000080/k>c00Go000009VIV@2IVIT0VIVIo`00000507moO`03
0000001VIVH0IVIV008000001@1oOgl01Ol00000VIVIo`00002c/k?o000000D0c<c<1?l000040<c<
c006o`00002c/k<0/k>co`00002IVIWo00000P1oOgl010000000IVIV06IVIP00000=04a<C0030000
001VIVH0IVIV0080IVIV00@0000007moO`1oOgoo00000`2IVIT00ol00000/k>c0;>c/`040;>c/`03
o`00003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<00`2c/k<01Ol00000VIVI09VIV@2IVIWo0000
00<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooo
oooo023ooooo00?o0000ooooooooool0;Oooool>0:Vmj0030000R`1UDZL0IE:W0080RFRV0P2PMjD3
0:j1Y0030;F8Y@32UJL0`YFW0080`iR[0P3H/K000`3eg[<0b^5eojVmj004ooooo`807bnX00@0DDf^
06mIZ02;JJL0RfVW0P2PMjD01@2_PZ@0_8nW0;b?Y`2lSjL0b9RU0080gk:X00<0nm^Rooooooooool0
8oooool00`007:T0A5S108mo_@0208mo_@<0]Y:b00<0bYfY0>:i[P3fk9L00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooal00000
100I6AT010000000<c<c03<c<`00000204a<C0050000001VIVH0000007moOol000000P2IVIT01?l0
0000/k>c0;>c/ol000080<c<c004o`00002c/k<0/k>co`0000<0VIVI00?o000007moO`1oOgl00`1o
Ogl2000000H0Ogmo00?o000009VIVOl000000P2c/k<01?l00000c<c<0<c<c03<c<`2o`0000@0i^KV
0_l000020<c<c009o`00002c/k<0/k>c0;>c/ol00000VIVIo`00001oOgl000000080IVIV00<00000
04a<C01<C4`02`1<C4`00`000000IVIV06IVIP0206IVIP040000001oOgl0Ogmoo`0000<0VIVI00?o
00000;>c/`2c/k<01@2c/k<01Ol00000c<c<0<c<c03<c<co000000H0/k>c00Go000009VIV@2IVIT0
VIVIo`00000307moO`040000001VIVH0IVIV000000<0C4a<00<0000003<c<oooool00oooool00`00
003oooooooooo`0Qooooo`03o`000?oooooooooo02kooooo302Y_NP00`0006@0<cJU06EBY`0208UX
YP80X7NU0`2^PJ@01@2eR:D0`YFW0<:EY`32UJL0`iR[0080f;6`00<0mMjcooooooooool01Oooool0
0`0O;jP0DDf^055=[P0208]YY`80X7NU102lSjL20=nbZ0030?_KXP34ceCooooo02Gooooo00@001bY
04AH`@2?Okd0Sgnm0`2fT[820>:i[PCooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`002Oooool01000003ooooooooooooooolO000000<06ATI00L0000003<c<`0c<c<0<c<c
0000001<C4`000000080IVIV00D0000007moOol00000VIVIo`0000020;>c/`03o`00003<c<`0c<c<
0080c<c<0_l000040<c<c004o`00002c/k<0/k>co`000080VIVI00?o000007moO`1oOgl02P1oOgl0
1_l00000VIVI09VIVOl00000/k>co`0000<0c<c<00?o00000>KViP3Vi^H01P3Vi^H01?l00000c<c<
0<c<c?l000020;>c/`03o`00002IVIWo00000080Ogmo00@0000006IVIP1VIVH000003@1<C4`01@00
0000IVIV06IVIP1VIVH0000000<0Ogmo00Go000009VIV@2IVIT0VIVIo`0000070;>c/`Co00001P2c
/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000
<c<cooooo`03ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool0;_ooool:0:Vmj0;o
ZKgX00@0<cJU06EBY`29J:H0RFRV0`2PMjD20:j1Y0@0`YFW0P3H/K000`3eg[<0b^5eooooo`07oooo
o`0501l_Z01ACJh0QFb_08E/[`2PMjD00P2XPZ/30;b?Y`80gk:X00<0nm^Rooooooooool09_ooool0
1@007:T0Sgnm08mo_@2?Okd0]Y:b0080bK?500<0h[V^ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooal000000`0I
6AT02@000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0000000207moO`05o`00002IVIWo0000
0;>c/ol00000103<c<`00ol00000i^KV0>KViP02o`0000<0c<c<00Co00000;>c/`2c/k?o00000P2I
VIT00ol00000Ogmo07moO`0807moO`04o`00002IVIT0VIVIo`000080/k>c00Co00000<c<c03<c<co
00002P3Vi^H01_l00000c<c<0<c<c?l00000/k>co`000080VIVI00?o000007moO`0000000P1VIVH0
0`000000C4a<04a<C00;04a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl01Ol00000VIVI09VI
V@2IVIWo00000140/k>c00Go000009VIV@2IVIT0VIVIo`00000307moO`040000001VIVH0IVIV0000
00<0C4a<00<0000003<c<oooool00oooool00`00003oooooooooo`0Sooooo`03o`000?oooooooooo
02kooooo202Y_NP3ojVmj0030000R`1UDZL0IE:W0080RFRV0P2PMjD20:j1Y0@0`YFW00<0fJn]0=Ra
/03eg[<02Oooool010000700DDf^08E/[`25K:l30:R2Z`<0_8nW00<0e:f`0=nbZ03kfj80:Oooool3
07J@g`<0bK?51_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0009oooo
o`0400000?oooooooooooooooal000000`0I6AT02@000000<c<c03<c<`0c<c<0000004a<C0000000
IVIV0000000207moO`05o`00002IVIWo00000;>c/ol000000`3<c<`00ol00000i^KV0>KViP030>KV
iP04o`00003<c<`0c<c<o`000080/k>c00Co000009VIV@2IVIWo00002P1oOgl01?l00000VIVI09VI
VOl000020;>c/`04o`00003<c<`0c<c<o`0000@0i^KV0_l000040>KViP06o`00003<c<`0c<c<o`00
002c/k?o00000P2IVIT00ol00000Ogmo0000000206IVIP030000001<C4`0C4a<00/0C4a<00D00000
06IVIP1VIVH0IVIV0000000307moO`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<03P2c
/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000
<c<cooooo`03ooooo`0300000?oooooooooo02Cooooo0_l0000_ooooo`<0ZKgX2?nY_NP206EBY`80
RFRV0P2PMjD00`2^PJ@0^XjX0;Z>Z0020<:EY`80fJn]00<0n=j]0;C>Eoooool02Oooool2055=[P04
08E/[`2XPZ/0Z8:[0:R2Z`80_8nW0P3D[K000`3kfj;oooooooooo`0Yooooo`<0MY3O00<0bK?5oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009ooooo`04
00000?oooooooooooooooah00000100I6AT010000000<c<c03<c<`00000204a<C0090000001VIVH0
000007moOol00000VIVIo`00002c/k?o000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H01Ol00000
c<c<0<c<c03<c<co00000080/k>c00Co000009VIV@2IVIWo0000201oOgl01ol00000VIVI09VIV@2I
VIWo00000;>c/ol000000P3<c<`00ol00000i^KV0>KViP020>KViP04o`00003oool0ooooo`0000@0
i^KV00So00000<c<c03<c<co00000;>c/ol00000VIVIo`000080Ogmo00@0000006IVIP1VIVH00000
3@1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00Go000009VIV@2IVIT0VIVIo`00000?0;>c
/`05o`00002IVIT0VIVI09VIVOl000000`1oOgl010000000IVIV06IVIP00000304a<C0030000000c
<c<0<c<c00Cooooo00<00000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`[oZKgX00@0
=c^Y06EBY`29J:H0RFRV0P2PMjD0102^PJ@0^XjX0;Z>Z032UJL30=V_[@030?SN[Ooooooooooo00Wo
oooo00@0001`055=[P25K:l0QFb_0`2XPZ/0102lSjL0e:f`0=B]/03hj[0gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo7P000004
01TI6@040000000c<c<0<c<c00000080C4a<00T0000006IVIP000000Ogmoo`00002IVIWo00000;>c
/ol000000`3<c<`00ol00000i^KV0>KViP050>KViP04o`00003<c<`0c<c<o`000080/k>c00Co0000
09VIV@2IVIWo0000201oOgl01ol00000VIVI09VIV@2IVIWo00000;>c/ol000000P3<c<`01Ol00000
i^KV0>KViP3Vi^Ko000000<0oooo0_l000030>KViP08o`00003<c<`0c<c<o`00002c/k?o000009VI
VOl0000207moO`040000001VIVH0IVIV000000d0C4a<00D0000006IVIP1VIVH0IVIV0000000307mo
O`03o`00002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<02`2c/k<00ol00000VIVI09VIV@0209VI
V@05o`00001oOgl0Ogmo07moO`0000000P1VIVH01@000000C4a<04a<C01<C4`000000080<c<c1?oo
ool00`00003oooooooooo`0Wooooo`03o`000?oooooooooo02gooooo2?nY_NP00oooool0002;03Lk
Z@0208UXYP030:1gY@2WPJ/0^XjX0080^XjX00D0`YFW0=V_[@3I[jd0n=j]0;C>E`0<ooooo`03000L
Z@25K:l0QFb_0080Z8:[00D0^Z6o0=B]/03D[K00e:f`0?SZ/00hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo7P00000401TI6@04
0000000c<c<0<c<c00000080C4a<00T0000006IVIP000000Ogmoo`00002IVIWo00000;>c/ol00000
0`3<c<`00ol00000i^KV0>KViP050>KViP04o`00003<c<`0c<c<o`000080/k>c00Co000009VIV@2I
VIWo0000201oOgl01ol00000VIVI09VIV@2IVIWo00000;>c/ol000000P3<c<`00ol00000i^KV0>KV
iP020>KViP03o`00003ooooo000000D0i^KV00So00000<c<c03<c<co00000;>c/ol00000VIVIo`00
0080Ogmo00@0000006IVIP1VIVH000003@1<C4`00`000000IVIV06IVIP0206IVIP04o`00001oOgl0
Ogmoo`0000D0VIVI00?o00000;>c/`2c/k<02@2c/k<00ol00000VIVI09VIV@0309VIV@05o`00001o
Ogl0Ogmo07moO`0000000P1VIVH01@000000C4a<04a<C01<C4`000000080<c<c1?ooool00`00003o
ooooooooo`0Xooooo`03o`000?oooooooooo02gooooo0onY_NP6ooooo`0303LkZ@21JJl0PFV_0080
Yh6[0`2jSZP0103AZk80fJn]0=V_[@3hgZd=ooooo`04000LZ@1_NLd0KgW=0:R2Z`<0^Z6o00<0e:f`
0?SZ/?ooool0>Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`0400000?oooooooooooooooah00000100I6AT010000000<c<c03<c<`00000204a<C0090000001V
IVH0000007moOol00000VIVIo`00002c/k?o000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H01?l0
0000c<c<0<c<c?l000030;>c/`04o`00002IVIT0VIVIo`0000P0Ogmo00Oo000009VIV@2IVIT0VIVI
o`00002c/k?o00000080c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000i^KV0>KViP040>KViP08
o`00003<c<`0c<c<o`00002c/k?o000009VIVOl0000207moO`040000001VIVH0IVIV000000h0C4a<
00D0000006IVIP1VIVH0IVIV0000000307moO`03o`00002IVIT0VIVI00<0VIVI0ol000060;>c/`;o
00001@2IVIT01Ol00000Ogmo07moO`1oOgl0000000<0IVIV00D0000004a<C01<C4`0C4a<00000002
03<c<`Cooooo00<00000ooooooooool0:Oooool2o`0002gooooo00?o0000ooooooooool01_ooool0
0`0g>jT0PFV_085Y[`030:N1Z`80^XjX0P3AZk800`3I[jd0n=j]ooooo`0=ooooo`03000LZ@1_NLd0
^Z6o00<0^Z6o00<0e:f`0?SZ/?ooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo0009ooooo`0400000?oooooooooooooooal000000`0I6AT02@000000<c<c03<c<`0c
<c<0000004a<C0000000IVIV0000000207moO`05o`00002IVIWo00000;>c/ol000000`3<c<`00ol0
0000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c?l000000`2c/k<00ol00000VIVIo`00000:
07moO`04o`00002IVIT0VIVIo`000080/k>c00Co00000<c<c03<c<co00002P3Vi^H01_l00000c<c<
0<c<c?l00000/k>co`000080VIVI00?o000007moO`0000000P1VIVH00`000000C4a<04a<C00=04a<
C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmoo`00000709VIV@Ko00001`2IVIT0
1Ol00000Ogmo07moO`1oOgl000000080IVIV00<0000004a<C01<C4`00P1<C4`00ol00000<c<c03<c
<`04ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`06ooooo`030=5[000g>jT0PFV_00<0Yh6[00D0^XjX0=6[/P3AZk80dJ^b0?K[]P0@ooooo`80KgW=
0`2jXKl00`33o]Goooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool000Wooooo00@00000oooooooooooooooo7`00000301TI6@09o`00000c<c<0<c<c03<c<`00
0000C4a<0000001VIVH000000080Ogmo00Co000009VIVOl00000/k>c0_l000030<c<c0Co0000103<
c<`01?l00000/k>c0;>c/ol0000209VIV@03o`00001oOgl0Ogmo00P0Ogmo00Co000009VIV@2IVIWo
00000P2c/k<01?l00000c<c<0<c<c?l0000:0>KViP06o`00003<c<`0c<c<o`00002c/k?o00000P2I
VIT00ol00000Ogmo0000000206IVIP030000001<C4`0C4a<00<0C4a<100000000ol00000000004a<
C00404a<C005o`00001VIVH0IVIV06IVIP000000101oOgl2o`000140VIVI00Go000007moO`1oOgl0
Ogmo0000000306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<01?ooool00`00003o
ooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00`0g>jT0
PFV_085Y[`020:N1Z`050;Z>Z03AZk80dJ^b0=6[/P3fjkH04oooool00`2jXKl0`okEooooo`0moooo
o`05o`000?ooooooooooooooool000002oooool000Wooooo00@00000oooooooooooooooo7`000003
01TI6@090000000c<c<0<c<c03<c<ol00000C4a<0000001VIVH000000080Ogmo00?o000009VIVOl0
00000`2c/k<00ol00000c<c<0<c<c0070<c<c004o`00002c/k<0/k>co`0000<0VIVI00?o000007mo
O`1oOgl02@1oOgl01_l00000VIVI09VIVOl00000/k>co`0000<0c<c<00?o00000>KViP3Vi^H01P3V
i^H01?l00000c<c<0<c<c?l000020;>c/`06o`00002IVIT0VIVIo`00001oOgl000000P1VIVH00`00
0000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`01@00
0000IVIV06IVIP1VIVH0000000D0Ogmo00?o000009VIV@2IVIT03@2IVIT00ol00000Ogmo07moO`02
07moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c03<c<`04ooooo`0300000?oo
oooooooo02gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`030000N021
JJl0PFV_0080Yh6[0`3AZk800`3fjkKoooooooooo`1Cooooo`04o`000?ooooooooooo`0000_ooooo
0009ooooo`0400000?oooooooooooooooal00000100I6AT010000000<c<c03<c<`00000204a<C003
0000001VIVH000000080Ogmo00?o000009VIVOl000000`2c/k<3o`0000D0c<c<00Co00000;>c/`2c
/k?o00000`2IVIT00ol00000Ogmo07moO`0207moO`@000001@1oOgl01Ol00000VIVI09VIVOl00000
/k>c00;o00000P3<c<`3o`000080i^KV0ol000020<c<c004o`00002c/k<0/k>co`000080VIVI00?o
000007moO`0000000P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00H0<c<c00<0
000004a<C01<C4`00`1<C4`010000000IVIV06IVIP1VIVH2000000@0Ogmo00?o000009VIV@2IVIT0
302IVIT01Ol00000Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C01<C4`00P1<C4`010000000
<c<c03<c<`0c<c<4ooooo`0300000?oooooooooo02kooooo0_l0000Xooooo`03o`000?oooooooooo
00Sooooo0P1PL/h0102WPJ/0^J2o0;VP_`3AZk820?K[]UKooooo00?o0000ooooool000002oooool0
00Wooooo00@00000oooooooooooooooo7`00000401TI6@070000000c<c<0<c<c03<c<`000000C4a<
0000000206IVIP040000001oOgoo000009VIV@?o0000102c/k<5o`0000030;>c/ol0003o00000080
VIVI0_l0000307moO`03o`0000000000IVIV00<0IVIV0`00000307moO`04o`00002IVIT0VIVIo`00
0080/k>c0_l000030<c<c0;o0000103<c<`2o`0000050;>c/ol00000VIVI09VIVOl000000P1oOgl0
1?l00000IVIV06IVIP00000304a<C003o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo1?l0000809VIV@;o0000101o
Ogl01@000000IVIV06IVIP1VIVH0000000@0C4a<00@0000003<c<`0c<c<0<c<c1?ooool00`00003o
ooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool01@1PL/h0
^J2o0;VP_`2iX;l0dJ^b05Sooooo00?o0000ooooool000002oooool000Wooooo00@00000oooooooo
oooooooo7`00000401TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000306IVIP03o`00001o
Ogoo000000<0VIVI00?o00000;>c/`2c/k<01P2c/k<01Ol00000VIVI09VIV@2IVIWo000000<0Ogmo
0P00000906IVIP040000001oOgl0Ogmoo`000080VIVI00?o00000;>c/`2c/k<00P2c/k<3o`000080
c<c<1?l000020;>c/`07o`00002IVIT0VIVI09VIVOl00000Ogmo0000000306IVIP040000001<C4`0
C4a<000000/0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo00D0Ogmo0ol0000409VIV@03o`00001oOgl0Ogmo00@0Ogmo00D0000006IVIP1VIVH0IVIV
0000000404a<C0040000000c<c<0<c<c03<c<`Cooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00<0^J2o0;[mdOooool0FOooool00ol0003o
ooooo`00000:ooooo`002Oooool01000003ooooooooooooooolP000000@06ATI00L0000003<c<`0c
<c<0<c<c0000001<C4`000000080IVIV00<0000007moO`1oOgl00_l0000209VIV@So00000`2IVIT0
1Ol00000Ogmo07moO`1oOgl0000000`0IVIV00<0000007moO`1oOgl00_l00000102IVIWo0000o`00
0?l000040;>c/`;o0000102c/k<2o`000080VIVI0_l0000207moO`040000001VIVH0IVIV000000<0
C4a<00<0000003<c<`0c<c<02P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl01`1oOgl4o`0000L0Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<
C0040000000c<c<0<c<c03<c<`Cooooo00<00000ooooooooool0<_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06Sooooo0_l0000:ooooo`002Oooool01000003ooooooooooooooolP
000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV000000<0Ogmo
00?o000009VIV@2IVIT02@2IVIT01Ol00000Ogmo07moO`1oOgoo000000D0IVIV1@00000406IVIP05
0000001oOgl0Ogmo07moOol000000`2IVIT2o`0000L0/k>c00Go000009VIV@2IVIT0VIVIo`000003
07moO`040000001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<0300c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl04P1oOgl01@000000IVIV06IV
IP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<4ooooo`0300000?oooooooooo03?ooooo
0_l0000Sooooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`002Oooool01000003ooooooooo
oooooolQ000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV0000
00<0Ogmo2ol0000207moO`8000000P1VIVH200000003o`0000000000C4a<00@0C4a<00?o00000000
000000000P1VIVH010000000Ogmo07moO`1oOgl2o`0000<0VIVI1ol000001@2IVIWo0000o`000?l0
0000Ogmo0080000000Co000006IVIP00003o00000`1<C4`00ol00000<c<c03<c<`0>03<c<`03o`00
00000000C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH200000180Ogmo00D0000006IVIP1VIVH0
IVIV0000000304a<C0030000000c<c<0<c<c0080<c<c1?ooool00`00003oooooooooo`0eooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo0009ooooo`040000
0?ooooooooooooooob4000001@0I6AT01Ol00000<c<c03<c<ol0000000000080C4a<00Co00000000
001VIVKo00000P00000:07moO`<000000`1VIVH00`000000C4a<04a<C00:04a<C080000000<0IVIV
o`00000000000`1oOgl2o`0000P0VIVI00Go000007moO`1oOgl0Ogmo0000000306IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<01P0c<c<3000000P0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00l0Ogmo00D0000006IVIP1VIVH0IVIV
0000000304a<C0030000000c<c<0<c<c0080<c<c1?ooool00`00003oooooooooo`0fooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`0400000?oo
ooooooooooooob800000100I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C000
00000`1VIVH400000080Ogmo1000000406IVIP8000003`1<C4`010000000IVIV06IVIP00000407mo
O`So00000`1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<0100c<c<3
000000<06ATI0P00000703<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH0
0`000000Ogmo07moO`0@07moO`050000001VIVH0IVIV06IVIP0000000`1<C4`010000000<c<c03<c
<`0c<c<4ooooo`0300000?oooooooooo03Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1Looooo`Co00005?ooool000Wooooo00@00000oooooooooooooooo8P00000501TI6@030000
000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0C4a<0`00000406IVIP800000101VIVH200000003
o`0000000000C4a<00@0C4a<00?o00000000000000001@00000504a<C080000000<0IVIV00000?l0
00000P00000907moO`8000000P1VIVH2000000<0C4a<0P00000403<c<`0300000?l00000000000P0
6ATI00<0000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV0080
IVIV00<0000007moO`1oOgl03`1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00@0000003<c
<`0c<c<0<c<c1?ooool00`00003oooooooooo`0hooooo`;o00007_ooool00ol0003oooooooooo`1H
ooooo`Co00006?ooool000Wooooo00@00000oooooooooooooooo8P00000601TI6@030000000c<c<0
<c<c0080<c<c00?o00000000001<C4`00`1<C4`400000080IVIV1000000704a<C0800000200c<c<2
000000D0C4a<00<0000006IVIP1VIVH00P1VIVH900000080IVIV0P00000304a<C08000001@0c<c<0
0`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`0101<C4`0
1Ol00000IVIV06IVIP1VIVH000000140Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0040000
000c<c<0<c<c03<c<`Cooooo00<00000ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05Cooooo1?l0000Looooo`002Oooool01000003ooooooooooooooolS000000H0
6ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00504a<C08000001`1<C4`4000000`0
<c<c0`00000304a<C0<000002P1VIVH2000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0<01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000
IVIV06IVIP1VIVH0000000P0Ogmo1Ol0000507moO`050000001VIVH0IVIV06IVIP0000000`1<C4`0
0`000000<c<c03<c<`04ooooo`0300000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo00@00000oooooooooooooooo90000006
01TI6@030000000c<c<0<c<c00<0<c<c0P00000<04a<C003o`0000000000<c<c0180<c<c00<00000
04a<C01<C4`00`1<C4`:000000D0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0>
01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1V
IVH0000000H0Ogmo00?o000009VIV@2IVIT00`2IVIT00ol00000Ogmo07moO`0207moO`050000001V
IVH0IVIV06IVI_l000000`1<C4`00ol00000<c<c03<c<`04ooooo`0300000?oooooooooo03cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co00008oooool000Wooooo00@0
0000oooooooooooooooo9P00000501TI6@@000000`0c<c<<000000H0<c<c2`00000503<c<`03o`00
00000000C4a<00l0C4a<0P00000503<c<`8000004P0I6AT00ol00000<c<c03<c<`0303<c<`030000
001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000507moO`03o`00002IVIT0VIVI00D0
VIVI00?o000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00<0000003<c
<`0c<c<01?ooool00`00003oooooooooo`0mooooo`;o00006Oooool00ol0003oooooooooo`19oooo
o`Co00009oooool000Wooooo00@00000oooooooooooooooo9`00000801TI6@030000000c<c<0<c<c
00h0<c<c1000000;01TI6@<00000100c<c<3000000X0C4a<0`00000403<c<`<00000500I6AT00`00
0000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV00000004
07moO`03o`00002IVIT0VIVI00L0VIVI0_l0000207moO`050000001VIVH0IVIV06IVIP0000000P1<
C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`15ooooo`Co0000:oooool000Wooooo00@00000oooooooooooooooo:000
000801TI6@<000002P0c<c<3000001806ATI00<0000003<c<`0c<c<0100c<c<:000000H0<c<c00<0
000001TI6@0I6AT05P0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000
0`1VIVH01@000000Ogmo07moO`1oOgoo000000`0VIVI00Co000007moO`1oOgl000000`1VIVH01@00
0000C4a<04a<C0000000<c<c00Cooooo00<00000ooooooooool0@?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04?ooooo0ol0000_ooooo`002Oooool01000003ooooooooooooooolY
000000X06ATI2P00000F01TI6@<00000400c<c<3000001X06ATI00<0000003<c<`0c<c<00P0c<c<0
1@000000C4a<04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgoo0000102IVIT7o`0000<0VIVI
00Co000007moO`1oOgl000000P1VIVH01@000000C4a<04a<C0000000<c<c00Cooooo00<00000oooo
ooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo1?l0000boooo
o`002Oooool01000003ooooooooooooooolY00000003o`00000000006ATI02X06ATI0`00000:03<c
<`<000002`0I6AT:000000T06ATI00Go000003<c<`0c<c<0<c<c0000000304a<C0050000001VIVH0
IVIV06IVIP0000000P1oOgl01Ol00000VIVI09VIV@2IVIWo000000L0/k>c00Oo000009VIV@2IVIT0
VIVIo`00001oOgl000000080IVIV00D0000004a<C01<C4`0000003<c<`04ooooo`0300000?oooooo
oooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Oooool01000
003oooooooooooooool]000002`06ATI2P00000=01TI6@`00000200I6AT01@000000<c<c03<c<`0c
<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`04o`00002IVIT0VIVIo`0000T0
/k>c00Co000009VIV@2IVIWo00000P1oOgl010000000IVIV06IVIP00000204a<C00300000?oooooo
oooo00;ooooo00<00000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Oooooo1?l0000jooooo`002Oooool01000003oooooooooooooool^000001H06ATI2P00000P
01TI6@l00000200I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH00000
0P1oOgl01?l00000VIVI09VIVOl0000;0;>c/`06o`00002IVIT0VIVIo`00001oOgl000000P1VIVH0
10000000C4a<04a<C0000004ooooo`0300000?oooooooooo04Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00@00000oooooooooooooooo;P00
00000ol00000000000000002000000X06ATI5P00000G01TI6A@000001`0I6AT01@000000<c<c03<c
<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl01?l00000VIVI09VIVOl000040;>c
/`Go00000`2c/k<01_l00000VIVI09VIVOl00000Ogmo00000080IVIV00@0000004a<C01<C4`00000
0oooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
<?ooool3o`0004;ooooo0009ooooo`0400000?oooooooooooooooeH000004`0I6ATE000000L06ATI
00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo00Co000009VI
V@2IVIWo00000P2c/k<2o`0000D0c<c<00Wo00000;>c/`2c/k<0/k>co`00002IVIWo000007moO`00
00000P1VIVH010000000C4a<04a<C0000003ooooo`0300000?oooooooooo04Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wooooo00@00000oooooooo
ooooooooF@00000=01TI6AT000001`0I6AT010000000<c<c03<c<`00000204a<C0040000001VIVH0
IVIV00000080Ogmo00?o000009VIVOl000000P2c/k<00ol00000c<c<0<c<c0060<c<c004o`00002c
/k<0/k>co`000080VIVI00?o000007moO`0000000P1VIVH00`000000C4a<00000003ooooo`030000
0?oooooooooo04Sooooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo1?l00019ooooo`002Ooo
ool01000003ooooooooooooooomR00000003o`0000000000000001/000001P0I6AT010000000<c<c
03<c<`00000204a<C0060000001VIVH0IVIV0000001oOgoo00000P2IVIT00ol00000/k>co`00000:
0<c<c008o`00002c/k<0/k>co`00002IVIWo000007moO`00000206IVIP030000001<C4co000000?o
oooo00<00000ooooooooool0B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Co
oooo1?l0001=ooooo`002Oooool01000003ooooooooooooooon0000000H06ATI00@0000003<c<`0c
<c<000000P1<C4`01P000000IVIV06IVIP000000Ogmoo`000080VIVI00?o00000;>c/ol000002P3<
c<`02?l00000/k>c0;>c/ol00000VIVIo`00001oOgl000000P1VIVH00`000000C4a<ooooo`03oooo
o`0300000?oooooooooo04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`?o0000DOooool000Wooooo00@00000ooooooooooooooooP@00000501TI6@040000000c<c<0<c<c
00000080C4a<00H0000006IVIP1VIVH0000007moOol0000209VIV@03o`00002c/k?o000000X0c<c<
00So00000;>c/`2c/k?o000009VIVOl00000Ogmo00000080IVIV00<0000004a<C?ooool00oooool0
0`00003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4
o`0005Cooooo0009ooooo`0400000?oooooooooooooooh4000001@0I6AT01@000000<c<c03<c<`0c
<c<000000080C4a<00L0000006IVIP000000Ogmoo`00002IVIWo00000080/k>c00?o00000<c<c03<
c<`02@3<c<`01Ol00000/k>co`00002IVIWo00000080Ogmo00@0000006IVIP000000C4a<1?ooool0
0`00003oooooooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool0
00Wooooo00@00000ooooooooooooooooP00000000ol000006ATI01TI6@0301TI6@050000000c<c<0
<c<c03<c<`0000000P1<C4`01`000000IVIV0000001oOgoo000009VIVOl000000P2c/k<00ol00000
c<c<0<c<c0090<c<c005o`00002c/k?o000009VIVOl000000P1oOgl010000000IVIV0000001<C4`4
ooooo`0300000?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0E
ooooo`Co0000G?ooool000Wooooo00@00000ooooooooooooooooP@00000501TI6@050000000c<c<0
<c<c03<c<`0000000P1<C4`01`000000IVIV0000001oOgoo000009VIVOl000000P2c/k<00ol00000
c<c<0<c<c0090<c<c005o`00002c/k?o000009VIVOl000000P1oOgl01@000000IVIV0000001<C4`0
000000?ooooo00<00000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo0ol0001Pooooo`002Oooool01000003ooooooooooooooon2000000D06ATI00L00000
03<c<`0c<c<0<c<c0000001<C4`000000080IVIV00D0000007moOol00000VIVIo`0000020;>c/`03
o`00003<c<`0c<c<00L0c<c<00?o00000;>c/ol000000P2IVIT01Ol00000Ogmo0000001VIVH00000
0080C4a<00D00000oooooooooooooooo0000001Cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?oooooooooooooooh<00000100I6AT0
1`000000<c<c03<c<`0c<c<0000004a<C00000000P1VIVH00`000000Ogmoo`00000209VIV@03o`00
002c/k?o000000P0c<c<0_l000002@2c/k?o000009VIV@2IVIWo000007moO`000000IVIV00000002
04a<C00500000?ooooooooooooooo`000000E?ooool2o`0000?ooooo00?o0000ooooooooool02_oo
ool4o`0006Oooooo0009ooooo`0400000?oooooooooooooooh<00000100I6AT01`000000<c<c03<c
<`0c<c<0000004a<C00000000P1VIVH00`000000Ogmoo`00000209VIV@03o`00002c/k<0/k>c00?o
00000`3<c<`2o`0000<0/k>c00So000009VIV@2IVIWo000007moO`000000IVIV00000080C4a<00D0
0000oooooooooooooooo0000001Fooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`00
2Oooool01000003ooooooooooooooon4000000@06ATI00L0000003<c<`0c<c<0<c<c0000001<C4`0
00000080IVIV00<0000007moOol000000P2IVIT00ol00000/k>c0;>c/`020;>c/`?o0000102c/k<0
1_l00000VIVI09VIVOl00000Ogmo00000080IVIV00?o000004a<C00000001?ooool00`00003ooooo
ooooo`1Eooooo`03o`000?oooooo000000Gooooo0ol0001_ooooo`002Oooool01000003ooooooooo
oooooon4000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C003o`00001VIVH000000080
Ogmo00Co000009VIV@2IVIWo0000202c/k<2o`000080VIVI00Ko000007moO`1oOgoo000006IVIP00
000204a<C00300000?oooooooooo00;ooooo00<00000ooooooooool0E_ooool2o`000003ooooool0
003o000000;o0000L_ooool000Wooooo00@00000ooooooooooooooooQ000000401TI6@050000000c
<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVI_l0000207moO`;o000000@0VIVIo`000?l0
003o00000`2c/k<2o`000080VIVI0_l0000207moO`040000001VIVH0IVIV00000080C4a<00<00000
ooooooooool00_ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo00@00000oooo
ooooooooooooQ@00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IV
IP00000307moO`04o`00002IVIT0VIVI09VIV@?o00000P2IVIT2o`0000<0Ogmo00@0000006IVIP1V
IVH000000P1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`04
00000?ooooooooooooooohD00000100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00D00000
06IVIP1VIVH0IVIV0000000307moO`?o0000102IVIT00ol00000Ogmo07moO`0207moO`050000001V
IVH0IVIV06IVIP0000000P1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooohD000001@0I6AT01@000000<c<c03<c<`0c<c<000000080
C4a<00@00000o`00001VIVH0IVIV0P00000407moO`Co00000`1oOgl200000080IVIV00D00000o`00
001<C4`0C4a<0000000203<c<`Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
ooooooooooooQP00000501TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`01@000000IVIV06IV
IP1VIVH0000000P0Ogmo0P00000306IVIP050000001<C4`0C4a<04a<C00000000`0c<c<01@00003o
ooooooooooooool000000=7ooooo0009ooooo`0400000?ooooooooooooooohL000001@0I6AT01@00
0000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH0IVIV2000000406IVIP050000001<
C4`0C4a<04a<C00000000`0c<c<00`00003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooohP000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0
C4a<00<00000o`00000000002@1VIVH200000005o`00001<C4`0C4a<04a<C?l000000`0c<c<00`00
00006ATIooooo`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
ohL0000000?o000001TI6@0I6AT00`0I6AT00`000000<c<c03<c<`0203<c<`03o`0000000000C4a<
00<0C4a<0`00000306IVIP<00000101<C4`2000000@0<c<c00<0000001TI6Oooool00oooool00`00
003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon8000000H06ATI0P00000403<c
<`030000001<C4`0C4a<00@0C4a<0`00000604a<C0030000000c<c<0<c<c0080<c<c0P00000201TI
6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooR@00000701TI
6@030000000c<c<0<c<c0080<c<c0`00000904a<C0<00000100c<c<00`0000006ATI01TI6@0201TI
6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooR`00000601TI
6@0300000?l00000000000@0<c<c00<00000o`00000000001P00000603<c<`03o`00000I6AT06ATI
00<06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon<0000
00P06ATI00<0000003<c<`0c<c<03P0c<c<2000000H06ATI00Go0000oooooooooooooooo0000003A
ooooo`002Oooool01000003ooooooooooooooon=000000P06ATI0`00000903<c<`@000001`0I6AT0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
ooooohh000002P0I6AT9000000X06ATI00?o000000000?ooool00oooool00`00003oooooooooo`3?
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo0009oooookKo00004Ooooonfo`0000[ooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2>ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool4000000Oooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?oo
o`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08d0oooo00?o
okK100000?oo]/401?oo]/400ol0003ookK1oonf`@02oonf`@@000001?oo]/44000000CookK100?o
0000oonf`Ooo]/401?oo]/400ol0003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`2=
0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08d0oooo00<00000
oonf`Ooo]/400ooo]/401000003ookK1oonf`Ooo]/42000000cookK10P000003oonf`@0300000?oo
]/7ookK100?ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=
0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08`0oooo00<00000
oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo]/40000000KookK11@0000000ol0003ookK1oonf
`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3oool0R`3oool00`000000oooooonf`@03oonf`@0500000?oo]/7ookK1oonf`@000000
0ooo]/44000000GookK10`000003oonf`@05o`000?oo]/7ookK1oonf`@0000000ooo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo3_oo]/49o`00o`cookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08/0oooo00<000000?oooooo]/40
0_oo]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK10P000004oonf`@@000001?oo]/42000000;o
okK100@00000oonf`Ooo]/4000000ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo08d0oooo2ooo]/43o`00o`WookK100?o003ooonf`Ooo]/402Ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0RP3oool00`000000oooo0?ooo`03oonf`@04
00000?oo]/7ookK1000000;ookK100@00000oonf`Ooo]/7ookK10`000004oonf`@@000000_oo]/40
1000003ookK1oonf`@000002oonf`@0300000?oo]/7ookK100;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool0S@3oool:oonf`@03o`00oooo]/7ookK100_ookK100?o003o
oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R@3oool0
10000000oooo0?ooo`3oool2oonf`@0400000?oo]/7ookK1000000;ookK100<00000oonf`Ooo]/40
0P00000;oonf`@04o`000?oo]/7ookK1000000;ookK100D00000oonf`Ooo]/400000oonf`@02oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo2Ooo]/400ol00?oo
okK1oonf`@0=oonf`@03o`00oooo]/7ookK100OookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo08T0oooo00Co00000?ooo`3oool0oooo0_oo]/401000003ookK1oonf`@000002
oonf`@0300000?oo]/7o000000?ookK120000002oonf`@0400000?oo]/7ookK1000000;ookK100D0
0000oonf`Ooo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo08d0oooo2?oo]/400ol00?oookK1oonf`@0?oonf`@03o`00oooo]/7ookK100KookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08T0oooo00H000000?ooo`3oool0oooo
oonf`@000002oonf`@0400000?oo]/7ookK1000000;ookK100@00000oonf`Ooo]/4000002?oo]/40
0`00003ookK100000003oonf`@0400000?oo]/7ookK1000000;ookK100@00000oooooooooooo0000
2_ooool000Wooooo00?o0000ooooo`3oool0S@3oool8oonf`@03o`00oooo]/7ookK100oookK100?o
003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R03o
ool00`000000oooo0?ooo`020?ooo`05oonf`@00003ookK1oonf`@0000000_oo]/400`00003ookK1
00000002oonf`@0300000?oo]/7ookK100;ookK10_l00004oonf`@0300000?oo]/40000000;ookK1
00@00000oonf`Ooo]/7o00000_oo]/401000003oooooooooool0000:ooooo`002Oooool00ol0003o
oooo0?ooo`2=0?ooo`SookK100?o003ooonf`Ooo]/404?oo]/400ol00?oookK1oonf`@05oonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`280?ooo`030000003oool0oooo0080
oooo00@00000oonf`Ooo]/4000000_oo]/401P00003ookK1oonf`@00003ookK1000000?ookK10_l0
0002oonf`@;o00000ooo]/400ol0003ookK100000002oonf`@0400000?oo]/7ookK1000000;ookK1
00<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool7oonf`@03o`00oooo
]/7ookK1017ookK100?o003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`04o`000?oo]/7ookK1000000;ookK1
00H00000oonf`Ooo]/400000oonf`@000002oonf`@03o`000?oo]/7ookK100CookK100Ko0000oonf
`Ooo]/400000oonf`@000002oonf`@0400000?oo]/7ookK1000000;ookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`OookK100?o003ooonf`Ooo]/401_oo
]/43o`0000SookK100?o003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`0300000?oo]/40000000;ookK100H0
0000oonf`Ooo]/400000oonf`@000002oonf`@03o`000?oo]/7ookK100KookK100?o0000oonf`@00
00000_oo]/401P00003ookK1oonf`@00003ookK1000000;ookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`OookK100?o003ooonf`Ooo]/401Ooo]/45o`00
00SookK100?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0Q`3oool00`000000oooo0?ooo`020?ooo`0400000?oo]/7ookK1000000;ookK100<00000
oonf`@0000000_oo]/400ol0003ookK1o`00000:oonf`@03o`000?oo]/40000000;ookK100D00000
oonf`@00003ookK100000002oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool0S@3oool7oonf`@03o`00oooo]/7ookK100GookK11Ol00008oonf`@03o`00oooo]/7o
okK100CookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08L0oooo00<00000
0?ooo`3oool00P3oool01000003ookK1oonf`@000002oonf`@0300000?oo]/40000000;ookK100<0
0000oonf`Ol000002_oo]/400ol0003ookK100000002oonf`@0500000?oo]/400000oonf`@000000
0_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo1ooo
]/400ol00?oookK1oonf`@05oonf`@Go00002?oo]/400ol00?oookK1oonf`@04oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`270?ooo`030000003oool0oooo0080oooo00@0
0000oonf`Ooo]/4000000_oo]/400`00003ookK100000002oonf`@0300000?oo]/7o000000[ookK1
00?o0000oonf`@0000000_oo]/401@00003ookK100000?oo]/40000000;ookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`OookK100?o003ooonf`Ooo]/40
1_oo]/43o`0000WookK100?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0Q`3oool00`000000oooo0?ooo`020?ooo`0400000?oo]/7ookK1000000;o
okK100<00000oonf`@0000000_oo]/400`00003ookK1o`00000:oonf`@03o`000?oo]/40000000;o
okK100D00000oonf`@00003ookK100000002oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0S@3oool7oonf`@03o`00oooo]/7ookK101;ookK100?o003ooonf`Ooo
]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0Q`3oool00`000000
oooo0?ooo`020?ooo`0400000?oo]/7ookK1000000;ookK100<00000oonf`@0000000_oo]/400`00
003ookK1o`00000:oonf`@03o`000?oo]/40000000;ookK100D00000oonf`@00003ookK100000002
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool7oonf
`@03o`00oooo]/7ookK101;ookK100?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0Q`3oool00`000000oooo0?ooo`020?ooo`0400000?oo]/7ookK1
000000;ookK100<00000oonf`@0000000_oo]/401000003ookK1oonf`Ol00008oonf`@04o`000?oo
]/7ookK1000000;ookK100D00000oonf`@00003ookK100000002oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool7oonf`@03o`00oooo]/7ookK101;ookK1
00?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
QP3oool00`000000oooo0?ooo`030?ooo`0400000?oo]/7ookK1000000;ookK100H00000oonf`Ooo
]/400000oonf`@000003oonf`@;o00001?oo]/42o`0000;ookK100Ko0000oonf`Ooo]/400000oonf
`@000002oonf`@0300000?oo]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool0S@3oool8oonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo]/401Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0QP3oool00`000000oooo0?oo
o`030?ooo`0400000?oo]/7ookK1000000;ookK100@00000oonf`Ooo]/4000000_oo]/400ol0003o
okK1oonf`@02oonf`@Co00001?oo]/400`00003ookK100000002oonf`@0400000?oo]/7ookK1o`00
00;ookK100?o0000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool9oonf`@03
o`00oooo]/7ookK100gookK10_l00?l8oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`260?ooo`030000003oool0oooo00<0oooo00@00000oonf`Ooo]/4000000_oo]/401000
003ookK1oonf`@000003oonf`@0300000?oo]/7ookK100SookK100@00000oonf`Ooo]/4000000_oo
]/400`00003ookK100000003oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0
oooo08d0oooo2_oo]/42o`00o`_ookK10_l00?l:oonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`260?ooo`030000003oool0oooo00<0oooo00@00000oonf`Ooo]/4000000ooo
]/401000003ookK1oonf`@000003oonf`@0300000?oo]/7ookK100KookK100@00000oonf`Ooo]/40
00000_oo]/401000003ookK1oonf`@000003oonf`@0300000?oooooo000000[ooooo0009ooooo`03
o`000?ooool0oooo08d0oooo3?oo]/42o`00o`SookK100?o003ooonf`Ooo]/402_oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0QP3oool00`000000oooo0?ooo`030?ooo`05
00000?oo]/7ookK1oonf`@0000000_oo]/401000003ookK1oonf`@000004oonf`@<000000_oo]/43
000000;ookK100Oo0000oonf`Ooo]/7ookK1o`000?oo]/40000000?ookK100@00000oooooooooooo
00002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool>oonf`@;o003o0ooo]/43o`00o`gookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08D0oooo00<000000?ooo`3oool0
103oool01@00003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/400P000005oonf`@80
00001?oo]/42000000;ookK100@00000oonf`Ooo]/4000000ooo]/401000003oooooooooool0000:
ooooo`002Oooool00ol0003ooooo0?ooo`2=0?oooa3ookK10ol00?l@oonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`240?ooo`030000003oool0oooo00D0oooo00D00000oonf
`Ooo]/7ookK100000003oonf`@0300000?oo]/7ookK100;ookK10P000008oonf`@0500000?oo]/7o
okK1oonf`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`230?ooo`030000003oool0oooo00D0oooo00<000000?oooooo]/400ooo
]/401@00003ookK1oonf`Ooo]/40000000GookK10`000002oonf`@<000000ooo]/401@00003ookK1
oonf`Ooo]/40000000?ookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003o
oooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0600
oooo00<00000o`00000000002P00000D0?ooo`800000203oool00`000000oooooonf`@03oonf`@05
00000?oo]/7ookK1oonf`@0000002?oo]/42000000GookK100D00000oonf`Ooo]/7ookK1o`000004
oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`1F0?ooo`X000003@3oool6
000000d0oooo00<000000?ooo`3oool0203oool00`000000oooooonf`@03oonf`@0500000?oo]/7o
okK1oonf`@0000003_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100D0
0000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo04/0oooo2`00000M0?ooo`@00000203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00CookK100<00000oonf`Ooo]/400_oo
]/400`00003ookK1oonf`@0:oonf`@0300000?oo]/7ookK100?ookK100D00000oonf`Ooo]/7ookK1
00000002oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`180?ooo`<00000;03o
ool3000000<0oooo0P00000;0?ooo`030000003oool0oooo00?ookK100<00000oonf`Ooo]/401?oo
]/400`00003ookK1oonf`@08oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo
]/400`00003ookK1oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0;`3oool8
000000d0oooo1000000b0?ooo`<00000303oool010000000oooo0?ooo`3oool3oonf`@0300000?oo
]/7ookK100CookK100?o0000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100;ookK100@00000oonf`Ooo]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo02/0oooo100000080?ooo`d000006@3oool?000001`0oooo00<000000?ooo`3oool00P3o
ool2oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf
`@03oonf`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/7ookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo02P0oooo0`00000T0?ooo`h000003`3oool4000001L0oooo00<0
00000?ooo`3oool00`3oool00ooo]/400000oonf`@07oonf`@0300000?oo]/7ookK100KookK100<0
0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0400000?oo]/7ookK1oonf`@;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0U0?ooo`<00000803oool700000240oooo1000
000A0?ooo`03o`0000000000oooo00D0oooo00<00000oonf`Ooo]/401_oo]/400ol0003ookK1oonf
`@06oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/401000003ookK1oonf
`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool2oonf`@0300000?oo
]/7ookK100SookK12000000@oonf`@0300000?oo]/7ookK101?ookK13`000008oonf`@8000003_oo
]/400`00003ookK1oonf`@05oonf`@0300000?l0003ookK100KookK100<00000oonf`Ooo]/401ooo
]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK100@00000oonf`Ooo]/7ookK1
0_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooohkookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0280oooo00?ookK100000?oo]/401_oo
]/44000000SookK110000009oonf`@<000001?oo]/4B000000oookK110000006oonf`@0300000?oo
]/7ookK100[ookK100<00000oonf`Ooo]/401?oo]/42000000OookK10P00000;oonf`@0300000?oo
]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/401000003ookK1oonf`Ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool08P3oool00`00003ookK1oonf`@03oonf`@<000001?oo
]/44000000SookK12@000005oonf`@8000005_oo]/48000000OookK100?o0000oonf`Ooo]/401?oo
]/42000000SookK10P000006oonf`@0300000?oo]/7ookK100GookK10P00000=oonf`@0300000?oo
]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/401000003ookK1oonf`Ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool08@3oool00ol0003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100;ookK10`000004oonf`@@0000000Co000000000000000000003?oo]/400`00003o0000
oonf`@05oonf`@`0000000?o00000000000000000`000008oonf`@@000001?oo]/42000000KookK1
1@0000000ol00000000000000007oonf`@03o`000?oo]/7ookK100CookK10P00000@oonf`@03o`00
0?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool08@3oool01P00003ookK1oonf`Ooo]/400000o`0000?o
okK10P000003oonf`@P000001?oo]/43000000KookK10`000004oonf`@@000005Ooo]/45000000Co
okK10`000003oonf`@0300000?oo]/7ookK1017ookK100<00000oonf`Ooo]/401?oo]/400`00003o
okK1oonf`@0Aoonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400`00003o
okK1oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo
S_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0803oool01@000000oooo
oonf`Ooo]/40000000?ookK10P000002oonf`@<000002?oo]/44000000?ookK11P000004oonf`@<0
00001?oo]/4E000000GookK10`000004oonf`@8000000_oo]/42000000oookK10P000005oonf`@80
00001?oo]/4<000000GookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@05
00000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool08P3ooolZoonf`@Ko
003o4Ooo]/49o`00odCookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0
oooo00D000000?ooo`3ooooookK100000003oonf`@0300000?oo]/7ookK1008000000_oo]/4:0000
00?ookK100?o0000oonf`Ooo]/401ooo]/43000000;ookK11@00000Eoonf`@D000000ooo]/400`00
003o000000000003oonf`@0500000?oo]/7ookK1oonf`Ol000003Ooo]/400`00003ookK1oonf`@03
oonf`@8000001?oo]/42000000cookK100?o0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100?ookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000
ooooo`3oool08P3ooolWoonf`@?o003o1_oo]/42o`00o`gookK10_l00?l9oonf`@;o003o9Ooo]/49
o`00oaCookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0oooo00D00000
0?ooo`3ooooookK100000002oonf`@04o`000?oo]/7ookK1o`0000;ookK100<00000o`000?oo]/40
2Ooo]/4200000004oonf`@0000000000000000GookK10P000003oonf`@0300000?l0003ookK100Co
okK15@000005oonf`@8000001?oo]/401@00003ookK1oonf`Ooo]/40000000?ookK10P00000:oonf
`@0300000?oo]/7ookK100?ookK100?o0000oonf`Ooo]/400ooo]/400`00003o0000oonf`@0<oonf
`@8000001?oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100@00000oooo
oooooooo00002_ooool000Wooooo00?o0000ooooo`3oool08P3oool>oonf`@Co003o5Ooo]/400ol0
0?oookK1oonf`@08oonf`@03o`00oooo]/7ookK100WookK100?o003ooonf`Ooo]/402ooo]/400ol0
0?oookK1oonf`@0Ooonf`@?o003o2Ooo]/43o`00oa7ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo01h0oooo00D000000?ooo`3oool0oooo00000003oonf`@0400000?oo]/40
0000oonf`@d000000ooo]/401000003ookK1oonf`Ooo]/45000000CookK100@00000oonf`Ooo]/7o
okK11000000Loonf`@8000000ooo]/401@00003ookK1oonf`Ooo]/40000000CookK100<00000oonf
`Ooo]/401Ooo]/42000000GookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@0?oonf
`@8000000ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oooo
ool000002_ooool000Wooooo00?o0000ooooo`3oool08P3oool;oonf`@?o003o1?oo]/43o`00oa7o
okK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@07oonf`@03o`00oooo]/7ookK100go
okK100?o003ooonf`Ooo]/407?oo]/42o`00o`oookK100?o003ooonf`Ooo]/403_oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool07P3oool01@000000oooo0?ooo`3oool00000
00;ookK100L00000oonf`@00003ookK100000?oo]/40000000?ookK11ol000001Ooo]/4000000000
0000003ookK1008000002?oo]/42000000;ookK10P000004oonf`Aco00000_oo]/42000000;ookK1
00@00000oonf`Ooo]/4000001Ooo]/400`00003ookK1oonf`@02oonf`@8000001_oo]/400`00003o
okK1oonf`@02oonf`@8000001Ooo]/4;000000CookK100Go0000oonf`Ooo]/7ookK100000004oonf
`@0300000?oo]/7ookK100;ookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3o
ool08P3oool:oonf`@03o`00oooo]/7ookK100SookK100?o003ooonf`Ooo]/403Ooo]/400ol00?oo
okK1oonf`@0<oonf`@03o`00oooo]/7ookK100GookK100?o003ooonf`Ooo]/403_oo]/400ol00?oo
okK1oonf`@0Koonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo]/403Ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool07@3oool01@000000oooo0?ooo`3oool00000
00;ookK100L00000oonf`@00003ookK1o`000?oo]/40000000;ookK11_l00003oonf`@;o00000_oo
]/400ol0003ookK1oonf`@08000000?ookK100?o0000oonf`Ooo]/401?l0000Eoonf`@Go00000_oo
]/42o`0000;ookK100@00000oonf`Ooo]/4000000_oo]/400`00003ookK1oonf`@03oonf`@@00000
1ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100?o0000000000000000
2ooo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/401000003o
okK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280
oooo2Ooo]/400ol00?oookK1oonf`@09oonf`@03o`00oooo]/7ookK100cookK100?o003ooonf`Ooo
]/403_oo]/400ol00?oookK1oonf`@03oonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo
]/406Ooo]/400ol00?oookK1oonf`@0Boonf`@;o003o3Ooo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool07@3oool01@000000oooo0?ooo`3oool0000000;ookK100H00000oonf
`@00003ookK100000?l00002oonf`@03o`000?oo]/7o000000CookK10ol00002oonf`@04o`000?oo
]/7ookK1000000_ookK100@00000oonf`Ooo]/7o00001?oo]/48o`0000;ookK12ol00005oonf`@07
o`000?oo]/7ookK1oonf`Ol0003ookK100000002oonf`@0400000?oo]/7ookK10000013ookK100Go
0000oonf`Ooo]/7ookK100000004oonf`@0300000?oo]/7ookK100cookK10P000003oonf`@050000
0?oo]/7ookK1oonf`@0000001?oo]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo2Ooo]/400ol00?oookK1oonf`@0:oonf`@03
o`00oooo]/7ookK100_ookK100?o003ooonf`Ooo]/403_oo]/400ol00?oookK1oonf`@03oonf`@03
o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo]/406?oo]/400ol00?oookK1oonf`@0Doonf`@03
o`00oooo]/7ookK100_ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01d0
oooo014000000?ooo`3oool0oooo00000?oo]/400000oonf`@00003ookK100000?oo]/400000oonf
`Ol0003ookK1o`000002oonf`@Go000000GookK1o`000?l0003ookK1o`000002oonf`@0300000?oo
]/7ookK100OookK100@00000oonf`Ooo]/7o00001?oo]/400ol0003ookK1oonf`@06oonf`@;o0000
4?oo]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK100@00000oonf`Ooo]/4000000_oo]/400`00
003ookK1oonf`@0<oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/400`00003ookK1oonf`@05
oonf`@Co00001_oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/7ookK1
00000003oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3o
ool8oonf`@03o`00oooo]/7ookK100cookK100?o003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf
`@0?oonf`@05o`00oooo]/7ookK1oonf`Ol00?l05?oo]/400ol00?oookK1oonf`@0Goonf`@03o`00
oooo]/7ookK101GookK100?o003ooonf`Ooo]/402_oo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0703oool02`000000oooo0?ooo`3oool000000?oooooo]/400000oonf`@00
003ookK10080000000CookK1o`000?oo]/7o00000_oo]/400ol0003ookK1oonf`@03oonf`@06o`00
0?oo]/7ookK1o`000?oo]/7o00000_oo]/400`00003ookK1oonf`@06oonf`@0400000?oo]/7ookK1
o`0000?ookK100?o0000oonf`Ooo]/406_oo]/401ol0003ookK1oonf`Ooo]/7o0000oonf`@000000
0ooo]/401?l0003ookK1oonf`Ol0000<oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo
]/7ookK100000005oonf`@?o00001?oo]/43o`0000CookK100D00000oonf`Ooo]/7ookK1o`000003
oonf`@04o`000?oo]/7ookK1000000?ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?ooo`0R0?ooo`OookK100?o003ooonf`Ooo]/403_oo]/400ol00?oookK1oonf`@08
oonf`@03o`00oooo]/7ookK1013ookK100Go003ooonf`Ooo]/7ookK1o`00o`0Doonf`@03o`00oooo
]/7ookK101KookK100?o003ooonf`Ooo]/405ooo]/400ol00?oookK1oonf`@09oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0L0?ooo`0A0000003oool0oooo0?ooo`000000
oooo00000?oo]/400000oonf`@00003ookK100000?l0003ookK1o`000?oo]/400_l000001?oo]/7o
0000o`000?l00003oonf`@03o`000?oo]/7o000000;ookK100Go0000oonf`Ooo]/7o000000000005
oonf`@0400000?oo]/7ookK1o`0000?ookK100?o0000oonf`Ooo]/405Ooo]/43o`0000CookK100Co
0000oonf`Ooo]/7o00000_oo]/401000003ookK1oonf`@000003oonf`@0300000?oo]/7ookK100So
okK100<00000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/7o000000?ookK10ol0000:oonf
`@03o`000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK100000002oonf`@0500000?oo]/7o
okK1oonf`@0000000_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo0280oooo1_oo]/400ol00?oookK1oonf`@0@oonf`@03o`00oooo]/7ookK100OookK100?o003o
oonf`Ooo]/401_oo]/43o`0000SookK100Co003ooonf`Ooo]/7o003o2Ooo]/43o`0000WookK100?o
003ooonf`Ooo]/405?oo]/400ol00?oookK1oonf`@0Ioonf`@03o`00oooo]/7ookK100SookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01`0oooo018000000?ooo`3oool0oooo
0000003oool00000oonf`@00003ookK100000?oo]/400000o`000?oo]/7o0000oonf`Ol00002oonf
`@03o`000?oo]/7ookK100;o00000_oo]/42o`0000;ookK100?o0000oonf`Ooo]/400_oo]/401@00
003ookK1oonf`Ooo]/40000000?ookK100Go0000oonf`Ooo]/7ookK1o`000003oonf`@Go00003?oo
]/43o`0000;ookK100?o0000oonf`Ooo]/400_oo]/401?l0003ookK1oonf`Ol00002oonf`@040000
0?oo]/7ookK1000000?ookK100<00000oonf`Ooo]/401ooo]/400ol0003ookK1oonf`@03oonf`@05
00000?oo]/7ookK1oonf`@0000000ooo]/400ol0003ookK1oonf`@0;oonf`@05o`000?oo]/7ookK1
oonf`@0000000ooo]/401000003ookK1oonf`@000003oonf`@0300000?oo]/7ookK100;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool6oonf`@03o`00oooo]/7o
okK100GookK10ol00008oonf`@03o`00oooo]/7ookK100OookK100?o003ooonf`Ooo]/401Ooo]/45
o`0000OookK100Co003ooonf`Ooo]/7o003o2?oo]/45o`0000SookK100?o003ooonf`Ooo]/405?oo
]/400ol00?oookK1oonf`@0Ioonf`@03o`00oooo]/7ookK100SookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo01/0oooo00D000000?ooo`3oool0oooo000000020?ooo`0;0000
0?oo]/40000000000?oo]/400000o`000?oo]/7o0000oonf`Ol000000_oo]/400ol0003ookK1oonf
`@03oonf`@03o`000?oo]/7ookK100;o00000_oo]/400ol0003ookK1oonf`@02oonf`@0300000?oo
]/40000000?ookK100Go0000oonf`Ooo]/7ookK1o`000004oonf`@03o`000?oo]/7ookK100;ookK1
00?o0000oonf`Ooo]/402?oo]/400ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100;ookK1
00Co0000oonf`Ooo]/7o00000_oo]/401000003ookK1oonf`@000003oonf`@0300000?oo]/7ookK1
00KookK100<00000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100?o0000
oonf`Ooo]/401?oo]/44o`0000GookK100Go0000oonf`Ooo]/7ookK100000003oonf`@0400000?oo
]/7ookK1000000?ookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo
0?ooo`0R0?ooo`KookK100?o003ooonf`Ooo]/401?oo]/45o`0000OookK100?o003ooonf`Ooo]/40
1ooo]/400ol00?oookK1oonf`@05oonf`@Go00001ooo]/401?l00?oookK1oonf`Ol00?l8oonf`@Go
00002?oo]/400ol00?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK101_ookK100?o003ooonf`Ooo
]/401ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool06`3oool01@000000
oooo0?ooo`3oool000000080oooo00P00000oonf`@0000000000oonf`@00003o0000oonf`@;o0000
0_oo]/400ol0003ookK1oonf`@05oonf`@07o`000?oo]/7o0000oonf`Ol0003ookK1o`000005oonf
`@0300000?oo]/7ookK100;ookK100Co0000oonf`Ooo]/7o00001?oo]/400ol0003ookK1oonf`@03
oonf`@;o00002?oo]/42o`0000OookK100?o0000oonf`Ooo]/400_oo]/400ol0003ookK1o`000002
oonf`@0400000?oo]/7ookK1000000?ookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf
`@02oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/400ol0003ookK1oonf`@03oonf`@;o0000
1?oo]/400ol0003ookK1oonf`@03oonf`@05o`000?oo]/7ookK1oonf`@0000000_oo]/401@00003o
okK1oonf`Ooo]/40000000?ookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000oooo
o`3oool08P3oool6oonf`@03o`00oooo]/7ookK100CookK11Ol00007oonf`@03o`00oooo]/7ookK1
00OookK100?o003ooonf`Ooo]/401Ooo]/45o`0000KookK100Go003ooonf`Ooo]/7ookK1o`00o`08
oonf`@Go00002?oo]/400ol00?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK101_ookK100?o003o
oonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool06`3oool0
1@000000oooo0?ooo`3oool000000080oooo00P00000oonf`@0000000000oonf`@00003o0000oonf
`@;o00000_oo]/400ol0003ookK1oonf`@05oonf`@07o`000?oo]/7o0000oonf`Ol0003ookK1o`00
0005oonf`@0300000?oo]/7ookK100;ookK100Go0000oonf`Ooo]/7ookK1o`000004oonf`@Go0000
3?oo]/400ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100;ookK100?o0000oonf`Ol00000
0_oo]/401000003ookK1oonf`@000003oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo
]/400_oo]/401000003ookK1oonf`Ol00004oonf`@03o`000?oo]/7ookK100;ookK100?o0000oonf
`Ooo]/401Ooo]/400ol0003ookK1oonf`@02oonf`@05o`000?oo]/7ookK1oonf`@0000000_oo]/40
1@00003ookK1oonf`Ooo]/40000000?ookK100@00000oooooooooooo00002_ooool000Wooooo00?o
0000ooooo`3oool08P3oool6oonf`@03o`00oooo]/7ookK100CookK11Ol00007oonf`@03o`00oooo
]/7ookK100OookK100?o003ooonf`Ooo]/401_oo]/43o`0000OookK100Go003ooonf`Ooo]/7ookK1
o`00o`09oonf`@?o00002Ooo]/400ol00?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK101_ookK1
00?o003ooonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
6`3oool01@000000oooo0?ooo`3oool000000080oooo00P00000oonf`@0000000000oonf`@00003o
0000oonf`@;o00000_oo]/400ol0003ookK1oonf`@05oonf`@07o`000?oo]/7o0000oonf`Ol0003o
okK1o`000004oonf`@0300000?oo]/40000000CookK100Go0000oonf`Ooo]/7ookK1o`00000Eoonf
`@?o00000_oo]/400ol0003ookK1oonf`@03oonf`@03o`000?oo]/7o000000;ookK100@00000oonf
`Ooo]/4000000ooo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100;ookK100@00000
oonf`Ooo]/4000000ooo]/400ol0003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100OookK100?o
0000oonf`Ooo]/400_oo]/401?l0003ookK1oonf`@000002oonf`@0500000?oo]/7ookK1oonf`@00
00000ooo]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooo`Ko
okK100?o003ooonf`Ooo]/401Ooo]/43o`0000SookK100?o003ooonf`Ooo]/401ooo]/400ol00?oo
okK1oonf`@0@oonf`@05o`00oooo]/7ookK1oonf`Ol00?l05Ooo]/400ol00?oookK1oonf`@0Boonf
`@03o`00oooo]/7ookK101gookK100?o003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool06`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
oonf`@00003ookK10P0000001Ooo]/7o0000o`000?oo]/7o000000;ookK100?o0000oonf`Ooo]/40
0ooo]/400ol0003ookK1oonf`@02o`000003oonf`Ol0003ookK100?ookK100D00000oonf`Ooo]/7o
okK100000003oonf`@03o`000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/405Ooo]/42o`0000Go
okK100Ko0000oonf`Ooo]/7o0000oonf`@000002oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000CookK100Go
0000oonf`Ooo]/7ookK1o`00000;oonf`@05o`000?oo]/7ookK1oonf`Ol000000ooo]/401000003o
okK1oonf`@000003oonf`@0400000?oo]/7ookK1000000;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3oool08P3oool6oonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf
`Ooo]/401ooo]/400ol00?oookK1oonf`@0?oonf`@03o`00oooo]/7ookK100;ookK100?o003ooonf
`Ooo]/404ooo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK100cookK10ol0000>oonf
`@03o`00oooo]/7ookK100KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
01/0oooo00D000000?ooo`3oool0oooo000000020?ooo`0400000?oo]/400000oonf`@80000000Go
okK1o`000?l0003ookK1o`000002oonf`@03o`000?oo]/7ookK100Ko000000CookK1o`000?oo]/7o
00000_oo]/42000000GookK100@00000o`000?oo]/7ookK10_l00002oonf`@?o00006ooo]/42o`00
00;ookK100?o0000oonf`@0000000_oo]/400ol0003ookK1oonf`@02oonf`@0300000?oo]/7ookK1
00CookK100<00000oonf`Ooo]/400_oo]/401000003ookK1oonf`@000003oonf`@05o`000?oo]/7o
okK1oonf`Ol000003Ooo]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK100@00000oonf`Ooo]/40
00000ooo]/401000003ookK1oonf`@000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0280oooo1ooo]/400ol00?oookK1oonf`@0>oonf`@03o`00oooo]/7ookK100Wo
okK100?o003ooonf`Ooo]/403_oo]/400ol00?oookK1oonf`@02oonf`@03o`00oooo]/7ookK101;o
okK100?o003ooonf`Ooo]/404ooo]/400ol00?oookK1oonf`@0;oonf`@Go00003Ooo]/400ol00?oo
okK1oonf`@06oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0K0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool02`00003ookK100000?oo]/7o000000000?oo]/7o0000
oonf`Ol0003ookK100;o000000?ookK1o`000?l000000ooo]/402Ol0003ookK1oonf`Ooo]/7o0000
oonf`Ol0003ookK100000009oonf`@0400000?oo]/7ookK1oonf`@;o00000ooo]/4>o`0000cookK1
00?o0000oonf`Ooo]/400_oo]/400ol0003ookK100000002oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000?o
okK100Go0000oonf`Ooo]/7ookK1o`00000=oonf`@05o`000?oo]/7ookK1oonf`Ol000000_oo]/40
1000003ookK1oonf`@000003oonf`@0400000?oo]/7ookK1000000;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3oool08P3oool7oonf`@03o`00oooo]/7ookK100kookK100?o
003ooonf`Ooo]/402_oo]/400ol00?oookK1oonf`@0<oonf`@03o`00oooo]/7ookK100CookK100?o
003ooonf`Ooo]/404?oo]/400ol00?oookK1oonf`@0Doonf`@03o`00oooo]/7ookK100_ookK11Ol0
000=oonf`@03o`00oooo]/7ookK100KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo01`0oooo00L000000?ooo`3oool0oooo0000003oool0000000;ookK10P0000001_oo]/40
0000oonf`Ol0003ookK1o`0000;ookK100?o0000oonf`Ooo]/400ol00002oonf`@;o000000CookK1
o`000?oo]/4000002ooo]/400`00003ookK1oonf`@02oonf`@?o00003_oo]/47o`0000?ookK10_l0
0004oonf`@03o`000?oo]/7o000000;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf
`@05oonf`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/4000000ooo]/401Ol0003ookK1
oonf`Ooo]/7o000000gookK100Go0000oonf`Ooo]/7ookK1o`000002oonf`@0400000?oo]/7ookK1
000000?ookK100@00000oonf`Ooo]/4000000_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?ooo`0R0?ooo`SookK100?o003ooonf`Ooo]/403Ooo]/400ol00?oookK1oonf`@0;
oonf`@03o`00oooo]/7ookK100_ookK100?o003ooonf`Ooo]/401?oo]/400ol00?oookK1oonf`@0@
oonf`@03o`00oooo]/7ookK101CookK100?o003ooonf`Ooo]/402ooo]/45o`0000gookK100?o003o
oonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0703oool0
4@000000oooo0?ooo`3oool000000?oooooo]/7o0000oonf`@00003ookK100000?oo]/400000oonf
`Ol0003ookK100;o000000?ookK1o`000?l000000ooo]/42o`0000;ookK100?o0000oonf`Ol00000
0_oo]/4800000005o`000000003ookK100000?l000000P000003oonf`@ko00001ooo]/43o`0000?o
okK10ol000001Ooo]/400000oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/401_oo]/400`00
003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000?ookK100Go0000oonf`Ooo]/7ookK1o`00
000=oonf`@05o`000?oo]/7ookK1oonf`Ol000000_oo]/401000003ookK1oonf`@000003oonf`@04
00000?oo]/7ookK1000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
ool08P3oool8oonf`@;o003o3?oo]/42o`00o`oookK10_l00?l9oonf`@;o003o2?oo]/42o`00o`ko
okK10_l00?lGoonf`@03o`00oooo]/7ookK100cookK10ol0000>oonf`@03o`00oooo]/7ookK100Ko
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01`0oooo014000000?ooo`3o
ool0oooo0000003ooooookK100000?oo]/400000oonf`@00003ookK1o`000000003ookK1o`000002
oonf`@03o`000?oo]/7ookK100?o00000_oo]/42o`000005oonf`@0000000000oonf`@0000002_oo
]/400`00003ookK1oonf`@02oonf`@<000003_oo]/47o`0000?ookK10ol00003oonf`@0400000?oo
]/7ookK1000000CookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@02oonf`@040000
0?oo]/7ookK1000000?ookK100Go0000oonf`Ooo]/7ookK1o`00000=oonf`@05o`000?oo]/7ookK1
oonf`Ol000000_oo]/401000003ookK1oonf`@000003oonf`@0400000?oo]/7ookK1000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool:oonf`@;o003o2?oo
]/42o`00oa?ookK10ol00?l3oonf`@?o003o3?oo]/400ol00?oookK1oonf`@09oonf`@;o003o6Ooo
]/400ol00?oookK1oonf`@0Moonf`@03o`00oooo]/7ookK100KookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo01d0oooo00D000000?ooo`3oool0oooo00000002oonf`@050000
0?oo]/400000oonf`@0000000_oo]/400`00003ookK1o`000004o`0000?ookK10_l00002oonf`@04
00000?oo]/7ookK1000000CookK110000004oonf`@<000001?oo]/4>000000OookK10ol00003oonf
`@<000000_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100SookK100<00000oonf
`Ooo]/400_oo]/401000003ookK1oonf`@000003oonf`@05o`000?oo]/7ookK1oonf`Ol000003Ooo
]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK100@00000oonf`Ooo]/4000000ooo]/401000003o
okK1oonf`@000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280
oooo3?oo]/43o`00o`;ookK10ol00?lHoonf`@?o003o4?oo]/43o`00o`OookK100?o003ooonf`Ooo
]/406Ooo]/400ol00?oookK1oonf`@0Moonf`@03o`00oooo]/7ookK100KookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo01d0oooo00D000000?ooo`3oool0oooo00000002oonf
`@0600000?oo]/7ookK100000?oo]/4000000_oo]/401000003ookK1oonf`Ooo]/45o`0000;ookK1
0P000002oonf`@03o`000?oo]/7ookK100<000001?oo]/43000000CookK10`00000?oonf`@L00000
0ooo]/43000000CookK100<00000oonf`Ooo]/400_oo]/400ol0003ookK1oonf`@0:oonf`@050000
0?oo]/7ookK1oonf`@0000000ooo]/401000003ookK1oonf`Ol00003oonf`@03o`000?oo]/7ookK1
00[ookK100Go0000oonf`Ooo]/7ookK1o`000003oonf`@0400000?oo]/7ookK1000000;ookK100D0
0000oonf`Ooo]/7ookK100000002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0280oooo3ooo]/42o`00oc7ookK11ol00?lMoonf`@03o`00oooo]/7ookK101cookK100?o
003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool07P3o
ool01@000000oooo0?ooo`3oool0000000;ookK100H00000oonf`Ooo]/400000oonf`Ol000050000
00;ookK11@000002oonf`@80000000?ookK10000000000002_oo]/401000003o0000000000000003
oonf`@0300000?l00000000000`000001ooo]/43000000?ookK10`0000001?l0003ookK1oonf`Ooo
]/42000000gookK100D00000oonf`Ooo]/7ookK100000003oonf`@0300000?oo]/7ookK100;o0000
0ooo]/42o`0000[ookK100Go0000oonf`Ooo]/7ookK1o`000003oonf`@0400000?oo]/7ookK10000
00;ookK100D00000oonf`Ooo]/7ookK100000002ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0oooo0280ooooI_oo]/400ol00?oookK1oonf`@0Koonf`@03o`00oooo]/7ookK1
00OookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01h0oooo00H000000?oo
o`3oool0oooooonf`@000002oonf`@05o`000000003ookK1o`00000000000_oo]/45000000CookK1
0`0000000ooo]/40000000000005oonf`@@000001ooo]/44000000kookK110000006oonf`@<00000
1?oo]/43000000oookK100<00000oonf`Ooo]/400_oo]/401?l0003ookK1oonf`Ol00003oonf`@03
o`000?oo]/7ookK100?ookK100?o0000oonf`Ooo]/401_oo]/400ol0003ookK1oonf`@02oonf`@05
o`000?oo]/7ookK1oonf`@0000000_oo]/401000003ookK1oonf`@000003oonf`@0400000?oooooo
ooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo0280ooooI_oo]/400ol00?oookK1oonf`@0K
oonf`@03o`00oooo]/7ookK100OookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo01l0oooo00<000000?ooo`3oool00_oo]/401@00003ookK1oonf`Ooo]/40000000;ookK10P00
0003oonf`@H000000ooo]/401000003ookK1oonf`Ooo]/44000000CookK110000007oonf`@X00000
2?oo]/46000000KookK100<00000oonf`Ooo]/401Ooo]/47000000GookK100D00000oonf`Ooo]/7o
okK100000002oonf`@0300000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/400ooo]/43o`0000;o
okK10ol00004oonf`@05o`000?oo]/7ookK1oonf`@0000000_oo]/401000003ookK1oonf`@000003
oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool08P3ooomW
oonf`@03o`00oooo]/7ookK101WookK100?o003ooonf`Ooo]/402?oo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool0803oool00ol00000oooooonf`@02oonf`@0500000?oo]/7o
okK1oonf`@0000000ooo]/400`00003o000000000005oonf`@@0000000CookK10000000000000000
3?oo]/44000000gookK120000009oonf`@80000000?o0000oonf`Ooo]/400ooo]/43000000OookK1
00<00000oonf`Ooo]/400ooo]/401Ol0003ookK1oonf`Ooo]/40000000;ookK100<00000oonf`Ooo
]/400_oo]/400ol0003ookK1oonf`@05oonf`@;o00001_oo]/401Ol0003ookK1oonf`Ooo]/400000
00?ookK100@00000oonf`Ooo]/4000000ooo]/401@00003ookK1oooooooooooo000000[ooooo0009
ooooo`03o`000?ooool0oooo0280ooooIooo]/400ol00?oookK1oonf`@0Hoonf`@03o`00oooo]/7o
okK100WookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0200oooo00<00000
0?oooooo]/400ooo]/401?l000000000oonf`Ol00002000000CookK11@000004oonf`@0300000?oo
]/7ookK100GookK110000008oonf`@X000002ooo]/49000000KookK10P00000:oonf`@0300000?oo
]/7ookK100?ookK100D00000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`Ol0
00003Ooo]/42o`0000CookK100D00000oonf`Ooo]/7ookK100000002oonf`@0600000?oo]/7ookK1
oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R
0?ooofOookK100?o003ooonf`Ooo]/406?oo]/400ol00?oookK1oonf`@09oonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`0Q0?ooo`0300000?oo]/7ookK100CookK100@00000
oonf`Ooo]/7ookK110000002oonf`@L000001?oo]/44000000CookK11000000>oonf`@L000004Ooo
]/42000000gookK100<00000oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK1
00@00000oonf`Ooo]/7ookK10_l0000:oonf`@03o`000?oo]/7ookK100?ookK100D00000oonf`Ooo
]/7ookK100000002oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Oooooooooooo`00000:
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooofSookK10_l00?lGoonf`@03o`00oooo]/7ookK1
00[ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0280oooo00<00000oonf
`Ooo]/401?oo]/400`00003ookK1oonf`@04oonf`@8000002?oo]/43000000cookK11P00000?oonf
`A4000004?oo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/40
0`00003ookK1oonf`@02oonf`@;o00001_oo]/42o`0000GookK100D00000oonf`Ooo]/7ookK1o`00
0003oonf`@05o`000?oo]/7ookK1oonf`@0000000_oo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo0280ooooJ_oo]/400ol00?oookK1oonf`@0Boonf`@;o003o3Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool00ooo]/7o00000000
0005oonf`@03o`0000000000000000WookK10`0000000ol0003ookK1oonf`@0Coonf`@0300000?l0
0000000000D00000:Ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@000000
0ooo]/400ol000000000oonf`@04oonf`@Ko00001Ooo]/42000000CookK100D00000oonf`Ooo]/7o
okK100000002oonf`@0400000?l0003ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0S@3oool00ol00?oookK1oonf`@0?oonf`@;o003o3ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`T0
00008@3oool700000140oooo2P0000070?ooo`030000003oool0oooo00<0oooo00Go00000?ooo`3o
ool0oooo000000020?ooo`;ookK100<00000oonf`Ooo]/402ooo]/42000000GookK100D00000oonf
`Ooo]/7ookK100000003oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool0S@3oool00ooo]/7o003ooonf`@0>oonf`@03o`00oooo]/7o
okK100oookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo02H0oooo0`00000D
0?ooo``000005@3oool7000000H0oooo1000000:0?ooo`8000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?oooooo]/400_oo]/43000000WookK100<00000
oonf`Ooo]/401?oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/400_oo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo0_oo]/42
o`00o`cookK100?o003ooonf`Ooo]/404?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool0:@3oool3000000h0oooo0`00000<0?ooo`0400000?l000000000000001P0oooo1P00
000@0?ooo`0300000?l00000oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/4200000003o`000?oo
]/7ookK100?ookK10P000003oonf`@03o`000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo1?oo]/47
o`00o`?ookK10ol00?lBoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0/
0?ooo`@000001P3oool4000001<0oooo1P00000Y0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03o`000000003ookK100CookK100?o0000
0000000000000P000007oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/40
0`00003ookK1oonf`@02oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo
08d0oooo2ooo]/43o`00oaGookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
0300oooo1P00000M0?ooo`L000008`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool2oonf`@0300000?oo]/7ookK100gookK100<00000oonf
`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oooo
ool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`1J0?ooo`L00000703oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0ooo]/400`00003ookK1oonf`@0:oonf
`@8000001Ooo]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100?ookK100@00000oooo
oooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`1Q0?ooo`0300000?l00000000000D000005@3oool00`00
0000oooo0?ooo`030?ooo`800000103oool00ol0000000000?ooo`04oonf`@03o`00000000000000
00GookK10`0000000ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf
`Ooo]/400_oo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo
08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0J@3oool:0000
00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`0300000?oo]/7ookK1
00GookK11@000008oonf`@8000001Ooo]/400`00003ookK1oonf`@03oonf`@0500000?oo]/7ooooo
ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`1c0?ooo`<000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<00000oonf`Ooo]/404?oo]/400`00003ookK1oonf`@04oonf
`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo07H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00?ookK1o`000?oo]/403ooo]/400ol0003ookK1oonf`@04oonf`@03
o`000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo07H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo0_oo]/400`00003ookK1oonf`@0<oonf`@0300000?oo]/7ookK100CookK1
00<00000oonf`Ooo]/401?oo]/401?l0003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool3oonf`@0300000?oo]/7ookK100[ookK100<00000oonf`Ooo]/40
1Ooo]/400`00003ookK1oonf`@04oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`1g0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`CookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1
oonf`@05oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0M`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool5oonf`@8000001Ooo]/4200000003o`000?oo
]/7ookK100KookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`1g0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`OookK10`0000000ooo]/400000oonf`@0:
oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0M`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool:oonf`@0300000?oo]/7ookK100[ookK100<00000oonf
`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`1g0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`3ooolFoonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/400_oo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0M`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo5_oo]/400`00003ookK1oonf`@05oonf
`@0300000?oo]/7ookK100;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo07L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?oo
o`KookK11P00000:oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/400_oo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0MP3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool4oonf`@8000001_oo]/42000000Wo
okK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`1f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`?ookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1
oonf`@06oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0MP3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool2oonf`@0300000?oo]/7ookK100[ookK100<0
0000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo07D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00?ookK100000?oo]/403Ooo]/40
0`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0GP3oool7000000h0oooo0P0000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00003ookK1oonf`@0>oonf
`@03o`000?oo]/7ookK100CookK100?o0000oonf`Ooo]/401?oo]/401000003ookK1oonf`Ooo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0EP3oool500000003o`00000000000000
00L0oooo00?o0000000000000000100000030?ooo`@000002`3oool00ol00000oooo0?ooo`040?oo
o`03o`00003oool0oooo00<0oooo00<00000o`000?oo]/404Ooo]/42000000GookK100<00000oonf
`Ooo]/400ooo]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0D`3oool3000001H0oooo0`00000?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0Doonf`@0300000?oo]/7ookK100;ookK100<00000oonf
`Ooo]/400ooo]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0<P3oool@000000l0oooo0P00000Z0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`3oool5oonf`@P000002?oo]/400ol0003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo02h0oooo1000000@0?ooo`04o`00000000000000000000P0oooo00<00000
o`0000000000:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00?o0000
0?ooo`3oool00P3oool01Ooo]/400000o`000?l00000000000SookK100<00000o`00000000001_oo
]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100?ookK100D00000oonf`Ooooooooooo
o`00000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf`Ol00?oo003o00_o003o5Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0;03oool00`00003o00000?oo
o`0G0?ooo`P00000;@3oool00ol00000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100?ookK100<0
0000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7oooooooooool00000
2_ooool000Wooooo00?o0000ooooo`3oool0S@3oool00ol00?oookK1oonf`@0;oonf`@;o003o4ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0:P3oool2000002d0oooo4000
000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`0300000?oo]/7ookK100oookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf
`@02oonf`@0300000?oo]/7ookK100?ookK100@00000oooooooooooo00002_ooool000Wooooo00?o
0000ooooo`3oool0S03oool00ol00?oookK1oonf`@0>oonf`@;o003o4Ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`D000006`3o
ool300000100oooo00?o00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooooonf`@05oonf`@H000001_oo
]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7o000000?ookK100<00000oonf`Ooo]/400_oo
]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?ooo`2;0?ooo`03o`00o`3o
oooookK1017ookK10_l00?l?oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`0W0?ooo`0300000?l00000oooo00P0oooo100000050?ooo`03o`0000000000000000@00000403o
ool200000003o`0000000000oooo01<0oooo0`00000;0?ooo`8000001P3oool00`000000oooo0?oo
o`020?ooo`03o`00003oool0oooo0080oooo00<000000?ooo`3oool00_oo]/401000003o00000000
00000006oonf`@<000001?oo]/42000000?ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1
oonf`@03oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo08X0oooo00?o
003o0?ooo`3oool05?oo]/400ol00?oookK1oonf`@0<oonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo0`00000@0?ooo`<000002P3o
ool3000000L0oooo300000080?ooo`<000001P3oool2000000L0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3ooooo000000<0oooo00?ookK100000?oo]/403?oo]/400`00003ookK1
oonf`@03oonf`@0400000?oo]/7ookK1000000CookK100<00000oonf`Ooo]/400ooo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08T0oooo00Co003o0?ooo`3oool0
oooo5Ooo]/400ol00?oookK1oonf`@0;oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo0`00000F0?ooo`@000001@3oool00`000000
oooo0?ooo`050?ooo`<00000303oool4000000L0oooo1P0000080?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`0300000?oo]/7ookK100gookK100<00000oonf
`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/400_oo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08P0oooo00?o003o0?oo
o`3oool00P3ooolEoonf`@03o`00oooo]/7ookK100_ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`d0000000?o00000?ooo`3oool0203oool5000000L0oooo00<000000?ooo`3oool04@3oool20000
01<0oooo00?o00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00?o0000
oonf`Ooo]/403ooo]/400ol000000000oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo
]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0280ooooIOoo]/400ol00?oookK1oonf`@0Ioonf`@03o`00oooo]/7ookK100[ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0280oooo00?ookK100000?oo]/401Ooo
]/400`00003ookK1oonf`@02oonf`@8000003_oo]/430000013ookK10P0000000ol0003ookK1oonf
`@02oonf`@`000001_oo]/420000017ookK100D00000oonf`Ooo]/7ookK1o`000004oonf`@030000
0?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/48o`0000GookK100D00000oonf`Ooo]/7o
okK100000003oonf`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/7ookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooofGookK100?o003ooonf`Ooo
]/406Ooo]/400ol00?oookK1oonf`@0:oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`0R0?ooo`0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@05oonf`@P000001?oo]/43000000[ookK10`000004oonf`@<000003?oo]/44000000Co
okK100<00000oonf`Ooo]/403Ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf
`@0000001?oo]/400`00003ookK1oonf`@02oonf`@;o00002?oo]/42o`0000CookK100D00000oonf
`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooI?oo]/400ol00?oookK1oonf`@0K
oonf`@03o`00oooo]/7ookK100WookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo0280oooo00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7o
okK100?ookK10`000008oonf`@0300000?l0003ookK100CookK100<00000o`000?oo]/401_oo]/40
0`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK12`000004oonf`@03o`000?oo]/7o
okK100;ookK100<00000oonf`Ooo]/403?oo]/401@00003ookK1oonf`Ooo]/40000000CookK100D0
0000oonf`Ooo]/7ookK100000004oonf`@03o`000?oo]/7ookK100WookK100?o0000oonf`Ooo]/40
0_oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/7ookK100000003oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomToonf`@03
o`00oooo]/7ookK101cookK100?o003ooonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool08@3oool00`00003ookK1oonf`@03oonf`@0600000?oo]/7ookK1oonf
`@00003o00000_oo]/401000003o0000000000000003oonf`@D000001Ooo]/42000000GookK11`00
0005oonf`@8000000ooo]/42000000_ookK100?o00000000000000000_oo]/42000000?ookK100?o
00000000000000002_oo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`Ol00000
0ooo]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100_ookK100?o0000oonf`Ooo]/40
0_oo]/401Ol0003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/7ookK100000002oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomSoonf`@03
o`00oooo]/7ookK101gookK100?o003ooonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool08@3oool00`00003ookK1oonf`@03oonf`@0400000?oo]/7ookK10000
00?ookK100@00000oonf`Ooo]/7ookK110000005oonf`@<000001?oo]/42000000gookK10P000003
oonf`@8000000_oo]/4:o`0000CookK100D00000oonf`Ooo]/7ookK100000005oonf`@0300000?oo
]/7ookK100KookK100?o0000oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK1
00<00000oonf`Ooo]/400_oo]/400ol0003ookK1oonf`@0;oonf`@03o`000?oo]/7ookK100?ookK1
00@00000oonf`Ooo]/4000000ooo]/401@00003ookK1oonf`Ooo]/40000000;ookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooa?ookK11_l00?lPoonf`@Wo
003o8Ooo]/400ol00?oookK1oonf`@0Noonf`@03o`00oooo]/7ookK100OookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo0200oooo00<000000?oooooo]/400ooo]/401000003o
okK1oonf`@000003oonf`@0300000?oo]/7ookK1008000001?oo]/45o`0000?ookK10`000003oonf
`@8000002Ooo]/42000000CookK100<00000oonf`Ooo]/400_l0000:oonf`@;o00000ooo]/401Ol0
003ookK1oonf`Ooo]/7o000000GookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@03
oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/400`00003ookK1oonf`@02oonf`@03o`000?oo
]/7ookK100gookK100?o0000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000?ookK1
00H00000oonf`Ooo]/7ookK100000?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0280oooo3ooo]/44o`00o`KookK10ol00?lJoonf`@?o003o2Ooo]/43o`00oako
okK100?o003ooonf`Ooo]/407_oo]/400ol00?oookK1oonf`@07oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`0O0?ooo`030000003oool0oooo00?ookK100Go0000oonf`Ooo
]/7ookK1o`000002oonf`@04o`000?oo]/7ookK1o`0000;ookK11?l00005oonf`@Co00000_oo]/40
0ol0003ookK1oonf`@02oonf`@03o`0000000000000000GookK100L00000oonf`Ooo]/7ookK10000
0?l00000000000;ookK100?o0000oonf`Ooo]/400_oo]/46o`0000CookK10_l00002oonf`@050000
0?oo]/7ookK1oonf`@0000001Ooo]/401?l00000000000000?oo]/42000000KookK100D00000oonf
`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`Ol000001_oo]/45o`0000KookK100Go
0000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003o
okK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280oooo3_oo]/400ol00?oo
okK1oonf`@0;oonf`@03o`00oooo]/7ookK101KookK100?o003ooonf`Ooo]/403Ooo]/400ol00?oo
okK1oonf`@0Koonf`@03o`00oooo]/7ookK101kookK100?o003ooonf`Ooo]/401ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool07`3oool00`000000oooo0?ooo`03oonf`@05
00000?oo]/7ookK1oonf`@0000000_oo]/401P00003ookK1oonf`@00003ookK1o`0000gookK100?o
0000oonf`Ooo]/400P000005oonf`@@0000000Go0000oonf`Ooo]/7ookK100000004oonf`@03o`00
0?oo]/7ookK100?o00001_oo]/43o`0000?ookK100Co0000oonf`Ooo]/4000000_oo]/400`00003o
okK1oonf`@06oonf`@0300000?oo]/7ookK100KookK100D00000oonf`Ooo]/7ookK100000003oonf
`@0500000?oo]/7ookK1oonf`Ol000001_oo]/401Ol0003ookK1oonf`Ooo]/7o000000KookK100Go
0000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003o
okK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280oooo3Ooo]/400ol00?oo
okK1oonf`@0=oonf`@03o`00oooo]/7ookK101CookK100?o003ooonf`Ooo]/403ooo]/400ol00?oo
okK1oonf`@0Ioonf`@03o`00oooo]/7ookK100gookK10ol0000?oonf`@03o`00oooo]/7ookK100Oo
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0oooo00<000000?ooo`3o
ool00_oo]/401@00003ookK1oonf`Ooo]/40000000;ookK100H00000oonf`Ooo]/400000oonf`Ol0
0002oonf`@[o00000ooo]/401?l0003ookK1oonf`Ooo]/42000000[ookK100<00000oonf`Ooo]/40
0_oo]/401?l0003ookK1o`000?l00004oonf`@Go00000ooo]/42o`0000;ookK100Co0000oonf`Ooo
]/4000000_oo]/400`00003ookK1oonf`@0>oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/40
1@00003ookK1oonf`Ooo]/7o000000KookK100Go0000oonf`Ooo]/7ookK1o`000006oonf`@05o`00
0?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf
`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooo`cookK100?o003ooonf
`Ooo]/403ooo]/42o`00oa?ookK100?o003ooonf`Ooo]/404Ooo]/400ol00?oookK1oonf`@0Hoonf
`@03o`00oooo]/7ookK100cookK11Ol0000>oonf`@03o`00oooo]/7ookK100OookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0oooo00<000000?ooo`3oool00_oo]/401@00
003ookK1oonf`Ooo]/40000000;ookK100<00000oonf`@0000000_oo]/400ol0003ookK1o`00000:
oonf`@;o00000_oo]/400ol0003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100OookK100D00000
oonf`Ooo]/7ookK1o`000002oonf`@03o`000?oo]/7ookK100?o00001Ooo]/43o`0000;ookK100?o
0000oonf`Ol000000ooo]/401?l0003ookK1oonf`Ol0000>oonf`@0300000?oo]/7ookK100;ookK1
00@00000oonf`Ooo]/4000000ooo]/400ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100?o
okK100?o0000oonf`Ooo]/401?oo]/401Ol0003ookK1oonf`Ooo]/40000000;ookK100D00000oonf
`Ooo]/7ookK100000003oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000
ooooo`3oool08P3oool<oonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo]/404Ooo]/40
0ol00?oookK1oonf`@0Aoonf`@03o`00oooo]/7ookK101SookK100?o003ooonf`Ooo]/403?oo]/45
o`0000kookK100?o003ooonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool07P3oool01P000000oooo0?ooo`3ooooookK1000000?ookK100H00000oonf`Ol00000
0000oonf`Ol00002oonf`@?o00001?oo]/47o`0000;ookK100Co0000oonf`Ooo]/7o00000ooo]/43
000000GookK10P000003oonf`@05o`000?oo]/7ookK1o`000?oo]/400_l00003oonf`@Go00000ooo
]/401_l0003ookK1oonf`Ol0003ookK1o`0000;ookK100D00000oonf`Ooo]/7ookK10000000=oonf
`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/4000000ooo]/400ol0003ookK1oonf`@04
oonf`@03o`000?oo]/7ookK100CookK100?o0000oonf`Ooo]/400ooo]/401Ol0003ookK1oonf`Ooo
]/40000000;ookK100D00000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7oooooooooool0
00002_ooool000Wooooo00?o0000ooooo`3oool08P3oool<oonf`@03o`00oooo]/7ookK1017ookK1
00?o003ooonf`Ooo]/403ooo]/400ol00?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK101OookK1
00?o003ooonf`Ooo]/403?oo]/45o`0000kookK100?o003ooonf`Ooo]/401ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool07P3oool01P000000oooo0?ooo`3ooooookK10000
00?ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf`@02o`0000;ookK10ol00007oonf
`@04o`000?oo]/7ookK1o`0000;ookK100?o0000oonf`Ooo]/400ooo]/45000000CookK100Ko0000
oonf`Ooo]/7o0000oonf`Ol00003oonf`@;o00001Ooo]/42o`0000;ookK100Go0000oonf`Ol0003o
okK1o`000002oonf`@0500000?oo]/7ookK1oonf`@0000003Ooo]/400`00003ookK1oonf`@02oonf
`@0400000?oo]/7ookK1000000?ookK100?o0000oonf`Ooo]/401?oo]/400ol0003ookK1oonf`@04
oonf`@03o`000?oo]/7ookK100?ookK100Go0000oonf`Ooo]/7ookK100000002oonf`@0500000?oo
]/7ookK1oonf`@0000000ooo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`00
0?ooool0oooo0280oooo3?oo]/400ol00?oookK1oonf`@0Aoonf`@03o`00oooo]/7ookK100oookK1
00?o003ooonf`Ooo]/404ooo]/400ol00?oookK1oonf`@0Hoonf`@03o`00oooo]/7ookK100cookK1
0ol0000?oonf`@03o`00oooo]/7ookK100OookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo01h0oooo00D000000?ooo`3oool0oooo00000003oonf`@0300000?oo]/40000000;o
okK100<00000oonf`Ooo]/400_l00002oonf`@03o`000?oo]/7ookK100WookK100Co0000oonf`Ooo
]/7o00000_oo]/400ol0003ookK1oonf`@0:oonf`@04o`000?oo]/7ookK1o`0000;ookK100Co0000
oonf`Ooo]/7o00002Ooo]/400ol0003ookK1o`000002oonf`@03o`000?oo]/7o000000;ookK100D0
0000oonf`Ooo]/7ookK10000000=oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003o
okK1oonf`Ooo]/7o000000KookK100?o0000oonf`Ooo]/400_oo]/400ol0003ookK1oonf`@03oonf
`@05o`000?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D0
0000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooo`_ookK100?o
003ooonf`Ooo]/404_oo]/400ol00?oookK1oonf`@0>oonf`@03o`00oooo]/7ookK101CookK100?o
003ooonf`Ooo]/406?oo]/400ol00?oookK1oonf`@0Noonf`@03o`00oooo]/7ookK100OookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01h0oooo00D000000?ooo`3oool0oooo
00000003oonf`@03o`000?oo]/40000000;ookK100L00000oonf`Ol0003ookK1o`000?oo]/7o0000
00CookK11Ol00004oonf`@04o`000?oo]/7ookK1o`0000;ookK100?o0000oonf`Ooo]/402?oo]/40
1?l0003ookK1oonf`Ol00002oonf`@04o`000?oo]/7ookK1o`0000_ookK100?o0000oonf`Ol00000
0_oo]/400ol0003ookK1o`000002oonf`@0400000?oo]/7ookK1000000gookK100D00000oonf`Ooo
]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`Ol000001ooo]/44o`0000KookK100Go0000
oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1
oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280oooo2_oo]/400ol00?oookK1
oonf`@0Doonf`@03o`00oooo]/7ookK100gookK100?o003ooonf`Ooo]/405Ooo]/400ol00?oookK1
oonf`@0Goonf`@03o`00oooo]/7ookK101kookK100?o003ooonf`Ooo]/401ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool07P3oool01@000000oooo0?ooo`3ooooo000000?o
okK100<00000oonf`@0000000_oo]/401`00003ookK1o`000?oo]/7o0000oonf`Ol000001?oo]/40
1Ol0003ookK1oonf`Ooo]/7o000000CookK100Co0000oonf`Ooo]/7o00000_oo]/400ol0003ookK1
oonf`@08oonf`@04o`000?oo]/7ookK1o`0000;ookK100Co0000oonf`Ooo]/7o00002ooo]/400ol0
003ookK1o`000002oonf`@03o`000?oo]/7o000000;ookK100@00000oonf`Ooo]/4000003Ooo]/40
1@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/7ookK1o`00000Aoonf`@05o`00
0?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf
`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooo`[ookK100?o003ooonf
`Ooo]/401ooo]/43o`0000[ookK100?o003ooonf`Ooo]/403Ooo]/400ol00?oookK1oonf`@08oonf
`@?o00002_oo]/400ol00?oookK1oonf`@0Goonf`@03o`00oooo]/7ookK101kookK100?o003ooonf
`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool07P3oool01@00
0000oooo0?ooo`3oool0000000?ookK100<00000oonf`@0000000_oo]/401`00003ookK1o`000?oo
]/7o0000oonf`Ol000000ooo]/400ol0003ookK1oonf`@03oonf`@05o`000?oo]/7ookK1oonf`Ol0
00000_oo]/401Ol0003ookK1oonf`Ooo]/7o000000WookK100Co0000oonf`Ooo]/7o00000_oo]/40
1?l0003ookK1oonf`Ol00005oonf`@03o`000?oo]/7ookK100?ookK100?o0000oonf`Ol000000_oo
]/400ol0003ookK1o`000002oonf`@0400000?oo]/7ookK1000000gookK100D00000oonf`Ooo]/7o
okK100000003oonf`@0300000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/403Ooo]/400ol0003o
okK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401P00003ookK1oonf`Ooo]/40
0000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool:
oonf`@03o`00oooo]/7ookK100KookK11Ol00009oonf`@03o`00oooo]/7ookK100gookK100?o003o
oonf`Ooo]/401ooo]/45o`0000WookK100?o003ooonf`Ooo]/405ooo]/400ol00?oookK1oonf`@0M
oonf`@03o`00oooo]/7ookK100SookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo01d0oooo00<000000?ooo`3oool00P3oool01000003ookK1oonf`@000002oonf`@0700000?oo
]/400000oonf`Ol0003ookK1o`000002oonf`@04o`000?oo]/7ookK1o`0000KookK100Go0000oonf
`Ooo]/7ookK1o`000002oonf`@05o`000?oo]/7ookK1oonf`Ol000002?oo]/401ol0003ookK1oonf
`Ooo]/7o0000oonf`Ol000000_oo]/400ol0003ookK1oonf`@03oonf`@03o`000?oo]/7o000000Go
okK100Go0000oonf`Ol0003ookK1o`000002oonf`@03o`000?oo]/40000000;ookK100<00000oonf
`Ooo]/403?oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/7ookK1o`00
000?oonf`@03o`000?oo]/7ookK100;ookK100Co0000oonf`Ooo]/4000000ooo]/401@00003ookK1
oonf`Ooo]/40000000;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`0R0?ooo`[ookK100?o003ooonf`Ooo]/401_oo]/45o`0000WookK100?o003ooonf`Ooo]/40
3?oo]/400ol00?oookK1oonf`@08oonf`@Go00002Ooo]/400ol00?oookK1oonf`@0Hoonf`@03o`00
oooo]/7ookK101_ookK100?o003ooonf`Ooo]/402Ooo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`0400000?oo]/7ookK1000000;o
okK100L00000oonf`@00003ookK1o`000?oo]/7o000000;ookK100Co0000oonf`Ooo]/7o00001ooo
]/401?l0003ookK1oonf`Ol00002oonf`@05o`000?oo]/7ookK1oonf`Ol000002?oo]/401ol0003o
okK1oonf`Ooo]/7o0000oonf`Ol000000_oo]/400ol0003ookK1oonf`@02oonf`@05o`000?oo]/7o
okK1oonf`Ol000001?oo]/401Ol0003ookK1o`000?oo]/7o000000;ookK100?o0000oonf`@000000
0_oo]/400`00003ookK1oonf`@0<oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/400`00003o
okK1oonf`@02oonf`@;o00003?oo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf
`@0000000ooo]/401@00003ookK1oonf`Ooo]/40000000;ookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooo`[ookK100?o003ooonf`Ooo]/401_oo]/45o`00
00WookK100?o003ooonf`Ooo]/403?oo]/400ol00?oookK1oonf`@08oonf`@Go00002Ooo]/400ol0
0?oookK1oonf`@0Hoonf`@03o`00oooo]/7ookK101_ookK100?o003ooonf`Ooo]/402Ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool07@3oool00`000000oooo0?ooo`020?oo
o`0400000?oo]/7ookK1000000;ookK100L00000oonf`@00003ookK1o`000?oo]/7o000000;ookK1
00Co0000oonf`Ooo]/7o00001ooo]/401?l0003ookK1oonf`Ol00002oonf`@05o`000?oo]/7ookK1
oonf`Ol000002?oo]/401ol0003ookK1oonf`Ooo]/7o0000oonf`Ol000000_oo]/400ol0003ookK1
oonf`@03oonf`@03o`000?oo]/7o000000GookK100Go0000oonf`Ol0003ookK1o`000002oonf`@03
o`000?oo]/40000000;ookK100<00000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@02oonf`@04
o`000?oo]/7ookK1000000KookK10_l00008oonf`@;o00001Ooo]/401@00003ookK1oonf`Ooo]/40
000000?ookK100D00000oonf`Ooo]/7ookK100000002oonf`@;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool08P3oool:oonf`@03o`00oooo]/7ookK100OookK10ol0000:
oonf`@03o`00oooo]/7ookK100cookK100?o003ooonf`Ooo]/402Ooo]/43o`0000[ookK100?o003o
oonf`Ooo]/406Ooo]/400ol00?oookK1oonf`@0Ioonf`@03o`00oooo]/7ookK100[ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01d0oooo00<000000?ooo`3oool00P3oool0
1000003ookK1oonf`@000002oonf`@0700000?oo]/400000oonf`Ol0003ookK1o`000002oonf`@04
o`000?oo]/7ookK1o`0000KookK100Go0000oonf`Ooo]/7ookK1o`000002oonf`@05o`000?oo]/7o
okK1oonf`Ol000002?oo]/401ol0003ookK1oonf`Ooo]/7o0000oonf`Ol000000_oo]/400ol0003o
okK1oonf`@04oonf`@03o`000?oo]/7ookK100CookK100Go0000oonf`Ol0003ookK1o`000002oonf
`@03o`000?oo]/40000000;ookK100<00000oonf`Ooo]/403Ooo]/401@00003ookK1oonf`Ooo]/40
000000?ookK100<00000oonf`Ooo]/401Ooo]/42o`0000CookK10_l00006oonf`@0300000?oo]/7o
okK100;ookK100D00000oonf`Ooo]/7ookK100000002oonf`@0400000?oo]/7ookK1oonf`@;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool:oonf`@03o`00oooo
]/7ookK101CookK100?o003ooonf`Ooo]/403?oo]/400ol00?oookK1oonf`@0Foonf`@03o`00oooo
]/7ookK101[ookK100?o003ooonf`Ooo]/406?oo]/400ol00?oookK1oonf`@0:oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000
0ooo]/400`00003ookK100000002oonf`@0700000?oo]/7o0000oonf`Ol0003ookK1o`000003oonf
`@03o`000?oo]/7ookK100;ookK100?o0000oonf`Ooo]/400_oo]/401?l0003ookK1oonf`Ol00002
oonf`@03o`000?oo]/7ookK100SookK100Co0000oonf`Ooo]/7o00000_oo]/401?l0003ookK1oonf
`Ol0000;oonf`@03o`000?oo]/7o000000;ookK100?o0000oonf`Ol000000_oo]/401000003ookK1
oonf`@000007oonf`@8000001_oo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf
`@0000002?oo]/44o`0000SookK100D00000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7o
okK1oonf`@0000000ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo0280oooo2ooo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK100kookK100?o003o
oonf`Ooo]/405?oo]/400ol00?oookK1oonf`@0Loonf`@03o`00oooo]/7ookK101GookK10_l00?l=
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0N0?ooo`050000003oool0
oooo0?ooool000000ooo]/400`00003ookK100000002oonf`@0600000?oo]/7o0000oonf`Ol0003o
okK10_l00003oonf`@Co00001?oo]/42o`0000;ookK100Co0000oonf`Ooo]/7o00002_oo]/401?l0
003ookK1oonf`Ol00002oonf`@04o`000?oo]/7ookK1o`0000[ookK10_l000001ooo]/7o0000oonf
`Ooo]/7o0000oonf`Ol000000_oo]/401000003ookK1oonf`@000004oonf`@0600000?l000000000
oonf`Ol0000000001_oo]/401Ol0003ookK1oonf`Ooo]/40000000CookK100<00000o`0000000000
4?oo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401000003o
okK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280
oooo2ooo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK100kookK100?o003ooonf`Ooo
]/405?oo]/400ol00?oookK1oonf`@0Moonf`@03o`00oooo]/7ookK101?ookK100?o003ooonf`Ooo
]/403Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool07P3oool01@000000
oooo0?ooo`3oool0000000?ookK100?o0000oonf`@0000000_oo]/401@00003ookK1o`000?oo]/7o
000000?ookK100?o0000oonf`Ooo]/401ooo]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK100?o
0000oonf`Ooo]/402_oo]/401_l0003ookK1oonf`Ol0003ookK1o`0000?ookK100?o0000oonf`Ooo
]/401_oo]/401ol0003ookK1oonf`Ooo]/7o0000oonf`Ol000000_oo]/401?l0003ookK1oonf`@00
0002oonf`@0500000?oo]/7ookK1oonf`@0000001_oo]/400`00003ookK1oonf`@03oonf`@030000
0?oo]/7ookK100;ookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@0<oonf`@030000
0?oo]/7ookK100?ookK100D00000oonf`Ooo]/7ookK100000003oonf`@0400000?oo]/7ookK1oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool<oonf`@03
o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo]/404?oo]/400ol00?oookK1oonf`@0Coonf`@03
o`00oooo]/7ookK101kookK10_l00?lBoonf`@03o`00oooo]/7ookK100kookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo01h0oooo00H000000?ooo`3oool0oooooonf`@000002
oonf`@0400000?oo]/7ookK1000000;ookK100D00000oonf`Ol0003ookK1o`000003oonf`@?o0000
1Ooo]/401Ol0003ookK1oonf`Ooo]/7o000000;ookK100?o0000oonf`Ooo]/400_oo]/46000000Co
okK100Go0000oonf`Ooo]/7o0000oonf`@02o`0000;ookK10ol00003oonf`@;o00000ooo]/401_l0
003ookK1oonf`Ol0003ookK1o`0000;ookK100@00000oonf`Ooo]/4000000ooo]/400`00003ookK1
oonf`@06oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/42000000GookK1
00<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@00
00000ooo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool08P3oool<oonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf`Ooo]/40
4?oo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK1027ookK100?o003ooonf`Ooo]/40
3_oo]/400ol00?oookK1oonf`@0?oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`0N0?ooo`060000003oool0oooo0?oooooo]/4000000ooo]/401P00003ookK100000?l0003o
okK1000000;ookK100Co0000oonf`Ol0003o00001?oo]/45o`0000;ookK10_l00002oonf`@03o`00
0?oo]/7ookK100<000001_oo]/400ol0003ookK1oonf`@02oonf`@04o`000?oo]/7ookK1o`0000;o
okK10_l00003oonf`@?o00000ooo]/42o`0000;ookK100?o0000oonf`Ol000000_oo]/401000003o
okK1oonf`@000003oonf`@03o`000?oo]/7ookK100SookK100?o0000oonf`Ooo]/400ooo]/400`00
003o0000oonf`@03oonf`@0300000?oo]/7ookK100?ookK100?o00000000000000002Ooo]/400`00
003ookK1oonf`@03oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/400`00003ookK1oonf`@02
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool=oonf
`@03o`00oooo]/7ookK100gookK10_l00?lDoonf`@03o`00oooo]/7ookK1013ookK100?o003ooonf
`Ooo]/408ooo]/400ol00?oookK1oonf`@0:oonf`@?o003o4_oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool07P3oool01P000000oooo0?ooo`3ooooookK1000000?ookK100@0
0000oonf`Ooo]/4000000_oo]/400ol0003ookK1o`000003oonf`@03o`000?oo]/7ookK100KookK1
0_l00003oonf`@04o`000?oo]/7ookK1000000[ookK100D00000oonf`Ooo]/7ookK1o`000002oonf
`@03o`000?oo]/7ookK100;ookK10ol00003oonf`@?o00000ooo]/400ol0003ookK1o`000003oonf
`@0400000?oo]/7ookK1000000?ookK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@03
oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401Ooo]/43000000GookK100<00000
oonf`Ooo]/401?oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/400_oo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo3_oo]/40
0ol00?oookK1oonf`@0;oonf`@03o`00oooo]/7ookK101GookK100?o003ooonf`Ooo]/403_oo]/40
0ol00?oookK1oonf`@0Uoonf`@Co003o1?oo]/44o`00oaGookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo01l0oooo00<000000?ooo`3oool00_oo]/401@00003ookK1oonf`Ooo
]/40000000;ookK100<00000oonf`@0000000_oo]/42o`0000;ookK12?l00004oonf`@04o`000?oo
]/7ookK1000000cookK10P000002oonf`@;o000000CookK1o`000?l0003o00001?oo]/43o`0000?o
okK10ol00002oonf`@04o`000?oo]/7ookK1000000;ookK100D00000oonf`Ooo]/7ookK10000000=
oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@07
oonf`@D000001ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/400_oo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo3ooo]/40
0ol00?oookK1oonf`@09oonf`@03o`00oooo]/7ookK101OookK10_l00?l=oonf`@03o`00oooo]/7o
okK102[ookK11?l00?lIoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0O
0?ooo`030000003oool0oooo00;ookK100D00000oonf`Ooo]/7ookK100000002oonf`@0400000?oo
]/7ookK1000000?ookK100?o0000oonf`Ooo]/402Ooo]/42o`0000;ookK100?o0000oonf`Ooo]/40
0ooo]/46000000CookK100D00000oonf`Ooo]/7ookK1o`000003oonf`@;o00001_oo]/42o`0000Co
okK100Co0000oonf`Ooo]/4000000_oo]/401@00003ookK1oonf`Ooo]/40000000oookK100<00000
oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK101;ookK100<00000
oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000CookK10_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooa3ookK11Ol00?l2oonf`@Co003o7?oo]/43
o`00o`OookK10ol00?m:oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0O
0?ooo`030000003oool0oooo00?ookK100D00000oonf`Ooo]/7ookK100000002oonf`@0700000?oo
]/7ookK100000?l000000000oonf`@0;o`0000;ookK10P000003oonf`@80000000?o0000oonf`Ooo
]/401?oo]/400ol000000000oonf`@02oonf`@0400000?oo]/7ookK1oonf`@;o00000ooo]/47o`00
00;ookK10ol000001?oo]/400000o`000?oo]/42000000?ookK100?o0000oonf`Ooo]/403ooo]/40
0ol000000000oonf`@03oonf`@0300000?oo]/7ookK100;ookK10P00000Boonf`@0300000?oo]/7o
okK100;ookK100D00000oonf`Ooo]/7ookK100000004oonf`@;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool08P3ooolEoonf`@;o003o8ooo]/47o`00odgookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0oooo00<000000?ooo`3oool01?oo]/40
1Ol0003ookK1oonf`Ooo]/40000000;ookK100?o000000000?oo]/400_oo]/42000000WookK10`00
0003oonf`@8000002ooo]/42000000;ookK100?o000000000?oo]/400_oo]/42o`0000SookK10_l0
0003oonf`@0400000?oo]/7ookK1000000CookK100<00000oonf`Ooo]/401_oo]/44000000SookK1
00<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100oookK1
00<00000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000CookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooohkookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo0200oooo00<000000?oooooo]/401?oo]/401@00003ookK1
oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/400_oo]/43000000?ookK10`000004oonf`@80
00003ooo]/42000000;ookK100<00000oonf`Ooo]/400_oo]/48o`0000CookK100@00000oonf`Ooo
]/4000001?oo]/400`00003ookK1oonf`@04oonf`@<000001?oo]/400`00003ookK1oonf`@06oonf
`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@0@oonf
`@0500000?oo]/7ookK1oonf`@0000001?oo]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool08@3oool00`00003ookK1oonf`@04oonf`@0500000?oo]/7o
okK1oonf`@0000000ooo]/401000003o0000000000000003oonf`@<000000ooo]/4300000003o`00
0?oo]/7ookK100CookK100?o00000000000000001@000005oonf`@80000000?ookK100000?l00000
0P000009oonf`@80000000Co0000oonf`@00000000001?oo]/400ol0003ookK1oonf`@02oonf`@<0
00002?oo]/400`00003o0000oonf`@05oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf`Ooo
]/400_oo]/400`00003ookK1oonf`@0?oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/401000
003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
0280ooooS_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08@3oool00`00
003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK100?o000000000?oo]/401?oo]/430000
00?ookK10`000007oonf`@<000002?oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1
00;ookK12@000003oonf`@0300000?oo]/7ookK100;ookK10P000004oonf`@0300000?oo]/7ookK1
00_ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@04oonf`@05o`000?oo]/7ookK1
oonf`@0000004Ooo]/401@00003ookK1oonf`Ooo]/40000000CookK100@00000oonf`Ooo]/7ookK1
0_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooohkookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0280oooo00<00000oonf`Ooo]/401?oo
]/42000000CookK100<00000oonf`Ooo]/401Ooo]/43000000OookK10`00000<oonf`@<000001?oo
]/43000000[ookK10`000003oonf`@8000001Ooo]/400`00003ookK1oonf`@0=oonf`@0300000?oo
]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo]/40000000SookK1
1Ol00005oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401000003ookK1oonf`Ooo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool00ooo]/400000oonf`@06oonf`@03
00000?oo]/7ookK100;ookK10`00000<oonf`@03o`000000003ookK1017ookK10P000005oonf`@X0
00001Ooo]/400ol0003ookK1oonf`@04oonf`@03o`000?oo]/7ookK100oookK100<00000oonf`Ooo
]/400ooo]/400`00003ookK1oonf`@03oonf`@0500000?oo]/7ookK1oonf`@0000001_oo]/400ol0
003ookK1oonf`@03oonf`@03o`000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK100000003
oonf`@04o`000?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool08P3ooon>oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0R
0?ooo`;ookK10P000006oonf`@0300000?oo]/7ookK100CookK100<00000o`00000000002@000005
oonf`@/000001Ooo]/400ol0000000000000000Aoonf`@8000001?oo]/42000001?ookK100?o0000
oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001Ooo
]/400ol0003ookK1oonf`@05oonf`@;o00000ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK1
00<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo02H0oooo00<0
00000?ooo`3oool0103oool00ol0000000000000000A0?ooo`<000002`3oool00`000000oooo0?oo
o`050?ooo`<000002P3oool4000000@0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00H0
00000?ooo`3oool0oooooonf`@000003oonf`@0300000?oo]/7ookK100;ookK100?o0000oonf`Ooo
]/402?oo]/42o`0000;ookK100@00000oonf`Ooo]/4000000ooo]/400`00003ookK1oonf`@02oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`<0
00003@3oool00`000000oooo0?ooo`0=0?ooo`<000001`3oool:000000H0oooo0P00000H0?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3ooooookK100000003oonf`@0500000?oo]/7ookK1
oonf`Ol000003Ooo]/401?l0003ookK1oonf`@000002oonf`@0600000?oo]/7ookK1oonf`@00003o
okK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`kookK1
2Ol00?l<oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0X0?ooo`030000
003oool0oooo00P0oooo0P0000000ol00000000000000008000001<0oooo1000000A0?ooo`800000
6`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooooonf`@0000000ooo]/401000003o
okK1oonf`Ol00005oonf`@Oo00000ooo]/401?l0003ookK1oonf`@000002oonf`@0500000?oo]/7o
okK100000?oo]/400_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=
0?ooo`_ookK10ol00?l9oonf`@;o003o2_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool0:@3oool00ol0000000000?ooo`0[0?ooo`<000002P3oool4000000/0oooo2@00000:
0?ooo`05o`00003oool0oooo0?ooo`0000000P3oool00ooo]/400000oonf`@02oonf`@0400000?oo
]/7ookK1o`0000CookK100?o0000oonf`Ooo]/401Ooo]/401?l0003ookK1oonf`Ol00002oonf`@04
00000?oo]/7ookK1000000;ookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0
003ooooo0?ooo`2=0?ooo`[ookK100?o003ooonf`Ooo]/403?oo]/400ol00?oookK1oonf`@07oonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0[0?ooo`800000;@3oool:0000
00d0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`03oonf`@00003ookK100;ookK100@00000oonf`Ooo]/7o00000ooo]/400ol0003ookK1oonf
`@07oonf`@03o`000?oo]/7o000000?ookK100<00000oonf`@0000000_oo]/401@00003ookK1oooo
oooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo2Ooo]/400ol00?oookK1oonf
`@0>oonf`@03o`00oooo]/7ookK100KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo02d0oooo0P00000E0?ooo`/00000803oool2000000`0oooo00<000000?ooo`3oool01`3o
ool020000000oooo0?ooo`3oool000000?oooooo]/4000000_oo]/401000003ookK1oonf`Ol00003
oonf`@03o`000?oo]/7ookK100WookK100?o0000oonf`Ol000000_oo]/401000003ookK1oonf`@00
0002oonf`@0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo2?oo
]/400ol00?oookK1oonf`@0@oonf`@03o`00oooo]/7ookK100GookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo02l0oooo00@00000o`000000000000003P3oool3000000/0oooo
00<00000o`00000000006P3oool200000003o`00003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool020000000oooo0?ooo`3oool000000?oooooo]/4000000_oo]/401000003ookK1oonf`Ol0
0002oonf`@03o`000?oo]/7ookK100;ookK11_l00003oonf`@03o`000?oo]/7o000000;ookK100<0
0000oonf`@0000000_oo]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?oo
o`2=0?ooo`SookK100?o003ooonf`Ooo]/404?oo]/400ol00?oookK1oonf`@05oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0c0?ooo`h000004@3oool2000001H0oooo0P00
000C0?ooo`030000003oool0oooo00D0oooo00P000000?ooo`3oool0oooo0000003ooooookK10000
00;ookK100@00000oonf`Ooo]/7o00000_oo]/400ol0003ookK1oonf`@02o`0000KookK100Ko0000
oonf`Ooo]/7o0000oonf`Ol00002oonf`@0300000?oo]/40000000;ookK100@00000oooooooooooo
00002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool7oonf`@03o`00oooo]/7ookK101;ookK1
00?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
E03oool300000140oooo0P00000F0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0
00000?oooooo]/40000000;ookK100H00000oonf`Ooo]/7o0000oonf`Ol00002oonf`@03o`000?oo
]/7ookK100OookK100?o0000oonf`Ol000000_oo]/401_l0003ookK1oonf`@00003ookK1000000;o
okK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool7oonf`@03o`00
oooo]/7ookK101;ookK100?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0E`3oool7000000<0oooo0P0000000ol00000000000000002000001T0oooo
00<000000?ooo`3oool0103oool01`000000oooo0?ooo`000000oooooonf`@0000000_oo]/400`00
003ookK1o`000002oonf`@03o`000?oo]/7o000000_ookK100?o0000oonf`Ol000000_oo]/401Ol0
003ookK100000?oo]/40000000;ookK100?o0000ooooool000002_ooool000Wooooo00?o0000oooo
o`3oool0S@3oool6oonf`@03o`00oooo]/7ookK101?ookK100?o003ooonf`Ooo]/401?oo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0GP3oool300000200oooo00<000000?oo
o`3oool0103oool01`000000oooo0?ooo`000000oooooonf`@0000000_oo]/400`00003ookK1o`00
0002oonf`@03o`000?oo]/7o000000_ookK100?o0000oonf`Ol000000_oo]/401Ol0003ookK10000
0?oo]/40000000;ookK100?o0000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3o
ool6oonf`@03o`00oooo]/7ookK101CookK100?o003ooonf`Ooo]/400ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0PP3oool00`000000oooo0?ooo`030?ooo`070000003o
ool0oooo0000003ooooookK100000002oonf`@0300000?oo]/7o000000;ookK100?o0000oonf`Ol0
00002ooo]/400ol0003ookK1o`000002oonf`@05o`000?oo]/400000oonf`@0000000_oo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo1_oo]/400ol00?oo
okK1oonf`@07oonf`@?o00002_oo]/400ol00?oookK1oonf`@03oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo00000002oonf`@0500000?oo]/400000oonf`Ol000000_oo]/400ol0003ookK1o`00000;
oonf`@08o`000?oo]/7ookK1o`000?oo]/7o0000oonf`@000002oonf`@0500000?oo]/7ooooooooo
ool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool6oonf`@03o`00oooo]/7ookK100Ko
okK11Ol00009oonf`@03o`00oooo]/7ookK100?ookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo0880oooo00?o00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00;ookK100D00000oonf`@00003ookK1o`000002oonf`@03o`000?oo]/7o000000_ookK100So0000
oonf`Ooo]/7o0000oonf`Ol0003ookK1000000;ookK100D00000oonf`Oooooooooooo`00000:oooo
o`002Oooool00ol0003ooooo0?ooo`2=0?ooo`KookK100?o003ooonf`Ooo]/401_oo]/45o`0000Wo
okK100?o003ooonf`Ooo]/400ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
ool0PP3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000_oo]/401@00
003ookK100000?oo]/7o000000;ookK100?o0000oonf`Ol000002ooo]/402?l0003ookK1oonf`Ol0
003ookK1o`000?oo]/4000000_oo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03
o`000?ooool0oooo08d0oooo1_oo]/400ol00?oookK1oonf`@06oonf`@Go00002Ooo]/400ol00?oo
okK1oonf`@03oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`230?ooo`03
0000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo00000?oo]/40000000;ookK100<00000
oonf`Ol000000_oo]/400ol0003ookK1o`000009oonf`@04o`000?oo]/7ookK1o`0000;ookK100Go
0000oonf`@00003ookK100000002oonf`@03o`000?oooooo000000[ooooo0009ooooo`03o`000?oo
ool0oooo08d0oooo1_oo]/400ol00?oookK1oonf`@07oonf`@?o00002_oo]/400ol00?oookK1oonf
`@03oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`240?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo00000?oo]/40000000;ookK100<00000oonf`Ol0
00000_oo]/401?l0003ookK1oonf`Ol00008oonf`@06o`000?oo]/7ookK1o`000?oo]/7o00000_oo
]/400`00003ookK100000002oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0
oooo08d0oooo1_oo]/400ol00?oookK1oonf`@0Coonf`@03o`00oooo]/7ookK100CookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08@0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3ooooo0000oonf`@0000000_oo]/400`00003ookK1o`000002oonf`@04o`00
0?oo]/7ookK1oonf`@;o00001?oo]/42o`0000?ookK100?o0000oonf`Ol000000_oo]/400`00003o
okK100000002oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo
1ooo]/400ol00?oookK1oonf`@0Boonf`@03o`00oooo]/7ookK100CookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo08@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000;ookK100H00000oonf`Ooo]/400000oonf`Ol00002oonf`@03o`000?oo]/7o
okK100;ookK100Co0000oonf`Ol0003o00001?oo]/400ol0003ookK1o`000002oonf`@0300000?oo
]/40000000?ookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool7
oonf`@03o`00oooo]/7ookK101;ookK100?o003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`070000003oool0
oooooonf`@00003ookK100000002oonf`@0300000?oo]/7o000000?ookK100?o0000oonf`Ooo]/40
0_oo]/400ol0003ookK1oonf`@03oonf`@04o`000?oo]/7ookK1o`0000;ookK100<00000oonf`Ol0
00000_oo]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`So
okK100?o003ooonf`Ooo]/404?oo]/400ol00?oookK1oonf`@05oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`250?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
oooookK100000002oonf`@06o`000?oo]/7ookK100000?oo]/7o00000ooo]/44o`0000;ookK11?l0
0002oonf`@04o`000?oo]/7ookK1000000;ookK100@00000oonf`Ooo]/4000000_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`WookK100?o003ooonf`Ooo]/40
3ooo]/400ol00?oookK1oonf`@05oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`250?ooo`030000003oool0oooo0080oooo00D000000?ooo`3ooooookK100000002oonf`@06
00000?oo]/7ookK1oonf`@00003ookK10_l00005oonf`@;o00001?oo]/42o`0000;ookK100@00000
oonf`Ooo]/4000000ooo]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?oo
o`2=0?ooo`[ookK100?o003ooonf`Ooo]/403?oo]/42o`00o`SookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo08H0oooo00<000000?ooo`3oool00P3oool01@000000oooooonf
`Ooo]/40000000;ookK100D00000oonf`Ooo]/7ookK100000002oonf`@;o00002?oo]/401Ol0003o
okK1oonf`Ooo]/40000000;ookK100H00000oonf`Ooo]/7ookK100000?oo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo2ooo]/400ol00?oookK1oonf`@09
oonf`@;o003o2_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0QP3oool0
0ol00000oooo0?ooo`030?ooo`0500000?oo]/7ookK1oonf`@0000000_oo]/401@00003ookK1oonf
`Ooo]/40000000?ookK10ol000000ooo]/7o0000o`000002o`0000?ookK100Co0000oonf`Ooo]/7o
00000ooo]/400ol0003ookK1oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0oooo08d0oooo3?oo]/43o`00o`OookK100?o003ooonf`Ooo]/402_oo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool0QP3oool00`000000oooo0?ooo`040?ooo`04o`00
0?oo]/7ookK1o`0000?ookK100Co000000000?oo]/7o00000P000004oonf`@03o`000?oo]/7ookK1
00?ookK10P000002oonf`@8000000_oo]/401`00003ookK1oonf`Ooo]/400000ooooool000002_oo
ool000Wooooo00?o0000ooooo`3oool0S@3oool?oonf`@Oo003o3Ooo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`0500000?oo]/7o
okK1oonf`@0000001?oo]/401000003ookK1oonf`Ooo]/44000000;ookK110000002oonf`@800000
0ooo]/400`00003ookK1oonf`@02oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?oo
ool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0Q`3o
ool00`000000oooo0?ooo`030?ooo`03oonf`@00003ookK100;ookK100<00000oonf`Ooo]/400_oo
]/400`00003ookK1oonf`@04oonf`@8000001Ooo]/400ol0003ookK1oonf`@02oonf`@0300000?oo
]/7ookK100;ookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0S@3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`280?ooo`030000003o
ool0oooo0080oooo0_oo]/401`00003ookK1oonf`Ooo]/400000o`00000000000_oo]/400ol00000
000000000009oonf`@8000000_oo]/42000000CookK100D00000oonf`Oooooooooooo`00000:oooo
o`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo08T0oooo00Co00000?ooo`3oool0oooo0ooo]/400ol0003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100;ookK12@000002oonf`@8000001Ooo]/400`00003ookK1oonf`@02oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R@3oool010000000oooo0?ooo`3oool4oonf
`@0300000?oo]/7ookK100?ookK10`00000:oonf`@8000001_oo]/401000003ookK1oonf`Ooo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0RP3oool00`000000oooo0?ooo`05oonf
`@0300000?oo]/7ookK100GookK10P000006oonf`@03o`000000003ookK100KookK100<00000oonf
`Ooo]/400_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0
oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R`3oool2000000Ko
okK100<00000o`00000000001Ooo]/400ol00000000000000004000000KookK10P0000000ol0003o
okK1oonf`@03oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0
S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`030000
0?oo]/7ookK100KookK100<00000oonf`Ooo]/403Ooo]/42000000SookK100<00000ooooool00000
2_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`2=0?ooo`03oonf`@00003ookK100OookK10`00000:oonf`@8000002Ooo
]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08d0oooo0_oo]/400`00003ookK1oonf
`@08oonf`@X000002_oo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009oooookKo00004Ooooonfo`0000[ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0380952 0.0729085 0.000939897 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07291 -6 -4.5 ]
[-0.0125 .07291 0 4.5 ]
[-0.0125 .1669 -18 -4.5 ]
[-0.0125 .1669 0 4.5 ]
[-0.0125 .26089 -18 -4.5 ]
[-0.0125 .26089 0 4.5 ]
[-0.0125 .35488 -18 -4.5 ]
[-0.0125 .35488 0 4.5 ]
[-0.0125 .44887 -18 -4.5 ]
[-0.0125 .44887 0 4.5 ]
[-0.0125 .54286 -18 -4.5 ]
[-0.0125 .54286 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .07291 m
1 .07291 L
s
0 .1669 m
1 .1669 L
s
0 .26089 m
1 .26089 L
s
0 .35488 m
1 .35488 L
s
0 .44887 m
1 .44887 L
s
0 .54286 m
1 .54286 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(5)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(10)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(15)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(20)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(25)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07291 m
.00625 .07291 L
s
[(0)] -0.0125 .07291 1 0 Mshowa
0 .1669 m
.00625 .1669 L
s
[(100)] -0.0125 .1669 1 0 Mshowa
0 .26089 m
.00625 .26089 L
s
[(200)] -0.0125 .26089 1 0 Mshowa
0 .35488 m
.00625 .35488 L
s
[(300)] -0.0125 .35488 1 0 Mshowa
0 .44887 m
.00625 .44887 L
s
[(400)] -0.0125 .44887 1 0 Mshowa
0 .54286 m
.00625 .54286 L
s
[(500)] -0.0125 .54286 1 0 Mshowa
.125 Mabswid
0 .09171 m
.00375 .09171 L
s
0 .1105 m
.00375 .1105 L
s
0 .1293 m
.00375 .1293 L
s
0 .1481 m
.00375 .1481 L
s
0 .1857 m
.00375 .1857 L
s
0 .20449 m
.00375 .20449 L
s
0 .22329 m
.00375 .22329 L
s
0 .24209 m
.00375 .24209 L
s
0 .27969 m
.00375 .27969 L
s
0 .29848 m
.00375 .29848 L
s
0 .31728 m
.00375 .31728 L
s
0 .33608 m
.00375 .33608 L
s
0 .37368 m
.00375 .37368 L
s
0 .39247 m
.00375 .39247 L
s
0 .41127 m
.00375 .41127 L
s
0 .43007 m
.00375 .43007 L
s
0 .46767 m
.00375 .46767 L
s
0 .48646 m
.00375 .48646 L
s
0 .50526 m
.00375 .50526 L
s
0 .52406 m
.00375 .52406 L
s
0 .05411 m
.00375 .05411 L
s
0 .03531 m
.00375 .03531 L
s
0 .01651 m
.00375 .01651 L
s
0 .56166 m
.00375 .56166 L
s
0 .58045 m
.00375 .58045 L
s
0 .59925 m
.00375 .59925 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07291 m
1 .07291 L
s
.99375 .1669 m
1 .1669 L
s
.99375 .26089 m
1 .26089 L
s
.99375 .35488 m
1 .35488 L
s
.99375 .44887 m
1 .44887 L
s
.99375 .54286 m
1 .54286 L
s
.125 Mabswid
.99625 .09171 m
1 .09171 L
s
.99625 .1105 m
1 .1105 L
s
.99625 .1293 m
1 .1293 L
s
.99625 .1481 m
1 .1481 L
s
.99625 .1857 m
1 .1857 L
s
.99625 .20449 m
1 .20449 L
s
.99625 .22329 m
1 .22329 L
s
.99625 .24209 m
1 .24209 L
s
.99625 .27969 m
1 .27969 L
s
.99625 .29848 m
1 .29848 L
s
.99625 .31728 m
1 .31728 L
s
.99625 .33608 m
1 .33608 L
s
.99625 .37368 m
1 .37368 L
s
.99625 .39247 m
1 .39247 L
s
.99625 .41127 m
1 .41127 L
s
.99625 .43007 m
1 .43007 L
s
.99625 .46767 m
1 .46767 L
s
.99625 .48646 m
1 .48646 L
s
.99625 .50526 m
1 .50526 L
s
.99625 .52406 m
1 .52406 L
s
.99625 .05411 m
1 .05411 L
s
.99625 .03531 m
1 .03531 L
s
.99625 .01651 m
1 .01651 L
s
.99625 .56166 m
1 .56166 L
s
.99625 .58045 m
1 .58045 L
s
.99625 .59925 m
1 .59925 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.0619 .27827 L
.1 .36711 L
.1381 .44861 L
.17619 .50184 L
.21429 .52868 L
.25238 .54148 L
.29048 .54891 L
.32857 .55388 L
.36667 .5576 L
.40476 .56086 L
.44286 .56422 L
.48095 .568 L
.51905 .57226 L
.55714 .57686 L
.59524 .5815 L
.63333 .58591 L
.67143 .58991 L
.70952 .59336 L
.74762 .59622 L
.78571 .59843 L
.82381 .60007 L
.8619 .60125 L
.9 .60212 L
.9381 .60279 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.0619 .27827 Mdot
.1 .36711 Mdot
.1381 .44861 Mdot
.17619 .50184 Mdot
.21429 .52868 Mdot
.25238 .54148 Mdot
.29048 .54891 Mdot
.32857 .55388 Mdot
.36667 .5576 Mdot
.40476 .56086 Mdot
.44286 .56422 Mdot
.48095 .568 Mdot
.51905 .57226 Mdot
.55714 .57686 Mdot
.59524 .5815 Mdot
.63333 .58591 Mdot
.67143 .58991 Mdot
.70952 .59336 Mdot
.74762 .59622 Mdot
.78571 .59843 Mdot
.82381 .60007 Mdot
.8619 .60125 Mdot
.9 .60212 Mdot
.9381 .60279 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`00033ooooo0ol0000/ooooo`?o00001?ooool2o`0002[ooooo0ol00003oooo
o`?o0000:?ooool5o`0000?ooooo0_l0000Yooooo`Go00000_ooool3o`0000Cooooo000Iooooo`04
o`000?ooooooooooo`0002kooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool09_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02Wooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo007ooooo000I
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Iooooo`04o`000?ooooooooooo`0003;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00Oooool001Wooooo00Co0000oooooooooooo0000;_ooool4o`0002gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`04o`000?ooooooooooooooo`Co0000
:?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?ooool01_l0
003ooooooooooooooooo0000ooooo`Co00001?ooool001Wooooo00Co0000oooooooooooo0000;_oo
ool00ol0003oooooooooo`0]ooooo`;o00001?ooool01?l0003oooooooooool0000Yooooo`;o0000
0oooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Xooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`006_ooool2
o`0002oooooo1Ol0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`04o`000?oooooo
ooooooooo`Go0000:?ooool3o`0000Cooooo0_l0000Zooooo`?o00000_ooool5o`0000?ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eooooo`0300000?l0
003o00000?oo00001ol000010000007ooooo000Eooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`4000000Oooool001Gooooo00<00000oooo
ooooool00_ooool3ool0037ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`03oooo
o`4000000Oooool001Gooooo00@00000oooooooooooooooo1Ooo000`ooooo`030000Oooooooooooo
02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
03Kooooo0@000001ooooo`005Oooool01000003oooooooooooooool5ool0033ooooo00<0001ooooo
ooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0=_ooool10000007ooooo000Eooooo`0400000?l0003oooooooooo`Goo`00<?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`02ooooo`?o
o`00<Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
0oooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo02oooooo00<0001oooooooooool0;ooo
ool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0;oooool0
0`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000o`000?ooool01?ooool00`00
003oooooooooo`0_ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Gooooo0Ol000010000007ooooo000Eooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool0;oooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`40
00000Oooool001Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0_ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo02oooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?l0003o
oooo00Cooooo00<00000ooooooooool0;oooool00`0007ooooooooooo`0_ooooo`030000Oooooooo
oooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0eooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02kooooo00<0001ooooo
ooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool000kooooo0_l00005ooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`400000
0Oooool000gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`030000
0?oooooooooo02kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000=ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000o`00000007l01@0007l00`000000001o0000O`3m0000O`7o0000
0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool0;_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool000gooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02kooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0=_ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`0]ooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo
0@000001ooooo`003_ooool2o`0000Gooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`0]ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`06
ooooo`0300000?oooooooooo02gooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=Oooool1o`00004000000Oooool0
01Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0]ooooo`030000Oooooooooooo
02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo02go
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool0;Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0]ooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`07ooooo`0300000?oooooooooo02cooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool01oooool00`00
003oooooooooo`0/ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo02cooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007o
oooo000Eooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0;?ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0/ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`07
ooooo`0300000?oooooooooo02cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=Oooool1o`00004000000Oooool0
01Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0/ooooo`030000Oooooooooooo
02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo02_o
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool0:oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`0[ooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`08ooooo`0300000?oooooooooo02_ooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`0[ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`08ooooo`0300000?oooooooooo02_ooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007o
oooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000oooooooo
ool02?ooool00`00003oooooooooo`0[ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`00
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo02[ooooo00<0001ooooo
ooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooo
ooooool0=_ooool10000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o00T0001o00<00000
0000O`0007l0n@0007l1o`00004000000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02Ooo
ool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
=_ooool10000007ooooo00000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0=_ooool10000007ooooo0002ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`;o00001Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo02[ooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00Wooooo00<0
0000ooooooooool0:_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0
001oooooooooool0;oooool00`0007ooooooooooo`0eooooo`7o00000@000001ooooo`005Oooool0
0`00003oooooooooo`0:ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0:Oooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`0Yooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo
000Eooooo`0300000?l0003ooooo00[ooooo00<00000ooooooooool0:Oooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo02Wooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00[ooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Go
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0Xooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo02Sooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00_ooooo00<0
0000ooooooooool0:?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0
001oooooooooool0;oooool00`0007ooooooooooo`0eooooo`7o00000@000001ooooo`005Oooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo02Sooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0:?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`0Xooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0;ooooo`0300000?oooooooooo02Sooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo
000Eooooo`0300000?l0003ooooo00cooooo00<00000ooooooooool09oooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0<ooooo`0300000?oooooo
oooo02Oooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00cooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool000Go
00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool09oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool00005ooooool0003oooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool03?ooool00`00003oooooooooo`0Wooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001
ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003o00000000O`0<0000O`030000000007l0001o0?H0001o0Ol0
00010000007ooooo0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool03?ooool00`00003ooooo
ooooo`0Wooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`0000Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`0=ooooo`0300000?oooooooooo02Kooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000
007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo00cooooo0ooo000Wooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo03Kooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo00_ooooo1Ooo000Vooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`0;ooooo`Goo`009_ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0e
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0;ooooo`Goo`009_ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool3ool002Oo
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo00kooooo
00<00000ooooooooool09Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool03_ooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`0?ooooo`0300000?oooooooooo02Cooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Tooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0@ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007o
oooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool08oooool00`0007oooooo
ooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003ooooooooo
o`0Rooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0A
ooooo`0300000?oooooooooo02;ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=Oooool1o`00004000000Oooool0
01Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Rooooo`030000Oooooooooooo
02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo027o
oooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oo
oooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo01;ooooo
00<00000ooooooooool08Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo
00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool04oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02oooooo00<0
001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`0Cooooo`0300000?oooooooooo023ooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool04oooool00`00
003oooooooooo`0Pooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0Dooooo`0300000?oooooooooo01oooooo00<0001oooooooooool0;oooool00`0007oo
ooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007o
oooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000oooooooo
ool05?ooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`00
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01kooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=_ooool10000007ooooo0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o01D0001o00<0
00000000O`0007l0k@0007l1o`00004000000Oooool000;ooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Fooooo`030000
0?oooooooooo01gooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo0004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo01Kooooo0ooo000Mooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`00
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`0Eooooo`Goo`007?ooool00`0007ooooooooooo`0_
ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0f
ooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool0
0`00003oooooooooo`0Eooooo`Goo`007?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooo
oooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool0
01Gooooo00<00000o`000?ooool05Oooool5ool001cooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=Oooool1o`00
004000000Oooool001Gooooo00<00000ooooooooool05_ooool3ool001gooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool0
6oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool06Ooo
ool00`00003oooooooooo`0Jooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Iooooo`0300000?oooooooooo01[ooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool1
0000007ooooo000Eooooo`0300000?l0003ooooo01[ooooo00<00000ooooooooool06Oooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Jooooo`03
00000?oooooooooo01Wooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`030000
0?oooooooooo01_ooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`400000
0Oooool001Gooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Hooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Looooo`0300000?oooooo
oooo01Oooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?l0003ooooo
01cooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo
033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0eooooo`7o00000@000001oooo
o`005Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01Oooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo01gooooo00<00000ooooooooool0
5_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Fooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0<?oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Nooooo`0300000?oooooooooo01Gooooo00<0001oooooooooool0;oooool0
0`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool1
0000007ooooo000Eooooo`0300000?l0003ooooo01kooooo00<00000ooooooooool05Oooool00`00
07ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`00
07ooooooooooo`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Oooooo`03
00000?oooooooooo01Cooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`030000
0?oooooooooo01oooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`400000
0Oooool000;ooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool08?oo
ool3ool001?ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooo
oooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo0003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00<00000ooooooooool07oooool5ool001;ooooo00<0001oooooooooool0;oooool00`0007oooooo
ooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo
0005o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?l00000001o01l0001o1Ooo003Q0000O`7o00000@000001ooooo`0000Co0000oooooooooooo
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool07oooool5ool001;ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo00001?oo
oooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0Pooooo`?oo`004oooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`400000
0Oooool000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo013ooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=_ooool10000007ooooo0003ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
1Oooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo00oooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
=_ooool10000007ooooo000Eooooo`0300000?l0003ooooo02Gooooo00<00000ooooooooool03_oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;ooo
ool00`0007ooooooooooo`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0U
ooooo`0300000?oooooooooo00kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`
ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo02Kooooo00<00000ooooooooool03Oooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0foooo
o`4000000Oooool001Gooooo00<00000ooooooooool09oooool00`00003oooooooooo`0<ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`03
0000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Xooooo`030000
0?oooooooooo00_ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000
Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?l0
003ooooo02Sooooo00<00000ooooooooool02oooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0eooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo00[ooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001o
ooooooooool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001ooooo
ooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0:_ooool3ool000Wooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0`ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`030000
0?oooooooooo02Wooooo1Ooo0008ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0
<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`005Ooo
ool00`00003o0000ooooo`0Yooooo`Goo`0000<00000ooooooooool01Oooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007oooooooooo
o`0eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Yooooo`Goo`0000?ooooo
00000?ooool01Oooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001o
ooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0:_ooool3ool000?ooooo00<00000ooooooooool00oooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0foooo
o`4000000Oooool001Gooooo00<00000ooooooooool0<Oooool2000000?ooooo00<0001ooooooooo
ool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo03?ooooo00@00000ooooooooool0
001o<Oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=_ooool10000007ooooo000Eooooo`0300000?l0003ooooo03Cooooo00@00000ool00?oo003o
o`00<?ooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0=?ooool5ool002oooooo
00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo03Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0dooooo`Goo`00;oooool00`0007oooooooooo
o`0`ooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo0000
1?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0=?oo
ool5ool000<000000oooool3ool002Kooooo00<0001oooooooooool0<?ooool00`0007oooooooooo
o`0_ooooo`030000Oooooooooooo03Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0eooooo`?oo`001?ooool2000000Goo`009Oooool00`0007ooooooooooo`0`ooooo`03
0000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo0004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`0300000?l00000001o03h0001o1Ooo00000`000000001o0000O`030000O`?oo`00^@0007l1o`00
004000000Oooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0=_ooool00`0007ooooooooooo`05
ooooo`Goo`0000?ooooo0000000000000P000005ool000Kooooo0ooo000Booooo`030000Oooooooo
oooo033ooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Oooool0
00Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0=_ooool00`0007ooooooooooo`06ooooo`?oo`001_ooool5ool000<000000_oo
ool5ool000Kooooo0ooo0008ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool0;ooo
ool00`0007ooooooooooo`0fooooo`4000000Oooool00003o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03Kooooo
00<0001oooooooooool03oooool5ool000?ooooo0P000005ool000<000000_ooool5ool000Kooooo
0ooo000aooooo`030000Oooooooooooo02oooooo00<0001oooooooooool0=_ooool10000007ooooo
0005o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0fooooo`030000Oooo
oooooooo013ooooo0ooo0006ooooo`Goo`000oooool2000000Goo`000`000002ooooo`Goo`001_oo
ool3ool002Oooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`4000000Ooo
ool001Gooooo00<00000o`000?ooool0=_ooool00`0007ooooooooooo`0Jooooo`?oo`001_ooool5
ool000?ooooo0P000005ool000<000000_ooool5ool000Kooooo0ooo000Mooooo`030000Oooooooo
oooo02oooooo00<0001oooooooooool0=Oooool1o`00004000000Oooool001Gooooo00<00000oooo
ooooool0=_ooool00`0007ooooooooooo`0Tooooo`?oo`001_ooool5ool000?ooooo0P000005ool0
00@0000000?oooooool00?oo00000ooo0007ooooo`?oo`004_ooool00`0007ooooooooooo`0_oooo
o`030000Oooooooooooo03Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0fooooo`03
0000Oooooooooooo02kooooo0ooo0006ooooo`Goo`001?ooool00`00003oo`00ool00003ool000@0
00000_ooool5ool000Kooooo0ooo0008ooooo`030000Oooooooooooo02oooooo00<0001ooooooooo
ool0=_ooool10000007ooooo000Eooooo`0300000?oooooooooo03Kooooo00<0001oooooooooool0
;oooool00`0007ooooooooooo`06ooooo`?oo`001_ooool5ool000Cooooo0P000005ool000<00000
0_ooool5ool000Oooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0fooooo`400000
0Oooool001Gooooo00<00000ooooooooool0=_ooool00`0007ooooooooooo`0_ooooo`030000Oooo
oooooooo013ooooo0ooo0007ooooo`Goo`000oooool2000000Goo`0000<00000ooooooooool00ooo
ool3ool0033ooooo00<0001oooooooooool0=_ooool10000007ooooo000Eooooo`0300000?l0003o
oooo03Kooooo00<0001oooooooooool0;oooool00`0007ooooooooooo`0Kooooo`?oo`001_ooool5
ool00003ooooo`0000000000008000001Ooo0006ooooo`?oo`009_ooool00`0007ooooooooooo`0e
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0fooooo`030000Oooooooooooo
02oooooo00<0001oooooooooool09Oooool3ool000Kooooo1Ooo0003000000;ooooo1Ooo0006oooo
o`?oo`007?ooool00`0007ooooooooooo`0fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0=_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo02kooooo1Ooo0003ooooo`80
00001Ooo0003000000;ooooo1Ooo0006ooooo`?oo`004_ooool00`0007ooooooooooo`0fooooo`40
00000Oooool001Gooooo00<00000ooooooooool0=_ooool00`0007ooooooooooo`0_ooooo`030000
Oooooooooooo02oooooo0ooo0006ooooo`Goo`000oooool2000000Goo`000`000002ooooo`Goo`00
1_ooool3ool000Oooooo0ooo000gooooo`4000000Oooool001Gooooo00<00000ooooooooool0=_oo
ool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool01_oo
ool3ool000Kooooo1Ooo0003ooooo`8000001Ooo0005000000Goo`000`000002ooooo`Goo`001_oo
ool3ool000Sooooo0ooo0007ooooo`?oo`001oooool3ool000Oooooo0ooo0004ooooo`4000000Ooo
ool001Gooooo00<00000o`000?ooool0=_ooool00`0007ooooooooooo`0_ooooo`030000Oooooooo
oooo033ooooo00<0001oooooooooool04?ooool3ool000Kooooo1Ooo0005ooooo`Goo`000oooool2
000000Goo`001@000005ool000@000000_ooool5ool000Gooooo1Ooo0005ooooo`Goo`001Oooool5
ool000;ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo03Kooooo00<0001ooooo
ooooool0;oooool00`0007ooooooooooo`0`ooooo`030000Oooooooooooo01[ooooo0ooo0006oooo
o`Goo`001Oooool5ool000Gooooo1Ooo0004ooooo`8000001Ooo0005000000Goo`001@000005ool0
00D000001Ooo0003ooooo`4000000Oooool001Gooooo00<00000ooooooooool0=_ooool00`0007oo
ooooooooo`0_ooooo`030000Oooooooooooo033ooooo00<0001oooooooooool09?ooool3ool000Oo
oooo0ooo0006ooooo`Goo`001_ooool5ool000Gooooo1Ooo0005ooooo`Goo`001Oooool5ool000?o
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0fooooo`030000Oooooooooooo02oooooo
00<0001oooooooooool0<?ooool00`0007ooooooooooo`0_ooooo`030000Oooooooooooo00Kooooo
0ooo0008ooooo`?oo`001oooool3ool000Oooooo0ooo0007ooooo`?oo`001?ooool10000007ooooo
000Eooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`4000000Oooool001Goooooo`00000;0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.73257, -127.927, \
0.0988505, 4.00653}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(scalar2\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #4: blue class, full covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes full covariance matrices", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 3;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[data2, k];\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data2, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.2300000000000182`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AntiPolygonalAllPlot[poly, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.2 g
.01923 .30013 m
.02828 .28846 L
.03846 .27607 L
.04436 .26923 L
.05769 .2546 L
.06209 .25 L
.07692 .23531 L
.08177 .23077 L
.09615 .21795 L
.10379 .21154 L
.11538 .2023 L
.12878 .19231 L
.13462 .18818 L
.15385 .17547 L
.1577 .17308 L
.17308 .16405 L
.19226 .15385 L
.19231 .15382 L
.21154 .14472 L
.23077 .13667 L
.23609 .13462 L
.25 .12961 L
.26923 .12348 L
.28846 .11825 L
.30058 .11538 L
.30769 .11387 L
.32692 .1103 L
.34615 .10752 L
.36538 .1055 L
.38462 .10421 L
.40385 .10362 L
.42308 .10373 L
.44231 .10452 L
.46154 .10598 L
.48077 .10809 L
.5 .11085 L
.51923 .11426 L
.52492 .11538 L
.53846 .11832 L
.55769 .12303 L
.57692 .1284 L
.59615 .13444 L
.5967 .13462 L
.61538 .14116 L
.63462 .1486 L
.64719 .15385 L
.65385 .15676 L
.67308 .16568 L
.68785 .17308 L
.69231 .17541 L
.71154 .18598 L
.72233 .19231 L
.73077 .19746 L
.75 .20991 L
.75241 .21154 L
.76923 .22342 L
.77908 .23077 L
.78846 .23808 L
.80298 .25 L
.80769 .25404 L
.82456 .26923 L
.82692 .27146 L
.84414 .28846 L
.84615 .29054 L
.86196 .30769 L
.86538 .3116 L
.87821 .32692 L
.88462 .33502 L
.89303 .34615 L
.90385 .3614 L
.90655 .36538 L
.91885 .38462 L
.92308 .39167 L
.93002 .40385 L
.94013 .42308 L
.94231 .42749 L
.94923 .44231 L
.95737 .46154 L
.96154 .47233 L
.96459 .48077 L
.97093 .5 L
.9764 .51923 L
.98077 .53728 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .30013 m
.02828 .28846 L
.03846 .27607 L
.04436 .26923 L
.05769 .2546 L
.06209 .25 L
.07692 .23531 L
.08177 .23077 L
.09615 .21795 L
.10379 .21154 L
.11538 .2023 L
.12878 .19231 L
.13462 .18818 L
.15385 .17547 L
.1577 .17308 L
.17308 .16405 L
.19226 .15385 L
.19231 .15382 L
.21154 .14472 L
.23077 .13667 L
.23609 .13462 L
.25 .12961 L
.26923 .12348 L
.28846 .11825 L
.30058 .11538 L
.30769 .11387 L
.32692 .1103 L
.34615 .10752 L
.36538 .1055 L
.38462 .10421 L
.40385 .10362 L
.42308 .10373 L
.44231 .10452 L
.46154 .10598 L
.48077 .10809 L
.5 .11085 L
.51923 .11426 L
.52492 .11538 L
.53846 .11832 L
.55769 .12303 L
.57692 .1284 L
.59615 .13444 L
.5967 .13462 L
.61538 .14116 L
.63462 .1486 L
.64719 .15385 L
.65385 .15676 L
.67308 .16568 L
.68785 .17308 L
.69231 .17541 L
Mistroke
.71154 .18598 L
.72233 .19231 L
.73077 .19746 L
.75 .20991 L
.75241 .21154 L
.76923 .22342 L
.77908 .23077 L
.78846 .23808 L
.80298 .25 L
.80769 .25404 L
.82456 .26923 L
.82692 .27146 L
.84414 .28846 L
.84615 .29054 L
.86196 .30769 L
.86538 .3116 L
.87821 .32692 L
.88462 .33502 L
.89303 .34615 L
.90385 .3614 L
.90655 .36538 L
.91885 .38462 L
.92308 .39167 L
.93002 .40385 L
.94013 .42308 L
.94231 .42749 L
.94923 .44231 L
.95737 .46154 L
.96154 .47233 L
.96459 .48077 L
.97093 .5 L
.9764 .51923 L
.98077 .53728 L
Mfstroke
.3 g
.01923 .47608 m
.02617 .46154 L
.03633 .44231 L
.03846 .43852 L
.04766 .42308 L
.05769 .40761 L
.06026 .40385 L
.07429 .38462 L
.07692 .38122 L
.08989 .36538 L
.09615 .35822 L
.1073 .34615 L
.11538 .33792 L
.12683 .32692 L
.13462 .31986 L
.1489 .30769 L
.15385 .30371 L
.17308 .28923 L
.17417 .28846 L
.19231 .27625 L
.20365 .26923 L
.21154 .26461 L
.23077 .25421 L
.23922 .25 L
.25 .24495 L
.26923 .23674 L
.28498 .23077 L
.28846 .22954 L
.30769 .22328 L
.32692 .21792 L
.34615 .21342 L
.35541 .21154 L
.36538 .20975 L
.38462 .20688 L
.40385 .2048 L
.42308 .20349 L
.44231 .20292 L
.46154 .2031 L
.48077 .20402 L
.5 .20568 L
.51923 .20807 L
.53846 .21122 L
.54019 .21154 L
.55769 .21513 L
.57692 .21982 L
.59615 .2253 L
.61298 .23077 L
.61538 .23161 L
.63462 .23878 L
.65385 .24686 L
.66078 .25 L
.67308 .2559 L
.69231 .26596 L
.69814 .26923 L
.71154 .27714 L
.7292 .28846 L
.73077 .28952 L
.75 .30325 L
.75583 .30769 L
.76923 .31848 L
.77907 .32692 L
.78846 .33545 L
.79958 .34615 L
.80769 .35444 L
.81781 .36538 L
.82692 .37589 L
.83407 .38462 L
.84615 .40045 L
.84861 .40385 L
.86159 .42308 L
.86538 .42914 L
.87316 .44231 L
.88343 .46154 L
.88462 .46393 L
.89248 .48077 L
.90039 .5 L
.90385 .50933 L
.90723 .51923 L
.91302 .53846 L
.91782 .55769 L
.92165 .57692 L
.92308 .58546 L
.92453 .59615 L
.92648 .61538 L
.92752 .63462 L
.92764 .65385 L
.92685 .67308 L
.92515 .69231 L
.92308 .70815 L
.92251 .71154 L
.91894 .73077 L
.9144 .75 L
.90886 .76923 L
.90385 .78422 L
.9023 .78846 L
.89467 .80769 L
.88592 .82692 L
.88462 .82958 L
.87597 .84615 L
.86538 .86435 L
.86475 .86538 L
.85215 .88462 L
.84615 .89307 L
.83807 .90385 L
.82692 .91768 L
.82233 .92308 L
.80769 .93923 L
.80474 .94231 L
.78846 .95835 L
.78504 .96154 L
.76923 .97548 L
.76286 .98077 L
.01923 .98077 L
F
0 g
.01923 .47608 m
.02617 .46154 L
.03633 .44231 L
.03846 .43852 L
.04766 .42308 L
.05769 .40761 L
.06026 .40385 L
.07429 .38462 L
.07692 .38122 L
.08989 .36538 L
.09615 .35822 L
.1073 .34615 L
.11538 .33792 L
.12683 .32692 L
.13462 .31986 L
.1489 .30769 L
.15385 .30371 L
.17308 .28923 L
.17417 .28846 L
.19231 .27625 L
.20365 .26923 L
.21154 .26461 L
.23077 .25421 L
.23922 .25 L
.25 .24495 L
.26923 .23674 L
.28498 .23077 L
.28846 .22954 L
.30769 .22328 L
.32692 .21792 L
.34615 .21342 L
.35541 .21154 L
.36538 .20975 L
.38462 .20688 L
.40385 .2048 L
.42308 .20349 L
.44231 .20292 L
.46154 .2031 L
.48077 .20402 L
.5 .20568 L
.51923 .20807 L
.53846 .21122 L
.54019 .21154 L
.55769 .21513 L
.57692 .21982 L
.59615 .2253 L
.61298 .23077 L
.61538 .23161 L
.63462 .23878 L
.65385 .24686 L
Mistroke
.66078 .25 L
.67308 .2559 L
.69231 .26596 L
.69814 .26923 L
.71154 .27714 L
.7292 .28846 L
.73077 .28952 L
.75 .30325 L
.75583 .30769 L
.76923 .31848 L
.77907 .32692 L
.78846 .33545 L
.79958 .34615 L
.80769 .35444 L
.81781 .36538 L
.82692 .37589 L
.83407 .38462 L
.84615 .40045 L
.84861 .40385 L
.86159 .42308 L
.86538 .42914 L
.87316 .44231 L
.88343 .46154 L
.88462 .46393 L
.89248 .48077 L
.90039 .5 L
.90385 .50933 L
.90723 .51923 L
.91302 .53846 L
.91782 .55769 L
.92165 .57692 L
.92308 .58546 L
.92453 .59615 L
.92648 .61538 L
.92752 .63462 L
.92764 .65385 L
.92685 .67308 L
.92515 .69231 L
.92308 .70815 L
.92251 .71154 L
.91894 .73077 L
.9144 .75 L
.90886 .76923 L
.90385 .78422 L
.9023 .78846 L
.89467 .80769 L
.88592 .82692 L
.88462 .82958 L
.87597 .84615 L
.86538 .86435 L
Mistroke
.86475 .86538 L
.85215 .88462 L
.84615 .89307 L
.83807 .90385 L
.82692 .91768 L
.82233 .92308 L
.80769 .93923 L
.80474 .94231 L
.78846 .95835 L
.78504 .96154 L
.76923 .97548 L
.76286 .98077 L
Mfstroke
.2 g
.01923 .85523 m
.02427 .86538 L
.03478 .88462 L
.03846 .89084 L
.04665 .90385 L
.05769 .91987 L
.06004 .92308 L
.07513 .94231 L
.07692 .94444 L
.09219 .96154 L
.09615 .96569 L
.11154 .98077 L
.01923 .98077 L
F
0 g
.01923 .85523 m
.02427 .86538 L
.03478 .88462 L
.03846 .89084 L
.04665 .90385 L
.05769 .91987 L
.06004 .92308 L
.07513 .94231 L
.07692 .94444 L
.09219 .96154 L
.09615 .96569 L
.11154 .98077 L
s
.1 g
.01923 .97689 m
.02248 .98077 L
.01923 .98077 L
F
0 g
.01923 .97689 m
.02248 .98077 L
s
.4 g
.67862 .98077 m
.69231 .97205 L
.70748 .96154 L
.71154 .95857 L
.73077 .9435 L
.7322 .94231 L
.75 .92656 L
.75369 .92308 L
.76923 .9074 L
.77254 .90385 L
.78846 .88546 L
.78915 .88462 L
.80381 .86538 L
.80769 .85987 L
.81674 .84615 L
.82692 .82904 L
.8281 .82692 L
.83802 .80769 L
.84615 .78953 L
.84659 .78846 L
.85391 .76923 L
.86003 .75 L
.865 .73077 L
.86538 .72913 L
.86886 .71154 L
.87165 .69231 L
.87337 .67308 L
.87404 .65385 L
.87366 .63462 L
.87223 .61538 L
.86974 .59615 L
.86616 .57692 L
.86538 .57336 L
.86147 .55769 L
.85562 .53846 L
.84856 .51923 L
.84615 .51335 L
.84022 .5 L
.83052 .48077 L
.82692 .47428 L
.81934 .46154 L
.80769 .44395 L
.80653 .44231 L
.7919 .42308 L
.78846 .4189 L
.7752 .40385 L
.76923 .39755 L
.75608 .38462 L
.75 .37903 L
.73402 .36538 L
.73077 .36278 L
.71154 .34845 L
.70823 .34615 L
.69231 .33576 L
.67738 .32692 L
.67308 .32453 L
.65385 .3146 L
.63886 .30769 L
.63462 .30586 L
.61538 .29823 L
.59615 .29163 L
.58576 .28846 L
.57692 .286 L
.55769 .28131 L
.53846 .27751 L
.51923 .27457 L
.5 .27249 L
.48077 .27124 L
.46154 .27083 L
.44231 .27123 L
.42308 .27247 L
.40385 .27454 L
.38462 .27747 L
.36538 .28127 L
.34615 .28597 L
.33724 .28846 L
.32692 .29161 L
.30769 .29823 L
.28846 .30588 L
.28425 .30769 L
.26923 .31463 L
.25 .32456 L
.24575 .32692 L
.23077 .33578 L
.21482 .34615 L
.21154 .34842 L
.19231 .36264 L
.18885 .36538 L
.17308 .37868 L
.16652 .38462 L
.15385 .39683 L
.14704 .40385 L
.13462 .41754 L
.1299 .42308 L
.11538 .44146 L
.11475 .44231 L
.10135 .46154 L
.09615 .46967 L
.08949 .48077 L
.07904 .5 L
.07692 .50421 L
.06988 .51923 L
.06194 .53846 L
.05769 .55007 L
.05513 .55769 L
.04941 .57692 L
.04474 .59615 L
.04108 .61538 L
.03846 .63418 L
.03841 .63462 L
.03673 .65385 L
.03602 .67308 L
.03629 .69231 L
.03754 .71154 L
.03846 .72125 L
.03979 .73077 L
.04307 .75 L
.04741 .76923 L
.05286 .78846 L
.05769 .80285 L
.05948 .80769 L
.06733 .82692 L
.07652 .84615 L
.07692 .84694 L
.08716 .86538 L
.09615 .87975 L
.09942 .88462 L
.11349 .90385 L
.11538 .90625 L
.12965 .92308 L
.13462 .92847 L
.14831 .94231 L
.15385 .94751 L
.17002 .96154 L
.17308 .96401 L
.19231 .97843 L
.19569 .98077 L
F
0 g
.67862 .98077 m
.69231 .97205 L
.70748 .96154 L
.71154 .95857 L
.73077 .9435 L
.7322 .94231 L
.75 .92656 L
.75369 .92308 L
.76923 .9074 L
.77254 .90385 L
.78846 .88546 L
.78915 .88462 L
.80381 .86538 L
.80769 .85987 L
.81674 .84615 L
.82692 .82904 L
.8281 .82692 L
.83802 .80769 L
.84615 .78953 L
.84659 .78846 L
.85391 .76923 L
.86003 .75 L
.865 .73077 L
.86538 .72913 L
.86886 .71154 L
.87165 .69231 L
.87337 .67308 L
.87404 .65385 L
.87366 .63462 L
.87223 .61538 L
.86974 .59615 L
.86616 .57692 L
.86538 .57336 L
.86147 .55769 L
.85562 .53846 L
.84856 .51923 L
.84615 .51335 L
.84022 .5 L
.83052 .48077 L
.82692 .47428 L
.81934 .46154 L
.80769 .44395 L
.80653 .44231 L
.7919 .42308 L
.78846 .4189 L
.7752 .40385 L
.76923 .39755 L
.75608 .38462 L
.75 .37903 L
.73402 .36538 L
Mistroke
.73077 .36278 L
.71154 .34845 L
.70823 .34615 L
.69231 .33576 L
.67738 .32692 L
.67308 .32453 L
.65385 .3146 L
.63886 .30769 L
.63462 .30586 L
.61538 .29823 L
.59615 .29163 L
.58576 .28846 L
.57692 .286 L
.55769 .28131 L
.53846 .27751 L
.51923 .27457 L
.5 .27249 L
.48077 .27124 L
.46154 .27083 L
.44231 .27123 L
.42308 .27247 L
.40385 .27454 L
.38462 .27747 L
.36538 .28127 L
.34615 .28597 L
.33724 .28846 L
.32692 .29161 L
.30769 .29823 L
.28846 .30588 L
.28425 .30769 L
.26923 .31463 L
.25 .32456 L
.24575 .32692 L
.23077 .33578 L
.21482 .34615 L
.21154 .34842 L
.19231 .36264 L
.18885 .36538 L
.17308 .37868 L
.16652 .38462 L
.15385 .39683 L
.14704 .40385 L
.13462 .41754 L
.1299 .42308 L
.11538 .44146 L
.11475 .44231 L
.10135 .46154 L
.09615 .46967 L
.08949 .48077 L
.07904 .5 L
Mistroke
.07692 .50421 L
.06988 .51923 L
.06194 .53846 L
.05769 .55007 L
.05513 .55769 L
.04941 .57692 L
.04474 .59615 L
.04108 .61538 L
.03846 .63418 L
.03841 .63462 L
.03673 .65385 L
.03602 .67308 L
.03629 .69231 L
.03754 .71154 L
.03846 .72125 L
.03979 .73077 L
.04307 .75 L
.04741 .76923 L
.05286 .78846 L
.05769 .80285 L
.05948 .80769 L
.06733 .82692 L
.07652 .84615 L
.07692 .84694 L
.08716 .86538 L
.09615 .87975 L
.09942 .88462 L
.11349 .90385 L
.11538 .90625 L
.12965 .92308 L
.13462 .92847 L
.14831 .94231 L
.15385 .94751 L
.17002 .96154 L
.17308 .96401 L
.19231 .97843 L
.19569 .98077 L
Mfstroke
.5 g
.58037 .98077 m
.59615 .97454 L
.61538 .96594 L
.62432 .96154 L
.63462 .95613 L
.65385 .94499 L
.65815 .94231 L
.67308 .93239 L
.68588 .92308 L
.69231 .9181 L
.70929 .90385 L
.71154 .90183 L
.72939 .88462 L
.73077 .88319 L
.74678 .86538 L
.75 .86151 L
.76189 .84615 L
.76923 .83573 L
.775 .82692 L
.78632 .80769 L
.78846 .80372 L
.79603 .78846 L
.80424 .76923 L
.80769 .76 L
.81105 .75 L
.81652 .73077 L
.82072 .71154 L
.82368 .69231 L
.82543 .67308 L
.82597 .65385 L
.82532 .63462 L
.82345 .61538 L
.82035 .59615 L
.81597 .57692 L
.81028 .55769 L
.80769 .55018 L
.80319 .53846 L
.79461 .51923 L
.78846 .50724 L
.78442 .5 L
.77244 .48077 L
.76923 .47608 L
.75846 .46154 L
.75 .45119 L
.74215 .44231 L
.73077 .43047 L
.72307 .42308 L
.71154 .41283 L
.70051 .40385 L
.69231 .39763 L
.67332 .38462 L
.67308 .38446 L
.65385 .37302 L
.63929 .36538 L
.63462 .36311 L
.61538 .35457 L
.59615 .34728 L
.59289 .34615 L
.57692 .34115 L
.55769 .33611 L
.53846 .33211 L
.51923 .32911 L
.5 .32707 L
.49816 .32692 L
.48077 .32597 L
.46154 .32581 L
.44231 .32657 L
.43619 .32692 L
.42308 .32827 L
.40385 .3309 L
.38462 .3345 L
.36538 .33909 L
.34615 .3447 L
.34169 .34615 L
.32692 .3514 L
.30769 .35924 L
.29436 .36538 L
.28846 .36831 L
.26923 .37872 L
.25937 .38462 L
.25 .3906 L
.23118 .40385 L
.23077 .40416 L
.21154 .41963 L
.20759 .42308 L
.19231 .43738 L
.18742 .44231 L
.17308 .45793 L
.17 .46154 L
.15485 .48077 L
.15385 .48214 L
.14167 .5 L
.13462 .51151 L
.13022 .51923 L
.12035 .53846 L
.11538 .54937 L
.11191 .55769 L
.10482 .57692 L
.099 .59615 L
.09615 .60737 L
.0944 .61538 L
.09098 .63462 L
.08871 .65385 L
.08758 .67308 L
.08759 .69231 L
.08874 .71154 L
.09106 .73077 L
.09459 .75 L
.09615 .75701 L
.09936 .76923 L
.10545 .78846 L
.11294 .80769 L
.11538 .81327 L
.12195 .82692 L
.13264 .84615 L
.13462 .84939 L
.1452 .86538 L
.15385 .87704 L
.15993 .88462 L
.17308 .89952 L
.17722 .90385 L
.19231 .91834 L
.19769 .92308 L
.21154 .93436 L
.2223 .94231 L
.23077 .94811 L
.25 .95994 L
.25284 .96154 L
.26923 .9701 L
.28846 .97879 L
.29329 .98077 L
F
0 g
.58037 .98077 m
.59615 .97454 L
.61538 .96594 L
.62432 .96154 L
.63462 .95613 L
.65385 .94499 L
.65815 .94231 L
.67308 .93239 L
.68588 .92308 L
.69231 .9181 L
.70929 .90385 L
.71154 .90183 L
.72939 .88462 L
.73077 .88319 L
.74678 .86538 L
.75 .86151 L
.76189 .84615 L
.76923 .83573 L
.775 .82692 L
.78632 .80769 L
.78846 .80372 L
.79603 .78846 L
.80424 .76923 L
.80769 .76 L
.81105 .75 L
.81652 .73077 L
.82072 .71154 L
.82368 .69231 L
.82543 .67308 L
.82597 .65385 L
.82532 .63462 L
.82345 .61538 L
.82035 .59615 L
.81597 .57692 L
.81028 .55769 L
.80769 .55018 L
.80319 .53846 L
.79461 .51923 L
.78846 .50724 L
.78442 .5 L
.77244 .48077 L
.76923 .47608 L
.75846 .46154 L
.75 .45119 L
.74215 .44231 L
.73077 .43047 L
.72307 .42308 L
.71154 .41283 L
.70051 .40385 L
.69231 .39763 L
Mistroke
.67332 .38462 L
.67308 .38446 L
.65385 .37302 L
.63929 .36538 L
.63462 .36311 L
.61538 .35457 L
.59615 .34728 L
.59289 .34615 L
.57692 .34115 L
.55769 .33611 L
.53846 .33211 L
.51923 .32911 L
.5 .32707 L
.49816 .32692 L
.48077 .32597 L
.46154 .32581 L
.44231 .32657 L
.43619 .32692 L
.42308 .32827 L
.40385 .3309 L
.38462 .3345 L
.36538 .33909 L
.34615 .3447 L
.34169 .34615 L
.32692 .3514 L
.30769 .35924 L
.29436 .36538 L
.28846 .36831 L
.26923 .37872 L
.25937 .38462 L
.25 .3906 L
.23118 .40385 L
.23077 .40416 L
.21154 .41963 L
.20759 .42308 L
.19231 .43738 L
.18742 .44231 L
.17308 .45793 L
.17 .46154 L
.15485 .48077 L
.15385 .48214 L
.14167 .5 L
.13462 .51151 L
.13022 .51923 L
.12035 .53846 L
.11538 .54937 L
.11191 .55769 L
.10482 .57692 L
.099 .59615 L
.09615 .60737 L
Mistroke
.0944 .61538 L
.09098 .63462 L
.08871 .65385 L
.08758 .67308 L
.08759 .69231 L
.08874 .71154 L
.09106 .73077 L
.09459 .75 L
.09615 .75701 L
.09936 .76923 L
.10545 .78846 L
.11294 .80769 L
.11538 .81327 L
.12195 .82692 L
.13264 .84615 L
.13462 .84939 L
.1452 .86538 L
.15385 .87704 L
.15993 .88462 L
.17308 .89952 L
.17722 .90385 L
.19231 .91834 L
.19769 .92308 L
.21154 .93436 L
.2223 .94231 L
.23077 .94811 L
.25 .95994 L
.25284 .96154 L
.26923 .9701 L
.28846 .97879 L
.29329 .98077 L
Mfstroke
.6 g
.40385 .38073 m
.42308 .37757 L
.44231 .37549 L
.46154 .37447 L
.48077 .3745 L
.5 .37559 L
.51923 .37775 L
.53846 .38103 L
.55442 .38462 L
.55769 .38547 L
.57692 .39113 L
.59615 .3981 L
.60969 .40385 L
.61538 .4065 L
.63462 .41648 L
.64579 .42308 L
.65385 .42825 L
.67308 .44213 L
.6733 .44231 L
.69231 .45856 L
.69546 .46154 L
.71154 .47826 L
.71374 .48077 L
.72899 .5 L
.73077 .50248 L
.74174 .51923 L
.75 .53388 L
.75234 .53846 L
.76103 .55769 L
.768 .57692 L
.76923 .58081 L
.77336 .59615 L
.77721 .61538 L
.7796 .63462 L
.7806 .65385 L
.7802 .67308 L
.77842 .69231 L
.77524 .71154 L
.77063 .73077 L
.76923 .73569 L
.76453 .75 L
.75687 .76923 L
.75 .78372 L
.74753 .78846 L
.73636 .80769 L
.73077 .81624 L
.72318 .82692 L
.71154 .84165 L
.70768 .84615 L
.69231 .86259 L
.68948 .86538 L
.67308 .88033 L
.66795 .88462 L
.65385 .89557 L
.6421 .90385 L
.63462 .90875 L
.61538 .92019 L
.61008 .92308 L
.59615 .9301 L
.57692 .93863 L
.56759 .94231 L
.55769 .94588 L
.53846 .95196 L
.51923 .95691 L
.5 .96079 L
.49582 .96154 L
.48077 .96362 L
.46154 .96541 L
.44231 .96617 L
.42308 .96589 L
.40385 .96455 L
.38462 .96213 L
.38085 .96154 L
.36538 .95856 L
.34615 .9538 L
.32692 .94776 L
.31245 .94231 L
.30769 .94032 L
.28846 .93135 L
.27332 .92308 L
.26923 .92064 L
.25 .90791 L
.24449 .90385 L
.23077 .89278 L
.22166 .88462 L
.21154 .87464 L
.20302 .86538 L
.19231 .85245 L
.18756 .84615 L
.1747 .82692 L
.17308 .82423 L
.16404 .80769 L
.1553 .78846 L
.15385 .78487 L
.14829 .76923 L
.14287 .75 L
.13893 .73077 L
.13641 .71154 L
.13526 .69231 L
.13544 .67308 L
.13696 .65385 L
.1398 .63462 L
.14401 .61538 L
.14962 .59615 L
.15385 .58416 L
.1567 .57692 L
.16535 .55769 L
.17308 .54302 L
.1757 .53846 L
.18792 .51923 L
.19231 .51301 L
.20226 .5 L
.21154 .48902 L
.21909 .48077 L
.23077 .46905 L
.23892 .46154 L
.25 .4521 L
.26261 .44231 L
.26923 .43754 L
.28846 .42499 L
.29165 .42308 L
.30769 .41417 L
.32692 .40488 L
.32927 .40385 L
.34615 .39699 L
.36538 .39039 L
.38462 .38499 L
.38608 .38462 L
F
0 g
.40385 .38073 m
.42308 .37757 L
.44231 .37549 L
.46154 .37447 L
.48077 .3745 L
.5 .37559 L
.51923 .37775 L
.53846 .38103 L
.55442 .38462 L
.55769 .38547 L
.57692 .39113 L
.59615 .3981 L
.60969 .40385 L
.61538 .4065 L
.63462 .41648 L
.64579 .42308 L
.65385 .42825 L
.67308 .44213 L
.6733 .44231 L
.69231 .45856 L
.69546 .46154 L
.71154 .47826 L
.71374 .48077 L
.72899 .5 L
.73077 .50248 L
.74174 .51923 L
.75 .53388 L
.75234 .53846 L
.76103 .55769 L
.768 .57692 L
.76923 .58081 L
.77336 .59615 L
.77721 .61538 L
.7796 .63462 L
.7806 .65385 L
.7802 .67308 L
.77842 .69231 L
.77524 .71154 L
.77063 .73077 L
.76923 .73569 L
.76453 .75 L
.75687 .76923 L
.75 .78372 L
.74753 .78846 L
.73636 .80769 L
.73077 .81624 L
.72318 .82692 L
.71154 .84165 L
.70768 .84615 L
.69231 .86259 L
Mistroke
.68948 .86538 L
.67308 .88033 L
.66795 .88462 L
.65385 .89557 L
.6421 .90385 L
.63462 .90875 L
.61538 .92019 L
.61008 .92308 L
.59615 .9301 L
.57692 .93863 L
.56759 .94231 L
.55769 .94588 L
.53846 .95196 L
.51923 .95691 L
.5 .96079 L
.49582 .96154 L
.48077 .96362 L
.46154 .96541 L
.44231 .96617 L
.42308 .96589 L
.40385 .96455 L
.38462 .96213 L
.38085 .96154 L
.36538 .95856 L
.34615 .9538 L
.32692 .94776 L
.31245 .94231 L
.30769 .94032 L
.28846 .93135 L
.27332 .92308 L
.26923 .92064 L
.25 .90791 L
.24449 .90385 L
.23077 .89278 L
.22166 .88462 L
.21154 .87464 L
.20302 .86538 L
.19231 .85245 L
.18756 .84615 L
.1747 .82692 L
.17308 .82423 L
.16404 .80769 L
.1553 .78846 L
.15385 .78487 L
.14829 .76923 L
.14287 .75 L
.13893 .73077 L
.13641 .71154 L
.13526 .69231 L
.13544 .67308 L
Mistroke
.13696 .65385 L
.1398 .63462 L
.14401 .61538 L
.14962 .59615 L
.15385 .58416 L
.1567 .57692 L
.16535 .55769 L
.17308 .54302 L
.1757 .53846 L
.18792 .51923 L
.19231 .51301 L
.20226 .5 L
.21154 .48902 L
.21909 .48077 L
.23077 .46905 L
.23892 .46154 L
.25 .4521 L
.26261 .44231 L
.26923 .43754 L
.28846 .42499 L
.29165 .42308 L
.30769 .41417 L
.32692 .40488 L
.32927 .40385 L
.34615 .39699 L
.36538 .39039 L
.38462 .38499 L
.38608 .38462 L
.40385 .38073 L
Mfstroke
.7 g
.44231 .42156 m
.46154 .42031 L
.48077 .42028 L
.5 .42149 L
.51454 .42308 L
.51923 .42395 L
.53846 .42772 L
.55769 .43289 L
.57692 .43955 L
.58379 .44231 L
.59615 .44786 L
.61538 .45804 L
.62123 .46154 L
.63462 .47039 L
.6483 .48077 L
.65385 .48541 L
.66938 .5 L
.67308 .50386 L
.68628 .51923 L
.69231 .5272 L
.69995 .53846 L
.71097 .55769 L
.71154 .55879 L
.71971 .57692 L
.72642 .59615 L
.73077 .61291 L
.73127 .61538 L
.73437 .63462 L
.7358 .65385 L
.7356 .67308 L
.73377 .69231 L
.73077 .7098 L
.7303 .71154 L
.72515 .73077 L
.71822 .75 L
.71154 .76498 L
.7094 .76923 L
.6985 .78846 L
.69231 .79793 L
.68527 .80769 L
.67308 .8227 L
.66931 .82692 L
.65385 .84264 L
.65005 .84615 L
.63462 .85921 L
.6265 .86538 L
.61538 .87316 L
.59681 .88462 L
.59615 .88499 L
.57692 .89499 L
.55769 .90339 L
.55655 .90385 L
.53846 .91033 L
.51923 .91592 L
.5 .92023 L
.48265 .92308 L
.48077 .92331 L
.46154 .92517 L
.44231 .92584 L
.42308 .9253 L
.40385 .92352 L
.40021 .92308 L
.38462 .92045 L
.36538 .91601 L
.34615 .91011 L
.32983 .90385 L
.32692 .90259 L
.30769 .89326 L
.2928 .88462 L
.28846 .88183 L
.26923 .86786 L
.2662 .86538 L
.25 .85066 L
.24559 .84615 L
.23077 .82903 L
.22914 .82692 L
.21589 .80769 L
.21154 .80037 L
.20525 .78846 L
.19686 .76923 L
.19231 .75628 L
.19046 .75 L
.18588 .73077 L
.183 .71154 L
.18174 .69231 L
.18207 .67308 L
.18397 .65385 L
.18746 .63462 L
.19231 .61623 L
.19258 .61538 L
.19941 .59615 L
.20807 .57692 L
.21154 .57022 L
.21874 .55769 L
.23077 .53968 L
.23166 .53846 L
.24723 .51923 L
.25 .51615 L
.26601 .5 L
.26923 .49704 L
.28846 .48115 L
.28897 .48077 L
.30769 .46778 L
.31791 .46154 L
.32692 .4565 L
.34615 .44703 L
.35724 .44231 L
.36538 .43917 L
.38462 .43278 L
.40385 .42776 L
.42308 .42403 L
.42846 .42308 L
F
0 g
.44231 .42156 m
.46154 .42031 L
.48077 .42028 L
.5 .42149 L
.51454 .42308 L
.51923 .42395 L
.53846 .42772 L
.55769 .43289 L
.57692 .43955 L
.58379 .44231 L
.59615 .44786 L
.61538 .45804 L
.62123 .46154 L
.63462 .47039 L
.6483 .48077 L
.65385 .48541 L
.66938 .5 L
.67308 .50386 L
.68628 .51923 L
.69231 .5272 L
.69995 .53846 L
.71097 .55769 L
.71154 .55879 L
.71971 .57692 L
.72642 .59615 L
.73077 .61291 L
.73127 .61538 L
.73437 .63462 L
.7358 .65385 L
.7356 .67308 L
.73377 .69231 L
.73077 .7098 L
.7303 .71154 L
.72515 .73077 L
.71822 .75 L
.71154 .76498 L
.7094 .76923 L
.6985 .78846 L
.69231 .79793 L
.68527 .80769 L
.67308 .8227 L
.66931 .82692 L
.65385 .84264 L
.65005 .84615 L
.63462 .85921 L
.6265 .86538 L
.61538 .87316 L
.59681 .88462 L
.59615 .88499 L
.57692 .89499 L
Mistroke
.55769 .90339 L
.55655 .90385 L
.53846 .91033 L
.51923 .91592 L
.5 .92023 L
.48265 .92308 L
.48077 .92331 L
.46154 .92517 L
.44231 .92584 L
.42308 .9253 L
.40385 .92352 L
.40021 .92308 L
.38462 .92045 L
.36538 .91601 L
.34615 .91011 L
.32983 .90385 L
.32692 .90259 L
.30769 .89326 L
.2928 .88462 L
.28846 .88183 L
.26923 .86786 L
.2662 .86538 L
.25 .85066 L
.24559 .84615 L
.23077 .82903 L
.22914 .82692 L
.21589 .80769 L
.21154 .80037 L
.20525 .78846 L
.19686 .76923 L
.19231 .75628 L
.19046 .75 L
.18588 .73077 L
.183 .71154 L
.18174 .69231 L
.18207 .67308 L
.18397 .65385 L
.18746 .63462 L
.19231 .61623 L
.19258 .61538 L
.19941 .59615 L
.20807 .57692 L
.21154 .57022 L
.21874 .55769 L
.23077 .53968 L
.23166 .53846 L
.24723 .51923 L
.25 .51615 L
.26601 .5 L
.26923 .49704 L
Mistroke
.28846 .48115 L
.28897 .48077 L
.30769 .46778 L
.31791 .46154 L
.32692 .4565 L
.34615 .44703 L
.35724 .44231 L
.36538 .43917 L
.38462 .43278 L
.40385 .42776 L
.42308 .42403 L
.42846 .42308 L
.44231 .42156 L
Mfstroke
.8 g
.40385 .47497 m
.42308 .4705 L
.44231 .46755 L
.46154 .46608 L
.48077 .46606 L
.5 .46753 L
.51923 .47054 L
.53846 .47516 L
.55563 .48077 L
.55769 .48156 L
.57692 .48993 L
.59515 .5 L
.59615 .50062 L
.61538 .51414 L
.62159 .51923 L
.63462 .53137 L
.64125 .53846 L
.65385 .55412 L
.65636 .55769 L
.66801 .57692 L
.67308 .58717 L
.67683 .59615 L
.68319 .61538 L
.68732 .63462 L
.68939 .65385 L
.68946 .67308 L
.68758 .69231 L
.6837 .71154 L
.67775 .73077 L
.67308 .74255 L
.6696 .75 L
.659 .76923 L
.65385 .77719 L
.64562 .78846 L
.63462 .80158 L
.62887 .80769 L
.61538 .82052 L
.60779 .82692 L
.59615 .83578 L
.58045 .84615 L
.57692 .84826 L
.55769 .85848 L
.54198 .86538 L
.53846 .86676 L
.51923 .8733 L
.5 .87825 L
.48077 .88169 L
.46154 .88368 L
.44231 .88422 L
.42308 .8833 L
.40385 .88086 L
.38462 .87683 L
.36538 .87106 L
.3507 .86538 L
.34615 .86336 L
.32692 .85341 L
.31535 .84615 L
.30769 .84074 L
.291 .82692 L
.28846 .82454 L
.27278 .80769 L
.26923 .80328 L
.25879 .78846 L
.25 .77314 L
.24807 .76923 L
.24005 .75 L
.2344 .73077 L
.23089 .71154 L
.23077 .71057 L
.22939 .69231 L
.22982 .67308 L
.23077 .66334 L
.23217 .65385 L
.23647 .63462 L
.2428 .61538 L
.25 .59881 L
.25134 .59615 L
.2623 .57692 L
.26923 .56671 L
.27609 .55769 L
.28846 .54346 L
.29333 .53846 L
.30769 .52526 L
.31511 .51923 L
.32692 .51057 L
.34368 .5 L
.34615 .49859 L
.36538 .48885 L
.38462 .48104 L
.38537 .48077 L
F
0 g
.40385 .47497 m
.42308 .4705 L
.44231 .46755 L
.46154 .46608 L
.48077 .46606 L
.5 .46753 L
.51923 .47054 L
.53846 .47516 L
.55563 .48077 L
.55769 .48156 L
.57692 .48993 L
.59515 .5 L
.59615 .50062 L
.61538 .51414 L
.62159 .51923 L
.63462 .53137 L
.64125 .53846 L
.65385 .55412 L
.65636 .55769 L
.66801 .57692 L
.67308 .58717 L
.67683 .59615 L
.68319 .61538 L
.68732 .63462 L
.68939 .65385 L
.68946 .67308 L
.68758 .69231 L
.6837 .71154 L
.67775 .73077 L
.67308 .74255 L
.6696 .75 L
.659 .76923 L
.65385 .77719 L
.64562 .78846 L
.63462 .80158 L
.62887 .80769 L
.61538 .82052 L
.60779 .82692 L
.59615 .83578 L
.58045 .84615 L
.57692 .84826 L
.55769 .85848 L
.54198 .86538 L
.53846 .86676 L
.51923 .8733 L
.5 .87825 L
.48077 .88169 L
.46154 .88368 L
.44231 .88422 L
.42308 .8833 L
Mistroke
.40385 .88086 L
.38462 .87683 L
.36538 .87106 L
.3507 .86538 L
.34615 .86336 L
.32692 .85341 L
.31535 .84615 L
.30769 .84074 L
.291 .82692 L
.28846 .82454 L
.27278 .80769 L
.26923 .80328 L
.25879 .78846 L
.25 .77314 L
.24807 .76923 L
.24005 .75 L
.2344 .73077 L
.23089 .71154 L
.23077 .71057 L
.22939 .69231 L
.22982 .67308 L
.23077 .66334 L
.23217 .65385 L
.23647 .63462 L
.2428 .61538 L
.25 .59881 L
.25134 .59615 L
.2623 .57692 L
.26923 .56671 L
.27609 .55769 L
.28846 .54346 L
.29333 .53846 L
.30769 .52526 L
.31511 .51923 L
.32692 .51057 L
.34368 .5 L
.34615 .49859 L
.36538 .48885 L
.38462 .48104 L
.38537 .48077 L
.40385 .47497 L
Mfstroke
.9 g
.44231 .51694 m
.46154 .51517 L
.48077 .51529 L
.5 .51733 L
.51126 .51923 L
.51923 .52139 L
.53846 .5277 L
.55769 .53662 L
.56102 .53846 L
.57692 .54876 L
.58804 .55769 L
.59615 .56534 L
.60645 .57692 L
.61538 .58923 L
.61957 .59615 L
.62878 .61538 L
.63462 .63388 L
.63477 .63462 L
.63795 .65385 L
.63851 .67308 L
.63651 .69231 L
.63462 .70348 L
.63193 .71154 L
.6246 .73077 L
.61538 .74813 L
.6142 .75 L
.60016 .76923 L
.59615 .77386 L
.58141 .78846 L
.57692 .79232 L
.55769 .80639 L
.55564 .80769 L
.53846 .81728 L
.51923 .82558 L
.51565 .82692 L
.5 .83168 L
.48077 .83577 L
.46154 .83796 L
.44231 .83828 L
.42308 .83671 L
.40385 .83313 L
.38462 .82735 L
.38344 .82692 L
.36538 .81903 L
.34634 .80769 L
.34615 .80756 L
.32692 .79189 L
.32346 .78846 L
.30769 .76947 L
.30752 .76923 L
.2962 .75 L
.28846 .73081 L
.28845 .73077 L
.28369 .71154 L
.28163 .69231 L
.2821 .67308 L
.28508 .65385 L
.28846 .64041 L
.29065 .63462 L
.29901 .61538 L
.30769 .60037 L
.31056 .59615 L
.32602 .57692 L
.32692 .57595 L
.34615 .55818 L
.34676 .55769 L
.36538 .54461 L
.37606 .53846 L
.38462 .53418 L
.40385 .52629 L
.42308 .52061 L
.42802 .51923 L
F
0 g
.44231 .51694 m
.46154 .51517 L
.48077 .51529 L
.5 .51733 L
.51126 .51923 L
.51923 .52139 L
.53846 .5277 L
.55769 .53662 L
.56102 .53846 L
.57692 .54876 L
.58804 .55769 L
.59615 .56534 L
.60645 .57692 L
.61538 .58923 L
.61957 .59615 L
.62878 .61538 L
.63462 .63388 L
.63477 .63462 L
.63795 .65385 L
.63851 .67308 L
.63651 .69231 L
.63462 .70348 L
.63193 .71154 L
.6246 .73077 L
.61538 .74813 L
.6142 .75 L
.60016 .76923 L
.59615 .77386 L
.58141 .78846 L
.57692 .79232 L
.55769 .80639 L
.55564 .80769 L
.53846 .81728 L
.51923 .82558 L
.51565 .82692 L
.5 .83168 L
.48077 .83577 L
.46154 .83796 L
.44231 .83828 L
.42308 .83671 L
.40385 .83313 L
.38462 .82735 L
.38344 .82692 L
.36538 .81903 L
.34634 .80769 L
.34615 .80756 L
.32692 .79189 L
.32346 .78846 L
.30769 .76947 L
.30752 .76923 L
Mistroke
.2962 .75 L
.28846 .73081 L
.28845 .73077 L
.28369 .71154 L
.28163 .69231 L
.2821 .67308 L
.28508 .65385 L
.28846 .64041 L
.29065 .63462 L
.29901 .61538 L
.30769 .60037 L
.31056 .59615 L
.32602 .57692 L
.32692 .57595 L
.34615 .55818 L
.34676 .55769 L
.36538 .54461 L
.37606 .53846 L
.38462 .53418 L
.40385 .52629 L
.42308 .52061 L
.42802 .51923 L
.44231 .51694 L
Mfstroke
1 g
.46154 .57553 m
.48077 .57614 L
.48657 .57692 L
.5 .57983 L
.51923 .58712 L
.53442 .59615 L
.53846 .59923 L
.55453 .61538 L
.55769 .61935 L
.56621 .63462 L
.57239 .65385 L
.57417 .67308 L
.57192 .69231 L
.56549 .71154 L
.55769 .72612 L
.55423 .73077 L
.53846 .7482 L
.5364 .75 L
.51923 .76241 L
.50626 .76923 L
.5 .77177 L
.48077 .77762 L
.46154 .78036 L
.44231 .78016 L
.42308 .77689 L
.40385 .77005 L
.40207 .76923 L
.38462 .7587 L
.37455 .75 L
.36538 .73974 L
.35953 .73077 L
.35098 .71154 L
.34723 .69231 L
.34757 .67308 L
.3519 .65385 L
.36063 .63462 L
.36538 .62697 L
.37478 .61538 L
.38462 .6058 L
.39744 .59615 L
.40385 .59226 L
.42308 .58328 L
.44231 .57788 L
.44774 .57692 L
F
0 g
.46154 .57553 m
.48077 .57614 L
.48657 .57692 L
.5 .57983 L
.51923 .58712 L
.53442 .59615 L
.53846 .59923 L
.55453 .61538 L
.55769 .61935 L
.56621 .63462 L
.57239 .65385 L
.57417 .67308 L
.57192 .69231 L
.56549 .71154 L
.55769 .72612 L
.55423 .73077 L
.53846 .7482 L
.5364 .75 L
.51923 .76241 L
.50626 .76923 L
.5 .77177 L
.48077 .77762 L
.46154 .78036 L
.44231 .78016 L
.42308 .77689 L
.40385 .77005 L
.40207 .76923 L
.38462 .7587 L
.37455 .75 L
.36538 .73974 L
.35953 .73077 L
.35098 .71154 L
.34723 .69231 L
.34757 .67308 L
.3519 .65385 L
.36063 .63462 L
.36538 .62697 L
.37478 .61538 L
.38462 .6058 L
.39744 .59615 L
.40385 .59226 L
.42308 .58328 L
.44231 .57788 L
.44774 .57692 L
.46154 .57553 L
s
.98077 .29601 m
.97596 .28846 L
.96309 .26923 L
.96154 .267 L
.94933 .25 L
.94231 .24065 L
.93464 .23077 L
.92308 .21644 L
.91899 .21154 L
.90385 .19401 L
.90233 .19231 L
.88462 .17309 L
.8846 .17308 L
.86576 .15385 L
.86538 .15348 L
.84615 .135 L
.84574 .13462 L
.82692 .11755 L
.82446 .11538 L
.80769 .10101 L
.80185 .09615 L
.78846 .08531 L
.7778 .07692 L
.76923 .07036 L
.75218 .05769 L
.75 .05611 L
.73077 .04252 L
.72485 .03846 L
.71154 .02955 L
.69556 .01923 L
.98077 .01923 L
F
.98077 .29601 m
.97596 .28846 L
.96309 .26923 L
.96154 .267 L
.94933 .25 L
.94231 .24065 L
.93464 .23077 L
.92308 .21644 L
.91899 .21154 L
.90385 .19401 L
.90233 .19231 L
.88462 .17309 L
.8846 .17308 L
.86576 .15385 L
.86538 .15348 L
.84615 .135 L
.84574 .13462 L
.82692 .11755 L
.82446 .11538 L
.80769 .10101 L
.80185 .09615 L
.78846 .08531 L
.7778 .07692 L
.76923 .07036 L
.75218 .05769 L
.75 .05611 L
.73077 .04252 L
.72485 .03846 L
.71154 .02955 L
.69556 .01923 L
s
.1 g
.98077 .74393 m
.97936 .75 L
.97435 .76923 L
.96847 .78846 L
.96168 .80769 L
.96154 .80808 L
.95395 .82692 L
.94524 .84615 L
.94231 .85217 L
.93549 .86538 L
.92464 .88462 L
.92308 .88723 L
.91262 .90385 L
.90385 .91675 L
.89933 .92308 L
.88468 .94231 L
.88462 .94239 L
.86852 .96154 L
.86538 .96506 L
.85069 .98077 L
.98077 .98077 L
F
0 g
.98077 .74393 m
.97936 .75 L
.97435 .76923 L
.96847 .78846 L
.96168 .80769 L
.96154 .80808 L
.95395 .82692 L
.94524 .84615 L
.94231 .85217 L
.93549 .86538 L
.92464 .88462 L
.92308 .88723 L
.91262 .90385 L
.90385 .91675 L
.89933 .92308 L
.88468 .94231 L
.88462 .94239 L
.86852 .96154 L
.86538 .96506 L
.85069 .98077 L
s
.98077 .95205 m
.97413 .96154 L
.96154 .97852 L
.9598 .98077 L
.98077 .98077 L
F
.98077 .95205 m
.97413 .96154 L
.96154 .97852 L
.9598 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.196 .669 .936 r
.39775 .63251 .40403 .63504 .41424 .63575 .40798 .6335 Mtetra
.135 .639 .904 r
.40798 .6335 .41424 .63575 .42452 .63662 .41827 .63467 Mtetra
.072 .605 .863 r
.41827 .63467 .42452 .63662 .43485 .63763 .42863 .63599 Mtetra
.01 .567 .815 r
.42863 .63599 .43485 .63763 .44524 .63875 .43904 .63744 Mtetra
0 .527 .761 r
.43904 .63744 .44524 .63875 .4557 .63996 .44953 .63899 Mtetra
0 .487 .704 r
.44953 .63899 .4557 .63996 .46623 .64123 .46008 .6406 Mtetra
.15 0 0 r
.46008 .6406 .46623 .64123 .47682 .64252 .4707 .64224 Mtetra
.19 0 0 r
.4707 .64224 .47682 .64252 .48748 .64379 .48139 .64387 Mtetra
.221 0 0 r
.48139 .64387 .48748 .64379 .49821 .645 .49216 .64544 Mtetra
.245 0 0 r
.49216 .64544 .49821 .645 .50901 .6461 .50299 .6469 Mtetra
.261 0 0 r
.50299 .6469 .50901 .6461 .51988 .64707 .5139 .64821 Mtetra
.27 0 0 r
.5139 .64821 .51988 .64707 .53082 .64784 .52489 .64931 Mtetra
.273 0 0 r
.52489 .64931 .53082 .64784 .54183 .64837 .53594 .65017 Mtetra
.269 0 0 r
.53594 .65017 .54183 .64837 .5529 .64863 .54706 .65073 Mtetra
.26 0 0 r
.54706 .65073 .5529 .64863 .56403 .64857 .55825 .65095 Mtetra
.246 0 0 r
.55825 .65095 .56403 .64857 .57522 .64815 .5695 .65078 Mtetra
.227 0 0 r
.5695 .65078 .57522 .64815 .58647 .64733 .5808 .65019 Mtetra
.203 0 0 r
.5808 .65019 .58647 .64733 .59778 .64609 .59216 .64915 Mtetra
.174 0 0 r
.59216 .64915 .59778 .64609 .60912 .64441 .60358 .64762 Mtetra
.14 0 0 r
.60358 .64762 .60912 .64441 .62052 .64225 .61503 .64559 Mtetra
.102 0 0 r
.61503 .64559 .62052 .64225 .63195 .63962 .62653 .64303 Mtetra
.059 0 0 r
.62653 .64303 .63195 .63962 .64341 .63649 .63806 .63994 Mtetra
.012 0 0 r
.63806 .63994 .64341 .63649 .65491 .63286 .64962 .63632 Mtetra
0 0 0 r
.64962 .63632 .65491 .63286 .66643 .62875 .6612 .63216 Mtetra
.6612 .63216 .66643 .62875 .67797 .62416 .67281 .62748 Mtetra
.67281 .62748 .67797 .62416 .68953 .6191 .68443 .62229 Mtetra
.68443 .62229 .68953 .6191 .7011 .61361 .69607 .61663 Mtetra
.69607 .61663 .7011 .61361 .71269 .60769 .70771 .61051 Mtetra
.70771 .61051 .71269 .60769 .72428 .60139 .71936 .60397 Mtetra
.406 .828 .656 r
.71936 .60397 .72428 .60139 .73588 .59474 .73101 .59704 Mtetra
.467 .868 .697 r
.73101 .59704 .73588 .59474 .74748 .58778 .74267 .58977 Mtetra
.524 .903 .736 r
.74267 .58977 .74748 .58778 .75909 .58054 .75433 .58221 Mtetra
.576 .933 .772 r
.75433 .58221 .75909 .58054 .77071 .57308 .76599 .57438 Mtetra
.623 .956 .804 r
.76599 .57438 .77071 .57308 .78233 .56541 .77766 .56635 Mtetra
.663 .972 .832 r
.77766 .56635 .78233 .56541 .79397 .55761 .78933 .55815 Mtetra
.697 .983 .856 r
.78933 .55815 .79397 .55761 .80561 .54969 .80101 .54983 Mtetra
.724 .988 .875 r
.80101 .54983 .80561 .54969 .81727 .5417 .8127 .54144 Mtetra
.746 .989 .891 r
.8127 .54144 .81727 .5417 .82894 .53369 .8244 .53301 Mtetra
.762 .985 .903 r
.8244 .53301 .82894 .53369 .84063 .52569 .83612 .5246 Mtetra
.773 .978 .913 r
.83612 .5246 .84063 .52569 .85234 .51773 .84786 .51622 Mtetra
.78 .969 .92 r
.84786 .51622 .85234 .51773 .86408 .50984 .85962 .50793 Mtetra
.784 .958 .925 r
.85962 .50793 .86408 .50984 .87585 .50205 .87142 .49974 Mtetra
.785 .946 .928 r
.87142 .49974 .87585 .50205 .88766 .49438 .88324 .49169 Mtetra
.784 .932 .93 r
.88324 .49169 .88766 .49438 .8995 .48686 .8951 .4838 Mtetra
.781 .919 .93 r
.8951 .4838 .8995 .48686 .91139 .4795 .90701 .47608 Mtetra
.777 .905 .93 r
.90701 .47608 .91139 .4795 .92332 .47232 .91896 .46855 Mtetra
.771 .892 .93 r
.91896 .46855 .92332 .47232 .9353 .46532 .93095 .46123 Mtetra
.765 .879 .929 r
.93095 .46123 .9353 .46532 .94733 .45851 .943 .45411 Mtetra
.758 .867 .928 r
.943 .45411 .94733 .45851 .95942 .45189 .95511 .44721 Mtetra
.752 .855 .926 r
.95511 .44721 .95942 .45189 .97157 .44547 .96728 .44052 Mtetra
.155 .643 .92 r
.39142 .62996 .39775 .63251 .40798 .6335 .40167 .63123 Mtetra
.091 .609 .883 r
.40167 .63123 .40798 .6335 .41827 .63467 .41197 .63269 Mtetra
.025 .571 .837 r
.41197 .63269 .41827 .63467 .42863 .63599 .42235 .63433 Mtetra
0 .53 .785 r
.42235 .63433 .42863 .63599 .43904 .63744 .43278 .6361 Mtetra
0 .487 .728 r
.43278 .6361 .43904 .63744 .44953 .63899 .44329 .63799 Mtetra
.15 0 0 r
.44329 .63799 .44953 .63899 .46008 .6406 .45386 .63996 Mtetra
.196 0 0 r
.45386 .63996 .46008 .6406 .4707 .64224 .46451 .64195 Mtetra
.233 0 0 r
.46451 .64195 .4707 .64224 .48139 .64387 .47524 .64394 Mtetra
.262 0 0 r
.47524 .64394 .48139 .64387 .49216 .64544 .48603 .64587 Mtetra
.283 0 0 r
.48603 .64587 .49216 .64544 .50299 .6469 .49691 .64769 Mtetra
.297 0 0 r
.49691 .64769 .50299 .6469 .5139 .64821 .50786 .64935 Mtetra
.304 0 0 r
.50786 .64935 .5139 .64821 .52489 .64931 .51888 .6508 Mtetra
.51888 .6508 .52489 .64931 .53594 .65017 .52998 .65199 Mtetra
.298 0 0 r
.52998 .65199 .53594 .65017 .54706 .65073 .54115 .65286 Mtetra
.287 0 0 r
.54115 .65286 .54706 .65073 .55825 .65095 .55239 .65337 Mtetra
.271 0 0 r
.55239 .65337 .55825 .65095 .5695 .65078 .5637 .65347 Mtetra
.25 0 0 r
.5637 .65347 .5695 .65078 .5808 .65019 .57506 .65311 Mtetra
.223 0 0 r
.57506 .65311 .5808 .65019 .59216 .64915 .58648 .65227 Mtetra
.192 0 0 r
.58648 .65227 .59216 .64915 .60358 .64762 .59796 .65091 Mtetra
.156 0 0 r
.59796 .65091 .60358 .64762 .61503 .64559 .60948 .64901 Mtetra
.115 0 0 r
.60948 .64901 .61503 .64559 .62653 .64303 .62104 .64654 Mtetra
.07 0 0 r
.62104 .64654 .62653 .64303 .63806 .63994 .63263 .64349 Mtetra
.019 0 0 r
.63263 .64349 .63806 .63994 .64962 .63632 .64426 .63987 Mtetra
0 0 0 r
.64426 .63987 .64962 .63632 .6612 .63216 .65591 .63567 Mtetra
.65591 .63567 .6612 .63216 .67281 .62748 .66758 .63091 Mtetra
.66758 .63091 .67281 .62748 .68443 .62229 .67927 .6256 Mtetra
.67927 .6256 .68443 .62229 .69607 .61663 .69097 .61977 Mtetra
.69097 .61977 .69607 .61663 .70771 .61051 .70267 .61345 Mtetra
.70267 .61345 .70771 .61051 .71936 .60397 .71438 .60666 Mtetra
.417 .832 .651 r
.71438 .60666 .71936 .60397 .73101 .59704 .72609 .59946 Mtetra
.478 .872 .692 r
.72609 .59946 .73101 .59704 .74267 .58977 .7378 .59189 Mtetra
.536 .907 .73 r
.7378 .59189 .74267 .58977 .75433 .58221 .74951 .58398 Mtetra
.589 .936 .765 r
.74951 .58398 .75433 .58221 .76599 .57438 .76122 .5758 Mtetra
.636 .959 .797 r
.76122 .5758 .76599 .57438 .77766 .56635 .77293 .56739 Mtetra
.676 .976 .824 r
.77293 .56739 .77766 .56635 .78933 .55815 .78465 .5588 Mtetra
.709 .986 .847 r
.78465 .5588 .78933 .55815 .80101 .54983 .79637 .55007 Mtetra
.736 .991 .867 r
.79637 .55007 .80101 .54983 .8127 .54144 .80809 .54127 Mtetra
.758 .991 .883 r
.80809 .54127 .8127 .54144 .8244 .53301 .81982 .53242 Mtetra
.773 .988 .895 r
.81982 .53242 .8244 .53301 .83612 .5246 .83157 .52358 Mtetra
.784 .981 .905 r
.83157 .52358 .83612 .5246 .84786 .51622 .84334 .51479 Mtetra
.791 .972 .912 r
.84334 .51479 .84786 .51622 .85962 .50793 .85513 .50608 Mtetra
.795 .961 .918 r
.85513 .50608 .85962 .50793 .87142 .49974 .86694 .49749 Mtetra
.795 .949 .921 r
.86694 .49749 .87142 .49974 .88324 .49169 .87879 .48905 Mtetra
.794 .936 .924 r
.87879 .48905 .88324 .49169 .8951 .4838 .89067 .48077 Mtetra
.79 .923 .925 r
.89067 .48077 .8951 .4838 .90701 .47608 .90259 .47269 Mtetra
.785 .909 .926 r
.90259 .47269 .90701 .47608 .91896 .46855 .91456 .46481 Mtetra
.78 .896 .926 r
.91456 .46481 .91896 .46855 .93095 .46123 .92657 .45716 Mtetra
.773 .883 .925 r
.92657 .45716 .93095 .46123 .943 .45411 .93864 .44973 Mtetra
.766 .87 .924 r
.93864 .44973 .943 .45411 .95511 .44721 .95077 .44253 Mtetra
.759 .858 .924 r
.95077 .44253 .95511 .44721 .96728 .44052 .96295 .43556 Mtetra
.118 .617 .904 r
.38503 .62734 .39142 .62996 .40167 .63123 .39529 .62889 Mtetra
.051 .58 .863 r
.39529 .62889 .40167 .63123 .41197 .63269 .40562 .63065 Mtetra
0 .539 .815 r
.40562 .63065 .41197 .63269 .42235 .63433 .41601 .6326 Mtetra
0 .495 .76 r
.41601 .6326 .42235 .63433 .43278 .6361 .42646 .6347 Mtetra
0 .452 .702 r
.42646 .6347 .43278 .6361 .44329 .63799 .43699 .63693 Mtetra
.19 0 0 r
.43699 .63693 .44329 .63799 .45386 .63996 .44759 .63924 Mtetra
.233 0 0 r
.44759 .63924 .45386 .63996 .46451 .64195 .45826 .6416 Mtetra
.268 0 0 r
.45826 .6416 .46451 .64195 .47524 .64394 .46902 .64395 Mtetra
.295 0 0 r
.46902 .64395 .47524 .64394 .48603 .64587 .47985 .64624 Mtetra
.314 0 0 r
.47985 .64624 .48603 .64587 .49691 .64769 .49076 .64842 Mtetra
.325 0 0 r
.49076 .64842 .49691 .64769 .50786 .64935 .50174 .65044 Mtetra
.33 0 0 r
.50174 .65044 .50786 .64935 .51888 .6508 .51281 .65223 Mtetra
.328 0 0 r
.51281 .65223 .51888 .6508 .52998 .65199 .52395 .65375 Mtetra
.32 0 0 r
.52395 .65375 .52998 .65199 .54115 .65286 .53517 .65494 Mtetra
.307 0 0 r
.53517 .65494 .54115 .65286 .55239 .65337 .54646 .65574 Mtetra
.289 0 0 r
.54646 .65574 .55239 .65337 .5637 .65347 .55782 .65611 Mtetra
.265 0 0 r
.55782 .65611 .5637 .65347 .57506 .65311 .56924 .656 Mtetra
.236 0 0 r
.56924 .656 .57506 .65311 .58648 .65227 .58073 .65537 Mtetra
.203 0 0 r
.58073 .65537 .58648 .65227 .59796 .65091 .59226 .65418 Mtetra
.164 0 0 r
.59226 .65418 .59796 .65091 .60948 .64901 .60385 .65241 Mtetra
.12 0 0 r
.60385 .65241 .60948 .64901 .62104 .64654 .61547 .65003 Mtetra
.071 0 0 r
.61547 .65003 .62104 .64654 .63263 .64349 .62714 .64704 Mtetra
.017 0 0 r
.62714 .64704 .63263 .64349 .64426 .63987 .63883 .64343 Mtetra
0 0 0 r
.63883 .64343 .64426 .63987 .65591 .63567 .65055 .6392 Mtetra
.65055 .6392 .65591 .63567 .66758 .63091 .66229 .63436 Mtetra
.66229 .63436 .66758 .63091 .67927 .6256 .67404 .62894 Mtetra
.67404 .62894 .67927 .6256 .69097 .61977 .6858 .62294 Mtetra
.6858 .62294 .69097 .61977 .70267 .61345 .69757 .61642 Mtetra
.372 .799 .617 r
.69757 .61642 .70267 .61345 .71438 .60666 .70934 .60939 Mtetra
.437 .844 .658 r
.70934 .60939 .71438 .60666 .72609 .59946 .72111 .60192 Mtetra
.5 .883 .697 r
.72111 .60192 .72609 .59946 .7378 .59189 .73287 .59404 Mtetra
.557 .917 .734 r
.73287 .59404 .7378 .59189 .74951 .58398 .74464 .5858 Mtetra
.609 .944 .767 r
.74464 .5858 .74951 .58398 .76122 .5758 .7564 .57726 Mtetra
.655 .966 .796 r
.7564 .57726 .76122 .5758 .77293 .56739 .76815 .56847 Mtetra
.693 .98 .822 r
.76815 .56847 .77293 .56739 .78465 .5588 .77991 .55948 Mtetra
.726 .99 .843 r
.77991 .55948 .78465 .5588 .79637 .55007 .79167 .55035 Mtetra
.752 .994 .861 r
.79167 .55035 .79637 .55007 .80809 .54127 .80343 .54112 Mtetra
.772 .994 .876 r
.80343 .54112 .80809 .54127 .81982 .53242 .8152 .53186 Mtetra
.786 .99 .888 r
.8152 .53186 .81982 .53242 .83157 .52358 .82697 .52259 Mtetra
.796 .983 .898 r
.82697 .52259 .83157 .52358 .84334 .51479 .83877 .51338 Mtetra
.803 .974 .905 r
.83877 .51338 .84334 .51479 .85513 .50608 .85058 .50426 Mtetra
.805 .963 .91 r
.85058 .50426 .85513 .50608 .86694 .49749 .86242 .49526 Mtetra
.806 .951 .915 r
.86242 .49526 .86694 .49749 .87879 .48905 .87429 .48642 Mtetra
.803 .938 .917 r
.87429 .48642 .87879 .48905 .89067 .48077 .88619 .47776 Mtetra
.799 .925 .919 r
.88619 .47776 .89067 .48077 .90259 .47269 .89814 .4693 Mtetra
.794 .912 .92 r
.89814 .4693 .90259 .47269 .91456 .46481 .91012 .46107 Mtetra
.788 .899 .921 r
.91012 .46107 .91456 .46481 .92657 .45716 .92216 .45308 Mtetra
.781 .886 .921 r
.92216 .45308 .92657 .45716 .93864 .44973 .93424 .44533 Mtetra
.773 .873 .921 r
.93424 .44533 .93864 .44973 .95077 .44253 .94639 .43783 Mtetra
.766 .861 .92 r
.94639 .43783 .95077 .44253 .96295 .43556 .95859 .43058 Mtetra
.086 .593 .891 r
.37859 .62462 .38503 .62734 .39529 .62889 .38886 .62645 Mtetra
.017 .553 .847 r
.38886 .62645 .39529 .62889 .40562 .63065 .3992 .6285 Mtetra
0 .51 .797 r
.3992 .6285 .40562 .63065 .41601 .6326 .40961 .63076 Mtetra
0 .466 .741 r
.40961 .63076 .41601 .6326 .42646 .6347 .42008 .63318 Mtetra
.171 0 0 r
.42008 .63318 .42646 .6347 .43699 .63693 .43063 .63574 Mtetra
.221 0 0 r
.43063 .63574 .43699 .63693 .44759 .63924 .44125 .6384 Mtetra
.262 0 0 r
.44125 .6384 .44759 .63924 .45826 .6416 .45195 .64111 Mtetra
.295 0 0 r
.45195 .64111 .45826 .6416 .46902 .64395 .46273 .64381 Mtetra
.32 0 0 r
.46273 .64381 .46902 .64395 .47985 .64624 .47359 .64646 Mtetra
.337 0 0 r
.47359 .64646 .47985 .64624 .49076 .64842 .48454 .64901 Mtetra
.346 0 0 r
.48454 .64901 .49076 .64842 .50174 .65044 .49556 .65138 Mtetra
.349 0 0 r
.49556 .65138 .50174 .65044 .51281 .65223 .50667 .65352 Mtetra
.345 0 0 r
.50667 .65352 .51281 .65223 .52395 .65375 .51786 .65537 Mtetra
.336 0 0 r
.51786 .65537 .52395 .65375 .53517 .65494 .52912 .65688 Mtetra
.321 0 0 r
.52912 .65688 .53517 .65494 .54646 .65574 .54046 .65798 Mtetra
.3 0 0 r
.54046 .65798 .54646 .65574 .55782 .65611 .55187 .65862 Mtetra
.274 0 0 r
.55187 .65862 .55782 .65611 .56924 .656 .56335 .65875 Mtetra
.242 0 0 r
.56335 .65875 .56924 .656 .58073 .65537 .57489 .65833 Mtetra
.205 0 0 r
.57489 .65833 .58073 .65537 .59226 .65418 .58649 .65732 Mtetra
.163 0 0 r
.58649 .65732 .59226 .65418 .60385 .65241 .59814 .65569 Mtetra
.115 0 0 r
.59814 .65569 .60385 .65241 .61547 .65003 .60983 .65342 Mtetra
.062 0 0 r
.60983 .65342 .61547 .65003 .62714 .64704 .62156 .65049 Mtetra
.004 0 0 r
.62156 .65049 .62714 .64704 .63883 .64343 .63332 .64689 Mtetra
0 0 0 r
.63332 .64689 .63883 .64343 .65055 .6392 .64511 .64264 Mtetra
.64511 .64264 .65055 .6392 .66229 .63436 .65691 .63773 Mtetra
.65691 .63773 .66229 .63436 .67404 .62894 .66873 .63219 Mtetra
.66873 .63219 .67404 .62894 .6858 .62294 .68056 .62604 Mtetra
.68056 .62604 .6858 .62294 .69757 .61642 .69239 .61932 Mtetra
.403 .821 .638 r
.69239 .61932 .69757 .61642 .70934 .60939 .70422 .61206 Mtetra
.469 .864 .677 r
.70422 .61206 .70934 .60939 .72111 .60192 .71605 .60432 Mtetra
.531 .901 .713 r
.71605 .60432 .72111 .60192 .73287 .59404 .72788 .59614 Mtetra
.587 .932 .746 r
.72788 .59614 .73287 .59404 .74464 .5858 .73969 .58757 Mtetra
.636 .956 .776 r
.73969 .58757 .74464 .5858 .7564 .57726 .7515 .57868 Mtetra
.679 .974 .802 r
.7515 .57868 .7564 .57726 .76815 .56847 .76331 .56951 Mtetra
.716 .986 .824 r
.76331 .56951 .76815 .56847 .77991 .55948 .77511 .56013 Mtetra
.746 .994 .843 r
.77511 .56013 .77991 .55948 .79167 .55035 .78691 .55059 Mtetra
.769 .996 .859 r
.78691 .55059 .79167 .55035 .80343 .54112 .79871 .54095 Mtetra
.787 .994 .872 r
.79871 .54095 .80343 .54112 .8152 .53186 .81051 .53126 Mtetra
.8 .99 .883 r
.81051 .53126 .8152 .53186 .82697 .52259 .82232 .52157 Mtetra
.809 .983 .892 r
.82232 .52157 .82697 .52259 .83877 .51338 .83415 .51194 Mtetra
.814 .973 .898 r
.83415 .51194 .83877 .51338 .85058 .50426 .84599 .5024 Mtetra
.816 .963 .904 r
.84599 .5024 .85058 .50426 .86242 .49526 .85786 .49299 Mtetra
.816 .951 .908 r
.85786 .49299 .86242 .49526 .87429 .48642 .86975 .48375 Mtetra
.813 .939 .911 r
.86975 .48375 .87429 .48642 .88619 .47776 .88167 .4747 Mtetra
.808 .926 .913 r
.88167 .4747 .88619 .47776 .89814 .4693 .89364 .46588 Mtetra
.803 .913 .915 r
.89364 .46588 .89814 .4693 .91012 .46107 .90564 .45729 Mtetra
.796 .9 .916 r
.90564 .45729 .91012 .46107 .92216 .45308 .9177 .44896 Mtetra
.788 .887 .916 r
.9177 .44896 .92216 .45308 .93424 .44533 .9298 .44089 Mtetra
.78 .875 .917 r
.9298 .44089 .93424 .44533 .94639 .43783 .94197 .43309 Mtetra
.772 .863 .916 r
.94197 .43309 .94639 .43783 .95859 .43058 .95419 .42556 Mtetra
.059 .571 .88 r
.37209 .62178 .37859 .62462 .38886 .62645 .38238 .62387 Mtetra
0 .53 .835 r
.38238 .62387 .38886 .62645 .3992 .6285 .39273 .62621 Mtetra
0 .486 .784 r
.39273 .62621 .3992 .6285 .40961 .63076 .40315 .62876 Mtetra
0 .442 .729 r
.40315 .62876 .40961 .63076 .42008 .63318 .41365 .6315 Mtetra
.195 0 0 r
.41365 .6315 .42008 .63318 .43063 .63574 .42421 .63438 Mtetra
.243 0 0 r
.42421 .63438 .43063 .63574 .44125 .6384 .43485 .63737 Mtetra
.283 0 0 r
.43485 .63737 .44125 .6384 .45195 .64111 .44558 .64042 Mtetra
.314 0 0 r
.44558 .64042 .45195 .64111 .46273 .64381 .45638 .64348 Mtetra
.337 0 0 r
.45638 .64348 .46273 .64381 .47359 .64646 .46727 .64648 Mtetra
.352 0 0 r
.46727 .64648 .47359 .64646 .48454 .64901 .47825 .64937 Mtetra
.36 0 0 r
.47825 .64937 .48454 .64901 .49556 .65138 .48931 .65209 Mtetra
.361 0 0 r
.48931 .65209 .49556 .65138 .50667 .65352 .50045 .65457 Mtetra
.356 0 0 r
.50045 .65457 .50667 .65352 .51786 .65537 .51168 .65676 Mtetra
.344 0 0 r
.51168 .65676 .51786 .65537 .52912 .65688 .52299 .65857 Mtetra
.327 0 0 r
.52299 .65857 .52912 .65688 .54046 .65798 .53438 .65997 Mtetra
.304 0 0 r
.53438 .65997 .54046 .65798 .55187 .65862 .54585 .66088 Mtetra
.275 0 0 r
.54585 .66088 .55187 .65862 .56335 .65875 .55738 .66126 Mtetra
.24 0 0 r
.55738 .66126 .56335 .65875 .57489 .65833 .56898 .66105 Mtetra
.199 0 0 r
.56898 .66105 .57489 .65833 .58649 .65732 .58064 .66023 Mtetra
.153 0 0 r
.58064 .66023 .58649 .65732 .59814 .65569 .59235 .65874 Mtetra
.1 0 0 r
.59235 .65874 .59814 .65569 .60983 .65342 .60411 .65658 Mtetra
.042 0 0 r
.60411 .65658 .60983 .65342 .62156 .65049 .6159 .65371 Mtetra
0 0 0 r
.6159 .65371 .62156 .65049 .63332 .64689 .62773 .65014 Mtetra
.62773 .65014 .63332 .64689 .64511 .64264 .63959 .64586 Mtetra
.63959 .64586 .64511 .64264 .65691 .63773 .65146 .64089 Mtetra
.65146 .64089 .65691 .63773 .66873 .63219 .66335 .63525 Mtetra
.66335 .63525 .66873 .63219 .68056 .62604 .67524 .62895 Mtetra
.376 .807 .634 r
.67524 .62895 .68056 .62604 .69239 .61932 .68714 .62205 Mtetra
.446 .851 .671 r
.68714 .62205 .69239 .61932 .70422 .61206 .69903 .61457 Mtetra
.511 .89 .706 r
.69903 .61457 .70422 .61206 .71605 .60432 .71092 .60657 Mtetra
.57 .923 .738 r
.71092 .60657 .71605 .60432 .72788 .59614 .7228 .59809 Mtetra
.623 .949 .766 r
.7228 .59809 .72788 .59614 .73969 .58757 .73468 .5892 Mtetra
.669 .969 .791 r
.73468 .5892 .73969 .58757 .7515 .57868 .74654 .57996 Mtetra
.709 .984 .812 r
.74654 .57996 .7515 .57868 .76331 .56951 .7584 .57042 Mtetra
.741 .992 .831 r
.7584 .57042 .76331 .56951 .77511 .56013 .77024 .56066 Mtetra
.768 .997 .846 r
.77024 .56066 .77511 .56013 .78691 .55059 .78209 .55072 Mtetra
.788 .997 .859 r
.78209 .55072 .78691 .55059 .79871 .54095 .79393 .54067 Mtetra
.804 .994 .87 r
.79393 .54067 .79871 .54095 .81051 .53126 .80577 .53056 Mtetra
.815 .988 .879 r
.80577 .53056 .81051 .53126 .82232 .52157 .81761 .52046 Mtetra
.822 .981 .886 r
.81761 .52046 .82232 .52157 .83415 .51194 .82947 .51041 Mtetra
.826 .971 .892 r
.82947 .51041 .83415 .51194 .84599 .5024 .84134 .50045 Mtetra
.827 .961 .897 r
.84134 .50045 .84599 .5024 .85786 .49299 .85323 .49064 Mtetra
.825 .949 .901 r
.85323 .49064 .85786 .49299 .86975 .48375 .86515 .481 Mtetra
.822 .937 .904 r
.86515 .481 .86975 .48375 .88167 .4747 .8771 .47158 Mtetra
.817 .925 .907 r
.8771 .47158 .88167 .4747 .89364 .46588 .88909 .46238 Mtetra
.811 .912 .909 r
.88909 .46238 .89364 .46588 .90564 .45729 .90112 .45344 Mtetra
.803 .899 .91 r
.90112 .45344 .90564 .45729 .9177 .44896 .91319 .44477 Mtetra
.795 .887 .911 r
.91319 .44477 .9177 .44896 .9298 .44089 .92532 .43639 Mtetra
.787 .875 .912 r
.92532 .43639 .9298 .44089 .94197 .43309 .9375 .42829 Mtetra
.778 .863 .912 r
.9375 .42829 .94197 .43309 .95419 .42556 .94975 .42048 Mtetra
.039 .553 .872 r
.36554 .61878 .37209 .62178 .38238 .62387 .37584 .62112 Mtetra
0 .511 .828 r
.37584 .62112 .38238 .62387 .39273 .62621 .38621 .62372 Mtetra
0 .467 .778 r
.38621 .62372 .39273 .62621 .40315 .62876 .39665 .62656 Mtetra
0 .423 .724 r
.39665 .62656 .40315 .62876 .41365 .6315 .40715 .62959 Mtetra
.211 0 0 r
.40715 .62959 .41365 .6315 .42421 .63438 .41774 .63279 Mtetra
.258 0 0 r
.41774 .63279 .42421 .63438 .43485 .63737 .4284 .6361 Mtetra
.296 0 0 r
.4284 .6361 .43485 .63737 .44558 .64042 .43914 .63947 Mtetra
.325 0 0 r
.43914 .63947 .44558 .64042 .45638 .64348 .44997 .64286 Mtetra
.347 0 0 r
.44997 .64286 .45638 .64348 .46727 .64648 .46089 .64621 Mtetra
.361 0 0 r
.46089 .64621 .46727 .64648 .47825 .64937 .4719 .64944 Mtetra
.367 0 0 r
.4719 .64944 .47825 .64937 .48931 .65209 .48299 .65249 Mtetra
.366 0 0 r
.48299 .65249 .48931 .65209 .50045 .65457 .49417 .65531 Mtetra
.359 0 0 r
.49417 .65531 .50045 .65457 .51168 .65676 .50544 .65781 Mtetra
.346 0 0 r
.50544 .65781 .51168 .65676 .52299 .65857 .51679 .65993 Mtetra
.326 0 0 r
.51679 .65993 .52299 .65857 .53438 .65997 .52823 .66161 Mtetra
.3 0 0 r
.52823 .66161 .53438 .65997 .54585 .66088 .53975 .66279 Mtetra
.268 0 0 r
.53975 .66279 .54585 .66088 .55738 .66126 .55133 .66341 Mtetra
.229 0 0 r
.55133 .66341 .55738 .66126 .56898 .66105 .56299 .66342 Mtetra
.184 0 0 r
.56299 .66342 .56898 .66105 .58064 .66023 .57471 .66278 Mtetra
.132 0 0 r
.57471 .66278 .58064 .66023 .59235 .65874 .58648 .66144 Mtetra
.074 0 0 r
.58648 .66144 .59235 .65874 .60411 .65658 .5983 .65939 Mtetra
.01 0 0 r
.5983 .65939 .60411 .65658 .6159 .65371 .61016 .65659 Mtetra
0 0 0 r
.61016 .65659 .6159 .65371 .62773 .65014 .62206 .65305 Mtetra
.62206 .65305 .62773 .65014 .63959 .64586 .63398 .64877 Mtetra
.63398 .64877 .63959 .64586 .65146 .64089 .64592 .64374 Mtetra
.64592 .64374 .65146 .64089 .66335 .63525 .65788 .638 Mtetra
.358 .801 .648 r
.65788 .638 .66335 .63525 .67524 .62895 .66984 .63157 Mtetra
.43 .847 .683 r
.66984 .63157 .67524 .62895 .68714 .62205 .6818 .62449 Mtetra
.498 .887 .715 r
.6818 .62449 .68714 .62205 .69903 .61457 .69376 .6168 Mtetra
.56 .921 .743 r
.69376 .6168 .69903 .61457 .71092 .60657 .70571 .60855 Mtetra
.616 .947 .769 r
.70571 .60855 .71092 .60657 .7228 .59809 .71765 .59979 Mtetra
.664 .968 .791 r
.71765 .59979 .7228 .59809 .73468 .5892 .72958 .59059 Mtetra
.706 .983 .81 r
.72958 .59059 .73468 .5892 .74654 .57996 .7415 .58102 Mtetra
.74 .992 .826 r
.7415 .58102 .74654 .57996 .7584 .57042 .75341 .57112 Mtetra
.769 .997 .84 r
.75341 .57112 .7584 .57042 .77024 .56066 .7653 .56098 Mtetra
.791 .998 .851 r
.7653 .56098 .77024 .56066 .78209 .55072 .77719 .55065 Mtetra
.808 .996 .861 r
.77719 .55065 .78209 .55072 .79393 .54067 .78907 .5402 Mtetra
.821 .991 .869 r
.78907 .5402 .79393 .54067 .80577 .53056 .80095 .52969 Mtetra
.829 .985 .876 r
.80095 .52969 .80577 .53056 .81761 .52046 .81284 .51918 Mtetra
.835 .976 .882 r
.81284 .51918 .81761 .52046 .82947 .51041 .82473 .50872 Mtetra
.837 .967 .887 r
.82473 .50872 .82947 .51041 .84134 .50045 .83663 .49837 Mtetra
.837 .956 .891 r
.83663 .49837 .84134 .50045 .85323 .49064 .84855 .48816 Mtetra
.834 .945 .895 r
.84855 .48816 .85323 .49064 .86515 .481 .8605 .47813 Mtetra
.83 .933 .898 r
.8605 .47813 .86515 .481 .8771 .47158 .87247 .46833 Mtetra
.825 .922 .9 r
.87247 .46833 .8771 .47158 .88909 .46238 .88448 .45877 Mtetra
.818 .91 .902 r
.88448 .45877 .88909 .46238 .90112 .45344 .89654 .44949 Mtetra
.81 .898 .904 r
.89654 .44949 .90112 .45344 .91319 .44477 .90863 .44049 Mtetra
.802 .886 .906 r
.90863 .44049 .91319 .44477 .92532 .43639 .92079 .43179 Mtetra
.793 .874 .907 r
.92079 .43179 .92532 .43639 .9375 .42829 .93299 .4234 Mtetra
.784 .863 .908 r
.93299 .4234 .9375 .42829 .94975 .42048 .94526 .41531 Mtetra
.026 .538 .868 r
.35894 .61558 .36554 .61878 .37584 .62112 .36926 .61816 Mtetra
0 .496 .825 r
.36926 .61816 .37584 .62112 .38621 .62372 .37964 .62101 Mtetra
0 .453 .777 r
.37964 .62101 .38621 .62372 .39665 .62656 .39008 .62411 Mtetra
0 .41 .726 r
.39008 .62411 .39665 .62656 .40715 .62959 .40061 .62742 Mtetra
0 .37 .675 r
.40061 .62742 .40715 .62959 .41774 .63279 .41121 .6309 Mtetra
.263 0 0 r
.41121 .6309 .41774 .63279 .4284 .6361 .42189 .63451 Mtetra
.3 0 0 r
.42189 .63451 .4284 .6361 .43914 .63947 .43265 .6382 Mtetra
.328 0 0 r
.43265 .6382 .43914 .63947 .44997 .64286 .4435 .64191 Mtetra
.349 0 0 r
.4435 .64191 .44997 .64286 .46089 .64621 .45445 .64557 Mtetra
.361 0 0 r
.45445 .64557 .46089 .64621 .4719 .64944 .46548 .64912 Mtetra
.366 0 0 r
.46548 .64912 .4719 .64944 .48299 .65249 .4766 .6525 Mtetra
.364 0 0 r
.4766 .6525 .48299 .65249 .49417 .65531 .48782 .65562 Mtetra
.355 0 0 r
.48782 .65562 .49417 .65531 .50544 .65781 .49913 .65843 Mtetra
.339 0 0 r
.49913 .65843 .50544 .65781 .51679 .65993 .51052 .66085 Mtetra
.317 0 0 r
.51052 .66085 .51679 .65993 .52823 .66161 .522 .66281 Mtetra
.287 0 0 r
.522 .66281 .52823 .66161 .53975 .66279 .53357 .66425 Mtetra
.251 0 0 r
.53357 .66425 .53975 .66279 .55133 .66341 .54521 .66511 Mtetra
.207 0 0 r
.54521 .66511 .55133 .66341 .56299 .66342 .55692 .66533 Mtetra
.156 0 0 r
.55692 .66533 .56299 .66342 .57471 .66278 .56869 .66486 Mtetra
.099 0 0 r
.56869 .66486 .57471 .66278 .58648 .66144 .58052 .66367 Mtetra
.034 0 0 r
.58052 .66367 .58648 .66144 .5983 .65939 .59241 .66173 Mtetra
0 0 0 r
.59241 .66173 .5983 .65939 .61016 .65659 .60433 .65901 Mtetra
.60433 .65901 .61016 .65659 .62206 .65305 .6163 .65551 Mtetra
.6163 .65551 .62206 .65305 .63398 .64877 .62829 .65122 Mtetra
.62829 .65122 .63398 .64877 .64592 .64374 .64029 .64615 Mtetra
.348 .804 .679 r
.64029 .64615 .64592 .64374 .65788 .638 .65232 .64032 Mtetra
.423 .85 .711 r
.65232 .64032 .65788 .638 .66984 .63157 .66434 .63377 Mtetra
.494 .89 .739 r
.66434 .63377 .66984 .63157 .6818 .62449 .67637 .62653 Mtetra
.558 .924 .764 r
.67637 .62653 .6818 .62449 .69376 .6168 .68839 .61863 Mtetra
.615 .95 .786 r
.68839 .61863 .69376 .6168 .70571 .60855 .70041 .61015 Mtetra
.665 .97 .804 r
.70041 .61015 .70571 .60855 .71765 .59979 .71241 .60113 Mtetra
.708 .984 .819 r
.71241 .60113 .71765 .59979 .72958 .59059 .7244 .59164 Mtetra
.743 .993 .831 r
.7244 .59164 .72958 .59059 .7415 .58102 .73638 .58175 Mtetra
.772 .997 .841 r
.73638 .58175 .7415 .58102 .75341 .57112 .74834 .57151 Mtetra
.795 .998 .85 r
.74834 .57151 .75341 .57112 .7653 .56098 .76028 .56101 Mtetra
.813 .996 .857 r
.76028 .56101 .7653 .56098 .77719 .55065 .77222 .55031 Mtetra
.827 .992 .863 r
.77222 .55031 .77719 .55065 .78907 .5402 .78414 .53948 Mtetra
.836 .986 .869 r
.78414 .53948 .78907 .5402 .80095 .52969 .79607 .52858 Mtetra
.843 .978 .873 r
.79607 .52858 .80095 .52969 .81284 .51918 .80799 .51767 Mtetra
.846 .97 .877 r
.80799 .51767 .81284 .51918 .82473 .50872 .81992 .50682 Mtetra
.847 .96 .881 r
.81992 .50682 .82473 .50872 .83663 .49837 .83185 .49608 Mtetra
.845 .95 .885 r
.83185 .49608 .83663 .49837 .84855 .48816 .8438 .48548 Mtetra
.842 .939 .888 r
.8438 .48548 .84855 .48816 .8605 .47813 .85578 .47509 Mtetra
.837 .928 .891 r
.85578 .47509 .8605 .47813 .87247 .46833 .86778 .46492 Mtetra
.831 .917 .894 r
.86778 .46492 .87247 .46833 .88448 .45877 .87982 .45501 Mtetra
.824 .906 .896 r
.87982 .45501 .88448 .45877 .89654 .44949 .8919 .44539 Mtetra
.816 .894 .898 r
.8919 .44539 .89654 .44949 .90863 .44049 .90402 .43607 Mtetra
.808 .883 .9 r
.90402 .43607 .90863 .44049 .92079 .43179 .9162 .42707 Mtetra
.799 .872 .902 r
.9162 .42707 .92079 .43179 .93299 .4234 .92843 .41839 Mtetra
.79 .861 .903 r
.92843 .41839 .93299 .4234 .94526 .41531 .94072 .41004 Mtetra
.019 .526 .868 r
.3523 .61215 .35894 .61558 .36926 .61816 .36262 .61494 Mtetra
0 .486 .828 r
.36262 .61494 .36926 .61816 .37964 .62101 .37301 .61802 Mtetra
0 .444 .783 r
.37301 .61802 .37964 .62101 .39008 .62411 .38347 .62136 Mtetra
0 .403 .736 r
.38347 .62136 .39008 .62411 .40061 .62742 .39401 .62493 Mtetra
0 .365 .688 r
.39401 .62493 .40061 .62742 .41121 .6309 .40462 .62868 Mtetra
.26 0 0 r
.40462 .62868 .41121 .6309 .42189 .63451 .41532 .63256 Mtetra
.296 0 0 r
.41532 .63256 .42189 .63451 .43265 .6382 .4261 .63654 Mtetra
.322 0 0 r
.4261 .63654 .43265 .6382 .4435 .64191 .43698 .64054 Mtetra
.341 0 0 r
.43698 .64054 .4435 .64191 .45445 .64557 .44794 .64449 Mtetra
.353 0 0 r
.44794 .64449 .45445 .64557 .46548 .64912 .459 .64835 Mtetra
.356 0 0 r
.459 .64835 .46548 .64912 .4766 .6525 .47015 .65202 Mtetra
.352 0 0 r
.47015 .65202 .4766 .6525 .48782 .65562 .4814 .65544 Mtetra
.341 0 0 r
.4814 .65544 .48782 .65562 .49913 .65843 .49275 .65854 Mtetra
.323 0 0 r
.49275 .65854 .49913 .65843 .51052 .66085 .50418 .66124 Mtetra
.297 0 0 r
.50418 .66124 .51052 .66085 .522 .66281 .5157 .66346 Mtetra
.263 0 0 r
.5157 .66346 .522 .66281 .53357 .66425 .52731 .66515 Mtetra
.222 0 0 r
.52731 .66515 .53357 .66425 .54521 .66511 .539 .66623 Mtetra
.173 0 0 r
.539 .66623 .54521 .66511 .55692 .66533 .55076 .66665 Mtetra
.115 0 0 r
.55076 .66665 .55692 .66533 .56869 .66486 .56259 .66636 Mtetra
.05 0 0 r
.56259 .66636 .56869 .66486 .58052 .66367 .57449 .66531 Mtetra
0 0 0 r
.57449 .66531 .58052 .66367 .59241 .66173 .58643 .66348 Mtetra
.58643 .66348 .59241 .66173 .60433 .65901 .59842 .66084 Mtetra
.59842 .66084 .60433 .65901 .6163 .65551 .61044 .65738 Mtetra
.263 .759 .695 r
.61044 .65738 .6163 .65551 .62829 .65122 .6225 .65309 Mtetra
.344 .812 .727 r
.6225 .65309 .62829 .65122 .64029 .64615 .63457 .64799 Mtetra
.423 .859 .755 r
.63457 .64799 .64029 .64615 .65232 .64032 .64666 .64209 Mtetra
.496 .899 .78 r
.64666 .64209 .65232 .64032 .66434 .63377 .65876 .63543 Mtetra
.562 .931 .8 r
.65876 .63543 .66434 .63377 .67637 .62653 .67085 .62804 Mtetra
.62 .956 .816 r
.67085 .62804 .67637 .62653 .68839 .61863 .68294 .61997 Mtetra
.671 .974 .828 r
.68294 .61997 .68839 .61863 .70041 .61015 .69502 .61127 Mtetra
.713 .987 .838 r
.69502 .61127 .70041 .61015 .71241 .60113 .70708 .60201 Mtetra
.749 .994 .845 r
.70708 .60201 .71241 .60113 .7244 .59164 .71913 .59224 Mtetra
.778 .997 .851 r
.71913 .59224 .7244 .59164 .73638 .58175 .73116 .58205 Mtetra
.801 .997 .855 r
.73116 .58205 .73638 .58175 .74834 .57151 .74318 .5715 Mtetra
.819 .995 .859 r
.74318 .5715 .74834 .57151 .76028 .56101 .75518 .56066 Mtetra
.833 .99 .862 r
.75518 .56066 .76028 .56101 .77222 .55031 .76716 .5496 Mtetra
.843 .984 .865 r
.76716 .5496 .77222 .55031 .78414 .53948 .77913 .53841 Mtetra
.85 .977 .868 r
.77913 .53841 .78414 .53948 .79607 .52858 .7911 .52714 Mtetra
.854 .969 .871 r
.7911 .52714 .79607 .52858 .80799 .51767 .80306 .51586 Mtetra
.856 .96 .873 r
.80306 .51586 .80799 .51767 .81992 .50682 .81503 .50464 Mtetra
.855 .951 .876 r
.81503 .50464 .81992 .50682 .83185 .49608 .827 .49352 Mtetra
.853 .941 .879 r
.827 .49352 .83185 .49608 .8438 .48548 .83899 .48257 Mtetra
.849 .931 .881 r
.83899 .48257 .8438 .48548 .85578 .47509 .85099 .47181 Mtetra
.843 .921 .884 r
.85099 .47181 .85578 .47509 .86778 .46492 .86303 .4613 Mtetra
.837 .91 .887 r
.86303 .4613 .86778 .46492 .87982 .45501 .8751 .45106 Mtetra
.83 .9 .889 r
.8751 .45106 .87982 .45501 .8919 .44539 .8872 .44111 Mtetra
.821 .889 .892 r
.8872 .44111 .8919 .44539 .90402 .43607 .89935 .43149 Mtetra
.813 .879 .894 r
.89935 .43149 .90402 .43607 .9162 .42707 .91155 .42219 Mtetra
.803 .869 .896 r
.91155 .42219 .9162 .42707 .92843 .41839 .92381 .41324 Mtetra
.794 .859 .898 r
.92381 .41324 .92843 .41839 .94072 .41004 .93613 .40462 Mtetra
.02 .519 .871 r
.3456 .60846 .3523 .61215 .36262 .61494 .35594 .61144 Mtetra
0 .48 .834 r
.35594 .61144 .36262 .61494 .37301 .61802 .36634 .61472 Mtetra
0 .44 .793 r
.36634 .61472 .37301 .61802 .38347 .62136 .37681 .61828 Mtetra
0 .402 .751 r
.37681 .61828 .38347 .62136 .39401 .62493 .38736 .62207 Mtetra
0 .367 .708 r
.38736 .62207 .39401 .62493 .40462 .62868 .39799 .62606 Mtetra
0 .335 .667 r
.39799 .62606 .40462 .62868 .41532 .63256 .4087 .63019 Mtetra
.282 0 0 r
.4087 .63019 .41532 .63256 .4261 .63654 .4195 .63442 Mtetra
.307 0 0 r
.4195 .63442 .4261 .63654 .43698 .64054 .43039 .63869 Mtetra
.325 0 0 r
.43039 .63869 .43698 .64054 .44794 .64449 .44138 .64291 Mtetra
.334 0 0 r
.44138 .64291 .44794 .64449 .459 .64835 .45246 .64704 Mtetra
.336 0 0 r
.45246 .64704 .459 .64835 .47015 .65202 .46364 .65098 Mtetra
.33 0 0 r
.46364 .65098 .47015 .65202 .4814 .65544 .47492 .65467 Mtetra
.316 0 0 r
.47492 .65467 .4814 .65544 .49275 .65854 .4863 .65803 Mtetra
.294 0 0 r
.4863 .65803 .49275 .65854 .50418 .66124 .49777 .66099 Mtetra
.264 0 0 r
.49777 .66099 .50418 .66124 .5157 .66346 .50933 .66346 Mtetra
.226 0 0 r
.50933 .66346 .5157 .66346 .52731 .66515 .52098 .66537 Mtetra
.179 0 0 r
.52098 .66537 .52731 .66515 .539 .66623 .53272 .66667 Mtetra
.123 0 0 r
.53272 .66667 .539 .66623 .55076 .66665 .54453 .66728 Mtetra
.058 0 0 r
.54453 .66728 .55076 .66665 .56259 .66636 .55641 .66715 Mtetra
0 0 0 r
.55641 .66715 .56259 .66636 .57449 .66531 .56836 .66625 Mtetra
.56836 .66625 .57449 .66531 .58643 .66348 .58036 .66453 Mtetra
.177 .709 .726 r
.58036 .66453 .58643 .66348 .59842 .66084 .59241 .66197 Mtetra
.262 .768 .759 r
.59241 .66197 .59842 .66084 .61044 .65738 .6045 .65855 Mtetra
.347 .822 .788 r
.6045 .65855 .61044 .65738 .6225 .65309 .61662 .65427 Mtetra
.428 .869 .812 r
.61662 .65427 .6225 .65309 .63457 .64799 .62876 .64915 Mtetra
.502 .908 .831 r
.62876 .64915 .63457 .64799 .64666 .64209 .64091 .64319 Mtetra
.57 .939 .846 r
.64091 .64319 .64666 .64209 .65876 .63543 .65307 .63644 Mtetra
.628 .962 .856 r
.65307 .63644 .65876 .63543 .67085 .62804 .66523 .62892 Mtetra
.679 .978 .862 r
.66523 .62892 .67085 .62804 .68294 .61997 .67738 .62068 Mtetra
.721 .988 .865 r
.67738 .62068 .68294 .61997 .69502 .61127 .68953 .61179 Mtetra
.756 .994 .867 r
.68953 .61179 .69502 .61127 .70708 .60201 .70165 .6023 Mtetra
.785 .996 .867 r
.70165 .6023 .70708 .60201 .71913 .59224 .71376 .59229 Mtetra
.807 .994 .867 r
.71376 .59229 .71913 .59224 .73116 .58205 .72585 .58182 Mtetra
.825 .991 .866 r
.72585 .58182 .73116 .58205 .74318 .5715 .73792 .57098 Mtetra
.839 .986 .866 r
.73792 .57098 .74318 .5715 .75518 .56066 .74998 .55983 Mtetra
.849 .98 .866 r
.74998 .55983 .75518 .56066 .76716 .5496 .76201 .54845 Mtetra
.856 .973 .866 r
.76201 .54845 .76716 .5496 .77913 .53841 .77403 .53692 Mtetra
.861 .965 .866 r
.77403 .53692 .77913 .53841 .7911 .52714 .78604 .52531 Mtetra
.863 .957 .867 r
.78604 .52531 .7911 .52714 .80306 .51586 .79805 .51368 Mtetra
.863 .949 .869 r
.79805 .51368 .80306 .51586 .81503 .50464 .81006 .50211 Mtetra
.861 .94 .87 r
.81006 .50211 .81503 .50464 .827 .49352 .82207 .49065 Mtetra
.858 .931 .873 r
.82207 .49065 .827 .49352 .83899 .48257 .83409 .47935 Mtetra
.854 .921 .875 r
.83409 .47935 .83899 .48257 .85099 .47181 .84613 .46826 Mtetra
.848 .912 .877 r
.84613 .46826 .85099 .47181 .86303 .4613 .8582 .45742 Mtetra
.841 .902 .88 r
.8582 .45742 .86303 .4613 .8751 .45106 .8703 .44686 Mtetra
.834 .893 .883 r
.8703 .44686 .8751 .45106 .8872 .44111 .88244 .43661 Mtetra
.825 .883 .885 r
.88244 .43661 .8872 .44111 .89935 .43149 .89462 .4267 Mtetra
.817 .874 .888 r
.89462 .4267 .89935 .43149 .91155 .42219 .90685 .41713 Mtetra
.807 .864 .89 r
.90685 .41713 .91155 .42219 .92381 .41324 .91913 .40791 Mtetra
.798 .855 .893 r
.91913 .40791 .92381 .41324 .93613 .40462 .93148 .39905 Mtetra
.027 .514 .877 r
.33886 .60448 .3456 .60846 .35594 .61144 .34921 .60762 Mtetra
0 .477 .844 r
.34921 .60762 .35594 .61144 .36634 .61472 .35962 .61108 Mtetra
0 .441 .808 r
.35962 .61108 .36634 .61472 .37681 .61828 .37011 .61482 Mtetra
0 .405 .77 r
.37011 .61482 .37681 .61828 .38736 .62207 .38067 .6188 Mtetra
0 .373 .733 r
.38067 .6188 .38736 .62207 .39799 .62606 .39131 .623 Mtetra
0 .345 .698 r
.39131 .623 .39799 .62606 .4087 .63019 .40203 .62735 Mtetra
0 .322 .666 r
.40203 .62735 .4087 .63019 .4195 .63442 .41285 .6318 Mtetra
.282 0 0 r
.41285 .6318 .4195 .63442 .43039 .63869 .42376 .6363 Mtetra
.297 0 0 r
.42376 .6363 .43039 .63869 .44138 .64291 .43477 .64076 Mtetra
.305 0 0 r
.43477 .64076 .44138 .64291 .45246 .64704 .44587 .64512 Mtetra
.304 0 0 r
.44587 .64512 .45246 .64704 .46364 .65098 .45708 .64931 Mtetra
.295 0 0 r
.45708 .64931 .46364 .65098 .47492 .65467 .46838 .65324 Mtetra
.278 0 0 r
.46838 .65324 .47492 .65467 .4863 .65803 .47979 .65684 Mtetra
.252 0 0 r
.47979 .65684 .4863 .65803 .49777 .66099 .49129 .66002 Mtetra
.217 0 0 r
.49129 .66002 .49777 .66099 .50933 .66346 .50289 .66271 Mtetra
.173 0 0 r
.50289 .66271 .50933 .66346 .52098 .66537 .51459 .66483 Mtetra
.119 0 0 r
.51459 .66483 .52098 .66537 .53272 .66667 .52636 .66632 Mtetra
.056 0 0 r
.52636 .66632 .53272 .66667 .54453 .66728 .53822 .66711 Mtetra
.016 .59 .729 r
.53822 .66711 .54453 .66728 .55641 .66715 .55016 .66714 Mtetra
.095 .652 .764 r
.55016 .66714 .55641 .66715 .56836 .66625 .56215 .66637 Mtetra
.18 .715 .797 r
.56215 .66637 .56836 .66625 .58036 .66453 .57421 .66475 Mtetra
.267 .774 .828 r
.57421 .66475 .58036 .66453 .59241 .66197 .58632 .66227 Mtetra
.352 .828 .854 r
.58632 .66227 .59241 .66197 .6045 .65855 .59847 .6589 Mtetra
.435 .874 .874 r
.59847 .6589 .6045 .65855 .61662 .65427 .61065 .65465 Mtetra
.51 .912 .888 r
.61065 .65465 .61662 .65427 .62876 .64915 .62285 .64951 Mtetra
.578 .941 .897 r
.62285 .64951 .62876 .64915 .64091 .64319 .63507 .6435 Mtetra
.636 .963 .9 r
.63507 .6435 .64091 .64319 .65307 .63644 .64729 .63667 Mtetra
.686 .977 .9 r
.64729 .63667 .65307 .63644 .66523 .62892 .65951 .62904 Mtetra
.728 .985 .897 r
.65951 .62904 .66523 .62892 .67738 .62068 .67173 .62067 Mtetra
.762 .989 .893 r
.67173 .62067 .67738 .62068 .68953 .61179 .68394 .61161 Mtetra
.79 .989 .888 r
.68394 .61161 .68953 .61179 .70165 .6023 .69613 .60192 Mtetra
.812 .987 .882 r
.69613 .60192 .70165 .6023 .71376 .59229 .7083 .59169 Mtetra
.83 .983 .877 r
.7083 .59169 .71376 .59229 .72585 .58182 .72045 .58098 Mtetra
.843 .978 .873 r
.72045 .58098 .72585 .58182 .73792 .57098 .73257 .56987 Mtetra
.853 .972 .869 r
.73257 .56987 .73792 .57098 .74998 .55983 .74468 .55844 Mtetra
.861 .965 .867 r
.74468 .55844 .74998 .55983 .76201 .54845 .75677 .54676 Mtetra
.865 .958 .865 r
.75677 .54676 .76201 .54845 .77403 .53692 .76884 .53493 Mtetra
.868 .95 .864 r
.76884 .53493 .77403 .53692 .78604 .52531 .7809 .52301 Mtetra
.869 .942 .863 r
.7809 .52301 .78604 .52531 .79805 .51368 .79295 .51106 Mtetra
.868 .934 .864 r
.79295 .51106 .79805 .51368 .81006 .50211 .805 .49917 Mtetra
.866 .926 .865 r
.805 .49917 .81006 .50211 .82207 .49065 .81705 .48739 Mtetra
.862 .918 .866 r
.81705 .48739 .82207 .49065 .83409 .47935 .82912 .47578 Mtetra
.857 .91 .868 r
.82912 .47578 .83409 .47935 .84613 .46826 .8412 .46438 Mtetra
.851 .901 .871 r
.8412 .46438 .84613 .46826 .8582 .45742 .8533 .45323 Mtetra
.844 .893 .873 r
.8533 .45323 .8582 .45742 .8703 .44686 .86543 .44238 Mtetra
.837 .884 .876 r
.86543 .44238 .8703 .44686 .88244 .43661 .8776 .43186 Mtetra
.828 .876 .879 r
.8776 .43186 .88244 .43661 .89462 .4267 .88982 .42167 Mtetra
.82 .867 .882 r
.88982 .42167 .89462 .4267 .90685 .41713 .90208 .41185 Mtetra
.81 .859 .885 r
.90208 .41185 .90685 .41713 .91913 .40791 .9144 .40239 Mtetra
.801 .85 .887 r
.9144 .40239 .91913 .40791 .93148 .39905 .92677 .3933 Mtetra
.04 .513 .885 r
.33209 .60019 .33886 .60448 .34921 .60762 .34244 .60346 Mtetra
0 .479 .856 r
.34244 .60346 .34921 .60762 .35962 .61108 .35286 .60706 Mtetra
0 .445 .825 r
.35286 .60706 .35962 .61108 .37011 .61482 .36336 .61095 Mtetra
0 .412 .793 r
.36336 .61095 .37011 .61482 .38067 .6188 .37393 .61509 Mtetra
0 .383 .762 r
.37393 .61509 .38067 .6188 .39131 .623 .38458 .61946 Mtetra
0 .359 .733 r
.38458 .61946 .39131 .623 .40203 .62735 .39532 .62399 Mtetra
0 .339 .707 r
.39532 .62399 .40203 .62735 .41285 .6318 .40615 .62863 Mtetra
0 .326 .686 r
.40615 .62863 .41285 .6318 .42376 .6363 .41708 .63331 Mtetra
0 .319 .67 r
.41708 .63331 .42376 .6363 .43477 .64076 .4281 .63798 Mtetra
0 .319 .66 r
.4281 .63798 .43477 .64076 .44587 .64512 .43923 .64254 Mtetra
.259 0 0 r
.43923 .64254 .44587 .64512 .45708 .64931 .45046 .64693 Mtetra
.247 0 0 r
.45046 .64693 .45708 .64931 .46838 .65324 .46179 .65107 Mtetra
.225 0 0 r
.46179 .65107 .46838 .65324 .47979 .65684 .47322 .65487 Mtetra
0 .395 .684 r
.47322 .65487 .47979 .65684 .49129 .66002 .48476 .65825 Mtetra
0 .434 .706 r
.48476 .65825 .49129 .66002 .50289 .66271 .49639 .66113 Mtetra
0 .48 .733 r
.49639 .66113 .50289 .66271 .51459 .66483 .50812 .66344 Mtetra
0 .532 .764 r
.50812 .66344 .51459 .66483 .52636 .66632 .51994 .6651 Mtetra
.027 .59 .797 r
.51994 .6651 .52636 .66632 .53822 .66711 .53184 .66604 Mtetra
.104 .65 .831 r
.53184 .66604 .53822 .66711 .55016 .66714 .54382 .66622 Mtetra
.187 .711 .864 r
.54382 .66622 .55016 .66714 .56215 .66637 .55587 .66557 Mtetra
.273 .769 .892 r
.55587 .66557 .56215 .66637 .57421 .66475 .56798 .66405 Mtetra
.358 .822 .915 r
.56798 .66405 .57421 .66475 .58632 .66227 .58014 .66165 Mtetra
.44 .867 .931 r
.58014 .66165 .58632 .66227 .59847 .6589 .59234 .65833 Mtetra
.515 .904 .941 r
.59234 .65833 .59847 .6589 .61065 .65465 .60458 .6541 Mtetra
.582 .932 .944 r
.60458 .6541 .61065 .65465 .62285 .64951 .61684 .64895 Mtetra
.64 .952 .942 r
.61684 .64895 .62285 .64951 .63507 .6435 .62912 .64292 Mtetra
.689 .965 .936 r
.62912 .64292 .63507 .6435 .64729 .63667 .64141 .63603 Mtetra
.73 .973 .928 r
.64141 .63603 .64729 .63667 .65951 .62904 .6537 .62831 Mtetra
.764 .976 .918 r
.6537 .62831 .65951 .62904 .67173 .62067 .66598 .61982 Mtetra
.791 .976 .908 r
.66598 .61982 .67173 .62067 .68394 .61161 .67824 .61061 Mtetra
.813 .974 .899 r
.67824 .61061 .68394 .61161 .69613 .60192 .6905 .60076 Mtetra
.831 .97 .89 r
.6905 .60076 .69613 .60192 .7083 .59169 .70273 .59034 Mtetra
.844 .964 .882 r
.70273 .59034 .7083 .59169 .72045 .58098 .71494 .57942 Mtetra
.854 .959 .875 r
.71494 .57942 .72045 .58098 .73257 .56987 .72712 .56808 Mtetra
.862 .952 .869 r
.72712 .56808 .73257 .56987 .74468 .55844 .73928 .5564 Mtetra
.867 .946 .865 r
.73928 .5564 .74468 .55844 .75677 .54676 .75143 .54447 Mtetra
.87 .939 .862 r
.75143 .54447 .75677 .54676 .76884 .53493 .76355 .53236 Mtetra
.872 .932 .859 r
.76355 .53236 .76884 .53493 .7809 .52301 .77566 .52016 Mtetra
.872 .925 .858 r
.77566 .52016 .7809 .52301 .79295 .51106 .78776 .50794 Mtetra
.87 .918 .858 r
.78776 .50794 .79295 .51106 .805 .49917 .79986 .49576 Mtetra
.867 .911 .858 r
.79986 .49576 .805 .49917 .81705 .48739 .81195 .48369 Mtetra
.863 .904 .86 r
.81195 .48369 .81705 .48739 .82912 .47578 .82406 .4718 Mtetra
.858 .897 .862 r
.82406 .4718 .82912 .47578 .8412 .46438 .83618 .46012 Mtetra
.853 .89 .864 r
.83618 .46012 .8412 .46438 .8533 .45323 .84832 .4487 Mtetra
.846 .882 .867 r
.84832 .4487 .8533 .45323 .86543 .44238 .86049 .43759 Mtetra
.838 .875 .87 r
.86049 .43759 .86543 .44238 .8776 .43186 .8727 .42681 Mtetra
.83 .868 .873 r
.8727 .42681 .8776 .43186 .88982 .42167 .88494 .41638 Mtetra
.821 .86 .876 r
.88494 .41638 .88982 .42167 .90208 .41185 .89724 .40632 Mtetra
.812 .852 .879 r
.89724 .40632 .90208 .41185 .9144 .40239 .90959 .39663 Mtetra
.803 .845 .882 r
.90959 .39663 .9144 .40239 .92677 .3933 .922 .38734 Mtetra
.059 .514 .894 r
.32527 .59556 .33209 .60019 .34244 .60346 .33563 .59893 Mtetra
.007 .483 .869 r
.33563 .59893 .34244 .60346 .35286 .60706 .34606 .60263 Mtetra
0 .452 .843 r
.34606 .60263 .35286 .60706 .36336 .61095 .35657 .60664 Mtetra
0 .423 .817 r
.35657 .60664 .36336 .61095 .37393 .61509 .36715 .61091 Mtetra
0 .397 .791 r
.36715 .61091 .37393 .61509 .38458 .61946 .37782 .6154 Mtetra
0 .376 .769 r
.37782 .6154 .38458 .61946 .39532 .62399 .38857 .62007 Mtetra
0 .36 .749 r
.38857 .62007 .39532 .62399 .40615 .62863 .39941 .62486 Mtetra
0 .35 .734 r
.39941 .62486 .40615 .62863 .41708 .63331 .41036 .62969 Mtetra
0 .346 .725 r
.41036 .62969 .41708 .63331 .4281 .63798 .4214 .63451 Mtetra
0 .35 .721 r
.4214 .63451 .4281 .63798 .43923 .64254 .43254 .63924 Mtetra
0 .361 .723 r
.43254 .63924 .43923 .64254 .45046 .64693 .44379 .6438 Mtetra
0 .379 .731 r
.44379 .6438 .45046 .64693 .46179 .65107 .45514 .6481 Mtetra
0 .406 .746 r
.45514 .6481 .46179 .65107 .47322 .65487 .4666 .65207 Mtetra
0 .44 .766 r
.4666 .65207 .47322 .65487 .48476 .65825 .47816 .65561 Mtetra
0 .481 .792 r
.47816 .65561 .48476 .65825 .49639 .66113 .48983 .65866 Mtetra
0 .529 .821 r
.48983 .65866 .49639 .66113 .50812 .66344 .50159 .66112 Mtetra
.044 .582 .853 r
.50159 .66112 .50812 .66344 .51994 .6651 .51344 .66292 Mtetra
.117 .638 .885 r
.51344 .66292 .51994 .6651 .53184 .66604 .52539 .664 Mtetra
.196 .695 .915 r
.52539 .664 .53184 .66604 .54382 .66622 .53741 .6643 Mtetra
.278 .749 .94 r
.53741 .6643 .54382 .66622 .55587 .66557 .5495 .66376 Mtetra
.36 .8 .96 r
.5495 .66376 .55587 .66557 .56798 .66405 .56166 .66233 Mtetra
.439 .843 .973 r
.56166 .66233 .56798 .66405 .58014 .66165 .57387 .66 Mtetra
.512 .879 .979 r
.57387 .66 .58014 .66165 .59234 .65833 .58613 .65674 Mtetra
.578 .907 .979 r
.58613 .65674 .59234 .65833 .60458 .6541 .59842 .65253 Mtetra
.635 .927 .973 r
.59842 .65253 .60458 .6541 .61684 .64895 .61074 .6474 Mtetra
.684 .94 .963 r
.61074 .6474 .61684 .64895 .62912 .64292 .62308 .64135 Mtetra
.725 .949 .952 r
.62308 .64135 .62912 .64292 .64141 .63603 .63543 .63441 Mtetra
.758 .952 .939 r
.63543 .63441 .64141 .63603 .6537 .62831 .64778 .62662 Mtetra
.786 .953 .926 r
.64778 .62662 .6537 .62831 .66598 .61982 .66012 .61804 Mtetra
.808 .952 .913 r
.66012 .61804 .66598 .61982 .67824 .61061 .67245 .60873 Mtetra
.826 .949 .901 r
.67245 .60873 .67824 .61061 .6905 .60076 .68476 .59874 Mtetra
.84 .945 .89 r
.68476 .59874 .6905 .60076 .70273 .59034 .69705 .58816 Mtetra
.851 .94 .881 r
.69705 .58816 .70273 .59034 .71494 .57942 .70932 .57706 Mtetra
.859 .934 .873 r
.70932 .57706 .71494 .57942 .72712 .56808 .72157 .56553 Mtetra
.865 .929 .866 r
.72157 .56553 .72712 .56808 .73928 .5564 .73379 .55364 Mtetra
.869 .923 .861 r
.73379 .55364 .73928 .5564 .75143 .54447 .74598 .54149 Mtetra
.871 .918 .857 r
.74598 .54149 .75143 .54447 .76355 .53236 .75816 .52915 Mtetra
.872 .912 .854 r
.75816 .52915 .76355 .53236 .77566 .52016 .77032 .51671 Mtetra
.872 .906 .852 r
.77032 .51671 .77566 .52016 .78776 .50794 .78247 .50425 Mtetra
.87 .9 .852 r
.78247 .50425 .78776 .50794 .79986 .49576 .79462 .49182 Mtetra
.867 .895 .852 r
.79462 .49182 .79986 .49576 .81195 .48369 .80676 .47951 Mtetra
.863 .889 .853 r
.80676 .47951 .81195 .48369 .82406 .4718 .81891 .46736 Mtetra
.858 .883 .855 r
.81891 .46736 .82406 .4718 .83618 .46012 .83107 .45544 Mtetra
.852 .877 .857 r
.83107 .45544 .83618 .46012 .84832 .4487 .84326 .44379 Mtetra
.846 .871 .86 r
.84326 .44379 .84832 .4487 .86049 .43759 .85547 .43244 Mtetra
.839 .865 .863 r
.85547 .43244 .86049 .43759 .8727 .42681 .86771 .42143 Mtetra
.831 .858 .866 r
.86771 .42143 .8727 .42681 .88494 .41638 .88 .41078 Mtetra
.822 .852 .87 r
.88 .41078 .88494 .41638 .89724 .40632 .89233 .40051 Mtetra
.813 .845 .873 r
.89233 .40051 .89724 .40632 .90959 .39663 .90472 .39063 Mtetra
.804 .839 .877 r
.90472 .39063 .90959 .39663 .922 .38734 .91717 .38114 Mtetra
.083 .518 .903 r
.31841 .59058 .32527 .59556 .33563 .59893 .32878 .59401 Mtetra
.035 .489 .883 r
.32878 .59401 .33563 .59893 .34606 .60263 .33923 .59778 Mtetra
0 .461 .861 r
.33923 .59778 .34606 .60263 .35657 .60664 .34974 .60186 Mtetra
0 .435 .84 r
.34974 .60186 .35657 .60664 .36715 .61091 .36034 .60622 Mtetra
0 .413 .82 r
.36034 .60622 .36715 .61091 .37782 .6154 .37101 .6108 Mtetra
0 .395 .803 r
.37101 .6108 .37782 .6154 .38857 .62007 .38178 .61557 Mtetra
0 .382 .789 r
.38178 .61557 .38857 .62007 .39941 .62486 .39264 .62045 Mtetra
0 .375 .78 r
.39264 .62045 .39941 .62486 .41036 .62969 .40359 .6254 Mtetra
0 .375 .776 r
.40359 .6254 .41036 .62969 .4214 .63451 .41465 .63033 Mtetra
0 .381 .777 r
.41465 .63033 .4214 .63451 .43254 .63924 .42581 .63518 Mtetra
0 .395 .784 r
.42581 .63518 .43254 .63924 .44379 .6438 .43708 .63985 Mtetra
0 .416 .796 r
.43708 .63985 .44379 .6438 .45514 .6481 .44845 .64428 Mtetra
0 .444 .814 r
.44845 .64428 .45514 .6481 .4666 .65207 .45993 .64837 Mtetra
0 .479 .836 r
.45993 .64837 .4666 .65207 .47816 .65561 .47152 .65205 Mtetra
.009 .52 .862 r
.47152 .65205 .47816 .65561 .48983 .65866 .48321 .65522 Mtetra
.068 .566 .89 r
.48321 .65522 .48983 .65866 .50159 .66112 .495 .6578 Mtetra
.134 .616 .918 r
.495 .6578 .50159 .66112 .51344 .66292 .50689 .65973 Mtetra
.207 .667 .944 r
.50689 .65973 .51344 .66292 .52539 .664 .51887 .66092 Mtetra
.282 .716 .967 r
.51887 .66092 .52539 .664 .53741 .6643 .53093 .66132 Mtetra
.359 .763 .983 r
.53093 .66132 .53741 .6643 .5495 .66376 .54306 .66087 Mtetra
.433 .804 .994 r
.54306 .66087 .5495 .66376 .56166 .66233 .55526 .65953 Mtetra
.502 .838 .998 r
.55526 .65953 .56166 .66233 .57387 .66 .56752 .65726 Mtetra
.565 .866 .996 r
.56752 .65726 .57387 .66 .58613 .65674 .57983 .65404 Mtetra
.621 .887 .989 r
.57983 .65404 .58613 .65674 .59842 .65253 .59218 .64987 Mtetra
.669 .902 .978 r
.59218 .64987 .59842 .65253 .61074 .6474 .60455 .64475 Mtetra
.71 .912 .965 r
.60455 .64475 .61074 .6474 .62308 .64135 .61695 .6387 Mtetra
.744 .918 .951 r
.61695 .6387 .62308 .64135 .63543 .63441 .62935 .63174 Mtetra
.772 .921 .936 r
.62935 .63174 .63543 .63441 .64778 .62662 .64176 .62391 Mtetra
.795 .921 .922 r
.64176 .62391 .64778 .62662 .66012 .61804 .65416 .61526 Mtetra
.814 .92 .908 r
.65416 .61526 .66012 .61804 .67245 .60873 .66655 .60586 Mtetra
.829 .918 .896 r
.66655 .60586 .67245 .60873 .68476 .59874 .67892 .59577 Mtetra
.841 .915 .884 r
.67892 .59577 .68476 .59874 .69705 .58816 .69127 .58507 Mtetra
.851 .911 .875 r
.69127 .58507 .69705 .58816 .70932 .57706 .7036 .57384 Mtetra
.858 .907 .866 r
.7036 .57384 .70932 .57706 .72157 .56553 .7159 .56215 Mtetra
.863 .903 .86 r
.7159 .56215 .72157 .56553 .73379 .55364 .72818 .5501 Mtetra
.867 .899 .854 r
.72818 .5501 .73379 .55364 .74598 .54149 .74044 .53777 Mtetra
.869 .895 .85 r
.74044 .53777 .74598 .54149 .75816 .52915 .75267 .52524 Mtetra
.869 .89 .847 r
.75267 .52524 .75816 .52915 .77032 .51671 .76489 .51261 Mtetra
.869 .886 .845 r
.76489 .51261 .77032 .51671 .78247 .50425 .77709 .49994 Mtetra
.867 .882 .845 r
.77709 .49994 .78247 .50425 .79462 .49182 .78928 .48731 Mtetra
.864 .877 .845 r
.78928 .48731 .79462 .49182 .80676 .47951 .80147 .47478 Mtetra
.861 .873 .846 r
.80147 .47478 .80676 .47951 .81891 .46736 .81367 .46243 Mtetra
.856 .868 .848 r
.81367 .46243 .81891 .46736 .83107 .45544 .82588 .4503 Mtetra
.851 .863 .85 r
.82588 .4503 .83107 .45544 .84326 .44379 .83811 .43844 Mtetra
.845 .859 .853 r
.83811 .43844 .84326 .44379 .85547 .43244 .85036 .4269 Mtetra
.838 .853 .857 r
.85036 .4269 .85547 .43244 .86771 .42143 .86265 .41569 Mtetra
.83 .848 .86 r
.86265 .41569 .86771 .42143 .88 .41078 .87498 .40486 Mtetra
.822 .843 .864 r
.87498 .40486 .88 .41078 .89233 .40051 .88735 .39441 Mtetra
.814 .837 .868 r
.88735 .39441 .89233 .40051 .90472 .39063 .89978 .38436 Mtetra
.805 .832 .872 r
.89978 .38436 .90472 .39063 .91717 .38114 .91227 .37471 Mtetra
.11 .523 .911 r
.31151 .58524 .31841 .59058 .32878 .59401 .3219 .5887 Mtetra
.067 .497 .895 r
.3219 .5887 .32878 .59401 .33923 .59778 .33236 .5925 Mtetra
.027 .472 .878 r
.33236 .5925 .33923 .59778 .34974 .60186 .34289 .59662 Mtetra
0 .449 .861 r
.34289 .59662 .34974 .60186 .36034 .60622 .35349 .60101 Mtetra
0 .43 .846 r
.35349 .60101 .36034 .60622 .37101 .6108 .36418 .60564 Mtetra
0 .415 .834 r
.36418 .60564 .37101 .6108 .38178 .61557 .37496 .61045 Mtetra
0 .405 .825 r
.37496 .61045 .38178 .61557 .39264 .62045 .38583 .6154 Mtetra
0 .401 .82 r
.38583 .6154 .39264 .62045 .40359 .6254 .39679 .6204 Mtetra
0 .402 .82 r
.39679 .6204 .40359 .6254 .41465 .63033 .40786 .6254 Mtetra
0 .411 .824 r
.40786 .6254 .41465 .63033 .42581 .63518 .41904 .63032 Mtetra
0 .426 .834 r
.41904 .63032 .42581 .63518 .43708 .63985 .43032 .63507 Mtetra
0 .447 .847 r
.43032 .63507 .43708 .63985 .44845 .64428 .44172 .63958 Mtetra
0 .475 .865 r
.44172 .63958 .44845 .64428 .45993 .64837 .45322 .64376 Mtetra
.042 .509 .886 r
.45322 .64376 .45993 .64837 .47152 .65205 .46483 .64752 Mtetra
.094 .547 .909 r
.46483 .64752 .47152 .65205 .48321 .65522 .47654 .65077 Mtetra
.153 .589 .932 r
.47654 .65077 .48321 .65522 .495 .6578 .48836 .65345 Mtetra
.217 .632 .954 r
.48836 .65345 .495 .6578 .50689 .65973 .50028 .65546 Mtetra
.285 .676 .972 r
.50028 .65546 .50689 .65973 .51887 .66092 .51229 .65673 Mtetra
.354 .717 .986 r
.51229 .65673 .51887 .66092 .53093 .66132 .52438 .65721 Mtetra
.422 .754 .995 r
.52438 .65721 .53093 .66132 .54306 .66087 .53655 .65684 Mtetra
.486 .787 .998 r
.53655 .65684 .54306 .66087 .55526 .65953 .5488 .65556 Mtetra
.545 .814 .996 r
.5488 .65556 .55526 .65953 .56752 .65726 .5611 .65335 Mtetra
.599 .836 .989 r
.5611 .65335 .56752 .65726 .57983 .65404 .57345 .65019 Mtetra
.646 .853 .979 r
.57345 .65019 .57983 .65404 .59218 .64987 .58585 .64606 Mtetra
.687 .866 .967 r
.58585 .64606 .59218 .64987 .60455 .64475 .59827 .64096 Mtetra
.721 .874 .953 r
.59827 .64096 .60455 .64475 .61695 .6387 .61072 .63491 Mtetra
.751 .88 .938 r
.61072 .63491 .61695 .6387 .62935 .63174 .62318 .62795 Mtetra
.775 .883 .924 r
.62318 .62795 .62935 .63174 .64176 .62391 .63564 .6201 Mtetra
.796 .885 .91 r
.63564 .6201 .64176 .62391 .65416 .61526 .6481 .61141 Mtetra
.812 .885 .897 r
.6481 .61141 .65416 .61526 .66655 .60586 .66055 .60196 Mtetra
.826 .884 .885 r
.66055 .60196 .66655 .60586 .67892 .59577 .67298 .5918 Mtetra
.837 .883 .875 r
.67298 .5918 .67892 .59577 .69127 .58507 .68539 .58102 Mtetra
.846 .881 .866 r
.68539 .58102 .69127 .58507 .7036 .57384 .69778 .56968 Mtetra
.853 .879 .858 r
.69778 .56968 .7036 .57384 .7159 .56215 .71014 .55788 Mtetra
.858 .876 .851 r
.71014 .55788 .7159 .56215 .72818 .5501 .72247 .54571 Mtetra
.861 .874 .846 r
.72247 .54571 .72818 .5501 .74044 .53777 .73479 .53325 Mtetra
.863 .871 .842 r
.73479 .53325 .74044 .53777 .75267 .52524 .74707 .52058 Mtetra
.864 .868 .84 r
.74707 .52058 .75267 .52524 .76489 .51261 .75935 .50779 Mtetra
.864 .865 .838 r
.75935 .50779 .76489 .51261 .77709 .49994 .7716 .49496 Mtetra
.863 .862 .838 r
.7716 .49496 .77709 .49994 .78928 .48731 .78385 .48217 Mtetra
.86 .859 .838 r
.78385 .48217 .78928 .48731 .80147 .47478 .79609 .46949 Mtetra
.857 .856 .839 r
.79609 .46949 .80147 .47478 .81367 .46243 .80834 .45697 Mtetra
.853 .853 .841 r
.80834 .45697 .81367 .46243 .82588 .4503 .8206 .44467 Mtetra
.848 .849 .844 r
.8206 .44467 .82588 .4503 .83811 .43844 .83287 .43265 Mtetra
.842 .846 .847 r
.83287 .43265 .83811 .43844 .85036 .4269 .84517 .42094 Mtetra
.836 .842 .85 r
.84517 .42094 .85036 .4269 .86265 .41569 .85751 .40958 Mtetra
.829 .838 .854 r
.85751 .40958 .86265 .41569 .87498 .40486 .86988 .39859 Mtetra
.821 .834 .858 r
.86988 .39859 .87498 .40486 .88735 .39441 .8823 .38799 Mtetra
.813 .829 .863 r
.8823 .38799 .88735 .39441 .89978 .38436 .89477 .37779 Mtetra
.804 .824 .867 r
.89477 .37779 .89978 .38436 .91227 .37471 .9073 .368 Mtetra
.14 .529 .919 r
.30459 .57952 .31151 .58524 .3219 .5887 .31499 .58297 Mtetra
.102 .505 .905 r
.31499 .58297 .3219 .5887 .33236 .5925 .32546 .58677 Mtetra
.067 .483 .892 r
.32546 .58677 .33236 .5925 .34289 .59662 .336 .59088 Mtetra
.037 .463 .879 r
.336 .59088 .34289 .59662 .35349 .60101 .34661 .59527 Mtetra
.012 .446 .868 r
.34661 .59527 .35349 .60101 .36418 .60564 .35731 .5999 Mtetra
0 .434 .859 r
.35731 .5999 .36418 .60564 .37496 .61045 .3681 .60472 Mtetra
0 .426 .853 r
.3681 .60472 .37496 .61045 .38583 .6154 .37898 .60968 Mtetra
0 .424 .851 r
.37898 .60968 .38583 .6154 .39679 .6204 .38996 .6147 Mtetra
0 .427 .853 r
.38996 .6147 .39679 .6204 .40786 .6254 .40105 .61971 Mtetra
0 .436 .859 r
.40105 .61971 .40786 .6254 .41904 .63032 .41224 .62465 Mtetra
.013 .451 .869 r
.41224 .62465 .41904 .63032 .43032 .63507 .42354 .62943 Mtetra
.041 .472 .882 r
.42354 .62943 .43032 .63507 .44172 .63958 .43494 .63398 Mtetra
.078 .498 .898 r
.43494 .63398 .44172 .63958 .45322 .64376 .44646 .63819 Mtetra
.122 .528 .915 r
.44646 .63819 .45322 .64376 .46483 .64752 .45809 .64199 Mtetra
.172 .562 .933 r
.45809 .64199 .46483 .64752 .47654 .65077 .46983 .6453 Mtetra
.228 .597 .95 r
.46983 .6453 .47654 .65077 .48836 .65345 .48167 .64802 Mtetra
.287 .634 .964 r
.48167 .64802 .48836 .65345 .50028 .65546 .49361 .65008 Mtetra
.348 .669 .975 r
.49361 .65008 .50028 .65546 .51229 .65673 .50565 .65142 Mtetra
.408 .702 .982 r
.50565 .65142 .51229 .65673 .52438 .65721 .51778 .65195 Mtetra
.467 .733 .985 r
.51778 .65195 .52438 .65721 .53655 .65684 .52998 .65163 Mtetra
.522 .759 .983 r
.52998 .65163 .53655 .65684 .5488 .65556 .54226 .65041 Mtetra
.573 .781 .978 r
.54226 .65041 .5488 .65556 .5611 .65335 .5546 .64825 Mtetra
.618 .8 .969 r
.5546 .64825 .5611 .65335 .57345 .65019 .567 .64513 Mtetra
.658 .814 .958 r
.567 .64513 .57345 .65019 .58585 .64606 .57944 .64103 Mtetra
.693 .825 .946 r
.57944 .64103 .58585 .64606 .59827 .64096 .59191 .63596 Mtetra
.724 .834 .933 r
.59191 .63596 .59827 .64096 .61072 .63491 .6044 .62994 Mtetra
.75 .84 .92 r
.6044 .62994 .61072 .63491 .62318 .62795 .61691 .62298 Mtetra
.771 .844 .907 r
.61691 .62298 .62318 .62795 .63564 .6201 .62943 .61514 Mtetra
.79 .847 .894 r
.62943 .61514 .63564 .6201 .6481 .61141 .64194 .60644 Mtetra
.805 .849 .883 r
.64194 .60644 .6481 .61141 .66055 .60196 .65445 .59697 Mtetra
.818 .85 .872 r
.65445 .59697 .66055 .60196 .67298 .5918 .66693 .58678 Mtetra
.829 .851 .863 r
.66693 .58678 .67298 .5918 .68539 .58102 .6794 .57594 Mtetra
.837 .85 .855 r
.6794 .57594 .68539 .58102 .69778 .56968 .69185 .56455 Mtetra
.844 .85 .848 r
.69185 .56455 .69778 .56968 .71014 .55788 .70427 .55269 Mtetra
.849 .849 .842 r
.70427 .55269 .71014 .55788 .72247 .54571 .71666 .54044 Mtetra
.853 .848 .838 r
.71666 .54044 .72247 .54571 .73479 .53325 .72903 .52788 Mtetra
.856 .847 .834 r
.72903 .52788 .73479 .53325 .74707 .52058 .74138 .51512 Mtetra
.857 .846 .832 r
.74138 .51512 .74707 .52058 .75935 .50779 .7537 .50223 Mtetra
.857 .845 .831 r
.7537 .50223 .75935 .50779 .7716 .49496 .76602 .48929 Mtetra
.856 .843 .83 r
.76602 .48929 .7716 .49496 .78385 .48217 .77832 .47639 Mtetra
.855 .841 .831 r
.77832 .47639 .78385 .48217 .79609 .46949 .79061 .46358 Mtetra
.852 .839 .832 r
.79061 .46358 .79609 .46949 .80834 .45697 .80291 .45094 Mtetra
.848 .837 .835 r
.80291 .45094 .80834 .45697 .8206 .44467 .81522 .43852 Mtetra
.844 .835 .837 r
.81522 .43852 .8206 .44467 .83287 .43265 .82755 .42638 Mtetra
.839 .833 .841 r
.82755 .42638 .83287 .43265 .84517 .42094 .8399 .41454 Mtetra
.833 .83 .845 r
.8399 .41454 .84517 .42094 .85751 .40958 .85228 .40306 Mtetra
.826 .827 .849 r
.85228 .40306 .85751 .40958 .86988 .39859 .8647 .39195 Mtetra
.819 .824 .853 r
.8647 .39195 .86988 .39859 .8823 .38799 .87716 .38123 Mtetra
.811 .82 .858 r
.87716 .38123 .8823 .38799 .89477 .37779 .88968 .37092 Mtetra
.803 .817 .862 r
.88968 .37092 .89477 .37779 .9073 .368 .90225 .36102 Mtetra
.171 .535 .924 r
.29763 .57344 .30459 .57952 .31499 .58297 .30804 .57684 Mtetra
.138 .514 .913 r
.30804 .57684 .31499 .58297 .32546 .58677 .31852 .58059 Mtetra
.108 .494 .902 r
.31852 .58059 .32546 .58677 .336 .59088 .32908 .58466 Mtetra
.082 .476 .893 r
.32908 .58466 .336 .59088 .34661 .59527 .33971 .58901 Mtetra
.062 .462 .884 r
.33971 .58901 .34661 .59527 .35731 .5999 .35042 .59359 Mtetra
.048 .451 .878 r
.35042 .59359 .35731 .5999 .3681 .60472 .36122 .59837 Mtetra
.04 .445 .874 r
.36122 .59837 .3681 .60472 .37898 .60968 .37211 .60328 Mtetra
.04 .444 .874 r
.37211 .60328 .37898 .60968 .38996 .6147 .38311 .60827 Mtetra
.047 .448 .877 r
.38311 .60827 .38996 .6147 .40105 .61971 .3942 .61326 Mtetra
.062 .456 .882 r
.3942 .61326 .40105 .61971 .41224 .62465 .4054 .61817 Mtetra
.084 .47 .891 r
.4054 .61817 .41224 .62465 .42354 .62943 .41672 .62293 Mtetra
.113 .489 .901 r
.41672 .62293 .42354 .62943 .43494 .63398 .42814 .62746 Mtetra
.15 .512 .913 r
.42814 .62746 .43494 .63398 .44646 .63819 .43967 .63167 Mtetra
.192 .538 .926 r
.43967 .63167 .44646 .63819 .45809 .64199 .45132 .63547 Mtetra
.239 .566 .938 r
.45132 .63547 .45809 .64199 .46983 .6453 .46307 .63878 Mtetra
.289 .596 .948 r
.46307 .63878 .46983 .6453 .48167 .64802 .47494 .64151 Mtetra
.342 .625 .957 r
.47494 .64151 .48167 .64802 .49361 .65008 .4869 .64359 Mtetra
.396 .654 .962 r
.4869 .64359 .49361 .65008 .50565 .65142 .49896 .64495 Mtetra
.448 .681 .964 r
.49896 .64495 .50565 .65142 .51778 .65195 .51112 .64551 Mtetra
.498 .706 .963 r
.51112 .64551 .51778 .65195 .52998 .65163 .52335 .64523 Mtetra
.545 .727 .959 r
.52335 .64523 .52998 .65163 .54226 .65041 .53566 .64404 Mtetra
.588 .746 .952 r
.53566 .64404 .54226 .65041 .5546 .64825 .54804 .64192 Mtetra
.627 .762 .943 r
.54804 .64192 .5546 .64825 .567 .64513 .56047 .63883 Mtetra
.662 .775 .933 r
.56047 .63883 .567 .64513 .57944 .64103 .57295 .63478 Mtetra
.693 .786 .922 r
.57295 .63478 .57944 .64103 .59191 .63596 .58547 .62975 Mtetra
.72 .795 .91 r
.58547 .62975 .59191 .63596 .6044 .62994 .59801 .62375 Mtetra
.743 .802 .899 r
.59801 .62375 .6044 .62994 .61691 .62298 .61056 .61683 Mtetra
.764 .807 .888 r
.61056 .61683 .61691 .62298 .62943 .61514 .62313 .609 Mtetra
.781 .811 .877 r
.62313 .609 .62943 .61514 .64194 .60644 .63569 .60032 Mtetra
.796 .815 .867 r
.63569 .60032 .64194 .60644 .65445 .59697 .64825 .59086 Mtetra
.808 .817 .858 r
.64825 .59086 .65445 .59697 .66693 .58678 .66079 .58067 Mtetra
.818 .82 .85 r
.66079 .58067 .66693 .58678 .6794 .57594 .67332 .56983 Mtetra
.827 .821 .843 r
.67332 .56983 .6794 .57594 .69185 .56455 .68582 .55842 Mtetra
.834 .822 .837 r
.68582 .55842 .69185 .56455 .70427 .55269 .69829 .54653 Mtetra
.84 .823 .832 r
.69829 .54653 .70427 .55269 .71666 .54044 .71075 .53425 Mtetra
.844 .824 .829 r
.71075 .53425 .71666 .54044 .72903 .52788 .72317 .52166 Mtetra
.847 .824 .826 r
.72317 .52166 .72903 .52788 .74138 .51512 .73558 .50884 Mtetra
.849 .824 .824 r
.73558 .50884 .74138 .51512 .7537 .50223 .74796 .4959 Mtetra
.849 .824 .823 r
.74796 .4959 .7537 .50223 .76602 .48929 .76033 .4829 Mtetra
.76033 .4829 .76602 .48929 .77832 .47639 .77269 .46993 Mtetra
.848 .824 .824 r
.77269 .46993 .77832 .47639 .79061 .46358 .78504 .45705 Mtetra
.846 .823 .826 r
.78504 .45705 .79061 .46358 .80291 .45094 .79739 .44433 Mtetra
.843 .822 .828 r
.79739 .44433 .80291 .45094 .81522 .43852 .80976 .43184 Mtetra
.839 .821 .831 r
.80976 .43184 .81522 .43852 .82755 .42638 .82214 .41961 Mtetra
.834 .82 .835 r
.82214 .41961 .82755 .42638 .8399 .41454 .83454 .40769 Mtetra
.829 .818 .839 r
.83454 .40769 .8399 .41454 .85228 .40306 .84697 .39612 Mtetra
.823 .816 .843 r
.84697 .39612 .85228 .40306 .8647 .39195 .85944 .38493 Mtetra
.816 .814 .848 r
.85944 .38493 .8647 .39195 .87716 .38123 .87195 .37413 Mtetra
.809 .812 .853 r
.87195 .37413 .87716 .38123 .88968 .37092 .88452 .36373 Mtetra
.801 .809 .858 r
.88452 .36373 .88968 .37092 .90225 .36102 .89714 .35375 Mtetra
.203 .542 .928 r
.29064 .56699 .29763 .57344 .30804 .57684 .30107 .57031 Mtetra
.174 .522 .919 r
.30107 .57031 .30804 .57684 .31852 .58059 .31156 .57398 Mtetra
.149 .504 .91 r
.31156 .57398 .31852 .58059 .32908 .58466 .32213 .57796 Mtetra
.127 .489 .902 r
.32213 .57796 .32908 .58466 .33971 .58901 .33277 .58222 Mtetra
.111 .476 .896 r
.33277 .58222 .33971 .58901 .35042 .59359 .3435 .58671 Mtetra
.101 .467 .891 r
.3435 .58671 .35042 .59359 .36122 .59837 .35431 .59141 Mtetra
.097 .461 .888 r
.35431 .59141 .36122 .59837 .37211 .60328 .36522 .59623 Mtetra
.1 .461 .888 r
.36522 .59623 .37211 .60328 .38311 .60827 .37622 .60113 Mtetra
.109 .464 .89 r
.37622 .60113 .38311 .60827 .3942 .61326 .38733 .60604 Mtetra
.125 .472 .894 r
.38733 .60604 .3942 .61326 .4054 .61817 .39855 .61088 Mtetra
.148 .484 .9 r
.39855 .61088 .4054 .61817 .41672 .62293 .40987 .61557 Mtetra
.177 .5 .908 r
.40987 .61557 .41672 .62293 .42814 .62746 .42131 .62004 Mtetra
.212 .519 .916 r
.42131 .62004 .42814 .62746 .43967 .63167 .43285 .62419 Mtetra
.251 .541 .924 r
.43285 .62419 .43967 .63167 .45132 .63547 .44451 .62795 Mtetra
.294 .564 .931 r
.44451 .62795 .45132 .63547 .46307 .63878 .45629 .63122 Mtetra
.339 .588 .936 r
.45629 .63122 .46307 .63878 .47494 .64151 .46817 .63393 Mtetra
.385 .612 .94 r
.46817 .63393 .47494 .64151 .4869 .64359 .48015 .63599 Mtetra
.431 .636 .942 r
.48015 .63599 .4869 .64359 .49896 .64495 .49223 .63734 Mtetra
.476 .658 .941 r
.49223 .63734 .49896 .64495 .51112 .64551 .50441 .6379 Mtetra
.519 .678 .937 r
.50441 .6379 .51112 .64551 .52335 .64523 .51667 .63763 Mtetra
.56 .697 .932 r
.51667 .63763 .52335 .64523 .53566 .64404 .52901 .63646 Mtetra
.597 .713 .925 r
.52901 .63646 .53566 .64404 .54804 .64192 .54141 .63436 Mtetra
.631 .727 .917 r
.54141 .63436 .54804 .64192 .56047 .63883 .55388 .63131 Mtetra
.662 .739 .908 r
.55388 .63131 .56047 .63883 .57295 .63478 .56639 .62729 Mtetra
.689 .75 .898 r
.56639 .62729 .57295 .63478 .58547 .62975 .57895 .6223 Mtetra
.714 .759 .888 r
.57895 .6223 .58547 .62975 .59801 .62375 .59153 .61635 Mtetra
.735 .767 .878 r
.59153 .61635 .59801 .62375 .61056 .61683 .60413 .60946 Mtetra
.754 .773 .869 r
.60413 .60946 .61056 .61683 .62313 .609 .61674 .60168 Mtetra
.77 .778 .86 r
.61674 .60168 .62313 .609 .63569 .60032 .62935 .59305 Mtetra
.784 .783 .852 r
.62935 .59305 .63569 .60032 .64825 .59086 .64196 .58362 Mtetra
.796 .787 .844 r
.64196 .58362 .64825 .59086 .66079 .58067 .65455 .57346 Mtetra
.807 .791 .837 r
.65455 .57346 .66079 .58067 .67332 .56983 .66713 .56266 Mtetra
.816 .794 .832 r
.66713 .56266 .67332 .56983 .68582 .55842 .67969 .55128 Mtetra
.823 .796 .827 r
.67969 .55128 .68582 .55842 .69829 .54653 .69222 .53941 Mtetra
.829 .798 .823 r
.69222 .53941 .69829 .54653 .71075 .53425 .70473 .52713 Mtetra
.833 .8 .82 r
.70473 .52713 .71075 .53425 .72317 .52166 .71722 .51455 Mtetra
.837 .802 .817 r
.71722 .51455 .72317 .52166 .73558 .50884 .72968 .50174 Mtetra
.839 .803 .816 r
.72968 .50174 .73558 .50884 .74796 .4959 .74212 .48878 Mtetra
.841 .805 .816 r
.74212 .48878 .74796 .4959 .76033 .4829 .75455 .47577 Mtetra
.841 .806 .816 r
.75455 .47577 .76033 .4829 .77269 .46993 .76696 .46278 Mtetra
.84 .806 .818 r
.76696 .46278 .77269 .46993 .78504 .45705 .77937 .44988 Mtetra
.839 .807 .82 r
.77937 .44988 .78504 .45705 .79739 .44433 .79178 .43713 Mtetra
.836 .807 .822 r
.79178 .43713 .79739 .44433 .80976 .43184 .8042 .4246 Mtetra
.833 .807 .826 r
.8042 .4246 .80976 .43184 .82214 .41961 .81664 .41233 Mtetra
.829 .807 .83 r
.81664 .41233 .82214 .41961 .83454 .40769 .82909 .40037 Mtetra
.824 .806 .834 r
.82909 .40037 .83454 .40769 .84697 .39612 .84158 .38876 Mtetra
.819 .806 .839 r
.84158 .38876 .84697 .39612 .85944 .38493 .8541 .37752 Mtetra
.813 .804 .843 r
.8541 .37752 .85944 .38493 .87195 .37413 .86667 .36666 Mtetra
.806 .803 .848 r
.86667 .36666 .87195 .37413 .88452 .36373 .87929 .35622 Mtetra
.799 .801 .853 r
.87929 .35622 .88452 .36373 .89714 .35375 .89196 .34618 Mtetra
.235 .549 .93 r
.28361 .56018 .29064 .56699 .30107 .57031 .29406 .56339 Mtetra
.21 .531 .922 r
.29406 .56339 .30107 .57031 .31156 .57398 .30457 .56693 Mtetra
.189 .514 .915 r
.30457 .56693 .31156 .57398 .32213 .57796 .31515 .57079 Mtetra
.171 .5 .908 r
.31515 .57079 .32213 .57796 .33277 .58222 .32581 .57492 Mtetra
.159 .489 .902 r
.32581 .57492 .33277 .58222 .3435 .58671 .33655 .57928 Mtetra
.152 .48 .898 r
.33655 .57928 .3435 .58671 .35431 .59141 .34738 .58384 Mtetra
.15 .475 .896 r
.34738 .58384 .35431 .59141 .36522 .59623 .3583 .58854 Mtetra
.155 .474 .895 r
.3583 .58854 .36522 .59623 .37622 .60113 .36932 .59331 Mtetra
.166 .477 .896 r
.36932 .59331 .37622 .60113 .38733 .60604 .38044 .59809 Mtetra
.183 .484 .898 r
.38044 .59809 .38733 .60604 .39855 .61088 .39166 .60281 Mtetra
.205 .494 .902 r
.39166 .60281 .39855 .61088 .40987 .61557 .403 .60738 Mtetra
.232 .507 .906 r
.403 .60738 .40987 .61557 .42131 .62004 .41445 .61174 Mtetra
.264 .523 .91 r
.41445 .61174 .42131 .62004 .43285 .62419 .42601 .61579 Mtetra
.3 .54 .914 r
.42601 .61579 .43285 .62419 .44451 .62795 .43768 .61946 Mtetra
.338 .559 .918 r
.43768 .61946 .44451 .62795 .45629 .63122 .44947 .62265 Mtetra
.377 .579 .919 r
.44947 .62265 .45629 .63122 .46817 .63393 .46136 .62529 Mtetra
.418 .599 .92 r
.46136 .62529 .46817 .63393 .48015 .63599 .47336 .6273 Mtetra
.458 .618 .919 r
.47336 .6273 .48015 .63599 .49223 .63734 .48546 .62861 Mtetra
.497 .636 .916 r
.48546 .62861 .49223 .63734 .50441 .6379 .49766 .62915 Mtetra
.534 .653 .912 r
.49766 .62915 .50441 .6379 .51667 .63763 .50994 .62885 Mtetra
.569 .669 .906 r
.50994 .62885 .51667 .63763 .52901 .63646 .5223 .62768 Mtetra
.602 .683 .899 r
.5223 .62768 .52901 .63646 .54141 .63436 .53474 .6256 Mtetra
.632 .696 .892 r
.53474 .6256 .54141 .63436 .55388 .63131 .54723 .62257 Mtetra
.659 .708 .884 r
.54723 .62257 .55388 .63131 .56639 .62729 .55977 .61858 Mtetra
.684 .718 .875 r
.55977 .61858 .56639 .62729 .57895 .6223 .57236 .61363 Mtetra
.706 .727 .867 r
.57236 .61363 .57895 .6223 .59153 .61635 .58498 .60774 Mtetra
.726 .735 .859 r
.58498 .60774 .59153 .61635 .60413 .60946 .59762 .60091 Mtetra
.743 .743 .851 r
.59762 .60091 .60413 .60946 .61674 .60168 .61027 .59319 Mtetra
.759 .749 .844 r
.61027 .59319 .61674 .60168 .62935 .59305 .62293 .58462 Mtetra
.772 .755 .837 r
.62293 .58462 .62935 .59305 .64196 .58362 .63558 .57526 Mtetra
.784 .76 .831 r
.63558 .57526 .64196 .58362 .65455 .57346 .64823 .56517 Mtetra
.795 .764 .825 r
.64823 .56517 .65455 .57346 .66713 .56266 .66086 .55443 Mtetra
.804 .768 .82 r
.66086 .55443 .66713 .56266 .67969 .55128 .67347 .54312 Mtetra
.811 .772 .816 r
.67347 .54312 .67969 .55128 .69222 .53941 .68606 .53131 Mtetra
.817 .775 .813 r
.68606 .53131 .69222 .53941 .70473 .52713 .69862 .51909 Mtetra
.823 .778 .811 r
.69862 .51909 .70473 .52713 .71722 .51455 .71116 .50656 Mtetra
.826 .781 .81 r
.71116 .50656 .71722 .51455 .72968 .50174 .72368 .4938 Mtetra
.829 .784 .809 r
.72368 .4938 .72968 .50174 .74212 .48878 .73618 .48088 Mtetra
.831 .786 .809 r
.73618 .48088 .74212 .48878 .75455 .47577 .74867 .46791 Mtetra
.832 .788 .81 r
.74867 .46791 .75455 .47577 .76696 .46278 .76114 .45494 Mtetra
.832 .79 .812 r
.76114 .45494 .76696 .46278 .77937 .44988 .77361 .44206 Mtetra
.831 .792 .814 r
.77361 .44206 .77937 .44988 .79178 .43713 .78608 .42933 Mtetra
.83 .793 .817 r
.78608 .42933 .79178 .43713 .8042 .4246 .79856 .41681 Mtetra
.827 .794 .821 r
.79856 .41681 .8042 .4246 .81664 .41233 .81105 .40455 Mtetra
.823 .795 .825 r
.81105 .40455 .81664 .41233 .82909 .40037 .82356 .39259 Mtetra
.819 .795 .829 r
.82356 .39259 .82909 .40037 .84158 .38876 .8361 .38097 Mtetra
.814 .795 .834 r
.8361 .38097 .84158 .38876 .8541 .37752 .84868 .36971 Mtetra
.809 .795 .839 r
.84868 .36971 .8541 .37752 .86667 .36666 .86131 .35884 Mtetra
.802 .794 .844 r
.86131 .35884 .86667 .36666 .87929 .35622 .87398 .34837 Mtetra
.796 .793 .85 r
.87398 .34837 .87929 .35622 .89196 .34618 .8867 .33831 Mtetra
.266 .556 .93 r
.27656 .55304 .28361 .56018 .29406 .56339 .28703 .55609 Mtetra
.245 .539 .923 r
.28703 .55609 .29406 .56339 .30457 .56693 .29756 .55948 Mtetra
.227 .524 .917 r
.29756 .55948 .30457 .56693 .31515 .57079 .30816 .56317 Mtetra
.212 .511 .911 r
.30816 .56317 .31515 .57079 .32581 .57492 .31883 .56713 Mtetra
.203 .5 .906 r
.31883 .56713 .32581 .57492 .33655 .57928 .32958 .57133 Mtetra
.198 .492 .902 r
.32958 .57133 .33655 .57928 .34738 .58384 .34043 .57571 Mtetra
.199 .487 .899 r
.34043 .57571 .34738 .58384 .3583 .58854 .35136 .58023 Mtetra
.205 .486 .897 r
.35136 .58023 .3583 .58854 .36932 .59331 .36239 .58482 Mtetra
.216 .488 .896 r
.36239 .58482 .36932 .59331 .38044 .59809 .37352 .58943 Mtetra
.233 .493 .897 r
.37352 .58943 .38044 .59809 .39166 .60281 .38476 .59398 Mtetra
.254 .5 .898 r
.38476 .59398 .39166 .60281 .403 .60738 .39611 .59839 Mtetra
.279 .511 .899 r
.39611 .59839 .403 .60738 .41445 .61174 .40757 .6026 Mtetra
.308 .524 .9 r
.40757 .6026 .41445 .61174 .42601 .61579 .41914 .6065 Mtetra
.34 .538 .901 r
.41914 .6065 .42601 .61579 .43768 .61946 .43083 .61004 Mtetra
.373 .553 .902 r
.43083 .61004 .43768 .61946 .44947 .62265 .44262 .61311 Mtetra
.408 .569 .901 r
.44262 .61311 .44947 .62265 .46136 .62529 .45453 .61565 Mtetra
.443 .585 .9 r
.45453 .61565 .46136 .62529 .47336 .6273 .46654 .61757 Mtetra
.478 .601 .897 r
.46654 .61757 .47336 .6273 .48546 .62861 .47866 .6188 Mtetra
.512 .617 .893 r
.47866 .6188 .48546 .62861 .49766 .62915 .49087 .61928 Mtetra
.544 .631 .888 r
.49087 .61928 .49766 .62915 .50994 .62885 .50317 .61895 Mtetra
.575 .645 .883 r
.50317 .61895 .50994 .62885 .5223 .62768 .51555 .61776 Mtetra
.604 .658 .876 r
.51555 .61776 .5223 .62768 .53474 .6256 .52801 .61567 Mtetra
.63 .67 .869 r
.52801 .61567 .53474 .6256 .54723 .62257 .54053 .61266 Mtetra
.655 .681 .862 r
.54053 .61266 .54723 .62257 .55977 .61858 .5531 .6087 Mtetra
.677 .691 .855 r
.5531 .6087 .55977 .61858 .57236 .61363 .56571 .60379 Mtetra
.698 .7 .848 r
.56571 .60379 .57236 .61363 .58498 .60774 .57837 .59795 Mtetra
.716 .708 .841 r
.57837 .59795 .58498 .60774 .59762 .60091 .59104 .5912 Mtetra
.733 .716 .835 r
.59104 .5912 .59762 .60091 .61027 .59319 .60373 .58355 Mtetra
.748 .723 .829 r
.60373 .58355 .61027 .59319 .62293 .58462 .61643 .57507 Mtetra
.761 .729 .823 r
.61643 .57507 .62293 .58462 .63558 .57526 .62913 .56581 Mtetra
.773 .735 .818 r
.62913 .56581 .63558 .57526 .64823 .56517 .64182 .55582 Mtetra
.783 .74 .814 r
.64182 .55582 .64823 .56517 .66086 .55443 .6545 .54518 Mtetra
.792 .745 .81 r
.6545 .54518 .66086 .55443 .67347 .54312 .66716 .53396 Mtetra
.8 .75 .807 r
.66716 .53396 .67347 .54312 .68606 .53131 .6798 .52226 Mtetra
.806 .754 .805 r
.6798 .52226 .68606 .53131 .69862 .51909 .69242 .51014 Mtetra
.812 .758 .803 r
.69242 .51014 .69862 .51909 .71116 .50656 .70502 .49771 Mtetra
.816 .762 .802 r
.70502 .49771 .71116 .50656 .72368 .4938 .71759 .48504 Mtetra
.819 .766 .802 r
.71759 .48504 .72368 .4938 .73618 .48088 .73015 .47221 Mtetra
.822 .769 .803 r
.73015 .47221 .73618 .48088 .74867 .46791 .7427 .45932 Mtetra
.823 .772 .804 r
.7427 .45932 .74867 .46791 .76114 .45494 .75523 .44643 Mtetra
.824 .775 .806 r
.75523 .44643 .76114 .45494 .77361 .44206 .76776 .43361 Mtetra
.824 .777 .809 r
.76776 .43361 .77361 .44206 .78608 .42933 .78029 .42094 Mtetra
.822 .779 .812 r
.78029 .42094 .78608 .42933 .79856 .41681 .79283 .40848 Mtetra
.82 .781 .816 r
.79283 .40848 .79856 .41681 .81105 .40455 .80538 .39626 Mtetra
.817 .783 .82 r
.80538 .39626 .81105 .40455 .82356 .39259 .81795 .38434 Mtetra
.814 .784 .825 r
.81795 .38434 .82356 .39259 .8361 .38097 .83055 .37274 Mtetra
.809 .785 .83 r
.83055 .37274 .8361 .38097 .84868 .36971 .84319 .36151 Mtetra
.804 .785 .835 r
.84319 .36151 .84868 .36971 .86131 .35884 .85587 .35066 Mtetra
.798 .786 .841 r
.85587 .35066 .86131 .35884 .87398 .34837 .86859 .3402 Mtetra
.792 .785 .846 r
.86859 .3402 .87398 .34837 .8867 .33831 .88138 .33015 Mtetra
.296 .562 .929 r
.26948 .54556 .27656 .55304 .28703 .55609 .27996 .54844 Mtetra
.278 .547 .923 r
.27996 .54844 .28703 .55609 .29756 .55948 .29051 .55164 Mtetra
.262 .533 .917 r
.29051 .55164 .29756 .55948 .30816 .56317 .30113 .55513 Mtetra
.251 .52 .911 r
.30113 .55513 .30816 .56317 .31883 .56713 .31182 .55889 Mtetra
.243 .51 .906 r
.31182 .55889 .31883 .56713 .32958 .57133 .3226 .56287 Mtetra
.241 .502 .902 r
.3226 .56287 .32958 .57133 .34043 .57571 .33345 .56704 Mtetra
.242 .497 .898 r
.33345 .56704 .34043 .57571 .35136 .58023 .3444 .57134 Mtetra
.249 .495 .895 r
.3444 .57134 .35136 .58023 .36239 .58482 .35545 .57572 Mtetra
.26 .496 .893 r
.35545 .57572 .36239 .58482 .37352 .58943 .36659 .58011 Mtetra
.276 .5 .892 r
.36659 .58011 .37352 .58943 .38476 .59398 .37784 .58445 Mtetra
.296 .505 .891 r
.37784 .58445 .38476 .59398 .39611 .59839 .3892 .58866 Mtetra
.319 .514 .89 r
.3892 .58866 .39611 .59839 .40757 .6026 .40067 .59266 Mtetra
.344 .524 .889 r
.40067 .59266 .40757 .6026 .41914 .6065 .41226 .59638 Mtetra
.373 .535 .888 r
.41226 .59638 .41914 .6065 .43083 .61004 .42395 .59974 Mtetra
.402 .547 .886 r
.42395 .59974 .43083 .61004 .44262 .61311 .43576 .60265 Mtetra
.433 .56 .884 r
.43576 .60265 .44262 .61311 .45453 .61565 .44768 .60505 Mtetra
.463 .574 .881 r
.44768 .60505 .45453 .61565 .46654 .61757 .4597 .60684 Mtetra
.494 .587 .877 r
.4597 .60684 .46654 .61757 .47866 .6188 .47183 .60797 Mtetra
.523 .6 .872 r
.47183 .60797 .47866 .6188 .49087 .61928 .48405 .60837 Mtetra
.552 .613 .867 r
.48405 .60837 .49087 .61928 .50317 .61895 .49637 .60798 Mtetra
.579 .625 .862 r
.49637 .60798 .50317 .61895 .51555 .61776 .50876 .60675 Mtetra
.605 .637 .856 r
.50876 .60675 .51555 .61776 .52801 .61567 .52124 .60464 Mtetra
.629 .648 .85 r
.52124 .60464 .52801 .61567 .54053 .61266 .53378 .60163 Mtetra
.651 .658 .844 r
.53378 .60163 .54053 .61266 .5531 .6087 .54637 .59769 Mtetra
.671 .668 .838 r
.54637 .59769 .5531 .6087 .56571 .60379 .55901 .59283 Mtetra
.69 .677 .832 r
.55901 .59283 .56571 .60379 .57837 .59795 .57169 .58706 Mtetra
.707 .685 .826 r
.57169 .58706 .57837 .59795 .59104 .5912 .5844 .58038 Mtetra
.723 .693 .821 r
.5844 .58038 .59104 .5912 .60373 .58355 .59713 .57283 Mtetra
.737 .7 .816 r
.59713 .57283 .60373 .58355 .61643 .57507 .60986 .56445 Mtetra
.75 .707 .811 r
.60986 .56445 .61643 .57507 .62913 .56581 .6226 .55531 Mtetra
.761 .713 .807 r
.6226 .55531 .62913 .56581 .64182 .55582 .63533 .54544 Mtetra
.772 .719 .804 r
.63533 .54544 .64182 .55582 .6545 .54518 .64806 .53494 Mtetra
.781 .725 .801 r
.64806 .53494 .6545 .54518 .66716 .53396 .66077 .52386 Mtetra
.788 .73 .799 r
.66077 .52386 .66716 .53396 .6798 .52226 .67346 .51229 Mtetra
.795 .735 .797 r
.67346 .51229 .6798 .52226 .69242 .51014 .68613 .50032 Mtetra
.801 .74 .796 r
.68613 .50032 .69242 .51014 .70502 .49771 .69878 .48802 Mtetra
.806 .745 .796 r
.69878 .48802 .70502 .49771 .71759 .48504 .71142 .47548 Mtetra
.81 .749 .796 r
.71142 .47548 .71759 .48504 .73015 .47221 .72403 .46279 Mtetra
.812 .753 .797 r
.72403 .46279 .73015 .47221 .7427 .45932 .73664 .45002 Mtetra
.814 .757 .799 r
.73664 .45002 .7427 .45932 .75523 .44643 .74923 .43725 Mtetra
.815 .76 .801 r
.74923 .43725 .75523 .44643 .76776 .43361 .76182 .42455 Mtetra
.816 .764 .804 r
.76182 .42455 .76776 .43361 .78029 .42094 .77441 .41198 Mtetra
.815 .767 .808 r
.77441 .41198 .78029 .42094 .79283 .40848 .78701 .39961 Mtetra
.813 .769 .812 r
.78701 .39961 .79283 .40848 .80538 .39626 .79962 .38747 Mtetra
.811 .772 .816 r
.79962 .38747 .80538 .39626 .81795 .38434 .81226 .37563 Mtetra
.808 .774 .821 r
.81226 .37563 .81795 .38434 .83055 .37274 .82492 .3641 Mtetra
.804 .775 .827 r
.82492 .3641 .83055 .37274 .84319 .36151 .83761 .35293 Mtetra
.799 .777 .832 r
.83761 .35293 .84319 .36151 .85587 .35066 .85035 .34213 Mtetra
.794 .777 .838 r
.85035 .34213 .85587 .35066 .86859 .3402 .86314 .33171 Mtetra
.788 .778 .843 r
.86314 .33171 .86859 .3402 .88138 .33015 .87598 .32169 Mtetra
.324 .569 .927 r
.26237 .53779 .26948 .54556 .27996 .54844 .27287 .54046 Mtetra
.309 .554 .922 r
.27287 .54046 .27996 .54844 .29051 .55164 .28344 .54344 Mtetra
.296 .541 .916 r
.28344 .54344 .29051 .55164 .30113 .55513 .29408 .5467 Mtetra
.286 .529 .91 r
.29408 .5467 .30113 .55513 .31182 .55889 .30479 .55022 Mtetra
.281 .519 .905 r
.30479 .55022 .31182 .55889 .3226 .56287 .31558 .55396 Mtetra
.279 .512 .9 r
.31558 .55396 .3226 .56287 .33345 .56704 .32646 .55787 Mtetra
.282 .506 .895 r
.32646 .55787 .33345 .56704 .3444 .57134 .33743 .56192 Mtetra
.288 .504 .891 r
.33743 .56192 .3444 .57134 .35545 .57572 .34849 .56604 Mtetra
.299 .503 .888 r
.34849 .56604 .35545 .57572 .36659 .58011 .35965 .57018 Mtetra
.313 .505 .885 r
.35965 .57018 .36659 .58011 .37784 .58445 .37091 .57426 Mtetra
.331 .51 .882 r
.37091 .57426 .37784 .58445 .3892 .58866 .38228 .57822 Mtetra
.352 .516 .88 r
.38228 .57822 .3892 .58866 .40067 .59266 .39376 .58199 Mtetra
.375 .523 .877 r
.39376 .58199 .40067 .59266 .41226 .59638 .40535 .58549 Mtetra
.4 .532 .874 r
.40535 .58549 .41226 .59638 .42395 .59974 .41706 .58863 Mtetra
.426 .542 .871 r
.41706 .58863 .42395 .59974 .43576 .60265 .42887 .59135 Mtetra
.453 .553 .868 r
.42887 .59135 .43576 .60265 .44768 .60505 .4408 .59357 Mtetra
.48 .564 .864 r
.4408 .59357 .44768 .60505 .4597 .60684 .45283 .59521 Mtetra
.506 .576 .859 r
.45283 .59521 .4597 .60684 .47183 .60797 .46497 .5962 Mtetra
.532 .587 .855 r
.46497 .5962 .47183 .60797 .48405 .60837 .4772 .59649 Mtetra
.558 .598 .85 r
.4772 .59649 .48405 .60837 .49637 .60798 .48953 .59601 Mtetra
.582 .609 .845 r
.48953 .59601 .49637 .60798 .50876 .60675 .50194 .59472 Mtetra
.605 .619 .839 r
.50194 .59472 .50876 .60675 .52124 .60464 .51443 .59258 Mtetra
.626 .629 .834 r
.51443 .59258 .52124 .60464 .53378 .60163 .52698 .58956 Mtetra
.647 .639 .828 r
.52698 .58956 .53378 .60163 .54637 .59769 .5396 .58565 Mtetra
.666 .648 .823 r
.5396 .58565 .54637 .59769 .55901 .59283 .55226 .58083 Mtetra
.683 .657 .818 r
.55226 .58083 .55901 .59283 .57169 .58706 .56497 .57511 Mtetra
.699 .665 .813 r
.56497 .57511 .57169 .58706 .5844 .58038 .5777 .56852 Mtetra
.714 .673 .809 r
.5777 .56852 .5844 .58038 .59713 .57283 .59046 .56108 Mtetra
.727 .681 .805 r
.59046 .56108 .59713 .57283 .60986 .56445 .60323 .55283 Mtetra
.74 .688 .801 r
.60323 .55283 .60986 .56445 .6226 .55531 .616 .54382 Mtetra
.751 .694 .798 r
.616 .54382 .6226 .55531 .63533 .54544 .62878 .5341 Mtetra
.761 .701 .795 r
.62878 .5341 .63533 .54544 .64806 .53494 .64154 .52376 Mtetra
.77 .707 .793 r
.64154 .52376 .64806 .53494 .66077 .52386 .6543 .51285 Mtetra
.778 .713 .791 r
.6543 .51285 .66077 .52386 .67346 .51229 .66704 .50146 Mtetra
.785 .719 .79 r
.66704 .50146 .67346 .51229 .68613 .50032 .67976 .48966 Mtetra
.791 .724 .79 r
.67976 .48966 .68613 .50032 .69878 .48802 .69247 .47754 Mtetra
.796 .729 .79 r
.69247 .47754 .69878 .48802 .71142 .47548 .70516 .46517 Mtetra
.8 .734 .791 r
.70516 .46517 .71142 .47548 .72403 .46279 .71783 .45265 Mtetra
.803 .739 .792 r
.71783 .45265 .72403 .46279 .73664 .45002 .7305 .44005 Mtetra
.805 .743 .794 r
.7305 .44005 .73664 .45002 .74923 .43725 .74315 .42744 Mtetra
.807 .747 .797 r
.74315 .42744 .74923 .43725 .76182 .42455 .7558 .41489 Mtetra
.808 .751 .8 r
.7558 .41489 .76182 .42455 .77441 .41198 .76845 .40247 Mtetra
.807 .755 .804 r
.76845 .40247 .77441 .41198 .78701 .39961 .78111 .39023 Mtetra
.806 .758 .808 r
.78111 .39023 .78701 .39961 .79962 .38747 .79379 .37822 Mtetra
.804 .761 .813 r
.79379 .37822 .79962 .38747 .81226 .37563 .80648 .36648 Mtetra
.802 .764 .818 r
.80648 .36648 .81226 .37563 .82492 .3641 .81921 .35506 Mtetra
.798 .766 .824 r
.81921 .35506 .82492 .3641 .83761 .35293 .83197 .34398 Mtetra
.794 .768 .829 r
.83197 .34398 .83761 .35293 .85035 .34213 .84477 .33326 Mtetra
.789 .77 .835 r
.84477 .33326 .85035 .34213 .86314 .33171 .85762 .32291 Mtetra
.784 .771 .841 r
.85762 .32291 .86314 .33171 .87598 .32169 .87052 .31294 Mtetra
.351 .575 .925 r
.25522 .52974 .26237 .53779 .27287 .54046 .26575 .53218 Mtetra
.337 .562 .919 r
.26575 .53218 .27287 .54046 .28344 .54344 .27635 .53491 Mtetra
.326 .549 .914 r
.27635 .53491 .28344 .54344 .29408 .5467 .28701 .53791 Mtetra
.319 .538 .908 r
.28701 .53791 .29408 .5467 .30479 .55022 .29774 .54116 Mtetra
.314 .528 .902 r
.29774 .54116 .30479 .55022 .31558 .55396 .30855 .54462 Mtetra
.313 .52 .896 r
.30855 .54462 .31558 .55396 .32646 .55787 .31945 .54826 Mtetra
.316 .515 .891 r
.31945 .54826 .32646 .55787 .33743 .56192 .33043 .55202 Mtetra
.323 .511 .887 r
.33043 .55202 .33743 .56192 .34849 .56604 .34151 .55585 Mtetra
.333 .51 .882 r
.34151 .55585 .34849 .56604 .35965 .57018 .35268 .55969 Mtetra
.346 .511 .878 r
.35268 .55969 .35965 .57018 .37091 .57426 .36396 .56349 Mtetra
.362 .513 .874 r
.36396 .56349 .37091 .57426 .38228 .57822 .37534 .56717 Mtetra
.38 .518 .87 r
.37534 .56717 .38228 .57822 .39376 .58199 .38683 .57066 Mtetra
.401 .524 .866 r
.38683 .57066 .39376 .58199 .40535 .58549 .39843 .57389 Mtetra
.423 .531 .862 r
.39843 .57389 .40535 .58549 .41706 .58863 .41015 .57679 Mtetra
.446 .539 .858 r
.41015 .57679 .41706 .58863 .42887 .59135 .42197 .57928 Mtetra
.469 .547 .854 r
.42197 .57928 .42887 .59135 .4408 .59357 .43391 .58129 Mtetra
.493 .557 .849 r
.43391 .58129 .4408 .59357 .45283 .59521 .44595 .58274 Mtetra
.517 .566 .845 r
.44595 .58274 .45283 .59521 .46497 .5962 .45809 .58357 Mtetra
.54 .576 .84 r
.45809 .58357 .46497 .5962 .4772 .59649 .47033 .58373 Mtetra
.562 .586 .835 r
.47033 .58373 .4772 .59649 .48953 .59601 .48267 .58314 Mtetra
.584 .595 .83 r
.48267 .58314 .48953 .59601 .50194 .59472 .49509 .58177 Mtetra
.605 .605 .825 r
.49509 .58177 .50194 .59472 .51443 .59258 .50759 .57958 Mtetra
.624 .614 .82 r
.50759 .57958 .51443 .59258 .52698 .58956 .52016 .57654 Mtetra
.643 .623 .815 r
.52016 .57654 .52698 .58956 .5396 .58565 .53279 .57264 Mtetra
.66 .632 .811 r
.53279 .57264 .5396 .58565 .55226 .58083 .54547 .56786 Mtetra
.677 .64 .806 r
.54547 .56786 .55226 .58083 .56497 .57511 .55819 .56221 Mtetra
.692 .649 .802 r
.55819 .56221 .56497 .57511 .5777 .56852 .57095 .55571 Mtetra
.706 .656 .798 r
.57095 .55571 .5777 .56852 .59046 .56108 .58374 .54838 Mtetra
.719 .664 .795 r
.58374 .54838 .59046 .56108 .60323 .55283 .59654 .54027 Mtetra
.73 .671 .792 r
.59654 .54027 .60323 .55283 .616 .54382 .60935 .53142 Mtetra
.741 .678 .789 r
.60935 .53142 .616 .54382 .62878 .5341 .62216 .52188 Mtetra
.751 .685 .787 r
.62216 .52188 .62878 .5341 .64154 .52376 .63496 .51172 Mtetra
.76 .691 .786 r
.63496 .51172 .64154 .52376 .6543 .51285 .64776 .501 Mtetra
.768 .698 .785 r
.64776 .501 .6543 .51285 .66704 .50146 .66055 .48981 Mtetra
.775 .704 .784 r
.66055 .48981 .66704 .50146 .67976 .48966 .67332 .47822 Mtetra
.781 .709 .784 r
.67332 .47822 .67976 .48966 .69247 .47754 .68608 .46631 Mtetra
.786 .715 .785 r
.68608 .46631 .69247 .47754 .70516 .46517 .69882 .45416 Mtetra
.791 .72 .786 r
.69882 .45416 .70516 .46517 .71783 .45265 .71156 .44185 Mtetra
.794 .726 .788 r
.71156 .44185 .71783 .45265 .7305 .44005 .72428 .42945 Mtetra
.797 .731 .79 r
.72428 .42945 .7305 .44005 .74315 .42744 .73699 .41704 Mtetra
.799 .735 .793 r
.73699 .41704 .74315 .42744 .7558 .41489 .7497 .40468 Mtetra
.8 .74 .797 r
.7497 .40468 .7558 .41489 .76845 .40247 .76242 .39243 Mtetra
.8 .744 .801 r
.76242 .39243 .76845 .40247 .78111 .39023 .77514 .38036 Mtetra
.799 .748 .805 r
.77514 .38036 .78111 .39023 .79379 .37822 .78788 .36851 Mtetra
.798 .752 .81 r
.78788 .36851 .79379 .37822 .80648 .36648 .80064 .35692 Mtetra
.796 .755 .816 r
.80064 .35692 .80648 .36648 .81921 .35506 .81343 .34563 Mtetra
.793 .758 .821 r
.81343 .34563 .81921 .35506 .83197 .34398 .82625 .33467 Mtetra
.789 .76 .827 r
.82625 .33467 .83197 .34398 .84477 .33326 .83911 .32406 Mtetra
.785 .762 .833 r
.83911 .32406 .84477 .33326 .85762 .32291 .85202 .31381 Mtetra
.78 .764 .839 r
.85202 .31381 .85762 .32291 .87052 .31294 .86499 .30393 Mtetra
.376 .582 .922 r
.24804 .52145 .25522 .52974 .26575 .53218 .2586 .52363 Mtetra
.364 .569 .917 r
.2586 .52363 .26575 .53218 .27635 .53491 .26922 .52609 Mtetra
.355 .557 .911 r
.26922 .52609 .27635 .53491 .28701 .53791 .2799 .52881 Mtetra
.348 .546 .905 r
.2799 .52881 .28701 .53791 .29774 .54116 .29066 .53177 Mtetra
.345 .536 .899 r
.29066 .53177 .29774 .54116 .30855 .54462 .30149 .53492 Mtetra
.344 .528 .893 r
.30149 .53492 .30855 .54462 .31945 .54826 .31241 .53824 Mtetra
.347 .522 .887 r
.31241 .53824 .31945 .54826 .33043 .55202 .32341 .54168 Mtetra
.353 .518 .881 r
.32341 .54168 .33043 .55202 .34151 .55585 .33451 .54519 Mtetra
.362 .516 .876 r
.33451 .54519 .34151 .55585 .35268 .55969 .3457 .54872 Mtetra
.374 .516 .871 r
.3457 .54872 .35268 .55969 .36396 .56349 .35699 .55219 Mtetra
.389 .517 .866 r
.35699 .55219 .36396 .56349 .37534 .56717 .36839 .55556 Mtetra
.405 .52 .861 r
.36839 .55556 .37534 .56717 .38683 .57066 .37989 .55875 Mtetra
.423 .524 .856 r
.37989 .55875 .38683 .57066 .39843 .57389 .3915 .56168 Mtetra
.442 .53 .852 r
.3915 .56168 .39843 .57389 .41015 .57679 .40322 .56431 Mtetra
.463 .536 .847 r
.40322 .56431 .41015 .57679 .42197 .57928 .41506 .56653 Mtetra
.483 .543 .842 r
.41506 .56653 .42197 .57928 .43391 .58129 .427 .5683 Mtetra
.505 .551 .837 r
.427 .5683 .43391 .58129 .44595 .58274 .43904 .56954 Mtetra
.526 .559 .832 r
.43904 .56954 .44595 .58274 .45809 .58357 .45119 .57019 Mtetra
.546 .568 .827 r
.45119 .57019 .45809 .58357 .47033 .58373 .46344 .57018 Mtetra
.566 .576 .823 r
.46344 .57018 .47033 .58373 .48267 .58314 .47578 .56947 Mtetra
.586 .585 .818 r
.47578 .56947 .48267 .58314 .49509 .58177 .48821 .568 Mtetra
.605 .593 .813 r
.48821 .568 .49509 .58177 .50759 .57958 .50072 .56575 Mtetra
.623 .602 .809 r
.50072 .56575 .50759 .57958 .52016 .57654 .5133 .56268 Mtetra
.64 .61 .804 r
.5133 .56268 .52016 .57654 .53279 .57264 .52594 .55878 Mtetra
.656 .619 .8 r
.52594 .55878 .53279 .57264 .54547 .56786 .53864 .55403 Mtetra
.671 .627 .796 r
.53864 .55403 .54547 .56786 .55819 .56221 .55138 .54845 Mtetra
.685 .635 .793 r
.55138 .54845 .55819 .56221 .57095 .55571 .56416 .54205 Mtetra
.698 .642 .79 r
.56416 .54205 .57095 .55571 .58374 .54838 .57697 .53484 Mtetra
.711 .65 .787 r
.57697 .53484 .58374 .54838 .59654 .54027 .5898 .52688 Mtetra
.722 .657 .785 r
.5898 .52688 .59654 .54027 .60935 .53142 .60263 .51819 Mtetra
.732 .664 .783 r
.60263 .51819 .60935 .53142 .62216 .52188 .61548 .50884 Mtetra
.742 .671 .781 r
.61548 .50884 .62216 .52188 .63496 .51172 .62832 .49889 Mtetra
.751 .678 .78 r
.62832 .49889 .63496 .51172 .64776 .501 .64116 .4884 Mtetra
.759 .684 .779 r
.64116 .4884 .64776 .501 .66055 .48981 .65399 .47744 Mtetra
.766 .69 .779 r
.65399 .47744 .66055 .48981 .67332 .47822 .66681 .46608 Mtetra
.772 .697 .78 r
.66681 .46608 .67332 .47822 .68608 .46631 .67962 .45441 Mtetra
.777 .703 .781 r
.67962 .45441 .68608 .46631 .69882 .45416 .69242 .4425 Mtetra
.782 .708 .782 r
.69242 .4425 .69882 .45416 .71156 .44185 .70521 .43043 Mtetra
.786 .714 .785 r
.70521 .43043 .71156 .44185 .72428 .42945 .71798 .41827 Mtetra
.788 .719 .787 r
.71798 .41827 .72428 .42945 .73699 .41704 .73076 .40608 Mtetra
.791 .725 .79 r
.73076 .40608 .73699 .41704 .7497 .40468 .74353 .39395 Mtetra
.792 .729 .794 r
.74353 .39395 .7497 .40468 .76242 .39243 .75631 .38192 Mtetra
.792 .734 .798 r
.75631 .38192 .76242 .39243 .77514 .38036 .76909 .37005 Mtetra
.792 .739 .803 r
.76909 .37005 .77514 .38036 .78788 .36851 .7819 .35838 Mtetra
.791 .743 .808 r
.7819 .35838 .78788 .36851 .80064 .35692 .79472 .34697 Mtetra
.789 .746 .814 r
.79472 .34697 .80064 .35692 .81343 .34563 .80757 .33585 Mtetra
.787 .75 .819 r
.80757 .33585 .81343 .34563 .82625 .33467 .82046 .32503 Mtetra
.783 .753 .825 r
.82046 .32503 .82625 .33467 .83911 .32406 .83339 .31456 Mtetra
.78 .756 .831 r
.83339 .31456 .83911 .32406 .85202 .31381 .84636 .30442 Mtetra
.775 .758 .837 r
.84636 .30442 .85202 .31381 .86499 .30393 .85939 .29465 Mtetra
.399 .588 .919 r
.24083 .51293 .24804 .52145 .2586 .52363 .25142 .51484 Mtetra
.389 .576 .914 r
.25142 .51484 .2586 .52363 .26922 .52609 .26206 .51701 Mtetra
.381 .564 .908 r
.26206 .51701 .26922 .52609 .2799 .52881 .27277 .51943 Mtetra
.375 .554 .902 r
.27277 .51943 .2799 .52881 .29066 .53177 .28355 .52207 Mtetra
.372 .544 .895 r
.28355 .52207 .29066 .53177 .30149 .53492 .29441 .5249 Mtetra
.372 .536 .889 r
.29441 .5249 .30149 .53492 .31241 .53824 .30535 .52788 Mtetra
.375 .53 .883 r
.30535 .52788 .31241 .53824 .32341 .54168 .31637 .53098 Mtetra
.381 .525 .877 r
.31637 .53098 .32341 .54168 .33451 .54519 .32749 .53414 Mtetra
.389 .522 .871 r
.32749 .53414 .33451 .54519 .3457 .54872 .3387 .53732 Mtetra
.399 .521 .865 r
.3387 .53732 .3457 .54872 .35699 .55219 .35 .54045 Mtetra
.412 .521 .859 r
.35 .54045 .35699 .55219 .36839 .55556 .36141 .54347 Mtetra
.426 .523 .854 r
.36141 .54347 .36839 .55556 .37989 .55875 .37293 .54633 Mtetra
.442 .526 .848 r
.37293 .54633 .37989 .55875 .3915 .56168 .38455 .54895 Mtetra
.459 .53 .843 r
.38455 .54895 .3915 .56168 .40322 .56431 .39628 .55126 Mtetra
.477 .535 .837 r
.39628 .55126 .40322 .56431 .41506 .56653 .40812 .55321 Mtetra
.496 .541 .832 r
.40812 .55321 .41506 .56653 .427 .5683 .42007 .55471 Mtetra
.515 .547 .827 r
.42007 .55471 .427 .5683 .43904 .56954 .43212 .55571 Mtetra
.533 .554 .822 r
.43212 .55571 .43904 .56954 .45119 .57019 .44428 .55615 Mtetra
.552 .561 .817 r
.44428 .55615 .45119 .57019 .46344 .57018 .45653 .55596 Mtetra
.57 .569 .813 r
.45653 .55596 .46344 .57018 .47578 .56947 .46888 .5551 Mtetra
.588 .577 .808 r
.46888 .5551 .47578 .56947 .48821 .568 .48131 .55352 Mtetra
.605 .584 .804 r
.48131 .55352 .48821 .568 .50072 .56575 .49383 .55119 Mtetra
.621 .592 .8 r
.49383 .55119 .50072 .56575 .5133 .56268 .50642 .54808 Mtetra
.637 .6 .796 r
.50642 .54808 .5133 .56268 .52594 .55878 .51907 .54417 Mtetra
.652 .608 .792 r
.51907 .54417 .52594 .55878 .53864 .55403 .53178 .53946 Mtetra
.666 .615 .789 r
.53178 .53946 .53864 .55403 .55138 .54845 .54453 .53394 Mtetra
.679 .623 .786 r
.54453 .53394 .55138 .54845 .56416 .54205 .55733 .52763 Mtetra
.692 .63 .783 r
.55733 .52763 .56416 .54205 .57697 .53484 .57016 .52056 Mtetra
.703 .638 .781 r
.57016 .52056 .57697 .53484 .5898 .52688 .58301 .51275 Mtetra
.714 .645 .779 r
.58301 .51275 .5898 .52688 .60263 .51819 .59588 .50424 Mtetra
.724 .652 .777 r
.59588 .50424 .60263 .51819 .61548 .50884 .60875 .4951 Mtetra
.734 .659 .776 r
.60875 .4951 .61548 .50884 .62832 .49889 .62163 .48536 Mtetra
.742 .666 .775 r
.62163 .48536 .62832 .49889 .64116 .4884 .63451 .47511 Mtetra
.75 .673 .775 r
.63451 .47511 .64116 .4884 .65399 .47744 .64738 .4644 Mtetra
.757 .679 .775 r
.64738 .4644 .65399 .47744 .66681 .46608 .66025 .45331 Mtetra
.763 .685 .776 r
.66025 .45331 .66681 .46608 .67962 .45441 .6731 .44191 Mtetra
.769 .692 .778 r
.6731 .44191 .67962 .45441 .69242 .4425 .68595 .43026 Mtetra
.773 .698 .78 r
.68595 .43026 .69242 .4425 .70521 .43043 .69879 .41846 Mtetra
.777 .704 .782 r
.69879 .41846 .70521 .43043 .71798 .41827 .71163 .40656 Mtetra
.781 .709 .785 r
.71163 .40656 .71798 .41827 .73076 .40608 .72446 .39464 Mtetra
.783 .715 .788 r
.72446 .39464 .73076 .40608 .74353 .39395 .73729 .38275 Mtetra
.784 .72 .792 r
.73729 .38275 .74353 .39395 .75631 .38192 .75013 .37096 Mtetra
.785 .725 .797 r
.75013 .37096 .75631 .38192 .76909 .37005 .76298 .35932 Mtetra
.785 .73 .801 r
.76298 .35932 .76909 .37005 .7819 .35838 .77585 .34788 Mtetra
.785 .735 .807 r
.77585 .34788 .7819 .35838 .79472 .34697 .78874 .33667 Mtetra
.783 .739 .812 r
.78874 .33667 .79472 .34697 .80757 .33585 .80165 .32573 Mtetra
.781 .743 .818 r
.80165 .32573 .80757 .33585 .82046 .32503 .81461 .31509 Mtetra
.778 .746 .824 r
.81461 .31509 .82046 .32503 .83339 .31456 .8276 .30477 Mtetra
.774 .749 .83 r
.8276 .30477 .83339 .31456 .84636 .30442 .84064 .29478 Mtetra
.77 .752 .836 r
.84064 .29478 .84636 .30442 .85939 .29465 .85373 .28513 Mtetra
.42 .595 .916 r
.23358 .50423 .24083 .51293 .25142 .51484 .2442 .50585 Mtetra
.411 .583 .911 r
.2442 .50585 .25142 .51484 .26206 .51701 .25487 .50772 Mtetra
.404 .572 .905 r
.25487 .50772 .26206 .51701 .27277 .51943 .26561 .50981 Mtetra
.4 .561 .898 r
.26561 .50981 .27277 .51943 .28355 .52207 .27642 .51212 Mtetra
.397 .552 .892 r
.27642 .51212 .28355 .52207 .29441 .5249 .2873 .51461 Mtetra
.397 .544 .885 r
.2873 .51461 .29441 .5249 .30535 .52788 .29826 .51723 Mtetra
.4 .538 .879 r
.29826 .51723 .30535 .52788 .31637 .53098 .30931 .51997 Mtetra
.405 .533 .872 r
.30931 .51997 .31637 .53098 .32749 .53414 .32045 .52276 Mtetra
.412 .529 .866 r
.32045 .52276 .32749 .53414 .3387 .53732 .33167 .52557 Mtetra
.421 .527 .859 r
.33167 .52557 .3387 .53732 .35 .54045 .343 .52833 Mtetra
.433 .526 .853 r
.343 .52833 .35 .54045 .36141 .54347 .35442 .53099 Mtetra
.445 .527 .847 r
.35442 .53099 .36141 .54347 .37293 .54633 .36595 .53349 Mtetra
.459 .528 .841 r
.36595 .53349 .37293 .54633 .38455 .54895 .37759 .53577 Mtetra
.475 .531 .836 r
.37759 .53577 .38455 .54895 .39628 .55126 .38933 .53775 Mtetra
.49 .535 .83 r
.38933 .53775 .39628 .55126 .40812 .55321 .40118 .53939 Mtetra
.507 .54 .825 r
.40118 .53939 .40812 .55321 .42007 .55471 .41313 .54061 Mtetra
.524 .545 .819 r
.41313 .54061 .42007 .55471 .43212 .55571 .42519 .54135 Mtetra
.54 .551 .814 r
.42519 .54135 .43212 .55571 .44428 .55615 .43735 .54156 Mtetra
.557 .557 .809 r
.43735 .54156 .44428 .55615 .45653 .55596 .44961 .54118 Mtetra
.573 .564 .805 r
.44961 .54118 .45653 .55596 .46888 .5551 .46196 .54015 Mtetra
.589 .57 .8 r
.46196 .54015 .46888 .5551 .48131 .55352 .47439 .53845 Mtetra
.605 .577 .796 r
.47439 .53845 .48131 .55352 .49383 .55119 .48691 .53603 Mtetra
.62 .585 .792 r
.48691 .53603 .49383 .55119 .50642 .54808 .49951 .53287 Mtetra
.635 .592 .789 r
.49951 .53287 .50642 .54808 .51907 .54417 .51217 .52894 Mtetra
.648 .599 .785 r
.51217 .52894 .51907 .54417 .53178 .53946 .52489 .52425 Mtetra
.662 .606 .782 r
.52489 .52425 .53178 .53946 .54453 .53394 .53766 .51879 Mtetra
.674 .614 .78 r
.53766 .51879 .54453 .53394 .55733 .52763 .55047 .51258 Mtetra
.686 .621 .777 r
.55047 .51258 .55733 .52763 .57016 .52056 .56331 .50564 Mtetra
.697 .628 .775 r
.56331 .50564 .57016 .52056 .58301 .51275 .57618 .49799 Mtetra
.708 .635 .774 r
.57618 .49799 .58301 .51275 .59588 .50424 .58907 .48967 Mtetra
.717 .642 .773 r
.58907 .48967 .59588 .50424 .60875 .4951 .60198 .48074 Mtetra
.726 .649 .772 r
.60198 .48074 .60875 .4951 .62163 .48536 .61489 .47124 Mtetra
.735 .656 .772 r
.61489 .47124 .62163 .48536 .63451 .47511 .6278 .46124 Mtetra
.742 .663 .772 r
.6278 .46124 .63451 .47511 .64738 .4644 .64071 .4508 Mtetra
.749 .669 .773 r
.64071 .4508 .64738 .4644 .66025 .45331 .65362 .43998 Mtetra
.755 .676 .774 r
.65362 .43998 .66025 .45331 .6731 .44191 .66653 .42887 Mtetra
.761 .682 .775 r
.66653 .42887 .6731 .44191 .68595 .43026 .67942 .41752 Mtetra
.766 .689 .777 r
.67942 .41752 .68595 .43026 .69879 .41846 .69232 .406 Mtetra
.77 .695 .78 r
.69232 .406 .69879 .41846 .71163 .40656 .70521 .39439 Mtetra
.773 .701 .783 r
.70521 .39439 .71163 .40656 .72446 .39464 .7181 .38275 Mtetra
.775 .707 .787 r
.7181 .38275 .72446 .39464 .73729 .38275 .73099 .37114 Mtetra
.777 .712 .791 r
.73099 .37114 .73729 .38275 .75013 .37096 .74389 .35962 Mtetra
.778 .718 .795 r
.74389 .35962 .75013 .37096 .76298 .35932 .7568 .34823 Mtetra
.779 .723 .8 r
.7568 .34823 .76298 .35932 .77585 .34788 .76973 .33702 Mtetra
.778 .728 .806 r
.76973 .33702 .77585 .34788 .78874 .33667 .78269 .32604 Mtetra
.777 .732 .811 r
.78269 .32604 .78874 .33667 .80165 .32573 .79567 .31531 Mtetra
.775 .736 .817 r
.79567 .31531 .80165 .32573 .81461 .31509 .80869 .30487 Mtetra
.773 .74 .823 r
.80869 .30487 .81461 .31509 .8276 .30477 .82175 .29472 Mtetra
.769 .744 .829 r
.82175 .29472 .8276 .30477 .84064 .29478 .83486 .28489 Mtetra
.765 .747 .836 r
.83486 .28489 .84064 .29478 .85373 .28513 .84801 .27539 Mtetra
.44 .602 .914 r
.22629 .49537 .23358 .50423 .2442 .50585 .23694 .49669 Mtetra
.432 .59 .908 r
.23694 .49669 .2442 .50585 .25487 .50772 .24764 .49824 Mtetra
.426 .579 .902 r
.24764 .49824 .25487 .50772 .26561 .50981 .25841 .50001 Mtetra
.422 .569 .896 r
.25841 .50001 .26561 .50981 .27642 .51212 .26925 .50197 Mtetra
.42 .56 .889 r
.26925 .50197 .27642 .51212 .2873 .51461 .28016 .50409 Mtetra
.42 .552 .882 r
.28016 .50409 .2873 .51461 .29826 .51723 .29115 .50635 Mtetra
.422 .545 .875 r
.29115 .50635 .29826 .51723 .30931 .51997 .30222 .50871 Mtetra
.427 .54 .868 r
.30222 .50871 .30931 .51997 .32045 .52276 .31338 .51112 Mtetra
.433 .536 .862 r
.31338 .51112 .32045 .52276 .33167 .52557 .32463 .51354 Mtetra
.441 .533 .855 r
.32463 .51354 .33167 .52557 .343 .52833 .33597 .51591 Mtetra
.451 .531 .848 r
.33597 .51591 .343 .52833 .35442 .53099 .34741 .51819 Mtetra
.462 .531 .842 r
.34741 .51819 .35442 .53099 .36595 .53349 .35896 .52032 Mtetra
.475 .532 .836 r
.35896 .52032 .36595 .53349 .37759 .53577 .37061 .52224 Mtetra
.488 .534 .83 r
.37061 .52224 .37759 .53577 .38933 .53775 .38236 .52388 Mtetra
.502 .536 .824 r
.38236 .52388 .38933 .53775 .40118 .53939 .39421 .52519 Mtetra
.517 .54 .819 r
.39421 .52519 .40118 .53939 .41313 .54061 .40617 .52611 Mtetra
.532 .544 .813 r
.40617 .52611 .41313 .54061 .42519 .54135 .41824 .52658 Mtetra
.547 .549 .808 r
.41824 .52658 .42519 .54135 .43735 .54156 .4304 .52654 Mtetra
.562 .554 .803 r
.4304 .52654 .43735 .54156 .44961 .54118 .44266 .52594 Mtetra
.577 .56 .799 r
.44266 .52594 .44961 .54118 .46196 .54015 .45502 .52474 Mtetra
.591 .566 .794 r
.45502 .52474 .46196 .54015 .47439 .53845 .46746 .5229 Mtetra
.606 .573 .79 r
.46746 .5229 .47439 .53845 .48691 .53603 .47998 .52037 Mtetra
.62 .579 .787 r
.47998 .52037 .48691 .53603 .49951 .53287 .49258 .51715 Mtetra
.633 .586 .783 r
.49258 .51715 .49951 .53287 .51217 .52894 .50524 .5132 Mtetra
.646 .593 .78 r
.50524 .5132 .51217 .52894 .52489 .52425 .51797 .50853 Mtetra
.658 .599 .778 r
.51797 .50853 .52489 .52425 .53766 .51879 .53075 .50313 Mtetra
.67 .606 .775 r
.53075 .50313 .53766 .51879 .55047 .51258 .54357 .49701 Mtetra
.681 .613 .773 r
.54357 .49701 .55047 .51258 .56331 .50564 .55643 .49019 Mtetra
.692 .62 .772 r
.55643 .49019 .56331 .50564 .57618 .49799 .56932 .4827 Mtetra
.702 .627 .77 r
.56932 .4827 .57618 .49799 .58907 .48967 .58224 .47458 Mtetra
.711 .634 .77 r
.58224 .47458 .58907 .48967 .60198 .48074 .59516 .46587 Mtetra
.72 .641 .769 r
.59516 .46587 .60198 .48074 .61489 .47124 .6081 .45662 Mtetra
.728 .648 .769 r
.6081 .45662 .61489 .47124 .6278 .46124 .62105 .44688 Mtetra
.735 .654 .77 r
.62105 .44688 .6278 .46124 .64071 .4508 .634 .43672 Mtetra
.742 .661 .771 r
.634 .43672 .64071 .4508 .65362 .43998 .64695 .4262 Mtetra
.748 .668 .772 r
.64695 .4262 .65362 .43998 .66653 .42887 .6599 .41538 Mtetra
.753 .674 .774 r
.6599 .41538 .66653 .42887 .67942 .41752 .67284 .40434 Mtetra
.758 .681 .776 r
.67284 .40434 .67942 .41752 .69232 .406 .68579 .39313 Mtetra
.762 .687 .779 r
.68579 .39313 .69232 .406 .70521 .39439 .69873 .38183 Mtetra
.766 .693 .782 r
.69873 .38183 .70521 .39439 .7181 .38275 .71168 .37049 Mtetra
.768 .699 .786 r
.71168 .37049 .7181 .38275 .73099 .37114 .72463 .35917 Mtetra
.77 .705 .79 r
.72463 .35917 .73099 .37114 .74389 .35962 .73759 .34793 Mtetra
.772 .711 .795 r
.73759 .34793 .74389 .35962 .7568 .34823 .75056 .33681 Mtetra
.772 .716 .8 r
.75056 .33681 .7568 .34823 .76973 .33702 .76356 .32587 Mtetra
.772 .721 .805 r
.76356 .32587 .76973 .33702 .78269 .32604 .77658 .31513 Mtetra
.771 .726 .811 r
.77658 .31513 .78269 .32604 .79567 .31531 .78963 .30463 Mtetra
.769 .731 .817 r
.78963 .30463 .79567 .31531 .80869 .30487 .80271 .29439 Mtetra
.767 .735 .823 r
.80271 .29439 .80869 .30487 .82175 .29472 .81584 .28444 Mtetra
.764 .739 .829 r
.81584 .28444 .82175 .29472 .83486 .28489 .82901 .27479 Mtetra
.761 .742 .836 r
.82901 .27479 .83486 .28489 .84801 .27539 .84224 .26544 Mtetra
.458 .608 .911 r
.21896 .48637 .22629 .49537 .23694 .49669 .22964 .48739 Mtetra
.451 .597 .906 r
.22964 .48739 .23694 .49669 .24764 .49824 .24038 .48862 Mtetra
.446 .587 .9 r
.24038 .48862 .24764 .49824 .25841 .50001 .25118 .49004 Mtetra
.442 .577 .893 r
.25118 .49004 .25841 .50001 .26925 .50197 .26205 .49165 Mtetra
.441 .568 .886 r
.26205 .49165 .26925 .50197 .28016 .50409 .27299 .49341 Mtetra
.441 .56 .88 r
.27299 .49341 .28016 .50409 .29115 .50635 .28401 .49528 Mtetra
.443 .553 .873 r
.28401 .49528 .29115 .50635 .30222 .50871 .2951 .49725 Mtetra
.446 .547 .865 r
.2951 .49725 .30222 .50871 .31338 .51112 .30629 .49927 Mtetra
.452 .543 .859 r
.30629 .49927 .31338 .51112 .32463 .51354 .31756 .50129 Mtetra
.459 .539 .852 r
.31756 .50129 .32463 .51354 .33597 .51591 .32892 .50327 Mtetra
.468 .537 .845 r
.32892 .50327 .33597 .51591 .34741 .51819 .34038 .50516 Mtetra
.478 .536 .838 r
.34038 .50516 .34741 .51819 .35896 .52032 .35194 .5069 Mtetra
.489 .536 .832 r
.35194 .5069 .35896 .52032 .37061 .52224 .3636 .50844 Mtetra
.5 .537 .826 r
.3636 .50844 .37061 .52224 .38236 .52388 .37536 .50973 Mtetra
.513 .539 .82 r
.37536 .50973 .38236 .52388 .39421 .52519 .38723 .5107 Mtetra
.526 .541 .814 r
.38723 .5107 .39421 .52519 .40617 .52611 .3992 .51131 Mtetra
.539 .545 .809 r
.3992 .51131 .40617 .52611 .41824 .52658 .41127 .51148 Mtetra
.553 .549 .804 r
.41127 .51148 .41824 .52658 .4304 .52654 .42344 .51119 Mtetra
.567 .553 .799 r
.42344 .51119 .4304 .52654 .44266 .52594 .4357 .51037 Mtetra
.58 .558 .794 r
.4357 .51037 .44266 .52594 .45502 .52474 .44806 .50898 Mtetra
.593 .564 .79 r
.44806 .50898 .45502 .52474 .46746 .5229 .4605 .50698 Mtetra
.606 .569 .786 r
.4605 .50698 .46746 .5229 .47998 .52037 .47303 .50435 Mtetra
.619 .575 .783 r
.47303 .50435 .47998 .52037 .49258 .51715 .48563 .50105 Mtetra
.632 .581 .78 r
.48563 .50105 .49258 .51715 .50524 .5132 .4983 .49707 Mtetra
.644 .588 .777 r
.4983 .49707 .50524 .5132 .51797 .50853 .51103 .49241 Mtetra
.655 .594 .774 r
.51103 .49241 .51797 .50853 .53075 .50313 .52382 .48706 Mtetra
.666 .601 .772 r
.52382 .48706 .53075 .50313 .54357 .49701 .53665 .48103 Mtetra
.677 .607 .77 r
.53665 .48103 .54357 .49701 .55643 .49019 .54953 .47434 Mtetra
.687 .614 .769 r
.54953 .47434 .55643 .49019 .56932 .4827 .56243 .46702 Mtetra
.696 .621 .768 r
.56243 .46702 .56932 .4827 .58224 .47458 .57536 .45909 Mtetra
.705 .627 .767 r
.57536 .45909 .58224 .47458 .59516 .46587 .58832 .4506 Mtetra
.714 .634 .767 r
.58832 .4506 .59516 .46587 .6081 .45662 .60128 .44159 Mtetra
.721 .641 .768 r
.60128 .44159 .6081 .45662 .62105 .44688 .61426 .43212 Mtetra
.729 .648 .768 r
.61426 .43212 .62105 .44688 .634 .43672 .62724 .42225 Mtetra
.735 .654 .769 r
.62724 .42225 .634 .43672 .64695 .4262 .64023 .41203 Mtetra
.741 .661 .771 r
.64023 .41203 .64695 .4262 .6599 .41538 .65322 .40152 Mtetra
.747 .668 .773 r
.65322 .40152 .6599 .41538 .67284 .40434 .66621 .3908 Mtetra
.751 .674 .776 r
.66621 .3908 .67284 .40434 .68579 .39313 .67921 .37991 Mtetra
.756 .681 .779 r
.67921 .37991 .68579 .39313 .69873 .38183 .6922 .36893 Mtetra
.759 .687 .782 r
.6922 .36893 .69873 .38183 .71168 .37049 .7052 .3579 Mtetra
.762 .693 .786 r
.7052 .3579 .71168 .37049 .72463 .35917 .71821 .3469 Mtetra
.764 .699 .79 r
.71821 .3469 .72463 .35917 .73759 .34793 .73123 .33595 Mtetra
.765 .705 .795 r
.73123 .33595 .73759 .34793 .75056 .33681 .74427 .32513 Mtetra
.766 .711 .8 r
.74427 .32513 .75056 .33681 .76356 .32587 .75733 .31445 Mtetra
.766 .716 .806 r
.75733 .31445 .76356 .32587 .77658 .31513 .77042 .30397 Mtetra
.765 .721 .811 r
.77042 .30397 .77658 .31513 .78963 .30463 .78353 .29371 Mtetra
.764 .726 .817 r
.78353 .29371 .78963 .30463 .80271 .29439 .79668 .2837 Mtetra
.762 .73 .823 r
.79668 .2837 .80271 .29439 .81584 .28444 .80988 .27396 Mtetra
.759 .734 .83 r
.80988 .27396 .81584 .28444 .82901 .27479 .82312 .26449 Mtetra
.756 .738 .836 r
.82312 .26449 .82901 .27479 .84224 .26544 .83641 .25532 Mtetra
.475 .615 .909 r
.21159 .47728 .21896 .48637 .22964 .48739 .2223 .47798 Mtetra
.469 .604 .903 r
.2223 .47798 .22964 .48739 .24038 .48862 .23308 .47888 Mtetra
.464 .594 .897 r
.23308 .47888 .24038 .48862 .25118 .49004 .24391 .47997 Mtetra
.461 .585 .891 r
.24391 .47997 .25118 .49004 .26205 .49165 .25481 .48121 Mtetra
.46 .576 .884 r
.25481 .48121 .26205 .49165 .27299 .49341 .26578 .4826 Mtetra
.459 .568 .877 r
.26578 .4826 .27299 .49341 .28401 .49528 .27683 .48409 Mtetra
.461 .561 .87 r
.27683 .48409 .28401 .49528 .2951 .49725 .28795 .48566 Mtetra
.464 .555 .863 r
.28795 .48566 .2951 .49725 .30629 .49927 .29916 .48728 Mtetra
.469 .55 .856 r
.29916 .48728 .30629 .49927 .31756 .50129 .31046 .4889 Mtetra
.475 .546 .849 r
.31046 .4889 .31756 .50129 .32892 .50327 .32184 .49047 Mtetra
.483 .543 .842 r
.32184 .49047 .32892 .50327 .34038 .50516 .33332 .49196 Mtetra
.492 .541 .836 r
.33332 .49196 .34038 .50516 .35194 .5069 .3449 .49331 Mtetra
.501 .541 .829 r
.3449 .49331 .35194 .5069 .3636 .50844 .35658 .49447 Mtetra
.512 .541 .823 r
.35658 .49447 .3636 .50844 .37536 .50973 .36835 .49539 Mtetra
.523 .542 .817 r
.36835 .49539 .37536 .50973 .38723 .5107 .38023 .49602 Mtetra
.535 .544 .811 r
.38023 .49602 .38723 .5107 .3992 .51131 .3922 .4963 Mtetra
.547 .547 .806 r
.3922 .4963 .3992 .51131 .41127 .51148 .40428 .49618 Mtetra
.559 .55 .801 r
.40428 .49618 .41127 .51148 .42344 .51119 .41645 .49562 Mtetra
.571 .554 .796 r
.41645 .49562 .42344 .51119 .4357 .51037 .42872 .49456 Mtetra
.583 .558 .791 r
.42872 .49456 .4357 .51037 .44806 .50898 .44108 .49297 Mtetra
.596 .563 .787 r
.44108 .49297 .44806 .50898 .4605 .50698 .45353 .49082 Mtetra
.608 .568 .784 r
.45353 .49082 .4605 .50698 .47303 .50435 .46606 .48806 Mtetra
.619 .573 .78 r
.46606 .48806 .47303 .50435 .48563 .50105 .47866 .48469 Mtetra
.631 .579 .777 r
.47866 .48469 .48563 .50105 .4983 .49707 .49134 .48067 Mtetra
.642 .584 .775 r
.49134 .48067 .4983 .49707 .51103 .49241 .50407 .47601 Mtetra
.653 .59 .772 r
.50407 .47601 .51103 .49241 .52382 .48706 .51687 .47071 Mtetra
.663 .597 .77 r
.51687 .47071 .52382 .48706 .53665 .48103 .52971 .46476 Mtetra
.673 .603 .769 r
.52971 .46476 .53665 .48103 .54953 .47434 .54259 .45819 Mtetra
.683 .609 .768 r
.54259 .45819 .54953 .47434 .56243 .46702 .55551 .45103 Mtetra
.692 .616 .767 r
.55551 .45103 .56243 .46702 .57536 .45909 .56846 .44329 Mtetra
.7 .622 .766 r
.56846 .44329 .57536 .45909 .58832 .4506 .58144 .43502 Mtetra
.708 .629 .766 r
.58144 .43502 .58832 .4506 .60128 .44159 .59443 .42627 Mtetra
.716 .636 .767 r
.59443 .42627 .60128 .44159 .61426 .43212 .60744 .41707 Mtetra
.723 .642 .768 r
.60744 .41707 .61426 .43212 .62724 .42225 .62045 .40749 Mtetra
.729 .649 .769 r
.62045 .40749 .62724 .42225 .64023 .41203 .63348 .39757 Mtetra
.735 .656 .771 r
.63348 .39757 .64023 .41203 .65322 .40152 .64651 .38738 Mtetra
.74 .662 .773 r
.64651 .38738 .65322 .40152 .66621 .3908 .65954 .37698 Mtetra
.745 .669 .776 r
.65954 .37698 .66621 .3908 .67921 .37991 .67258 .36642 Mtetra
.749 .675 .779 r
.67258 .36642 .67921 .37991 .6922 .36893 .68563 .35577 Mtetra
.753 .682 .783 r
.68563 .35577 .6922 .36893 .7052 .3579 .69868 .34507 Mtetra
.755 .688 .787 r
.69868 .34507 .7052 .3579 .71821 .3469 .71175 .33438 Mtetra
.758 .694 .791 r
.71175 .33438 .71821 .3469 .73123 .33595 .72483 .32374 Mtetra
.759 .7 .796 r
.72483 .32374 .73123 .33595 .74427 .32513 .73793 .31321 Mtetra
.76 .706 .801 r
.73793 .31321 .74427 .32513 .75733 .31445 .75105 .30282 Mtetra
.76 .711 .806 r
.75105 .30282 .75733 .31445 .77042 .30397 .7642 .29261 Mtetra
.76 .717 .812 r
.7642 .29261 .77042 .30397 .78353 .29371 .77738 .2826 Mtetra
.758 .722 .818 r
.77738 .2826 .78353 .29371 .79668 .2837 .7906 .27283 Mtetra
.757 .726 .824 r
.7906 .27283 .79668 .2837 .80988 .27396 .80386 .2633 Mtetra
.754 .73 .83 r
.80386 .2633 .80988 .27396 .82312 .26449 .81716 .25403 Mtetra
.751 .734 .837 r
.81716 .25403 .82312 .26449 .83641 .25532 .83052 .24503 Mtetra
.491 .621 .907 r
.20417 .4681 .21159 .47728 .2223 .47798 .21492 .4685 Mtetra
.486 .612 .902 r
.21492 .4685 .2223 .47798 .23308 .47888 .22573 .46907 Mtetra
.481 .602 .896 r
.22573 .46907 .23308 .47888 .24391 .47997 .23659 .46981 Mtetra
.478 .593 .889 r
.23659 .46981 .24391 .47997 .25481 .48121 .24753 .4707 Mtetra
.477 .584 .883 r
.24753 .4707 .25481 .48121 .26578 .4826 .25853 .47171 Mtetra
.477 .576 .876 r
.25853 .47171 .26578 .4826 .27683 .48409 .26961 .47282 Mtetra
.478 .569 .869 r
.26961 .47282 .27683 .48409 .28795 .48566 .28076 .47399 Mtetra
.481 .563 .862 r
.28076 .47399 .28795 .48566 .29916 .48728 .292 .47521 Mtetra
.485 .558 .855 r
.292 .47521 .29916 .48728 .31046 .4889 .30332 .47642 Mtetra
.49 .553 .848 r
.30332 .47642 .31046 .4889 .32184 .49047 .31473 .47759 Mtetra
.497 .55 .841 r
.31473 .47759 .32184 .49047 .33332 .49196 .32623 .47868 Mtetra
.505 .548 .834 r
.32623 .47868 .33332 .49196 .3449 .49331 .33783 .47963 Mtetra
.513 .546 .827 r
.33783 .47963 .3449 .49331 .35658 .49447 .34952 .48041 Mtetra
.522 .546 .821 r
.34952 .48041 .35658 .49447 .36835 .49539 .36131 .48096 Mtetra
.532 .546 .815 r
.36131 .48096 .36835 .49539 .38023 .49602 .3732 .48123 Mtetra
.543 .548 .809 r
.3732 .48123 .38023 .49602 .3922 .4963 .38519 .48118 Mtetra
.554 .549 .804 r
.38519 .48118 .3922 .4963 .40428 .49618 .39727 .48076 Mtetra
.565 .552 .799 r
.39727 .48076 .40428 .49618 .41645 .49562 .40945 .47992 Mtetra
.576 .555 .794 r
.40945 .47992 .41645 .49562 .42872 .49456 .42172 .47862 Mtetra
.587 .559 .79 r
.42172 .47862 .42872 .49456 .44108 .49297 .43409 .47683 Mtetra
.598 .563 .786 r
.43409 .47683 .44108 .49297 .45353 .49082 .44653 .47451 Mtetra
.609 .567 .782 r
.44653 .47451 .45353 .49082 .46606 .48806 .45907 .47163 Mtetra
.62 .572 .779 r
.45907 .47163 .46606 .48806 .47866 .48469 .47167 .46816 Mtetra
.631 .577 .776 r
.47167 .46816 .47866 .48469 .49134 .48067 .48435 .4641 Mtetra
.641 .583 .773 r
.48435 .4641 .49134 .48067 .50407 .47601 .49709 .45944 Mtetra
.651 .588 .771 r
.49709 .45944 .50407 .47601 .51687 .47071 .50989 .45417 Mtetra
.661 .594 .77 r
.50989 .45417 .51687 .47071 .52971 .46476 .52274 .44831 Mtetra
.67 .6 .768 r
.52274 .44831 .52971 .46476 .54259 .45819 .53564 .44186 Mtetra
.679 .606 .767 r
.53564 .44186 .54259 .45819 .55551 .45103 .54857 .43484 Mtetra
.688 .612 .767 r
.54857 .43484 .55551 .45103 .56846 .44329 .56154 .4273 Mtetra
.696 .619 .766 r
.56154 .4273 .56846 .44329 .58144 .43502 .57453 .41925 Mtetra
.704 .625 .767 r
.57453 .41925 .58144 .43502 .59443 .42627 .58754 .41074 Mtetra
.711 .632 .767 r
.58754 .41074 .59443 .42627 .60744 .41707 .60058 .40181 Mtetra
.718 .638 .768 r
.60058 .40181 .60744 .41707 .62045 .40749 .61362 .39252 Mtetra
.724 .645 .77 r
.61362 .39252 .62045 .40749 .63348 .39757 .62668 .38291 Mtetra
.729 .651 .772 r
.62668 .38291 .63348 .39757 .64651 .38738 .63975 .37304 Mtetra
.735 .658 .774 r
.63975 .37304 .64651 .38738 .65954 .37698 .65283 .36296 Mtetra
.739 .664 .777 r
.65283 .36296 .65954 .37698 .67258 .36642 .66592 .35273 Mtetra
.743 .671 .78 r
.66592 .35273 .67258 .36642 .68563 .35577 .67901 .34241 Mtetra
.747 .677 .784 r
.67901 .34241 .68563 .35577 .69868 .34507 .69212 .33204 Mtetra
.75 .684 .788 r
.69212 .33204 .69868 .34507 .71175 .33438 .70524 .32167 Mtetra
.752 .69 .792 r
.70524 .32167 .71175 .33438 .72483 .32374 .71838 .31135 Mtetra
.753 .696 .797 r
.71838 .31135 .72483 .32374 .73793 .31321 .73154 .30112 Mtetra
.754 .702 .802 r
.73154 .30112 .73793 .31321 .75105 .30282 .74472 .29102 Mtetra
.754 .708 .808 r
.74472 .29102 .75105 .30282 .7642 .29261 .75793 .28108 Mtetra
.754 .713 .814 r
.75793 .28108 .7642 .29261 .77738 .2826 .77118 .27133 Mtetra
.753 .718 .819 r
.77118 .27133 .77738 .2826 .7906 .27283 .78446 .26179 Mtetra
.751 .723 .826 r
.78446 .26179 .7906 .27283 .80386 .2633 .79779 .25249 Mtetra
.749 .727 .832 r
.79779 .25249 .80386 .2633 .81716 .25403 .81116 .24342 Mtetra
.746 .731 .838 r
.81116 .24342 .81716 .25403 .83052 .24503 .82459 .2346 Mtetra
.505 .628 .906 r
.1967 .45888 .20417 .4681 .21492 .4685 .20749 .45897 Mtetra
.501 .619 .9 r
.20749 .45897 .21492 .4685 .22573 .46907 .21833 .45922 Mtetra
.497 .61 .894 r
.21833 .45922 .22573 .46907 .23659 .46981 .22923 .45961 Mtetra
.494 .601 .888 r
.22923 .45961 .23659 .46981 .24753 .4707 .2402 .46014 Mtetra
.493 .592 .882 r
.2402 .46014 .24753 .4707 .25853 .47171 .25124 .46078 Mtetra
.493 .585 .875 r
.25124 .46078 .25853 .47171 .26961 .47282 .26235 .4615 Mtetra
.494 .577 .868 r
.26235 .4615 .26961 .47282 .28076 .47399 .27354 .46229 Mtetra
.496 .571 .861 r
.27354 .46229 .28076 .47399 .292 .47521 .2848 .4631 Mtetra
.5 .566 .854 r
.2848 .4631 .292 .47521 .30332 .47642 .29615 .46391 Mtetra
.504 .561 .847 r
.29615 .46391 .30332 .47642 .31473 .47759 .30758 .46468 Mtetra
.51 .557 .84 r
.30758 .46468 .31473 .47759 .32623 .47868 .31911 .46536 Mtetra
.517 .555 .833 r
.31911 .46536 .32623 .47868 .33783 .47963 .33073 .46592 Mtetra
.524 .553 .827 r
.33073 .46592 .33783 .47963 .34952 .48041 .34244 .46632 Mtetra
.532 .552 .821 r
.34244 .46632 .34952 .48041 .36131 .48096 .35424 .4665 Mtetra
.541 .552 .815 r
.35424 .4665 .36131 .48096 .3732 .48123 .36614 .46642 Mtetra
.551 .552 .809 r
.36614 .46642 .3732 .48123 .38519 .48118 .37814 .46604 Mtetra
.56 .553 .803 r
.37814 .46604 .38519 .48118 .39727 .48076 .39023 .46531 Mtetra
.57 .555 .798 r
.39023 .46531 .39727 .48076 .40945 .47992 .40242 .4642 Mtetra
.58 .558 .794 r
.40242 .4642 .40945 .47992 .42172 .47862 .4147 .46266 Mtetra
.59 .561 .789 r
.4147 .46266 .42172 .47862 .43409 .47683 .42707 .46065 Mtetra
.601 .564 .785 r
.42707 .46065 .43409 .47683 .44653 .47451 .43952 .45816 Mtetra
.611 .568 .782 r
.43952 .45816 .44653 .47451 .45907 .47163 .45205 .45514 Mtetra
.621 .573 .779 r
.45205 .45514 .45907 .47163 .47167 .46816 .46466 .45159 Mtetra
.631 .577 .776 r
.46466 .45159 .47167 .46816 .48435 .4641 .47734 .44748 Mtetra
.64 .582 .773 r
.47734 .44748 .48435 .4641 .49709 .45944 .49009 .4428 Mtetra
.65 .587 .771 r
.49009 .4428 .49709 .45944 .50989 .45417 .50289 .43757 Mtetra
.659 .593 .77 r
.50289 .43757 .50989 .45417 .52274 .44831 .51575 .43177 Mtetra
.668 .599 .769 r
.51575 .43177 .52274 .44831 .53564 .44186 .52866 .42543 Mtetra
.676 .604 .768 r
.52866 .42543 .53564 .44186 .54857 .43484 .5416 .41857 Mtetra
.684 .61 .767 r
.5416 .41857 .54857 .43484 .56154 .4273 .55458 .4112 Mtetra
.692 .616 .767 r
.55458 .4112 .56154 .4273 .57453 .41925 .56759 .40336 Mtetra
.699 .623 .767 r
.56759 .40336 .57453 .41925 .58754 .41074 .58063 .39509 Mtetra
.706 .629 .768 r
.58063 .39509 .58754 .41074 .60058 .40181 .59369 .38643 Mtetra
.713 .635 .769 r
.59369 .38643 .60058 .40181 .61362 .39252 .60677 .37742 Mtetra
.719 .642 .771 r
.60677 .37742 .61362 .39252 .62668 .38291 .61986 .36811 Mtetra
.724 .648 .773 r
.61986 .36811 .62668 .38291 .63975 .37304 .63296 .35856 Mtetra
.729 .655 .776 r
.63296 .35856 .63975 .37304 .65283 .36296 .64608 .34881 Mtetra
.734 .661 .778 r
.64608 .34881 .65283 .36296 .66592 .35273 .65921 .33891 Mtetra
.738 .668 .782 r
.65921 .33891 .66592 .35273 .67901 .34241 .67236 .32891 Mtetra
.741 .674 .785 r
.67236 .32891 .67901 .34241 .69212 .33204 .68552 .31887 Mtetra
.744 .681 .79 r
.68552 .31887 .69212 .33204 .70524 .32167 .69869 .30882 Mtetra
.746 .687 .794 r
.69869 .30882 .70524 .32167 .71838 .31135 .71189 .29882 Mtetra
.748 .693 .799 r
.71189 .29882 .71838 .31135 .73154 .30112 .7251 .28889 Mtetra
.749 .699 .804 r
.7251 .28889 .73154 .30112 .74472 .29102 .73835 .27908 Mtetra
.749 .705 .81 r
.73835 .27908 .74472 .29102 .75793 .28108 .75162 .26942 Mtetra
.749 .71 .815 r
.75162 .26942 .75793 .28108 .77118 .27133 .76493 .25993 Mtetra
.748 .715 .821 r
.76493 .25993 .77118 .27133 .78446 .26179 .77828 .25064 Mtetra
.746 .72 .827 r
.77828 .25064 .78446 .26179 .79779 .25249 .79167 .24155 Mtetra
.744 .724 .833 r
.79167 .24155 .79779 .25249 .81116 .24342 .80511 .23269 Mtetra
.742 .728 .839 r
.80511 .23269 .81116 .24342 .82459 .2346 .8186 .22406 Mtetra
.519 .635 .904 r
.18918 .44962 .1967 .45888 .20749 .45897 .2 .44941 Mtetra
.515 .626 .899 r
.2 .44941 .20749 .45897 .21833 .45922 .21088 .44934 Mtetra
.511 .617 .894 r
.21088 .44934 .21833 .45922 .22923 .45961 .22182 .4494 Mtetra
.509 .609 .888 r
.22182 .4494 .22923 .45961 .2402 .46014 .23283 .44958 Mtetra
.508 .6 .881 r
.23283 .44958 .2402 .46014 .25124 .46078 .2439 .44985 Mtetra
.507 .593 .875 r
.2439 .44985 .25124 .46078 .26235 .4615 .25504 .4502 Mtetra
.508 .586 .868 r
.25504 .4502 .26235 .4615 .27354 .46229 .26626 .4506 Mtetra
.51 .58 .861 r
.26626 .4506 .27354 .46229 .2848 .4631 .27756 .45102 Mtetra
.513 .574 .854 r
.27756 .45102 .2848 .4631 .29615 .46391 .28894 .45143 Mtetra
.517 .569 .847 r
.28894 .45143 .29615 .46391 .30758 .46468 .3004 .4518 Mtetra
.522 .565 .84 r
.3004 .4518 .30758 .46468 .31911 .46536 .31195 .45209 Mtetra
.528 .562 .834 r
.31195 .45209 .31911 .46536 .33073 .46592 .32358 .45226 Mtetra
.535 .56 .827 r
.32358 .45226 .33073 .46592 .34244 .46632 .33531 .45227 Mtetra
.542 .558 .821 r
.33531 .45227 .34244 .46632 .35424 .4665 .34714 .45208 Mtetra
.55 .558 .815 r
.34714 .45208 .35424 .4665 .36614 .46642 .35905 .45165 Mtetra
.558 .558 .809 r
.35905 .45165 .36614 .46642 .37814 .46604 .37106 .45094 Mtetra
.567 .558 .804 r
.37106 .45094 .37814 .46604 .39023 .46531 .38317 .44991 Mtetra
.576 .56 .799 r
.38317 .44991 .39023 .46531 .40242 .4642 .39536 .44852 Mtetra
.585 .562 .794 r
.39536 .44852 .40242 .4642 .4147 .46266 .40765 .44674 Mtetra
.594 .564 .79 r
.40765 .44674 .4147 .46266 .42707 .46065 .42002 .44452 Mtetra
.603 .567 .786 r
.42002 .44452 .42707 .46065 .43952 .45816 .43248 .44185 Mtetra
.613 .57 .783 r
.43248 .44185 .43952 .45816 .45205 .45514 .44501 .4387 Mtetra
.622 .574 .78 r
.44501 .4387 .45205 .45514 .46466 .45159 .45763 .43505 Mtetra
.631 .578 .777 r
.45763 .43505 .46466 .45159 .47734 .44748 .47031 .43088 Mtetra
.64 .583 .775 r
.47031 .43088 .47734 .44748 .49009 .4428 .48306 .42619 Mtetra
.649 .588 .773 r
.48306 .42619 .49009 .4428 .50289 .43757 .49587 .42098 Mtetra
.658 .593 .771 r
.49587 .42098 .50289 .43757 .51575 .43177 .50874 .41525 Mtetra
.666 .598 .77 r
.50874 .41525 .51575 .43177 .52866 .42543 .52165 .40901 Mtetra
.674 .604 .769 r
.52165 .40901 .52866 .42543 .5416 .41857 .53461 .40228 Mtetra
.682 .609 .769 r
.53461 .40228 .5416 .41857 .55458 .4112 .5476 .39508 Mtetra
.689 .615 .769 r
.5476 .39508 .55458 .4112 .56759 .40336 .56063 .38745 Mtetra
.696 .621 .769 r
.56063 .38745 .56759 .40336 .58063 .39509 .57369 .37941 Mtetra
.702 .628 .77 r
.57369 .37941 .58063 .39509 .59369 .38643 .58677 .37101 Mtetra
.709 .634 .771 r
.58677 .37101 .59369 .38643 .60677 .37742 .59988 .36228 Mtetra
.714 .64 .773 r
.59988 .36228 .60677 .37742 .61986 .36811 .613 .35327 Mtetra
.72 .646 .775 r
.613 .35327 .61986 .36811 .63296 .35856 .62614 .34402 Mtetra
.725 .653 .778 r
.62614 .34402 .63296 .35856 .64608 .34881 .6393 .33459 Mtetra
.729 .659 .781 r
.6393 .33459 .64608 .34881 .65921 .33891 .65248 .32501 Mtetra
.733 .666 .784 r
.65248 .32501 .65921 .33891 .67236 .32891 .66567 .31534 Mtetra
.736 .672 .788 r
.66567 .31534 .67236 .32891 .68552 .31887 .67887 .30562 Mtetra
.739 .678 .792 r
.67887 .30562 .68552 .31887 .69869 .30882 .6921 .29589 Mtetra
.741 .685 .797 r
.6921 .29589 .69869 .30882 .71189 .29882 .70535 .2862 Mtetra
.743 .691 .801 r
.70535 .2862 .71189 .29882 .7251 .28889 .71863 .27658 Mtetra
.744 .697 .807 r
.71863 .27658 .7251 .28889 .73835 .27908 .73193 .26706 Mtetra
.744 .702 .812 r
.73193 .26706 .73835 .27908 .75162 .26942 .74526 .25767 Mtetra
.744 .708 .818 r
.74526 .25767 .75162 .26942 .76493 .25993 .75864 .24844 Mtetra
.743 .713 .823 r
.75864 .24844 .76493 .25993 .77828 .25064 .77205 .23938 Mtetra
.742 .718 .829 r
.77205 .23938 .77828 .25064 .79167 .24155 .78551 .23052 Mtetra
.74 .722 .835 r
.78551 .23052 .79167 .24155 .80511 .23269 .79901 .22187 Mtetra
.737 .726 .841 r
.79901 .22187 .80511 .23269 .8186 .22406 .81257 .21342 Mtetra
.531 .641 .903 r
.1816 .44035 .18918 .44962 .2 .44941 .19246 .43984 Mtetra
.527 .633 .898 r
.19246 .43984 .2 .44941 .21088 .44934 .20338 .43946 Mtetra
.525 .625 .893 r
.20338 .43946 .21088 .44934 .22182 .4494 .21436 .43919 Mtetra
.522 .616 .887 r
.21436 .43919 .22182 .4494 .23283 .44958 .2254 .43903 Mtetra
.521 .609 .881 r
.2254 .43903 .23283 .44958 .2439 .44985 .23651 .43895 Mtetra
.521 .601 .875 r
.23651 .43895 .2439 .44985 .25504 .4502 .24769 .43893 Mtetra
.521 .594 .868 r
.24769 .43893 .25504 .4502 .26626 .4506 .25894 .43895 Mtetra
.523 .588 .861 r
.25894 .43895 .26626 .4506 .27756 .45102 .27027 .43899 Mtetra
.526 .583 .855 r
.27027 .43899 .27756 .45102 .28894 .45143 .28168 .43901 Mtetra
.529 .578 .848 r
.28168 .43901 .28894 .45143 .3004 .4518 .29317 .43899 Mtetra
.533 .573 .841 r
.29317 .43899 .3004 .4518 .31195 .45209 .30474 .43889 Mtetra
.539 .57 .835 r
.30474 .43889 .31195 .45209 .32358 .45226 .3164 .43868 Mtetra
.544 .567 .828 r
.3164 .43868 .32358 .45226 .33531 .45227 .32815 .43832 Mtetra
.551 .565 .822 r
.32815 .43832 .33531 .45227 .34714 .45208 .34 .43777 Mtetra
.558 .564 .816 r
.34 .43777 .34714 .45208 .35905 .45165 .35193 .437 Mtetra
.565 .564 .811 r
.35193 .437 .35905 .45165 .37106 .45094 .36395 .43597 Mtetra
.573 .564 .805 r
.36395 .43597 .37106 .45094 .38317 .44991 .37607 .43464 Mtetra
.581 .565 .8 r
.37607 .43464 .38317 .44991 .39536 .44852 .38827 .43297 Mtetra
.59 .566 .796 r
.38827 .43297 .39536 .44852 .40765 .44674 .40057 .43094 Mtetra
.598 .568 .792 r
.40057 .43094 .40765 .44674 .42002 .44452 .41295 .42852 Mtetra
.606 .571 .788 r
.41295 .42852 .42002 .44452 .43248 .44185 .42541 .42567 Mtetra
.615 .574 .784 r
.42541 .42567 .43248 .44185 .44501 .4387 .43795 .42238 Mtetra
.624 .577 .781 r
.43795 .42238 .44501 .4387 .45763 .43505 .45057 .41862 Mtetra
.632 .581 .779 r
.45057 .41862 .45763 .43505 .47031 .43088 .46326 .41439 Mtetra
.64 .585 .776 r
.46326 .41439 .47031 .43088 .48306 .42619 .47601 .40968 Mtetra
.649 .589 .775 r
.47601 .40968 .48306 .42619 .49587 .42098 .48883 .40449 Mtetra
.657 .594 .773 r
.48883 .40449 .49587 .42098 .50874 .41525 .5017 .39881 Mtetra
.664 .599 .772 r
.5017 .39881 .50874 .41525 .52165 .40901 .51462 .39267 Mtetra
.672 .604 .771 r
.51462 .39267 .52165 .40901 .53461 .40228 .52759 .38607 Mtetra
.679 .61 .771 r
.52759 .38607 .53461 .40228 .5476 .39508 .5406 .37904 Mtetra
.686 .615 .771 r
.5406 .37904 .5476 .39508 .56063 .38745 .55365 .3716 Mtetra
.693 .621 .772 r
.55365 .3716 .56063 .38745 .57369 .37941 .56673 .36378 Mtetra
.699 .627 .773 r
.56673 .36378 .57369 .37941 .58677 .37101 .57983 .35562 Mtetra
.705 .633 .774 r
.57983 .35562 .58677 .37101 .59988 .36228 .59296 .34716 Mtetra
.711 .639 .776 r
.59296 .34716 .59988 .36228 .613 .35327 .60612 .33843 Mtetra
.716 .646 .778 r
.60612 .33843 .613 .35327 .62614 .34402 .61929 .32948 Mtetra
.72 .652 .781 r
.61929 .32948 .62614 .34402 .6393 .33459 .63249 .32036 Mtetra
.724 .658 .784 r
.63249 .32036 .6393 .33459 .65248 .32501 .6457 .3111 Mtetra
.728 .665 .787 r
.6457 .3111 .65248 .32501 .66567 .31534 .65894 .30174 Mtetra
.731 .671 .791 r
.65894 .30174 .66567 .31534 .67887 .30562 .67219 .29234 Mtetra
.734 .677 .795 r
.67219 .29234 .67887 .30562 .6921 .29589 .68547 .28292 Mtetra
.736 .683 .8 r
.68547 .28292 .6921 .29589 .70535 .2862 .69878 .27354 Mtetra
.738 .689 .804 r
.69878 .27354 .70535 .2862 .71863 .27658 .71211 .26421 Mtetra
.739 .695 .81 r
.71211 .26421 .71863 .27658 .73193 .26706 .72547 .25497 Mtetra
.739 .701 .815 r
.72547 .25497 .73193 .26706 .74526 .25767 .73887 .24585 Mtetra
.739 .706 .82 r
.73887 .24585 .74526 .25767 .75864 .24844 .7523 .23687 Mtetra
.738 .711 .826 r
.7523 .23687 .75864 .24844 .77205 .23938 .76578 .22806 Mtetra
.737 .716 .832 r
.76578 .22806 .77205 .23938 .78551 .23052 .7793 .21942 Mtetra
.735 .721 .837 r
.7793 .21942 .78551 .23052 .79901 .22187 .79287 .21096 Mtetra
.733 .725 .843 r
.79287 .21096 .79901 .22187 .81257 .21342 .80649 .20271 Mtetra
.543 .648 .903 r
.17397 .43108 .1816 .44035 .19246 .43984 .18487 .43029 Mtetra
.539 .64 .898 r
.18487 .43029 .19246 .43984 .20338 .43946 .19582 .42961 Mtetra
.537 .632 .893 r
.19582 .42961 .20338 .43946 .21436 .43919 .20684 .42902 Mtetra
.535 .624 .887 r
.20684 .42902 .21436 .43919 .2254 .43903 .21792 .42852 Mtetra
.534 .617 .881 r
.21792 .42852 .2254 .43903 .23651 .43895 .22907 .4281 Mtetra
.533 .61 .875 r
.22907 .4281 .23651 .43895 .24769 .43893 .24028 .42772 Mtetra
.534 .603 .869 r
.24028 .42772 .24769 .43893 .25894 .43895 .25157 .42738 Mtetra
.535 .597 .862 r
.25157 .42738 .25894 .43895 .27027 .43899 .26293 .42705 Mtetra
.537 .591 .856 r
.26293 .42705 .27027 .43899 .28168 .43901 .27437 .42669 Mtetra
.54 .586 .849 r
.27437 .42669 .28168 .43901 .29317 .43899 .28589 .42629 Mtetra
.544 .582 .843 r
.28589 .42629 .29317 .43899 .30474 .43889 .29749 .42582 Mtetra
.549 .578 .836 r
.29749 .42582 .30474 .43889 .3164 .43868 .30918 .42524 Mtetra
.554 .575 .83 r
.30918 .42524 .3164 .43868 .32815 .43832 .32095 .42452 Mtetra
.56 .573 .824 r
.32095 .42452 .32815 .43832 .34 .43777 .33281 .42362 Mtetra
.566 .572 .818 r
.33281 .42362 .34 .43777 .35193 .437 .34476 .42251 Mtetra
.572 .571 .813 r
.34476 .42251 .35193 .437 .36395 .43597 .3568 .42116 Mtetra
.579 .57 .808 r
.3568 .42116 .36395 .43597 .37607 .43464 .36893 .41954 Mtetra
.587 .571 .803 r
.36893 .41954 .37607 .43464 .38827 .43297 .38115 .41761 Mtetra
.594 .572 .798 r
.38115 .41761 .38827 .43297 .40057 .43094 .39345 .41534 Mtetra
.602 .573 .794 r
.39345 .41534 .40057 .43094 .41295 .42852 .40584 .4127 Mtetra
.61 .575 .79 r
.40584 .4127 .41295 .42852 .42541 .42567 .41831 .40968 Mtetra
.618 .578 .787 r
.41831 .40968 .42541 .42567 .43795 .42238 .43086 .40625 Mtetra
.625 .581 .784 r
.43086 .40625 .43795 .42238 .45057 .41862 .44348 .40239 Mtetra
.633 .584 .781 r
.44348 .40239 .45057 .41862 .46326 .41439 .45617 .3981 Mtetra
.641 .588 .779 r
.45617 .3981 .46326 .41439 .47601 .40968 .46893 .39336 Mtetra
.649 .592 .777 r
.46893 .39336 .47601 .40968 .48883 .40449 .48176 .38817 Mtetra
.656 .596 .776 r
.48176 .38817 .48883 .40449 .5017 .39881 .49464 .38254 Mtetra
.663 .601 .775 r
.49464 .38254 .5017 .39881 .51462 .39267 .50757 .37648 Mtetra
.67 .606 .774 r
.50757 .37648 .51462 .39267 .52759 .38607 .52055 .37 Mtetra
.677 .611 .774 r
.52055 .37 .52759 .38607 .5406 .37904 .53357 .36312 Mtetra
.684 .616 .774 r
.53357 .36312 .5406 .37904 .55365 .3716 .54664 .35587 Mtetra
.69 .622 .775 r
.54664 .35587 .55365 .3716 .56673 .36378 .55973 .34826 Mtetra
.696 .628 .776 r
.55973 .34826 .56673 .36378 .57983 .35562 .57286 .34033 Mtetra
.702 .634 .777 r
.57286 .34033 .57983 .35562 .59296 .34716 .58602 .33213 Mtetra
.707 .64 .779 r
.58602 .33213 .59296 .34716 .60612 .33843 .59921 .32367 Mtetra
.712 .646 .782 r
.59921 .32367 .60612 .33843 .61929 .32948 .61241 .31501 Mtetra
.716 .652 .784 r
.61241 .31501 .61929 .32948 .63249 .32036 .62565 .30618 Mtetra
.72 .658 .787 r
.62565 .30618 .63249 .32036 .6457 .3111 .6389 .29722 Mtetra
.724 .664 .791 r
.6389 .29722 .6457 .3111 .65894 .30174 .65218 .28817 Mtetra
.727 .67 .794 r
.65218 .28817 .65894 .30174 .67219 .29234 .66548 .27907 Mtetra
.729 .677 .799 r
.66548 .27907 .67219 .29234 .68547 .28292 .67881 .26996 Mtetra
.732 .683 .803 r
.67881 .26996 .68547 .28292 .69878 .27354 .69217 .26086 Mtetra
.733 .689 .808 r
.69217 .26086 .69878 .27354 .71211 .26421 .70555 .25182 Mtetra
.734 .694 .813 r
.70555 .25182 .71211 .26421 .72547 .25497 .71897 .24286 Mtetra
.734 .7 .818 r
.71897 .24286 .72547 .25497 .73887 .24585 .73243 .234 Mtetra
.734 .705 .823 r
.73243 .234 .73887 .24585 .7523 .23687 .74592 .22527 Mtetra
.734 .71 .829 r
.74592 .22527 .7523 .23687 .76578 .22806 .75946 .21669 Mtetra
.733 .715 .834 r
.75946 .21669 .76578 .22806 .7793 .21942 .77304 .20826 Mtetra
.731 .72 .84 r
.77304 .20826 .7793 .21942 .79287 .21096 .78668 .20001 Mtetra
.729 .724 .846 r
.78668 .20001 .79287 .21096 .80649 .20271 .80037 .19193 Mtetra
.553 .654 .902 r
.16627 .42182 .17397 .43108 .18487 .43029 .17721 .42076 Mtetra
.55 .647 .898 r
.17721 .42076 .18487 .43029 .19582 .42961 .18821 .41979 Mtetra
.548 .639 .893 r
.18821 .41979 .19582 .42961 .20684 .42902 .19926 .4189 Mtetra
.546 .632 .887 r
.19926 .4189 .20684 .42902 .21792 .42852 .21038 .41808 Mtetra
.545 .625 .882 r
.21038 .41808 .21792 .42852 .22907 .4281 .22156 .41732 Mtetra
.545 .618 .876 r
.22156 .41732 .22907 .4281 .24028 .42772 .23281 .41661 Mtetra
.545 .612 .87 r
.23281 .41661 .24028 .42772 .25157 .42738 .24414 .41592 Mtetra
.546 .606 .864 r
.24414 .41592 .25157 .42738 .26293 .42705 .25553 .41522 Mtetra
.548 .6 .858 r
.25553 .41522 .26293 .42705 .27437 .42669 .267 .41451 Mtetra
.551 .595 .851 r
.267 .41451 .27437 .42669 .28589 .42629 .27855 .41375 Mtetra
.554 .591 .845 r
.27855 .41375 .28589 .42629 .29749 .42582 .29018 .41291 Mtetra
.558 .587 .839 r
.29018 .41291 .29749 .42582 .30918 .42524 .3019 .41197 Mtetra
.563 .584 .833 r
.3019 .41197 .30918 .42524 .32095 .42452 .3137 .4109 Mtetra
.568 .581 .827 r
.3137 .4109 .32095 .42452 .33281 .42362 .32558 .40967 Mtetra
.573 .579 .821 r
.32558 .40967 .33281 .42362 .34476 .42251 .33755 .40824 Mtetra
.579 .578 .816 r
.33755 .40824 .34476 .42251 .3568 .42116 .34961 .40658 Mtetra
.586 .578 .811 r
.34961 .40658 .3568 .42116 .36893 .41954 .36175 .40467 Mtetra
.592 .578 .806 r
.36175 .40467 .36893 .41954 .38115 .41761 .37398 .40248 Mtetra
.599 .578 .802 r
.37398 .40248 .38115 .41761 .39345 .41534 .3863 .39998 Mtetra
.606 .579 .797 r
.3863 .39998 .39345 .41534 .40584 .4127 .39869 .39714 Mtetra
.613 .581 .794 r
.39869 .39714 .40584 .4127 .41831 .40968 .41117 .39394 Mtetra
.62 .583 .79 r
.41117 .39394 .41831 .40968 .43086 .40625 .42373 .39037 Mtetra
.628 .586 .788 r
.42373 .39037 .43086 .40625 .44348 .40239 .43636 .3864 Mtetra
.635 .589 .785 r
.43636 .3864 .44348 .40239 .45617 .3981 .44906 .38204 Mtetra
.642 .592 .783 r
.44906 .38204 .45617 .3981 .46893 .39336 .46183 .37727 Mtetra
.649 .596 .781 r
.46183 .37727 .46893 .39336 .48176 .38817 .47466 .37209 Mtetra
.656 .6 .78 r
.47466 .37209 .48176 .38817 .49464 .38254 .48755 .3665 Mtetra
.663 .604 .779 r
.48755 .3665 .49464 .38254 .50757 .37648 .50049 .36051 Mtetra
.669 .609 .778 r
.50049 .36051 .50757 .37648 .52055 .37 .51348 .35414 Mtetra
.676 .613 .778 r
.51348 .35414 .52055 .37 .53357 .36312 .52652 .3474 Mtetra
.682 .619 .778 r
.52652 .3474 .53357 .36312 .54664 .35587 .5396 .34031 Mtetra
.688 .624 .779 r
.5396 .34031 .54664 .35587 .55973 .34826 .55272 .3329 Mtetra
.694 .629 .78 r
.55272 .3329 .55973 .34826 .57286 .34033 .56587 .3252 Mtetra
.699 .635 .781 r
.56587 .3252 .57286 .34033 .58602 .33213 .57905 .31723 Mtetra
.704 .641 .783 r
.57905 .31723 .58602 .33213 .59921 .32367 .59226 .30903 Mtetra
.709 .647 .786 r
.59226 .30903 .59921 .32367 .61241 .31501 .6055 .30064 Mtetra
.713 .653 .788 r
.6055 .30064 .61241 .31501 .62565 .30618 .61877 .29209 Mtetra
.717 .659 .791 r
.61877 .29209 .62565 .30618 .6389 .29722 .63207 .28342 Mtetra
.72 .665 .795 r
.63207 .28342 .6389 .29722 .65218 .28817 .64539 .27466 Mtetra
.723 .671 .798 r
.64539 .27466 .65218 .28817 .66548 .27907 .65874 .26585 Mtetra
.725 .677 .803 r
.65874 .26585 .66548 .27907 .67881 .26996 .67211 .25703 Mtetra
.727 .683 .807 r
.67211 .25703 .67881 .26996 .69217 .26086 .68552 .24822 Mtetra
.729 .688 .812 r
.68552 .24822 .69217 .26086 .70555 .25182 .69896 .23945 Mtetra
.73 .694 .816 r
.69896 .23945 .70555 .25182 .71897 .24286 .71244 .23075 Mtetra
.73 .7 .822 r
.71244 .23075 .71897 .24286 .73243 .234 .72595 .22215 Mtetra
.73 .705 .827 r
.72595 .22215 .73243 .234 .74592 .22527 .7395 .21365 Mtetra
.729 .71 .832 r
.7395 .21365 .74592 .22527 .75946 .21669 .7531 .20529 Mtetra
.728 .715 .838 r
.7531 .20529 .75946 .21669 .77304 .20826 .76675 .19707 Mtetra
.727 .719 .843 r
.76675 .19707 .77304 .20826 .78668 .20001 .78045 .18901 Mtetra
.725 .723 .848 r
.78045 .18901 .78668 .20001 .80037 .19193 .7942 .1811 Mtetra
.563 .66 .902 r
.15852 .41259 .16627 .42182 .17721 .42076 .16949 .41126 Mtetra
.56 .653 .898 r
.16949 .41126 .17721 .42076 .18821 .41979 .18053 .41001 Mtetra
.558 .646 .893 r
.18053 .41001 .18821 .41979 .19926 .4189 .19162 .40883 Mtetra
.557 .639 .888 r
.19162 .40883 .19926 .4189 .21038 .41808 .20278 .40772 Mtetra
.556 .633 .883 r
.20278 .40772 .21038 .41808 .22156 .41732 .214 .40664 Mtetra
.556 .626 .877 r
.214 .40664 .22156 .41732 .23281 .41661 .22529 .4056 Mtetra
.556 .62 .871 r
.22529 .4056 .23281 .41661 .24414 .41592 .23665 .40457 Mtetra
.557 .614 .866 r
.23665 .40457 .24414 .41592 .25553 .41522 .24808 .40354 Mtetra
.559 .609 .86 r
.24808 .40354 .25553 .41522 .267 .41451 .25958 .40248 Mtetra
.561 .604 .853 r
.25958 .40248 .267 .41451 .27855 .41375 .27116 .40137 Mtetra
.564 .6 .847 r
.27116 .40137 .27855 .41375 .29018 .41291 .28282 .40019 Mtetra
.567 .596 .841 r
.28282 .40019 .29018 .41291 .3019 .41197 .29456 .39891 Mtetra
.571 .592 .836 r
.29456 .39891 .3019 .41197 .3137 .4109 .30639 .39751 Mtetra
.576 .59 .83 r
.30639 .39751 .3137 .4109 .32558 .40967 .3183 .39595 Mtetra
.581 .588 .824 r
.3183 .39595 .32558 .40967 .33755 .40824 .33029 .39421 Mtetra
.586 .586 .819 r
.33029 .39421 .33755 .40824 .34961 .40658 .34236 .39226 Mtetra
.592 .585 .814 r
.34236 .39226 .34961 .40658 .36175 .40467 .35453 .39007 Mtetra
.598 .585 .81 r
.35453 .39007 .36175 .40467 .37398 .40248 .36677 .38763 Mtetra
.604 .585 .805 r
.36677 .38763 .37398 .40248 .3863 .39998 .3791 .3849 Mtetra
.61 .586 .801 r
.3791 .3849 .3863 .39998 .39869 .39714 .39151 .38186 Mtetra
.617 .587 .798 r
.39151 .38186 .39869 .39714 .41117 .39394 .404 .37849 Mtetra
.623 .589 .795 r
.404 .37849 .41117 .39394 .42373 .39037 .41656 .37478 Mtetra
.63 .591 .792 r
.41656 .37478 .42373 .39037 .43636 .3864 .4292 .37071 Mtetra
.637 .594 .789 r
.4292 .37071 .43636 .3864 .44906 .38204 .44191 .36628 Mtetra
.643 .597 .787 r
.44191 .36628 .44906 .38204 .46183 .37727 .45469 .36147 Mtetra
.65 .6 .785 r
.45469 .36147 .46183 .37727 .47466 .37209 .46752 .35629 Mtetra
.656 .604 .784 r
.46752 .35629 .47466 .37209 .48755 .3665 .48042 .35073 Mtetra
.663 .608 .783 r
.48042 .35073 .48755 .3665 .50049 .36051 .49338 .34481 Mtetra
.669 .612 .783 r
.49338 .34481 .50049 .36051 .51348 .35414 .50638 .33853 Mtetra
.675 .617 .782 r
.50638 .33853 .51348 .35414 .52652 .3474 .51944 .33192 Mtetra
.681 .622 .783 r
.51944 .33192 .52652 .3474 .5396 .34031 .53253 .32499 Mtetra
.686 .627 .783 r
.53253 .32499 .5396 .34031 .55272 .3329 .54567 .31776 Mtetra
.691 .632 .785 r
.54567 .31776 .55272 .3329 .56587 .3252 .55884 .31026 Mtetra
.697 .637 .786 r
.55884 .31026 .56587 .3252 .57905 .31723 .57205 .30251 Mtetra
.701 .643 .788 r
.57205 .30251 .57905 .31723 .59226 .30903 .58529 .29456 Mtetra
.706 .648 .79 r
.58529 .29456 .59226 .30903 .6055 .30064 .59857 .28642 Mtetra
.71 .654 .793 r
.59857 .28642 .6055 .30064 .61877 .29209 .61187 .27814 Mtetra
.713 .66 .796 r
.61187 .27814 .61877 .29209 .63207 .28342 .6252 .26974 Mtetra
.716 .666 .799 r
.6252 .26974 .63207 .28342 .64539 .27466 .63856 .26125 Mtetra
.719 .672 .803 r
.63856 .26125 .64539 .27466 .65874 .26585 .65196 .25272 Mtetra
.721 .678 .807 r
.65196 .25272 .65874 .26585 .67211 .25703 .66538 .24417 Mtetra
.723 .683 .811 r
.66538 .24417 .67211 .25703 .68552 .24822 .67884 .23563 Mtetra
.725 .689 .816 r
.67884 .23563 .68552 .24822 .69896 .23945 .69233 .22712 Mtetra
.725 .695 .82 r
.69233 .22712 .69896 .23945 .71244 .23075 .70586 .21867 Mtetra
.726 .7 .825 r
.70586 .21867 .71244 .23075 .72595 .22215 .71943 .21031 Mtetra
.726 .705 .83 r
.71943 .21031 .72595 .22215 .7395 .21365 .73304 .20204 Mtetra
.725 .71 .836 r
.73304 .20204 .7395 .21365 .7531 .20529 .7467 .19389 Mtetra
.724 .714 .841 r
.7467 .19389 .7531 .20529 .76675 .19707 .76041 .18586 Mtetra
.723 .719 .846 r
.76041 .18586 .76675 .19707 .78045 .18901 .77417 .17798 Mtetra
.721 .723 .851 r
.77417 .17798 .78045 .18901 .7942 .1811 .78798 .17024 Mtetra
.572 .666 .902 r
.1507 .40338 .15852 .41259 .16949 .41126 .16171 .4018 Mtetra
.569 .659 .898 r
.16171 .4018 .16949 .41126 .18053 .41001 .17279 .4003 Mtetra
.568 .653 .893 r
.17279 .4003 .18053 .41001 .19162 .40883 .18392 .39884 Mtetra
.566 .647 .889 r
.18392 .39884 .19162 .40883 .20278 .40772 .19512 .39744 Mtetra
.566 .64 .884 r
.19512 .39744 .20278 .40772 .214 .40664 .20637 .39606 Mtetra
.565 .634 .879 r
.20637 .39606 .214 .40664 .22529 .4056 .2177 .39471 Mtetra
.566 .629 .873 r
.2177 .39471 .22529 .4056 .23665 .40457 .22909 .39337 Mtetra
.567 .623 .868 r
.22909 .39337 .23665 .40457 .24808 .40354 .24056 .39201 Mtetra
.568 .618 .862 r
.24056 .39201 .24808 .40354 .25958 .40248 .2521 .39063 Mtetra
.57 .613 .856 r
.2521 .39063 .25958 .40248 .27116 .40137 .26371 .38919 Mtetra
.573 .609 .85 r
.26371 .38919 .27116 .40137 .28282 .40019 .2754 .38768 Mtetra
.576 .605 .845 r
.2754 .38768 .28282 .40019 .29456 .39891 .28717 .38608 Mtetra
.579 .601 .839 r
.28717 .38608 .29456 .39891 .30639 .39751 .29902 .38435 Mtetra
.583 .599 .834 r
.29902 .38435 .30639 .39751 .3183 .39595 .31096 .38249 Mtetra
.588 .596 .828 r
.31096 .38249 .3183 .39595 .33029 .39421 .32297 .38045 Mtetra
.592 .595 .823 r
.32297 .38045 .33029 .39421 .34236 .39226 .33507 .37822 Mtetra
.598 .593 .818 r
.33507 .37822 .34236 .39226 .35453 .39007 .34725 .37577 Mtetra
.603 .593 .814 r
.34725 .37577 .35453 .39007 .36677 .38763 .35951 .37308 Mtetra
.609 .593 .81 r
.35951 .37308 .36677 .38763 .3791 .3849 .37185 .37013 Mtetra
.614 .593 .806 r
.37185 .37013 .3791 .3849 .39151 .38186 .38428 .3669 Mtetra
.62 .594 .802 r
.38428 .3669 .39151 .38186 .404 .37849 .39678 .36337 Mtetra
.626 .595 .799 r
.39678 .36337 .404 .37849 .41656 .37478 .40935 .35952 Mtetra
.632 .597 .796 r
.40935 .35952 .41656 .37478 .4292 .37071 .422 .35535 Mtetra
.639 .6 .794 r
.422 .35535 .4292 .37071 .44191 .36628 .43472 .35084 Mtetra
.645 .602 .792 r
.43472 .35084 .44191 .36628 .45469 .36147 .44751 .34599 Mtetra
.651 .605 .79 r
.44751 .34599 .45469 .36147 .46752 .35629 .46036 .3408 Mtetra
.657 .609 .789 r
.46036 .3408 .46752 .35629 .48042 .35073 .47327 .33527 Mtetra
.663 .612 .788 r
.47327 .33527 .48042 .35073 .49338 .34481 .48623 .32941 Mtetra
.668 .616 .788 r
.48623 .32941 .49338 .34481 .50638 .33853 .49925 .32322 Mtetra
.674 .621 .787 r
.49925 .32322 .50638 .33853 .51944 .33192 .51232 .31672 Mtetra
.68 .625 .788 r
.51232 .31672 .51944 .33192 .53253 .32499 .52543 .30993 Mtetra
.685 .63 .788 r
.52543 .30993 .53253 .32499 .54567 .31776 .53859 .30287 Mtetra
.69 .635 .79 r
.53859 .30287 .54567 .31776 .55884 .31026 .55179 .29555 Mtetra
.694 .64 .791 r
.55179 .29555 .55884 .31026 .57205 .30251 .56502 .28802 Mtetra
.699 .646 .793 r
.56502 .28802 .57205 .30251 .58529 .29456 .57829 .28028 Mtetra
.703 .651 .795 r
.57829 .28028 .58529 .29456 .59857 .28642 .5916 .27238 Mtetra
.707 .656 .798 r
.5916 .27238 .59857 .28642 .61187 .27814 .60493 .26434 Mtetra
.71 .662 .801 r
.60493 .26434 .61187 .27814 .6252 .26974 .6183 .2562 Mtetra
.713 .668 .804 r
.6183 .2562 .6252 .26974 .63856 .26125 .63171 .24797 Mtetra
.716 .673 .808 r
.63171 .24797 .63856 .26125 .65196 .25272 .64514 .2397 Mtetra
.718 .679 .812 r
.64514 .2397 .65196 .25272 .66538 .24417 .65862 .2314 Mtetra
.719 .685 .816 r
.65862 .2314 .66538 .24417 .67884 .23563 .67212 .22311 Mtetra
.721 .69 .82 r
.67212 .22311 .67884 .23563 .69233 .22712 .68567 .21485 Mtetra
.722 .695 .825 r
.68567 .21485 .69233 .22712 .70586 .21867 .69925 .20664 Mtetra
.722 .701 .829 r
.69925 .20664 .70586 .21867 .71943 .21031 .71288 .1985 Mtetra
.722 .706 .834 r
.71288 .1985 .71943 .21031 .73304 .20204 .72655 .19044 Mtetra
.721 .71 .839 r
.72655 .19044 .73304 .20204 .7467 .19389 .74026 .18249 Mtetra
.72 .715 .844 r
.74026 .18249 .7467 .19389 .76041 .18586 .75403 .17465 Mtetra
.719 .719 .849 r
.75403 .17465 .76041 .18586 .77417 .17798 .76785 .16694 Mtetra
.717 .723 .854 r
.76785 .16694 .77417 .17798 .78798 .17024 .78173 .15935 Mtetra
.58 .671 .902 r
.14281 .3942 .1507 .40338 .16171 .4018 .15387 .39239 Mtetra
.578 .665 .898 r
.15387 .39239 .16171 .4018 .17279 .4003 .16498 .39064 Mtetra
.576 .66 .894 r
.16498 .39064 .17279 .4003 .18392 .39884 .17615 .38893 Mtetra
.575 .654 .89 r
.17615 .38893 .18392 .39884 .19512 .39744 .18738 .38725 Mtetra
.575 .648 .885 r
.18738 .38725 .19512 .39744 .20637 .39606 .19868 .38559 Mtetra
.575 .642 .88 r
.19868 .38559 .20637 .39606 .2177 .39471 .21004 .38395 Mtetra
.575 .637 .875 r
.21004 .38395 .2177 .39471 .22909 .39337 .22148 .38231 Mtetra
.576 .631 .87 r
.22148 .38231 .22909 .39337 .24056 .39201 .23298 .38065 Mtetra
.577 .626 .864 r
.23298 .38065 .24056 .39201 .2521 .39063 .24455 .37896 Mtetra
.579 .622 .859 r
.24455 .37896 .2521 .39063 .26371 .38919 .2562 .37721 Mtetra
.581 .618 .853 r
.2562 .37721 .26371 .38919 .2754 .38768 .26792 .37539 Mtetra
.584 .614 .848 r
.26792 .37539 .2754 .38768 .28717 .38608 .27972 .37348 Mtetra
.587 .61 .843 r
.27972 .37348 .28717 .38608 .29902 .38435 .2916 .37146 Mtetra
.591 .608 .837 r
.2916 .37146 .29902 .38435 .31096 .38249 .30356 .3693 Mtetra
.594 .605 .832 r
.30356 .3693 .31096 .38249 .32297 .38045 .3156 .36698 Mtetra
.599 .603 .828 r
.3156 .36698 .32297 .38045 .33507 .37822 .32772 .36448 Mtetra
.603 .602 .823 r
.32772 .36448 .33507 .37822 .34725 .37577 .33992 .36178 Mtetra
.608 .601 .819 r
.33992 .36178 .34725 .37577 .35951 .37308 .3522 .35887 Mtetra
.613 .601 .814 r
.3522 .35887 .35951 .37308 .37185 .37013 .36456 .35571 Mtetra
.619 .601 .811 r
.36456 .35571 .37185 .37013 .38428 .3669 .377 .35229 Mtetra
.624 .602 .807 r
.377 .35229 .38428 .3669 .39678 .36337 .38951 .3486 Mtetra
.629 .603 .804 r
.38951 .3486 .39678 .36337 .40935 .35952 .4021 .34462 Mtetra
.635 .604 .802 r
.4021 .34462 .40935 .35952 .422 .35535 .41476 .34034 Mtetra
.641 .606 .799 r
.41476 .34034 .422 .35535 .43472 .35084 .42749 .33576 Mtetra
.646 .608 .797 r
.42749 .33576 .43472 .35084 .44751 .34599 .44029 .33087 Mtetra
.652 .611 .796 r
.44029 .33087 .44751 .34599 .46036 .3408 .45315 .32566 Mtetra
.658 .614 .794 r
.45315 .32566 .46036 .3408 .47327 .33527 .46607 .32015 Mtetra
.663 .618 .793 r
.46607 .32015 .47327 .33527 .48623 .32941 .47905 .31433 Mtetra
.668 .621 .793 r
.47905 .31433 .48623 .32941 .49925 .32322 .49209 .30822 Mtetra
.674 .625 .793 r
.49209 .30822 .49925 .32322 .51232 .31672 .50517 .30182 Mtetra
.679 .63 .793 r
.50517 .30182 .51232 .31672 .52543 .30993 .5183 .29516 Mtetra
.684 .634 .794 r
.5183 .29516 .52543 .30993 .53859 .30287 .53148 .28825 Mtetra
.688 .639 .795 r
.53148 .28825 .53859 .30287 .55179 .29555 .5447 .28111 Mtetra
.693 .644 .796 r
.5447 .28111 .55179 .29555 .56502 .28802 .55796 .27376 Mtetra
.697 .649 .798 r
.55796 .27376 .56502 .28802 .57829 .28028 .57126 .26623 Mtetra
.701 .654 .801 r
.57126 .26623 .57829 .28028 .5916 .27238 .5846 .25855 Mtetra
.704 .659 .803 r
.5846 .25855 .5916 .27238 .60493 .26434 .59797 .25074 Mtetra
.707 .665 .806 r
.59797 .25074 .60493 .26434 .6183 .2562 .61137 .24283 Mtetra
.71 .67 .809 r
.61137 .24283 .6183 .2562 .63171 .24797 .62482 .23484 Mtetra
.712 .676 .813 r
.62482 .23484 .63171 .24797 .64514 .2397 .6383 .22681 Mtetra
.714 .681 .816 r
.6383 .22681 .64514 .2397 .65862 .2314 .65181 .21875 Mtetra
.716 .686 .82 r
.65181 .21875 .65862 .2314 .67212 .22311 .66537 .21069 Mtetra
.717 .692 .825 r
.66537 .21069 .67212 .22311 .68567 .21485 .67896 .20266 Mtetra
.718 .697 .829 r
.67896 .20266 .68567 .21485 .69925 .20664 .6926 .19466 Mtetra
.718 .702 .834 r
.6926 .19466 .69925 .20664 .71288 .1985 .70628 .18673 Mtetra
.718 .707 .838 r
.70628 .18673 .71288 .1985 .72655 .19044 .72001 .17888 Mtetra
.718 .711 .843 r
.72001 .17888 .72655 .19044 .74026 .18249 .73378 .17111 Mtetra
.717 .715 .848 r
.73378 .17111 .74026 .18249 .75403 .17465 .74761 .16345 Mtetra
.716 .719 .852 r
.74761 .16345 .75403 .17465 .76785 .16694 .76149 .15589 Mtetra
.714 .723 .857 r
.76149 .15589 .76785 .16694 .78173 .15935 .77543 .14844 Mtetra
.587 .676 .902 r
.13486 .38506 .14281 .3942 .15387 .39239 .14595 .38303 Mtetra
.585 .671 .898 r
.14595 .38303 .15387 .39239 .16498 .39064 .1571 .38104 Mtetra
.584 .666 .895 r
.1571 .38104 .16498 .39064 .17615 .38893 .16831 .37909 Mtetra
.583 .66 .891 r
.16831 .37909 .17615 .38893 .18738 .38725 .17958 .37715 Mtetra
.583 .655 .886 r
.17958 .37715 .18738 .38725 .19868 .38559 .19092 .37524 Mtetra
.583 .65 .882 r
.19092 .37524 .19868 .38559 .21004 .38395 .20232 .37332 Mtetra
.583 .645 .877 r
.20232 .37332 .21004 .38395 .22148 .38231 .21379 .3714 Mtetra
.584 .64 .872 r
.21379 .3714 .22148 .38231 .23298 .38065 .22533 .36945 Mtetra
.585 .635 .867 r
.22533 .36945 .23298 .38065 .24455 .37896 .23694 .36747 Mtetra
.587 .631 .862 r
.23694 .36747 .24455 .37896 .2562 .37721 .24862 .36543 Mtetra
.589 .626 .857 r
.24862 .36543 .2562 .37721 .26792 .37539 .26037 .36333 Mtetra
.591 .623 .852 r
.26037 .36333 .26792 .37539 .27972 .37348 .2722 .36113 Mtetra
.594 .619 .846 r
.2722 .36113 .27972 .37348 .2916 .37146 .28411 .35882 Mtetra
.597 .617 .842 r
.28411 .35882 .2916 .37146 .30356 .3693 .2961 .35639 Mtetra
.601 .614 .837 r
.2961 .35639 .30356 .3693 .3156 .36698 .30816 .3538 Mtetra
.605 .612 .832 r
.30816 .3538 .3156 .36698 .32772 .36448 .3203 .35106 Mtetra
.609 .611 .828 r
.3203 .35106 .32772 .36448 .33992 .36178 .33253 .34812 Mtetra
.613 .61 .823 r
.33253 .34812 .33992 .36178 .3522 .35887 .34483 .34498 Mtetra
.618 .609 .82 r
.34483 .34498 .3522 .35887 .36456 .35571 .35721 .34163 Mtetra
.623 .609 .816 r
.35721 .34163 .36456 .35571 .377 .35229 .36966 .33803 Mtetra
.628 .609 .813 r
.36966 .33803 .377 .35229 .38951 .3486 .38219 .33419 Mtetra
.633 .61 .81 r
.38219 .33419 .38951 .3486 .4021 .34462 .3948 .33008 Mtetra
.638 .612 .807 r
.3948 .33008 .4021 .34462 .41476 .34034 .40747 .3257 Mtetra
.643 .613 .805 r
.40747 .3257 .41476 .34034 .42749 .33576 .42022 .32105 Mtetra
.648 .615 .803 r
.42022 .32105 .42749 .33576 .44029 .33087 .43303 .31611 Mtetra
.653 .618 .801 r
.43303 .31611 .44029 .33087 .45315 .32566 .4459 .31089 Mtetra
.658 .621 .8 r
.4459 .31089 .45315 .32566 .46607 .32015 .45884 .30538 Mtetra
.664 .624 .799 r
.45884 .30538 .46607 .32015 .47905 .31433 .47183 .2996 Mtetra
.669 .627 .799 r
.47183 .2996 .47905 .31433 .49209 .30822 .48488 .29356 Mtetra
.673 .631 .799 r
.48488 .29356 .49209 .30822 .50517 .30182 .49799 .28725 Mtetra
.678 .635 .799 r
.49799 .28725 .50517 .30182 .5183 .29516 .51114 .2807 Mtetra
.683 .639 .8 r
.51114 .2807 .5183 .29516 .53148 .28825 .52434 .27392 Mtetra
.687 .643 .801 r
.52434 .27392 .53148 .28825 .5447 .28111 .53758 .26694 Mtetra
.691 .648 .802 r
.53758 .26694 .5447 .28111 .55796 .27376 .55087 .25976 Mtetra
.695 .653 .804 r
.55087 .25976 .55796 .27376 .57126 .26623 .56419 .25242 Mtetra
.698 .658 .806 r
.56419 .25242 .57126 .26623 .5846 .25855 .57756 .24494 Mtetra
.702 .663 .809 r
.57756 .24494 .5846 .25855 .59797 .25074 .59097 .23734 Mtetra
.705 .668 .811 r
.59097 .23734 .59797 .25074 .61137 .24283 .60441 .22964 Mtetra
.707 .673 .815 r
.60441 .22964 .61137 .24283 .62482 .23484 .61789 .22187 Mtetra
.709 .678 .818 r
.61789 .22187 .62482 .23484 .6383 .22681 .63142 .21406 Mtetra
.711 .684 .822 r
.63142 .21406 .6383 .22681 .65181 .21875 .64498 .20622 Mtetra
.713 .689 .825 r
.64498 .20622 .65181 .21875 .66537 .21069 .65858 .19838 Mtetra
.714 .694 .829 r
.65858 .19838 .66537 .21069 .67896 .20266 .67222 .19055 Mtetra
.714 .699 .834 r
.67222 .19055 .67896 .20266 .6926 .19466 .68591 .18276 Mtetra
.715 .703 .838 r
.68591 .18276 .6926 .19466 .70628 .18673 .69964 .17503 Mtetra
.715 .708 .842 r
.69964 .17503 .70628 .18673 .72001 .17888 .71343 .16735 Mtetra
.714 .712 .847 r
.71343 .16735 .72001 .17888 .73378 .17111 .72726 .15976 Mtetra
.713 .716 .851 r
.72726 .15976 .73378 .17111 .74761 .16345 .74114 .15225 Mtetra
.712 .72 .856 r
.74114 .15225 .74761 .16345 .76149 .15589 .75508 .14484 Mtetra
.711 .723 .86 r
.75508 .14484 .76149 .15589 .77543 .14844 .76908 .13753 Mtetra
.594 .681 .902 r
.12683 .37594 .13486 .38506 .14595 .38303 .13797 .37371 Mtetra
.592 .676 .899 r
.13797 .37371 .14595 .38303 .1571 .38104 .14916 .37151 Mtetra
.592 .672 .895 r
.14916 .37151 .1571 .38104 .16831 .37909 .1604 .36932 Mtetra
.591 .667 .892 r
.1604 .36932 .16831 .37909 .17958 .37715 .17172 .36715 Mtetra
.591 .662 .888 r
.17172 .36715 .17958 .37715 .19092 .37524 .18309 .36499 Mtetra
.591 .657 .883 r
.18309 .36499 .19092 .37524 .20232 .37332 .19453 .36282 Mtetra
.591 .652 .879 r
.19453 .36282 .20232 .37332 .21379 .3714 .20603 .36064 Mtetra
.592 .648 .874 r
.20603 .36064 .21379 .3714 .22533 .36945 .21761 .35843 Mtetra
.593 .643 .87 r
.21761 .35843 .22533 .36945 .23694 .36747 .22925 .35617 Mtetra
.594 .639 .865 r
.22925 .35617 .23694 .36747 .24862 .36543 .24097 .35386 Mtetra
.596 .635 .86 r
.24097 .35386 .24862 .36543 .26037 .36333 .25275 .35148 Mtetra
.598 .631 .855 r
.25275 .35148 .26037 .36333 .2722 .36113 .26462 .34902 Mtetra
.601 .628 .85 r
.26462 .34902 .2722 .36113 .28411 .35882 .27655 .34645 Mtetra
.604 .625 .846 r
.27655 .34645 .28411 .35882 .2961 .35639 .28857 .34376 Mtetra
.607 .623 .841 r
.28857 .34376 .2961 .35639 .30816 .3538 .30066 .34093 Mtetra
.611 .621 .837 r
.30066 .34093 .30816 .3538 .3203 .35106 .31283 .33794 Mtetra
.614 .619 .833 r
.31283 .33794 .3203 .35106 .33253 .34812 .32507 .33479 Mtetra
.618 .618 .829 r
.32507 .33479 .33253 .34812 .34483 .34498 .3374 .33144 Mtetra
.622 .618 .825 r
.3374 .33144 .34483 .34498 .35721 .34163 .3498 .3279 Mtetra
.627 .617 .821 r
.3498 .3279 .35721 .34163 .36966 .33803 .36227 .32413 Mtetra
.631 .618 .818 r
.36227 .32413 .36966 .33803 .38219 .33419 .37482 .32014 Mtetra
.636 .618 .815 r
.37482 .32014 .38219 .33419 .3948 .33008 .38744 .31591 Mtetra
.641 .619 .813 r
.38744 .31591 .3948 .33008 .40747 .3257 .40013 .31144 Mtetra
.645 .621 .811 r
.40013 .31144 .40747 .3257 .42022 .32105 .41289 .30671 Mtetra
.65 .622 .809 r
.41289 .30671 .42022 .32105 .43303 .31611 .42572 .30172 Mtetra
.655 .625 .807 r
.42572 .30172 .43303 .31611 .4459 .31089 .43861 .29648 Mtetra
.66 .627 .806 r
.43861 .29648 .4459 .31089 .45884 .30538 .45156 .29098 Mtetra
.664 .63 .805 r
.45156 .29098 .45884 .30538 .47183 .2996 .46457 .28523 Mtetra
.669 .633 .805 r
.46457 .28523 .47183 .2996 .48488 .29356 .47764 .27924 Mtetra
.673 .637 .805 r
.47764 .27924 .48488 .29356 .49799 .28725 .49076 .27301 Mtetra
.678 .64 .805 r
.49076 .27301 .49799 .28725 .51114 .2807 .50393 .26656 Mtetra
.682 .644 .806 r
.50393 .26656 .51114 .2807 .52434 .27392 .51715 .2599 Mtetra
.686 .648 .807 r
.51715 .2599 .52434 .27392 .53758 .26694 .53042 .25305 Mtetra
.69 .653 .808 r
.53042 .25305 .53758 .26694 .55087 .25976 .54373 .24604 Mtetra
.693 .657 .81 r
.54373 .24604 .55087 .25976 .56419 .25242 .55709 .23886 Mtetra
.697 .662 .812 r
.55709 .23886 .56419 .25242 .57756 .24494 .57049 .23156 Mtetra
.7 .667 .814 r
.57049 .23156 .57756 .24494 .59097 .23734 .58393 .22415 Mtetra
.702 .672 .817 r
.58393 .22415 .59097 .23734 .60441 .22964 .59741 .21664 Mtetra
.705 .677 .82 r
.59741 .21664 .60441 .22964 .61789 .22187 .61093 .20908 Mtetra
.707 .682 .823 r
.61093 .20908 .61789 .22187 .63142 .21406 .6245 .20146 Mtetra
.708 .686 .827 r
.6245 .20146 .63142 .21406 .64498 .20622 .6381 .19382 Mtetra
.71 .691 .83 r
.6381 .19382 .64498 .20622 .65858 .19838 .65175 .18618 Mtetra
.711 .696 .834 r
.65175 .18618 .65858 .19838 .67222 .19055 .66544 .17854 Mtetra
.711 .701 .838 r
.66544 .17854 .67222 .19055 .68591 .18276 .67918 .17094 Mtetra
.711 .705 .842 r
.67918 .17094 .68591 .18276 .69964 .17503 .69297 .16338 Mtetra
.711 .709 .847 r
.69297 .16338 .69964 .17503 .71343 .16735 .7068 .15588 Mtetra
.711 .714 .851 r
.7068 .15588 .71343 .16735 .72726 .15976 .72069 .14844 Mtetra
.71 .717 .855 r
.72069 .14844 .72726 .15976 .74114 .15225 .73463 .14108 Mtetra
.709 .721 .859 r
.73463 .14108 .74114 .15225 .75508 .14484 .74863 .1338 Mtetra
.708 .724 .863 r
.74863 .1338 .75508 .14484 .76908 .13753 .76269 .1266 Mtetra
.6 .686 .902 r
.11874 .36686 .12683 .37594 .13797 .37371 .12991 .36443 Mtetra
.599 .681 .899 r
.12991 .36443 .13797 .37371 .14916 .37151 .14114 .36203 Mtetra
.598 .677 .896 r
.14114 .36203 .14916 .37151 .1604 .36932 .15243 .35963 Mtetra
.598 .673 .893 r
.15243 .35963 .1604 .36932 .17172 .36715 .16377 .35724 Mtetra
.597 .668 .889 r
.16377 .35724 .17172 .36715 .18309 .36499 .17519 .35485 Mtetra
.598 .664 .885 r
.17519 .35485 .18309 .36499 .19453 .36282 .18666 .35244 Mtetra
.598 .659 .881 r
.18666 .35244 .19453 .36282 .20603 .36064 .1982 .35002 Mtetra
.599 .655 .877 r
.1982 .35002 .20603 .36064 .21761 .35843 .20981 .34756 Mtetra
.6 .651 .872 r
.20981 .34756 .21761 .35843 .22925 .35617 .22149 .34506 Mtetra
.601 .647 .868 r
.22149 .34506 .22925 .35617 .24097 .35386 .23324 .3425 Mtetra
.603 .643 .863 r
.23324 .3425 .24097 .35386 .25275 .35148 .24507 .33986 Mtetra
.605 .64 .859 r
.24507 .33986 .25275 .35148 .26462 .34902 .25696 .33715 Mtetra
.607 .637 .854 r
.25696 .33715 .26462 .34902 .27655 .34645 .26893 .33433 Mtetra
.61 .634 .85 r
.26893 .33433 .27655 .34645 .28857 .34376 .28097 .3314 Mtetra
.613 .632 .846 r
.28097 .3314 .28857 .34376 .30066 .34093 .29309 .32834 Mtetra
.616 .63 .842 r
.29309 .32834 .30066 .34093 .31283 .33794 .30529 .32514 Mtetra
.619 .628 .838 r
.30529 .32514 .31283 .33794 .32507 .33479 .31756 .32177 Mtetra
.623 .627 .834 r
.31756 .32177 .32507 .33479 .3374 .33144 .3299 .31824 Mtetra
.627 .626 .83 r
.3299 .31824 .3374 .33144 .3498 .3279 .34232 .31451 Mtetra
.631 .626 .827 r
.34232 .31451 .3498 .3279 .36227 .32413 .35482 .31059 Mtetra
.635 .626 .824 r
.35482 .31059 .36227 .32413 .37482 .32014 .36739 .30646 Mtetra
.639 .626 .821 r
.36739 .30646 .37482 .32014 .38744 .31591 .38002 .30212 Mtetra
.643 .627 .819 r
.38002 .30212 .38744 .31591 .40013 .31144 .39273 .29754 Mtetra
.648 .628 .817 r
.39273 .29754 .40013 .31144 .41289 .30671 .40551 .29274 Mtetra
.652 .63 .815 r
.40551 .29274 .41289 .30671 .42572 .30172 .41836 .28771 Mtetra
.657 .632 .814 r
.41836 .28771 .42572 .30172 .43861 .29648 .43126 .28244 Mtetra
.661 .634 .812 r
.43126 .28244 .43861 .29648 .45156 .29098 .44423 .27694 Mtetra
.665 .637 .812 r
.44423 .27694 .45156 .29098 .46457 .28523 .45726 .27121 Mtetra
.669 .64 .811 r
.45726 .27121 .46457 .28523 .47764 .27924 .47035 .26526 Mtetra
.674 .643 .811 r
.47035 .26526 .47764 .27924 .49076 .27301 .48349 .2591 Mtetra
.678 .646 .812 r
.48349 .2591 .49076 .27301 .50393 .26656 .49668 .25274 Mtetra
.681 .65 .812 r
.49668 .25274 .50393 .26656 .51715 .2599 .50993 .24619 Mtetra
.685 .654 .813 r
.50993 .24619 .51715 .2599 .53042 .25305 .52322 .23946 Mtetra
.689 .658 .814 r
.52322 .23946 .53042 .25305 .54373 .24604 .53656 .23258 Mtetra
.692 .662 .816 r
.53656 .23258 .54373 .24604 .55709 .23886 .54995 .22556 Mtetra
.695 .667 .818 r
.54995 .22556 .55709 .23886 .57049 .23156 .56338 .21842 Mtetra
.698 .671 .82 r
.56338 .21842 .57049 .23156 .58393 .22415 .57685 .21117 Mtetra
.7 .676 .823 r
.57685 .21117 .58393 .22415 .59741 .21664 .59037 .20385 Mtetra
.702 .68 .826 r
.59037 .20385 .59741 .21664 .61093 .20908 .60393 .19646 Mtetra
.704 .685 .829 r
.60393 .19646 .61093 .20908 .6245 .20146 .61754 .18902 Mtetra
.706 .69 .832 r
.61754 .18902 .6245 .20146 .6381 .19382 .63119 .18156 Mtetra
.707 .694 .836 r
.63119 .18156 .6381 .19382 .65175 .18618 .64488 .1741 Mtetra
.708 .699 .839 r
.64488 .1741 .65175 .18618 .66544 .17854 .65862 .16664 Mtetra
.708 .703 .843 r
.65862 .16664 .66544 .17854 .67918 .17094 .67241 .1592 Mtetra
.708 .707 .847 r
.67241 .1592 .67918 .17094 .69297 .16338 .68625 .1518 Mtetra
.708 .711 .851 r
.68625 .1518 .69297 .16338 .7068 .15588 .70014 .14445 Mtetra
.708 .715 .855 r
.70014 .14445 .7068 .15588 .72069 .14844 .71408 .13715 Mtetra
.707 .719 .858 r
.71408 .13715 .72069 .14844 .73463 .14108 .72808 .12992 Mtetra
.706 .722 .862 r
.72808 .12992 .73463 .14108 .74863 .1338 .74214 .12276 Mtetra
.705 .725 .866 r
.74214 .12276 .74863 .1338 .76269 .1266 .75625 .11567 Mtetra
.605 .69 .903 r
.11058 .35779 .11874 .36686 .12991 .36443 .12179 .35519 Mtetra
.604 .686 .9 r
.12179 .35519 .12991 .36443 .14114 .36203 .13305 .3526 Mtetra
.604 .682 .897 r
.13305 .3526 .14114 .36203 .15243 .35963 .14437 .35001 Mtetra
.604 .678 .894 r
.14437 .35001 .15243 .35963 .16377 .35724 .15576 .34741 Mtetra
.604 .674 .89 r
.15576 .34741 .16377 .35724 .17519 .35485 .16721 .34481 Mtetra
.604 .67 .887 r
.16721 .34481 .17519 .35485 .18666 .35244 .17872 .34218 Mtetra
.604 .666 .883 r
.17872 .34218 .18666 .35244 .1982 .35002 .1903 .33953 Mtetra
.605 .662 .879 r
.1903 .33953 .1982 .35002 .20981 .34756 .20195 .33685 Mtetra
.606 .658 .875 r
.20195 .33685 .20981 .34756 .22149 .34506 .21366 .33411 Mtetra
.608 .655 .871 r
.21366 .33411 .22149 .34506 .23324 .3425 .22545 .33132 Mtetra
.609 .651 .867 r
.22545 .33132 .23324 .3425 .24507 .33986 .2373 .32846 Mtetra
.611 .648 .862 r
.2373 .32846 .24507 .33986 .25696 .33715 .24923 .32551 Mtetra
.613 .645 .858 r
.24923 .32551 .25696 .33715 .26893 .33433 .26123 .32246 Mtetra
.616 .643 .854 r
.26123 .32246 .26893 .33433 .28097 .3314 .2733 .31931 Mtetra
.618 .64 .85 r
.2733 .31931 .28097 .3314 .29309 .32834 .28545 .31604 Mtetra
.621 .639 .846 r
.28545 .31604 .29309 .32834 .30529 .32514 .29767 .31263 Mtetra
.624 .637 .843 r
.29767 .31263 .30529 .32514 .31756 .32177 .30997 .30907 Mtetra
.628 .636 .839 r
.30997 .30907 .31756 .32177 .3299 .31824 .32234 .30535 Mtetra
.631 .635 .836 r
.32234 .30535 .3299 .31824 .34232 .31451 .33479 .30147 Mtetra
.635 .634 .833 r
.33479 .30147 .34232 .31451 .35482 .31059 .3473 .29739 Mtetra
.638 .634 .83 r
.3473 .29739 .35482 .31059 .36739 .30646 .35989 .29313 Mtetra
.642 .635 .827 r
.35989 .29313 .36739 .30646 .38002 .30212 .37255 .28867 Mtetra
.646 .635 .825 r
.37255 .28867 .38002 .30212 .39273 .29754 .38528 .28401 Mtetra
.65 .636 .823 r
.38528 .28401 .39273 .29754 .40551 .29274 .39808 .27914 Mtetra
.654 .638 .821 r
.39808 .27914 .40551 .29274 .41836 .28771 .41094 .27405 Mtetra
.658 .639 .82 r
.41094 .27405 .41836 .28771 .43126 .28244 .42387 .26876 Mtetra
.662 .641 .819 r
.42387 .26876 .43126 .28244 .44423 .27694 .43686 .26325 Mtetra
.666 .644 .818 r
.43686 .26325 .44423 .27694 .45726 .27121 .44991 .25754 Mtetra
.67 .646 .818 r
.44991 .25754 .45726 .27121 .47035 .26526 .46301 .25162 Mtetra
.674 .649 .818 r
.46301 .25162 .47035 .26526 .48349 .2591 .47618 .24552 Mtetra
.678 .652 .818 r
.47618 .24552 .48349 .2591 .49668 .25274 .48939 .23923 Mtetra
.681 .656 .819 r
.48939 .23923 .49668 .25274 .50993 .24619 .50266 .23277 Mtetra
.684 .66 .819 r
.50266 .23277 .50993 .24619 .52322 .23946 .51598 .22615 Mtetra
.688 .663 .821 r
.51598 .22615 .52322 .23946 .53656 .23258 .52935 .21939 Mtetra
.691 .667 .822 r
.52935 .21939 .53656 .23258 .54995 .22556 .54276 .2125 Mtetra
.693 .671 .824 r
.54276 .2125 .54995 .22556 .56338 .21842 .55623 .2055 Mtetra
.696 .676 .826 r
.55623 .2055 .56338 .21842 .57685 .21117 .56974 .19841 Mtetra
.698 .68 .829 r
.56974 .19841 .57685 .21117 .59037 .20385 .58329 .19124 Mtetra
.7 .684 .831 r
.58329 .19124 .59037 .20385 .60393 .19646 .59689 .18401 Mtetra
.702 .689 .834 r
.59689 .18401 .60393 .19646 .61754 .18902 .61054 .17674 Mtetra
.703 .693 .837 r
.61054 .17674 .61754 .18902 .63119 .18156 .62423 .16944 Mtetra
.704 .697 .841 r
.62423 .16944 .63119 .18156 .64488 .1741 .63797 .16213 Mtetra
.705 .701 .844 r
.63797 .16213 .64488 .1741 .65862 .16664 .65176 .15483 Mtetra
.705 .705 .848 r
.65176 .15483 .65862 .16664 .67241 .1592 .6656 .14754 Mtetra
.705 .709 .851 r
.6656 .14754 .67241 .1592 .68625 .1518 .67949 .14029 Mtetra
.705 .713 .855 r
.67949 .14029 .68625 .1518 .70014 .14445 .69343 .13307 Mtetra
.705 .717 .858 r
.69343 .13307 .70014 .14445 .71408 .13715 .70743 .1259 Mtetra
.704 .72 .862 r
.70743 .1259 .71408 .13715 .72808 .12992 .72148 .11878 Mtetra
.703 .723 .865 r
.72148 .11878 .72808 .12992 .74214 .12276 .73559 .11173 Mtetra
.702 .726 .869 r
.73559 .11173 .74214 .12276 .75625 .11567 .74977 .10474 Mtetra
.61 .694 .903 r
.10235 .34875 .11058 .35779 .12179 .35519 .11359 .34598 Mtetra
.61 .69 .9 r
.11359 .34598 .12179 .35519 .13305 .3526 .12489 .34321 Mtetra
.609 .687 .897 r
.12489 .34321 .13305 .3526 .14437 .35001 .13625 .34044 Mtetra
.609 .683 .894 r
.13625 .34044 .14437 .35001 .15576 .34741 .14767 .33766 Mtetra
.609 .68 .891 r
.14767 .33766 .15576 .34741 .16721 .34481 .15916 .33486 Mtetra
.61 .676 .888 r
.15916 .33486 .16721 .34481 .17872 .34218 .17071 .33203 Mtetra
.61 .672 .885 r
.17071 .33203 .17872 .34218 .1903 .33953 .18232 .32918 Mtetra
.611 .669 .881 r
.18232 .32918 .1903 .33953 .20195 .33685 .19401 .32628 Mtetra
.612 .665 .877 r
.19401 .32628 .20195 .33685 .21366 .33411 .20576 .32333 Mtetra
.613 .662 .874 r
.20576 .32333 .21366 .33411 .22545 .33132 .21758 .32032 Mtetra
.615 .659 .87 r
.21758 .32032 .22545 .33132 .2373 .32846 .22947 .31724 Mtetra
.617 .656 .866 r
.22947 .31724 .2373 .32846 .24923 .32551 .24143 .31408 Mtetra
.619 .653 .862 r
.24143 .31408 .24923 .32551 .26123 .32246 .25346 .31083 Mtetra
.621 .651 .858 r
.25346 .31083 .26123 .32246 .2733 .31931 .26556 .30747 Mtetra
.623 .649 .855 r
.26556 .30747 .2733 .31931 .28545 .31604 .27774 .304 Mtetra
.626 .647 .851 r
.27774 .304 .28545 .31604 .29767 .31263 .28999 .3004 Mtetra
.629 .645 .848 r
.28999 .3004 .29767 .31263 .30997 .30907 .30231 .29666 Mtetra
.632 .644 .844 r
.30231 .29666 .30997 .30907 .32234 .30535 .31471 .29278 Mtetra
.635 .643 .841 r
.31471 .29278 .32234 .30535 .33479 .30147 .32718 .28874 Mtetra
.638 .643 .838 r
.32718 .28874 .33479 .30147 .3473 .29739 .33972 .28453 Mtetra
.642 .643 .836 r
.33972 .28453 .3473 .29739 .35989 .29313 .35233 .28014 Mtetra
.645 .643 .833 r
.35233 .28014 .35989 .29313 .37255 .28867 .36501 .27558 Mtetra
.649 .643 .831 r
.36501 .27558 .37255 .28867 .38528 .28401 .37776 .27082 Mtetra
.652 .644 .829 r
.37776 .27082 .38528 .28401 .39808 .27914 .39058 .26588 Mtetra
.656 .645 .827 r
.39058 .26588 .39808 .27914 .41094 .27405 .40347 .26075 Mtetra
.66 .647 .826 r
.40347 .26075 .41094 .27405 .42387 .26876 .41641 .25542 Mtetra
.663 .649 .825 r
.41641 .25542 .42387 .26876 .43686 .26325 .42942 .2499 Mtetra
.667 .651 .824 r
.42942 .2499 .43686 .26325 .44991 .25754 .44249 .2442 Mtetra
.671 .653 .824 r
.44249 .2442 .44991 .25754 .46301 .25162 .45562 .23831 Mtetra
.674 .656 .824 r
.45562 .23831 .46301 .25162 .47618 .24552 .46881 .23225 Mtetra
.678 .659 .824 r
.46881 .23225 .47618 .24552 .48939 .23923 .48205 .22603 Mtetra
.681 .662 .825 r
.48205 .22603 .48939 .23923 .50266 .23277 .49535 .21964 Mtetra
.684 .665 .826 r
.49535 .21964 .50266 .23277 .51598 .22615 .50869 .21312 Mtetra
.687 .669 .827 r
.50869 .21312 .51598 .22615 .52935 .21939 .52209 .20646 Mtetra
.69 .673 .828 r
.52209 .20646 .52935 .21939 .54276 .2125 .53554 .19969 Mtetra
.692 .676 .83 r
.53554 .19969 .54276 .2125 .55623 .2055 .54903 .19282 Mtetra
.694 .68 .832 r
.54903 .19282 .55623 .2055 .56974 .19841 .56258 .18586 Mtetra
.696 .684 .834 r
.56258 .18586 .56974 .19841 .58329 .19124 .57617 .17883 Mtetra
.698 .688 .837 r
.57617 .17883 .58329 .19124 .59689 .18401 .58981 .17174 Mtetra
.7 .692 .84 r
.58981 .17174 .59689 .18401 .61054 .17674 .6035 .16461 Mtetra
.701 .696 .843 r
.6035 .16461 .61054 .17674 .62423 .16944 .61723 .15745 Mtetra
.702 .7 .846 r
.61723 .15745 .62423 .16944 .63797 .16213 .63102 .15029 Mtetra
.702 .704 .849 r
.63102 .15029 .63797 .16213 .65176 .15483 .64485 .14312 Mtetra
.703 .708 .852 r
.64485 .14312 .65176 .15483 .6656 .14754 .65874 .13596 Mtetra
.703 .712 .855 r
.65874 .13596 .6656 .14754 .67949 .14029 .67268 .12883 Mtetra
.703 .715 .859 r
.67268 .12883 .67949 .14029 .69343 .13307 .68668 .12173 Mtetra
.702 .718 .862 r
.68668 .12173 .69343 .13307 .70743 .1259 .70073 .11467 Mtetra
.701 .722 .865 r
.70073 .11467 .70743 .1259 .72148 .11878 .71484 .10766 Mtetra
.7 .724 .869 r
.71484 .10766 .72148 .11878 .73559 .11173 .729 .1007 Mtetra
.699 .727 .872 r
.729 .1007 .73559 .11173 .74977 .10474 .74323 .09379 Mtetra
.614 .697 .903 r
.09404 .33971 .10235 .34875 .11359 .34598 .10532 .33679 Mtetra
.614 .694 .901 r
.10532 .33679 .11359 .34598 .12489 .34321 .11665 .33386 Mtetra
.614 .691 .898 r
.11665 .33386 .12489 .34321 .13625 .34044 .12805 .33092 Mtetra
.614 .688 .895 r
.12805 .33092 .13625 .34044 .14767 .33766 .13951 .32797 Mtetra
.614 .685 .892 r
.13951 .32797 .14767 .33766 .15916 .33486 .15103 .32499 Mtetra
.615 .681 .889 r
.15103 .32499 .15916 .33486 .17071 .33203 .16262 .32197 Mtetra
.616 .678 .886 r
.16262 .32197 .17071 .33203 .18232 .32918 .17427 .31893 Mtetra
.616 .675 .883 r
.17427 .31893 .18232 .32918 .19401 .32628 .18599 .31584 Mtetra
.617 .672 .88 r
.18599 .31584 .19401 .32628 .20576 .32333 .19777 .31269 Mtetra
.619 .669 .876 r
.19777 .31269 .20576 .32333 .21758 .32032 .20963 .30949 Mtetra
.62 .666 .873 r
.20963 .30949 .21758 .32032 .22947 .31724 .22155 .30621 Mtetra
.622 .663 .869 r
.22155 .30621 .22947 .31724 .24143 .31408 .23355 .30286 Mtetra
.624 .661 .866 r
.23355 .30286 .24143 .31408 .25346 .31083 .24561 .29941 Mtetra
.626 .659 .862 r
.24561 .29941 .25346 .31083 .26556 .30747 .25775 .29586 Mtetra
.628 .657 .859 r
.25775 .29586 .26556 .30747 .27774 .304 .26995 .29221 Mtetra
.631 .655 .856 r
.26995 .29221 .27774 .304 .28999 .3004 .28223 .28844 Mtetra
.633 .653 .852 r
.28223 .28844 .28999 .3004 .30231 .29666 .29459 .28453 Mtetra
.636 .652 .849 r
.29459 .28453 .30231 .29666 .31471 .29278 .30701 .28049 Mtetra
.639 .651 .846 r
.30701 .28049 .31471 .29278 .32718 .28874 .3195 .27631 Mtetra
.642 .651 .844 r
.3195 .27631 .32718 .28874 .33972 .28453 .33207 .27196 Mtetra
.645 .651 .841 r
.33207 .27196 .33972 .28453 .35233 .28014 .34471 .26746 Mtetra
.648 .651 .839 r
.34471 .26746 .35233 .28014 .36501 .27558 .35741 .2628 Mtetra
.651 .651 .837 r
.35741 .2628 .36501 .27558 .37776 .27082 .37019 .25796 Mtetra
.655 .652 .835 r
.37019 .25796 .37776 .27082 .39058 .26588 .38303 .25295 Mtetra
.658 .653 .834 r
.38303 .25295 .39058 .26588 .40347 .26075 .39593 .24777 Mtetra
.661 .654 .832 r
.39593 .24777 .40347 .26075 .41641 .25542 .4089 .24241 Mtetra
.665 .656 .831 r
.4089 .24241 .41641 .25542 .42942 .2499 .42194 .23688 Mtetra
.668 .658 .831 r
.42194 .23688 .42942 .2499 .44249 .2442 .43503 .23118 Mtetra
.671 .66 .83 r
.43503 .23118 .44249 .2442 .45562 .23831 .44818 .22531 Mtetra
.675 .663 .83 r
.44818 .22531 .45562 .23831 .46881 .23225 .46139 .21928 Mtetra
.678 .665 .831 r
.46139 .21928 .46881 .23225 .48205 .22603 .47466 .21311 Mtetra
.681 .668 .831 r
.47466 .21311 .48205 .22603 .49535 .21964 .48798 .20679 Mtetra
.683 .671 .832 r
.48798 .20679 .49535 .21964 .50869 .21312 .50136 .20035 Mtetra
.686 .674 .833 r
.50136 .20035 .50869 .21312 .52209 .20646 .51478 .19378 Mtetra
.689 .678 .834 r
.51478 .19378 .52209 .20646 .53554 .19969 .52826 .18711 Mtetra
.691 .681 .836 r
.52826 .18711 .53554 .19969 .54903 .19282 .54179 .18035 Mtetra
.693 .685 .838 r
.54179 .18035 .54903 .19282 .56258 .18586 .55537 .1735 Mtetra
.695 .689 .84 r
.55537 .1735 .56258 .18586 .57617 .17883 .569 .16659 Mtetra
.696 .692 .842 r
.569 .16659 .57617 .17883 .58981 .17174 .58268 .15962 Mtetra
.698 .696 .845 r
.58268 .15962 .58981 .17174 .6035 .16461 .59641 .15262 Mtetra
.699 .7 .848 r
.59641 .15262 .6035 .16461 .61723 .15745 .61019 .14559 Mtetra
.699 .704 .85 r
.61019 .14559 .61723 .15745 .63102 .15029 .62402 .13854 Mtetra
.7 .707 .853 r
.62402 .13854 .63102 .15029 .64485 .14312 .6379 .1315 Mtetra
.7 .711 .856 r
.6379 .1315 .64485 .14312 .65874 .13596 .65184 .12446 Mtetra
.7 .714 .859 r
.65184 .12446 .65874 .13596 .67268 .12883 .66583 .11744 Mtetra
.7 .717 .862 r
.66583 .11744 .67268 .12883 .68668 .12173 .67987 .11044 Mtetra
.7 .72 .866 r
.67987 .11044 .68668 .12173 .70073 .11467 .69398 .10348 Mtetra
.699 .723 .869 r
.69398 .10348 .70073 .11467 .71484 .10766 .70814 .09655 Mtetra
.698 .726 .872 r
.70814 .09655 .71484 .10766 .729 .1007 .72236 .08967 Mtetra
.697 .728 .874 r
.72236 .08967 .729 .1007 .74323 .09379 .73665 .08284 Mtetra
.618 .7 .903 r
.08566 .33068 .09404 .33971 .10532 .33679 .09697 .32761 Mtetra
.618 .697 .901 r
.09697 .32761 .10532 .33679 .11665 .33386 .10834 .32454 Mtetra
.618 .695 .899 r
.10834 .32454 .11665 .33386 .12805 .33092 .11978 .32144 Mtetra
.619 .692 .896 r
.11978 .32144 .12805 .33092 .13951 .32797 .13127 .31833 Mtetra
.619 .689 .894 r
.13127 .31833 .13951 .32797 .15103 .32499 .14283 .31518 Mtetra
.619 .686 .891 r
.14283 .31518 .15103 .32499 .16262 .32197 .15445 .312 Mtetra
.62 .683 .888 r
.15445 .312 .16262 .32197 .17427 .31893 .16614 .30878 Mtetra
.621 .681 .885 r
.16614 .30878 .17427 .31893 .18599 .31584 .17789 .30551 Mtetra
.622 .678 .882 r
.17789 .30551 .18599 .31584 .19777 .31269 .18972 .30219 Mtetra
.623 .675 .879 r
.18972 .30219 .19777 .31269 .20963 .30949 .2016 .2988 Mtetra
.625 .673 .876 r
.2016 .2988 .20963 .30949 .22155 .30621 .21356 .29534 Mtetra
.626 .67 .872 r
.21356 .29534 .22155 .30621 .23355 .30286 .22559 .29181 Mtetra
.628 .668 .869 r
.22559 .29181 .23355 .30286 .24561 .29941 .23769 .28819 Mtetra
.63 .666 .866 r
.23769 .28819 .24561 .29941 .25775 .29586 .24985 .28447 Mtetra
.632 .664 .863 r
.24985 .28447 .25775 .29586 .26995 .29221 .26209 .28065 Mtetra
.635 .663 .86 r
.26209 .28065 .26995 .29221 .28223 .28844 .2744 .27671 Mtetra
.637 .661 .857 r
.2744 .27671 .28223 .28844 .29459 .28453 .28678 .27265 Mtetra
.64 .66 .854 r
.28678 .27265 .29459 .28453 .30701 .28049 .29923 .26847 Mtetra
.642 .659 .851 r
.29923 .26847 .30701 .28049 .3195 .27631 .31176 .26415 Mtetra
.645 .659 .849 r
.31176 .26415 .3195 .27631 .33207 .27196 .32435 .25969 Mtetra
.648 .658 .847 r
.32435 .25969 .33207 .27196 .34471 .26746 .33701 .25508 Mtetra
.651 .659 .844 r
.33701 .25508 .34471 .26746 .35741 .2628 .34974 .25032 Mtetra
.654 .659 .843 r
.34974 .25032 .35741 .2628 .37019 .25796 .36254 .2454 Mtetra
.657 .659 .841 r
.36254 .2454 .37019 .25796 .38303 .25295 .3754 .24033 Mtetra
.66 .66 .839 r
.3754 .24033 .38303 .25295 .39593 .24777 .38833 .23509 Mtetra
.663 .662 .838 r
.38833 .23509 .39593 .24777 .4089 .24241 .40133 .2297 Mtetra
.666 .663 .837 r
.40133 .2297 .4089 .24241 .42194 .23688 .41439 .22415 Mtetra
.669 .665 .837 r
.41439 .22415 .42194 .23688 .43503 .23118 .4275 .21845 Mtetra
.672 .667 .837 r
.4275 .21845 .43503 .23118 .44818 .22531 .44068 .21259 Mtetra
.675 .669 .836 r
.44068 .21259 .44818 .22531 .46139 .21928 .45392 .2066 Mtetra
.678 .672 .837 r
.45392 .2066 .46139 .21928 .47466 .21311 .46721 .20046 Mtetra
.68 .674 .837 r
.46721 .20046 .47466 .21311 .48798 .20679 .48056 .1942 Mtetra
.683 .677 .838 r
.48056 .1942 .48798 .20679 .50136 .20035 .49397 .18782 Mtetra
.685 .68 .839 r
.49397 .18782 .50136 .20035 .51478 .19378 .50743 .18133 Mtetra
.688 .683 .84 r
.50743 .18133 .51478 .19378 .52826 .18711 .52094 .17474 Mtetra
.69 .686 .842 r
.52094 .17474 .52826 .18711 .54179 .18035 .5345 .16807 Mtetra
.691 .69 .844 r
.5345 .16807 .54179 .18035 .55537 .1735 .54812 .16132 Mtetra
.693 .693 .845 r
.54812 .16132 .55537 .1735 .569 .16659 .56178 .15452 Mtetra
.694 .696 .848 r
.56178 .15452 .569 .16659 .58268 .15962 .5755 .14766 Mtetra
.696 .7 .85 r
.5755 .14766 .58268 .15962 .59641 .15262 .58927 .14076 Mtetra
.697 .703 .852 r
.58927 .14076 .59641 .15262 .61019 .14559 .60309 .13384 Mtetra
.697 .707 .855 r
.60309 .13384 .61019 .14559 .62402 .13854 .61697 .1269 Mtetra
.698 .71 .858 r
.61697 .1269 .62402 .13854 .6379 .1315 .6309 .11996 Mtetra
.698 .713 .86 r
.6309 .11996 .6379 .1315 .65184 .12446 .64488 .11302 Mtetra
.698 .716 .863 r
.64488 .11302 .65184 .12446 .66583 .11744 .65893 .10609 Mtetra
.698 .719 .866 r
.65893 .10609 .66583 .11744 .67987 .11044 .67302 .09918 Mtetra
.697 .722 .869 r
.67302 .09918 .67987 .11044 .69398 .10348 .68718 .0923 Mtetra
.697 .725 .872 r
.68718 .0923 .69398 .10348 .70814 .09655 .7014 .08546 Mtetra
.696 .727 .874 r
.7014 .08546 .70814 .09655 .72236 .08967 .71567 .07864 Mtetra
.695 .729 .877 r
.71567 .07864 .72236 .08967 .73665 .08284 .73002 .07187 Mtetra
.622 .703 .903 r
.07721 .32164 .08566 .33068 .09697 .32761 .08855 .31844 Mtetra
.622 .701 .901 r
.08855 .31844 .09697 .32761 .10834 .32454 .09996 .31523 Mtetra
.622 .698 .899 r
.09996 .31523 .10834 .32454 .11978 .32144 .11143 .31199 Mtetra
.622 .696 .897 r
.11143 .31199 .11978 .32144 .13127 .31833 .12296 .30873 Mtetra
.623 .693 .894 r
.12296 .30873 .13127 .31833 .14283 .31518 .13455 .30543 Mtetra
.624 .691 .892 r
.13455 .30543 .14283 .31518 .15445 .312 .14621 .30209 Mtetra
.624 .688 .889 r
.14621 .30209 .15445 .312 .16614 .30878 .15793 .29871 Mtetra
.625 .686 .887 r
.15793 .29871 .16614 .30878 .17789 .30551 .16972 .29528 Mtetra
.626 .683 .884 r
.16972 .29528 .17789 .30551 .18972 .30219 .18158 .29179 Mtetra
.628 .681 .881 r
.18158 .29179 .18972 .30219 .2016 .2988 .1935 .28824 Mtetra
.629 .679 .878 r
.1935 .28824 .2016 .2988 .21356 .29534 .20549 .28462 Mtetra
.631 .677 .875 r
.20549 .28462 .21356 .29534 .22559 .29181 .21755 .28092 Mtetra
.632 .675 .872 r
.21755 .28092 .22559 .29181 .23769 .28819 .22968 .27714 Mtetra
.634 .673 .869 r
.22968 .27714 .23769 .28819 .24985 .28447 .24188 .27326 Mtetra
.636 .671 .867 r
.24188 .27326 .24985 .28447 .26209 .28065 .25415 .26928 Mtetra
.638 .67 .864 r
.25415 .26928 .26209 .28065 .2744 .27671 .26649 .2652 Mtetra
.641 .668 .861 r
.26649 .2652 .2744 .27671 .28678 .27265 .2789 .261 Mtetra
.643 .667 .858 r
.2789 .261 .28678 .27265 .29923 .26847 .29139 .25669 Mtetra
.645 .667 .856 r
.29139 .25669 .29923 .26847 .31176 .26415 .30394 .25224 Mtetra
.648 .666 .854 r
.30394 .25224 .31176 .26415 .32435 .25969 .31656 .24767 Mtetra
.651 .666 .852 r
.31656 .24767 .32435 .25969 .33701 .25508 .32924 .24296 Mtetra
.653 .666 .85 r
.32924 .24296 .33701 .25508 .34974 .25032 .342 .23811 Mtetra
.656 .666 .848 r
.342 .23811 .34974 .25032 .36254 .2454 .35483 .23311 Mtetra
.659 .667 .846 r
.35483 .23311 .36254 .2454 .3754 .24033 .36772 .22798 Mtetra
.662 .668 .845 r
.36772 .22798 .3754 .24033 .38833 .23509 .38067 .22269 Mtetra
.664 .669 .844 r
.38067 .22269 .38833 .23509 .40133 .2297 .39369 .21727 Mtetra
.667 .67 .843 r
.39369 .21727 .40133 .2297 .41439 .22415 .40677 .21169 Mtetra
.67 .672 .843 r
.40677 .21169 .41439 .22415 .4275 .21845 .41992 .20598 Mtetra
.673 .673 .842 r
.41992 .20598 .4275 .21845 .44068 .21259 .43312 .20014 Mtetra
.675 .675 .842 r
.43312 .20014 .44068 .21259 .45392 .2066 .44639 .19416 Mtetra
.678 .678 .843 r
.44639 .19416 .45392 .2066 .46721 .20046 .45971 .18806 Mtetra
.68 .68 .843 r
.45971 .18806 .46721 .20046 .48056 .1942 .47309 .18184 Mtetra
.683 .683 .844 r
.47309 .18184 .48056 .1942 .49397 .18782 .48652 .17551 Mtetra
.685 .685 .845 r
.48652 .17551 .49397 .18782 .50743 .18133 .50001 .16909 Mtetra
.687 .688 .846 r
.50001 .16909 .50743 .18133 .52094 .17474 .51356 .16257 Mtetra
.689 .691 .847 r
.51356 .16257 .52094 .17474 .5345 .16807 .52716 .15598 Mtetra
.69 .694 .849 r
.52716 .15598 .5345 .16807 .54812 .16132 .54081 .14931 Mtetra
.692 .697 .851 r
.54081 .14931 .54812 .16132 .56178 .15452 .55451 .14259 Mtetra
.693 .7 .853 r
.55451 .14259 .56178 .15452 .5755 .14766 .56827 .13583 Mtetra
.694 .704 .855 r
.56827 .13583 .5755 .14766 .58927 .14076 .58209 .12902 Mtetra
.695 .707 .857 r
.58209 .12902 .58927 .14076 .60309 .13384 .59595 .12219 Mtetra
.695 .71 .859 r
.59595 .12219 .60309 .13384 .61697 .1269 .60987 .11534 Mtetra
.696 .713 .862 r
.60987 .11534 .61697 .1269 .6309 .11996 .62385 .10849 Mtetra
.696 .716 .864 r
.62385 .10849 .6309 .11996 .64488 .11302 .63788 .10163 Mtetra
.696 .719 .867 r
.63788 .10163 .64488 .11302 .65893 .10609 .65197 .09479 Mtetra
.695 .721 .869 r
.65197 .09479 .65893 .10609 .67302 .09918 .66612 .08796 Mtetra
.695 .724 .872 r
.66612 .08796 .67302 .09918 .68718 .0923 .68033 .08114 Mtetra
.694 .726 .874 r
.68033 .08114 .68718 .0923 .7014 .08546 .6946 .07436 Mtetra
.694 .728 .877 r
.6946 .07436 .7014 .08546 .71567 .07864 .70893 .0676 Mtetra
.693 .73 .879 r
.70893 .0676 .71567 .07864 .73002 .07187 .72333 .06088 Mtetra
.625 .705 .903 r
.06868 .31258 .07721 .32164 .08855 .31844 .08006 .30927 Mtetra
.625 .703 .901 r
.08006 .30927 .08855 .31844 .09996 .31523 .0915 .30593 Mtetra
.626 .701 .9 r
.0915 .30593 .09996 .31523 .11143 .31199 .103 .30256 Mtetra
.626 .699 .897 r
.103 .30256 .11143 .31199 .12296 .30873 .11457 .29916 Mtetra
.627 .697 .895 r
.11457 .29916 .12296 .30873 .13455 .30543 .1262 .29572 Mtetra
.627 .695 .893 r
.1262 .29572 .13455 .30543 .14621 .30209 .13789 .29224 Mtetra
.628 .692 .891 r
.13789 .29224 .14621 .30209 .15793 .29871 .14965 .28871 Mtetra
.629 .69 .888 r
.14965 .28871 .15793 .29871 .16972 .29528 .16147 .28513 Mtetra
.63 .688 .886 r
.16147 .28513 .16972 .29528 .18158 .29179 .17336 .2815 Mtetra
.631 .686 .883 r
.17336 .2815 .18158 .29179 .1935 .28824 .18532 .27779 Mtetra
.633 .684 .88 r
.18532 .27779 .1935 .28824 .20549 .28462 .19735 .27402 Mtetra
.634 .682 .878 r
.19735 .27402 .20549 .28462 .21755 .28092 .20944 .27017 Mtetra
.636 .681 .875 r
.20944 .27017 .21755 .28092 .22968 .27714 .2216 .26624 Mtetra
.638 .679 .873 r
.2216 .26624 .22968 .27714 .24188 .27326 .23384 .26222 Mtetra
.64 .677 .87 r
.23384 .26222 .24188 .27326 .25415 .26928 .24614 .2581 Mtetra
.642 .676 .867 r
.24614 .2581 .25415 .26928 .26649 .2652 .25851 .25388 Mtetra
.644 .675 .865 r
.25851 .25388 .26649 .2652 .2789 .261 .27095 .24955 Mtetra
.646 .674 .863 r
.27095 .24955 .2789 .261 .29139 .25669 .28346 .24512 Mtetra
.648 .674 .86 r
.28346 .24512 .29139 .25669 .30394 .25224 .29604 .24056 Mtetra
.651 .673 .858 r
.29604 .24056 .30394 .25224 .31656 .24767 .30869 .23588 Mtetra
.653 .673 .856 r
.30869 .23588 .31656 .24767 .32924 .24296 .32141 .23107 Mtetra
.656 .673 .855 r
.32141 .23107 .32924 .24296 .342 .23811 .33419 .22614 Mtetra
.658 .673 .853 r
.33419 .22614 .342 .23811 .35483 .23311 .34704 .22107 Mtetra
.661 .674 .852 r
.34704 .22107 .35483 .23311 .36772 .22798 .35996 .21588 Mtetra
.663 .674 .85 r
.35996 .21588 .36772 .22798 .38067 .22269 .37294 .21054 Mtetra
.666 .675 .849 r
.37294 .21054 .38067 .22269 .39369 .21727 .38599 .20508 Mtetra
.668 .677 .849 r
.38599 .20508 .39369 .21727 .40677 .21169 .3991 .19949 Mtetra
.671 .678 .848 r
.3991 .19949 .40677 .21169 .41992 .20598 .41227 .19376 Mtetra
.673 .68 .848 r
.41227 .19376 .41992 .20598 .43312 .20014 .4255 .18792 Mtetra
.676 .681 .848 r
.4255 .18792 .43312 .20014 .44639 .19416 .4388 .18195 Mtetra
.678 .683 .848 r
.4388 .18195 .44639 .19416 .45971 .18806 .45215 .17588 Mtetra
.68 .686 .848 r
.45215 .17588 .45971 .18806 .47309 .18184 .46556 .16969 Mtetra
.682 .688 .849 r
.46556 .16969 .47309 .18184 .48652 .17551 .47902 .16341 Mtetra
.684 .691 .85 r
.47902 .16341 .48652 .17551 .50001 .16909 .49255 .15703 Mtetra
.686 .693 .851 r
.49255 .15703 .50001 .16909 .51356 .16257 .50613 .15058 Mtetra
.688 .696 .852 r
.50613 .15058 .51356 .16257 .52716 .15598 .51976 .14405 Mtetra
.689 .699 .854 r
.51976 .14405 .52716 .15598 .54081 .14931 .53345 .13745 Mtetra
.69 .701 .855 r
.53345 .13745 .54081 .14931 .55451 .14259 .54719 .1308 Mtetra
.691 .704 .857 r
.54719 .1308 .55451 .14259 .56827 .13583 .56099 .12411 Mtetra
.692 .707 .859 r
.56099 .12411 .56827 .13583 .58209 .12902 .57485 .11738 Mtetra
.693 .71 .861 r
.57485 .11738 .58209 .12902 .59595 .12219 .58876 .11063 Mtetra
.693 .713 .863 r
.58876 .11063 .59595 .12219 .60987 .11534 .60272 .10386 Mtetra
.694 .716 .866 r
.60272 .10386 .60987 .11534 .62385 .10849 .61675 .09708 Mtetra
.694 .718 .868 r
.61675 .09708 .62385 .10849 .63788 .10163 .63083 .09029 Mtetra
.694 .721 .87 r
.63083 .09029 .63788 .10163 .65197 .09479 .64497 .08351 Mtetra
.693 .723 .873 r
.64497 .08351 .65197 .09479 .66612 .08796 .65917 .07674 Mtetra
.693 .725 .875 r
.65917 .07674 .66612 .08796 .68033 .08114 .67343 .06999 Mtetra
.692 .728 .877 r
.67343 .06999 .68033 .08114 .6946 .07436 .68775 .06326 Mtetra
.692 .73 .879 r
.68775 .06326 .6946 .07436 .70893 .0676 .70214 .05654 Mtetra
.691 .731 .882 r
.70214 .05654 .70893 .0676 .72333 .06088 .71659 .04986 Mtetra
.628 .707 .903 r
.06008 .30351 .06868 .31258 .08006 .30927 .07149 .30008 Mtetra
.628 .706 .902 r
.07149 .30008 .08006 .30927 .0915 .30593 .08297 .29662 Mtetra
.629 .704 .9 r
.08297 .29662 .0915 .30593 .103 .30256 .09451 .29313 Mtetra
.629 .702 .898 r
.09451 .29313 .103 .30256 .11457 .29916 .1061 .28961 Mtetra
.63 .7 .896 r
.1061 .28961 .11457 .29916 .1262 .29572 .11777 .28604 Mtetra
.631 .698 .894 r
.11777 .28604 .1262 .29572 .13789 .29224 .12949 .28243 Mtetra
.631 .696 .892 r
.12949 .28243 .13789 .29224 .14965 .28871 .14129 .27877 Mtetra
.632 .694 .89 r
.14129 .27877 .14965 .28871 .16147 .28513 .15314 .27505 Mtetra
.634 .693 .887 r
.15314 .27505 .16147 .28513 .17336 .2815 .16507 .27128 Mtetra
.635 .691 .885 r
.16507 .27128 .17336 .2815 .18532 .27779 .17706 .26744 Mtetra
.636 .689 .883 r
.17706 .26744 .18532 .27779 .19735 .27402 .18912 .26352 Mtetra
.638 .687 .88 r
.18912 .26352 .19735 .27402 .20944 .27017 .20125 .25954 Mtetra
.639 .686 .878 r
.20125 .25954 .20944 .27017 .2216 .26624 .21344 .25547 Mtetra
.641 .685 .875 r
.21344 .25547 .2216 .26624 .23384 .26222 .22571 .25132 Mtetra
.643 .683 .873 r
.22571 .25132 .23384 .26222 .24614 .2581 .23804 .24707 Mtetra
.645 .682 .871 r
.23804 .24707 .24614 .2581 .25851 .25388 .25045 .24273 Mtetra
.647 .681 .869 r
.25045 .24273 .25851 .25388 .27095 .24955 .26292 .23828 Mtetra
.649 .68 .866 r
.26292 .23828 .27095 .24955 .28346 .24512 .27546 .23373 Mtetra
.651 .68 .864 r
.27546 .23373 .28346 .24512 .29604 .24056 .28807 .22907 Mtetra
.653 .679 .862 r
.28807 .22907 .29604 .24056 .30869 .23588 .30075 .22429 Mtetra
.655 .679 .861 r
.30075 .22429 .30869 .23588 .32141 .23107 .31349 .2194 Mtetra
.658 .679 .859 r
.31349 .2194 .32141 .23107 .33419 .22614 .32631 .21438 Mtetra
.66 .68 .858 r
.32631 .21438 .33419 .22614 .34704 .22107 .33919 .20925 Mtetra
.662 .68 .856 r
.33919 .20925 .34704 .22107 .35996 .21588 .35213 .20399 Mtetra
.665 .681 .855 r
.35213 .20399 .35996 .21588 .37294 .21054 .36514 .19862 Mtetra
.667 .682 .854 r
.36514 .19862 .37294 .21054 .38599 .20508 .37822 .19312 Mtetra
.669 .683 .854 r
.37822 .19312 .38599 .20508 .3991 .19949 .39136 .1875 Mtetra
.672 .684 .853 r
.39136 .1875 .3991 .19949 .41227 .19376 .40456 .18176 Mtetra
.674 .685 .853 r
.40456 .18176 .41227 .19376 .4255 .18792 .41782 .17591 Mtetra
.676 .687 .853 r
.41782 .17591 .4255 .18792 .4388 .18195 .43114 .16995 Mtetra
.678 .689 .853 r
.43114 .16995 .4388 .18195 .45215 .17588 .44452 .16389 Mtetra
.68 .691 .854 r
.44452 .16389 .45215 .17588 .46556 .16969 .45797 .15773 Mtetra
.682 .693 .854 r
.45797 .15773 .46556 .16969 .47902 .16341 .47146 .15148 Mtetra
.684 .695 .855 r
.47146 .15148 .47902 .16341 .49255 .15703 .48502 .14514 Mtetra
.685 .698 .856 r
.48502 .14514 .49255 .15703 .50613 .15058 .49864 .13873 Mtetra
.687 .7 .857 r
.49864 .13873 .50613 .15058 .51976 .14405 .51231 .13226 Mtetra
.688 .703 .858 r
.51231 .13226 .51976 .14405 .53345 .13745 .52603 .12572 Mtetra
.689 .705 .86 r
.52603 .12572 .53345 .13745 .54719 .1308 .53982 .11913 Mtetra
.69 .708 .862 r
.53982 .11913 .54719 .1308 .56099 .12411 .55366 .1125 Mtetra
.691 .71 .863 r
.55366 .1125 .56099 .12411 .57485 .11738 .56755 .10584 Mtetra
.691 .713 .865 r
.56755 .10584 .57485 .11738 .58876 .11063 .58151 .09914 Mtetra
.692 .716 .867 r
.58151 .09914 .58876 .11063 .60272 .10386 .59552 .09243 Mtetra
.692 .718 .869 r
.59552 .09243 .60272 .10386 .61675 .09708 .60959 .08571 Mtetra
.692 .72 .871 r
.60959 .08571 .61675 .09708 .63083 .09029 .62372 .07899 Mtetra
.692 .723 .873 r
.62372 .07899 .63083 .09029 .64497 .08351 .6379 .07226 Mtetra
.692 .725 .875 r
.6379 .07226 .64497 .08351 .65917 .07674 .65216 .06554 Mtetra
.691 .727 .878 r
.65216 .06554 .65917 .07674 .67343 .06999 .66647 .05883 Mtetra
.691 .729 .88 r
.66647 .05883 .67343 .06999 .68775 .06326 .68084 .05214 Mtetra
.69 .731 .882 r
.68084 .05214 .68775 .06326 .70214 .05654 .69528 .04546 Mtetra
.689 .732 .884 r
.69528 .04546 .70214 .05654 .71659 .04986 .70979 .03881 Mtetra
.63 .709 .903 r
.05141 .2944 .06008 .30351 .07149 .30008 .06285 .29087 Mtetra
.631 .708 .902 r
.06285 .29087 .07149 .30008 .08297 .29662 .07436 .28731 Mtetra
.631 .706 .9 r
.07436 .28731 .08297 .29662 .09451 .29313 .08593 .2837 Mtetra
.632 .704 .898 r
.08593 .2837 .09451 .29313 .1061 .28961 .09756 .28006 Mtetra
.633 .703 .897 r
.09756 .28006 .1061 .28961 .11777 .28604 .10926 .27638 Mtetra
.633 .701 .895 r
.10926 .27638 .11777 .28604 .12949 .28243 .12102 .27265 Mtetra
.634 .7 .893 r
.12102 .27265 .12949 .28243 .14129 .27877 .13285 .26886 Mtetra
.635 .698 .891 r
.13285 .26886 .14129 .27877 .15314 .27505 .14474 .26502 Mtetra
.637 .696 .889 r
.14474 .26502 .15314 .27505 .16507 .27128 .1567 .26112 Mtetra
.638 .695 .887 r
.1567 .26112 .16507 .27128 .17706 .26744 .16872 .25715 Mtetra
.639 .693 .884 r
.16872 .25715 .17706 .26744 .18912 .26352 .18081 .25311 Mtetra
.641 .692 .882 r
.18081 .25311 .18912 .26352 .20125 .25954 .19298 .249 Mtetra
.642 .691 .88 r
.19298 .249 .20125 .25954 .21344 .25547 .2052 .24481 Mtetra
.644 .69 .878 r
.2052 .24481 .21344 .25547 .22571 .25132 .2175 .24053 Mtetra
.646 .689 .876 r
.2175 .24053 .22571 .25132 .23804 .24707 .22987 .23617 Mtetra
.647 .688 .874 r
.22987 .23617 .23804 .24707 .25045 .24273 .2423 .23171 Mtetra
.649 .687 .872 r
.2423 .23171 .25045 .24273 .26292 .23828 .25481 .22716 Mtetra
.651 .686 .87 r
.25481 .22716 .26292 .23828 .27546 .23373 .26738 .2225 Mtetra
.653 .686 .868 r
.26738 .2225 .27546 .23373 .28807 .22907 .28002 .21774 Mtetra
.655 .685 .866 r
.28002 .21774 .28807 .22907 .30075 .22429 .29273 .21288 Mtetra
.657 .685 .865 r
.29273 .21288 .30075 .22429 .31349 .2194 .3055 .2079 Mtetra
.659 .685 .863 r
.3055 .2079 .31349 .2194 .32631 .21438 .31835 .20281 Mtetra
.662 .685 .862 r
.31835 .20281 .32631 .21438 .33919 .20925 .33126 .19761 Mtetra
.664 .686 .861 r
.33126 .19761 .33919 .20925 .35213 .20399 .34423 .1923 Mtetra
.666 .687 .86 r
.34423 .1923 .35213 .20399 .36514 .19862 .35727 .18688 Mtetra
.668 .687 .859 r
.35727 .18688 .36514 .19862 .37822 .19312 .37038 .18134 Mtetra
.67 .688 .858 r
.37038 .18134 .37822 .19312 .39136 .1875 .38354 .17569 Mtetra
.672 .69 .858 r
.38354 .17569 .39136 .1875 .40456 .18176 .39678 .16994 Mtetra
.674 .691 .858 r
.39678 .16994 .40456 .18176 .41782 .17591 .41007 .16408 Mtetra
.676 .692 .858 r
.41007 .16408 .41782 .17591 .43114 .16995 .42342 .15812 Mtetra
.678 .694 .858 r
.42342 .15812 .43114 .16995 .44452 .16389 .43684 .15207 Mtetra
.68 .696 .858 r
.43684 .15207 .44452 .16389 .45797 .15773 .45031 .14593 Mtetra
.681 .698 .859 r
.45031 .14593 .45797 .15773 .47146 .15148 .46384 .1397 Mtetra
.683 .7 .86 r
.46384 .1397 .47146 .15148 .48502 .14514 .47744 .1334 Mtetra
.684 .702 .86 r
.47744 .1334 .48502 .14514 .49864 .13873 .49109 .12702 Mtetra
.686 .704 .862 r
.49109 .12702 .49864 .13873 .51231 .13226 .50479 .12058 Mtetra
.687 .707 .863 r
.50479 .12058 .51231 .13226 .52603 .12572 .51856 .11409 Mtetra
.688 .709 .864 r
.51856 .11409 .52603 .12572 .53982 .11913 .53238 .10755 Mtetra
.689 .711 .866 r
.53238 .10755 .53982 .11913 .55366 .1125 .54626 .10097 Mtetra
.689 .714 .867 r
.54626 .10097 .55366 .1125 .56755 .10584 .5602 .09436 Mtetra
.69 .716 .869 r
.5602 .09436 .56755 .10584 .58151 .09914 .5742 .08772 Mtetra
.69 .718 .871 r
.5742 .08772 .58151 .09914 .59552 .09243 .58826 .08106 Mtetra
.69 .72 .872 r
.58826 .08106 .59552 .09243 .60959 .08571 .60237 .07438 Mtetra
.69 .723 .874 r
.60237 .07438 .60959 .08571 .62372 .07899 .61655 .0677 Mtetra
.69 .725 .876 r
.61655 .0677 .62372 .07899 .6379 .07226 .63079 .06102 Mtetra
.69 .727 .878 r
.63079 .06102 .6379 .07226 .65216 .06554 .64509 .05434 Mtetra
.689 .728 .88 r
.64509 .05434 .65216 .06554 .66647 .05883 .65945 .04767 Mtetra
.689 .73 .882 r
.65945 .04767 .66647 .05883 .68084 .05214 .67388 .041 Mtetra
.688 .732 .884 r
.67388 .041 .68084 .05214 .69528 .04546 .68838 .03435 Mtetra
.688 .733 .885 r
.68838 .03435 .69528 .04546 .70979 .03881 .70294 .02772 Mtetra
.632 .711 .903 r
.04266 .28527 .05141 .2944 .06285 .29087 .05414 .28163 Mtetra
.633 .709 .902 r
.05414 .28163 .06285 .29087 .07436 .28731 .06568 .27797 Mtetra
.633 .708 .9 r
.06568 .27797 .07436 .28731 .08593 .2837 .07728 .27426 Mtetra
.634 .707 .899 r
.07728 .27426 .08593 .2837 .09756 .28006 .08895 .27051 Mtetra
.635 .705 .897 r
.08895 .27051 .09756 .28006 .10926 .27638 .10067 .26672 Mtetra
.636 .704 .895 r
.10067 .26672 .10926 .27638 .12102 .27265 .11247 .26287 Mtetra
.637 .703 .894 r
.11247 .26287 .12102 .27265 .13285 .26886 .12433 .25897 Mtetra
.638 .701 .892 r
.12433 .25897 .13285 .26886 .14474 .26502 .13625 .25502 Mtetra
.639 .7 .89 r
.13625 .25502 .14474 .26502 .1567 .26112 .14825 .251 Mtetra
.64 .699 .888 r
.14825 .251 .1567 .26112 .16872 .25715 .1603 .24692 Mtetra
.642 .697 .886 r
.1603 .24692 .16872 .25715 .18081 .25311 .17243 .24276 Mtetra
.643 .696 .884 r
.17243 .24276 .18081 .25311 .19298 .249 .18462 .23854 Mtetra
.645 .695 .882 r
.18462 .23854 .19298 .249 .2052 .24481 .19689 .23423 Mtetra
.646 .694 .88 r
.19689 .23423 .2052 .24481 .2175 .24053 .20922 .22985 Mtetra
.648 .693 .878 r
.20922 .22985 .2175 .24053 .22987 .23617 .22162 .22537 Mtetra
.65 .692 .876 r
.22162 .22537 .22987 .23617 .2423 .23171 .23408 .22081 Mtetra
.651 .692 .875 r
.23408 .22081 .2423 .23171 .25481 .22716 .24662 .21616 Mtetra
.653 .691 .873 r
.24662 .21616 .25481 .22716 .26738 .2225 .25922 .21141 Mtetra
.655 .691 .871 r
.25922 .21141 .26738 .2225 .28002 .21774 .27189 .20656 Mtetra
.657 .691 .87 r
.27189 .20656 .28002 .21774 .29273 .21288 .28463 .20161 Mtetra
.659 .691 .868 r
.28463 .20161 .29273 .21288 .3055 .2079 .29744 .19655 Mtetra
.661 .691 .867 r
.29744 .19655 .3055 .2079 .31835 .20281 .31031 .1914 Mtetra
.663 .691 .866 r
.31031 .1914 .31835 .20281 .33126 .19761 .32325 .18614 Mtetra
.665 .691 .865 r
.32325 .18614 .33126 .19761 .34423 .1923 .33626 .18077 Mtetra
.667 .692 .864 r
.33626 .18077 .34423 .1923 .35727 .18688 .34933 .1753 Mtetra
.669 .693 .863 r
.34933 .1753 .35727 .18688 .37038 .18134 .36246 .16973 Mtetra
.671 .694 .863 r
.36246 .16973 .37038 .18134 .38354 .17569 .37566 .16405 Mtetra
.673 .695 .862 r
.37566 .16405 .38354 .17569 .39678 .16994 .38893 .15828 Mtetra
.675 .696 .862 r
.38893 .15828 .39678 .16994 .41007 .16408 .40225 .1524 Mtetra
.676 .697 .862 r
.40225 .1524 .41007 .16408 .42342 .15812 .41564 .14644 Mtetra
.678 .699 .862 r
.41564 .14644 .42342 .15812 .43684 .15207 .42908 .14039 Mtetra
.68 .701 .863 r
.42908 .14039 .43684 .15207 .45031 .14593 .44259 .13426 Mtetra
.681 .702 .863 r
.44259 .13426 .45031 .14593 .46384 .1397 .45616 .12805 Mtetra
.682 .704 .864 r
.45616 .12805 .46384 .1397 .47744 .1334 .46979 .12177 Mtetra
.684 .706 .865 r
.46979 .12177 .47744 .1334 .49109 .12702 .48347 .11542 Mtetra
.685 .708 .866 r
.48347 .11542 .49109 .12702 .50479 .12058 .49722 .10901 Mtetra
.686 .71 .867 r
.49722 .10901 .50479 .12058 .51856 .11409 .51102 .10255 Mtetra
.687 .712 .868 r
.51102 .10255 .51856 .11409 .53238 .10755 .52489 .09605 Mtetra
.687 .714 .869 r
.52489 .09605 .53238 .10755 .54626 .10097 .53881 .08951 Mtetra
.688 .716 .871 r
.53881 .08951 .54626 .10097 .5602 .09436 .55279 .08293 Mtetra
.688 .718 .872 r
.55279 .08293 .5602 .09436 .5742 .08772 .56683 .07633 Mtetra
.689 .721 .874 r
.56683 .07633 .5742 .08772 .58826 .08106 .58094 .06971 Mtetra
.689 .723 .875 r
.58094 .06971 .58826 .08106 .60237 .07438 .5951 .06307 Mtetra
.689 .724 .877 r
.5951 .06307 .60237 .07438 .61655 .0677 .60932 .05643 Mtetra
.689 .726 .879 r
.60932 .05643 .61655 .0677 .63079 .06102 .62361 .04978 Mtetra
.688 .728 .88 r
.62361 .04978 .63079 .06102 .64509 .05434 .63796 .04313 Mtetra
.688 .73 .882 r
.63796 .04313 .64509 .05434 .65945 .04767 .65238 .03648 Mtetra
.687 .731 .884 r
.65238 .03648 .65945 .04767 .67388 .041 .66686 .02984 Mtetra
.687 .733 .885 r
.66686 .02984 .67388 .041 .68838 .03435 .68141 .0232 Mtetra
.686 .734 .887 r
.68141 .0232 .68838 .03435 .70294 .02772 .69602 .01658 Mtetra
.634 .712 .903 r
.03384 .27608 .04266 .28527 .05414 .28163 .04535 .27236 Mtetra
.635 .711 .902 r
.04535 .27236 .05414 .28163 .06568 .27797 .05692 .2686 Mtetra
.636 .71 .9 r
.05692 .2686 .06568 .27797 .07728 .27426 .06855 .26479 Mtetra
.636 .709 .899 r
.06855 .26479 .07728 .27426 .08895 .27051 .08025 .26095 Mtetra
.637 .707 .897 r
.08025 .26095 .08895 .27051 .10067 .26672 .09201 .25705 Mtetra
.638 .706 .896 r
.09201 .25705 .10067 .26672 .11247 .26287 .10384 .2531 Mtetra
.639 .705 .894 r
.10384 .2531 .11247 .26287 .12433 .25897 .11573 .2491 Mtetra
.64 .704 .893 r
.11573 .2491 .12433 .25897 .13625 .25502 .12769 .24504 Mtetra
.641 .703 .891 r
.12769 .24504 .13625 .25502 .14825 .251 .13972 .24091 Mtetra
.643 .702 .889 r
.13972 .24091 .14825 .251 .1603 .24692 .15181 .23672 Mtetra
.644 .701 .887 r
.15181 .23672 .1603 .24692 .17243 .24276 .16397 .23246 Mtetra
.645 .7 .886 r
.16397 .23246 .17243 .24276 .18462 .23854 .17619 .22813 Mtetra
.647 .699 .884 r
.17619 .22813 .18462 .23854 .19689 .23423 .18849 .22372 Mtetra
.648 .698 .882 r
.18849 .22372 .19689 .23423 .20922 .22985 .20085 .21923 Mtetra
.65 .697 .881 r
.20085 .21923 .20922 .22985 .22162 .22537 .21328 .21466 Mtetra
.652 .697 .879 r
.21328 .21466 .22162 .22537 .23408 .22081 .22578 .21 Mtetra
.653 .696 .877 r
.22578 .21 .23408 .22081 .24662 .21616 .23835 .20525 Mtetra
.655 .696 .876 r
.23835 .20525 .24662 .21616 .25922 .21141 .25099 .20042 Mtetra
.657 .695 .874 r
.25099 .20042 .25922 .21141 .27189 .20656 .26369 .19548 Mtetra
.659 .695 .873 r
.26369 .19548 .27189 .20656 .28463 .20161 .27646 .19046 Mtetra
.66 .695 .872 r
.27646 .19046 .28463 .20161 .29744 .19655 .2893 .18533 Mtetra
.662 .695 .87 r
.2893 .18533 .29744 .19655 .31031 .1914 .3022 .18011 Mtetra
.664 .696 .869 r
.3022 .18011 .31031 .1914 .32325 .18614 .31517 .17479 Mtetra
.666 .696 .868 r
.31517 .17479 .32325 .18614 .33626 .18077 .32821 .16937 Mtetra
.668 .697 .868 r
.32821 .16937 .33626 .18077 .34933 .1753 .34131 .16386 Mtetra
.67 .697 .867 r
.34131 .16386 .34933 .1753 .36246 .16973 .35448 .15824 Mtetra
.671 .698 .867 r
.35448 .15824 .36246 .16973 .37566 .16405 .36771 .15254 Mtetra
.673 .699 .866 r
.36771 .15254 .37566 .16405 .38893 .15828 .381 .14674 Mtetra
.675 .7 .866 r
.381 .14674 .38893 .15828 .40225 .1524 .39436 .14086 Mtetra
.676 .702 .866 r
.39436 .14086 .40225 .1524 .41564 .14644 .40778 .13488 Mtetra
.678 .703 .866 r
.40778 .13488 .41564 .14644 .42908 .14039 .42126 .12883 Mtetra
.679 .705 .866 r
.42126 .12883 .42908 .14039 .44259 .13426 .43481 .1227 Mtetra
.681 .706 .867 r
.43481 .1227 .44259 .13426 .45616 .12805 .44841 .1165 Mtetra
.682 .708 .868 r
.44841 .1165 .45616 .12805 .46979 .12177 .46207 .11023 Mtetra
.683 .71 .868 r
.46207 .11023 .46979 .12177 .48347 .11542 .4758 .1039 Mtetra
.684 .711 .869 r
.4758 .1039 .48347 .11542 .49722 .10901 .48958 .09752 Mtetra
.685 .713 .87 r
.48958 .09752 .49722 .10901 .51102 .10255 .50343 .09109 Mtetra
.686 .715 .871 r
.50343 .09109 .51102 .10255 .52489 .09605 .51733 .08461 Mtetra
.686 .717 .872 r
.51733 .08461 .52489 .09605 .53881 .08951 .53129 .07809 Mtetra
.687 .719 .874 r
.53129 .07809 .53881 .08951 .55279 .08293 .54532 .07155 Mtetra
.687 .721 .875 r
.54532 .07155 .55279 .08293 .56683 .07633 .55941 .06498 Mtetra
.687 .723 .877 r
.55941 .06498 .56683 .07633 .58094 .06971 .57355 .05838 Mtetra
.687 .724 .878 r
.57355 .05838 .58094 .06971 .5951 .06307 .58777 .05177 Mtetra
.687 .726 .88 r
.58777 .05177 .5951 .06307 .60932 .05643 .60204 .04515 Mtetra
.687 .728 .881 r
.60204 .04515 .60932 .05643 .62361 .04978 .61638 .03852 Mtetra
.687 .729 .883 r
.61638 .03852 .62361 .04978 .63796 .04313 .63078 .03189 Mtetra
.687 .731 .884 r
.63078 .03189 .63796 .04313 .65238 .03648 .64524 .02526 Mtetra
.686 .732 .886 r
.64524 .02526 .65238 .03648 .66686 .02984 .65978 .01863 Mtetra
.685 .734 .887 r
.65978 .01863 .66686 .02984 .68141 .0232 .67438 .01201 Mtetra
.685 .735 .889 r
.67438 .01201 .68141 .0232 .69602 .01658 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.5774 .39549 m
.6032 .39521 L
.62374 .3968 L
.629 .39747 L
.6548 .40233 L
.6806 .40994 L
.7064 .42059 L
.71056 .4226 L
.7322 .43467 L
.7522 .4484 L
.758 .45293 L
.78149 .4742 L
.7838 .47659 L
.80368 .5 L
.8096 .50815 L
.82084 .5258 L
.83403 .5516 L
.8354 .55464 L
.84392 .5774 L
.85085 .6032 L
.85507 .629 L
.85671 .6548 L
.85582 .6806 L
.85237 .7064 L
.84626 .7322 L
.83728 .758 L
.8354 .76257 L
.82513 .7838 L
.8096 .80905 L
.80921 .8096 L
.78868 .8354 L
.7838 .84065 L
.76181 .8612 L
.758 .8643 L
.7322 .88256 L
.72484 .887 L
.7064 .89665 L
.6806 .90729 L
.66333 .9128 L
.6548 .91491 L
.629 .91977 L
.6032 .92203 L
.5774 .92176 L
.5516 .91893 L
.5258 .91348 L
.52318 .9128 L
.5 .90523 L
.4742 .89387 L
.46142 .887 L
.4484 .87895 L
Mistroke
.42446 .8612 L
.4226 .85963 L
.39759 .8354 L
.3968 .83452 L
.37704 .8096 L
.371 .8006 L
.36114 .7838 L
.34898 .758 L
.3452 .74841 L
.34 .7322 L
.33389 .7064 L
.33044 .6806 L
.32955 .6548 L
.33119 .629 L
.33541 .6032 L
.34235 .5774 L
.3452 .56891 L
.35222 .5516 L
.36543 .5258 L
.371 .51664 L
.38258 .5 L
.3968 .48269 L
.40476 .4742 L
.4226 .45759 L
.43405 .4484 L
.4484 .43829 L
.4742 .42337 L
.47571 .4226 L
.5 .41201 L
.5258 .40375 L
.5516 .39831 L
.56252 .3968 L
.5774 .39549 L
Mfstroke
.40363 .9902 m
.4226 .98464 L
.4484 .97467 L
.46899 .9644 L
.4742 .96139 L
.5 .94409 L
.507 .9386 L
.5258 .92174 L
.53444 .9128 L
.5516 .89215 L
.55535 .887 L
.57156 .8612 L
.5774 .85004 L
.58397 .8354 L
.59317 .8096 L
.59947 .7838 L
.6031 .758 L
.6032 .75693 L
.60418 .7322 L
.6032 .71138 L
.60272 .7064 L
.59869 .6806 L
.59197 .6548 L
.58231 .629 L
.5774 .61828 L
.56937 .6032 L
.55251 .5774 L
.5516 .57617 L
.53075 .5516 L
.5258 .54657 L
.50207 .5258 L
.5 .52422 L
.4742 .50691 L
.46175 .5 L
.4484 .4936 L
.4226 .48363 L
.3968 .47661 L
.38742 .4742 L
.371 .47231 L
.3452 .47059 L
.3194 .4714 L
.29688 .4742 L
.2936 .47477 L
.2678 .48079 L
.242 .48967 L
.21946 .5 L
.2162 .50174 L
.1904 .5175 L
.17907 .5258 L
.1646 .53788 L
Mistroke
.1504 .5516 L
.1388 .5645 L
.12864 .5774 L
.113 .60113 L
.11181 .6032 L
.09885 .629 L
.08921 .6548 L
.0872 .66096 L
.08248 .6806 L
.07844 .7064 L
.07698 .7322 L
.07806 .758 L
.0817 .7838 L
.0872 .80715 L
.08801 .8096 L
.09719 .8354 L
.10961 .8612 L
.113 .8672 L
.1258 .887 L
.1388 .9038 L
.14673 .9128 L
.1646 .93043 L
.17415 .9386 L
.1904 .9508 L
.21221 .9644 L
.2162 .96656 L
.242 .9786 L
.2678 .98749 L
.27703 .9902 L
Mfstroke
.0098 .65567 m
.0356 .6721 L
.05055 .6806 L
.0614 .68632 L
.0872 .69855 L
.10623 .7064 L
.113 .70895 L
.1388 .71765 L
.1646 .72475 L
.1904 .73031 L
.20079 .7322 L
.2162 .73439 L
.242 .73704 L
.2678 .73827 L
.2936 .73809 L
.3194 .73651 L
.3452 .73351 L
.35403 .7322 L
.371 .72906 L
.3968 .72312 L
.4226 .71564 L
.4484 .70652 L
.44872 .7064 L
.4742 .69568 L
.5 .68297 L
.50442 .6806 L
.5258 .66823 L
.54645 .6548 L
.5516 .6512 L
.5774 .6316 L
.58056 .629 L
.6032 .60896 L
.6092 .6032 L
.629 .58265 L
.63369 .5774 L
.6548 .55166 L
.65484 .5516 L
.6732 .5258 L
.6806 .51427 L
.68912 .5 L
.70289 .4742 L
.7064 .46696 L
.7147 .4484 L
.72472 .4226 L
.7322 .39975 L
.73306 .3968 L
.73982 .371 L
.74505 .3452 L
.74882 .3194 L
.75115 .2936 L
Mistroke
.75208 .2678 L
.75159 .242 L
.74971 .2162 L
.74639 .1904 L
.74162 .1646 L
.73535 .1388 L
.7322 .12773 L
.72751 .113 L
.71803 .0872 L
.70679 .0614 L
.7064 .06057 L
.69366 .0356 L
.6806 .01328 L
.67843 .0098 L
Mfstroke
0 g
.03 w
.59313 .65862 Mdot
.34058 .73415 Mdot
.27749 .26376 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.46078 .57701 m
.48039 .57763 L
.48631 .57843 L
.5 .58139 L
.51961 .58883 L
.5351 .59804 L
.53922 .60118 L
.5556 .61765 L
.55882 .62169 L
.5675 .63725 L
.57381 .65686 L
.57562 .67647 L
.57333 .69608 L
.56677 .71569 L
.55882 .73056 L
.5553 .73529 L
.53922 .75307 L
.53711 .7549 L
.51961 .76755 L
.50638 .77451 L
.5 .77709 L
.48039 .78306 L
.46078 .78586 L
.44118 .78566 L
.42157 .78232 L
.40196 .77534 L
.40014 .77451 L
.38235 .76377 L
.37209 .7549 L
.36275 .74445 L
.35678 .73529 L
.34806 .71569 L
.34423 .69608 L
.34458 .67647 L
.34899 .65686 L
.3579 .63725 L
.36275 .62945 L
.37233 .61765 L
.38235 .60788 L
.39543 .59804 L
.40196 .59407 L
.42157 .58491 L
.44118 .57941 L
.44671 .57843 L
.46078 .57701 L
s
.44118 .51727 m
.46078 .51547 L
.48039 .51559 L
.5 .51767 L
.51148 .51961 L
.51961 .52181 L
.53922 .52824 L
.55882 .53734 L
.56222 .53922 L
.57843 .54972 L
.58977 .55882 L
.59804 .56662 L
.60854 .57843 L
.61765 .59097 L
.62192 .59804 L
.63131 .61765 L
.63725 .6365 L
.63742 .63725 L
.64066 .65686 L
.64122 .67647 L
.63919 .69608 L
.63725 .70747 L
.63452 .71569 L
.62704 .73529 L
.61765 .75299 L
.61644 .7549 L
.60213 .77451 L
.59804 .77923 L
.58301 .79412 L
.57843 .79805 L
.55882 .8124 L
.55674 .81373 L
.53922 .8235 L
.51961 .83196 L
.51595 .83333 L
.5 .83818 L
.48039 .84235 L
.46078 .84458 L
.44118 .84492 L
.42157 .84331 L
.40196 .83967 L
.38235 .83376 L
.38116 .83333 L
.36275 .82529 L
.34333 .81373 L
.34314 .81359 L
.32353 .79761 L
.32 .79412 L
.30392 .77476 L
.30375 .77451 L
Mistroke
.2922 .7549 L
.28431 .73533 L
.2843 .73529 L
.27945 .71569 L
.27735 .69608 L
.27783 .67647 L
.28087 .65686 L
.28431 .64316 L
.28655 .63725 L
.29507 .61765 L
.30392 .60234 L
.30685 .59804 L
.32261 .57843 L
.32353 .57744 L
.34314 .55932 L
.34375 .55882 L
.36275 .54548 L
.37362 .53922 L
.38235 .53485 L
.40196 .5268 L
.42157 .52101 L
.42661 .51961 L
.44118 .51727 L
Mfstroke
.40196 .47448 m
.42157 .46992 L
.44118 .46691 L
.46078 .46541 L
.48039 .4654 L
.5 .4669 L
.51961 .46996 L
.53922 .47468 L
.55672 .48039 L
.55882 .4812 L
.57843 .48974 L
.59702 .5 L
.59804 .50064 L
.61765 .51441 L
.62398 .51961 L
.63725 .53198 L
.64402 .53922 L
.65686 .55518 L
.65942 .55882 L
.67131 .57843 L
.67647 .58888 L
.6803 .59804 L
.68678 .61765 L
.691 .63725 L
.6931 .65686 L
.69318 .67647 L
.69125 .69608 L
.6873 .71569 L
.68124 .73529 L
.67647 .7473 L
.67292 .7549 L
.66212 .77451 L
.65686 .78262 L
.64847 .79412 L
.63725 .80749 L
.6314 .81373 L
.61765 .8268 L
.6099 .83333 L
.59804 .84236 L
.58203 .85294 L
.57843 .85509 L
.55882 .86551 L
.5428 .87255 L
.53922 .87395 L
.51961 .88062 L
.5 .88567 L
.48039 .88918 L
.46078 .8912 L
.44118 .89175 L
.42157 .89081 L
Mistroke
.40196 .88833 L
.38235 .88422 L
.36275 .87834 L
.34777 .87255 L
.34314 .87048 L
.32353 .86034 L
.31172 .85294 L
.30392 .84742 L
.28691 .83333 L
.28431 .8309 L
.26833 .81373 L
.26471 .80923 L
.25406 .79412 L
.2451 .7785 L
.24313 .77451 L
.23496 .7549 L
.22919 .73529 L
.22562 .71569 L
.22549 .7147 L
.22408 .69608 L
.22452 .67647 L
.22549 .66654 L
.22692 .65686 L
.2313 .63725 L
.23776 .61765 L
.2451 .60075 L
.24646 .59804 L
.25764 .57843 L
.26471 .56802 L
.2717 .55882 L
.28431 .54432 L
.28928 .53922 L
.30392 .52576 L
.31148 .51961 L
.32353 .51078 L
.34061 .5 L
.34314 .49857 L
.36275 .48863 L
.38235 .48067 L
.38312 .48039 L
.40196 .47448 L
Mfstroke
.44118 .42002 m
.46078 .41875 L
.48039 .41872 L
.5 .41995 L
.51482 .42157 L
.51961 .42246 L
.53922 .42631 L
.55882 .43157 L
.57843 .43836 L
.58543 .44118 L
.59804 .44684 L
.61765 .45722 L
.6236 .46078 L
.63725 .46981 L
.65121 .48039 L
.65686 .48512 L
.6727 .5 L
.67647 .50394 L
.68993 .51961 L
.69608 .52773 L
.70388 .53922 L
.71511 .55882 L
.71569 .55995 L
.72402 .57843 L
.73086 .59804 L
.73529 .61512 L
.7358 .61765 L
.73897 .63725 L
.74042 .65686 L
.74021 .67647 L
.73835 .69608 L
.73529 .71391 L
.73482 .71569 L
.72956 .73529 L
.7225 .7549 L
.71569 .77017 L
.71351 .77451 L
.70239 .79412 L
.69608 .80377 L
.6889 .81373 L
.67647 .82903 L
.67263 .83333 L
.65686 .84936 L
.65299 .85294 L
.63725 .86625 L
.62898 .87255 L
.61765 .88048 L
.59871 .89216 L
.59804 .89254 L
.57843 .90274 L
Mistroke
.55882 .9113 L
.55766 .91176 L
.53922 .91838 L
.51961 .92408 L
.5 .92847 L
.48231 .93137 L
.48039 .93161 L
.46078 .93351 L
.44118 .93419 L
.42157 .93364 L
.40196 .93182 L
.39826 .93137 L
.38235 .92869 L
.36275 .92417 L
.34314 .91815 L
.3265 .91176 L
.32353 .91049 L
.30392 .90097 L
.28874 .89216 L
.28431 .88931 L
.26471 .87507 L
.26162 .87255 L
.2451 .85754 L
.2406 .85294 L
.22549 .83548 L
.22383 .83333 L
.21032 .81373 L
.20588 .80626 L
.19947 .79412 L
.19091 .77451 L
.18627 .76131 L
.18439 .7549 L
.17972 .73529 L
.17678 .71569 L
.1755 .69608 L
.17584 .67647 L
.17778 .65686 L
.18133 .63725 L
.18627 .61851 L
.18655 .61765 L
.19351 .59804 L
.20234 .57843 L
.20588 .5716 L
.21322 .55882 L
.22549 .54046 L
.2264 .53922 L
.24227 .51961 L
.2451 .51647 L
.26142 .5 L
.26471 .49699 L
Mistroke
.28431 .48078 L
.28483 .48039 L
.30392 .46715 L
.31434 .46078 L
.32353 .45565 L
.34314 .44599 L
.35444 .44118 L
.36275 .43798 L
.38235 .43146 L
.40196 .42634 L
.42157 .42254 L
.42706 .42157 L
.44118 .42002 L
Mfstroke
.40196 .37839 m
.42157 .37517 L
.44118 .37305 L
.46078 .37201 L
.48039 .37204 L
.5 .37315 L
.51961 .37536 L
.53922 .3787 L
.55548 .38235 L
.55882 .38323 L
.57843 .389 L
.59804 .3961 L
.61184 .40196 L
.61765 .40466 L
.63725 .41484 L
.64865 .42157 L
.65686 .42685 L
.67647 .441 L
.6767 .44118 L
.69608 .45775 L
.69929 .46078 L
.71569 .47783 L
.71793 .48039 L
.73348 .5 L
.73529 .50253 L
.74648 .51961 L
.7549 .53454 L
.75729 .53922 L
.76615 .55882 L
.77325 .57843 L
.77451 .58239 L
.77872 .59804 L
.78264 .61765 L
.78509 .63725 L
.7861 .65686 L
.78569 .67647 L
.78388 .69608 L
.78064 .71569 L
.77594 .73529 L
.77451 .74031 L
.76972 .7549 L
.7619 .77451 L
.7549 .78928 L
.75238 .79412 L
.741 .81373 L
.73529 .82245 L
.72755 .83333 L
.71569 .84835 L
.71175 .85294 L
.69608 .8697 L
Mistroke
.69319 .87255 L
.67647 .88779 L
.67124 .89216 L
.65686 .90332 L
.64488 .91176 L
.63725 .91677 L
.61765 .92843 L
.61223 .93137 L
.59804 .93853 L
.57843 .94723 L
.56892 .95098 L
.55882 .95463 L
.53922 .96082 L
.51961 .96587 L
.5 .96982 L
.49573 .97059 L
.48039 .97271 L
.46078 .97453 L
.44118 .97531 L
.42157 .97502 L
.40196 .97366 L
.38235 .97119 L
.37851 .97059 L
.36275 .96756 L
.34314 .9627 L
.32353 .95654 L
.30878 .95098 L
.30392 .94896 L
.28431 .93981 L
.26888 .93137 L
.26471 .92888 L
.2451 .91591 L
.23948 .91176 L
.22549 .90049 L
.21621 .89216 L
.20588 .88198 L
.19719 .87255 L
.18627 .85936 L
.18144 .85294 L
.16832 .83333 L
.16667 .83058 L
.15745 .81373 L
.14854 .79412 L
.14706 .79045 L
.14139 .77451 L
.13586 .7549 L
.13185 .73529 L
.12928 .71569 L
.12811 .69608 L
.1283 .67647 L
Mistroke
.12984 .65686 L
.13274 .63725 L
.13703 .61765 L
.14275 .59804 L
.14706 .58581 L
.14997 .57843 L
.15879 .55882 L
.16667 .54386 L
.16934 .53922 L
.1818 .51961 L
.18627 .51327 L
.19642 .5 L
.20588 .4888 L
.21358 .48039 L
.22549 .46844 L
.2338 .46078 L
.2451 .45116 L
.25795 .44118 L
.26471 .43631 L
.28431 .42352 L
.28757 .42157 L
.30392 .41248 L
.32353 .40302 L
.32592 .40196 L
.34314 .39497 L
.36275 .38824 L
.38235 .38273 L
.38385 .38235 L
.40196 .37839 L
Mfstroke
.58195 .9902 m
.59804 .98385 L
.61765 .97507 L
.62676 .97059 L
.63725 .96507 L
.65686 .95372 L
.66125 .95098 L
.67647 .94086 L
.68952 .93137 L
.69608 .92629 L
.7134 .91176 L
.71569 .90971 L
.73389 .89216 L
.73529 .8907 L
.75162 .87255 L
.7549 .8686 L
.76702 .85294 L
.77451 .84231 L
.78039 .83333 L
.79194 .81373 L
.79412 .80967 L
.80183 .79412 L
.81021 .77451 L
.81373 .7651 L
.81715 .7549 L
.82273 .73529 L
.82701 .71569 L
.83003 .69608 L
.83181 .67647 L
.83236 .65686 L
.83169 .63725 L
.82979 .61765 L
.82663 .59804 L
.82217 .57843 L
.81636 .55882 L
.81373 .55116 L
.80914 .53922 L
.80039 .51961 L
.79412 .50738 L
.79 .5 L
.77779 .48039 L
.77451 .47561 L
.76353 .46078 L
.7549 .45023 L
.7469 .44118 L
.73529 .4291 L
.72744 .42157 L
.71569 .41112 L
.70444 .40196 L
.69608 .39563 L
Mistroke
.67672 .38235 L
.67647 .3822 L
.65686 .37053 L
.64202 .36275 L
.63725 .36043 L
.61765 .35172 L
.59804 .34428 L
.59471 .34314 L
.57843 .33804 L
.55882 .3329 L
.53922 .32882 L
.51961 .32576 L
.5 .32368 L
.49813 .32353 L
.48039 .32256 L
.46078 .32239 L
.44118 .32317 L
.43494 .32353 L
.42157 .3249 L
.40196 .32759 L
.38235 .33125 L
.36275 .33593 L
.34314 .34166 L
.33858 .34314 L
.32353 .34848 L
.30392 .35648 L
.29033 .36275 L
.28431 .36573 L
.26471 .37634 L
.25465 .38235 L
.2451 .38846 L
.22591 .40196 L
.22549 .40228 L
.20588 .41805 L
.20185 .42157 L
.18627 .43615 L
.18129 .44118 L
.16667 .45711 L
.16352 .46078 L
.14808 .48039 L
.14706 .48179 L
.13464 .5 L
.12745 .51174 L
.12297 .51961 L
.1129 .53922 L
.10784 .55034 L
.1043 .55882 L
.09707 .57843 L
.09114 .59804 L
.08824 .60947 L
Mistroke
.08645 .61765 L
.08296 .63725 L
.08065 .65686 L
.07949 .67647 L
.0795 .69608 L
.08068 .71569 L
.08305 .73529 L
.08664 .7549 L
.08824 .76205 L
.0915 .77451 L
.09771 .79412 L
.10535 .81373 L
.10784 .81941 L
.11454 .83333 L
.12544 .85294 L
.12745 .85624 L
.13825 .87255 L
.14706 .88443 L
.15326 .89216 L
.16667 .90735 L
.17089 .91176 L
.18627 .92654 L
.19176 .93137 L
.20588 .94288 L
.21685 .95098 L
.22549 .95689 L
.2451 .96895 L
.24799 .97059 L
.26471 .97932 L
.28431 .98818 L
.28924 .9902 L
Mfstroke
.68213 .9902 m
.69608 .9813 L
.71155 .97059 L
.71569 .96756 L
.73529 .95219 L
.73675 .95098 L
.7549 .93493 L
.75866 .93137 L
.77451 .91539 L
.77788 .91176 L
.79412 .89302 L
.79482 .89216 L
.80977 .87255 L
.81373 .86692 L
.82295 .85294 L
.83333 .83549 L
.83453 .83333 L
.84464 .81373 L
.85294 .7952 L
.85339 .79412 L
.86085 .77451 L
.86709 .7549 L
.87216 .73529 L
.87255 .73363 L
.8761 .71569 L
.87893 .69608 L
.88069 .67647 L
.88137 .65686 L
.88098 .63725 L
.87953 .61765 L
.87699 .59804 L
.87334 .57843 L
.87255 .57479 L
.86856 .55882 L
.86259 .53922 L
.8554 .51961 L
.85294 .51361 L
.8469 .5 L
.837 .48039 L
.83333 .47378 L
.8256 .46078 L
.81373 .44286 L
.81254 .44118 L
.79762 .42157 L
.79412 .41731 L
.7806 .40196 L
.77451 .39554 L
.7611 .38235 L
.7549 .37666 L
.73861 .36275 L
Mistroke
.73529 .36009 L
.71569 .34548 L
.71231 .34314 L
.69608 .33254 L
.68086 .32353 L
.67647 .32109 L
.65686 .31096 L
.64159 .30392 L
.63725 .30206 L
.61765 .29427 L
.59804 .28754 L
.58744 .28431 L
.57843 .28181 L
.55882 .27702 L
.53922 .27314 L
.51961 .27015 L
.5 .26803 L
.48039 .26676 L
.46078 .26633 L
.44118 .26675 L
.42157 .26801 L
.40196 .27012 L
.38235 .27311 L
.36275 .27698 L
.34314 .28178 L
.33405 .28431 L
.32353 .28752 L
.30392 .29427 L
.28431 .30207 L
.28002 .30392 L
.26471 .31099 L
.2451 .32112 L
.24076 .32353 L
.22549 .33256 L
.20922 .34314 L
.20588 .34544 L
.18627 .35995 L
.18275 .36275 L
.16667 .3763 L
.15998 .38235 L
.14706 .39481 L
.14011 .40196 L
.12745 .41592 L
.12264 .42157 L
.10784 .44031 L
.1072 .44118 L
.09353 .46078 L
.08824 .46907 L
.08144 .48039 L
.07078 .5 L
Mistroke
.06863 .5043 L
.06145 .51961 L
.05335 .53922 L
.04902 .55105 L
.04641 .55882 L
.04058 .57843 L
.03581 .59804 L
.03208 .61765 L
.02941 .63681 L
.02936 .63725 L
.02765 .65686 L
.02692 .67647 L
.02719 .69608 L
.02847 .71569 L
.02941 .72558 L
.03077 .73529 L
.03411 .7549 L
.03854 .77451 L
.0441 .79412 L
.04902 .80879 L
.05084 .81373 L
.05885 .83333 L
.06822 .85294 L
.06863 .85374 L
.07907 .87255 L
.08824 .8872 L
.09156 .89216 L
.10591 .91176 L
.10784 .91421 L
.12239 .93137 L
.12745 .93687 L
.14141 .95098 L
.14706 .95628 L
.16355 .97059 L
.16667 .97311 L
.18627 .98781 L
.18972 .9902 L
Mfstroke
.0098 .47561 m
.01688 .46078 L
.02723 .44118 L
.02941 .43732 L
.03879 .42157 L
.04902 .4058 L
.05164 .40196 L
.06594 .38235 L
.06863 .37889 L
.08185 .36275 L
.08824 .35544 L
.0996 .34314 L
.10784 .33474 L
.11951 .32353 L
.12745 .31633 L
.14202 .30392 L
.14706 .29986 L
.16667 .2851 L
.16778 .28431 L
.18627 .27186 L
.19784 .26471 L
.20588 .26 L
.22549 .24939 L
.23411 .2451 L
.2451 .23994 L
.26471 .23158 L
.28076 .22549 L
.28431 .22423 L
.30392 .21785 L
.32353 .21239 L
.34314 .2078 L
.35258 .20588 L
.36275 .20406 L
.38235 .20114 L
.40196 .19901 L
.42157 .19767 L
.44118 .1971 L
.46078 .19728 L
.48039 .19822 L
.5 .19991 L
.51961 .20235 L
.53922 .20556 L
.54098 .20588 L
.55882 .20954 L
.57843 .21432 L
.59804 .21991 L
.61519 .22549 L
.61765 .22634 L
.63725 .23366 L
.65686 .2419 L
Mistroke
.66393 .2451 L
.67647 .25111 L
.69608 .26137 L
.70203 .26471 L
.71569 .27277 L
.73369 .28431 L
.73529 .28539 L
.7549 .29939 L
.76084 .30392 L
.77451 .31492 L
.78454 .32353 L
.79412 .33222 L
.80545 .34314 L
.81373 .35159 L
.82404 .36275 L
.83333 .37346 L
.84062 .38235 L
.85294 .39849 L
.85544 .40196 L
.86868 .42157 L
.87255 .42775 L
.88047 .44118 L
.89094 .46078 L
.89216 .46322 L
.90018 .48039 L
.90825 .5 L
.91176 .50951 L
.91521 .51961 L
.92112 .53922 L
.92601 .55882 L
.92992 .57843 L
.93137 .58713 L
.93285 .59804 L
.93485 .61765 L
.9359 .63725 L
.93603 .65686 L
.93522 .67647 L
.93348 .69608 L
.93137 .71223 L
.9308 .71569 L
.92715 .73529 L
.92252 .7549 L
.91688 .77451 L
.91176 .78979 L
.91019 .79412 L
.90241 .81373 L
.89348 .83333 L
.89216 .83604 L
.88334 .85294 L
.87255 .8715 L
Mistroke
.8719 .87255 L
.85906 .89216 L
.85294 .90078 L
.8447 .91176 L
.83333 .92587 L
.82865 .93137 L
.81373 .94784 L
.81072 .95098 L
.79412 .96734 L
.79063 .97059 L
.77451 .98481 L
.76802 .9902 L
Mfstroke
.0098 .8622 m
.01494 .87255 L
.02565 .89216 L
.02941 .8985 L
.03776 .91176 L
.04902 .9281 L
.05141 .93137 L
.0668 .95098 L
.06863 .95315 L
.08419 .97059 L
.08824 .97482 L
.10392 .9902 L
s
.0098 .29621 m
.01903 .28431 L
.02941 .27168 L
.03543 .26471 L
.04902 .24978 L
.05351 .2451 L
.06863 .23012 L
.07357 .22549 L
.08824 .21242 L
.09602 .20588 L
.10784 .19646 L
.1215 .18627 L
.12745 .18207 L
.14706 .1691 L
.15099 .16667 L
.16667 .15746 L
.18623 .14706 L
.18627 .14704 L
.20588 .13776 L
.22549 .12954 L
.23091 .12745 L
.2451 .12234 L
.26471 .1161 L
.28431 .11076 L
.29667 .10784 L
.30392 .1063 L
.32353 .10266 L
.34314 .09983 L
.36275 .09776 L
.38235 .09644 L
.40196 .09585 L
.42157 .09596 L
.44118 .09677 L
.46078 .09825 L
.48039 .1004 L
.5 .10322 L
.51961 .10669 L
.52541 .10784 L
.53922 .11083 L
.55882 .11564 L
.57843 .12111 L
.59804 .12727 L
.59859 .12745 L
.61765 .13413 L
.63725 .1417 L
.65008 .14706 L
.65686 .15003 L
.67647 .15913 L
.69153 .16667 L
.69608 .16904 L
Mistroke
.71569 .17983 L
.72669 .18627 L
.73529 .19153 L
.7549 .20422 L
.75736 .20588 L
.77451 .21799 L
.78455 .22549 L
.79412 .23295 L
.80892 .2451 L
.81373 .24922 L
.83093 .26471 L
.83333 .26697 L
.85089 .28431 L
.85294 .28644 L
.86906 .30392 L
.87255 .3079 L
.88563 .32353 L
.89216 .33178 L
.90074 .34314 L
.91176 .35868 L
.91452 .36275 L
.92706 .38235 L
.93137 .38955 L
.93845 .40196 L
.94876 .42157 L
.95098 .42607 L
.95804 .44118 L
.96634 .46078 L
.97059 .47179 L
.9737 .48039 L
.98016 .5 L
.98574 .51961 L
.9902 .53802 L
Mfstroke
.9902 .74871 m
.98876 .7549 L
.98366 .77451 L
.97766 .79412 L
.97074 .81373 L
.97059 .81412 L
.96285 .83333 L
.95397 .85294 L
.95098 .85907 L
.94403 .87255 L
.93297 .89216 L
.93137 .89482 L
.92071 .91176 L
.91176 .92493 L
.90716 .93137 L
.89222 .95098 L
.89216 .95106 L
.87575 .97059 L
.87255 .97418 L
.85757 .9902 L
s
.0098 .98625 m
.01312 .9902 L
s
.9902 .96091 m
.98343 .97059 L
.97059 .9879 L
.96882 .9902 L
s
.9902 .29201 m
.98529 .28431 L
.97217 .26471 L
.97059 .26244 L
.95814 .2451 L
.95098 .23557 L
.94316 .22549 L
.93137 .21088 L
.92721 .20588 L
.91176 .18801 L
.91022 .18627 L
.89216 .16668 L
.89214 .16667 L
.87293 .14706 L
.87255 .14668 L
.85294 .12785 L
.85252 .12745 L
.83333 .11005 L
.83082 .10784 L
.81373 .09319 L
.80777 .08824 L
.79412 .07717 L
.78324 .06863 L
.77451 .06193 L
.75713 .04902 L
.7549 .04741 L
.73529 .03355 L
.72925 .02941 L
.71569 .02033 L
.6994 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo07_ooooo0`00
000dooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooogd06ATI<000
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooogh06ATI;`00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooogl06ATI;P00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooh006ATI00?o
0000000000000000:P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooh806ATI:`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooh@06ATI:@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooh@06ATI00?o00000000000000009P000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooohH06ATI9`000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooohL06ATI9P000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooohT06ATI90000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooohX06ATI8`000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?oooooooooooooooh/06ATI8P000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?oooooooooooooooh`06ATI8@000004ooooo`0300000?oooooooooo08_ooooo0_l0
0012ooooo`002Oooool01000003ooooooooooooooon=01TI6@0300000?l00000000001d000001?oo
ool00`00003oooooooooo`28ooooo`?o000000?oooooo`000?ooool0@Oooool000Wooooo00@00000
oooooooooooooooo?@0I6ATF000003`06ATI7P000004ooooo`0300000?oooooooooo08Kooooo0_l0
0003ooooo`03ojnlhol0003o0000047ooooo0009ooooo`0400000?ooooooooooooooocH06ATI1`00
000F03<c<`H00000=`0I6ATM000000Cooooo00<00000ooooooooool0Poooool3o`0000;ooooo00Oo
[k_Sojnlhon__>?o[kcSo`000?oooooo0000043ooooo0009ooooo`0400000?oooooooooooooooc40
6ATI1@00000S03<c<`0400000?l000000000000003@06ATI00<00000o`00000000006@000004oooo
o`0300000?oooooooooo083ooooo0ol00003ooooo`Co[k_S0_n__><00ol0003oooooo`000010oooo
o`002Oooool01000003oooooooooooooool/01TI6@D00000;00c<c<7000002l06ATI6P000004oooo
o`0300000?oooooooooo07kooooo0_l00005ooooo`;o[k_R0on_^n<01_n_^n;o[k_So`000?n_^n?o
ooooo`0003oooooo0009ooooo`0400000?ooooooooooooooobX06ATI0P00000h03<c<`<00000;@0I
6ATI000000Cooooo00<00000ooooooooool0Noooool3o`0000Gooooo1On_^n801_n_^n?o[k_Rojnk
h_n_^n;o0000ok2khP;ooooo00?o0000ooooooooool0??ooool000Wooooo00@00000oooooooooooo
oooo9`0I6AT3000003d0<c<c0`00000[01TI6AP000001?ooool00`00003oooooooooo`1iooooo`;o
00001Oooool00on_^^;o[k_RojnkhP08ojnkhP06ok2kh_l0003o/;_Rok2kh_oooooo0000?_ooool0
00Wooooo00@00000oooooooooooooooo900I6AT200000003o`00000c<c<0<c<c0440<c<c00<00000
01TI6@0I6AT0:00I6AT00ol0000000000000000E000000Cooooo00<00000ooooooooool0M_ooool3
o`0000Gooooo00Co[k[Qojnjh_n_^^;o[k[R0_n_^n800on`^^7o[k_RojnkhP03ojnkhP;o/;_R00Ko
0000ok2kh_n`^n;o/;_Rooooool0000mooooo`002Oooool01000003ooooooooooooooolQ01TI6@<0
0000A`0c<c<3000002P06ATI5`000004ooooo`0300000?oooooooooo07Cooooo0_l00005ooooo`03
ojnihOn_^^7o[k[Q00;o[k[Q00?o[k[Rok2jhOn`^^400on`^^42ojnkhP05ok2jhOn`^n;o/;_Rok2k
h_l000001?n`^n800ol0003oooooooooo`0kooooo`002Oooool01000003ooooooooooooooolP01TI
6@030000000c<c<0<c<c04/0<c<c0`00000V01TI6AH000001?ooool00`00003oooooooooo`1aoooo
o`?o00001Oooool4ojnih@;o[k[Q00?o/;WQok2jhOn`^^402?n`^^401?n`^n;o/;_Qo`000?n`^n42
ok2khP03ok2khOoooooo000003cooooo0009ooooo`0400000?oooooooooooooooah06ATI0P00001A
03<c<`03o`0000000000000002@06ATI00<00000o`00000000004P000004ooooo`0300000?oooooo
oooo06kooooo0ol00007ooooo`;o[kWP0on_^N401?n`^N3o/;WQok2ihOn`^N42ok2jh@03ok2jh?n`
^^7o/;[Q00Co/;[Q0_n`^n400ol0003o/K[Qok2kh@03ok2kh@03ooooool0003ooooo03[ooooo0009
ooooo`0400000?oooooooooooooooa`06ATI0P00001F03<c<`800000900I6ATC000000Cooooo00<0
0000ooooooooool0K?ooool2o`0000Sooooo1On_^N001_n_^N7o/;WPok2ih?n`^N3o/;WQok2ih0Co
/;[P0_n`^^402?n`^^3o/;[Qok2jhOn`^^7o/;_Qok6jhOl0003o/K[Q0_n`^n400ona^^7oooooo`00
000kooooo`002Oooool01000003ooooooooooooooolJ01TI6@800000FP0c<c<2000002<06ATI4P00
0004ooooo`0300000?oooooooooo06Wooooo0ol00007ooooo`;o[kSO1On_^N001On`^Moo/;WPok2i
h?n`^N3o/;WO00?o/;WP0_n`^^000ona^Moo/;[Pok2jh002ok2jh005ok2jhOna^^3o/K[Pok6jhOl0
00001Ona^^400ooooooo0000ooooo`0iooooo`002Oooool01000003ooooooooooooooolI01TI6@03
0000000c<c<0<c<c05`0<c<c00?o000001TI6@0I6AT08@0I6ATA000000Cooooo00<00000oooooooo
ool0Ioooool2o`0000Sooooo1On_^=l00on_^N3o/;SOok2ig`03ok2ig`05ok2ih?n`^Moo/;WOok2i
gon`^N001Ona^Ml2ok2jh003ok6igona^^3o/K[P00;o/K[P00?o0000ok6jh?na^^000_na^^401?na
^^3oooooooooool0000iooooo`002Oooool01000003ooooooooooooooolG01TI6@0300000?l00000
<c<c05l0<c<c0P00000Q01TI6A4000001?ooool00`00003oooooooooo`1Tooooo`?o00001oooool0
0on_]moo[kSOojnhg`04ojnhg`04ok2ggon`^=oo/;SOok2hg`;o/;WO00Go/;SOok2igon`^Moo/;WO
ok6hgP0:ok6ig`;o/K[P00Go/KWOo`000?na^^3o/K[Pok:jg`03ok6jh003ooooool0003ooooo03So
oooo0009ooooo`0400000?oooooooooooooooaD06ATI0P00001T03<c<`800000800I6AT@000000Co
oooo00<00000ooooooooool0H_ooool2o`0000Sooooo00Co[kONojnggon_]moo[kOO0_n_^=l00on`
]mko/;OOok2gg`02ok2gg`03ok2hgon`]mko/;ON00?o/;SO00Co/;WOok6hg_na^=ko/KSN0_na^Ml0
0ona^=ko/KWOok6ig`07ok6ig`03o`000?na^^3o/[[O00;o/[[O00Go/K[Pok:jgoooooooooooo`00
000hooooo`002Oooool01000003ooooooooooooooolD01TI6@030000000c<c<0<c<c06H0<c<c0P00
000O01TI6@l000001?ooool00`00003oooooooooo`1Oooooo`?o00002Oooool3ojnggP03ojnggon_
]]ko[kKN00?o/;ON0_n`]ml5ok2ggP03ok2hgona]mko/KON00Oo/KSN0_na^Ml00ona^=ko/KWOok6i
g`03ok6ig`05o`000?nb^]oo/[[Ook:jgonb^Ml00onb^]l2ooooo`03o`000?oooooooooo03Gooooo
0009ooooo`0400000?oooooooooooooooa<06ATI00?o000003<c<`0c<c<0J@0c<c<00ol000006ATI
01TI6@0M01TI6@h000001?ooool00`00003oooooooooo`1Mooooo`;o00002_ooool01?n_]]ko[kON
ojngg_n_]mh5ojnfgP03ok2gg_n`]]go/;KM00Go/;ON00?o/KOMok6gg_na]mh00_na]mh00ona^=ko
/KONok6ggP02ok6hgP03ok:hgOna^=ko/KSN00;o/KSN00Oo/KWOok:hg_nb^=ko/[WOo`000?nb^Moo
/[[O00?o/[WO0onb^]l00ooooooo0000ooooo`0fooooo`002Oooool01000003ooooooooooooooolB
01TI6@030000000c<c<0<c<c06/0<c<c0P00000N01TI6@d000001?ooool00`00003oooooooooo`1J
ooooo`?o00002_ooool4ojnfgP03ojngg_n_]]ko[kKN00?o[kKN1On`]]d00on`]mko/;KMok2fg@03
ok6gg@;o/KON00Go/KOMok6gg_na]mko/KONok6hgP03ok:hg@;o/KSN00?o/[SMok:hg_nb^=h00_nb
^=h00ol0003o/[WNok:ig`02ok:ig`03ok>ig_nb^]oo/[[O00;o/[[O00?oooooo`000?ooool0=Ooo
ool000Wooooo00@00000oooooooooooooooo400I6AT200000380<c<c5@00000Y03<c<`8000007@0I
6AT<000000Cooooo00<00000ooooooooool0Eoooool3o`0000[ooooo00?o[[GNojnfg_n_]]h00on_
]]h2ojneg@Co[kKN1On`]]d00on`]Mco/;KMok2fg@02ok2fg@03ok6ggOna]]co/KOM00?o/KOM00?o
/KONok:ggOnb]md01onb^=d2ok:hgP05ok>hgOl0003o/[WNok:ig_nb^Ml00onc^Mh2ok:jg`04ok>i
g_ooooooooooo`0003Gooooo0009ooooo`0400000?ooooooooooooooo`l06ATI00<0000003<c<`0c
<c<0:P0c<c<8000001D0C4a<100000001?l00000000000000000000S03<c<`030000000I6AT06ATI
01/06ATI2`000004ooooo`0300000?oooooooooo05Gooooo0_l0000;ooooo`Co[[GN0_n_]]h5ojne
g@03ojnfg_n`]Mgo/;GM00?o/;KM1?n`]M`2ok2fg@04ok6eg?na]]co/KKLok6fg0;o/KOM00?o/[KL
ok:ggOnb]md00_nb]md00onb^=go/[OLok:gg002ok:hg@06ok>gg?nc^=go/kSMok>hgOl0003o/[WN
0_nc^=d7ok>igP03ooooool0003ooooo03Cooooo0009ooooo`0400000?ooooooooooooooo`l06ATI
00<0000003<c<`0c<c<09`0c<c<200000003o`00001<C4`0C4a<02<0C4a<0`00000Q03<c<`030000
000I6AT06ATI01/06ATI00?o00000000000000001`000004ooooo`0300000?oooooooooo05;ooooo
0ol0000:ooooo`;o[[CM1?n^]Mh2ojndg@Go[kGM00?o[kCLok2egOn`]Md00_n`]Md00on`]]go/;GL
ok2eg003ok2eg0Co/KGL00?o/KKLok6efona]M/00onb]]`2ok:gg@05ok:fg?nb]mco/[OLok:gg?nc
]]/00onc]m`2ok>hg@03o`000?nc^=go/kSM00;o/kSM00?o/kWNok>igOnc^Md00_nc^Mh01?nd^Mgo
ooooooooool0000dooooo`002Oooool01000003oooooooooooooool=01TI6@800000900c<c<60000
02/0C4a<0`00000O03<c<`030000000I6AT06ATI01X06ATI2P000004ooooo`0300000?oooooooooo
053ooooo0_l0000;ooooo`03ojfdgOn^]=go[[CM00;o[[CM00?o[[GNojjdgOn_]=d00on_]=d00on_
]Mgo[kCLojndg003ojndg0;o/;GM00?o/;CLok2eg?n`]M`00on`]M`2ok6df`;o/KGL00?o/KCKok6e
fona]M/00_na]M/00onb]]co/[GKok:fg003ok:fg006ok:gg?nc]]_o/kKKok>ffonc]mco/kOK0_nc
]m`01Ol0003o/kOLok>hgOnc^=go];SL00?o/kWM1?nd^Md00ooooooo0000ooooo`0cooooo`002Ooo
ool01000003oooooooooooooool<01TI6@030000000c<c<0<c<c0280<c<c0P00000d04a<C0@00000
700c<c<2000001/06ATI2@000004ooooo`0300000?oooooooooo04gooooo0ol0000;ooooo`Co[KCM
0_n^]=d01?n^/mco[[CMojjdgOn^]=d2ojndg@03ojncg?n_]=co[kCL00?o[kCL0_n`/m/3ok2dg0;o
/;GL00?o/;CKok6dfona]=/01Ona]=/2ok6ef`04ok:df_nb]M_o/[GKok:ef`;o/[KL1?nc]]/01onc
]][o/kOKok>gfonc]m_o/kOLo`000?nd]m/01?nd^=`00onc^Mgo];SLokBhg002okBig@04okFig?oo
ooooooooo`0003?ooooo0009ooooo`0400000?ooooooooooooooo`/06ATI00<0000003<c<`0c<c<0
8@0c<c<2000003X0C4a<0`00000K03<c<`8000006P0I6AT8000000Cooooo00<00000ooooooooool0
Boooool2o`0000gooooo0_n]/md3ojfdg@Co[[?L00?o[[CMojjcg?n^/m`00on_/m`2ojndg003ojnc
fon`/m_o/;?K00;o/;?K00?o/;CLok2cf_n`]=/00on`]=/00ona]=_o/KCJok6dfP03ok6df`Co/[CJ
00?o/[GKok>df_nc]=X01?nc]]/3ok>ffP04ok>gfond]][o];KJo`0000;o];OK0_nd^=`01Ond^=_o
];SLokBhg?nd^=co]KSK00?o]KWL0_ooool00ol0003oooooooooo`0`ooooo`002Oooool01000003o
ooooooooooooool901TI6@0300000?l00000<c<c01l0<c<c1000000o04a<C0<000006P0c<c<00`00
00006ATI01TI6@0G01TI6@P000001?ooool00`00003oooooooooo`18ooooo`?o00003Oooool5ojfc
g@03ojfdgOn^/mco[[?L00;o[[?L00?o[[;Kojjcg?n^/m`00_n^/m`00on_/mco[k;Kojnbf`03ojnc
f`;o/;?K00Co/;;Jok2cf_n`/m[o/;?J0_n`]=/00ona/m[o/KCJok6dfP02ok6dfP03ok6dfonb/m[o
/[?J00;o/[CJ00?o/[CIok>df_nc]=X00_nc]=X00onc]]_o/kGJok>ffP02ok>ffP07okBefOnd]][o
];KJokBff_l0003o];OKokFgfP04okBhf`06okBhg?ne^=_o]KSKokFhfone^Mco][WL0_ooool00ol0
003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c
01d0<c<c0`00001604a<C0030000000c<c<0<c<c01P0<c<c00<0000001TI6@0I6AT05`0I6AT70000
00Cooooo00<00000ooooooooool0AOooool3o`0000gooooo0_n//md5ojfcg@03ojfbg?n^/mco[[?L
00;o[[?L0on^/]/2ojjcg003ojnaf_n_/]_o[k;K00;o[k;K00?o[k?Kok2bf_n`/]X00on`/]X00on`
/m[o/K;Iok6bf@03ok6cfP;o/KCJ00Co/[?Iok:cf_nb/m[o/[?J1?nb]=T2ok>dfP05ok>dfOnc]M[o
/kGJok>ef_nc]]X00ond]MT2okBffP04o`000?ne]m[o]KOJokFgfP;o];SK00Go]KOJokFhfone^=_o
]KSKokJhf`03okJig0;ooooo00?o0000ooooooooool0;oooool000Wooooo00@00000oooooooooooo
oooo1`0I6AT00`000000<c<c03<c<`0M03<c<`030000001<C4`0C4a<04P0C4a<1000000G03<c<`03
o`00000I6AT06ATI01P06ATI1@000004ooooo`0300000?oooooooooo04?ooooo0_l0000>ooooo`03
ojbbgOn//mgo[;?M00;o[;?M00?o[K?Mojfbg?n]/]`00on]/]`00on^/mco[[;Kojjbf`03ojjbf`04
ojjcg?n_/M[o[k7JojnafP;o[k;K00?o[k7Iok2bf_n`/]X00on`/]X00on`/MWo/K;Iok6bf@02ok6b
f@03ok6cf_na/]Wo/[?I00?o/[?I00?o/[?Jok:cfOnb/mT00onb]=T4ok>df@03ok>ef_nd]=Wo];CI
00?o];GI00Go];KJokFffOl0003o]KKIokFgfP02okJff@?o]KOJ00Ko]KSKokJhfonf^=_o][SKokJi
g?nf^M/3ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?ooooooooooooooo`L06ATI
00?o000003<c<`0c<c<06`0c<c<00`00003o000004a<C01>04a<C08000005P0c<c<00`0000006ATI
01TI6@0G01TI6@D000001?ooool00`00003oooooooooo`10ooooo`?o00003_ooool01?n[/]go[;;M
ojbbgOn//]d2ojbcg@03ojbbg?n]/]co[K;L00?o[K;L00?o[K7Kojjbfon^/]/00on^/]/2ojjafP?o
[k7J00Co[k;KojnafOn_/MWo[k7I0_n`/]X4ok2af@;o/K;I00Co/K7Hok6bfOna/]Wo/K;I0_nb/mT0
0onb/]So/[?Iok:cf@02ok:cf@03ok:dfOnc/mSo/k?H00;o/kCI00?o];?HokBdfOnd]=T00_nd]=T0
1_nd]MWo]KCHokFffOne]]Wo0000okJef0Co][KI00?o]KOJokJgfOnf^=/00_nf^=/01?ng^=[o][WK
okJifonf^M/2ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?ooooooooooooooo`H0
6ATI00<0000003<c<`0c<c<06P0c<c<2000005<0C4a<00<0000003<c<`0c<c<0500c<c<00`000000
6ATI01TI6@0G01TI6@@000001?ooool00`00003oooooooooo`0nooooo`;o00003_ooool5oj^bg@03
ojbbgOn//Mco[;7L00?o[;;L0_n]/]`4ojfaf`;o[[;K00?o[[3Jojjaf_n^/MX00_n^/MX00on_/M[o
[k3Iojnaf@03ojnaf@03ok2bf_n`/=So/;3H00?o/;7I1?na/MP00ona/]Wo/[7Gok:ae`03ok:bf0;o
/[?I00Co/k;Gok>cf?nc/mSo/k?H1?nd/mP2okBdf@06okFceone]=So]KCHokFdf?ne]]Wo00000_nf
]MP2okJff@05okJff?nf]mWo][OIokJgfOnf^=/00ong^=X00onf^M_o]kWJokNifP02ooooo`03o`00
0?oooooooooo02gooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00<0000003<c<`0c<c<0
6P0c<c<00`000000C4a<04a<C01D04a<C003o`00000c<c<0<c<c01@0<c<c00<0000001TI6@0I6AT0
5`0I6AT3000000Cooooo00<00000ooooooooool0>oooool3o`0000kooooo00?oZk;Noj^bgOn[/]d0
0on[/]d00on[/Mco[;7Lojbag002ojbag003ojbbg?n//=_o[;3K00Co[K7K0_n]/=X3ojj`fP;o[[7J
00Co[[3Iojn`fOn_/=Wo[k3I0_n_/MT00on_/=So/;3Hok2`f002ok2`f003ok2afOn`/=So/;3H00;o
/K7H00?o/K3Gok:aeonb/ML00_nb/ML00onb/]So/k7Gok>be`03ok>be`03ok>cf?nd/]Oo];;G00?o
];?H1?ne/mL01?ne]=So][CGokJdeol00002okJef0Co][KH00?o][OIokNgfOng^=X00_ng^=X00onh
^=Wo]kWJokNifP02okNifP;ooooo00?o0000ooooooooool0;?ooool000Wooooo00@00000oooooooo
oooooooo100I6AT00`000000<c<c03<c<`0I03<c<`0300000?l00000C4a<02@0C4a<4P00000Q04a<
C0<00000500c<c<00ol00000000001TI6@0F01TI6@03o`0000000000000000Cooooo00<00000oooo
ooooool0>Oooool2o`0000kooooo0_nZ/]h3oj^bgP;oZk;M1?n[/M`2ojbag0Go[;3K00?o[K7Kojf_
f_n]/=X00on]/=X00on^/=[o[ZoIojj_f@03ojj`f@03ojn`fOn_[mSo[joH00?o[k3H0_n`/=P01On`
[mOo/;3Hok2`f?n`/=So/K7H00?o/K3G0_nb/ML01?nb/=Ko/k7Gok>aeonc/ML2ok>be`03ok>ae_nd
/]Oo];;G00;o];;G00?o];?HokFbe_ne/]H00_ne/mL01_nf/mKo][CGokJdeonf]=Oo0000okJef0;o
]kGG0_nf]]P01Ong]]Oo]kOIokNgfOng]mWo]kSJ00?o^;SI0_ng^MX01?nh^MWoooooooooool0000^
ooooo`002Oooool01000003oooooooooooooool301TI6@03o`00000c<c<0<c<c01P0<c<c0P00000P
04a<C0L000004P1VIVH7000001d0C4a<0P00000D03<c<`030000000I6AT06ATI01@06ATI0`000004
ooooo`0300000?oooooooooo03Kooooo0ol0000>ooooo`03ojVbg_nZ/]koZ[;N00;oZ[;N00?oZk;N
ojZagOnZ/Md01?n[/M`2oj^`f`Go[;3K00Co[:oJojf_f_n][m[o[JoJ0_n]/=X00on][]Wo[ZoIojj_
f@02ojj_f@03ojj`fOn^[]So[joH00?o[joH00?o[k3Hok2^eon`[]L00on`[mL00on`/=So/JoFok6_
eP03ok6`e`Co/[3F00?o/k7Gok>`eOnc/=D00onc/MH2okBbe`04okBae_ne/]Ko]K;FokFbePCo][?F
0_nf]=L01?l0003o]kGGokNeeong]ML4okNfe`03okNgfOnh]mSo^;OH00?o^;SI1?nh^MT2ooooo`03
o`000?oooooooooo02_ooooo0009ooooo`0400000?ooooooooooooooo`806ATI00<0000003<c<`0c
<c<0600c<c<00`000000C4a<04a<C00M04a<C0<00000801VIVH4000001/0C4a<00<0000003<c<`0c
<c<04P0c<c<00`0000006ATI01TI6@0D01TI6@8000001?ooool00`00003oooooooooo`0cooooo`?o
00003oooool01?nY/MkoZK;NojVbg_nY/]h2ojZbgP03ojZ`gOnZ/MgoZ[7M00;oZ[7M00?oZk7Loj^_
fon[/=/00on[/=/00on//=_o[:oJojb_fP03ojb_fP03ojf_f_n][]Wo[JkI00?o[JkI0_n^[mT01?n^
[]Oo[ZkHojj^f?n^[]P2ojn_f003ojn^e_n`[]Oo/:kG00;o/:kG00?o/:oGok2^e_na[mH00ona[mH0
0ona/=Oo/ZoEok:_e@03ok:`ePCo/k3E00?o/k7FokB`e?nd/MH00ond/MH00one/]Ko][;EokJbe@03
okJceP;o]k?F00?o0000okNce_ng]ML00_ng]=H2okNfe`03okRee_nh]mSo^;OH00;o^;OH00?o^;SI
okVhf?ni^=P00_nh^MT01?ni^MWoooooooooool0000]ooooo`002Oooool01P00003ooooooooooooo
ool06ATI000001T0<c<c00?o00000000001<C4`06P1<C4`5000002L0IVIV1000000H04a<C0800000
4`0c<c<00ol000006ATI01TI6@0D01TI6@0300000?oooooooooo00;ooooo00<00000ooooooooool0
<Oooool2o`0000oooooo0_nX/Ml3ojVagP03ojVbg_nY/=goZK3M00?oZ[3M0_nZ/Md01?nZ[mcoZjoK
oj^_fon[[m/2oj^`f`03oj^^f_n/[m[o[:oJ00?o[:oJ00?o[:kIojf^fOn][]T00on][]T2ojf]e`?o
[ZkG00?o[ZkHojj]e_n^[MH00on_[]H2ok2^e`04ok2]eOn`[]Ko/:kFok2^eP;o/JoF00?o/JkDok:_
eOnb[mD00_nb[mD00onb/=Ko/joDok>_e002ok>`e@04okB_e?nd/=Co];3DokB`e0;o];7F00?o]K3D
okJbeOnf/]D00_nf/]D00onf/mKo][;EokJbe@02okNceP05o`000?ng]=Ko]kCFokNde_ng]]L00onh
]MH2okRgf004okVfeoni^=So^KSHokVhf0Co^KWI0_ooool00ol0003oooooooooo`0Zooooo`002Ooo
ool01P00003oooooooooooooool06ATI000001P0<c<c00<0000004a<C01<C4`06@1<C4`200000300
IVIV0`00000G04a<C0030000000c<c<0<c<c0100<c<c00<0000001TI6@0I6AT0500I6AT00`00003o
ooooooooo`02ooooo`0300000?oooooooooo02kooooo0ol0000=ooooo`OoZ;7O00?oZK7NojV`gOnY
/=d00onY/=d00onZ/=goZJoLojV_g003ojZ_g003oj^_fonZ[][oZZkJ00?oZjkJ0_n/[mX01?n[[MWo
[:kIojb^fOn/[]T2ojf^f@03ojb/eon][MOo[JgG00;o[JgG00?o[ZkGojj/e_n^[MH00on^[MH00on_
[]Ko[jcEok2]e@03ok2]e@03ok2^e_na[MCo/JgD00?o/JkD0_nb[mD01Onb[]Co/joDok>_e?nc[mCo
/k3E00?o]:oD0_nd/=@01?ne[m?o]K3DokF`e?ne/=@2okJbe@04okJae?nf/]Go][;EokJbe@;o]k?E
00?o0000okNceOng]=H00_nh]=D3okReePCo^KKG00?o^KSHokZheonj^=L00_ni^MT01Onj^MSooooo
oooooooooooo000002_ooooo0009ooooo`0500000?ooooooooooooooo`000000600c<c<00`000000
C4a<04a<C00F04a<C0@00000=@1VIVH3000001D0C4a<00<0000003<c<`0c<c<0400c<c<00`000000
6ATI01TI6@0D01TI6@0500000?ooooooooooooooo`000000;_ooool2o`0000gooooo0_nW/^07ojRa
g`03ojR`g_nY/=goZK3M00?oZK3M1OnY[m`00onZ[mcoZZkJojZ^fP03ojZ^fP03oj^^f_n[[MWoZjgI
00?oZjgI00?o[:kIojb/eon/[=L00on/[=L2ojf]e`04ojf/e_n^[=Ko[ZcFojj/eP;o[ZgF00Co[Z_D
ojn/eOn_[=Go[jcE0_n`[MD00on`[=?o/JgDok6]e002ok6]e003ok6^e?nb[M?o/ZkD00?o/ZkD00?o
/joDok>^donc[]<00ond[m@01_nd/=Co]JoCokF_done[m?o]K3DokJ`d`Co][7D00Ko][;EokNbe?ng
/]Co]k?Eo`000?ng/mD4okRde@03okRee_ni]MKo^KGF00;o^KKG00Co^[OFokZheonj^=Oo^[SG1?nj
^MP2ooooo`03o`000?oooooooooo02Wooooo0009ooooo`0400000?oooooooooooooooaP0<c<c00<0
000004a<C01<C4`05@1<C4`00ol00000000006IVIP0k06IVIP800000501<C4`00ol00000<c<c03<c
<`0@03<c<`030000000I6AT06ATI01<06ATI1?ooool00`00003oooooooooo`0Yooooo`?o00003Ooo
ool5ojNbh003ojRagonW/=koZ;3N00GoZ;3N0_nY/=d00onX[mcoZJoLojV_g003ojV_g003ojV^fonZ
[][oZZkJ00?oZZkJ00?oZZcIoj^]fOn[[MT00on[[MT00on[[=Oo[:cGojb/e`04ojb/e`Co[JcF0_n^
[=H01?n^[MKo[Z_Dojj[e?n^Zm@2ojn/e@Co/:cC0_na[M@01?naZm;o/ZgCok:]donb[M<2ok:^e003
ok>]d_nc[]?o/jkC00;o/jkC00?o]:oDokB^d_ne[m<00_ne[m<01?nf[m;o][3CokJ`donf/=<2okJa
e003okNadong/]Co]k;D00;o]k;D00?o0000okRce?nh/m@00_nh]=D01?ni]=Co^KGFokVee_ni]MH4
okZgeP03okZheonk^=Oo^kSG00;o^[WH00Go^kWGooooooooooooooooo`00000Zooooo`002Oooool0
1000003ooooooooooooooolF03<c<`0300000?l00000C4a<01D0C4a<0P00001006IVIP03o`000000
0000C4a<0180C4a<00<0000003<c<`0c<c<0400c<c<00`0000006ATI01TI6@0B01TI6@Cooooo00<0
0000ooooooooool09oooool2o`0000kooooo00?oY[;QojNbh?nW/^000onW/^001?nW/=ooYk3NojN`
g_nW/=h4ojR`gP;oZ:oM0onX[m`00onY[mcoZ:kKojR^f`03ojV^f`03ojZ^f_nY[=WoZJcI00?oZZcI
0_n[[MT01?nZZmOoZjcGoj^/eon[[=L4ojb/e`;o[:_F0on][=H00on^[=Ko[Z_Dojj[e003ojj[e003
ojn/eOn_Zm?o[j_C00?o/:cC00Co/JgDok6[d_naZm;o/J_B0_nb[M<4ok>]dP;o/jkC00Go]:gAokB^
d_nd[];o]:kBokF_d`03okJ_dP;o][3C00Co]joAokNadong/M?o]k7C0_ng/]@01?nh/M?o0000okRc
e?nh/m@4okVde003okVee_nj]MCo^[GD00;o^[OF00Go^kOEok^heonk^=Oo^kSGokbheP03ok^ie`?o
oooo00?o0000ooooooooool09oooool000Wooooo00@00000oooooooooooooooo5@0c<c<00`000000
C4a<04a<C00D04a<C0800000A01VIVH200000180C4a<00<0000003<c<`0c<c<0400c<c<00`000000
6ATI01TI6@0A01TI6@Cooooo00<00000ooooooooool09?ooool3o`0000kooooo1?nV/^42ojNbh004
ojJagonW/=ooYk3OojN`g`?oYk3N00?oZ;3NojN_gOnX[md00onX[md00onX[mcoZ:gKojR^f`03ojR^
f`03ojV^fonY[=[oZJcJ00?oZJcI00?oZZcIojV[f?nZZmL00onZZmL2oj^/e`;o[:cG00Co[:[Fojb[
e_n/ZmKo[:_F0_n][=H00on]Z]Co[Z_Dojj[e003ojj[e003ojnZdon_Zm?o[j_C00;o[j_C00?o/:cC
ok2Zd_n`Z]800onaZm800onb[M?o/Z_Aok:[d@03ok>]dPCo]:gA00?o]:kBokF]dOnf[m800onf[m80
1_nf/=?o]joAokN_dOng[m7o]k7CokR`d@?o^;7C00Co0000okRce?ni/m?o^K?C0_ni]=@01Onj]=?o
^[GDokZee?nj]MCo^kGD00?o^kOE00Ko^kSGokbhe_nl^=Ko_;SFok^ieonl^ML3ooooo`03o`000?oo
oooooooo02Oooooo0009ooooo`0400000?oooooooooooooooa@0<c<c00<0000004a<C01<C4`04`1<
C4`2000004P0IVIV0P00000A04a<C08000004@0c<c<00`0000006ATI01TI6@0@01TI6@Cooooo00<0
0000ooooooooool08_ooool2o`0000kooooo0_nU/^44ojJbh@;oY[7P0onV/Ml00onW/=ooYZoNojJ_
gP02ojN_gP?oYjoM0_nX[md01?nW[McoZ:gKojR]fonX[M/2ojR^f`03ojR/f_nY[=[oZJcJ00;oZJcJ
00?oZJcIojV[f?nYZmP00_nYZmP3ojZ[e`03oj^/eon[Z]KoZj[F00?o[:[F00?o[:_FojbYe?n/ZM@0
0on]Z]@2ojj[e004ojjYdon_Z]?o[j[CojnZd`;o[j_C00?o/:WBok2Zd_n`Z]800_n`Z]800onaZm;o
/J[Aok:[d@03ok:[d@03ok>]d_nc[=7o/jcA00;o]:gA00Co]:c@okF]dOne[M7o]JgA0_nf[m801Onf
[]3o]joAokN_dOng[m7o^:o@00?o^;3A0_nh/M<01Ol0003o^K?CokVcdoni/m?o^[?B00?o^[CC00Ko
^[GDok^ee?nk]MCo^kGDok^geOnl]m@3okbheP04okfheOnl^MOo_;WGokbie`?ooooo00?o0000oooo
ooooool09_ooool000Wooooo00@00000oooooooooooooooo4`0c<c<00ol00000C4a<04a<C00B04a<
C08000007@1VIVH500000003o`0000000000000000X000007@1VIVH00`00003o000004a<C00@04a<
C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I6AT03`0I6AT4ooooo`0300000?oooooooooo
01oooooo0ol0000<ooooo`03ojFch_nU/^;oYK;R00;oYK;R0_nU/^400onV/^7oYK7PojFah003ojJa
h003ojJagonV[mooYZoO00?oYZoN0_nW[mh00onW[mgoYjgLojN]g003ojN]g003ojR]fonW[=[oYjcJ
00?oZ:cJ0_nY[=X00onXZ]SoZJ_HojV[f004ojV[f003ojZ[eonZZMKoZj[F00?oZj[F00?o[:[Foj^X
e?n/ZM@00on/ZM@00on]Z]Co[JSBojfXdP03ojjYd`03ojnZdon_Z=7o[jSA00?o/:WB0_n`Z]801?na
ZM3o/J[Aok6ZdOnaZ]42ok:[d@05ok>Zd?nc[=7o/jcAok>/dOnd[M400ond[=02okF]d@05okJ]d?nf
[]3o]Zk@okJ^d?ng[m400onh[m02okR`d@;o^K7A00?o0000okVadOni/m<00onj/m800onj]=?o^kCB
ok^ee002ok^ee005okbfdonl]mCo_;ODokbge?nl^=H00onm^=D00onl^MOo_K[Fooooo`03ooooo`03
o`000?oooooooooo02Gooooo0009ooooo`0400000?oooooooooooooooa80<c<c00<0000004a<C01<
C4`04P1<C4`00`000000IVIV06IVIP0J06IVIP<000004P1oOgl7000001P0IVIV00<0000004a<C01<
C4`03`1<C4`00`000000<c<c03<c<`0>03<c<`030000000I6AT06ATI00l06ATI1?ooool00`00003o
ooooooooo`0Looooo`?o00003Oooool01?nT/n?oYK?RojFch_nU/n82ojFbhP?oYK7Q1?nU/N000onV
/N3oYK3OojJ_g`03ojJ_g`03ojJ_g_nV[]goYZkM00;oYZkM1?nW[M`2ojN/f`?oYjcJ00?oZ:cJojNZ
fOnXZ]P00onXZ]P4ojV[f004ojVYe_nZZMKoZZWFojZYeP;oZj[F1?n[Z=@2ojbYe003ojbWd_n]Z=;o
[JSB00;o[JSB00?o[ZWCojjWdOn_Z=400on_Z=400on`ZM;o/:S@ok6Yd003ok6Yd003ok6ZdOnbZLoo
/ZW?00?o/j[@00?o/jcAokB[condZll00ond[=001_ne[M7o]Zg@okJ]d?nf[M3o]Zk@okN]c`Co^:o@
00Ko^;3AokV`d?ni/=3o^K7Ao`000?nj/M03okZcdP05ok^cdOnk]=;o^kCBok^dd_nk]M@00onl]]<0
0onl]mCo_KODokfhe@02okfhe@04okjieOnm^]Ko_K[FokfjeP?ooooo00?o0000ooooooooool09Ooo
ool000Wooooo00@00000oooooooooooooooo4@0c<c<00`000000C4a<04a<C00A04a<C08000005P1V
IVH7000001`0Ogmo1000000E06IVIP800000401<C4`00`000000<c<c03<c<`0>03<c<`030000000I
6AT06ATI00h06ATI1?ooool00`00003oooooooooo`0Jooooo`;o00003Oooool5ojBch`03ojFch_nT
/^;oY;;R00GoYK7Q0_nU/N001?nU/>3oYK3OojF`gonU/=l2ojJ_g`03ojF^g_nV[]goYZkM00CoYZkM
00?oYjgLojJ/fonW[=/00onW[=/00onW[=[oYj[IojNZf@02ojNZf@?oZ:[H00?oZJ_HojRXe_nXZ=H0
0onYZMH00onZZMKoZZODojZWe004oj^Xe003oj^Wd_n/Ym;o[:OB00;o[:OB0_n]Z=801?n]Y]7o[ZOA
ojjWdOn^Ym42ojnXd@04ojnWd?n`Z=3o/:S@ok2Xd0;o/JW@00?o/JS?ok:YconbZLl00_nbZLl00onc
Z]3o/jW?okB[c`03okB[c`03okB/d?neZloo]Zg@00;o]Zg@00Co]jc>okN]cong[Loo]jg?0_nh[m00
1_ni[/oo^K3@okV`d?ni/=3o^[7@o`0000;o^[7@00Co^[?Bok^cdOnk/m7o^k?A0_nk]=83okbfd`05
okjfd_nm]mCo_KODokfge?nm^=D00onn^MD00onm^]Ko_[_FokjkeP03ooooo`03o`000?oooooooooo
02Cooooo0009ooooo`0400000?oooooooooooooooa40<c<c00<0000004a<C01<C4`0401<C4`00`00
0000IVIV06IVIP0D06IVIP03o`0000000000Ogmo02H0Ogmo0`00000D06IVIP030000001<C4`0C4a<
00h0C4a<00<0000003<c<`0c<c<03@0c<c<00`0000006ATI01TI6@0>01TI6@Cooooo00<00000oooo
ooooool05oooool3o`0000_ooooo0_nS]>@2ojBci0CoY;?S1OnT/^800onU/N7oY;3QojB`h@02ojB`
h0?oYK3P00?oYK3OojF^g_nU[]h00onU[]h00onV[]goYJcLojF/g002ojF/g0?oYZcK0_nW[=/00onV
Z][oYj[IojNZf@04ojNZf@03ojRZf?nXZ=OoZ:SF00?oZ:SF00?oZJWFojVWe?nZYm@00onZYm@00on[
Z=CoZZKBoj^WdP02oj^WdP?o[:OB00Co[JSBojfVdOn]Y]7o[JKA0_n^Ym401?n_Z=7o[jO@ojnWd?n_
Ym02ok2Xd004ok6Yd?naZ<oo/JS?ok6Xc`;o/ZW?00Co/ZS>ok>YconcZLoo/jW?0_ndZll01OndZ/ko
]J_?okF[coneZloo]Zg@00?o]jc>0_ng[Ll4okV^c`04okV`d?nj/<oo0000o`0000;o^[7@1?nk/m40
1?nk]=;o_KCAokfddOnl]]<3okjfdP03okfge?nn^=?o_[WE00;o_[WE00Co_k[Dokjke_nn^mKo_[_F
1?ooool00ol0003oooooooooo`0Sooooo`002Oooool01000003oooooooooooooool@03<c<`030000
001<C4`0C4a<00l0C4a<00<00000o`00001VIVH0501VIVH2000002`0Ogmo00@00000o`0000000000
00004@1VIVH00`00003o000004a<C00>04a<C003o`00000c<c<0<c<c00d0<c<c00<0000001TI6@0I
6AT03@0I6AT4ooooo`0300000?oooooooooo01Kooooo0_l0000;ooooo`GoXkCT0_nT/n@00onT/n?o
Xk;Soj>bh`04ojBbhP03ojBahOnT/>7oY;3Q00;oY;3Q0_nT/>000onU/>3oY:kOojB^g`04ojF^gP03
ojB/gOnU[=coYJcL00CoYJcL00?oYZcKojFZf_nUZ]X00onVZ]X00onWZ]WoYZSHojNXe`02ojNXe`?o
Z:SG0_nXZ=H01?nXYmGoZJODojVWe?nYYm@2ojZWe004ojVVdonZY];oZZKBojZVdP?oZjOB00?o[:OB
ojbVdOn]Y]400on]Y]400on^Ym7o[ZK?ojjVc`03ojnWd003ok2Xd?n`Ylko/:O>00?o/JS?00Co/ZW?
ok:Xc_nbZ<ko/ZS>0_ncZLl4okBZcP03okF[confZlgo]Z_=00?o]jc>00?o]jg?okR]c_nh[Lh00_ni
[/l3o`000003okZ`col0003o^[7@00;o^k7@0_nk/m401?nm/m3o_KCAokfddOnm]=43okjfdP05okng
d_nn^=?o_[SCokjhdonn^MD00ono^]@00onn^mKo`;_Fol2keP03ooooo`03o`000?oooooooooo02?o
oooo0009ooooo`0400000?ooooooooooooooo`l0<c<c00<0000004a<C01<C4`03`1<C4`00`000000
IVIV06IVIP0B06IVIP<00000<P1oOgl200000140IVIV00<0000004a<C01<C4`03@1<C4`00`000000
<c<c03<c<`0=03<c<`030000000I6AT06ATI00`06ATI1?ooool00`00003oooooooooo`0Fooooo`03
o`000?oooooo000000Sooooo00?oXkCUoj>di?nS]>@00onS]>@01?nS/nCoXk?Soj>chonS/n<3oj>b
h`03ojBbh_nS/N;oY;7Q00;oY;7Q0_nT/>400onS[n3oY:oOojB_g`04ojB^g`03ojF^g_nT[MgoY:cM
00;oY:cM1?nU[=`00onUZ]_oYJ[JojFZfP02ojFZfP03ojJZf_nUZ=SoYZSH00;oYZSH0onWZ=L00onX
Z=OoYjKEojNVe@03ojRWe@03ojVWe?nXYM?oZJKC00?oZJKC0_nZY]82oj^WdP04oj^UdOn/Y]7o[:KA
ojbVd@;o[JKA00?o[JG?ojjVcon^Y/l00_n^Y/l00on_Ym3o[jG>ok2WcP03ok2WcP03ok6XconaYlgo
/ZS>00?o/ZS>00?o/jW?okBXcOndZ<d00_ndZ/h00oneZLgo]Z_=okJ[c@02okJ[c@04okN/c_nh[<go
^:g>okR]cP?o00000_nj[/h2okZ`c`04ok^`c_l0003o^k7@ok^ad0Co_K?@00Co_KCAokjedOnn]M7o
_[KB0ono]m800onn^=?o`;WCoknje002oknje004ol6je?o0^mKo`;_Fol2kePCooooo00?o0000oooo
ooooool08_ooool000Wooooo00@00000oooooooooooooooo3@0c<c<200000140C4a<00<0000006IV
IP1VIVH0401VIVH3000003L0Ogmo0P00000@06IVIP030000001<C4`0C4a<00d0C4a<00<0000003<c
<`0c<c<03@0c<c<00ol000006ATI01TI6@0;01TI6@Cooooo00<00000ooooooooool05_ooool01?l0
003oooooooooool00003ooooo`03oj:ei_nS]>GoXkCU00?oXkCU00?oXkCToj>ci?nS/n@00onS/n@0
0onS/n?oXk;Soj>bh`02oj>ah`?oXk7R00?oY;7Qoj>_hOnS[n400onS[n02ojB_g`;oY:kO00GoXjgN
ojB]gOnT[MgoY:gMojB/g@02ojB[g0;oY:[K0onUZ]/2ojFZfP04ojFXfOnUZ=SoYJSHojFXf0?oYZSH
00?oYjSGojJVe_nWY]D00onWY]D00onXYmGoYjGCojRUd`02ojRUd`?oZJKC00?oZZKBojZTdOnZY=40
0on[YM400on/Y]7o[:C?ojfUc`03ojfUc`;o[ZK?00Co[ZC>ojnUc_n_YLko[jG>0_n`Ylh01?n`YLgo
/JO=ok6WcOnaYld2ok:XcP05ok>WcOndZ<go]:S=okBXcOndZ/h00oneZLd2okJ[c@03okNZc?nh[<go
000000;o000000?o^:g>okV]cOnj[/h00_nj[/h4ok^`cP03o`000?nm/Loo_K7?00;o_K?@00Go_[??
okjedOnn]M7o_[GAokned003okngdP?o`;WC00Go_k[Dol6je?o1^]Co`K[Dol2keP02ol6leP?ooooo
00?o0000ooooooooool08_ooool000Wooooo00@00000oooooooooooooooo300c<c<00`000000C4a<
04a<C00?04a<C00300000?l00000IVIV0100IVIV00?o00000000001oOgl0>`1oOgl00`00003o0000
06IVIP0>06IVIP0300000?l00000C4a<00d0C4a<00<0000003<c<`0c<c<03@0c<c<00`0000006ATI
01TI6@0:01TI6@Cooooo00<00000ooooooooool05_ooool01?l0003oooooooooooooool5oj:eiP03
oj>diOnR]>GoX[CU00?oX[CU0onS/n@2oj:bi0?oXk;S0_nS/N<00onS/N;oX[3Roj:`hP03oj>_h@03
oj>_h?nR[]ooXZkO00;oXjgO0onS[Mh00onT[MgoXj_Moj>[g@03ojB[g0;oY:[K00?oYJ[KojBXfOnT
Z=T00onUZ=T2ojFXf0;oYZSH00CoYJKFojJVe_nVY]KoYZKF0_nWY]D01?nVY=CoYjGCojNUdonWYM<3
ojRUd`03ojVVdonYY=7oZZCA00?oZZCA00?oZjGAoj^Scon/Y<l00_n/Y<l3ojfUc`Co[ZC>0_n_YLh4
ok2Uc@;o/JO=1?ncYld00ondZ<go]:O<okBWc003okFYc@04okJ[cOl0003o0000o`0000;o^:c=1?ni
[Ld00onj[/ko^jk=ok^^c@02ok^`cP04okb`cOnm/Loo0000okfac`Co_[??00Go_[GAokned?no]M3o
_kG@okngdP02ol2gd@03ol2idoo1^M;o`KWB00?o`K[D0oo1_=H4ooooo`03o`000?oooooooooo027o
oooo0009ooooo`0400000?ooooooooooooooo``0<c<c00<0000004a<C01<C4`03P1<C4`00`000000
IVIV06IVIP0?06IVIP800000@01oOgl00`000000IVIV06IVIP0>06IVIP030000001<C4`0C4a<00`0
C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0:01TI6@Cooooo00<00000oooooooo
ool05Oooool00ol0003oX[KWoj:fi`03oj:fiP?oX[GV0_nR]>H4oj:di@04oj:ciOnR/nCoX[?Toj:c
i0?oX[;T00?oXk;Soj:ahonR/>801OnR/>800onS[n7oXZkPoj:^g`03oj:^g`;oXjgO00?oXjgNoj:[
gOnSZmd00onSZmd00onTZmcoXjWKoj>XfP02oj>XfP?oY:SI00?oYJSIojBVf?nUY]L00_nUY]L3ojFV
eP03ojJVe_nVY=CoYZCD00?oYZCD0_nWYM<2ojRUd`04ojRSdOnYY=7oZJCAojVTd@;oZZCA00CoZZ??
oj^Scon[XlooZj??0on/Y<l00on]YLoo[J?>ojfScP03ojjTcP03ojnUc_n_Y<go[jC=00?o/:G=00?o
/JO=ok:Vc?nbY/`00oncYld4okBWc0?o00000ongZ/`00onh[<go^J_<okV[c002okV]c@05okZ]c?nk
[/go^jk=ok^^cOnk/<h00onl/<d00ol0003o_[;>okjbcP03okjcc`?o_kG@00Co`KK@ol2gdOo0]m7o
`;OA1?o1^M801?o1^]Co`[_Dol:ke?o1_=H2ol:mePCooooo00?o0000ooooooooool08?ooool000Wo
oooo00@00000oooooooooooooooo2`0c<c<00`000000C4a<04a<C00>04a<C0030000001VIVH0IVIV
00l0IVIV00<0000007moO`1oOgl05P1oOglF000001D0Ogmo0P00000?06IVIP030000001<C4`0C4a<
00`0C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0901TI6@Cooooo00<00000oooo
ooooool05Oooool01Ol0003oX[KWoj:fionR]^OoX[KV00GoX[GV0_nR]>H00onR]>GoX[?Uoj:ci@02
oj:ci@?oX[?T00?oX[;Toj6ahonR/N<00_nR/N<2oj:`hP03oj6_h_nR[n7oXZoQ00?oXZkP0_nR[]l0
0onQ[=ooXZcNoj:/gP03oj:[g@;oXj_M00CoXZWLoj>YfonSZM_oXjWK0onSZ=X00onTZ=WoXjKHojBV
f002ojBVf0?oYJKG00?oYJKFojFTeOnVY=@01OnVY=@00onWYM?oYj?BojNSdP03ojRSd@03ojVTdOnY
X/ooZZ??00?oZZ??0_n[Xll2ojbTc`04ojbSc_n]Xlko[J?>ojfScP;o[ZC>00?o[Z?<ojnTcOn_Y<d0
0_n_Y<d00on`YLgo/JC;ok:Vc003ok:Vc003ok>WcOncY/_o/jK;00?o00000onfZ</2okNZc005okRZ
boniZlco^J_<okV[c?ni[Ld00onj[L`00onk[/go_:k<okb^c003okb`c@05okjbc_l0003o_[;>okjb
c_nn/ll00_no]<l01Ono]M3o`KK@ol6fd?o1]]3o`;OA00;o`[SA0_o1^M801?o3^];o`[_Dol:ke?o2
^m@3ol:mePCooooo00?o0000ooooooooool08?ooool000Wooooo00@00000oooooooooooooooo2P0c
<c<00`000000C4a<04a<C00>04a<C003o`00001VIVH0IVIV00h0IVIV0P00000F07moO`<000005P2I
VIT3000001@0Ogmo0P00000>06IVIP030000001<C4`0C4a<00/0C4a<00<0000003<c<`0c<c<0300c
<c<00`0000006ATI01TI6@0901TI6@Cooooo00<00000ooooooooool05Oooool01?l0003ooooooj:f
ionQ]^L5oj:eiP03oj6di_nQ]>GoXKCU00CoX[?U1OnQ/^@2oj6ah`03oj:ahonQ/>;oXK3R00?oXJoR
0_nR[n400onR[^3oXJgOoj6]g`03oj6/g`;oXZcN00?oXZ_Moj6Yg?nQZM`00onRZM`2oj>Yf`;oXjSJ
00CoXZKIoj>Vf?nSY]SoXjKH0_nTY]P2ojFVe`04ojBTe_nUY=GoYJCEojFTe@CoYZCD00?oYZ;BojNS
d_nWXm800_nWXm800onXXm7oZ:7@ojVRc`02ojVRc`?oZZ??00?oZj??oj^Rc_n[X/h00on/Xlh00on]
Xlko[J;<ojjSc003ojjSc0;o[jC=00Co/:?;ok6TbonaY<_o/JC;0_nbY/`01OnbYL_o0000o`000?l0
003o]:O<00?o]JO;0_nfZ</4okRZb`03okV[c?njZl_o^Z_;00?o^Zg<1?nl[/`01_nl/<go_[3=okj`
cOnn//ko0000oknbc@?o_kC?0oo1]]001?o2]loo`[SAol:hdOo2^=44ol>jdP04ol:ke?o3_MCo`kgD
ol:meP;o`koF1?ooool00ol0003oooooooooo`0Oooooo`002Oooool01000003oooooooooooooool:
03<c<`03o`00001<C4`0C4a<00d0C4a<00<0000006IVIP1VIVH03@1VIVH2000001@0Ogmo1000000L
09VIV@04o`0000000000000000000180Ogmo0P00000=06IVIP03o`00001<C4`0C4a<00/0C4a<00<0
000003<c<`0c<c<0300c<c<00ol000006ATI01TI6@0801TI6@Cooooo00<00000ooooooooool05Ooo
ool00ol0003oooooooooo`02oj6fi`03oj:ei_nQ]NKoXKGV00?oXKCV0_nQ]>D00onR/nGoXK?Uoj6c
i@04oj6bi0;oX;7T0_nQ/><3oj6`hP03oj6_h_nP[^7oXJgP00;oXJgP0onQ[Ml00onQ[=ooX:_Noj6Z
g@02oj6Zg@?oXJWL00?oXZWLoj6WfonRYmX00_nRYmX3oj:Vf@03oj>Vf?nRY=OoXjCF00;oXjCF0onT
Y=H00onUY=GoY:;CojFRd`02ojFRd`?oYZ;B0_nWXm801?nVXM3oZ:7@ojRQd?nXXM03ojVRc`03ojZS
conYXLkoZj;>00?oZj;>00?o[:?>ojbQc?n]X/`00_n]X/`3ojjSc0Co/:?;0_naY</3o`000003ok:U
boncY/_o]:G:00Co]JO;00?o]ZS;okNXb_ngZ<X00onhZ//4okZ[b`03okZ]c?nk[L_o^jg;00;o_:k<
00Co_Jo<okj`cOnn/<go_[3=0_no//d00ol0003o_k;=okndc`02ol6ecP05ol6fd?o2]loo`[O?ol:g
coo2^=400_o3^M42ol>jdP;oa;cB00Co`kgDolBne?o4_]Co`koF0_o5`=H4ooooo`03o`000?oooooo
oooo01kooooo0009ooooo`0400000?ooooooooooooooo`T0<c<c00<0000004a<C01<C4`03@1<C4`0
0`000000IVIV06IVIP0<06IVIP8000004`1oOgl3000002@0VIVI0`00000A07moO`030000001VIVH0
IVIV00/0IVIV00<0000004a<C01<C4`02P1<C4`00`000000<c<c03<c<`0=03<c<`030000000I6AT0
6ATI00L06ATI1?ooool00`00003oooooooooo`0Eooooo`04o`000?ooooooooooooooo`?oXKGW0_nQ
]NH3oj6diPGoXK?U00?oXK;Toj2ai?nP/N@00onP/N@2oj6`h`03oj6`h_nP[^;oX:kQ00;oX:kQ0onQ
[N000onQ[MooX:_Ooj2[gP02oj2[gP?oXJ[M00?oXJWLoj2XfonQYm/00_nQYm/3oj:WfP03oj:VfOnQ
Y=SoXZCG00;oXZCG0onSY=H00onTY=KoXj;DojBRd`02ojBRd`?oYJ;C00?oYZ;BojFPdOnVXM000onV
XM02ojRQd0;oZJ;?00CoZ:3>ojVQc_nYXLkoZJ7>0_n[X/h01?n[X<co[:7<ojbQc?n/XL`3ojfRc003
ojjSc?n_X/_o[j;;00?o/:?;0_l000001?naXl[o/ZG;ok:UbonbYL/3okBUbP?o]JO;1?ngZ<X00onh
Z/_o^JW:okVYbP02okZ[b`05ok^[b_nk[L_o^jg;ok^]bonl[/`00onm[l`01_nn/<go_k7<oknac?no
//go0000ol6cc@?o`KG>0oo2]ll01?o3^<oo`kWAol>idOo3^M43olBldP04olFmd_o4_]Coa;kDolBn
e0?oaL3F00Goa/;Fooooooooooooooooo`00000Pooooo`002Oooool01000003oooooooooooooool8
03<c<`030000001<C4`0C4a<00d0C4a<00?o000006IVIP1VIVH0301VIVH00`000000Ogmo07moO`0@
07moO`<00000:P2IVIT3000000l0Ogmo0P00000<06IVIP030000001<C4`0C4a<00X0C4a<00<00000
03<c<`0c<c<0300c<c<00`0000006ATI01TI6@0701TI6@Cooooo00<00000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`03oj6eionP]>OoX;CV00?oX;CV0_nQ]>H00onQ/nGoX;;Uoj2bi@02
oj2bi@CoX;7T00CoWk3Soin_honO[n?oWjoS0_nP[^800onP[^7oWjcQoin/h@02oin/h0?oX:_O00?o
X:_NoinYgOnOZMd00_nPZ=`3oj2Xf`03oj6WfonPYMWoXJGI00;oXJGI0onQY=P3oj:Te`03oj>Te_nR
X]GoXj;D00;oXj;D0onTX]<00onUX]?oY:3AojFPd@02ojFPd@?oYZ7@00?oZ:7@ojNOc_nWWlh00onX
X<h00onYXLkoZIo<oj^Pc003oj^Pc0;o[:7<0_n]X/`01?n]XL_o[j;;ojnRbon_X//3o`0000Co/J?:
00?o/ZG;ok>TbOncY<T00ondYLX00oneYl_o]ZO9okJWb@02okNXbP05okRXbOniZL[o^JW:okVYb_nj
Zl/00onkZlX00onk[L_o_Jg:okf_c002okf_c009okj_bono/Lco_k7<oknac?no//go`K?=o`000?o1
/lgo`KG>00;o`[K>00Go`[O?ol>hcoo3^<oo`kS?ol>id@02olBkd@05olBld_o5_M;oaKgBolFmd_o4
_]@00_o6_m@01?o5`=Koa/;FolK2e_o6`]H3ooooo`03o`000?oooooooooo01gooooo0009ooooo`04
00000?ooooooooooooooo`L0<c<c00<0000004a<C01<C4`03@1<C4`00`000000IVIV06IVIP0;06IV
IP8000003`1oOgl01000003o000000000000000`09VIV@03o`00001oOgl0Ogmo00h0Ogmo00<00000
06IVIP1VIVH02P1VIVH00ol00000C4a<04a<C00:04a<C0030000000c<c<0<c<c00`0<c<c00<00000
01TI6@0I6AT01P0I6AT4ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool00oooool3
oj2di`;oX;CV00?oWk?Voj2ci_nP/nH01?nP/^D2oinai0;oWk3T0onO/><00onO[n?oWZkRoij^hP02
oin]h@?oWjcQ0_nO[>000onPZmooWjWNoinYgP03oinYg@;oX:SL00?oX:SKoinVf_nOY]X00_nPYMT3
oj6Uf@03oj6Tf?nPX]KoXJ;F00;oXJ;F0onRX]D2oj>Re0;oY:;C00CoXj3BojBPdOnTX=7oY:3A0onU
X=400onVXM3oYYo?ojNOcP03ojNOcP03ojRPc_nXW/coZIo<00;oZIo<0on[X<`00on/XLco[9o;ojbO
b`02ojfQb`?o00001?n`X/X2ok6SbP04ok:SbOncY<Wo/jC9ok>Tb@;o]:G:00Go]JG9okJWbOnfYlWo
]ZO9okNXbP03okRXb@03okVYb_njZ/Wo^j_:00;o^j_:00Go_:c9okf]b_nm[L[o_Jg:okf_c003okj_
b`03oknac?o0//co`;;<00;o`K?=00Go0000ol:fc_o2]/ko`[K>olBgcP03ol>hc`?oa;_A0oo5_M80
1?o7_];oa[oDolJoe?o6_m@3olK2eP03olO3e_oooooooooo00;ooooo00?o0000ooooooooool07?oo
ool000Wooooo00@00000oooooooooooooooo1`0c<c<00ol00000C4a<04a<C00<04a<C0030000001V
IVH0IVIV00/0IVIV00<0000007moO`1oOgl03P1oOgl00`000000VIVI09VIV@0c09VIV@<000003P1o
Ogl00`000000IVIV06IVIP0:06IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<0300c
<c<00`0000006ATI01TI6@0601TI6@Cooooo00<00000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`03oj2dionO]>OoWkCW00?oWk?V0_nP/nH00onP/^GoWk;Uoinbi@03oinai0;oWk3T00?o
Wk3Soij^honN[^<00onN[^82oin]h@03oin/hOnNZn3oWZ[O00;oWZ[O0onOZMh01?nOZMgoWZOLoijV
fonNY]/4oinVfP;oX:GI00?oXJGIoinSeonPX]H00_nPX]H3oj6ReP03oj:ReOnQX=?oXZ3B00;oXZ3B
0onSX=800onTX=7oY9k@ojFNc`02ojFNc`?oYYo?0_nWWlh01?nWW/goZ9k<ojRNc?nXW/`3ojVOc004
oj^Pc?n[W/_o[9o;ojbOb`?o000000Co[Yo9ojnQbOn_XLWo[j790on`X/X4ok:Sb@;o/jC91?neYLT0
0onfYlWo]jK8okRXb@02okRXb@05okVXb?njZ/Wo^Z[9okZZbOnkZlX00onl[<T2okf]bP04okj^b_nn
[l_o_Zo;okj_b`Co`;;<00Co`K?=ol:dcOl0003o`[K>0oo4]lh01?o3^<ooaKW?olFicoo4^m42olJl
d@05olFmd_o7_];oakkBolNnd_o6_m@00_o7`M@01?o6`]Koal?FolO3e_o7`mH3ooooo`03o`000?oo
oooooooo01cooooo0009ooooo`0400000?ooooooooooooooo`L0<c<c00<0000004a<C01<C4`02`1<
C4`00`000000IVIV06IVIP0;06IVIP030000001oOgl0Ogmo00d0Ogmo0P00000i09VIV@8000003@1o
Ogl00`000000IVIV06IVIP0:06IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<0300c
<c<00`0000006ATI01TI6@0501TI6@Cooooo00<00000ooooooooool05?ooool00ol0003ooooooooo
o`06ooooo`;oWkCW0onO/nH3oinbiP;oWk;U00?oWk7Toij`i?nN[n@00_nN[n@3oij^h`04oij^h_nM
[>;oWJcQoif/h@?oWZ_P0onNZ]l00onOZMkoWJOMoijWg002oijWg0;oWZKK0_nOY]X00onNXmWoWZ?H
oijSf003oinSe`?oX:;F00?oXJ;Foj2Pe?nQX=<00_nQX=<3oj:PdP03oj>Pd_nRW]3oY9k@00;oY9k@
0onUW/l00onVWlooYIg=ojNNc@03ojNNc@;oZ9k<0_nYWl`00onYW/_oZik;o`000002o`000003ojbO
bon/W/Wo[Yo900;o[Yo90on_XLT00on`X/[o/:78ok2Qb003ok:Sb@03ok>TbOndY<So]:C800;o]JG9
00Go]ZG8okNVb?ngY/So]jK8okRXb@03okVXb0;o^Z[91?nl[<T01Onm[L[o_Zk:okj^b_nn[/[o_Zo;
00;o`;3:0_o0//`01?o2/l_o`[C=ol:dcOl00003olBgcP04olFhc_o5^LooaKW?olFic`?oa[cA0oo7
_]801?o8`=?oal7DolO1e?o7`M@3olO3eP03olS5eooooooooooo00;ooooo00?o0000ooooooooool0
6oooool000Wooooo00@00000oooooooooooooooo1P0c<c<00`000000C4a<04a<C00;04a<C003o`00
001VIVH0IVIV00/0IVIV00?o000007moO`1oOgl03@1oOgl00`000000VIVI09VIV@0F09VIV@h00000
5`2IVIT00`000000Ogmo07moO`0;07moO`030000001VIVH0IVIV00X0IVIV00<0000004a<C01<C4`0
2@1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI00D06ATI1?ooool00`00003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Oooooo0onO/nL2oinciP03oinbi_nN/NKoW[7U00;oW[7U
0_nN/>@00onN[nCoWJkSoif^h`02oif]hP?oWJcR0_nM[>400onNZn3oW:WOoibYg`02oifXgP?oWJOM
00?oWZOLoibUfonMY=X00_nMY=X3oijSf@;oWZ?H00?oWj?GoijPe_nOX=D00_nOX=D3oj2Pe0?oXJ3C
00?oXZ3Boj6NdOnRW]000_nRW]03ojBNd003ojFNconTW<koYIg=00;oYIg=0onWW/d00onXW/coZ9g;
ojVNb`03o`0000;oZik;00Co[9o;ojbNbOn/W/Wo[9k90_n^WlT2ojnQb@04ojnPb?n`XLSo/:78ok2Q
b0;o/Z?900Go/Z;7okBTb?ndY<So]:C8okFUb@03okJUb0;o]jK81?niZ<P00onjZ/Wo^j[8ok^Zb003
okb/b@?o_Zk:00Go_jo9ol2`b_o0/<[o`;3:ol2bc003ol:cb`04ol:dcOo4]/co0000olBgcP?oaKS>
00CoaKW?olJkcoo6^looa[cA0_o7_]401Oo7_];ob<3ColS0doo8`=?oal7D00;ob<?E00?oal?FolS5
eoo8aML01Oooool00ol0003oooooooooo`0Jooooo`002Oooool01000003oooooooooooooool503<c
<`030000001<C4`0C4a<00`0C4a<00<0000006IVIP1VIVH02P1VIVH2000000`0Ogmo00<00000o`00
000000004P2IVIT500000003o`0000000000/k>c00d0/k>c00?o00000000000000001000000A09VI
V@03o`00001oOgl0Ogmo00/0Ogmo00<0000006IVIP1VIVH02@1VIVH00ol00000C4a<04a<C00:04a<
C003o`00000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT0100I6AT4ooooo`0300000?oooooooooo
01Cooooo00?o0000ooooooooool02?ooool01?nO/nOoW[?Woijbi_nN/^H3oijaiP03oijaiOnM/>Go
WK3U00;oWJoT0onM[^<2oif]hP03oif/h_nLZn7oW:_Q00;oW:[P0onLZMl2oifXgP03oifWgOnLYMco
W:GK00;oW:GK0onMY=X2oijSf@03oijSf?nMXMOoWJ7G00;oWZ3F0onOX=D00onPX=CoWikCoj2MdP02
oj2MdP?oXIkA0_nRW]02ojBNd004oj>Lc_nTW<koY9c>ojBLcP?oYIg=00?oYik=ojJLbol000000_l0
0003ojVNb`03oj^Nbon[WLWoZig900?o[9k900?o[Yo9ojjOb?n_X<P00on_X<P00on`XLSo/J77ok:R
a`03ok:Ra`03okBTb?ndXlOo]:?700?o]ZG800?o]jK8okRVaonhY/L00oniZ<P4ok^Zb004okb/bOnm
[<So_Jc8okj^bP?o_jo90_o0/<X3ol:cb`05ol>dboo4]/coa;K<olBfc?l000000_o5^<h01?o7^/ko
a[_?olJkcoo6^ll3olNnd@06olVodOo8`=?ob<3ColS0doo9`]?ob<?E0_o9aMD00oo8aMOobLOGolW7
e`04ooooo`03o`000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooo`@0<c<c00<0
000004a<C01<C4`0301<C4`00`000000IVIV06IVIP0:06IVIP030000001oOgl0Ogmo00/0Ogmo00<0
000009VIV@2IVIT0402IVIT3000001`0/k>c0`00000?09VIV@800000301oOgl00ol00000IVIV06IV
IP0906IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI
6@0401TI6@Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`?oW[?W0_nN
/^H00onN/NKoWK3Uoif`i@03oif`i@;oWJoT00CoWJkSoib]honL[>;oW:cR1?nLZn42oibZh004oibY
gonKYmkoVjKMoi^Vg@?oW:GL0onLYM/01?nMY=[oW:;IoibQf?nLXMP4oifQe`;oWZ3F00?oWj3EoijN
e?nOW]<00_nOW]<3oj2MdP;oXIkA00?oXYk@oj:LconRW<l00onSW<h2ojBLcP;oYIg=0ol000001_nV
W<_oZ9g;ojRMbonXWL_oZIk;ojVLb@CoZig900?o[9k9ojbMb?n^WlP00_n^WlP3ojnPb0?o/J770onb
X/L4okBSa`03okJUb?ngYLOo^:K700?o^:K700?o^JS8okZXaonjZ<L00_nkZ/P01?nlZlSo_Jc8okf/
b?nm[<P4okn_b@04ol2`b_o2/L[o`[7:ol:cb`?o`kC;00Coa;K<olFgc?l0003oaKS>0oo7^/h01?o6
^loob;g?olRmcoo7_]43olVod@03olS0doo9`]?obL;C00?obLGE0oo9amL00oo:b=Soooooooooo`02
ooooo`03o`000?oooooooooo01Wooooo0009ooooo`0400000?ooooooooooooooo`<0<c<c00<00000
04a<C01<C4`0301<C4`00`000000IVIV06IVIP0:06IVIP03o`00001oOgl0Ogmo00/0Ogmo00<00000
09VIV@2IVIT03`2IVIT200000280/k>c00<0000009VIV@2IVIT03P2IVIT2000000/0Ogmo00<00000
06IVIP1VIVH02@1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00/0<c<c00<00000
01TI6@0I6AT00`0I6AT4ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool0
0onN/nOoWK;Woifbi`03oifaiP?oWK3U0onK[^@3oib]h`;oW:cR0_nLZn400onJZN7oVjSOoi^Xg`03
oi^WgP;oVjKM00?oW:GLoiZSfonJXm/00_nKXmX3oibRf@;oW:7H0_nMXML00onLW]KoWIkEoifNe@03
oijNe0?oWikC00CoX9gBoinKd?nPVm3oX9_@1?nRW<l2oj>LcP04ojBLc_l0003o0000o`0000;oYI_<
0_nVW</2ojRMb`04ojRKbOnYW<WoZIc9ojVLb@;oZig900CoZic8ojbMb?n/WLSo[9g80on^WlP00on_
X<So/9o7ok2Oa`03ok6Qa`03ok:RaoncX/Ko/j;600;o]:?700Co]Z?6okNUaongYLOo]jG70_nhY/L0
1?niYlOo^ZS7okZXaonjZ<L4okb[b003okf/b?no[LSo_jg800;o_jo900Co`K39ol:ab_o2/L[o`[7:
0oo3]</01Oo5]/_oaKO<olFgc?o5]lco000000;oak[>00Cob;c>olRmcoo8_Loob;g?0oo9_m42ol_2
dP04olW2doo;a=CoblCDolW5e@;oblKF00?obLOGol[8f?o:b=P01?ooool00ol0003oooooooooo`0I
ooooo`002Oooool01000003oooooooooooooool303<c<`03o`00001<C4`0C4a<00/0C4a<00<00000
06IVIP1VIVH02P1VIVH00`000000Ogmo07moO`0:07moO`0300000?l00000VIVI00h0VIVI00<00000
o`00000000009@2c/k<4000000h0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP09
06IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@02
01TI6@Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`;oWK;W00?oWK7V
oib`i_nK[nD00_nK[nD4oi^^i003oib]honJZn?oVZ_S00?oVZ[R0_nJZN42oi^Xg`03oi^Wg_nIYMko
VJGN00;oVZCL0onJXm/2oi^SfP03oibRfOnJWmSoVioG00;oVioG0onLW]H2oifNe@;oWYkD0_nOW]<0
1?nNVm7oWi_@oinKd?nOVm02oj2Kd0;oXYc?00CoXI[=oj:JcOl0003o00000_nTVl`3ojFKc003ojJL
bonVV/[oZ9_900?oZ9_90_nYW<T01?n[WLWoZic8oj^Lb?n[W<P2ojbMb0;o[Yo800Co[Yk7ok2Oaon`
WlOo/9o70_naXLL01OnbX<Ko/j;6ok>Ra_ncX/Ko]:?700?o]Z?60_ngYLL4okVWa`03okZXaonkZLOo
^jW700;o_:_800Go_Z_7okn]b?no[LSo_jg8okn_b@03ol6`b@04ol:ab_o3//[o`k;:ol>db`?oaKK;
00CoaKO<olNic?o7^Lco00000oo8_<h01?o8_LoobKk@olVnd?o9_m42ol_2dP04olc4d_o;a=CoblCD
ol_4e0?oblKF00Coc<WGol[8f?o;bmWobl_I1?ooool00ol0003oooooooooo`0Hooooo`002Oooool0
1000003oooooooooooooool303<c<`030000001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH02@1V
IVH00`000000Ogmo07moO`0:07moO`030000002IVIT0VIVI00d0VIVI0P00000/0;>c/`8000003@2I
VIT00`000000Ogmo07moO`0907moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`02@1<
C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI00806ATI1?ooool00`00003ooooooooo
o`0Cooooo`03o`000?oooooooooo00cooooo0onL/NL2oib`iP03oi^_iOnJ[^GoVZkU00;oVZgT0onJ
[><2oiZ[h`04oiZZh_nIZ>7oVJOPoiVWh0;oVJKO1?nIYMh2oiZTg004oiZSfonIXM[oVJ3IoiVPf@?o
VYoH0onKWmL2oibNeP03oifNeOnKW=?oW9cB00;oW9cB0onNVm42oinKd003oj2Kd?nOV/koXI[=00?o
00000_nRV/d3ojBKc003ojFKc?nUV/[oYY[:00;oYY[:0onXVlT00onYW<WoZI_8ojVKb003oj^Lb003
ojbMb?n]W<Oo[Yk700?o[Yk70_n`WlL4ok:PaP03ok>Ra_ndX/Ko]Z?600?o]Z?600?o]jG7okRUa_nh
YLH00oniYlL3ok^Ya`05okb[b?nnZlOo_Z_7okj[aono[LP00_o0[/P3ol6`b@?o`k;:00CoaKC:olFf
boo5]/_oaKK;0oo7^L`01?o8_<ko0000olRlc_o:_/h3olVnd003ol_1d?o;`];oc<CB00;oc<CB00Co
blCDolc6e?o<a]CoblKF0_o<bML3ol_;f@03olc=f_oooooooooo00;ooooo00?o0000ooooooooool0
5oooool000Wooooo00@00000oooooooooooooooo0P0c<c<00`000000C4a<04a<C00;04a<C0030000
001VIVH0IVIV00T0IVIV00<0000007moO`1oOgl02P1oOgl00`000000VIVI09VIV@0<09VIV@800000
<02c/k<00`000000VIVI09VIV@0;09VIV@030000001oOgl0Ogmo00T0Ogmo00<0000006IVIP1VIVH0
201VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0
0P0I6AT4ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00onL/NOoV[3W
oiZ`i`02oiZ_iP?oVZkU0_nJ[N@01?nJ[>?oV:_SoiVYh_nIZN83oiVXh@;oVJOP0_nIY]l2oiVUgP03
oiRSgOnHX]coV:;L00?oVJ7J0_nIX=T3oiZOf004oi^OeonIWMKoVYcDoiZLe0?oVicC0onLW=801?nN
Vm7oW9W@oijIconNVLl3o`0000?oXI[=00?oXY[=oj6HbonSVL/00_nSVL/3ojFJbP?oYY[:00?oZ9_9
ojNJb?nYVlP00onYVlP00on[W<SoZi_7ojfLa`02ojfLa`?o[Yk700?o/9o7ok2Oa_n`WlH00onbX<H3
okBRaP?o]Z?61?nhYLH00oniYlOo^ZO6okZWaP02ok^Ya`04okfYa_nnZlOo_Z_7okj[a`Co`:k800Co
`K39ol>abOo3/LWo`k;:0oo5]<X01?o5]/_oakO;olNgboo7^L`2olRjc@05o`000?o:_/kob[k>olZn
c_o9_]000_o;`M03olc4dP06olg6doo<a]Coc<KDolc6e?o=b=Goc<WG0_o=bmP01?o;bmWoc<gJolc=
f_o=cm/3ooooo`03o`000?oooooooooo01Oooooo0009ooooo`0400000?ooooooooooooooo`80<c<c
00<0000004a<C01<C4`02P1<C4`00`000000IVIV06IVIP0906IVIP03o`00001oOgl0Ogmo00X0Ogmo
00<0000009VIV@2IVIT0302IVIT00`000000/k>c0;>c/`0a0;>c/`03o`00002IVIT0VIVI00/0VIVI
00?o000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00T0C4a<
00<0000003<c<`0c<c<02`0c<c<0100000006ATI01TI6@0I6AT4ooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool03_ooool3oiZ`i`;oVZoV00CoVZkUoiV]iOnI[>CoVJcT0onHZn<2oiVY
hP03oiVXhOnGY^7oUjKQ00;oUjGO0_nGY=h3oiRSg@;oV:;L00?oVJ7JoiNOf_nHW]P00_nHW]P2oiRM
e`?oVIgF0_nJW=@3oi^Ld`03oibLd_nKVM7oW9W@00?o000000KoWYW?oinJc_nOV/koWi[>oj6JcOnP
V<`3oj6Hb`?oXiW;0_nUV/X2ojJJbP04ojJIb?nWV/SoYi[8ojNJb0;oZI_800CoZI[7oj^Kaon[VlOo
Zi_70on]W<L00on^W/Oo[ig6ok2OaP03ok2OaP03ok:Pa_nbX<Go/Z3500?o]:;600?o]Z?6okJSaOnf
XlD00_nhYLH01OniYLGo^ZO6okZWa_njYlKo^jW700?o_JW600?o_Z_7okn/aono[<L00_o0[/P01?o2
[lSo`k79ol>abOo3/LT3olFdbP04olJfb_o7]l_oakO;olNgb`?ob;[=00Kob[g=o`000?o:_/kob[k>
olc0coo;`M02olg3d@05olc4d_o=a]?ocLKColg6doo<a]@00_o=b=D01Oo?bmKocL_Holk=fOo>cMWo
c<gJ00;ocLoK1?ooool00ol0003oooooooooo`0Fooooo`002Oooool01P00003oooooooooooooool0
<c<c000000`0C4a<00?o000006IVIP1VIVH02P1VIVH00`000000Ogmo07moO`0907moO`030000002I
VIT0VIVI00/0VIVI00<00000o`00002c/k<05P2c/k<8000001H0/k>c0`00000;09VIV@030000001o
Ogl0Ogmo00P0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00904a<C0030000000c
<c<0<c<c00X0<c<c00Co000001TI6@0I6AT06ATI1?ooool00`00003oooooooooo`0Cooooo`03o`00
0?oooooooooo00oooooo0_nI[nH3oiV^iP;oVJgU0_nI[>@00onHZn?oUjWSoiNYh`02oiNXhP?oUjKQ
0_nGYMl2oiNTgP04oiRSgOnFXMcoUZ3KoiJPf`?oUioJ0onHW]P2oiRMe`;oVIgF00?oVYcDoiVJdonJ
V]800_nJV]83o`0000;oW9W@0onNVLl00onOV/koWYS=oj2Hc002oj2Hc0?oXIS;00?oXiW;oj>HbOnT
V<T00_nTV<T3ojJIb003ojNJb?nWVLOoZI[700?oZI[70_n[VlL2ojfLa`04ojfLa_n_WLKo[ig6ojnM
aP;o/9o600Co/Ik5ok:PaOnbX<Go/Z350_ndX/H01OneX/Go]Z?5okJSaOnfXlGo^:G600?o^JG50_nj
YlH3okfYaP05okj[a_no[<Oo_jc7okn/aoo0[/P00oo2[lP01?o3/LWoa;;9olBbbOo5]<X3olJfbP04
olNgboo8^Lcob;W<olRjc@?ob[g=00?o0000olc0coo<`<l00oo=`m43olg6d`;oclSD00?ocLSEolo;
e_o?bmH00oo>cMT01?o?cm[ocLoKolgAg?o=dM`4ooooo`03o`000?oooooooooo01Gooooo0009oooo
o`0600000?ooooooooooooooo`0c<c<00000301<C4`00`000000IVIV06IVIP0906IVIP030000001o
Ogl0Ogmo00T0Ogmo00?o000009VIV@2IVIT02P2IVIT200000180/k>c1`0000080<c<c0L000004P2c
/k<00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH0201V
IVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT01?oo
ool00`00003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_nI[nH01?nI[^KoUjgVoiN/
iOnG[>D3oiNZi0?oUjWS0_nGZ>801?nGY^7oUJGPoiFSgonEXml2oiFRg@?oUZ7L0_nFX=/3oiNOfP04
oiRNf?nFW=OoUi_FoiNKeP;oV9[D0_nIV]<3o`000005oiZJd_nKVM7oViWAoibId?nKUll00onMUlh3
oijHc@;oX9S<0_nQV</01?nQUl[oXiS9oj>HbOnSV<T3ojBHb@03ojJIb?nVV<OoYiW700;oYiW70onY
V/L00on[VlOoZi_6ojfLaP03ojfLaP;o[ig61?naW/D2ok:Pa@Co]J;500?o]Z?5okRTaOniYLD00oni
YLD01?njYlKo_:S6okbXa_nmZLH3okj[aP;o_jc70oo2[lP01?o4/LSoa;;9olBbbOo4//T3olJfbP04
olRhb_o8^Lcob;W<olRic0?ob[g=00Koc;o>olc0col0003oc<3?olg2d?o=`m42olk6dP03olg6doo?
b=CoclSD00;od<_E00Cocl_Fom3=eoo@cMOoc/gI0_o?cmX01?o?dM_ocM7LolgBgOo=d]d3ooooo`03
o`000?oooooooooo01Gooooo0009ooooo`0500000?ooooooooooooooo`000000301<C4`00`000000
IVIV06IVIP0906IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT02@2IVIT200000140
/k>c0`00000F0<c<c0<00000402c/k<00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00P0
Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00X0
<c<c00<0000001TI6@0I6AT01?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo017o
oooo0onH[^H2oiN]iP;oUjcU00?oUj[ToiFXi?nEZ>@00_nEYn82oiFVh@?oUJGP0_nEXml2oiFRg@03
oiJQg?nDWm_oU9kJ00;oU9kJ0_nEWMT3oiJLe`;oUi_F0ol00002oiVJd`04oiZJd_nIUm7oVYO@oiZG
d0?oViO?0onMUlh2oijHc@03oj2Hc?nOU/_oXIO:00?oXIO:0_nSV<T2ojBHb@04ojBGb?nVV<OoYYS7
ojJHa`?oYiW700?oZI[7ojVIa_n[VlH00_n[VlH3ojfLaP03ojnMa_n_WLGo[ig500?o/Ik500?o/Z35
ok>PaOncX<D00_neX/D01?nfX/Co^:C5okRTaOnhY<D2okVUa@04okZVaOnlZ<Ko_:S6okbXaPCo_Z_6
00Co_jc7ol6^aoo1[/Oo`Zo80oo4/LP01?o4//Woa[C9olJdbOo6]/X3olRhbP04olRic?o:^lcob[_<
olZmc@?oc;o>00?o0000olg2d?o=`]000oo>a]801Oo@b=?oclSDom3;eOo@bmGodLkF00?od<gG00Co
d=3Iolo?f_o?dM_ocm7K0oo=d]d01Oo>e=oooooooooooooooooo000001Kooooo0009ooooo`040000
0?ooooooooooooooo``0C4a<00<0000006IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0907moO`03
0000002IVIT0VIVI00T0VIVI00<000000;>c/`2c/k<03@2c/k<4000001`0c<c<0`00000>0;>c/`03
o`00002IVIT0VIVI00T0VIVI00<0000007moO`1oOgl0201oOgl00ol00000IVIV06IVIP0706IVIP03
o`00001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@04ooooo`03
00000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00onH[^KoUZgVoiJ]iP02oiF[i@?o
UJ[U0_nEZ>@2oiFWhP;oUJKQ00?oUJGPoi>SgonCXMh00_nCXMh2oi>Pg@;oU9oK0onDW]X2oiFMf@04
oiJLeol0003o0000o`0000?oUYSC0_nGV=83oiVGd@;oVYO@0onKUll01?nMUlkoW9K=oifFc?nMU/`3
oinFb`?oXIO:00?oXiS9oj:Fb?nTUlP00onTUlP2ojJHa`;oYiW700CoYiS6ojVIa_nYVLKoZIW60_n[
VlH2ojfLaP04ojfLaOn_WLGo[ig5ojnMa@;o/Ik500Go/Yk4ok>PaOncX<Go/j35okFRa@03okJRa0;o
^:C51?njY/D00onlZ<Ko_JW5okfYa@03okj[aP?o`Jk700Co`jo7olBab?o4/LSoa;780oo6]<T01?o8
]lWob;S:olRhb_o8^<X3olZkc0?oc;o>0_o>`/h01?l0003oclG@olo5d?o>a]82om38d`03om7;e?o@
bmGodLkF00;odLkF00God<gGom3@fOoAd][odM;JoloAf`02om3Dg004olgBgOo>e=ooc]COolgFh0?o
oooo00?o0000ooooooooool04oooool000Wooooo00@00000oooooooooooooooo301<C4`00`000000
IVIV06IVIP0906IVIP030000001oOgl0Ogmo00P0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000
/k>c0;>c/`0;0;>c/`<000008`3<c<`00`000000/k>c0;>c/`0<0;>c/`8000002P2IVIT00`000000
Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`0201<C4`00`000000
<c<c03<c<`0:03<c<`030000000I6AT06ATI00Cooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`;oUZgV0_nEZnD01?nEZ^GoTjSToi>WhonCYn<2oi>UhP;oTjCQ0onCXml3oi>Q
gP;oTj3M0_nDWm/00onDW][oTY_Ioi>Jf002o`000004oiBIe_nEVMGoUIWEoiFIe@?oUYSC0_nGV=82
oiVGd@03oiZGd?nIULooVYG>00;oVYG>0onLU/d2oifFc0?oWiK;00?oXIO:oj2FbOnRU/P00_nRU/P3
ojBGb003ojJHaonVUlKoYiS600?oYiS60_nYVLH00on[VlKo[9[5ojfLa@03ojfLa@;o[ig51?nbW/@2
ok>Pa@Co]Z;400?o^:C5okVUaOniYLD00onjY/D4okfYa@04okj[a_o0[<Ko`:c6ol6^a`?o`jo700?o
a;78olFcb?o5/lP00_o6]<T2olRgb@04olRhb_o:^/_ob[[;olZkc0;oc;k=00Woc;o>olk2c_o>`/ko
d<C?olo5d?l0003oclG@om78dOo@b=<00_oAbm@3om7>eP04om;@eoo@d=WodM;Jom7BfP;od]GK00Co
d=CLom3Fg_o@e]koc]CO0_o=e^001?o=f>7oooooooooool0000Eooooo`002Oooool01000003ooooo
ooooooooool;04a<C0030000001VIVH0IVIV00T0IVIV00<0000007moO`1oOgl0201oOgl00`000000
VIVI09VIV@0909VIV@030000002c/k<0/k>c00/0/k>c00<000000<c<c03<c<`09@3<c<`3000000d0
/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0
IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AWooooo00?o
oooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`;oU:_V0_nCZ^D3oi>Xi0;o
TjOS0_nCYN82oi>Th@03oi>Sgon@XMooT:7O00;oTIoN0_nAW]`2oi6Lf`?o00000_nCV]P2oiBIeP?o
UIWE00CoUYSCoiBFd_nFU]7oUYKA0_nGUM03oiVEc`?oVYG>0_nLU/d00onMU/coW9C;oijEbP02oijE
bP?oX9K90onRU/P00onTUlSoY9K7ojJGaP02ojJGaP?oYiS600?oZIW6ojVIaOn/V/D00_n/V/D3ojfL
a@03ojnMaOn`WLCo/9g400?o/Yk400?o/j35okBQa?ndXL@00onfX/@4okVUa@03okZVaOnlYlGo_:O5
00;o_JW500Co_j_5ol2/a_o0[<Ko`:c61?o3[lL3olFcb004olJdbOo8]lWob;O9olRgb@?ob[[;0oo<
_/d00oo>`Lgoc/;>om34c`02om34c`03olo5d?l0003odLSA00?odL_D00Kod/kEom7>e_oBd=Ood]3G
om?CfOoAd]X2om;Ef`03om;GgOo@e]kod=KN00;od=SO00CocMKPolgHhOo=fN?ocMWS0_ooool00ol0
003oooooooooo`0Booooo`002Oooool01000003oooooooooooooool:04a<C003o`00001VIVH0IVIV
00T0IVIV00<0000007moO`1oOgl0201oOgl00ol00000VIVI09VIV@0809VIV@03o`0000000000/k>c
00X0/k>c00<00000o`0000000000:`3<c<`00`00003o00000;>c/`0;0;>c/`03o`00002IVIT0VIVI
00P0VIVI00?o000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<
00P0C4a<00<0000003<c<`0c<c<02P0c<c<00`00003oooooooooo`02ooooo`0300000?oooooooooo
01;ooooo00?o0000ooooooooool05Oooool2oiB[iP;oTj[U00?oTjSToi6Wi?nAYn@00_n@YN<2oi2S
hP;oT:;Q0on@XMl2oi6OgP?o000000GoTIcKoi:KfOnBVmWoTi[Hoi6He`03oi:GeP;oTiOD0onDU]82
oiJFd@;oUiG@0onIULl01?nJULkoVI?=oi^Dc?nKU<`3oibDb`?oWYG:0_nPU/T2oj:Fb004oj:EaonT
U/OoY9K7ojBFa`;oYYO60_nWV<H01?nXV<GoZIW5ojVIaOnYVLD3ojbJa@03ojfLaOn^VlCo/9g400?o
/9g400?o/Yk4ok:Oa?ndXL@00ondXL@00onfX/Co]j?4okNSa002okVUa@05okZVa?nlYlGo_:O5okbW
aOnmZLD00onoZlD00oo0[<Ko`Zk6ol:^aP02ol>_a`;oaK770_o5/lP3olRgb@;ob[W:00Cob[[;olbm
c?o<_Lcoc;k=0_o>`Ld3om34c`;odLO@00Co0000om;;dooBbm?odL_D0_oBc]D01_oDdMKod]3Gom?C
fOoCdmWoe=KJom;Ef`;od]OM00God=KNom3Hgoo@f=oocm[QolgHh@02olgIh`04olcJi?oooooooooo
o`0001Cooooo0009ooooo`0400000?ooooooooooooooo`X0C4a<00<0000006IVIP1VIVH02@1VIVH0
0`000000Ogmo07moO`0807moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<02P2c/k<0
0`000000c<c<0<c<c00]0<c<c0800000302c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0
Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0
<c<c00X0<c<c00<00000ooooooooool00_ooool00`00003oooooooooo`0Booooo`03o`000?oooooo
oooo01Kooooo0_nBZ^H3oi6Xi@;oTJOT0_n@YN<2oi2ShP;oT:;Q00CoT:7Oo`000?l0003o00000_n?
Vm`2ohnJfP?oT9WH0_nAV=L3oi:GeP;oTiOD0_nDU]82oiJFd@03oiNEd?nFTlooUi?>00;oUi?>0onI
Tld2oi^Dc0?oW9C;0_nNULX00onPU/WoWiC8oj:Ea`03oj:Ea`;oY9K700?oYYO6ojJFa_nXV<D00onX
V<D2ojVIa@;o[9[500Co[9[4ojjKa?n^VlCo[Y_40_n`WL@01?naWLCo/Yo4ok:Oa?nbWl@2okBQa005
okJQa?ngXlCo]j?4okNSa?niYLD00onjY/@2okbWa@?o_j_500Go`:c6ol:^a_o2[/Ko`Zk6ol>_a`03
olFaa`04olFcb?o7]LSoakG8olRgb@?ob[W:0oo<_L`3olk1c@03om34c_o@a<oodLO@00;odLO@00Go
d/_Co`000?oBbm?oe<kDom;>e@02omCAeP06omGDf?oCdmWoe=KJomCFf_oDfMcod]OM0_oBf]h01Oo@
f=oocm[QoloJhOo?fn;ocMWS00;oc=[T00Cobm_Uoooooooooooo00004oooool000Wooooo00@00000
oooooooooooooooo2P1<C4`00`000000IVIV06IVIP0806IVIP030000001oOgl0Ogmo00P0Ogmo00<0
000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<0300c<c<00<0
00000;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00P0Ogmo00<0
000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00X0<c<c00<0
0000ooooooooool00_ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo0_nB
Z^H01?nAZ>GoSjOUohjUi?n>YN@2ohjSh`;oSZ;R0ol00002ohjNgP;oSYgM0_n?Vm`2ohnJfP?oT9WH
0_nAV=L01?nBUmKoT9GEoi6DdonAU=<2oi:DdP?oU9?@0_nFTll3oiNCcP;oVI?=0_nKU<`2oibDb`03
oibCb_nNTlWoWY?900?oWiC80onRULL00onTU/OoXiG6ojJFaP02ojJFaP?oZ9S500?oZIW5ojZIaOn/
V/@00on/V/@2ojjKa004ok2Ma?naWLCo/Ig4ok6Ma0;o/Yo41?nfXL@2okNSa0Co^ZK400Co_:O5okfY
aOnmZLGo_j_50oo0[<H2ol:^aP?oaK7700Coa[C8olNeb?o7]LSoakG80oo:^LX2olblb`04olbmc?o>
`<coc/3<olk1c@;od<C>0ooAam02om?;dP05om;;dol0003oe<kDomGAeOoDdMH00_oEe=P01_oFemWo
e=KJomCIg?oDfMcoe=_Mom;JgP;od]cP00Gocm[QoloKh_o?fn;oc]gSolcJi002ol_Ki@04ol[Liooo
ooooooooo`0001;ooooo0009ooooo`0400000?ooooooooooooooo`T0C4a<00<0000006IVIP1VIVH0
201VIVH00ol00000Ogmo07moO`0807moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0
2P2c/k<00`000000c<c<0<c<c00E0<c<c0P000005@3<c<`00ol00000/k>c0;>c/`090;>c/`030000
002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0706IVIP030000
001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<02`0c<c<01@00003oooooooooooooool0000001?o
oooo00?o0000ooooooooool06Oooool2oi2XiP;oSjOU0_n>YN@3o`000003ohjRh_n>X>3oRikP00?o
RicN0_n;Vmd2ohbIf`;oSISI0_n=UmP2ohjFeP?oT9GE0_nAU=<2oi:DdP?oU9?@0_nFTll2oiNCcP04
oiVCcOnHT/coVY;;oiZBb`CoW9?:0_nNTlT3oinDb003oj:EaonQU<OoXiG600;oXiG60onVU/H00onX
V<GoZ9O5ojZIa@02ojZIa@?o[9[400?o[Y_4ojnLa?n_W<@00onaWL@00onbWlCo]9o4okBOa003okJQ
a003okNSa?niY<Co^JC400;o^ZK400Co_:O4okfYaOnmZLGo_JW51?o0[<H01?o2[/Koa;36olB`a_o5
/LL3olJdb004olNeb?o9^<WobKS9olZibP;oc;c;00Koc[o<olk0c?o>`<coc/3<om33cOo@a<h2om;7
c`0:om77d?oCbm;odl_Bom?;d_oEc]?oe<kDo`000?oEdMGoe]GGomGDf0;oe]OI00Koe][KomCIg?oD
fmgoe=_MomCNgooBg>02om7Mh@05oloKh_o>gN?oc]gSolgNiOo;fnD00_o:g>L00oo8g>Soooooo`00
000Booooo`002Oooool01000003oooooooooooooool904a<C0030000001VIVH0IVIV00P0IVIV00<0
000007moO`1oOgl01`1oOgl00ol00000VIVI09VIV@0809VIV@03o`00002c/k<0/k>c00T0/k>c00<0
00000<c<c03<c<`03`3<c<`7000000P0i^KV0`0000000ol0000000000000000@0<c<c08000002P2c
/k<00ol00000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01P1V
IVH00ol00000C4a<04a<C00804a<C0030000000c<c<0<c<c00X0<c<c00D00000oooooooooooooooo
0000000Cooooo`03o`000?oooooooooo01Wooooo0_n=YnH01?n<YNGo0000o`000?l00002oh^Qh`;o
RioQ0on;W^03oh^LgP;oRi_M0_n<VM/2ohfHf@;oSIOH0_n>U]H2oi2Ee@;oTICC0_nBU=82oiBCd003
oi:Bd?nDTLkoU97>00;oUY;=0onHT/`2oiZBb`?oW9?:0_nNTlT2oinDb004oinCaonQU<OoXIC7oj6D
a`;oXiG60_nVU/H01?nVU/GoZ9O5ojRGaOnXUlD3ojZIa@03ojbJa?n]V/Co[ic400?o[ic400?o/Ig4
ok:Na?ndWl@00ondWl@00onfXLCo]j;4okVTa002okVTa005okZVa?nlYlCo_:O4okbWa?nmZLD00_no
ZlD3ol2/aP?oa;3600CoaK;7olJdb?o6]<Soa[C80oo9^<T00oo<^l[oc;c;oljoc002oljoc003olk0
c?o@`lgod<?=00?od/O?0_oDbm401OoCbm;oeLkComG>dooFd]Co000000;oe]GG00KoemSHomKGfOoF
f]_oe][KomKMg?oDfmd2omCNg`06om?PhOoAgN7odMoSom7Ohoo>gN?ocMkU0_o<gnH01_o:g>Oob=cX
olSLj?o7g>Woooooo`00017ooooo0009ooooo`0400000?ooooooooooooooo`T0C4a<00<0000006IV
IP1VIVH0201VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00L0VIVI00<000000;>c
/`2c/k<0202c/k<00`00003o00000<c<c00>0<c<c0<000005@3Vi^H00`000000c<c<0<c<c00?0<c<
c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0707mo
O`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0:03<c
<`0500000?ooooooooooooooo`0000004oooool00ol0003oooooooooo`0Iooooo`?o00000_n<YND2
ohbSi0;oRj7S0_n;Wn42oh^Nh0;oRicN00?oR9[NohRHg?n8V=`00_n9Um/2ohZFf@;oRiCG0_n<TmH2
ohfCe0?oSi;B0_n@T]43oi:Bd0;oU97>0_nFT/d2oiRBc0?oVY;;00?oW9?:oi^BbOnMT/P00_nMT/P3
oinCa`;oXIC70_nSULH4ojJFa@;oZ9O50_nZVLD01?n[VLCo[I[4ojfJa?n]V/@2ojnLa004ok2La?nb
W/Co/Yk4ok:Na0;o]9o400Go]J74okNRa?ngX/Co]j;4okVTa002okZUa0?o_:O41?noZlD01?o0[<Ko
`Zk6ol:^a_o4/<H3olFba`04olJdb?o9]/SobKK8olVhb@;oc;_:00Coc[k;oljoc?o>_lcoc[o<0oo@
`ld01?oBa/ood/O?omC;dOoDbm42omK>dP05omG>dooFd]Coe];DomSEe_l000000_oGf=P01_oHfm[o
e][KomKMg?oFgMcoe]oNomCNg`;odn3Q00Kodn;Rom7Ohoo@hNCod>7TolkRi_o<gnH2ol_Oj003olSL
j?o7g>WoaMcZ00?o00004?ooool000Wooooo00@00000oooooooooooooooo201<C4`00`000000IVIV
06IVIP0806IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c
0;>c/`080;>c/`030000003<c<`0c<c<00h0c<c<00<000000>KViP3Vi^H05`3Vi^H3000000l0c<c<
00?o00000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00L0Ogmo
00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c
00D00000oooooooooooooooo0000000Cooooo`03o`000?oooooooooo01Kooooo0ol00002ooooo`;o
RjGW0_n9XnD2ohVQi0;oR9oS0_n8WN42ohRLg`?oR9[N0_n8V=`2ohVGf`;oRYKI0_n;U=L2ohbCeP;o
SI?D0on?T]82oi2Bd@;oTY;@0_nDTLh01?nFT/goU93<oiN@bonGT</3oiVAbP?oVi;90onMT/P2oinC
a`03oj6DaonQTlKoXiG600;oXiG60onVU/D2ojRGa@CoZiW40_n]V/@01?n_W<Co/9c4ok2La?n`W<@2
ok:Na004okBOa?neXLCo]J74okFQa0;o]j;41?njYL@00onlYlCo_JW5okfYa@02okn[a@04ol6]a_o2
[/Ko`Zk6ol:^aP?oaK;700Cob;G8olVfb?o9]/SobKK80oo<^lX2oljnb`04oljoc?o@`/god<;=om33
c@;od/K?00?oe<[@omC;dOoFc]800_oFc]801_oGd]?oe];DomSEe_oHeMKofMWHo`0000;of=_J00Ko
f=kLomKMg?oFgmkoe]oNomKRh?oCh>42om?RhP04om;Si?o@hNCoc^;VolgRi`;obmoX00?obMoYolOO
j_o5g>X00_o4g>/00ooooooo0000ooooo`0?ooooo`002Oooool01000003oooooooooooooool704a<
C0030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0709VI
V@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`0303<c<`3000001d0i^KV0`00000=0<c<
c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607mo
O`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c
<`0500000?ooooooooooooooo`0000004oooool00ol0003oooooooooo`0Dooooo`;o00001_ooool2
oh^Ui`;oRJ?U0_n9XN@2ohROh`;oR9gQ0_n8W=l2ohRJgP;oR9SL0_n9Um/2ohZFf@;oRiCG00CoS9?F
ohVAeOn;TM?oRi7C0on=T=82ohj@d0;oT93?0_nBT<h3oiB@c0;oUi3;0onITLX2oi^Bb@;oWI;800?o
W978oinBaonOT/L00onQTlH3oj>EaP;oYYK50onXUlD3oj^Ia003ojfJa?n]VlCo/9c400?o/9c400?o
/Yk4ok>Oa?neXL@00oneXL@00ongX/Co^:C4okRTa002okZUa005okbWaOnmZLGo_JW5okfYaOnoZlD0
0oo1[LH01?o2[/Koa;77olBaaoo5//L3olReb004olVfb?o;^LWobkW9olbkbP?oc[k;0oo@`/d01?oB
a/kod/K?omC:d?oDb]03omK>dP;oem;C0_oHeMH2omWIf003omWLfOl0003of=kL00;of>7M00Soe]oN
omKRh?oEi>;oeNCRom?Rh_oBhnCod>CUolkRiP;ocN;W00Kobn?YolWOjOo7gn[oamoZolGOjoo4g>/2
ol;Kk003o`000?oooooooooo00kooooo0009ooooo`0400000?ooooooooooooooo`L0C4a<00<00000
06IVIP1VIVH0201VIVH00`000000Ogmo07moO`0607moO`03o`00002IVIT0VIVI00P0VIVI00?o0000
0;>c/`2c/k<01`2c/k<00ol00000c<c<0<c<c00<0<c<c0030000003Vi^H0i^KV0240i^KV00<00000
0<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00H0VIVI00<00000
07moO`1oOgl01P1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00L0C4a<00<00000
03<c<`0c<c<02@0c<c<4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool04_ooool3
o`0000Wooooo0_n7Y>L2ohJRi@;oQYoT0_n5WN<00on5Vn7oQIWOohFIg`02ohFHgP;oQIKL0_n6UMX2
ohNCf@;oR9;G0on9TMD2oh^Ad`?oSI3B0_n>T=02oi2@c`;oTY3>0onDT<`2oiN@b`;oVI7:00?oVi;9
oiZAbOnLTLP00onLTLP2oinBa`;oXI?60_nSULH01?nSU<GoYYK5ojJFaOnVU/D3ojRGa@;oZiW40on]
Vl@3ok2La0?o/io40_neXL@01OnfX/Co^:C4okRTa?nhY<Co^ZG400?o_:O50_nmZLD3ol6]aP04ol>_
a_o4/LOoa;77olBaa`?ob;G800Cob[S9ol^ibOo;^LWobkW90oo>_//2om31c003om32cOoBa/kod/K>
00?oe<[@00Koe/kAomK>d_oGd]?oem;ComWFeOoHeMH2omWIf0;ofMcI00Go0000omSQgOoHhMgof>CO
omKRh002omGThP03omCVhooBhnCod>CU00;ocnGW00KocN;Wol_SjOo9hn[obN?ZolOOj_o5gn/2olCN
k003ol;Kk?o0f^go0000013ooooo0009ooooo`0400000?ooooooooooooooo`L0C4a<00<0000006IV
IP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI00<000000;>c
/`2c/k<01`2c/k<00`000000c<c<0<c<c00:0<c<c08000009@3Vi^H00`000000c<c<0<c<c00:0<c<
c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607mo
O`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c
<`Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`?o00003Oooool2ohBR
i`;oPj3V00?oPYgToh:Khon2Vn<00_n2VN42ohFIg`;oQISN0_n5U]`2ohJEfP;oQi?I0_n8T]L3ohVA
e@;oRi7C0_n=T=82ohj@d0;oT93?0_nBT<h2oiB@c003oi>?c?nESl_oUHo;00;oV93:0onJTLT3oibA
b0;oWi;70_nQTlH4oj>Da@;oYYK50_nXUlD01?nYV<GoZiW4oj^Ia?n[VL@3ojfKa003ok2La?naWLCo
/Ig400;o/io400Co]J74okJRa?nfX/Co]Z;40_nhY<@4okbWa@04okfYaOnoZlGo_j_5ol6]aP?o`jo6
00Coa;77olJcaoo6/lOob;G80oo:^<T01?o;^LWocKg:olfmb_o>_//2om31c0;od/G=00Cod/K>omC:
cooDb/ooe<[@0_oFc]401_oHd]?oem;ComWFeOoIe]Gof][GomWIf0;ofMcI00?of^3Kom[SgOl00000
0_oHi=l00ooGi^7oeNCRomCVh`02om;Wi@06om7Xi_o?iNOocNKXolgVj?o;i^[obN?Z0_o7h^/01oo5
h^coa=k/ol;MkOo2gNgo`=[]ooooool000003oooool000Wooooo00@00000oooooooooooooooo1`1<
C4`00ol00000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0202I
VIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H09P3V
i^H00`000000c<c<0<c<c00:0<c<c003o`00002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2I
VIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<
C4`00`000000<c<c03<c<`0803<c<`Cooooo00<00000ooooooooool04?ooool00ol0003ooooooooo
o`0<ooooo`?o00004Oooool2ohBRi`;oPj3V00?oPYgToh:Khon2Vn<00_n2VN400on1UmooPYKNoh:F
gP03oh:Dg0;oPi;J0_n4TMP2ohF@e`;oQhoE0_n8Sm<2ohZ>dP;oS8k@0_n>S/l3oi6>c@?oTho<0_nE
Sl/2oiR@bP?oVY790_nLTLP2oijBa`?oXI?60onSU<D2ojJFa@CoZIS50_n[VL@2ojfKa005ojjKa?na
WLCo/Ig4ok6Ma?ncWl@00_ndX<@3okJRa003okRTa?njYLCo^ZG400?o_:O50onoZlD01?o1[LKo`jo6
ol>_a_o3[lH3olJca`04olVgb?o:^<Wob[S9olZhb@?ocKg:00?ocl3<om31c?oBaLd00_oBaLd3omC:
c`06omO>dOoFc]7of=;ComSBdooJe]CofMKE0_oJf]L00ooKg]WofMcIom[Pf`02om[Sg@07omWVg_l0
003oenKQomOVhOoFj>?oe>[Tom;Wi@02om7XiP08oloYj?o=i^SobnKZol_Vj_o9i^_oan;[olGRk?o3
hNd2ol;Mk@?ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo1P1<
C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2I
VIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00T0c<c<0P00000Z0>KViP8000002`3<
c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01P1o
Ogl00ol00000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0200c
<c<4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool02Oooool3o`0001Cooooo0_n1
X>L2oh2NiP;oOicT0_mnVN<2ogjGh@03ogjEgon2U]koPYKN00?oPYCL0_n3T]X2ohBAf0;oQI3G0_n7
SmD2ohR?d`;oRXkB0_n<S]02ohj>c`?oTHk=0_nCSl`2oiF?b`03oiR@b_nGSlWoVI3800;oVI380onL
TLP2oijBa`?oXI?600?oXiC5ojBEaOnVU/D00_nVU/D3ojVHa@03oj^Ia?n/V/Co[Y_400?o[Y_40_na
WL@4okBPa003okJRa?nhY<Co^ZG400?o^ZG400Co_:O5okfYaOnmZLGo_j_50oo1[LH01?o3[lKoaK;7
olFbaoo6/lL3olVgb004olZhbOo<^l[oc;_:olfmbP;ocl3<0ooBaLd2omC9c`05omC:cooGc]7oelkA
omWBd_oHd]<00_oJe]@01ooKfmKof][Gom_NfOoKg]Wofn;Jom_Ug?oJhmd00_oIi]h00ol0003oenKQ
omKXh`02omCZi003om?/i_oAj>KocnWX00;ocNWZ00GobnKZolWVjoo7iNgoaN;/ol?Qk@06ooooo`03
o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooo`H0C4a<00<0000006IVIP1V
IVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c
/k<0202c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV02`0i^KV00<000000<c<c03<
c<`0203<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1o
Ogl01P1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c
<c<0200c<c<4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`0001So
oooo0_n1X>L2oh2NiP;oOicT0_mnVN<2ogjGh@03ogjEgomnTmkoOY?N00;oOY;L0_moT=X2oh6?f0;o
PXkG0_n4S]D2ohJ=d`;oR8gB0_n<S]000on>S/ooSHg?ohn=c@02ohn=c@;oTHk<0_nDS//3oiN?b@?o
VI380_nLTLP2oijBa`?oXI?60onTULD3ojJFa@;oZIS50on/V/@3ojjKa003ok6Ma?nbW/Co/Yk400;o
]:3400Co]Z;5okRTa?nhY<Co^:C40_njYL@01?nlYlGo_JW5okfYaOnmZLD4ol6]aP?oaK;71?o9]lP3
olbkbP?ocl3<00?od/C=om;5cOoDbLl00_oDbLl01_oGc]3oelkAomWBd_oId];of]ODom[Fe0;ofm_F
00?og=oHom_NfOoKh]X00_oKiM`02?oKj=kofNKNomWYh?oGjn;o0000omK]i?oDj^CodncV0_oAk>P0
1Oo>kNWocNWZol_Yjoo8j>goanG]00;oaNC^1oooool00ol0003oooooooooo`0=ooooo`002Oooool0
1000003oooooooooooooool504a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01`1o
Ogl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`0203<
c<`00`000000i^KV0>KViP0^0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c
/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01@1V
IVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00L0<c<c1?ooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00?ooooo0ol0000Looooo`03ogfNj?mlW>KoO9cV00;oNi[U0_mj
Un<2ogZEhP;oNY?P0_mnTmh2ogjBg0;oOi3J0_n1SmP2oh:>e`;oQ8kE0_n6SM<01?n8SM;oRXg@ohZ=
d?n:SM02ohf=c`?oShg=0_nAS/`2oiB>b`?oUho90_nIT<P01?nLTLSoVi78oijBaonNT/L4oj6CaP;o
Y9G50_nVU/D01?nWUlGoZIS5ojVHaOnYV<D2ojbJa0;o[Y_400Go[ig4ok:Na?nbW/Co/Yk4okBPa003
okJRa@;o^:C41?nlYlD00onmZLGo_jc6okn/aP02ol6]aP;oa;370_o5//L00oo7]LSobKO8olVgb002
ol^jbP04olbkb_o?_l_ocko;olo0c0;od/C=0ooDbLl2omO>d0;ofM;B0_oJem@01ooLfmKofm_FomcO
f?oLgmSog>?JomcWg?oKiM`00_oKj=h03?oJjmoofNkQomO[h_oFkNCo0000omC^iOoBknOodNcXolk]
jOo<k>_obnW[olSXk@;oa^O^00?oaNC^ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`00
2Oooool01000003oooooooooooooool504a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1o
Ogl01P1oOgl00`000000VIVI09VIV@0709VIV@03o`00002c/k<0/k>c00L0/k>c00?o00000<c<c03<
c<`0203<c<`00`000000i^KV0>KViP0C0>KViPWo0000503Vi^H00`000000c<c<0<c<c0080<c<c003
0000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00ol00000Ogmo07moO`0607moO`03
0000001VIVH0IVIV00D0IVIV00<00000o`00001<C4`0201<C4`00`000000<c<c03<c<`0703<c<`Co
oooo00<00000ooooooooool03oooool01?l0003oooooooooooooool3o`00023ooooo00?oNIgXogbL
i_mlW>H00_mkV^D2ogZGh`;oNYGR00?oNY?PogZAg_mjTMh00_mkT=`2ogb>fP;oOHgI0_n2S]L2ohB>
e@;oQXgC0_n8SM83ohZ=d0;oSHg?0_n?SLd2oi6>c0;oU8k;0_nGSlT00onFSl[oVI39oiV@b@03oi^A
b0;oWY;70onQTlH00onTULGoY9G6ojNGa@03ojNGa@;oZIS500?o[9[4ojfKaOn_WL@00on_WL@00onb
W/Co/j35okJRa@03okJRa@03okRTa?niY/Go^JK500;o_:O500Go_J[6okn/a_no[<Ko_jc6ol6]aP03
olB`a`04olFbaoo7]LSoakG8olVgb0;obk[:00Koc[k;olnoboo?_l_ocko;om74cOoBa<d3omC9c`;o
elk@0_oId]801_oKemCof]ODomcKe_oLfmKogN3HomcOf0;og>?J00Cog>OLomc[gOoKj=kof^_O0_oI
k^401ooGl>?oe^gTomC^iOl0003od?3Yolk]jOo<k>/00_o:k>`00oo7jnkoa^O^ooooo`09ooooo`03
o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooo`D0C4a<00<0000006IVIP1V
IVH01`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c
/k<01`2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV0140i^KV0_l000090?ooo`?o
00004@3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2I
VIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<
C4`01`1<C4`00`000000<c<c03<c<`0703<c<`Cooooo00<00000ooooooooool03oooool4o`0002Co
oooo0_miWNP2ogJHi@;oMYGT0_meTn82ogFAh0;oNY7N0_mkT=`2ogb>fP03ogf=fOmoS=OoOhcG00;o
PHcE0_n3Rm<2ohF;dP?oR8_@0_n;S<l2ohf<c@;oT8g<0_nCS//4oiJ?bP;oVI390_nKTLP3oijBa`03
oj6Ca_nQU<KoY9G600;oY9G60onWUlD00onYV<GoZYW5ojfKa@02ojfKa@?o[ig40oncX<D3okJRa@?o
^JK500Go_:O5okfZa_nmZ/Ko_J[6okn/aP02ol:_a`?oa;370oo7]LP00oo:^L[obk[:oljnb`02oljn
b`03olnobooAa<godLC=00?oe<W?0_oGc]03omWBdP03om_Ge?oLg=Kog=_F00;ogN3H00?ogNGJomcS
f_oLim`00_oLjmd02?oKk]oof_3QomW^hOoGl>?oeO7Uom?bi_oBknOo00000_o=l>X00oo;kncob^c/
olO[kP0<ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooo`D0C4a<
00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI
00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00h0i^KV
1?l0000>0?ooo`?o00003`3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00D0/k>c
00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV
00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c<`Cooooo00<00000ooooooooool0
3oooool2o`0002Kooooo0_meVnT00omcV>OoMYSUogJHi@02ogJEi0;oMI?R00?oMI7PogJ?g_mfSmh0
0_mfS]`2ogR<f`;oOHgI0_moS=L2oh6<e@;oPh_C0_n5Rm83ohR;d0;oRhc?0_n=S<d2oi2=c0;oThk;
0onFSlX2oiV@b@;oVi780onNT/L3oj6DaP;oY9G60_nWUlD01?nWV<KoZYW5ojZIaOnZVLD3ojfKa@03
ojnMa?naW/Go/Ik500?o/j3500?o]Z;5okNTaOngY<D00_niY/D01?nkZ<Ko_J[6okfZa_nmZ/H4ol:_
a`04olB`aoo6]<Soa[C8olNeb0;ob[W:00KocKg;oljnboo>_/_oc[k;om33cOoAa<d2omC8c`03omC9
cooGc]3oelk@00?ofM;B0_oKem@00ooLg=KogN7HomgPf002omgUfP04omgYfooMkMgog>_Mom_^g`;o
f_3Q00?oe_CTomGaiOoCl^H00_o@lnP00oo>ln[o0000ol__k002olS^kPkooooo00?o0000oooooooo
ool03?ooool000Wooooo00@00000oooooooooooooooo101<C4`00`000000IVIV06IVIP0706IVIP03
0000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`03
0000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H03@3Vi^H2o`0001D0oooo00?o00000>KViP3V
i^H0303Vi^H00ol00000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2I
VIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<
C4`01`1<C4`00`000000<c<c03<c<`0703<c<`Cooooo00<00000ooooooooool04Oooool00ol0003o
ooooooooo`0Tooooo`;oMI_Y0_mcV>L00ombU^KoLI?Tog6Ci002og2AhP03og2?hOmfSmkoMXoN00;o
MXkL00GoN8cKogV;fOmiRmWoNH_Iog^;e`02ogf:eP?oP8[D0_n5Rm82ohR;d0;oRhc?0_n=S<d2oi2=
c0?oThk;00CoUXo:oiF>b_nHT<WoV9390onKTLP3oijBa`;oXIC600?oY9G6ojBFa_nWV<H00onWV<H2
ojZIa@;o[I_500Co[Yc5ok6NaOnaW/Go/Ik50_ncX<D01OneX/Ko]jC5okNTaOngY<Go^JK500?o^jS6
00?o_J[6ol2]aoo0[LL00_o2[lL01?o4//Soa[C8olJdb?o6]<P3olZibP;ocKg;00?oc[k;om33cOo@
`ld00ooDb<l01?oFcM3oelk@omWBd_oId]82om_He007om_Ge?oLg=Kog=cFomgQf?oNi][ogNGJomgY
f`02omg]g@;of_?P00Oof_3QomKdi?oFm>CodoKUom3fioo@lnSoc_?Z00;obo;[00?o0000olS^k_oo
ool03_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool404a<C003
0000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@03
0000002c/k<0/k>c00H0/k>c00?o00000000003<c<`0203<c<`00`000000i^KV0>KViP0=0>KViP03
o`00003oool0oooo01H0oooo00?o00000>KViP3Vi^H0303Vi^H00`000000c<c<0<c<c0070<c<c003
0000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`03
0000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c<`Co
oooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03og2JjOm^UnSoKYOX00;o
KICV0_maTn@2og2AhP04og2?hOmaSMooLHgOog:<g@;oLh_K0omiRmT00omkRmOoOH[Fogf:eP02oh2:
e0;oPh[B0_n5R]42ohR;c`;oS8c>0_n?S<d3oi:=b`?oUHk:0_nHT<T3oi^Ab0;oWY;700?oXIC6oj6D
aonTU/H00_nTU/H3ojNHaP03ojZIaOn[VlKo[Yc500?o[Yc50_naW/D4okFRaP03okNTaOniY/Ko^jS6
00;o^jS600Go_J_7ol2]aoo0[LOo`:g7ol:_a`03olBbb004olJdb?o8^<[ob;S:olZibP;ocKg;00Ko
cl;=om33cOo@`lgod<?=om?7cooDb<l2omK=d0;ofM;B0_oKf=@2omgMeP07omcLe_oMhMSog^KJomkV
f_oNjm_og^oMomg]g@02om[ch005omSehOoFmn?oe_CTom?fiOo@m^L00_o>m^P01Oo;m^_obo;[olSb
kOoooooo000000oooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo
101<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0
1P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00?o00000>KViP3Vi^H0
303Vi^H00ol00000oooo0?ooo`0H0?ooo`03o`00003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`0
1`3<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
1`0c<c<4ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00om[V>[oKYOX
ofjGj002offDiP03ofbAiOm[Sn?oJhoS00;oJhgQ0_maSMl00ombS=goLh_Kog>;f`02ogF9fP;oMhWH
0_mmR]H2oh2:e0;oPh[B0_n5R]42ohR;c`;oS8c>0_n?S<d3oi:=b`;oUHk:0_nHT<T2oi^Ab003oi^A
bOnNTlSoWY?800?oXIC70onTU/H00onWV<KoZ9W7oj^KaP02oj^KaP?o[Yc500?o/Ik5ok:Pa_nbX<H0
0_neX/H01OnfYLOo^JK6okVVa_niY/Ko^jS600?o_J_70_o0[LL3olBbb006olNfb_o8^<[ob;S:olRh
b_o;_<cocKg;0oo?`/d01Oo@`lgodlO?om?7cooFcM7oe/g@00;ofM;B0_oKf=@2omgMeP;og^;H00Wo
gnOJomkVf_oNjm_og^oMomcbg_oKmMoof_?PomSehOoFmn<00_oCn>@01?o@nNGocOWWolkfj?o;m^/4
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooo
oooooooooooo101<C4`00`000000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00D0Ogmo00<00000
09VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00<00000
0>KViP3Vi^H02`3Vi^H2o`0001`0oooo00?o00000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c007
0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`05
07moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`06
03<c<`Cooooo00<00000ooooooooool05?ooool2o`0002Gooooo00CoJiSZofVEjOmWT^OoIi;W0_mV
SnD2of^?h`03of^=hOm/RmooK8_O00;oKH[N0_mcRm/2ogF9fP03ogN9f?mjRMKoNXWF00;oOHWD0_mo
RM<2oh>9d@;oR8_?0_n<S<h3ohn<c@04oi:=bonASLcoU8k;oiB>b`;oUi3:1?nKTLT2oijCb0;oXIC7
0_nTU/H01?nUUlOoZ9W7ojRIaonXVLL3oj^KaP03ojjLaOn_W/Ko/Z3600;o/Z3600Co]J;6okJUaonf
YLOo]ZG70_niY/H4okf[a`04ol2]aoo2/<Wo`[39olBbb0?oakK:00?ob;S:ol^lc?o;_<`00oo?`/d2
om;7c`05om?7cooFcM7oe/gAomSBdooId]800_oKf=@02OoMg]OogMgFomkRf?oNh]SognOJomo/fooN
jm_og^oMomcbgP02om_eg`08omShh?oEnN7od__Rom?hi?o@nNGocOWWol[hjOo7n>/6ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo
101<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0
1P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H0
2`3Vi^H00ol00000oooo0?ooo`0M0?ooo`03o`00003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`0
1`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
1P0c<c<4ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool08oooool01OmVU^_oHi?Y
ofNBiomWT^OoIXoU00;oIHgT0_mURn82ofb;g`03off:g_m^RMcoKXWL00;oL8SJ0_mcQmT2ogZ9eP;o
OHWD0_moRM<00on3RM7oQX[@ohJ:d003ohV;c`;oSHc=0onASL`2oiB>b`;oUi3:0onKTLT2oijCb003
oj6DaonRU/SoYIO700?oYIO70_nXVLL2oj^KaP05ojbMaon_W/Ko[ik6ojnNa_nbX<H00_ncXlL3okJU
a`03okVVa_nkZLSo^jW800?o_J_70oo2/<T01?o5]<_oakK:olNfb_o7]/X3ol^lc003olk1c_o?`/go
d/O?00;od/O?0ooFcM400ooHd]?ofmSEom_He002omgNe`03omkSf?oNh]SognOJ00;ogncK00Oog_7L
omcdgOoJn=kofoGOomShh?oEnN7od__R00;oco_T00?ob?_Wol[hjOo7n>/02?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?ooooooooooooooo`@0C4a<
00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI
00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00X0i^KV
00?o00000?ooo`3oool07`3oool00ol00000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00L0c<c<
00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00H0<c<c
1?ooool00`00003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo0_mPU>`2of>Cj@05of6@
j?mOSNKoIHgTofF=i?mURn800_mVRN42ofN8g`;oKXWL0_m`R=X00omcQmWoMXOGogJ7e`02ogV8eP;o
OhWC0_n3RM42ohJ:d0?oRH_?0_n=S<d2oi6=c0;oU8k;0onGT<X01?nKTLWoVi;:oijDbOnNU<T3oj:F
b0?oYIO700?oZ9W7ojVKb?n/WLL00on/WLL2ojnNaPCo/j?700?o]ZG7okRXb?nkZLP00onkZLP01?nm
ZlOo`:o9ol2_bOo2/<T3olFdb`04olNfb_o9^/cobK[<ol^lc0;oc/7>0_oAa]001?oBalooeLcAomG<
dOoFcM42omSBd`03om_HeOoLg]OogMkG00;og^?H00GognWJomo^fooOk=_og_7Lomcdg@02om[hgP07
omOjgooDo>3od?cQolcmh_o?nnCob?_WolGjj@0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo101<C4`00`000000IVIV06IVIP06
06IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`06
0;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0P
0?ooo`03o`00003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`05
0;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP06
06IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01P0c<c<4ooooo`0300000?oooooo
oooo01Sooooo00?o0000ooooooooool08_ooool2of2Dk003oefAj_mJS^WoFXkY00;oGhgV00GoGh_U
oen9homVRN7oIXWQofN8g`02ofV7g@;oJhKK0_mcQmT2ogJ7e`03ogV8e_mlR=CoO8SD00;oP8WB0_n4
R]43ohR;d0;oS8c>0_n?SLd2oi>?c0?oUi3;0onKT/X2oijDb@?oXYK800?oYIO7ojFIb?nYVlP00_nY
VlP3ojbMa`03ojnNa_naXLSo/J7800;o/j?700Co]ZK9okRXb?nhZ<So^:S80_nkZLP01?nm[LWo`:o9
ol2_bOo0[lT3olFdb`06olNicOo9^/cobK[<olVjc?o<_lkoc/7>0ooAa]03omG<d@08omSBe?oHd]?o
fmSEom_HeOoLg]Oog^GIomkSf?oOjMX2omo^f`08omkcgOoLmmgofO[Nom[hg_oGn]ooe?cPom3lhOo<
oN82olGli@03ol?liooooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`002Oooool01000003oooooooooooooool304a<C0030000001VIVH0IVIV00L0IVIV00<0
000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<0
00000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0:0>KViP03o`00003oool0oooo0240oooo00?o
00000>KViP3Vi^H02P3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00H0/k>c00<0
000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0
000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0603<c<`Cooooo00<00000ooooooooool06Ooo
ool2o`0002?ooooo00?oFI?/oeJ?jomFSn/00_mJS^T01?mIRnOoF8WVoeR9i_mORN<2oen7hP04of66
h?mYQmgoJHOMof^6f`;oKXKJ0_maQ]P2ogV8eP;oO8SD0_n0RM82ohB:d@?oR8_@0_n<S<h2ohn=c@;o
Tho<0onGT</2oi^BbP;oWYC90_nRU/P01?nRUlWoYIW8ojFIb?nUVLP3ojVKb003ojbMaon]WlWo/J78
00;o/J7800Co/j?7okJVbOnfY/Wo]ZK90_nhZ<P4okf]b@04ol2_bOo2/l_o`[?;olFdb`?oakW=00?o
bK[<olboc_o<_lh00ooAa]02omC<dP06omG<dOoHd]Cof=;Dom[Ie_oKf=Gog=kG0_oNiMT01?oNjm_o
g_3Lomo^fooNlmd2omcgg@08omWjg_oFo=kod_gNolgng_o5o^3o`_gRolGliOo3o>L>ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo
0`1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0
1P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H0
2@3Vi^H00ol00000oooo0?ooo`0R0?ooo`03o`00003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`0
1P3<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
1P0c<c<4ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool01?mBTNgoEXo[
oeJ?jomCS>T2oe69j003oeR9i_mHQnCoF8OT00;oGhOR00CoHHKPof>5g_mSQMkoIXGM0_m^Q]X01Oma
Q]SoMHOGogF7eomeQmOoNHOF00?oOHSD0_n4R]42ohR;d0;oS8c>0_n?SLd3oi>?c0;oUi3;00?oVi;:
oiZCbonNULX00_nNULX3oj:Gb@;oYIW80_nYVlP01OnZWLWo[Io9ojfObOn]WlWo/J7800;o/ZC:0onf
Y/T00onhZ<So^Z_:okZ[bP02okf]b@04ol2ac?o2/l_o`[?;ol:cb`?oakW=0_o:_/l01?o<_lkoclG@
olo5d?oAa]02omC<dP;oem;D00Kof=;Dom[Ie_oJfMKog=oHomgVf_oNiMT2omk[f`0;omk`g?oMmMgo
foWMomcggOoIn]koe_cNom;mg_o=o]koaOkPol;mh_nnoN@04Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooo`<0C4a<00<0000006IV
IP1VIVH01`1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI00<000000;>c
/`2c/k<01P2c/k<00`000000c<c<0<c<c0060<c<c003o`00003Vi^H0i^KV00X0i^KV00?o00000?oo
o`3oool08P3oool00ol00000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c
/`2c/k<01P2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00
003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo0_mBTNd00om?SNcoBh[Zoe69j002oe27
iP;oF8OT00?oF8GSoeZ4hOmJQ>400_mSQMh01?mVQMgoJHGKoff5f_m]QMX3ogF7e`03ogV7e_mmR=Co
OHSD00;oPH[C0_n6Rm42ohZ=d0;oSXk?0onBT<h2oiJAc0?oVY?;0onNULX2oj:Gb@03ojFIb?nVVl[o
ZYg900?oZYg900?o[Io9ojnRbonbY<X00onbY<X00onfY/Wo^:W;okZ[bP02okZ[bP05okf]bOo0/Lco
`;7<ol2ac?o2/l/00_o5^<d01?o7^Lgob[k?olZncoo:_/l3olo5d004om;;dooDc=;oem;DomOBe0;o
fMWG00Sof]WFomcOf?oLgmSogNKJomk/g?oNjm_og_3Lomgeg@;ofoWM00Ooeo_Mom?mg?o>o]coa?kK
ol3ng?nloMgo^OcO01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`00
2Oooool01000003oooooooooooooool304a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1o
Ogl01P1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<
c<`01`3<c<`00`000000i^KV0>KViP090>KViP03o`00003oool0oooo02@0oooo00?o00000>KViP3V
i^H02@3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2I
VIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<
C4`01`1<C4`00`000000<c<c03<c<`0603<c<`Cooooo00<00000ooooooooool07Oooool00ol0003o
ooooooooo`0Qooooo`03od^?kOm7S>coAhc/00;oBHOX0_m@QnH01?m@QNGoD8?Toe23i?mJQ>42oeb4
h0;oGhCN00?oJHGKoff5f_m]QMX00_maQ]T2ogF7e`;oOHSD0_n1R]<2ohJ;d@;oRXg@0_n>S/l3oi:@
cP;oUY7<0_nJTl/2oijEbP03oijGc?nSVL_oXiW;00?oYY_:0_nZWLT01?n[X<_o[j;;ojnRbon_X//2
ok:TbP05okBWc?nhZL_o^:W;okRYbonjZlX00_nm/<d3ol2ac0?oaKS=0_o8_M001?o:_/oocLCAolg4
dOo?aM02om;;d`04omGBe_oGd]CofMWGomWIe`;ofn3I00oog=oHomgVf_oNk=cog^cLomgbgOoLmmgo
fO[Mom_igOoGnmgodogLolkng?o4o]_o`?kLokcmgOnio=l05?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooo`<0C4a<00<0000006IV
IP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<01P2c/k<00`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00T0i^KV00?o00000?oo
o`3oool09@3oool00ol00000i^KV0>KViP080>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c
/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00
003oooooooooo`0Nooooo`;o00008_ooool00om4S^koAhc/odN<k002odV7j004odN4iom7PnKoAh?V
oe23i0;oDX;S0_mLQ>000omOQ=koHhCMof>4g@02off5fP;oLHKI00?oMHOGogZ8e_mjR=H00_mnR]@2
oh><d`;oRXg@0on>S/l2oi:@cP03oiJAc?nFTlkoVYG=00;oVYG=0onNUl`2oj>Ib`03ojJKb_nWW/co
Zj3;00?oZj3;0_n_X//01?nbY<[o]:O<okBWc?ndYl`2okRYb`Co_K3=00Co`;7<ol:fc_o2]/koaKS=
0_o8_M001_o;`m?ocLCAolg4dOo=a=7od<_Dom;;d`;oeM;F00?of=WIomWIeooKh=T00_oKh=T01OoL
imcogNgMomk/g?oMl]gog?OM00;ofO[M00KoeOgLol[ofOnno]Oo^OgGokGlf?nbnm/Gooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo
0`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0
1@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H0
2@3Vi^H00ol00000oooo0?ooo`0U0?ooo`03o`00003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`0
1`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
1P0c<c<4ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool08?ooool01ollS>ko?XW/
ocZ6j_ljQ^[o@8GYocj2iom7PnH00_m8PND00omBP^?oEH;QoeF2h@02oeR2h003of>4gOmWQMcoIhGL
00;oK8KK0_meQmL2ogZ8eP;oOX[D00CoPhcCohR=d_n8SM;oR8gB0_n=Sm42oi6Ad0?oUY?>0onJULd2
oijGc003oj>IbonSW<goYik<00;oYik<0on[X</00on_X/_o/JK=ok6Vc@03okBWc003okRYbonj[/ko
^Zk>00;o_K3=0_no]<l01?o2]/koaKcAolFldOo8_M03ol_3d`05olg4dOo@bmCod<_Dom?BeooEd]H0
0_oHfMT2om[Qf`0=om_PfOoLimcogNgMomg]gOoLlmkof_SNomKlgOoIn]goeOgLol[ofOngo=;o/O[B
ojgidP0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@0
0000oooooooooooooooo0`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo
00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<
00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0U0?ooo`03o`00003Vi^H0i^KV00P0i^KV
00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<
00<0000003<c<`0c<c<01P0c<c<4ooooo`0300000?oooooooooo027ooooo00?o0000ooooooooool0
8?ooool01OllS>ko=HO/ocZ6j_ljQ^[o=X;Y00;o?X;W0_m8PND01?m9PNCoEH;QoeF2hOmHP^02oeb3
g`;oIhGL00?oK8KKog67f_maQmX00_mfRMP2ogj:e0;oPhcC0on8SM82ohf?d@;oTI7@0_nFTlh2oiZE
c@03oiZGd?nOV/ooWi[?00?oXic=0onWW/`00on[X<_o[J?>ok6Vc@03ok6Vc@03okBWc?nf[<oo^Zk>
00;o^Zk>00Co_;?@okndcono]<oo_kC?0oo5_=43ol_3d`;oc/[F00God<_Dom?BeooCd]Ooe]WJomSI
f@02om[Qf`;ofnSM00_ofnoOomg]gOoLlmkof_SNomKlgOoAo]_oa?oGokgme?ngo=;o/O[BojgidP0L
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooo
oooooooooooo0`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<00000
09VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<00<00000
0>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0V0?ooo`03o`00003Vi^H0i^KV00P0i^KV00<00000
0<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<00000
07moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<00000
03<c<`0c<c<01P0c<c<4ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool2
oc>:k@04oc23j_l[OnSo:goXoc=oi`;o<WgV00?o?GoUocmniOm<P><00_m@PN800omLPmooHHCNof64
gP02ofJ6g@;oLHOJ00GoMXWHog^;eomkRmOoNh_Goh6=eP03ohJ?e0;oRi7C0_n@Tm83oiJEd@?oVYO@
0_nOV/l2oj>Lc@;oYik<00CoZ:7?ojfSc_n]Xlko[J?>0_naY/d01OnbZ]3o]Zc?okJ/conf[<oo^Zk>
00?o_;?@00Co_kC?ol:jd_o2^];oaKcA0_o8`]@01_o;`m?oc/[Folk:e_o>b]KodM7Iom?Be`;oe]WJ
00kof>7Mom[QfooKj=gofnSMom__gooJmMooeo[Oom?mgOoFo=godOkKokgmdonenloo[OW=oj;ec1ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooo
ooooooooool304a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000
VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000
i^KV0>KViP090>KViP03o`00003oool0oooo02H0oooo00?o00000>KViP3Vi^H0203Vi^H00`000000
c<c<0<c<c0070<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000
Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0603<c<`Cooooo00<00000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03
ob^8k?lSPnWo8h?Y00;o:goX00Oo:7gVoc9mi_lbO>Ko<WcVocmniOm2O^CoD87R00;oE8;Q0_mQQ=h0
0omVQ]goK8OLofb7g002og:9f`?oNh_G00CoPHgFohJ?e?n6SmCoQXoD0_n;TM<2oi2CdP?oUYGA0_nJ
Um000onOV/ooWigAojBOd002ojBOd0?oZ:7?00?o[J?>ojjXdOnbZ]000onbZ]000onf[<oo^K7Bokbc
d002okbcd004oknie?o2^];o`[[Bol:jdP?ob<;D0_o;bMP01Oo>b]KodM7Iom7AfOoDfMcoe]WJ00;o
f>7M00_ofNWOom_XgOoKkmoof_GOomOjgooCoMgocOoJolGoeonmoM?o]O_?ojgic@0Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo
0`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0
1@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0
2@3Vi^H00ol00000oooo0?ooo`0V0?ooo`03o`00003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`0
1`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
1P0c<c<4ooooo`0300000?oooooooooo02Cooooo0_l0000Qooooo`04ob>7jolSPnWo8h?Yoa]niP;o
77WU00Oo9W[Uoc9li_ldO>Go=7cUod9ni?m6OnCoE8;Q00;oFXCQ0_mOQN02ofb7g0;oLXWK0_mhS=X2
ogj>f@;oQXoD0_n;TM<2oi2CdP;oUYGA00?oUISDoiZJdonJV]<00onOWM43ojBOd003ojRQconZYM;o
[ZSA00;o[ZSA0_nbZ]001Ond[m?o^K7BokVad_ni/M;o_;?@00?o_kWD00Co`[[BolG1e_o5`MKob<;D
0_o;bMP2olkAf`05om7AfOoDfMcoe=WLomKRgooHhMd00_oIjMl02OoIl>7of?KQomCkh?o>o]goaooI
okkne?ndnlooX_C6oi_aa00Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool000Wooooo00@00000oooooooooooooooo0`1<C4`00`000000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<
c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0U0?ooo`03o`00003V
i^H0i^KV00T0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`060;>c/`030000002I
VIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<
C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<4ooooo`0300000?oooooooooo02Kooooo00?o
0000ooooooooool08?ooool2oaZ1i`05oa5ki?lLNNGo6GOToaUgi?lVNND00_ldO>D00olgO>GoAWoT
od^1i002oeZ4h@;oGhGP00CoIXSOog:9fombRM_oLXWK0_mhS=X00omnS]WoQ93HohB@f002ohZCe`?o
SiKE0onEV=@2oiZJd`;oWigA0_nTWm001OnUXm?oZZGBojZUd_nZYM;o[ZSA00;o/:gD0ond[m<00oni
/M;o^kOEok^ge@02oknie0;o`[oH00CoaL7FolS8f_o8b=[oblWH0_o>dM/2om7Ig`0=omCIg?oFh]oo
e^;OomOZh_oIjMoofO3QomSfhOoDnn3oc_kMolOofOnno]Co]?_?oiK^_P0Uooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo0`1<C4`0
0`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT0
0`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H0
0ol00000oooo0?ooo`0U0?ooo`03o`00003Vi^H0i^KV00T0i^KV00<000000<c<c03<c<`01P3<c<`0
0`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl0
0`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<4
ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool08?ooool2oa5oi@06o`Ihh?l9M^7o
6GOToaUgi?lHM^?o9gWU0_lZN^D01?lkO^GoBh7Tod^1i?mAPn<2oeR6h`03ofJ8gom]R]koKH[N00;o
LhgN0_mnS]T2ohB@f0;oRY?G0on?U]D2oiFHe003oiZJdonJW]KoX:7E00;oX:7E0onUXm<00onZYM;o
Zj_Fok2]e003ok2]e003okB_dong]MOo^kOE00;o^kOE00Co_[kIol:of?o2_mSo`[oH0oo8b=X00oo;
d=goc]7Kom7Ig`02om7Ig`03om?Rh_oFh]ooen[R00;oeo7S00Ooe?SSololhOo8o]go_okHokGkdOnO
l/CoU^jn02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool0
1000003oooooooooooooool304a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1o
Ogl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<
c<`00`000000i^KV0>KViP090>KViP03o`00003oool0oooo02D0oooo00?o00000>KViP3Vi^H02@3V
i^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01@2I
VIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<
C4`00`000000<c<c03<c<`0703<c<`Cooooo00<00000ooooooooool0:?ooool00ol0003ooooooooo
o`0Pooooo`;o3h?T00Oo0G_No`1bg?l3L]ko37?Po`YagolIM^?o:W[U00;o;W_U00Co@GoUodN2i_m7
P^KoF8KS0_mOR><2off:gP03og>=g_mjT=goNY3M00;oPI?K0on8U]X2ohjIf@;oU9_H0onJW]H3oj2Q
e@03ojFSdonVZ=SoZj_F00;oZj_F0_n`[M@01Onb/mWo]kGGokNeeong]MOo^kOE00?o_[kI00Co`[oH
olG7g?o5amcob<SJ0_o;d=d2olkIhP0<om7IgooCh^;odn;RomC[iOoCl^Koeo7SomChhoo?o>7ob?kM
okonf?nenm7oQnJf:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`0400000?ooooooooooooooo`<0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07mo
O`0607moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00T0i^KV00?o00000?ooo`3oool09@3oool00ol00000i^KV0>KV
iP090>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VI
V@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<
C00604a<C0030000000c<c<0<c<c00L0<c<c1?ooool00`00003oooooooooo`0Yooooo`;o00008ooo
ool01?l0N]_o07?Go`1^f?l0Km/2o`Yag`05oa]fhol^NnGo=7kVocAni_m7P^H00_m>Q^H2oen8h`03
ofJ<h_m^Sn;oKXoR00;oNY3M0_n1Tm/3ohRFfP;oSYWI0_nDVmP2oiZNeP;oX:7E00GoXJGIojJXf?nV
Z=SoYZSHoj^[eP02ojf`fP?o/[?I00?o]kGGokVlfoni_=/00_nn_]T2ol75gP04olG7g?o7cn3oaloP
ol_@g@;oc]WR0_o?h^D02OoCh^;oe>_Uom?bi_oCl^Kod?WVol[mhoo1o]go]_cFoigba00]ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooo
oooo0`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2I
VIT01@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3V
i^H02P3Vi^H00ol00000oooo0?ooo`0S0?ooo`03o`00003Vi^H0i^KV00X0i^KV00<000000<c<c03<
c<`01P3<c<`00`000000/k>c0;>c/`050;>c/`03o`00002IVIT0VIVI00D0VIVI00<0000007moO`1o
Ogl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00?o000003<c<`0c
<c<01`0c<c<4ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool08Oooool01?l0N]So
077Co`1YdOl0J]D2o`1]fP06o`1/fOlON>Co=7kVocAni_lkPNOoCXKV0_mGRNH2oen=iP03ofj?h_mf
T^7oMY;Q00?oOYKP0_n5VMl2ohfLg@;oU9oL0onJXm/3oj6Uf@03ojJXf?nW[]co[K3J00?o[K3J00?o
/[?IokBjgOni_=/00_ni_=/3ol75gP;o`lkS00CoaloPol[Hi?o:f>Coc]WR0_o?h^D02Oo@jnSoc_?Y
olkcjOoCl^Kod?WVol[mhoo1o]go]_cFo`00000^ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo0`1<C4`00ol00000IVIV06IVIP06
06IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`06
0;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02P3Vi^H00ol00000oooo0?ooo`0S
0?ooo`03o`00003Vi^H0i^KV00T0i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`05
0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP06
06IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01`0c<c<4ooooo`0300000?oooooo
oooo02cooooo00?o0000ooooooooool08_ooool02?l6RMko073;o`1WaOl0H/?o0679o`1VdOl0KM[o
9G_V0_l]OnP01?m3QNSoEhWVoeN9i_mOSNH2ofRAiP;oMY;Q0omnU^02ohFIg`;oSIcM0_nDWm`3oiZS
f`03oj6UfOnQZmkoYjkL00;oYjkL0_n]/=X01On_]moo];[MokBjgOnd^]go^KcK00;o_<CP00Ko`LGN
ol?>hoo3c^?o`lkSolGHj?o:f>@2ol_Rj009ol_[k?o@jnSoc_?YolkcjOo:nNSo`ogTokSlgOn[nM?o
WO?9037ooooo00Go0000ooooooooooooooooo`00000;ooooo`002Oooool01000003ooooooooooooo
ool304a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VI
V@0509VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP0:0>KViP03o`00003oool0oooo02<0oooo00?o00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<
c0070<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07mo
O`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c
<`0703<c<`Cooooo00<00000ooooooooool0;Oooool00ol0003oooooooooo`0Rooooo`;o2HgO00Oo
06K0o`1O^ol0Fk_o05o7o`1VdOl0Km_o;GoX00;o=XCZ00?oC8[YoeJ?jomFSn/00_mXTNH2og6EiP;o
NYWU0_n3WN@2oh^Qh`?oTjGR0onJZ>02oj6[gP03ojN^g?nX]N;o[kOO00?o[kOO00Co];[MokK2honf
`^?o_<CP0onncNH01_o3c^?oaMSXolGHj?o6h^cobn;Xol_[k0;obO?]00Go`oW[ok[liOn]n]coW_C@
ohk/``0dooooo`04o`000?ooooooooooo`0000_ooooo0009ooooo`0400000?ooooooooooooooo`<0
C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0
VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00X0
i^KV00?o00000?ooo`3oool08@3oool00ol00000i^KV0>KViP090>KViP030000003<c<`0c<c<00L0
c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00H0
Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00P0
<c<c1?ooool00`00003oooooooooo`0^ooooo`;o00009Oooool2oaJGi005o`1M/?l0FK_o05o6o`1Y
d_l3Lmh00olfQ>X3oeJ?j`03of2Djom[VN_oJiW[00;oNYWU0_n3WN@2oh^Qh`?oTjGR00?oVZSPoiZ^
i_nQ/^@00_nQ/^@2ojRehP;o[kOO0_n`_nD00onf`^?o^<_XokS;j002okk=iP;o_mO[00[oaMSXolKR
k?o5jnooaN__ol;cl?o9lngo`oW[ok[liOn]n]coK]R^=oooool00ol0003oooooo`00000;ooooo`00
2Oooool01000003oooooooooooooool304a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1o
Ogl01@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<
c<`01`3<c<`00`000000i^KV0>KViP0:0>KViP03o`00003oool0oooo0200oooo00?o00000>KViP3V
i^H02P3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2I
VIT01@2IVIT00ol00000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<
C4`01`1<C4`00`000000<c<c03<c<`0803<c<`Cooooo00<00000ooooooooool0<?ooool00ol0003o
ooooooooo`0Tooooo`;o9jC[00Ko5i_Ro`1H^Ol0HLKo06gEo`YhhOlVPnT2oc69k@03od^@k_mFU^oo
EYK_00;oJiW[0_meW^/01?moX^[oR:OYohRWjOn8YnT3oi6[i`;oVZkV00?oXK;Toj6jj_nY_NP00onY
_NP01?n`_nGo/LW/ok79k?nhbnP3okWEkP0;okoGjoo0hO3o`>7`okk[loo5jnoo`_?`ok[ikOn_n^Ko
X?KKoho^c?l00000>?ooool00ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooooooo
ool304a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0609VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KV
iP0:0>KViP03o`00003oool0oooo01l0oooo00?o00000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<
c0070<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07mo
O`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c
<`0803<c<`Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Tooooo`08o`000?oo
ooooooooooooool0FKSo06G8o`1bf?lCOnD2oc69k@04ocf@l?mFU^ooEYK_of:Ll0;oKZ;a0_miZ?00
0on8YnWoQ:g_ohB]k`02ohnbkP?oV;K/0_nQ^^X2ojVmj0;oZLK^00?o/LW/ok7Cl_nado800_nieNh2
okSOl`03ol3Ql?nnjo?o^O;c00;o/?O_00?oTO3HogkVaom/fKH0>oooool00ol0003oooooo`00000:
ooooo`002Oooool01000003oooooooooooooool304a<C0030000001VIVH0IVIV00L0IVIV00<00000
07moO`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<00000
0<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0:0>KViP03o`00003oool0oooo01d0oooo00?o0000
0>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00H0/k>c00<00000
09VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<00000
04a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`Cooooo00<00000ooooooooool0<_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00Go06[;o`1igOlOQn[o7hOZobb?
kP02odVHlP03oeNOm?m^X_7oKZ;a00;oNJS`0on4[Nl2ohnbkP03oiRfk?nF__?oU[kc00?oX<?a00Co
ZLK^ojS@mOnXd?Go/M?b0_n_gOL2okSOl`07okGYmon_l?Ko[o3foj?clOn`mnooK=_1oeW=[@0noooo
o`;o00002_ooool000Wooooo00@00000oooooooooooooooo101<C4`00`000000IVIV06IVIP0606IV
IP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`050;>c
/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H02`3Vi^H00ol00000oooo0?ooo`0K0?oo
o`03o`00003Vi^H0i^KV00/0i^KV00?o00000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`050;>c
/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0606IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<01Ol0003oooooooooooooool0
000003Gooooo0_l0000Sooooo`03o`000?oooooooooo00Oooooo00?o?`00o`1je_lHS>P00_ljV?<0
0om9X_KoIJOfofFWmP03og:^mP;oOkCf0_n;^_D01?nF__?oT/Ojoi;7n_nBaoX2oik<n004ojS@mOnU
f_[oYM[jojoMm`;oZnKj0_nRkOT01?n_l?KoXo?aoi?`iOl0000oooooo`?o00002_ooool000Wooooo
00@00000oooooooooooooooo101<C4`00`000000IVIV06IVIP0606IVIP03o`00001oOgl0Ogmo00H0
Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0
c<c<00<000000>KViP3Vi^H02`3Vi^H2o`0001X0oooo0_l0000=0>KViP030000003<c<`0c<c<00L0
c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00H0
Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0
<c<c00D00000oooooooooooooooo0000000gooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02_ooool01Ol0L<Co9iK^obNFk_lWU^ko=j7d00;oFJ_i0_mX/o/2ogNko0;oQL;k0_nBaoX2
oh_@oP05oiWFoOn@gOkoT=gnoikSoOnCj?X00_n3io02oiC^l@03od?2/Ooooooooooo03cooooo1?l0
000=ooooo`002Oooool01000003oooooooooooooool404a<C0030000001VIVH0IVIV00L0IVIV00<0
000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@03o`00002c/k<0/k>c00H0/k>c00<0
00000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0=0>KViP;o00005`3oool00ol00000i^KV0>KV
iP0=0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VI
V@0509VIV@030000001oOgl0Ogmo00D0Ogmo00?o000006IVIP1VIVH01`1VIVH00`000000C4a<04a<
C00604a<C0030000000c<c<0<c<c00T0<c<c00D00000oooooooooooooooo0000000hooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool03Oooool01Ol0KkCo08OBob:MjolRWN_o=:[a00;o
F[Ol0_m/`Oh01?mlbOooK/gnofk=o_m^cOh2oh3Fo`05oi3Mo_n3hO[oL=g^oe[Cf_m3a<80?oooool3
o`00017ooooo0009ooooo`0400000?ooooooooooooooo`D0C4a<00<0000006IVIP1VIVH01P1VIVH0
0`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01`2c/k<0
0`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00h0i^KV00?o00000?ooo`3oool04P3oool2
o`0000l0i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`060;>c/`03o`00002IVIT0
VIVI00D0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0
C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<00`00003oooooooooo`02ooooo`0300000?oooooo
oooo03Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`04oah00?l6Ulco
<[7Zoc:ajP?oAko`00?oG<ceodG4i?l^]l`0@?ooool4o`0001Cooooo0009ooooo`0400000?oooooo
ooooooooo`D0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002I
VIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000003V
i^H0i^KV00h0i^KV0_l0000@0?ooo`;o0000403Vi^H00ol00000c<c<0<c<c0070<c<c0030000002c
/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001V
IVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`0300000?oo
oooooooo00;ooooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?oo
ool4o`0001Sooooo0009ooooo`0400000?ooooooooooooooo`D0C4a<00<0000006IVIP1VIVH01P1V
IVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c
/k<00ol00000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV0100i^KV0_l0000<0?ooo`;o00004@3V
i^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2I
VIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<
C4`00`000000<c<c03<c<`0903<c<`0300000?oooooooooo00;ooooo00<00000ooooooooool0>_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000Looooo`002Oooool0
1000003oooooooooooooool504a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1o
Ogl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`02@3<
c<`00`000000i^KV0>KViP0A0>KViPco00004P3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c
/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001V
IVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0:03<c<`0300000?oo
oooooooo00;ooooo00<00000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo057ooooo0ol0000Pooooo`002Oooool01000003oooooooooooooool604a<C0030000001V
IVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c
/k<0/k>c00H0/k>c00<000000<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0]0>KViP030000003<
c<`0c<c<00T0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0609VIV@03o`00001o
Ogl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C003o`00000c
<c<0<c<c00T0<c<c00<0000001TI6Oooool00oooool00`00003oooooooooo`0looooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0COooool4o`0002?ooooo0009ooooo`0400000?oooooo
ooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`03o`00002I
VIT0VIVI00H0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0090<c<c0800000:`3V
i^H00`00003o00000<c<c00:0<c<c0030000002c/k<0/k>c00H0/k>c00?o000009VIV@2IVIT01P2I
VIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<
C4`00`000000<c<c03<c<`0903<c<`030000000I6AWooooo00?ooooo00<00000ooooooooool0?Ooo
ool2o`0001Wooooo00?o0000ooooooooool0BOooool4o`0002Oooooo0009ooooo`0400000?oooooo
ooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002I
VIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<c0030000003V
i^H0i^KV02L0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`060;>c/`030000002I
VIT0VIVI00L0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0606IVIP030000001<
C4`0C4a<00L0C4a<00<0000003<c<`0c<c<02@0c<c<00`0000006ATIooooo`03ooooo`0300000?oo
oooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:ooo
ool000Wooooo00@00000oooooooooooooooo1`1<C4`00ol00000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`030000003<
c<`0c<c<00X0c<c<00<000000>KViP3Vi^H09@3Vi^H00`000000c<c<0<c<c00:0<c<c003o`00002c
/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001V
IVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`030000000I
6AT06ATI00Cooooo00<00000ooooooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04?ooooo0ol0000_ooooo`002Oooool01000003oooooooooooooool704a<C0030000001V
IVH0IVIV00L0IVIV00?o000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@03o`00002c
/k<0/k>c00L0/k>c00?o00000<c<c03<c<`02`3<c<`2000002<0i^KV0P00000;0<c<c08000002@2c
/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00?o000006IVIP1VIVH01`1V
IVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT01?oo
ool00`00003oooooooooo`11ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?ooo
ool4o`0003;ooooo0009ooooo`0400000?ooooooooooooooo`L0C4a<00<0000006IVIP1VIVH01`1V
IVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c
/k<00`000000c<c<0<c<c00<0<c<c0030000003Vi^H0i^KV01h0i^KV0P00000<0<c<c0030000002c
/k<0/k>c00T0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001V
IVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`030000000I
6AT06ATI00Cooooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o0000ooooooooool0>ooo
ool4o`0003Kooooo0009ooooo`0400000?ooooooooooooooo`L0C4a<00<0000006IVIP1VIVH01`1V
IVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c
/k<00`000000c<c<0<c<c00<0<c<c0800000703Vi^H2000000d0c<c<00<000000;>c/`2c/k<02@2c
/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01`1V
IVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c00@0000001TI6@0I6AT06ATI
1?ooool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
=oooool4o`0003[ooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00<0000006IVIP1VIVH0
1`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0
202c/k<00`000000c<c<0<c<c00=0<c<c0030000003Vi^H0i^KV01L0i^KV00?o00000000003<c<`0
3P3<c<`00`000000/k>c0;>c/`080;>c/`03o`00002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl0
1P1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
2@0c<c<0100000006ATI01TI6@0I6AT4ooooo`0300000?oooooooooo04Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00@00000oooooooooooo
oooo201<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00?o000009VIV@2I
VIT01`2IVIT00`000000/k>c0;>c/`080;>c/`03o`0000000000c<c<00d0c<c<00@00000o`000000
00000000403Vi^H5000000l0c<c<0P0000090;>c/`8000002@2IVIT00`000000Ogmo07moO`0607mo
O`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c
<`030000000I6AT06ATI00806ATI1?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0009ooooo`0400000?oooooooooooooo
o`P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI
00P0VIVI00<000000;>c/`2c/k<02@2c/k<00`000000c<c<0<c<c00?0<c<c0L000001P3Vi^H30000
0180c<c<0P00000:0;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01P1oOgl00ol0
0000IVIV06IVIP0806IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<02@0c<c<00`00
00006ATI01TI6@0201TI6@Cooooo00<00000ooooooooool0Aoooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01000003oooooooooooooool904a<
C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0809VI
V@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`05@3<c<`6000001@0c<c<00<000000;>c
/`2c/k<02@2c/k<00ol00000VIVI09VIV@0809VIV@03o`00001oOgl0Ogmo00L0Ogmo00<0000006IV
IP1VIVH01`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI
6@0I6AT00`0I6AT4ooooo`0300000?oooooooooo04Sooooo0_l0000=ooooo`03o`000?oooooooooo
02Sooooo1?l00019ooooo`002Oooool01000003oooooooooooooool:04a<C0030000001VIVH0IVIV
00L0IVIV00?o000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c
00T0/k>c00?o00000000003<c<`0:`3<c<`200000003o`00002c/k<0/k>c00T0/k>c0P00000909VI
V@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00704a<
C0030000000c<c<0<c<c00X0<c<c00?o000001TI6@0I6AT00`0I6AT4ooooo`0300000?oooooooooo
04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000COooool000Wo
oooo00@00000oooooooooooooooo2P1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo
00P0Ogmo00?o000009VIV@2IVIT01`2IVIT00ol00000/k>c0;>c/`0;0;>c/`800000:@3<c<`00`00
0000/k>c0;>c/`0;0;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201oOgl00`00
0000IVIV06IVIP0706IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<02@0c<c<00`00
00006ATI01TI6@0401TI6@Cooooo00<00000ooooooooool0Boooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo027ooooo0ol0001Aooooo`002Oooool01@00003ooooooooooooooooo0000
00X0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0807moO`030000002IVIT0VIVI
00P0VIVI00<000000;>c/`2c/k<0302c/k<2000002D0c<c<0P00000=0;>c/`030000002IVIT0VIVI
00P0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<
00L0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0401TI6@Cooooo00<00000oooo
ooooool0C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0001Doooo
o`002Oooool01@00003ooooooooooooooooo000000X0C4a<00<0000006IVIP1VIVH01`1VIVH00`00
0000Ogmo07moO`0807moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<03@2c/k<00`00
0000c<c<0<c<c00Q0<c<c0030000002c/k<0/k>c00`0/k>c00<0000009VIV@2IVIT0202IVIT00ol0
0000Ogmo07moO`0807moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00ol0
0000<c<c03<c<`0:03<c<`030000000I6AT06ATI00D06ATI1?ooool00`00003oooooooooo`1=oooo
o`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wooooo00H00000oooooooo
oooooooo03<c<ol0000:04a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl0201oOgl0
0`000000VIVI09VIV@0809VIV@0300000?l00000000000`0/k>c00?o00000000000000007P3<c<`2
00000003o`00002c/k<0/k>c00/0/k>c0P00000:09VIV@8000002@1oOgl00ol00000IVIV06IVIP07
06IVIP03o`00001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@05
01TI6@Cooooo00<00000ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Gooooo1?l0001Looooo`002Oooool01P00003oooooooooooooool0<c<co`0000/0C4a<00<0
000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0807moO`03o`00002IVIT0VIVI00X0VIVI00<0
00000;>c/`2c/k<0302c/k<3000001L0c<c<1000000>0;>c/`8000002`2IVIT00`000000Ogmo07mo
O`0807moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c
<`0:03<c<`030000000I6AT06ATI00D06ATI1?ooool00`00003oooooooooo`1@ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009ooooo`0400000?oooooo
ooooooooo`80<c<c00?o000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001o
Ogl0Ogmo00P0Ogmo00<0000009VIV@2IVIT02P2IVIT00`000000/k>c0;>c/`0>0;>c/`L000002P3<
c<`600000140/k>c00<0000009VIV@2IVIT02P2IVIT00ol00000Ogmo07moO`0807moO`030000001V
IVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0:03<c<`030000000I
6AT06ATI00H06ATI1?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?ooooooooooooooo`80<c<c00?o
000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0806IVIP030000001oOgl0Ogmo00P0Ogmo0P00
000;09VIV@03o`0000000000/k>c01@0/k>c2P00000E0;>c/`8000002`2IVIT2000000X0Ogmo00<0
000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00X0<c<c00<0
000001TI6@0I6AT01`0I6AT4ooooo`0300000?oooooooooo05;ooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0001Wooooo`002Oooool01000003oooooooooooooool303<c<`03o`00001<
C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0:07moO`030000002I
VIT0VIVI00X0VIVI00<000000;>c/`2c/k<0;`2c/k<2000000`0VIVI00<0000007moO`1oOgl02@1o
Ogl00`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02P0c
<c<00`0000006ATI01TI6@0701TI6@Cooooo00<00000ooooooooool0E?ooool01?l0003ooooooooo
ool00008ooooo`Co0000Joooool000Wooooo00@00000oooooooooooooooo100c<c<00ol00000C4a<
04a<C00904a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl02P1oOgl00`000000VIVI
09VIV@0:09VIV@<00000;02c/k<2000000`0VIVI0P00000;07moO`030000001VIVH0IVIV00P0IVIV
00<0000004a<C01<C4`02@1<C4`00ol00000<c<c03<c<`0:03<c<`030000000I6AT06ATI00P06ATI
1?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo0ol0001_ooooo`002Ooo
ool01000003oooooooooooooool503<c<`03o`00001<C4`0C4a<00T0C4a<00?o000006IVIP1VIVH0
1`1VIVH00ol00000000007moO`0:07moO`030000002IVIT0VIVI00`0VIVI00<00000o`0000000000
9P2c/k<3000000d0VIVI00?o000007moO`1oOgl02@1oOgl00ol00000000006IVIP0906IVIP030000
001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0901TI6@Cooooo
00<00000ooooooooool0E_ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@0
0000oooooooooooooooo1@0c<c<00ol00000C4a<04a<C00904a<C0030000001VIVH0IVIV00T0IVIV
00<0000007moO`1oOgl02@1oOgl00ol00000000009VIV@0>09VIV@030000002c/k<0/k>c0240/k>c
0P00000>09VIV@8000002`1oOgl00`000000IVIV06IVIP0906IVIP03o`00001<C4`0C4a<00X0C4a<
00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0901TI6@Cooooo00<00000ooooooooool0
Eoooool2o`0007Kooooo0009ooooo`0400000?ooooooooooooooo`H0<c<c00?o000004a<C01<C4`0
2@1<C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00X0Ogmo00<0000009VIV@2IVIT0
3@2IVIT3000001h0/k>c0P00000>09VIV@800000301oOgl00`000000IVIV06IVIP0906IVIP030000
001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0:01TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1`0c<c<00ol00000C4a<
04a<C00904a<C0030000001VIVH0IVIV00T0IVIV00?o000007moO`1oOgl02P1oOgl00`000000VIVI
09VIV@0?09VIV@H000004@2c/k<7000000l0VIVI00?o000007moO`1oOgl02`1oOgl00`000000IVIV
06IVIP0906IVIP030000001<C4`0C4a<00X0C4a<00?o000003<c<`0c<c<02P0c<c<00ol000006ATI
01TI6@0;01TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
1`0c<c<00ol00000C4a<04a<C00:04a<C003o`00001VIVH0IVIV00T0IVIV00<0000007moO`1oOgl0
2P1oOgl00`00003o00000000000D09VIV@0300000?l00000000000h00000502IVIT2000000d0Ogmo
00?o000006IVIP1VIVH02@1VIVH00`000000C4a<04a<C00:04a<C0030000000c<c<0<c<c00/0<c<c
00<0000001TI6@0I6AT02`0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooo`P0<c<c00?o000004a<C01<C4`02@1<C4`2000000/0IVIV00<0000007moO`1oOgl0
301oOgl2000003D0VIVI0P00000>07moO`030000001VIVH0IVIV00T0IVIV00<00000o`00001<C4`0
2P1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI00`06ATI1?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003oooooooooooooool903<c<`03o`00001<C4`0C4a<00X0C4a<
00<0000006IVIP1VIVH02@1VIVH2000000h0Ogmo0P00000a09VIV@8000003P1oOgl2000000X0IVIV
0P00000<04a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT03@0I6AT4ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`X0<c<c00?o000004a<C01<C4`0
2P1<C4`00ol00000IVIV06IVIP0:06IVIP8000003P1oOgl00`00003o00000000000[09VIV@800000
00?o000007moO`1oOgl0301oOgl2000000/0IVIV00<0000004a<C01<C4`02`1<C4`00`000000<c<c
03<c<`0;03<c<`030000000I6AT06ATI00h06ATI1?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003oooooooooooooool:03<c<`03o`00001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH0
2`1VIVH00`000000Ogmo07moO`0>07moO`<000009@2IVIT3000000l0Ogmo00<00000o`00001VIVH0
2`1VIVH00`00003o000004a<C00;04a<C0030000000c<c<0<c<c00`0<c<c00<0000001TI6@0I6AT0
3P0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`/0<c<c
00?o000004a<C01<C4`02`1<C4`00`000000IVIV06IVIP0;06IVIP030000001oOgl0Ogmo0100Ogmo
1000000N09VIV@<000004@1oOgl00`000000IVIV06IVIP0;06IVIP030000001<C4`0C4a<00/0C4a<
00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0?01TI6@05o`000?ooooooooooooooo`00
0000dOooool000Wooooo00@00000oooooooooooooooo300c<c<00ol00000C4a<04a<C00;04a<C003
0000001VIVH0IVIV00/0IVIV00<0000007moO`1oOgl04`1oOgl3000001L0VIVI1000000B07moO`80
00003@1VIVH00`000000C4a<04a<C00;04a<C003o`00000c<c<0<c<c00`0<c<c00<0000001TI6@0I
6AT0400I6AT01Ol0003oooooooooooooool000000=7ooooo0009ooooo`0400000?oooooooooooooo
o`d0<c<c00?o000004a<C01<C4`02`1<C4`2000000`0IVIV00Co00000000000000000000501oOgl0
0`00003o000000000004000000X0VIVI1P00000D07moO`8000003@1VIVH00`00003o000004a<C00;
04a<C08000003P0c<c<00ol000006ATI01TI6@0@01TI6@03o`000?oooooooooo00;ooooo00<00000
ooooooooool0coooool000Wooooo00@00000oooooooooooooooo3P0c<c<00ol00000C4a<04a<C00<
04a<C0030000001VIVH0IVIV00d0IVIV0P00000I07moO`X00000601oOgl2000000h0IVIV00<00000
04a<C01<C4`02`1<C4`00`000000<c<c03<c<`0=03<c<`030000000I6AT06ATI01406ATI00?o0000
ooooooooool00_ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool?
03<c<`03o`00001<C4`0C4a<00`0C4a<00<0000006IVIP1VIVH03P1VIVH00`000000Ogmo07moO`0e
07moO`<000003P1VIVH2000000d0C4a<00?o000003<c<`0c<c<03@0c<c<00`0000006ATI01TI6@0A
01TI6@03o`000000003ooooo00?ooooo00<00000ooooooooool0coooool000Wooooo00D00000oooo
ooooooooooooo`00000?03<c<`03o`00001<C4`0C4a<00`0C4a<00?o000006IVIP1VIVH03P1VIVH2
o`0003<0Ogmo0P00000@06IVIP030000001<C4`0C4a<00`0C4a<00?o000003<c<`0c<c<03@0c<c<0
0`0000006ATI01TI6@0A01TI6@03o`0000000000000000Cooooo00<00000ooooooooool0coooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool0coooool000Wooooo]P00003Aooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`002Ooooonfo`00017ooooo]_l0000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo03Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1kooooo`800000=Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?ooo`1h0?ooo`03o`00o`3oool0oooo0180oooo8ooo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool0O@3oool00`000000oooo0?ooo`0=0?ooob?ookK10_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`1h0?ooo`030000o`3oool0oooo
0180oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0OP3oool20000
00d0oooo8ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo07T0
oooo00<0003o0?ooo`3oool04@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`200?ooo`030000003oool0oooo00X0oooo8ooo]/42ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo07T0oooo00<0003o0?ooo`3oool04@3ooolSoonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`210?ooo`0300000?l00000000000T0oooo
8ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo07X0oooo00<0
003o0?ooo`3oool0403ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`240?ooo`030000003oool0oooo00H0oooo8ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo07X0oooo00<0003o0?ooo`3oool0403ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`250?ooo`030000003oool0oooo00D0oooo8ooo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo07/0oooo00<0003o0?oo
o`3oool03`3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`260?oo
o`8000001@3ooolSoonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
ool0O03oool00`000?l0oooo0?ooo`0>0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo08P0oooo00<000000?ooo`3oool00P3ooolSoonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0O@3oool00`000?l0oooo0?ooo`0=0?ooob?ookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08T0oooo00@000000?ooo`3oool0
oooo8ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo07d0oooo
00<0003o0?ooo`3oool03@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`2:0?ooo`030000003oool0oooo02?ookK10_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`1n0?ooo`030000o`3oool0oooo00`0oooo8ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0R`3oool2000002?ookK10_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`1n0?ooo`030000o`3oool0oooo00`0oooo8ooo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0S@3oool00`00003ookK1oonf`@0P
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0OP3oool00`00
0?l0oooo0?ooo`0<0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
08d0oooo00?ookK100000?oo]/408?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo07l0oooo00<0003o0?ooo`3oool02`3ooolSoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`2=0?ooo`;ookK100<00000oonf`Ooo]/407_oo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo07l0oooo00<0003o0?ooo`3oool0
2`3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`?ookK1
00?o0000oonf`Ooo]/407Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0800oooo00<0003o0?ooo`3oool02P3ooolSoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0j0?oooad00000=P3oool4oonf`@0300000?oo]/7ookK101cookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`200?ooo`030000o`3oool0
oooo00X0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0=03oool6
000001d0oooo100000000ol00000oooo0?ooo`0_0?ooo`GookK100<00000oonf`Ooo]/406ooo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0800oooo00<0003o0?oo
o`3oool02P3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0_0?oo
o`@0000000?o00000?ooo`3oool09P3oool6000002/0oooo1_oo]/400`00003o0000oonf`@0Joonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0P@3oool00`000?l0
oooo0?ooo`090?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo02/0
oooo1000000c0?ooo`<00000:03oool8oonf`@0300000?oo]/7ookK101SookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`210?ooo`030000o`3oool0oooo00T0oooo
8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0:03oool3000003X0oooo
1000000T0?ooo`WookK100<00000oonf`Ooo]/405ooo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo0840oooo00<0003o0?ooo`3oool02@3ooolSoonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0W0?ooo`030000003oool0oooo03l0oooo0`00
000Q0?ooo`[ookK100<00000oonf`Ooo]/405_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo0840oooo00<0003o0?ooo`3oool02@3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`0T0?ooo`80000000?o00000?ooo`3oool0@`3oool3
000001h0oooo2ooo]/400`00003ookK1oonf`@0Eoonf`@;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3oool0PP3oool00`000?l0oooo0?ooo`080?ooob?ookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo0240oooo0`00001;0?ooo`030000003oool0oooo
01/0oooo3?oo]/400`00003ookK1oonf`@0Doonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0PP3oool00`000?l0oooo0?ooo`080?ooob?ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo0200oooo00<000000?ooo`3oool0C@3oool3000001X0
oooo3Ooo]/400`00003ookK1oonf`@0Coonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool0PP3oool00`000?l0oooo0?ooo`080?ooob?ookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo01h0oooo0P00001C0?ooo`03o`0000000000000001L0oooo
3_oo]/400`00003ookK1oonf`@0Boonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool0P`3oool00`000?l0oooo0?ooo`070?ooob?ookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0oooo01`0oooo0P00001H0?ooo`030000003oool0oooo01@0oooo3ooo
]/400`00003ookK1oonf`@0Aoonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool0P`3oool00`000?l0oooo0?ooo`070?ooob?ookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo01X0oooo0P00001K0?ooo`<000004`3oool@oonf`@0300000?oo]/7o
okK1013ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`230?oo
o`030000o`3oool0oooo00L0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0603oool200000600oooo00?o00000?ooo`3oool0403ooolAoonf`@8000004?oo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08<0oooo00<0003o0?ooo`3o
ool01`3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0G0?ooo`03
00000?l00000oooo0640oooo0P00000@0?oooa;ookK100<00000oonf`Ooo]/403_oo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08<0oooo00<0003o0?ooo`3oool0
1`3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0E0?ooo`800000
IP3oool00`000000oooo0?ooo`0=0?oooa?ookK100<00000oonf`Ooo]/403Ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08@0oooo00<0003o0?ooo`3oool01P3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0D0?ooo`030000003o
ool0oooo06L0oooo0P00000=0?oooaCookK100<00000oonf`Ooo]/403?oo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08@0oooo00<0003o0?ooo`3oool01P3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0C0?ooo`03o`00003oool0
oooo06X0oooo0P00000;0?oooaGookK100<00000oonf`Ooo]/402ooo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo08@0oooo00<0003o0?ooo`3oool01P3ooolSoonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0B0?ooo`030000003oool0oooo
06d0oooo0P0000090?oooaKookK100<00000oonf`Ooo]/402_oo]/42ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0oooo08@0oooo00<0003o0?ooo`3oool01P3ooolSoonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0@0?ooo`800000<P3ooolF000002X0
oooo0P0000070?oooaOookK100<00000oonf`Ooo]/402Ooo]/42ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo08@0oooo00<0003o0?ooo`3oool01P3ooolSoonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0>0?ooo`800000;03oool8000001H0oooo
2000000T0?ooo`030000003oool0oooo00@0oooo6?oo]/400`00003ookK1oonf`@08oonf`@;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomSoonf`@030000oooo
]/7ookK102SookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00h0oooo00<0
00000?ooo`3oool04@3ooolHoonf`@8000009_oo]/43000002;ookK100<00000oonf`Ooo]/406ooo
]/400ol0003ookK1oonf`@08oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool08P3ooomSoonf`@030000oooo]/7ookK102SookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo00`0oooo0P00000D0?oooaCookK11000000[oonf`@@000007ooo]/40
0`00003ookK1oonf`@0Koonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooof?ookK100<0003ooonf`Ooo]/40:?oo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02`3oool00`000000oooo0?ooo`0D0?oo
oa3ookK11000000coonf`@<000007Ooo]/42000001cookK100<00000oonf`Ooo]/401_oo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooHooo]/400`000?oo
okK1oonf`@0Xoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0:0?ooo`03
0000003oool0oooo01D0oooo3Ooo]/43000003[ookK100Co000000000000000000006ooo]/420000
01_ookK100<00000oonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0280ooooHooo]/400`000?oookK1oonf`@0Xoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`090?ooo`0300000?l00000oooo01H0oooo2_oo]/430000047o
okK10P00000Koonf`@0300000?oo]/7ookK101SookK100<00000oonf`Ooo]/401Ooo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooHooo]/400`000?oookK1
oonf`@0Xoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`080?ooo`030000
003oool0oooo01L0oooo2?oo]/42000004KookK10P00000Joonf`@0300000?oo]/7ookK101SookK1
00<00000oonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo0280ooooHooo]/400`000?oookK1oonf`@0Xoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`070?ooo`030000003oool0oooo01P0oooo1Ooo]/43000004[ookK100?o
000000000?oo]/406?oo]/400ol0003ookK1oonf`@0Hoonf`@03o`000?oo]/7ookK100?ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooof?ookK100<0003o
oonf`Ooo]/40:?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool01P3oool0
0ol00000oooo0?ooo`0I0?ooo`?ookK100<00000o`000?oo]/40C_oo]/400`00003ookK1oonf`@0G
oonf`@0300000?oo]/7ookK101OookK100<00000oonf`Ooo]/400ooo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo3?oo]/43000005CookK100<0003ooonf
`Ooo]/40:?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool01P3oool00`00
0000oooo0?ooo`0I0?ooo`03oonf`@000000000005;ookK10`00000Goonf`@0300000?oo]/7ookK1
01OookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0280oooo2ooo]/45000005?ookK100<0003ooonf`Ooo]/40:?oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`03
00000?oo]/7ookK105GookK100<00000o`000?oo]/405Ooo]/400`00003ookK1oonf`@0Foonf`@03
00000?oo]/7ookK100;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`0R0?ooo`_ookK11@00001Coonf`@030000oooo]/7ookK102SookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo00<0oooo0P00000K0?ooo`0300000?l0003ookK102SookK1
3000000Uoonf`@8000005Ooo]/400ol000000000oonf`@0Foonf`@0400000?l0003ookK1oonf`@;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3oool;oonf`@D00000
Dooo]/400`000?oookK1oonf`@0Xoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`020?ooo`030000003oool0oooo01T0oooo0P0000020?ooob;ookK11`00000<oonf`@L00000
8?oo]/42000001CookK100<00000oonf`Ooo]/405_oo]/400`00003ookK1oonf`@02ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo3?oo]/43000005CookK100<0
003ooonf`Ooo]/40:?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool00P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo6ooo]/47000001[ookK11`00
000Koonf`@0300000?oo]/7ookK101;ookK100<00000oonf`Ooo]/405_oo]/401@00003ookK1oooo
oooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280ooooHooo]/400`000?oookK1oonf
`@0Xoonf`@;ooooo00?o0000ooooooooool03oooool01Ol0003ooooo0?ooo`3oool0000001X0oooo
00<000000?ooo`3oool00`3ooolHoonf`@<00000:?oo]/42000001[ookK100<00000oonf`Ooo]/40
4_oo]/400`00003ookK1oonf`@0Eoonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo
00?o0000ooooo`3oool08P3ooomSoonf`@030000oooo]/7ookK102SookK10_ooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooool0oooo0?ooo`000000603oool2000000H0oooo5?oo]/4300000003
o`000?oo]/7ookK102_ookK100?o00000000000000000P00000Foonf`@8000004ooo]/400`00003o
okK1oonf`@0Eoonf`@0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo0280
ooooHooo]/400`000?oookK1oonf`@0Xoonf`@;ooooo00?o0000ooooooooool03oooool01?l0003o
oooo0?ooo`00000H0?ooo`030000003oool0oooo00H0oooo4Ooo]/43000003KookK10`00000Eoonf
`@8000004_oo]/400`00003ookK1oonf`@0Eoonf`@03o`000?oooooo000000[ooooo0009ooooo`03
o`000?ooool0oooo0280ooooHooo]/400`000?oookK1oonf`@0Xoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0000000H0?ooo`030000003oool0oooo00L0oooo3ooo]/42000003co
okK100<00000oonf`Ooo]/405?oo]/400ol0003ookK1oonf`@0@oonf`@0300000?oo]/7ookK101Co
okK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooof?ookK1
00<0003ooonf`Ooo]/40:?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
5P3oool00`00003o00000?ooo`090?ooo`gookK10P00000ooonf`@0400000?l000000000000001?o
okK100<00000oonf`Ooo]/404?oo]/400ol0003ookK1oonf`@0Coonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomRoonf`@030000oooo]/7ookK102WookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01D0oooo00<000000?ooo`3oool0
2P3oool:oonf`@<00000AOoo]/42000001;ookK100<00000oonf`Ooo]/404?oo]/400`00003ookK1
oonf`@0Boonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3o
oomRoonf`@030000oooo]/7ookK102WookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo01@0oooo00<000000?ooo`3oool02`3oool8oonf`@800000B_oo]/400`00003ookK1oonf
`@0@oonf`@0300000?oo]/7ookK100oookK100<00000oonf`Ooo]/404_oo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooH_oo]/400`000?oookK1oonf`@0Y
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0D0?ooo`030000003oool0
oooo00/0oooo1ooo]/400ol0003ookK1oonf`@0Soonf`@P000008?oo]/400`00003ookK1oonf`@0@
oonf`@0300000?oo]/7ookK100oookK100<00000oonf`Ooo]/404Ooo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooH_oo]/400`000?oookK1oonf`@0Yoonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0C0?ooo`030000003oool0oooo
00`0oooo1_oo]/42000001[ookK12@0000000ol000000000oonf`@07oonf`@L000006_oo]/400ol0
000000000000000@oonf`@8000004?oo]/400ol0003ookK1oonf`@0@oonf`@;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomRoonf`@030000oooo]/7ookK102Wo
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0180oooo00<000000?ooo`3o
ool03@3oool3oonf`@<000006Ooo]/43000001[ookK11`00000Foonf`@8000004?oo]/400`00003o
okK1oonf`@0>oonf`@0300000?oo]/7ookK100oookK10_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003ooooo0?ooo`0R0?ooof;ookK100<0003ooonf`Ooo]/40:Ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool0403oool200000100oooo0_oo]/400`00003ookK1
oonf`@0Foonf`@@000009?oo]/44000001CookK100<00000oonf`Ooo]/403_oo]/400`00003ookK1
oonf`@0>oonf`@0300000?oo]/7ookK100kookK10_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?ooof;ookK100<0003ooonf`Ooo]/40:Ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03oonf`Ol0
003ookK101CookK10P0000000ol000000000oonf`@0[oonf`@8000004ooo]/400`00003ookK1oonf
`@0>oonf`@0300000?oo]/7ookK100kookK100<00000oonf`Ooo]/403Ooo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooH_oo]/400`000?oookK1oonf`@0Y
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0>0?ooo`030000003oool0
oooo0100oooo0P00000Doonf`@800000<_oo]/420000017ookK100?o000000000?oo]/403_oo]/40
0`00003ookK1oonf`@0>oonf`@0300000?oo]/7ookK100gookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooof;ookK100<0003ooonf`Ooo]/40:Ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool03@3oool00`000000oooo0?ooo`0@0?oo
o`030000003ooooookK101;ookK10P00000foonf`@<000004?oo]/42000000kookK100<00000oonf
`Ooo]/403_oo]/400`00003ookK1oonf`@0<oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool08P3ooomRoonf`@030000oooo]/7ookK102WookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo00d0oooo00<000000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0Aoonf`@800000>ooo]/400`00003ookK1oonf`@0?oonf`@0300000?oo]/7ookK100co
okK100<00000oonf`Ooo]/403_oo]/400ol0003ookK1oonf`@0;oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomQoonf`@030000oooo]/7ookK102[ookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00`0oooo00<000000?ooo`3oool0
3P3oool2000000<0oooo3Ooo]/44000003kookK100?o00000000000000003ooo]/400ol000000000
oonf`@0<oonf`@0300000?oo]/7ookK100gookK100<00000oonf`Ooo]/402ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooHOoo]/400`000?oookK1oonf
`@0Zoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0<0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool<oonf`@0300000?oo]/7ookK101kookK12000
000Moonf`@8000003ooo]/400`00003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100gookK100<0
0000oonf`Ooo]/402_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo0280ooooHOoo]/400`000?oookK1oonf`@0Zoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00?o00000?ooo`3oool0103oool:
oonf`@8000006_oo]/47000000SookK11`00000Hoonf`@0300000?oo]/7ookK100gookK100<00000
oonf`Ooo]/402ooo]/400ol0003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100WookK10_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooof7ookK100<0003ooonf
`Ooo]/40:_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02@3oool00ol0
000000000?ooo`0>0?ooo`030000003oool0oooo00D0oooo2?oo]/42000001GookK11`00000Foonf
`@<0000000Co000000000000000000004_oo]/42000000kookK100?o0000oonf`Ooo]/402ooo]/40
0`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100SookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooof3ookK100<0003ooonf`Ooo]/40:ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo1ooo]/400`00003ookK1oonf`@0Boonf`@<000009?oo]/430000
017ookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@0;oonf`@0300000?oo]/7ookK1
00gookK100<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0280ooooH?oo]/400`000?oookK1oonf`@0[oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01P3oool6oonf`@0300000?oo]/7ookK1017ookK10P00000Zoonf`@0300000?oo]/7ookK100oo
okK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100co
okK100<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0oooo0280oooo?Ooo]/4?0000o`04o`00o`000?l0003o0000o`oookK100?o003o0000oooo
]/40;?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`8000002@3oool5oonf`@0300000?oo]/7ookK1013ookK10P00000]oonf`@<0
00003ooo]/400`00003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100_ookK100?o0000oonf`Ooo
]/403?oo]/400`00003ookK1oonf`@07oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool08P3ooolioonf`@@0003o4ooo]/450000o`[ookK100<0003ooonf`Ooo]/40
;?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool01P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00T0oooo0ooo]/420000013ookK10`00000boonf`@03o`00
00000000000000gookK100?o000000000?oo]/402ooo]/400ol0003ookK1oonf`@0;oonf`@030000
0?oo]/7ookK100cookK100<00000oonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo05P0oooo0`000?lL0?ooo`<0003o1`3oool00`000?l0oooo0?oo
o`090?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00H0oooo00?o
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo0P00
000h0?ooo`030000003oool0oooo00`0oooo0P00000;0?ooo`030000003ooooookK100[ookK100<0
0000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@06oonf`@;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool0EP3oool20000ob80oooo0`000?l30?ooo`030000o`3oool0
oooo00X0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool01@3oool0
0`000000oooo0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool2
000003/0oooo0P00000>0?ooo`030000003oool0oooo00T0oooo00<00000oonf`Ooo]/402_oo]/40
0`00003ookK1oonf`@0<oonf`@0300000?oo]/7ookK100GookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`1D0?ooo`80003o9`3oool01?l00?l0oooo0?ooo`000?l<
0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo0P00000G
0?oooa00000000?o00000?ooo`3oool05@3oool2000000d0oooo00<000000?ooo`3oool02@3oool0
0`00003ookK1oonf`@0:oonf`@03o`000?oo]/7ookK100cookK100?o0000oonf`Ooo]/401?oo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0580oooo0P000?lZ0?oo
o`<0003o303ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`040?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`0300000?l00000oooo0180oooo1@0000000ol00000oooo0?ooo`0?0?ooo`L000004P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000oonf`Ooo]/402ooo]/400`00
003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100CookK10_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?ooo`1?0?ooo`<0003o;P3oool00`000?l0oooo0?ooo`0:0?ooob?o
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0403oool3000001h0oooo0`00000@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0203oool00ooo]/400000oonf`@0;oonf`@0300000?oo]/7ookK100_ookK100<00000oonf`Ooo
]/401?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo04h0oooo
00<0003o0?ooo`3oool0;P3oool010000?l0oooo0000o`000?l:0?ooob?ookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`03o`00003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool3000002@0
oooo00<00000o`00003oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo0_oo]/400`00003ookK1oonf`@0:oonf`@0300000?oo]/7ookK100_ookK100<00000oonf`Ooo
]/400ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo04d0oooo
00<0003o0?ooo`3oool0;`3oool010000?l0oooo0?ooo`3oool20000o`P0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool00P3oool00ol00000oooo0?ooo`0;0?ooo`03
00000?l00000oooo00/0oooo00<000000?ooo`3oool02P3oool00`00003o00000?ooo`0>0?ooo`80
0000:@3oool2000000h0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0ooo]/400`00003o
okK1oonf`@09oonf`@0300000?oo]/7ookK100_ookK100<00000oonf`Ooo]/400ooo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo04/0oooo0P000?la0?ooo`030000
o`3oool0oooo00@0oooo00?o003o0?ooo`3oool01@3ooolSoonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0P00000]0?ooo`800000
3P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0ooo]/400`00003ookK1
oonf`@09oonf`@0300000?oo]/7ookK100_ookK100<00000oonf`Ooo]/400ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo04X0oooo00<0003o0?ooo`3oool0<@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo8ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00Go0000ooooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool2000000l0oooo00<000000?ooo`3oool0;`3oool2000000d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`CookK100<00000oonf`Ooo]/40
2Ooo]/400`00003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100;ookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`190?ooo`030000o`3oool0oooo0380oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooob?ookK10_ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooool0oooo000000d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00`0oooo0`00000d0?ooo`03o`0000000000oooo00/0oooo
00<000000?ooo`3oool02@3oool00ol00000oooo0?ooo`030?ooo`GookK100<00000oonf`Ooo]/40
2Ooo]/400ol0003ookK1oonf`@0;oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool0B03oool00`000?l0oooo0?ooo`0b0?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3ooolSoonf`@;ooooo00?o0000ooooooooool0
3oooool01?l0003ooooo0?ooo`00000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo2000000H0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`Go
okK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@0;oonf`@0400000?oo]/7ookK1oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0=@3oool:o`00o`P0
oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo0?oo
ob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00000C0?oo
o`L00000203oool700000180oooo0P00000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool6oonf`@0300000?oo]/7ookK100SookK100<00000oonf`Ooo]/402ooo]/401000
003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
0300oooo1Ol00?l:0?ooo`So003o=@3oool00ol00?l0oooo0?ooo`0;0?ooo`03o`00o`000?l0oooo
02?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool4000001H0oooo1000000@0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`3oool7oonf`@0300000?oo]/7ookK100SookK100<00000
oonf`Ooo]/402_oo]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo02d0oooo0ol00?lE0?ooo`04o`00o`3ooooo003oo`00oc<0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooooonf`@0Roonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`03o`0000000000oooo00h0oooo0`00000N0?ooo`8000003`3o
ool00ol00000oooo0?ooo`080?ooo`03o`0000000000oooo00T0oooo00?o00000?ooo`3oool01ooo
]/400ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100[ookK100<00000oonf`Ooo]/400_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0Z0?ooo`?o003o603oool0
10000?l0oooo0?ooo`3oool4o`00obh0oooo00<0003o0?ooo`3oool03P3oool00`000?oookK1oonf
`@0Qoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00`0oooo0`00000S0?ooo`8000003P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01ooo]/400`00003ookK1oonf`@09oonf`@0300000?oo
]/7ookK100[ookK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003ooooo0?ooo`0X0?ooo`;o003o6P3oool00`000?l0oooo0?ooo`060?ooo`?o003o:`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030000oooo]/7ookK1023ookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool2000002P0oooo0P00000=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooooonf`@07
oonf`@0300000?oo]/7ookK100SookK100<00000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@02
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo02H0oooo0_l00?lK0?oo
o`030000o`3oool0oooo00X0oooo00?o003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0?0?oo
o`030000oooo]/7ookK1023ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003ooooookK1
00OookK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@0:oonf`@0500000?oo]/7ooooo
ooooool000002_ooool000Wooooo00?o0000ooooo`3oool08`3oool3o`00oa`0oooo00<0003o0?oo
o`3oool0303oool2o`00obL0oooo00<0003o0?ooo`3oool0403oool00ooo]/7o003ooonf`@0Poonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03o`00003oool0oooo
00/0oooo00<00000o`00003oool0;03oool2000000`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/402?oo]/400ol0
003ookK1oonf`@0:oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000oooo
o`3oool08P3oool00ol00?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00h0oooo0_l00?lT0?oo
o`030000o`3oool0oooo0140oooo0_oo]/400`000?oookK1oonf`@0Noonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo0`00000a0?oo
o`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00?o0000oonf
`Ooo]/401_oo]/400`00003ookK1oonf`@09oonf`@0300000?oo]/7ookK100WookK100D00000oonf
`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0Q0?ooo`03o`00o`3oool0oooo
01d0oooo00<0003o0?ooo`3oool04@3oool00ol00?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo
0180oooo0_oo]/400`000?oookK1oonf`@0Noonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00?o00000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool80000
01H0oooo00?o00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK1
00[ookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool07`3oool2o`00
oal0oooo00<0003o0?ooo`3oool04`3oool00ol00?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo
0180oooo0ooo]/400`000?oookK1oonf`@0Moonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00ol0
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`00
003o000000000004000000P0oooo0`0000000ol0000000000000000A0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03oonf`@00003ookK1
00SookK100?o0000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@0:oonf`@0400000?oooooooooo
o`0000[ooooo0009ooooo`03o`000?ooool0oooo01d0oooo0_l00?lP0?ooo`03o`00o`3oool0oooo
01D0oooo0_l00?lN0?ooo`030000o`3oool0oooo01<0oooo1?oo]/400`000?oookK1oonf`@0Loonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00?o00000?ooo`3oool03P3oool3000001D0oooo0P00000@0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03oonf`@00003ookK1
00SookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@0:oonf`@0400000?oooooooooo
o`0000[ooooo0009ooooo`03o`000?ooool0oooo01`0oooo00?o003o0?ooo`3oool0803oool00`00
0?l0oooo0?ooo`0G0?ooo`03o`00o`3oool0oooo01/0oooo00<0003o0?ooo`3oool04`3oool4oonf
`@030000oooo]/7ookK101cookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`8000006P3oool30000
00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00?ookK100000?oo]/402?oo]/400`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK1
00[ookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool06`3oool00`000?l0
oooo0?ooo`0P0?ooo`030000o`3oool0oooo01T0oooo00?o003o0?ooo`3oool06@3oool00`000?l0
oooo0?ooo`0D0?ooo`GookK100<0003ooonf`Ooo]/406ooo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool07@3oool00ol00000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00ol00000oooo0?ooo`040?ooo`;ookK100<00000oonf`Ooo
]/401ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100[ookK100<00000ooooool0
00002_ooool000Wooooo00?o0000ooooo`3oool06P3oool00`000?l0oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo01X0oooo00?o003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0E0?ooo`KookK1
00<0003ooonf`Ooo]/406_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00?o00000000003oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<00000o`00003oool0
803oool2000000`0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool2oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1
oonf`@09oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool06@3o
ool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo01/0oooo00?o003o0?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0F0?ooo`KookK100<0003ooonf`Ooo]/406_oo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03o`00003o
ool0oooo00/0oooo0P00000U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0_oo]/400`00003ookK1oonf
`@07oonf`@0300000?oo]/7ookK100SookK100<00000oonf`Ooo]/402Ooo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01P0oooo00<0003o0?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`0M0?ooo`03o`00o`3oool0oooo01<0oooo00<0003oo`00o`3oool05`3oool7
oonf`@030000oooo]/7ookK101WookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo00H0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`800000:03oool2
000000`0oooo00?o00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo0ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK100<00000
oonf`Ooo]/402Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
01L0oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0N0?ooo`03o`00o`3oool0oooo
0180oooo00<0003o0?ooo`3oool05`3oool7oonf`@030000oooo]/7ookK101WookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool4oonf
`@03o`000?oo]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@09oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool05P3oool00`000?l0
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0200oooo00?o003o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0H0?ooo`SookK100<0003ooonf`Ooo]/406?oo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`CookK100<00000oonf`Ooo
]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100WookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0F0?ooo`030000o`3oool0oooo02<0oooo
00<0003o0?ooo`3oool08@3oool00ol00?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo01T0oooo
2?oo]/400`000?oookK1oonf`@0Hoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo1?oo]/400`00003ookK1oonf`@07oonf`@030000
0?oo]/7ookK100KookK100<00000oonf`Ooo]/402Ooo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo01D0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?oo
o`0R0?ooo`03o`00o`3oool0oooo00d0oooo00<0003o0?ooo`3oool06@3oool8oonf`@030000oooo
]/7ookK101SookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo1?l0
000G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo0?ooo`GookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1
oonf`@07oonf`@0300000?oo]/7ookK100SookK10_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`0D0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool08`3o
ool00ol00?l0oooo0?ooo`0;0?ooo`03o`00o`000?l0oooo01/0oooo2Ooo]/400`000?oookK1oonf
`@0Goonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00ol0000000000?ooo`0A0?ooo`Co0000103o
ool6o`000180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo1Ooo]/400`00003ookK1oonf`@06oonf`@03o`00
0?oo]/7ookK100OookK100?o0000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo01@0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?oo
o`0S0?ooo`03o`00o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0703oool9oonf`@030000oooo
]/7ookK101OookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03o`00003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo0ol0
000>0?ooo`;o00004@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`3oool5oonf`@0300000?oo]/7ookK100KookK1
00<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@08oonf`@;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3oool04`3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo02@0oooo00?o003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0M0?ooo`WookK100<0
003ooonf`Ooo]/405ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3o
ool00ol00000oooo0?ooo`0A0?ooo`?o00003`3oool00ol00000oooo0?ooo`070?ooo`03o`00003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05oonf`@0300000?oo
]/7ookK100OookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@08oonf`@;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool04`3oool00`000?l0oooo0?ooo`0T
0?ooo`030000o`3oool0oooo02H0oooo00?o003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0N
0?ooo`[ookK100<0003ooonf`Ooo]/405_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0303oool3o`0001L0oooo00?o00000?ooo`3oool0303oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@07
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool04@3oool00`00
0?oo003o0?ooo`0>0?oooaSookK100<0003ooonf`Ooo]/409ooo]/400ol00?oookK1oonf`@04oonf
`@030000oooo]/7ookK102WookK100<0003ooonf`Ooo]/405_oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooooonf`@06oonf`@03o`000?oo]/7ookK1
00SookK100?o0000oonf`Ooo]/403?oo]/400ol0003ookK1oonf`@0Ioonf`@03o`000?oo]/7ookK1
00_ookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK1
00KookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK1
00OookK100<00000oonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo0140oooo00<0003o0?ooo`3oool03P3ooolHoonf`@030000oooo]/7ookK102Oo
okK100?o003ooonf`Ooo]/400ooo]/400ol00?oookK1oonf`@0Zoonf`@030000oooo]/7ookK101Ko
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oooooo
]/401_oo]/400`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100_ookK100?o0000oonf`Ooo
]/406ooo]/400ol0003ookK1oonf`@0;oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo
]/401ooo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo
]/401ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo
6?oo]/400`000?oookK1oonf`@0Xoonf`@05o`00oooo]/7ookK1oonf`@000?l0;Ooo]/400`000?oo
okK1oonf`@0Foonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00KookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@0;oonf`@03
o`000?oo]/7ookK101gookK100?o0000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@08oonf`@03
00000?oo]/7ookK100KookK100?o0000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@03
00000?oo]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@07oonf`@;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0403oool00`000?l0oooo
0?ooo`0?0?oooaOookK100<0003ooonf`Ooo]/40:Ooo]/401?l00?oookK1oonf`@000?l_oonf`@03
0000oooo]/7ookK101GookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100_o
okK100?o0000oonf`Ooo]/407ooo]/400ol0003ookK1oonf`@0:oonf`@0300000?oo]/7ookK100Oo
okK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Go
okK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100Oo
okK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0@0?ooo`030000
o`3oool0oooo00l0oooo5ooo]/400`000?oookK1oonf`@0Yoonf`@03o`00oooo]/40003o033ookK1
00<0003ooonf`Ooo]/405Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`06oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/40
2ooo]/400ol0003ookK1oonf`@0Ooonf`@03o`000?oo]/7ookK100[ookK100<00000oonf`Ooo]/40
1ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/40
1Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/40
1ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00l0oooo00<0
003o0?ooo`3oool0403ooolGoonf`@030000oooo]/7ookK102WookK100?o003o0000oooo]/40<?oo
]/400`000?oookK1oonf`@0Eoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo0?ooo`GookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1
oonf`@0;oonf`@03o`000?oo]/7ookK1027ookK100?o0000oonf`Ooo]/402_oo]/400`00003ookK1
oonf`@07oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1
oonf`@05oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1
oonf`@07oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool03`3o
ool00`000?l0oooo0?ooo`0@0?oooaOookK100<0003ooonf`Ooo]/40:?oo]/400`000?oookK1o`00
o`0aoonf`@030000oooo]/7ookK101GookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo1Ooo]/400`00003ookK1oonf`@07oonf`@030000
0?oo]/7ookK100[ookK100?o0000oonf`Ooo]/408ooo]/400ol0003ookK1oonf`@09oonf`@030000
0?oo]/7ookK100OookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@030000
0?oo]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@030000
0?oo]/7ookK100OookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`0>0?ooo`030000o`3oool0oooo0140oooo5ooo]/400`000?oookK1oonf`@0Woonf`@050000oooo
]/7ookK1oonf`Ol00?l0<?oo]/400`000?oookK1oonf`@0Eoonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`GookK100<00000oonf`Ooo
]/401_oo]/400ol0003ookK1oonf`@0;oonf`@03o`000?oo]/7ookK102?ookK100?o0000oonf`Ooo
]/402Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo
]/401Ooo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo
]/401ooo]/400`00003ookK1oonf`@07oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool03P3oool00`000?l0oooo0?ooo`0A0?oooaOookK100<0003ooonf`Ooo]/40
9_oo]/400`000?oookK1oonf`@02oonf`@<00000;_oo]/400`000?oookK1oonf`@0Eoonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`Go
okK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@0:oonf`@03o`000?oo]/7ookK102Co
okK100?o0000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@07oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool03@3oool00`000?l0oooo0?ooo`0B0?oooaOookK1
00<0003ooonf`Ooo]/408ooo]/400`000?oo003o0000o`04oonf`@D00000;Ooo]/400`000?oookK1
oonf`@0Eoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo1?oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100[ookK1
00?o0000oonf`Ooo]/409Ooo]/400ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100KookK1
00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100KookK1
00<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK1
0_ooool00ol0003oooooooooo`08ooooo`002Oooool01?l0003ooooo0000o`000?l<0?ooo`030000
o`3oool0oooo0180oooo5ooo]/400`000?oookK1oonf`@0Roonf`@030000oooo]/7ookK100GookK1
1@00000]oonf`@030000oooo]/7ookK101GookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool4oonf`@0300000?oo]/7ookK100OookK1
00<00000oonf`Ooo]/402Ooo]/400ol0003ookK1oonf`@0Voonf`@03o`000?oo]/7ookK100WookK1
00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100OookK1
00<00000oonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`04o`000?oo
ool0oooo0?ooo`80003o2P3oool00`000?l0oooo0?ooo`0B0?oooaOookK100<0003ooonf`Ooo]/40
8Ooo]/400`000?oookK1oonf`@06oonf`@D00000;Ooo]/400`000?oookK1oonf`@0Eoonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
1?oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100WookK100?o0000oonf`Ooo]/40
9_oo]/400ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/40
1_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/40
1Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool04P3ooolGoonf`@030000oooo]/7ookK101oookK10P000?l:oonf`@<00000;_oo
]/400`000?oookK1oonf`@0Eoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo1?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100WookK100?o0000oonf`Ooo]/409ooo]/400ol0003ookK1oonf`@09oonf`@0300000?oo
]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo
]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo
]/7ookK100OookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`04
0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0C0?oooaOookK100<0003ooonf`Ooo]/407Ooo]/42
0000o`kookK100?o003ooonf`Ooo]/40;?oo]/400`000?oookK1oonf`@0Eoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo1?oo]/40
0ol0003ookK1oonf`@06oonf`@0300000?oo]/7ookK100WookK100?o0000oonf`Ooo]/409ooo]/40
0ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/40
0`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/40
0`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`060?ooo`80003o103oool00`000?l0oooo0?ooo`0C0?oo
oaOookK100<0003ooonf`Ooo]/407?oo]/400`000?oookK1oonf`@0>oonf`@03o`00oooo]/7ookK1
02cookK100<0003ooonf`Ooo]/405Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`CookK100<00000oonf`Ooo]/401_oo]/400`00
003ookK1oonf`@09oonf`@03o`000?oo]/7ookK102OookK100?o0000oonf`Ooo]/402Ooo]/400`00
003ookK1oonf`@06oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401Ooo]/400`00
003ookK1oonf`@05oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00
003ookK1oonf`@07oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
ool0203oool20000o`80oooo00<0003o0?ooo`3oool04`3ooolGoonf`@030000oooo]/7ookK101[o
okK100<0003oo`00oooo]/404?oo]/400ol00?oookK1oonf`@0/oonf`@030000oooo]/7ookK101Go
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool4oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/402Ooo]/400ol0003o
okK1oonf`@0Woonf`@03o`000?oo]/7ookK100WookK100<00000oonf`Ooo]/401_oo]/400`00003o
okK1oonf`@06oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/401Ooo]/400`00003o
okK1oonf`@06oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/401ooo]/42ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo00X0oooo0`000?lE0?oooaOookK1
00<0003ooonf`Ooo]/406?oo]/420000oa?ookK100?o003ooonf`Ooo]/40;?oo]/400`000?oookK1
oonf`@0Eoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo1?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100WookK1
00?o0000oonf`Ooo]/409ooo]/400ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100KookK1
00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK1
0_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0;0?ooo`040000o`3o
ool0003o0000oa<0oooo5ooo]/400`000?oookK1oonf`@0Foonf`@80003o5_oo]/400ol00?oookK1
oonf`@0Zoonf`@030000oooo]/7ookK101KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool4oonf`@0300000?oo]/7ookK100KookK1
00<00000oonf`Ooo]/402Ooo]/400ol0003ookK1oonf`@0Woonf`@03o`000?oo]/7ookK100WookK1
00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100GookK1
00<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100OookK1
00<00000oonf`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo00/0oooo00D0003o0?ooo`3oool0oooo0000o`0B0?oooaOookK100<0003ooonf`Ooo]/40
4ooo]/430000oaSookK100?o003ooonf`Ooo]/40:_oo]/400`000?oookK1oonf`@0Foonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
1?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100WookK100?o0000oonf`Ooo]/40
9ooo]/400ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/40
1_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/40
1_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK10_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo1000
0?l>0?oooaOookK100<0003ooonf`Ooo]/404?oo]/430000oa_ookK100?o003ooonf`Ooo]/40:_oo
]/400`000?oookK1oonf`@0Foonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo1?oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100WookK100?o0000oonf`Ooo]/409ooo]/400ol0003ookK1oonf`@08oonf`@0300000?oo
]/7ookK100OookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100SookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0;
0?ooo`030000o`3oool0oooo00H0oooo0P000?l<0?oooaOookK100<0003ooonf`Ooo]/403?oo]/44
0000oakookK100?o003ooonf`Ooo]/40:_oo]/400`000?oookK1oonf`@0Foonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo1?oo]/40
0`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100WookK100?o0000oonf`Ooo]/409Ooo]/40
0ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/40
0ol0003ookK1oonf`@05oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401Ooo]/40
0`00003ookK1oonf`@07oonf`@03o`000?oo]/7ookK100SookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo10000?l80?oo
oaSookK100<0003ooonf`Ooo]/402Ooo]/420000ob;ookK100?o003ooonf`Ooo]/40:_oo]/400`00
0?oookK1oonf`@0Foonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?oo
o`03o`00003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo1?oo]/400ol0003ookK1oonf`@07oonf`@0300000?oo]/7ookK1
00WookK100?o0000oonf`Ooo]/409Ooo]/400ol0003ookK1oonf`@09oonf`@0300000?oo]/7ookK1
00KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK1
00KookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK1
00SookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo1@000?l30?oooaOookK10`000007oonf`@<0003o9?oo]/400ol00?oo
okK1oonf`@0Yoonf`@030000oooo]/7ookK101OookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool4oonf`@0300000?oo]/7ookK100Oo
okK100<00000oonf`Ooo]/402Ooo]/400ol0003ookK1oonf`@0Toonf`@03o`000?oo]/7ookK100[o
okK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Go
okK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100Oo
okK100<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0oooo00/0oooo00<0003o0?ooo`3oool04@3oool00`000?oo003o0000o`020000oaCookK1
1@0000060000obOookK100?o003ooonf`Ooo]/40:Ooo]/400`000?oookK1oonf`@0Goonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`Go
okK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@0:oonf`@03o`000?oo]/7ookK102;o
okK100?o0000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@08oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool02`3oool00`000?l0oooo0?ooo`0D0?ooo`;ookK1
2@000?l8oonf`@<0003o1@00000]oonf`@03o`00oooo]/7ookK102WookK100<0003ooonf`Ooo]/40
5ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool010000000oooo
0?ooo`3oool5oonf`@0300000?oo]/7ookK100KookK10P00000<oonf`@03o`000?oo]/7ookK1023o
okK100?o0000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401Ooo]/400ol0003ookK1oonf`@06oonf`@0300000?oo]/7ookK100Ko
okK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@08oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool02`3oool00`000?l0oooo0?ooo`0D0?ooo`_ookK1
20000?l3oonf`@D00000;Ooo]/400ol00?oookK1oonf`@0Xoonf`@030000oooo]/7ookK101SookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
oooo1Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100_ookK100?o0000oonf`Ooo
]/408?oo]/400ol0003ookK1oonf`@0:oonf`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo
]/401_oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo
]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100SookK10_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0;0?ooo`030000o`3oool0oooo01@0oooo
5ooo]/43000000030000oooo]/7ookK102_ookK100?o003ooonf`Ooo]/40:?oo]/400`000?oookK1
oonf`@0Hoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo0?ooo`GookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@0;oonf`@03
o`000?oo]/7ookK101kookK100?o0000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@07oonf`@03
00000?oo]/7ookK100OookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@03
00000?oo]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@08oonf`@03
00000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo00/0oooo00<0003o0?ooo`3oool0
503ooolJoonf`@030000oooo]/7ookK102_ookK100?o003ooonf`Ooo]/40:?oo]/400`000?oookK1
oonf`@0Hoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo0?ooo`KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@0;oonf`@03
o`000?oo]/7ookK101gookK100?o0000oonf`Ooo]/402ooo]/400ol0003ookK1oonf`@07oonf`@03
00000?oo]/7ookK100KookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@06oonf`@03
00000?oo]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@09oonf`@03
00000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo00/0oooo00<0003o0?ooo`3oool0
503ooolJoonf`@030000oooo]/7ookK102_ookK100?o003ooonf`Ooo]/409ooo]/400ol00?oookK1
oonf`@0Ioonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00?o00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo0?ooo`KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@0;oonf`@;o
00006ooo]/42o`0000kookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@06oonf`@03
00000?oo]/7ookK100GookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@03
00000?oo]/7ookK100OookK100<00000oonf`Ooo]/402Ooo]/400`00003oooooo`00000:ooooo`00
2Oooool00ol0003ooooo0?ooo`0;0?ooo`030000o`3oool0oooo01@0oooo6_oo]/400`000?oookK1
oonf`@0[oonf`@03o`00oooo]/7ookK102OookK100<0003ooonf`Ooo]/406Ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00ol00000oooo0?ooo`06oonf`@030000
0?oo]/7ookK100OookK100<00000oonf`Ooo]/403Ooo]/42o`0001SookK100?o0000oonf`Ooo]/40
3Ooo]/400`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/40
1_oo]/400`00003ookK1oonf`@05oonf`@03o`000?oo]/7ookK100OookK100<00000oonf`Ooo]/40
1ooo]/400`00003ookK1oonf`@09oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?oo
ool0oooo00/0oooo00<0003o0?ooo`3oool0503ooolKoonf`@030000oooo]/7ookK102[ookK100?o
003ooonf`Ooo]/409ooo]/400`000?oookK1oonf`@0Ioonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00OookK100<00000oonf`Ooo]/401ooo
]/400`00003ookK1oonf`@0>oonf`@03o`000?oo]/7ookK101?ookK10_l0000?oonf`@0300000?oo
]/7ookK100SookK100<00000oonf`Ooo]/401Ooo]/400ol0003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo
]/7ookK100WookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0303o
ool00`000?l0oooo0?ooo`0C0?oooa_ookK100<0003ooonf`Ooo]/40:Ooo]/400ol00?oookK1oonf
`@0Woonf`@030000oooo]/7ookK101[ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?oooooo]/401_oo]/400`00003ookK1oonf`@08oonf`@0300000?oo
]/7ookK100kookK10ol0000@oonf`@;o00004?oo]/400ol0003ookK1oonf`@08oonf`@0300000?oo
]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100KookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@09oonf`@0400000?oo
ooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo00`0oooo00<0003o0?ooo`3oool04`3o
oolKoonf`@030000oooo]/7ookK102WookK100?o003ooonf`Ooo]/409ooo]/400`000?oookK1oonf
`@0Joonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
oooookK100KookK100?o0000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@0Aoonf`@03o`000?oo
]/7ookK100_ookK10_l0000Aoonf`@0300000?oo]/7ookK100WookK100<00000oonf`Ooo]/401_oo
]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401_oo
]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100WookK100@00000oooooooooooo0000
2_ooool000Wooooo00?o0000ooooo`3oool0303oool00`000?l0oooo0?ooo`0C0?oooacookK100<0
003ooonf`Ooo]/40:?oo]/400ol00?oookK1oonf`@0Voonf`@030000oooo]/7ookK101_ookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oooooo]/401_oo
]/400`00003ookK1oonf`@09oonf`@0300000?oo]/7ookK1017ookK13Ol0000Boonf`@0300000?oo
]/7ookK100WookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo
]/7ookK100[ookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0303o
ool00`000?l0oooo0?ooo`0C0?oooacookK100<0003ooonf`Ooo]/40:?oo]/400ol00?oookK1oonf
`@0Voonf`@030000oooo]/7ookK101_ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@09oonf`@0300000?oo
]/7ookK102kookK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo
]/7ookK100KookK100?o0000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@06oonf`@0300000?oo
]/7ookK100OookK100?o0000oonf`Ooo]/402Ooo]/401@00003ookK1oooooooooooo000000[ooooo
0009ooooo`03o`000?ooool0oooo00`0oooo00<0003o0?ooo`3oool04`3ooolMoonf`@030000oooo
]/7ookK102OookK100?o003ooonf`Ooo]/409Ooo]/400`000?oookK1oonf`@0Loonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00ol00000oooo0?ooo`060?ooo`0300000?oo]/7ookK100OookK100<0
0000oonf`Ooo]/402Ooo]/400`00003o0000oonf`@0[oonf`@8000002ooo]/400`00003ookK1oonf
`@07oonf`@03o`000?oo]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf
`@06oonf`@0300000?oo]/7ookK100SookK100<00000oonf`Ooo]/402Ooo]/401@00003ookK1oooo
oooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo00d0oooo00<0003o0?ooo`3oool0<03o
ool00`000?l0oooo0?ooo`0U0?ooo`03o`00o`3oool0oooo0280oooo0ooo]/400`000?oookK1oonf
`@0Moonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00?ookK100000?oo]/401ooo]/400`00003ookK1oonf`@08oonf`@0300000?oo
]/7ookK100WookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?oo
o`0=0?ooo`030000o`3oool0oooo0340oooo00?o003o0?ooo`3oool0903oool00ol00?l0oooo0?oo
o`0R0?ooo`;ookK100<0003ooonf`Ooo]/407_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3oool01P3oool00ol00000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`0300000?oo]/7ookK100KookK100<0
0000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@09oonf`@0300000?oo]/7ookK100;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool03@3oool00`000?l0oooo0?ooo`0a
0?ooo`030000o`3oool0oooo02@0oooo00?o003o0?ooo`3oool08P3oool2oonf`@030000oooo]/7o
okK101kookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00ol00000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00?o0000
0?ooo`3oool0203oool00ol00000oooo0?ooo`0:0?ooo`800000903oool2000000`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00?o0000
oonf`Ooo]/401ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100WookK100@00000
o`000?oo]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0>
0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool08`3oool00ol00?l0oooo0?ooo`0R
0?ooo`03oonf`@000?oookK1023ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`8000008@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/401ooo]/40
0`00003ookK1oonf`@09oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool03P3oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0
oooo0240oooo00?o003o0?ooo`3oool08`3oool00`000?oookK1oonf`@0Poonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool2000001d0oooo0P00000>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003ooooookK100OookK100<00000
oonf`Ooo]/402?oo]/400`00003ookK1oonf`@09oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool03P3oool00`000?l0oooo0?ooo`0c
0?ooo`030000o`3oool0oooo0200oooo00?o003o0?ooo`3oool08`3oool00`000?oookK1oonf`@0P
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`8000003P3oool2
000000T0oooo00?o00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003ooooo
okK100OookK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@09oonf`@0300000?oo]/7o
okK100;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0?0?oo
o`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool07`3oool00ol00?l0oooo0?ooo`0R0?oo
o`03o`00oooo]/7ookK1027ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03o`00003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00ol0000000000?ooo`0>0?ooo`<00000503oool20000
0003o`00003oool0oooo00`0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0P0000080?oo
o`030000003oool0oooo00OookK100<00000oonf`Ooo]/401ooo]/400`00003o0000oonf`@0:oonf
`@0300000?oo]/7ookK100;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?ooo`0?0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool07`3oool00ol00?l0
oooo0?ooo`0Q0?ooo`030000o`3ooooookK102;ookK10_ooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`@0
00002@3oool7000000l0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool01?l00000oooo0?ooo`3oool7oonf`@0300000?oo]/7ookK100OookK100<00000oonf
`Ooo]/402_oo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0403oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo01d0
oooo00?o003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Soonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool04P3oool9000001D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`03
o`00003oool0oooo00P0oooo00@000000?ooo`3oool0oooo1_oo]/400`00003ookK1oonf`@07oonf
`@0300000?oo]/7ookK100[ookK100<00000oonf`Ooo]/400ooo]/42ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0oooo0100oooo00<0003o0?ooo`3oool0=03oool00`000?l0
oooo0?ooo`0K0?ooo`03o`00o`3oool0oooo0240oooo00@0003o0?ooo`3oool0oooo8ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool02@3oool00ol0000000000?ooo`080?oo
o`03o`00003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`03o`0000000000oooo02h0oooo00?o00000?ooo`3oool02P3oool00`00003o00000?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool5oonf`@0300000?oo]/7ookK1
00SookK100<00000oonf`Ooo]/402Ooo]/400ol0003ookK1oonf`@04oonf`@;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool0403oool00`000?l0oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo01X0oooo00?o003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooob?o
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`03o`00003oool0oooo00L0oooo00?o00000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0[0?ooo`8000002`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool5oonf`@0300000?oo]/7ookK100So
okK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@04oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool04@3oool00ol00?l0oooo0?ooo`0e0?ooo`030000
ool00?l0003o01P0oooo00?o003o0?ooo`3oool07P3oool20000o`03o`00o`3oool0oooo00<0oooo
8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000002P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0;0?ooo`<00000:03oool2000000`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo1?oo]/400`00003ookK1oonf`@08oonf`@030000
0?oo]/7ookK100[ookK100<00000oonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?ooool0oooo0180oooo00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?oo
o`0E0?ooo`03o`00o`3oool0oooo01d0oooo00<0003o0?ooo`3oool01P3ooolSoonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003oooooo`00000;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool08`3oool2000000d0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo0ooo]/400`00003ookK1oonf`@09oonf`@0300000?oo
]/7ookK100WookK100<00000oonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo0180oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?ooo`0C
0?ooo`03o`00o`3oool0oooo01d0oooo00<0003o0?ooo`3oool01`3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool01?l0003ooooo0?ooool0000:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`0300000?l00000oooo00d0oooo00?o
00000000000000007P3oool4000000d0oooo0P00000:0?ooo`030000003oool0oooo00P0oooo00?o
00000?ooo`3oool01@3oool2oonf`@03o`000?oo]/7ookK100WookK100<00000oonf`Ooo]/402_oo
]/400`00003ookK1oonf`@05oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool04`3oool00`000?l0oooo0?ooo`0h0?ooo`80003o4P3oool00ol00?l0oooo0?ooo`0M
0?ooo`030000o`3oool0oooo00P0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooo`3ooooo00002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`<000005`3oool4000000l0oooo0P00
000;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool2oonf`@0300000?oo
]/7ookK100SookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@05oonf`@;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0503oool00`000?l0oooo0?ooo`0i
0?ooo`80003o3`3oool00ol00?l0oooo0?ooo`0K0?ooo`80003o00?o003o0?ooo`3oool02@3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool01Ol0003ooooo0?ooo`3ooooo000000/0oooo00?o
00000?ooo`3oool0203oool00ol00000oooo0?ooo`070?ooo`8000002`3oool00`000000oooo0?oo
o`0@0?ooo`<000004@3oool300000140oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00ooo]/400000oonf`@09oonf`@0300000?oo]/7ookK100_ookK100<0
0000oonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0
oooo01@0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0<0?ooo`03o`00o`3oool0
oooo01X0oooo00<0003o0?ooo`3oool0303ooolSoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`020?ooo`03o`00003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000o`00000000004P3ooolA
00000180oooo0P00000<0?ooo`0300000?l00000oooo00T0oooo00<000000?ooo`3oool0203oool0
0`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100_ookK100?o0000oonf`Ooo]/401ooo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01D0oooo00<0003o0?oo
o`3oool0>`3oool20000o``0oooo00?o003o0?ooo`3oool0603oool20000o`l0oooo8ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool00P3oool00ol00000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00?o0000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@0:oonf
`@0300000?oo]/7ookK100SookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?ooo`0F0?ooo`030000o`3oool0oooo03`0oooo0P000?l90?ooo`03o`00o`3oool0oooo01H0
oooo0`000?lA0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0080
oooo00?o00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool2000002l0oooo0P00000=0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`00003ookK1oonf`@08oonf`@0300000?oo]/7ookK100_o
okK100<00000oonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0oooo01L0oooo00<0003o0?ooo`3oool0?@3oool40000o`@0oooo00?o003o0?ooo`3oool0
5@3oool20000oa@0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
0`3oool00ol00000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00?o00000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`800000:`3oool2000000h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003ooooookK100WookK100<00000oonf`Ooo]/40
2_oo]/400`00003ookK1oonf`@09oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool0603oool00`000?l0oooo0?ooo`100?ooo`<0003o00?o003o0000o`3oool0403o
ool60000oaH0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0103o
ool00ol00000oooo0?ooo`090?ooo`03o`0000000000oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0=0?ooo`<000009P3oool2000000h0oooo0P00000;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02Ooo]/400`00003ookK1oonf`@0:oonf`@0300000?oo
]/7ookK100[ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0I
0?ooo`030000o`3oool0oooo0440oooo00?o003o0?ooo`3oool010000?l90?ooo`@0003o703ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`040?ooo`03o`00003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03o`0000000000
oooo00l0oooo0`00000O0?ooo`@000003P3oool2000000`0oooo00<000000?ooo`3oool0203oool0
0`00003o00000?ooo`020?ooo`SookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@0:
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool06P3oool00`00
0?l0oooo0?ooo`0o0?ooo`03o`00o`3oool0oooo00D0oooo2@000?lP0?ooob?ookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo00D0oooo00?o00000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00000A0?ooo`@000005`3oool40000
0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo1ooo]/400ol0003ookK1oonf`@0;oonf`@03o`000?oo]/7ookK100_ookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0K0?ooo`030000o`3oool0oooo03d0
oooo00?o003o0?ooo`3oool0;`3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003o
oooo0?ooo`060?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool02@3oool00ol00000
00000?ooo`0;0?ooo`0300000?l00000oooo0180oooo1000000>0?ooo`03o`000000000000000080
00004P3oool200000003o`00003oool0oooo00T0oooo00<00000o`00000000002P3oool00`000000
oooo0?ooo`040?ooo`KookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@0<oonf`@;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0703oool00`000?l0oooo
0?ooo`0k0?ooo`03o`00o`3oool0oooo0300oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool01P3oool00ol00000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`03o`0000000000000000`00000
5@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000o`00003oool0
1@3oool5oonf`@0300000?oo]/7ookK100cookK100<00000oonf`Ooo]/403?oo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo01d0oooo0P000?li0?ooo`;o003o<`3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`070?ooo`03o`00003o
ool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`800000=P3o
ool2000000d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`CookK100<0
0000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@0=oonf`@;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool07`3oool00`000?l0oooo0?ooo`0d0?ooo`;o003o=@3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`080?ooo`03o`00003oool0
oooo00/0oooo00<000000?ooo`3oool02@3oool2000000h0oooo0P00000a0?ooo`<000003P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo0ooo]/400ol0003ookK1oonf`@0<
oonf`@0300000?oo]/7ookK100kookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?ooo`0P0?ooo`80003o<`3oool00ol00?l0oooo0?ooo`0e0?ooob?ookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo00T0oooo0_l0000<0?ooo`03o`00003oool0oooo
00X0oooo0P00000>0?ooo`0400000?l000000000000002/0oooo0P00000@0?ooo`030000003oool0
oooo00T0oooo0P00000:0?ooo`?ookK100<00000oonf`Ooo]/402ooo]/420000013ookK10_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooo`030000o`3oool0oooo
02l0oooo00?o003o0?ooo`3oool0=P3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`0:0?ooo`03o`00003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool20000
0100oooo0`00000V0?ooo`800000403oool00`00003o00000?ooo`0:0?ooo`030000003oool0oooo
00X0oooo0_oo]/400`00003ookK1oonf`@0<oonf`@0300000?oo]/7ookK100oookK10_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0S0?ooo`03o`00o`3oool0oooo02/0
oooo0ol00?li0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00/0
oooo00?o00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100
oooo0`00000O0?ooo`@00000403oool2000000`0oooo00<000000?ooo`3oool02`3oool00ooo]/40
0000oonf`@0=oonf`@0300000?oo]/7ookK1013ookK100<00000ooooool000002_ooool000Wooooo
00?o0000ooooo`3oool0903oool20000obT0oooo0_l00?ll0?ooob?ookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo00/0oooo00?o00000?ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`03o`00003oool0oooo0180oooo1000000E0?ooo`03o`0000000000000000<00000
4P3oool2000000d0oooo00<000000?ooo`3oool0303oool00ol0003ookK1oonf`@0<oonf`@030000
0?oo]/7ookK1017ookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool09P3o
ool30000ob@0oooo0_l00?ln0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo00`0oooo0_l0000=0?ooo`8000003@3oool3000001D0oooo5P00000D0?ooo`0300000?l0
0000000000h0oooo00<00000o`00003oool02`3oool2000000kookK100<00000oonf`Ooo]/404Ooo
]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?ooo`0Y0?ooo`80003o7`3o
ool3o`00od00oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool03P3o
ool00ol00000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo0P00000k0?ooo`8000003P3o
ool3000000d0oooo00<000000?ooo`3oool03Ooo]/400`00003ookK1oonf`@0Aoonf`@0500000?oo
]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0:`3oool30000oaX0oooo0_l0
0?m30?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000l0oooo00?o
00000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo0P00
000?0?ooo`030000003oool0oooo00d0oooo00Co00000?ooo`3oool0oooo3?oo]/400`00003ookK1
oonf`@0Aoonf`@0300000?oo]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool0;P3oool2o`00oaH0oooo0_l00?m50?ooob?ookK10_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooo00000100oooo00?o00000?ooo`3oool0303oool00ol00000oooo0?oo
o`0>0?ooo`;o0000=03oool200000100oooo00<000000?ooo`3oool03@3oool00ol00000oooo0?oo
o`020?ooo`_ookK100<00000oonf`Ooo]/404Ooo]/401?l0003ookK1oonf`Ooo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooookKo00004Ooooonf
o`0000[ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AntiPolygonalAllPlot[poly, em\  // \ Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.79825 .98077 m
.79335 .96154 L
.78882 .94231 L
.78846 .9407 L
.78494 .92308 L
.78123 .90385 L
.77752 .88462 L
.77342 .86538 L
.76923 .84988 L
.76823 .84615 L
.76016 .82692 L
.75 .81578 L
.73134 .80769 L
.73077 .80757 L
.71154 .80616 L
.69231 .80768 L
.69219 .80769 L
.67308 .80955 L
.65385 .81162 L
.63462 .81364 L
.61538 .81546 L
.59615 .81701 L
.57692 .81824 L
.55769 .81914 L
.53846 .81971 L
.51923 .81994 L
.5 .81983 L
.48077 .81938 L
.46154 .8186 L
.44231 .81749 L
.42308 .81606 L
.40385 .81435 L
.38462 .81239 L
.36538 .81024 L
.34615 .80797 L
.34381 .80769 L
.32692 .80464 L
.30769 .80077 L
.28846 .79654 L
.26923 .79203 L
.25462 .78846 L
.25 .78708 L
.23077 .78088 L
.21154 .77403 L
.19911 .76923 L
.19231 .76623 L
.17308 .75674 L
.16129 .75 L
.15385 .74525 L
.13594 .73077 L
.13462 .72986 L
.12082 .71154 L
.11538 .69653 L
.11478 .69231 L
.11538 .68121 L
.1176 .67308 L
.12956 .65385 L
.13462 .64823 L
.15171 .63462 L
.15385 .63316 L
.17308 .6219 L
.18641 .61538 L
.19231 .61287 L
.21154 .60537 L
.23077 .59873 L
.23892 .59615 L
.25 .59328 L
.26923 .58855 L
.28846 .58417 L
.30769 .5802 L
.32555 .57692 L
.32692 .57675 L
.34615 .57442 L
.36538 .57225 L
.38462 .5703 L
.40385 .56862 L
.42308 .56723 L
.44231 .56617 L
.46154 .56544 L
.48077 .56505 L
.5 .565 L
.51923 .56528 L
.53846 .56591 L
.55769 .56686 L
.57692 .56813 L
.59615 .56969 L
.61538 .57152 L
.63462 .57353 L
.65385 .57561 L
.66611 .57692 L
.67308 .57783 L
.69231 .58001 L
.71154 .57999 L
.72367 .57692 L
.73077 .57369 L
.74317 .55769 L
.74719 .53846 L
.74847 .51923 L
.74883 .5 L
.74868 .48077 L
.74774 .46154 L
.74461 .44231 L
.73077 .42338 L
.73016 .42308 L
.71154 .41634 L
.69231 .41625 L
.67308 .4183 L
.65385 .42094 L
.63809 .42308 L
.63462 .42338 L
.61538 .42504 L
.59615 .42662 L
.57692 .42803 L
.55769 .42924 L
.53846 .4302 L
.51923 .43088 L
.5 .43128 L
.48077 .43139 L
.46154 .43119 L
.44231 .4307 L
.42308 .42992 L
.40385 .42886 L
.38462 .42754 L
.36538 .42599 L
.34615 .42425 L
.33404 .42308 L
.32692 .42204 L
.30769 .41896 L
.28846 .41548 L
.26923 .41161 L
.25 .40742 L
.23464 .40385 L
.23077 .40275 L
.21154 .39685 L
.19231 .3902 L
.1779 .38462 L
.17308 .38249 L
.15385 .37291 L
.14143 .36538 L
.13462 .36087 L
.11879 .34615 L
.11538 .34192 L
.10728 .32692 L
.10562 .30769 L
.11344 .28846 L
.11538 .28513 L
.13111 .26923 L
.13462 .26633 L
.15385 .25335 L
.15979 .25 L
.17308 .24326 L
.19231 .2347 L
.20211 .23077 L
.21154 .22751 L
.23077 .22124 L
.25 .21546 L
.26418 .21154 L
.26923 .21045 L
.28846 .2064 L
.30769 .20248 L
.32692 .19881 L
.34615 .19546 L
.36538 .19247 L
.36652 .19231 L
.38462 .19058 L
.40385 .18884 L
.42308 .18724 L
.44231 .18585 L
.46154 .1847 L
.48077 .18382 L
.5 .18323 L
.51923 .18294 L
.53846 .18295 L
.55769 .18327 L
.57692 .18388 L
.59615 .1848 L
.61538 .18599 L
.63462 .18743 L
.65385 .18906 L
.67308 .19074 L
.69231 .19224 L
.69324 .19231 L
.71154 .19335 L
.728 .19231 L
.73077 .19191 L
.75 .18439 L
.76123 .17308 L
.76923 .15577 L
.76995 .15385 L
.77575 .13462 L
.78011 .11538 L
.78407 .09615 L
.78804 .07692 L
.78846 .07494 L
.79258 .05769 L
.79756 .03846 L
.803 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.79825 .98077 m
.79335 .96154 L
.78882 .94231 L
.78846 .9407 L
.78494 .92308 L
.78123 .90385 L
.77752 .88462 L
.77342 .86538 L
.76923 .84988 L
.76823 .84615 L
.76016 .82692 L
.75 .81578 L
.73134 .80769 L
.73077 .80757 L
.71154 .80616 L
.69231 .80768 L
.69219 .80769 L
.67308 .80955 L
.65385 .81162 L
.63462 .81364 L
.61538 .81546 L
.59615 .81701 L
.57692 .81824 L
.55769 .81914 L
.53846 .81971 L
.51923 .81994 L
.5 .81983 L
.48077 .81938 L
.46154 .8186 L
.44231 .81749 L
.42308 .81606 L
.40385 .81435 L
.38462 .81239 L
.36538 .81024 L
.34615 .80797 L
.34381 .80769 L
.32692 .80464 L
.30769 .80077 L
.28846 .79654 L
.26923 .79203 L
.25462 .78846 L
.25 .78708 L
.23077 .78088 L
.21154 .77403 L
.19911 .76923 L
.19231 .76623 L
.17308 .75674 L
.16129 .75 L
.15385 .74525 L
.13594 .73077 L
Mistroke
.13462 .72986 L
.12082 .71154 L
.11538 .69653 L
.11478 .69231 L
.11538 .68121 L
.1176 .67308 L
.12956 .65385 L
.13462 .64823 L
.15171 .63462 L
.15385 .63316 L
.17308 .6219 L
.18641 .61538 L
.19231 .61287 L
.21154 .60537 L
.23077 .59873 L
.23892 .59615 L
.25 .59328 L
.26923 .58855 L
.28846 .58417 L
.30769 .5802 L
.32555 .57692 L
.32692 .57675 L
.34615 .57442 L
.36538 .57225 L
.38462 .5703 L
.40385 .56862 L
.42308 .56723 L
.44231 .56617 L
.46154 .56544 L
.48077 .56505 L
.5 .565 L
.51923 .56528 L
.53846 .56591 L
.55769 .56686 L
.57692 .56813 L
.59615 .56969 L
.61538 .57152 L
.63462 .57353 L
.65385 .57561 L
.66611 .57692 L
.67308 .57783 L
.69231 .58001 L
.71154 .57999 L
.72367 .57692 L
.73077 .57369 L
.74317 .55769 L
.74719 .53846 L
.74847 .51923 L
.74883 .5 L
.74868 .48077 L
Mistroke
.74774 .46154 L
.74461 .44231 L
.73077 .42338 L
.73016 .42308 L
.71154 .41634 L
.69231 .41625 L
.67308 .4183 L
.65385 .42094 L
.63809 .42308 L
.63462 .42338 L
.61538 .42504 L
.59615 .42662 L
.57692 .42803 L
.55769 .42924 L
.53846 .4302 L
.51923 .43088 L
.5 .43128 L
.48077 .43139 L
.46154 .43119 L
.44231 .4307 L
.42308 .42992 L
.40385 .42886 L
.38462 .42754 L
.36538 .42599 L
.34615 .42425 L
.33404 .42308 L
.32692 .42204 L
.30769 .41896 L
.28846 .41548 L
.26923 .41161 L
.25 .40742 L
.23464 .40385 L
.23077 .40275 L
.21154 .39685 L
.19231 .3902 L
.1779 .38462 L
.17308 .38249 L
.15385 .37291 L
.14143 .36538 L
.13462 .36087 L
.11879 .34615 L
.11538 .34192 L
.10728 .32692 L
.10562 .30769 L
.11344 .28846 L
.11538 .28513 L
.13111 .26923 L
.13462 .26633 L
.15385 .25335 L
.15979 .25 L
Mistroke
.17308 .24326 L
.19231 .2347 L
.20211 .23077 L
.21154 .22751 L
.23077 .22124 L
.25 .21546 L
.26418 .21154 L
.26923 .21045 L
.28846 .2064 L
.30769 .20248 L
.32692 .19881 L
.34615 .19546 L
.36538 .19247 L
.36652 .19231 L
.38462 .19058 L
.40385 .18884 L
.42308 .18724 L
.44231 .18585 L
.46154 .1847 L
.48077 .18382 L
.5 .18323 L
.51923 .18294 L
.53846 .18295 L
.55769 .18327 L
.57692 .18388 L
.59615 .1848 L
.61538 .18599 L
.63462 .18743 L
.65385 .18906 L
.67308 .19074 L
.69231 .19224 L
.69324 .19231 L
.71154 .19335 L
.728 .19231 L
.73077 .19191 L
.75 .18439 L
.76123 .17308 L
.76923 .15577 L
.76995 .15385 L
.77575 .13462 L
.78011 .11538 L
.78407 .09615 L
.78804 .07692 L
.78846 .07494 L
.79258 .05769 L
.79756 .03846 L
.803 .01923 L
Mfstroke
.2 g
.98077 .28329 m
.97876 .26923 L
.97536 .25 L
.97139 .23077 L
.96712 .21154 L
.96272 .19231 L
.96154 .1872 L
.95823 .17308 L
.95357 .15385 L
.94859 .13462 L
.94311 .11538 L
.94231 .11276 L
.93693 .09615 L
.92956 .07692 L
.92308 .06303 L
.921 .05769 L
.9087 .03846 L
.90385 .03395 L
.88462 .02207 L
.86538 .02624 L
.85235 .03846 L
.84615 .047 L
.83953 .05769 L
.83062 .07692 L
.82692 .08682 L
.82351 .09615 L
.81721 .11538 L
.81147 .13462 L
.80769 .14734 L
.80575 .15385 L
.79919 .17308 L
.78994 .19231 L
.78846 .19473 L
.77444 .21154 L
.76923 .21506 L
.75 .22272 L
.73077 .22392 L
.71154 .22213 L
.69231 .21923 L
.67308 .21611 L
.65385 .21322 L
.64132 .21154 L
.63462 .21083 L
.61538 .20903 L
.59615 .20756 L
.57692 .20644 L
.55769 .20566 L
.53846 .20523 L
.51923 .20514 L
.5 .2054 L
.48077 .206 L
.46154 .20692 L
.44231 .20816 L
.42308 .20971 L
.40394 .21154 L
.40385 .21155 L
.38462 .21416 L
.36538 .2172 L
.34615 .22069 L
.32692 .22461 L
.30769 .22899 L
.30041 .23077 L
.28846 .23417 L
.26923 .2403 L
.25 .24738 L
.24363 .25 L
.23077 .25586 L
.21154 .26674 L
.20789 .26923 L
.19231 .28098 L
.1868 .28846 L
.17795 .30769 L
.18074 .32692 L
.19231 .34284 L
.19584 .34615 L
.21154 .3579 L
.22578 .36538 L
.23077 .36776 L
.25 .37567 L
.26923 .38219 L
.27734 .38462 L
.28846 .38751 L
.30769 .39199 L
.32692 .39588 L
.34615 .39924 L
.36538 .4021 L
.37915 .40385 L
.38462 .40438 L
.40385 .40603 L
.42308 .40734 L
.44231 .40831 L
.46154 .40895 L
.48077 .40924 L
.5 .4092 L
.51923 .40882 L
.53846 .40811 L
.55769 .40708 L
.57692 .40575 L
.59615 .40412 L
.59917 .40385 L
.61538 .40184 L
.63462 .39909 L
.65385 .39597 L
.67308 .39258 L
.69231 .3892 L
.71154 .38647 L
.73077 .38583 L
.75 .39103 L
.76378 .40385 L
.76923 .41972 L
.77002 .42308 L
.77304 .44231 L
.7741 .46154 L
.77437 .48077 L
.77435 .5 L
.77417 .51923 L
.77365 .53846 L
.77223 .55769 L
.76923 .57535 L
.76879 .57692 L
.76166 .59615 L
.75 .60611 L
.73077 .61167 L
.71154 .61085 L
.69231 .60782 L
.67308 .60415 L
.65385 .60053 L
.63462 .59725 L
.62752 .59615 L
.61538 .59468 L
.59615 .5926 L
.57692 .59085 L
.55769 .58945 L
.53846 .58841 L
.51923 .58775 L
.5 .58747 L
.48077 .58757 L
.46154 .58805 L
.44231 .58891 L
.42308 .59016 L
.40385 .59178 L
.38462 .59377 L
.36538 .59613 L
.36519 .59615 L
.34615 .59937 L
.32692 .60317 L
.30769 .60755 L
.28846 .61259 L
.27885 .61538 L
.26923 .61859 L
.25 .62591 L
.23131 .63462 L
.23077 .63489 L
.21154 .64647 L
.20274 .65385 L
.19231 .66533 L
.18761 .67308 L
.18383 .69231 L
.19078 .71154 L
.19231 .71447 L
.20906 .73077 L
.21154 .73272 L
.23077 .74497 L
.24076 .75 L
.25 .7542 L
.26923 .76184 L
.28846 .76836 L
.29128 .76923 L
.30769 .77367 L
.32692 .77834 L
.34615 .78246 L
.36538 .78607 L
.37999 .78846 L
.38462 .78905 L
.40385 .79131 L
.42308 .79323 L
.44231 .79481 L
.46154 .79603 L
.48077 .79687 L
.5 .79734 L
.51923 .79742 L
.53846 .79713 L
.55769 .79644 L
.57692 .79538 L
.59615 .79393 L
.61538 .79211 L
.63462 .78993 L
.64614 .78846 L
.65385 .78723 L
.67308 .78386 L
.69231 .78024 L
.71154 .77681 L
.73077 .77458 L
.75 .77564 L
.76923 .78413 L
.77479 .78846 L
.78817 .80769 L
.78846 .80832 L
.79638 .82692 L
.80223 .84615 L
.80719 .86538 L
.80769 .86739 L
.81217 .88462 L
.81751 .90385 L
.8235 .92308 L
.82692 .93289 L
.83032 .94231 L
.83864 .96154 L
.84615 .97481 L
.85002 .98077 L
.98077 .98077 L
F
0 g
.98077 .28329 m
.97876 .26923 L
.97536 .25 L
.97139 .23077 L
.96712 .21154 L
.96272 .19231 L
.96154 .1872 L
.95823 .17308 L
.95357 .15385 L
.94859 .13462 L
.94311 .11538 L
.94231 .11276 L
.93693 .09615 L
.92956 .07692 L
.92308 .06303 L
.921 .05769 L
.9087 .03846 L
.90385 .03395 L
.88462 .02207 L
.86538 .02624 L
.85235 .03846 L
.84615 .047 L
.83953 .05769 L
.83062 .07692 L
.82692 .08682 L
.82351 .09615 L
.81721 .11538 L
.81147 .13462 L
.80769 .14734 L
.80575 .15385 L
.79919 .17308 L
.78994 .19231 L
.78846 .19473 L
.77444 .21154 L
.76923 .21506 L
.75 .22272 L
.73077 .22392 L
.71154 .22213 L
.69231 .21923 L
.67308 .21611 L
.65385 .21322 L
.64132 .21154 L
.63462 .21083 L
.61538 .20903 L
.59615 .20756 L
.57692 .20644 L
.55769 .20566 L
.53846 .20523 L
.51923 .20514 L
.5 .2054 L
Mistroke
.48077 .206 L
.46154 .20692 L
.44231 .20816 L
.42308 .20971 L
.40394 .21154 L
.40385 .21155 L
.38462 .21416 L
.36538 .2172 L
.34615 .22069 L
.32692 .22461 L
.30769 .22899 L
.30041 .23077 L
.28846 .23417 L
.26923 .2403 L
.25 .24738 L
.24363 .25 L
.23077 .25586 L
.21154 .26674 L
.20789 .26923 L
.19231 .28098 L
.1868 .28846 L
.17795 .30769 L
.18074 .32692 L
.19231 .34284 L
.19584 .34615 L
.21154 .3579 L
.22578 .36538 L
.23077 .36776 L
.25 .37567 L
.26923 .38219 L
.27734 .38462 L
.28846 .38751 L
.30769 .39199 L
.32692 .39588 L
.34615 .39924 L
.36538 .4021 L
.37915 .40385 L
.38462 .40438 L
.40385 .40603 L
.42308 .40734 L
.44231 .40831 L
.46154 .40895 L
.48077 .40924 L
.5 .4092 L
.51923 .40882 L
.53846 .40811 L
.55769 .40708 L
.57692 .40575 L
.59615 .40412 L
.59917 .40385 L
Mistroke
.61538 .40184 L
.63462 .39909 L
.65385 .39597 L
.67308 .39258 L
.69231 .3892 L
.71154 .38647 L
.73077 .38583 L
.75 .39103 L
.76378 .40385 L
.76923 .41972 L
.77002 .42308 L
.77304 .44231 L
.7741 .46154 L
.77437 .48077 L
.77435 .5 L
.77417 .51923 L
.77365 .53846 L
.77223 .55769 L
.76923 .57535 L
.76879 .57692 L
.76166 .59615 L
.75 .60611 L
.73077 .61167 L
.71154 .61085 L
.69231 .60782 L
.67308 .60415 L
.65385 .60053 L
.63462 .59725 L
.62752 .59615 L
.61538 .59468 L
.59615 .5926 L
.57692 .59085 L
.55769 .58945 L
.53846 .58841 L
.51923 .58775 L
.5 .58747 L
.48077 .58757 L
.46154 .58805 L
.44231 .58891 L
.42308 .59016 L
.40385 .59178 L
.38462 .59377 L
.36538 .59613 L
.36519 .59615 L
.34615 .59937 L
.32692 .60317 L
.30769 .60755 L
.28846 .61259 L
.27885 .61538 L
.26923 .61859 L
Mistroke
.25 .62591 L
.23131 .63462 L
.23077 .63489 L
.21154 .64647 L
.20274 .65385 L
.19231 .66533 L
.18761 .67308 L
.18383 .69231 L
.19078 .71154 L
.19231 .71447 L
.20906 .73077 L
.21154 .73272 L
.23077 .74497 L
.24076 .75 L
.25 .7542 L
.26923 .76184 L
.28846 .76836 L
.29128 .76923 L
.30769 .77367 L
.32692 .77834 L
.34615 .78246 L
.36538 .78607 L
.37999 .78846 L
.38462 .78905 L
.40385 .79131 L
.42308 .79323 L
.44231 .79481 L
.46154 .79603 L
.48077 .79687 L
.5 .79734 L
.51923 .79742 L
.53846 .79713 L
.55769 .79644 L
.57692 .79538 L
.59615 .79393 L
.61538 .79211 L
.63462 .78993 L
.64614 .78846 L
.65385 .78723 L
.67308 .78386 L
.69231 .78024 L
.71154 .77681 L
.73077 .77458 L
.75 .77564 L
.76923 .78413 L
.77479 .78846 L
.78817 .80769 L
.78846 .80832 L
.79638 .82692 L
.80223 .84615 L
Mistroke
.80719 .86538 L
.80769 .86739 L
.81217 .88462 L
.81751 .90385 L
.8235 .92308 L
.82692 .93289 L
.83032 .94231 L
.83864 .96154 L
.84615 .97481 L
.85002 .98077 L
Mfstroke
.3 g
.86538 .10186 m
.88462 .09679 L
.90385 .11062 L
.90828 .11538 L
.91952 .13462 L
.92308 .14483 L
.92683 .15385 L
.9338 .17308 L
.93988 .19231 L
.94231 .20049 L
.94549 .21154 L
.95074 .23077 L
.9555 .25 L
.95959 .26923 L
.96154 .28009 L
.96281 .28846 L
.96509 .30769 L
.96655 .32692 L
.96743 .34615 L
.96805 .36538 L
.96862 .38462 L
.96926 .40385 L
.96995 .42308 L
.97062 .44231 L
.9712 .46154 L
.97163 .48077 L
.9719 .5 L
.97199 .51923 L
.97191 .53846 L
.97169 .55769 L
.97137 .57692 L
.971 .59615 L
.97062 .61538 L
.97022 .63462 L
.9697 .65385 L
.96888 .67308 L
.96754 .69231 L
.96553 .71154 L
.96281 .73077 L
.96154 .73844 L
.95944 .75 L
.95558 .76923 L
.95137 .78846 L
.94687 .80769 L
.94231 .82584 L
.94203 .82692 L
.93675 .84615 L
.9306 .86538 L
.92308 .88444 L
.92303 .88462 L
.91538 .90385 L
.90385 .91718 L
.89757 .92308 L
.88462 .92903 L
.86686 .92308 L
.86538 .92189 L
.85109 .90385 L
.84615 .89496 L
.84101 .88462 L
.83325 .86538 L
.82692 .84668 L
.82674 .84615 L
.8201 .82692 L
.81272 .80769 L
.80769 .79662 L
.80352 .78846 L
.78978 .76923 L
.78846 .76789 L
.76923 .75413 L
.75 .75034 L
.73077 .75238 L
.71154 .75686 L
.69231 .76188 L
.67308 .7666 L
.66122 .76923 L
.65385 .77067 L
.63462 .77402 L
.61538 .77683 L
.59615 .77912 L
.57692 .78091 L
.55769 .78222 L
.53846 .78306 L
.51923 .78344 L
.5 .78337 L
.48077 .78285 L
.46154 .78188 L
.44231 .78045 L
.42308 .77855 L
.40385 .77618 L
.38462 .77332 L
.36538 .76994 L
.36172 .76923 L
.34615 .76573 L
.32692 .76069 L
.30769 .75474 L
.29455 .75 L
.28846 .7476 L
.26923 .73861 L
.25635 .73077 L
.25 .72764 L
.23516 .71154 L
.23077 .7042 L
.22735 .69231 L
.23077 .67547 L
.232 .67308 L
.25 .6539 L
.25008 .65385 L
.26923 .64178 L
.28524 .63462 L
.28846 .63331 L
.30769 .62646 L
.32692 .62084 L
.34615 .61616 L
.3497 .61538 L
.36538 .61243 L
.38462 .60935 L
.40385 .60681 L
.42308 .60479 L
.44231 .60325 L
.46154 .60219 L
.48077 .60159 L
.5 .60144 L
.51923 .60174 L
.53846 .6025 L
.55769 .6037 L
.57692 .60537 L
.59615 .60751 L
.61538 .61012 L
.63462 .61322 L
.64644 .61538 L
.65385 .61695 L
.67308 .6214 L
.69231 .6263 L
.71154 .63121 L
.72817 .63462 L
.73077 .63497 L
.75 .63483 L
.75101 .63462 L
.76923 .62456 L
.77687 .61538 L
.78448 .59615 L
.78789 .57692 L
.78846 .57309 L
.78954 .55769 L
.7902 .53846 L
.79043 .51923 L
.79054 .5 L
.79064 .48077 L
.79065 .46154 L
.79028 .44231 L
.78892 .42308 L
.78846 .41863 L
.78583 .40385 L
.77885 .38462 L
.76923 .37298 L
.7568 .36538 L
.75 .36349 L
.73077 .36317 L
.71691 .36538 L
.71154 .36651 L
.69231 .371 L
.67308 .37556 L
.65385 .37977 L
.63462 .38346 L
.62798 .38462 L
.61538 .38647 L
.59615 .38896 L
.57692 .39102 L
.55769 .39266 L
.53846 .3939 L
.51923 .39472 L
.5 .39513 L
.48077 .39513 L
.46154 .39471 L
.44231 .39387 L
.42308 .39259 L
.40385 .39086 L
.38462 .38866 L
.36538 .38595 L
.35708 .38462 L
.34615 .38255 L
.32692 .37835 L
.30769 .37329 L
.28846 .36711 L
.28376 .36538 L
.26923 .35955 L
.25 .34899 L
.24607 .34615 L
.23077 .33173 L
.22758 .32692 L
.22378 .30769 L
.23077 .29199 L
.23353 .28846 L
.25 .27307 L
.25787 .26923 L
.26923 .26299 L
.28846 .25455 L
.30102 .25 L
.30769 .2478 L
.32692 .24214 L
.34615 .23731 L
.36538 .23317 L
.37809 .23077 L
.38462 .22972 L
.40385 .22694 L
.42308 .2246 L
.44231 .22268 L
.46154 .22118 L
.48077 .2201 L
.5 .21943 L
.51923 .21918 L
.53846 .21934 L
.55769 .21992 L
.57692 .22094 L
.59615 .2224 L
.61538 .22432 L
.63462 .22671 L
.65385 .22961 L
.66071 .23077 L
.67308 .23316 L
.69231 .23727 L
.71154 .24161 L
.73077 .24539 L
.75 .24695 L
.76923 .24344 L
.78846 .23154 L
.78936 .23077 L
.80543 .21154 L
.80769 .2079 L
.81625 .19231 L
.82499 .17308 L
.82692 .16853 L
.83277 .15385 L
.84155 .13462 L
.84615 .12635 L
.85301 .11538 L
F
0 g
.86538 .10186 m
.88462 .09679 L
.90385 .11062 L
.90828 .11538 L
.91952 .13462 L
.92308 .14483 L
.92683 .15385 L
.9338 .17308 L
.93988 .19231 L
.94231 .20049 L
.94549 .21154 L
.95074 .23077 L
.9555 .25 L
.95959 .26923 L
.96154 .28009 L
.96281 .28846 L
.96509 .30769 L
.96655 .32692 L
.96743 .34615 L
.96805 .36538 L
.96862 .38462 L
.96926 .40385 L
.96995 .42308 L
.97062 .44231 L
.9712 .46154 L
.97163 .48077 L
.9719 .5 L
.97199 .51923 L
.97191 .53846 L
.97169 .55769 L
.97137 .57692 L
.971 .59615 L
.97062 .61538 L
.97022 .63462 L
.9697 .65385 L
.96888 .67308 L
.96754 .69231 L
.96553 .71154 L
.96281 .73077 L
.96154 .73844 L
.95944 .75 L
.95558 .76923 L
.95137 .78846 L
.94687 .80769 L
.94231 .82584 L
.94203 .82692 L
.93675 .84615 L
.9306 .86538 L
.92308 .88444 L
.92303 .88462 L
Mistroke
.91538 .90385 L
.90385 .91718 L
.89757 .92308 L
.88462 .92903 L
.86686 .92308 L
.86538 .92189 L
.85109 .90385 L
.84615 .89496 L
.84101 .88462 L
.83325 .86538 L
.82692 .84668 L
.82674 .84615 L
.8201 .82692 L
.81272 .80769 L
.80769 .79662 L
.80352 .78846 L
.78978 .76923 L
.78846 .76789 L
.76923 .75413 L
.75 .75034 L
.73077 .75238 L
.71154 .75686 L
.69231 .76188 L
.67308 .7666 L
.66122 .76923 L
.65385 .77067 L
.63462 .77402 L
.61538 .77683 L
.59615 .77912 L
.57692 .78091 L
.55769 .78222 L
.53846 .78306 L
.51923 .78344 L
.5 .78337 L
.48077 .78285 L
.46154 .78188 L
.44231 .78045 L
.42308 .77855 L
.40385 .77618 L
.38462 .77332 L
.36538 .76994 L
.36172 .76923 L
.34615 .76573 L
.32692 .76069 L
.30769 .75474 L
.29455 .75 L
.28846 .7476 L
.26923 .73861 L
.25635 .73077 L
.25 .72764 L
Mistroke
.23516 .71154 L
.23077 .7042 L
.22735 .69231 L
.23077 .67547 L
.232 .67308 L
.25 .6539 L
.25008 .65385 L
.26923 .64178 L
.28524 .63462 L
.28846 .63331 L
.30769 .62646 L
.32692 .62084 L
.34615 .61616 L
.3497 .61538 L
.36538 .61243 L
.38462 .60935 L
.40385 .60681 L
.42308 .60479 L
.44231 .60325 L
.46154 .60219 L
.48077 .60159 L
.5 .60144 L
.51923 .60174 L
.53846 .6025 L
.55769 .6037 L
.57692 .60537 L
.59615 .60751 L
.61538 .61012 L
.63462 .61322 L
.64644 .61538 L
.65385 .61695 L
.67308 .6214 L
.69231 .6263 L
.71154 .63121 L
.72817 .63462 L
.73077 .63497 L
.75 .63483 L
.75101 .63462 L
.76923 .62456 L
.77687 .61538 L
.78448 .59615 L
.78789 .57692 L
.78846 .57309 L
.78954 .55769 L
.7902 .53846 L
.79043 .51923 L
.79054 .5 L
.79064 .48077 L
.79065 .46154 L
.79028 .44231 L
Mistroke
.78892 .42308 L
.78846 .41863 L
.78583 .40385 L
.77885 .38462 L
.76923 .37298 L
.7568 .36538 L
.75 .36349 L
.73077 .36317 L
.71691 .36538 L
.71154 .36651 L
.69231 .371 L
.67308 .37556 L
.65385 .37977 L
.63462 .38346 L
.62798 .38462 L
.61538 .38647 L
.59615 .38896 L
.57692 .39102 L
.55769 .39266 L
.53846 .3939 L
.51923 .39472 L
.5 .39513 L
.48077 .39513 L
.46154 .39471 L
.44231 .39387 L
.42308 .39259 L
.40385 .39086 L
.38462 .38866 L
.36538 .38595 L
.35708 .38462 L
.34615 .38255 L
.32692 .37835 L
.30769 .37329 L
.28846 .36711 L
.28376 .36538 L
.26923 .35955 L
.25 .34899 L
.24607 .34615 L
.23077 .33173 L
.22758 .32692 L
.22378 .30769 L
.23077 .29199 L
.23353 .28846 L
.25 .27307 L
.25787 .26923 L
.26923 .26299 L
.28846 .25455 L
.30102 .25 L
.30769 .2478 L
.32692 .24214 L
Mistroke
.34615 .23731 L
.36538 .23317 L
.37809 .23077 L
.38462 .22972 L
.40385 .22694 L
.42308 .2246 L
.44231 .22268 L
.46154 .22118 L
.48077 .2201 L
.5 .21943 L
.51923 .21918 L
.53846 .21934 L
.55769 .21992 L
.57692 .22094 L
.59615 .2224 L
.61538 .22432 L
.63462 .22671 L
.65385 .22961 L
.66071 .23077 L
.67308 .23316 L
.69231 .23727 L
.71154 .24161 L
.73077 .24539 L
.75 .24695 L
.76923 .24344 L
.78846 .23154 L
.78936 .23077 L
.80543 .21154 L
.80769 .2079 L
.81625 .19231 L
.82499 .17308 L
.82692 .16853 L
.83277 .15385 L
.84155 .13462 L
.84615 .12635 L
.85301 .11538 L
.86538 .10186 L
Mfstroke
.4 g
.86538 .16058 m
.88462 .15541 L
.90385 .17049 L
.90617 .17308 L
.91798 .19231 L
.92308 .20596 L
.92543 .21154 L
.93265 .23077 L
.93867 .25 L
.94231 .26374 L
.9436 .26923 L
.94742 .28846 L
.95014 .30769 L
.95194 .32692 L
.95309 .34615 L
.95394 .36538 L
.95472 .38462 L
.95554 .40385 L
.95638 .42308 L
.95718 .44231 L
.95787 .46154 L
.95837 .48077 L
.95868 .5 L
.95878 .51923 L
.95867 .53846 L
.9584 .55769 L
.95799 .57692 L
.95752 .59615 L
.95701 .61538 L
.95645 .63462 L
.95575 .65385 L
.95469 .67308 L
.95307 .69231 L
.95069 .71154 L
.94746 .73077 L
.94342 .75 L
.94231 .75475 L
.93869 .76923 L
.93326 .78846 L
.92694 .80769 L
.92308 .81793 L
.92053 .82692 L
.91154 .84615 L
.90385 .85535 L
.89357 .86538 L
.88462 .86921 L
.87043 .86538 L
.86538 .86137 L
.8537 .84615 L
.84615 .83274 L
.84307 .82692 L
.83378 .80769 L
.82692 .79294 L
.82463 .78846 L
.81377 .76923 L
.80769 .76009 L
.80061 .75 L
.78846 .73779 L
.77977 .73077 L
.76923 .72776 L
.75 .72778 L
.73077 .73073 L
.73003 .73077 L
.71154 .73858 L
.69231 .74575 L
.67897 .75 L
.67308 .75179 L
.65385 .75691 L
.63462 .76112 L
.61538 .76455 L
.59615 .76729 L
.57865 .76923 L
.57692 .76938 L
.55769 .77082 L
.53846 .77175 L
.51923 .77219 L
.5 .77214 L
.48077 .77161 L
.46154 .77059 L
.44386 .76923 L
.44231 .76907 L
.42308 .76691 L
.40385 .76414 L
.38462 .76072 L
.36538 .75656 L
.34615 .75152 L
.34102 .75 L
.32692 .7454 L
.30769 .73759 L
.29471 .73077 L
.28846 .72828 L
.27032 .71154 L
.26923 .71016 L
.26162 .69231 L
.2672 .67308 L
.26923 .66836 L
.28846 .65385 L
.28851 .65385 L
.30769 .64352 L
.32692 .63621 L
.3319 .63462 L
.34615 .63041 L
.36538 .62571 L
.38462 .6219 L
.40385 .61884 L
.42308 .61644 L
.43341 .61538 L
.44231 .61468 L
.46154 .61351 L
.48077 .61284 L
.5 .61266 L
.51923 .61296 L
.53846 .61374 L
.55769 .615 L
.56244 .61538 L
.57692 .61687 L
.59615 .61934 L
.61538 .62244 L
.63462 .62621 L
.65385 .63075 L
.6679 .63462 L
.67308 .63614 L
.69231 .64248 L
.71154 .64982 L
.71868 .65385 L
.73077 .6561 L
.75 .65983 L
.76923 .65569 L
.77392 .65385 L
.78831 .63462 L
.78846 .63417 L
.79601 .61538 L
.80021 .59615 L
.80233 .57692 L
.80325 .55769 L
.80355 .53846 L
.80363 .51923 L
.80371 .5 L
.80386 .48077 L
.80403 .46154 L
.80402 .44231 L
.80342 .42308 L
.80162 .40385 L
.79766 .38462 L
.78992 .36538 L
.78846 .36291 L
.77476 .34615 L
.76923 .34344 L
.75 .33948 L
.73077 .34282 L
.71462 .34615 L
.71154 .34836 L
.69231 .35509 L
.67308 .36104 L
.65684 .36538 L
.65385 .36612 L
.63462 .37042 L
.61538 .37403 L
.59615 .37702 L
.57692 .37945 L
.55769 .38134 L
.53846 .38273 L
.51923 .38363 L
.5 .38406 L
.48077 .384 L
.46154 .38346 L
.44231 .38242 L
.42308 .38086 L
.40385 .37874 L
.38462 .376 L
.36538 .37257 L
.34615 .36829 L
.33513 .36538 L
.32692 .36304 L
.30769 .35636 L
.28846 .3469 L
.28725 .34615 L
.26923 .33222 L
.26494 .32692 L
.26006 .30769 L
.26923 .29015 L
.27078 .28846 L
.28846 .2735 L
.29875 .26923 L
.30769 .26493 L
.32692 .25739 L
.34615 .25145 L
.35152 .25 L
.36538 .24658 L
.38462 .24251 L
.40385 .23913 L
.42308 .23635 L
.44231 .23413 L
.46154 .23243 L
.48077 .23123 L
.49166 .23077 L
.5 .23053 L
.51923 .23031 L
.53846 .23053 L
.54671 .23077 L
.55769 .23125 L
.57692 .23248 L
.59615 .23425 L
.61538 .2366 L
.63462 .23959 L
.65385 .2433 L
.67308 .24782 L
.68113 .25 L
.69231 .25313 L
.71154 .25928 L
.73077 .26605 L
.74075 .26923 L
.75 .2712 L
.76923 .27016 L
.77199 .26923 L
.78846 .25957 L
.79996 .25 L
.80769 .24088 L
.81569 .23077 L
.82692 .21442 L
.82862 .21154 L
.84032 .19231 L
.84615 .18363 L
.85361 .17308 L
F
0 g
.86538 .16058 m
.88462 .15541 L
.90385 .17049 L
.90617 .17308 L
.91798 .19231 L
.92308 .20596 L
.92543 .21154 L
.93265 .23077 L
.93867 .25 L
.94231 .26374 L
.9436 .26923 L
.94742 .28846 L
.95014 .30769 L
.95194 .32692 L
.95309 .34615 L
.95394 .36538 L
.95472 .38462 L
.95554 .40385 L
.95638 .42308 L
.95718 .44231 L
.95787 .46154 L
.95837 .48077 L
.95868 .5 L
.95878 .51923 L
.95867 .53846 L
.9584 .55769 L
.95799 .57692 L
.95752 .59615 L
.95701 .61538 L
.95645 .63462 L
.95575 .65385 L
.95469 .67308 L
.95307 .69231 L
.95069 .71154 L
.94746 .73077 L
.94342 .75 L
.94231 .75475 L
.93869 .76923 L
.93326 .78846 L
.92694 .80769 L
.92308 .81793 L
.92053 .82692 L
.91154 .84615 L
.90385 .85535 L
.89357 .86538 L
.88462 .86921 L
.87043 .86538 L
.86538 .86137 L
.8537 .84615 L
.84615 .83274 L
Mistroke
.84307 .82692 L
.83378 .80769 L
.82692 .79294 L
.82463 .78846 L
.81377 .76923 L
.80769 .76009 L
.80061 .75 L
.78846 .73779 L
.77977 .73077 L
.76923 .72776 L
.75 .72778 L
.73077 .73073 L
.73003 .73077 L
.71154 .73858 L
.69231 .74575 L
.67897 .75 L
.67308 .75179 L
.65385 .75691 L
.63462 .76112 L
.61538 .76455 L
.59615 .76729 L
.57865 .76923 L
.57692 .76938 L
.55769 .77082 L
.53846 .77175 L
.51923 .77219 L
.5 .77214 L
.48077 .77161 L
.46154 .77059 L
.44386 .76923 L
.44231 .76907 L
.42308 .76691 L
.40385 .76414 L
.38462 .76072 L
.36538 .75656 L
.34615 .75152 L
.34102 .75 L
.32692 .7454 L
.30769 .73759 L
.29471 .73077 L
.28846 .72828 L
.27032 .71154 L
.26923 .71016 L
.26162 .69231 L
.2672 .67308 L
.26923 .66836 L
.28846 .65385 L
.28851 .65385 L
.30769 .64352 L
.32692 .63621 L
Mistroke
.3319 .63462 L
.34615 .63041 L
.36538 .62571 L
.38462 .6219 L
.40385 .61884 L
.42308 .61644 L
.43341 .61538 L
.44231 .61468 L
.46154 .61351 L
.48077 .61284 L
.5 .61266 L
.51923 .61296 L
.53846 .61374 L
.55769 .615 L
.56244 .61538 L
.57692 .61687 L
.59615 .61934 L
.61538 .62244 L
.63462 .62621 L
.65385 .63075 L
.6679 .63462 L
.67308 .63614 L
.69231 .64248 L
.71154 .64982 L
.71868 .65385 L
.73077 .6561 L
.75 .65983 L
.76923 .65569 L
.77392 .65385 L
.78831 .63462 L
.78846 .63417 L
.79601 .61538 L
.80021 .59615 L
.80233 .57692 L
.80325 .55769 L
.80355 .53846 L
.80363 .51923 L
.80371 .5 L
.80386 .48077 L
.80403 .46154 L
.80402 .44231 L
.80342 .42308 L
.80162 .40385 L
.79766 .38462 L
.78992 .36538 L
.78846 .36291 L
.77476 .34615 L
.76923 .34344 L
.75 .33948 L
.73077 .34282 L
Mistroke
.71462 .34615 L
.71154 .34836 L
.69231 .35509 L
.67308 .36104 L
.65684 .36538 L
.65385 .36612 L
.63462 .37042 L
.61538 .37403 L
.59615 .37702 L
.57692 .37945 L
.55769 .38134 L
.53846 .38273 L
.51923 .38363 L
.5 .38406 L
.48077 .384 L
.46154 .38346 L
.44231 .38242 L
.42308 .38086 L
.40385 .37874 L
.38462 .376 L
.36538 .37257 L
.34615 .36829 L
.33513 .36538 L
.32692 .36304 L
.30769 .35636 L
.28846 .3469 L
.28725 .34615 L
.26923 .33222 L
.26494 .32692 L
.26006 .30769 L
.26923 .29015 L
.27078 .28846 L
.28846 .2735 L
.29875 .26923 L
.30769 .26493 L
.32692 .25739 L
.34615 .25145 L
.35152 .25 L
.36538 .24658 L
.38462 .24251 L
.40385 .23913 L
.42308 .23635 L
.44231 .23413 L
.46154 .23243 L
.48077 .23123 L
.49166 .23077 L
.5 .23053 L
.51923 .23031 L
.53846 .23053 L
.54671 .23077 L
Mistroke
.55769 .23125 L
.57692 .23248 L
.59615 .23425 L
.61538 .2366 L
.63462 .23959 L
.65385 .2433 L
.67308 .24782 L
.68113 .25 L
.69231 .25313 L
.71154 .25928 L
.73077 .26605 L
.74075 .26923 L
.75 .2712 L
.76923 .27016 L
.77199 .26923 L
.78846 .25957 L
.79996 .25 L
.80769 .24088 L
.81569 .23077 L
.82692 .21442 L
.82862 .21154 L
.84032 .19231 L
.84615 .18363 L
.85361 .17308 L
.86538 .16058 L
Mfstroke
.5 g
.38462 .63338 m
.40385 .62976 L
.42308 .62696 L
.44231 .62488 L
.46154 .62345 L
.48077 .62262 L
.5 .62238 L
.51923 .62271 L
.53846 .62362 L
.55769 .62511 L
.57692 .62723 L
.59615 .63003 L
.61538 .63358 L
.62029 .63462 L
.63462 .63798 L
.65385 .64352 L
.67308 .65067 L
.68012 .65385 L
.69231 .6581 L
.71154 .67307 L
.71154 .67308 L
.72317 .69231 L
.71503 .71154 L
.71154 .71773 L
.69231 .73019 L
.68754 .73077 L
.67308 .73746 L
.65385 .74418 L
.63462 .74928 L
.6315 .75 L
.61538 .75337 L
.59615 .75658 L
.57692 .75902 L
.55769 .76078 L
.53846 .76191 L
.51923 .76246 L
.5 .76242 L
.48077 .76182 L
.46154 .76063 L
.44231 .75884 L
.42308 .7564 L
.40385 .75325 L
.38777 .75 L
.38462 .7493 L
.36538 .74438 L
.34615 .73805 L
.32936 .73077 L
.32692 .73006 L
.30769 .71936 L
.3011 .71154 L
.29138 .69231 L
.29801 .67308 L
.30769 .6595 L
.32325 .65385 L
.32692 .65191 L
.34615 .6438 L
.36538 .63792 L
.37898 .63462 L
F
0 g
.38462 .63338 m
.40385 .62976 L
.42308 .62696 L
.44231 .62488 L
.46154 .62345 L
.48077 .62262 L
.5 .62238 L
.51923 .62271 L
.53846 .62362 L
.55769 .62511 L
.57692 .62723 L
.59615 .63003 L
.61538 .63358 L
.62029 .63462 L
.63462 .63798 L
.65385 .64352 L
.67308 .65067 L
.68012 .65385 L
.69231 .6581 L
.71154 .67307 L
.71154 .67308 L
.72317 .69231 L
.71503 .71154 L
.71154 .71773 L
.69231 .73019 L
.68754 .73077 L
.67308 .73746 L
.65385 .74418 L
.63462 .74928 L
.6315 .75 L
.61538 .75337 L
.59615 .75658 L
.57692 .75902 L
.55769 .76078 L
.53846 .76191 L
.51923 .76246 L
.5 .76242 L
.48077 .76182 L
.46154 .76063 L
.44231 .75884 L
.42308 .7564 L
.40385 .75325 L
.38777 .75 L
.38462 .7493 L
.36538 .74438 L
.34615 .73805 L
.32936 .73077 L
.32692 .73006 L
.30769 .71936 L
.3011 .71154 L
Mistroke
.29138 .69231 L
.29801 .67308 L
.30769 .6595 L
.32325 .65385 L
.32692 .65191 L
.34615 .6438 L
.36538 .63792 L
.37898 .63462 L
.38462 .63338 L
Mfstroke
.5 g
.42308 .24694 m
.44231 .24446 L
.46154 .24258 L
.48077 .24127 L
.5 .24051 L
.51923 .24028 L
.53846 .2406 L
.55769 .24147 L
.57692 .24293 L
.59615 .24503 L
.61538 .24784 L
.62736 .25 L
.63462 .25144 L
.65385 .25598 L
.67308 .26199 L
.69017 .26923 L
.69231 .27024 L
.71154 .28151 L
.71921 .28846 L
.72669 .30769 L
.71154 .32637 L
.71078 .32692 L
.69231 .33954 L
.67394 .34615 L
.67308 .3465 L
.65385 .35329 L
.63462 .35864 L
.61538 .3629 L
.60189 .36538 L
.59615 .36633 L
.57692 .36905 L
.55769 .37115 L
.53846 .37267 L
.51923 .37364 L
.5 .37407 L
.48077 .37397 L
.46154 .37331 L
.44231 .37208 L
.42308 .37024 L
.40385 .36772 L
.38977 .36538 L
.38462 .36443 L
.36538 .36026 L
.34615 .35476 L
.32692 .34709 L
.32502 .34615 L
.30769 .33596 L
.29792 .32692 L
.29176 .30769 L
.30363 .28846 L
.30769 .2841 L
.32692 .27216 L
.33612 .26923 L
.34615 .2652 L
.36538 .25892 L
.38462 .25401 L
.40385 .2501 L
.40439 .25 L
F
0 g
.42308 .24694 m
.44231 .24446 L
.46154 .24258 L
.48077 .24127 L
.5 .24051 L
.51923 .24028 L
.53846 .2406 L
.55769 .24147 L
.57692 .24293 L
.59615 .24503 L
.61538 .24784 L
.62736 .25 L
.63462 .25144 L
.65385 .25598 L
.67308 .26199 L
.69017 .26923 L
.69231 .27024 L
.71154 .28151 L
.71921 .28846 L
.72669 .30769 L
.71154 .32637 L
.71078 .32692 L
.69231 .33954 L
.67394 .34615 L
.67308 .3465 L
.65385 .35329 L
.63462 .35864 L
.61538 .3629 L
.60189 .36538 L
.59615 .36633 L
.57692 .36905 L
.55769 .37115 L
.53846 .37267 L
.51923 .37364 L
.5 .37407 L
.48077 .37397 L
.46154 .37331 L
.44231 .37208 L
.42308 .37024 L
.40385 .36772 L
.38977 .36538 L
.38462 .36443 L
.36538 .36026 L
.34615 .35476 L
.32692 .34709 L
.32502 .34615 L
.30769 .33596 L
.29792 .32692 L
.29176 .30769 L
.30363 .28846 L
Mistroke
.30769 .2841 L
.32692 .27216 L
.33612 .26923 L
.34615 .2652 L
.36538 .25892 L
.38462 .25401 L
.40385 .2501 L
.40439 .25 L
.42308 .24694 L
Mfstroke
.6 g
.44231 .63434 m
.46154 .63266 L
.48077 .63169 L
.5 .63139 L
.51923 .63174 L
.53846 .63274 L
.55769 .63442 L
.55952 .63462 L
.57692 .63681 L
.59615 .64003 L
.61538 .64427 L
.63462 .64989 L
.64536 .65385 L
.65385 .65606 L
.67308 .66627 L
.67974 .67308 L
.6915 .69231 L
.68343 .71154 L
.67308 .72415 L
.65385 .73066 L
.65273 .73077 L
.63462 .73753 L
.61538 .74273 L
.59615 .74656 L
.57692 .74939 L
.57206 .75 L
.55769 .75145 L
.53846 .75278 L
.51923 .75342 L
.5 .75341 L
.48077 .75275 L
.46154 .75143 L
.44717 .75 L
.44231 .74941 L
.42308 .74664 L
.40385 .74296 L
.38462 .73811 L
.36538 .73161 L
.3633 .73077 L
.34615 .72511 L
.32984 .71154 L
.32692 .70856 L
.31887 .69231 L
.32679 .67308 L
.32692 .67283 L
.34615 .65599 L
.35731 .65385 L
.36538 .65057 L
.38462 .64447 L
.40385 .64003 L
.42308 .63674 L
.43971 .63462 L
F
0 g
.44231 .63434 m
.46154 .63266 L
.48077 .63169 L
.5 .63139 L
.51923 .63174 L
.53846 .63274 L
.55769 .63442 L
.55952 .63462 L
.57692 .63681 L
.59615 .64003 L
.61538 .64427 L
.63462 .64989 L
.64536 .65385 L
.65385 .65606 L
.67308 .66627 L
.67974 .67308 L
.6915 .69231 L
.68343 .71154 L
.67308 .72415 L
.65385 .73066 L
.65273 .73077 L
.63462 .73753 L
.61538 .74273 L
.59615 .74656 L
.57692 .74939 L
.57206 .75 L
.55769 .75145 L
.53846 .75278 L
.51923 .75342 L
.5 .75341 L
.48077 .75275 L
.46154 .75143 L
.44717 .75 L
.44231 .74941 L
.42308 .74664 L
.40385 .74296 L
.38462 .73811 L
.36538 .73161 L
.3633 .73077 L
.34615 .72511 L
.32984 .71154 L
.32692 .70856 L
.31887 .69231 L
.32679 .67308 L
.32692 .67283 L
.34615 .65599 L
.35731 .65385 L
.36538 .65057 L
.38462 .64447 L
.40385 .64003 L
Mistroke
.42308 .63674 L
.43971 .63462 L
.44231 .63434 L
Mfstroke
.6 g
.5 .24967 m
.51923 .24947 L
.53846 .24989 L
.54213 .25 L
.55769 .25093 L
.57692 .25266 L
.59615 .25516 L
.61538 .25862 L
.63462 .26338 L
.6517 .26923 L
.65385 .27007 L
.67308 .27955 L
.68454 .28846 L
.69158 .30769 L
.6765 .32692 L
.67308 .32994 L
.65385 .34092 L
.63541 .34615 L
.63462 .34642 L
.61538 .35192 L
.59615 .35612 L
.57692 .35934 L
.55769 .36174 L
.53846 .36344 L
.51923 .3645 L
.5 .36493 L
.48077 .36475 L
.46154 .36395 L
.44231 .36249 L
.42308 .36029 L
.40385 .3572 L
.38462 .35296 L
.36538 .34705 L
.36297 .34615 L
.34615 .34328 L
.32907 .32692 L
.32692 .32447 L
.32131 .30769 L
.32692 .29607 L
.33462 .28846 L
.34615 .27905 L
.36538 .2711 L
.37346 .26923 L
.38462 .26565 L
.40385 .2607 L
.42308 .25691 L
.44231 .25404 L
.46154 .25192 L
.48077 .25049 L
.4905 .25 L
F
0 g
.5 .24967 m
.51923 .24947 L
.53846 .24989 L
.54213 .25 L
.55769 .25093 L
.57692 .25266 L
.59615 .25516 L
.61538 .25862 L
.63462 .26338 L
.6517 .26923 L
.65385 .27007 L
.67308 .27955 L
.68454 .28846 L
.69158 .30769 L
.6765 .32692 L
.67308 .32994 L
.65385 .34092 L
.63541 .34615 L
.63462 .34642 L
.61538 .35192 L
.59615 .35612 L
.57692 .35934 L
.55769 .36174 L
.53846 .36344 L
.51923 .3645 L
.5 .36493 L
.48077 .36475 L
.46154 .36395 L
.44231 .36249 L
.42308 .36029 L
.40385 .3572 L
.38462 .35296 L
.36538 .34705 L
.36297 .34615 L
.34615 .34328 L
.32907 .32692 L
.32692 .32447 L
.32131 .30769 L
.32692 .29607 L
.33462 .28846 L
.34615 .27905 L
.36538 .2711 L
.37346 .26923 L
.38462 .26565 L
.40385 .2607 L
.42308 .25691 L
.44231 .25404 L
.46154 .25192 L
.48077 .25049 L
.4905 .25 L
Mistroke
.5 .24967 L
Mfstroke
.7 g
.40385 .65092 m
.42308 .64657 L
.44231 .64354 L
.46154 .64152 L
.48077 .64036 L
.5 .63999 L
.51923 .64036 L
.53846 .6415 L
.55769 .64346 L
.57692 .64636 L
.59615 .65042 L
.60868 .65385 L
.61538 .65505 L
.63462 .66115 L
.65083 .67308 L
.65385 .67562 L
.6639 .69231 L
.6545 .71154 L
.65385 .71249 L
.63462 .72745 L
.61622 .73077 L
.61538 .73104 L
.59615 .73627 L
.57692 .73993 L
.55769 .74244 L
.53846 .74403 L
.51923 .7448 L
.5 .74482 L
.48077 .74408 L
.46154 .74255 L
.44231 .74016 L
.42308 .73675 L
.40385 .73201 L
.39967 .73077 L
.38462 .72758 L
.36538 .71818 L
.35819 .71154 L
.34615 .69538 L
.34556 .69231 L
.34615 .68675 L
.35519 .67308 L
.36538 .66243 L
.38462 .65505 L
.3939 .65385 L
F
0 g
.40385 .65092 m
.42308 .64657 L
.44231 .64354 L
.46154 .64152 L
.48077 .64036 L
.5 .63999 L
.51923 .64036 L
.53846 .6415 L
.55769 .64346 L
.57692 .64636 L
.59615 .65042 L
.60868 .65385 L
.61538 .65505 L
.63462 .66115 L
.65083 .67308 L
.65385 .67562 L
.6639 .69231 L
.6545 .71154 L
.65385 .71249 L
.63462 .72745 L
.61622 .73077 L
.61538 .73104 L
.59615 .73627 L
.57692 .73993 L
.55769 .74244 L
.53846 .74403 L
.51923 .7448 L
.5 .74482 L
.48077 .74408 L
.46154 .74255 L
.44231 .74016 L
.42308 .73675 L
.40385 .73201 L
.39967 .73077 L
.38462 .72758 L
.36538 .71818 L
.35819 .71154 L
.34615 .69538 L
.34556 .69231 L
.34615 .68675 L
.35519 .67308 L
.36538 .66243 L
.38462 .65505 L
.3939 .65385 L
.40385 .65092 L
s
.7 g
.42308 .26741 m
.44231 .26378 L
.46154 .2612 L
.48077 .25949 L
.5 .25856 L
.51923 .25836 L
.53846 .25892 L
.55769 .26027 L
.57692 .26253 L
.59615 .26593 L
.60978 .26923 L
.61538 .2708 L
.63462 .27771 L
.65279 .28846 L
.65385 .28943 L
.66152 .30769 L
.65385 .31982 L
.6447 .32692 L
.63462 .33382 L
.61538 .34158 L
.59615 .34559 L
.5923 .34615 L
.57692 .34931 L
.55769 .35227 L
.53846 .35431 L
.51923 .35554 L
.5 .35601 L
.48077 .35575 L
.46154 .3547 L
.44231 .3528 L
.42308 .34986 L
.40605 .34615 L
.40385 .34599 L
.38462 .34331 L
.36538 .33279 L
.36039 .32692 L
.35037 .30769 L
.36538 .28867 L
.36569 .28846 L
.38462 .27657 L
.40385 .27104 L
.41525 .26923 L
F
0 g
.42308 .26741 m
.44231 .26378 L
.46154 .2612 L
.48077 .25949 L
.5 .25856 L
.51923 .25836 L
.53846 .25892 L
.55769 .26027 L
.57692 .26253 L
.59615 .26593 L
.60978 .26923 L
.61538 .2708 L
.63462 .27771 L
.65279 .28846 L
.65385 .28943 L
.66152 .30769 L
.65385 .31982 L
.6447 .32692 L
.63462 .33382 L
.61538 .34158 L
.59615 .34559 L
.5923 .34615 L
.57692 .34931 L
.55769 .35227 L
.53846 .35431 L
.51923 .35554 L
.5 .35601 L
.48077 .35575 L
.46154 .3547 L
.44231 .3528 L
.42308 .34986 L
.40605 .34615 L
.40385 .34599 L
.38462 .34331 L
.36538 .33279 L
.36039 .32692 L
.35037 .30769 L
.36538 .28867 L
.36569 .28846 L
.38462 .27657 L
.40385 .27104 L
.41525 .26923 L
.42308 .26741 L
s
.8 g
.44231 .65367 m
.46154 .65098 L
.48077 .64946 L
.5 .64894 L
.51923 .64937 L
.53846 .65078 L
.55769 .65325 L
.56137 .65385 L
.57692 .65556 L
.59615 .65967 L
.61538 .66878 L
.6209 .67308 L
.63462 .68661 L
.63647 .69231 L
.63462 .70063 L
.62465 .71154 L
.61538 .71985 L
.59615 .72769 L
.57692 .73026 L
.56976 .73077 L
.55769 .73269 L
.53846 .73479 L
.51923 .73581 L
.5 .73587 L
.48077 .73498 L
.46154 .73308 L
.44616 .73077 L
.44231 .73042 L
.42308 .72777 L
.40385 .72189 L
.38793 .71154 L
.38462 .70921 L
.3728 .69231 L
.38462 .67338 L
.38503 .67308 L
.40385 .6601 L
.42308 .65553 L
.44127 .65385 L
F
0 g
.44231 .65367 m
.46154 .65098 L
.48077 .64946 L
.5 .64894 L
.51923 .64937 L
.53846 .65078 L
.55769 .65325 L
.56137 .65385 L
.57692 .65556 L
.59615 .65967 L
.61538 .66878 L
.6209 .67308 L
.63462 .68661 L
.63647 .69231 L
.63462 .70063 L
.62465 .71154 L
.61538 .71985 L
.59615 .72769 L
.57692 .73026 L
.56976 .73077 L
.55769 .73269 L
.53846 .73479 L
.51923 .73581 L
.5 .73587 L
.48077 .73498 L
.46154 .73308 L
.44616 .73077 L
.44231 .73042 L
.42308 .72777 L
.40385 .72189 L
.38793 .71154 L
.38462 .70921 L
.3728 .69231 L
.38462 .67338 L
.38503 .67308 L
.40385 .6601 L
.42308 .65553 L
.44127 .65385 L
.44231 .65367 L
s
.8 g
.5 .2682 m
.51923 .26804 L
.53846 .26887 L
.54418 .26923 L
.55769 .26965 L
.57692 .27077 L
.59615 .27409 L
.61538 .28633 L
.61909 .28846 L
.63101 .30769 L
.61538 .32432 L
.61062 .32692 L
.59615 .33448 L
.57692 .34032 L
.55769 .34346 L
.53846 .34516 L
.51923 .34599 L
.51157 .34615 L
.5 .34635 L
.48675 .34615 L
.48077 .34605 L
.46154 .34543 L
.44231 .34418 L
.42308 .34139 L
.40385 .33415 L
.39439 .32692 L
.38462 .31877 L
.3807 .30769 L
.38462 .29971 L
.39927 .28846 L
.40385 .28539 L
.42308 .27678 L
.44231 .27247 L
.46154 .27031 L
.48077 .26927 L
.48184 .26923 L
F
0 g
.5 .2682 m
.51923 .26804 L
.53846 .26887 L
.54418 .26923 L
.55769 .26965 L
.57692 .27077 L
.59615 .27409 L
.61538 .28633 L
.61909 .28846 L
.63101 .30769 L
.61538 .32432 L
.61062 .32692 L
.59615 .33448 L
.57692 .34032 L
.55769 .34346 L
.53846 .34516 L
.51923 .34599 L
.51157 .34615 L
.5 .34635 L
.48675 .34615 L
.48077 .34605 L
.46154 .34543 L
.44231 .34418 L
.42308 .34139 L
.40385 .33415 L
.39439 .32692 L
.38462 .31877 L
.3807 .30769 L
.38462 .29971 L
.39927 .28846 L
.40385 .28539 L
.42308 .27678 L
.44231 .27247 L
.46154 .27031 L
.48077 .26927 L
.48184 .26923 L
.5 .2682 L
s
.9 g
.42308 .67065 m
.44231 .66224 L
.46154 .6586 L
.48077 .65707 L
.5 .65664 L
.51923 .65707 L
.53846 .65853 L
.55769 .66168 L
.57692 .668 L
.58635 .67308 L
.59615 .67859 L
.6067 .69231 L
.59615 .70805 L
.59027 .71154 L
.57692 .71939 L
.55769 .72495 L
.53846 .7273 L
.51923 .72818 L
.5 .72819 L
.48077 .72734 L
.46154 .72524 L
.44231 .72087 L
.42308 .712 L
.42236 .71154 L
.40385 .69649 L
.40257 .69231 L
.40385 .68661 L
.41959 .67308 L
F
0 g
.42308 .67065 m
.44231 .66224 L
.46154 .6586 L
.48077 .65707 L
.5 .65664 L
.51923 .65707 L
.53846 .65853 L
.55769 .66168 L
.57692 .668 L
.58635 .67308 L
.59615 .67859 L
.6067 .69231 L
.59615 .70805 L
.59027 .71154 L
.57692 .71939 L
.55769 .72495 L
.53846 .7273 L
.51923 .72818 L
.5 .72819 L
.48077 .72734 L
.46154 .72524 L
.44231 .72087 L
.42308 .712 L
.42236 .71154 L
.40385 .69649 L
.40257 .69231 L
.40385 .68661 L
.41959 .67308 L
.42308 .67065 L
s
.9 g
.44231 .288 m
.46154 .28122 L
.48077 .27761 L
.5 .27592 L
.51923 .27563 L
.53846 .27678 L
.55769 .28021 L
.57692 .28841 L
.577 .28846 L
.59615 .30393 L
.59629 .30769 L
.59615 .30814 L
.57692 .32346 L
.56754 .32692 L
.55769 .33047 L
.53846 .33505 L
.51923 .3374 L
.5 .33818 L
.48077 .33753 L
.46154 .33502 L
.44231 .32918 L
.43755 .32692 L
.42308 .3198 L
.41534 .30769 L
.42308 .2974 L
.44133 .28846 L
F
0 g
.44231 .288 m
.46154 .28122 L
.48077 .27761 L
.5 .27592 L
.51923 .27563 L
.53846 .27678 L
.55769 .28021 L
.57692 .28841 L
.577 .28846 L
.59615 .30393 L
.59629 .30769 L
.59615 .30814 L
.57692 .32346 L
.56754 .32692 L
.55769 .33047 L
.53846 .33505 L
.51923 .3374 L
.5 .33818 L
.48077 .33753 L
.46154 .33502 L
.44231 .32918 L
.43755 .32692 L
.42308 .3198 L
.41534 .30769 L
.42308 .2974 L
.44133 .28846 L
.44231 .288 L
s
1 g
.48077 .67205 m
.5 .67022 L
.51923 .67122 L
.53011 .67308 L
.53846 .67461 L
.55769 .68089 L
.56965 .69231 L
.55769 .70501 L
.53846 .71094 L
.53518 .71154 L
.51923 .71427 L
.5 .7147 L
.48077 .7123 L
.47659 .71154 L
.46154 .70788 L
.44231 .69742 L
.43971 .69231 L
.44231 .68634 L
.46154 .67619 L
.47414 .67308 L
F
0 g
.48077 .67205 m
.5 .67022 L
.51923 .67122 L
.53011 .67308 L
.53846 .67461 L
.55769 .68089 L
.56965 .69231 L
.55769 .70501 L
.53846 .71094 L
.53518 .71154 L
.51923 .71427 L
.5 .7147 L
.48077 .7123 L
.47659 .71154 L
.46154 .70788 L
.44231 .69742 L
.43971 .69231 L
.44231 .68634 L
.46154 .67619 L
.47414 .67308 L
.48077 .67205 L
s
1 g
.48077 .29862 m
.5 .29548 L
.51923 .29576 L
.53846 .30033 L
.54543 .30769 L
.53846 .31303 L
.51923 .31817 L
.5 .3191 L
.48077 .31662 L
.46549 .30769 L
F
0 g
.48077 .29862 m
.5 .29548 L
.51923 .29576 L
.53846 .30033 L
.54543 .30769 L
.53846 .31303 L
.51923 .31817 L
.5 .3191 L
.48077 .31662 L
.46549 .30769 L
.48077 .29862 L
s
.5 g
.86538 .20436 m
.88462 .20105 L
.89961 .21154 L
.90385 .2166 L
.91378 .23077 L
.92187 .25 L
.92308 .25367 L
.92835 .26923 L
.93323 .28846 L
.9366 .30769 L
.93881 .32692 L
.94026 .34615 L
.94132 .36538 L
.94229 .38462 L
.94231 .385 L
.94329 .40385 L
.94431 .42308 L
.94525 .44231 L
.94605 .46154 L
.94663 .48077 L
.94698 .5 L
.94708 .51923 L
.94695 .53846 L
.94662 .55769 L
.94612 .57692 L
.94554 .59615 L
.9449 .61538 L
.9442 .63462 L
.94332 .65385 L
.94231 .66952 L
.94203 .67308 L
.94007 .69231 L
.93718 .71154 L
.93319 .73077 L
.92793 .75 L
.92308 .76429 L
.92166 .76923 L
.91433 .78846 L
.90385 .80368 L
.90069 .80769 L
.88462 .81892 L
.86538 .81211 L
.86094 .80769 L
.84642 .78846 L
.84615 .78806 L
.83386 .76923 L
.82692 .75761 L
.82213 .75 L
.80976 .73077 L
.80769 .72817 L
.79951 .71154 L
.79265 .69231 L
.79483 .67308 L
.80087 .65385 L
.80639 .63462 L
.80769 .62934 L
.81068 .61538 L
.81335 .59615 L
.8147 .57692 L
.81519 .55769 L
.81528 .53846 L
.81527 .51923 L
.81534 .5 L
.81555 .48077 L
.81587 .46154 L
.81611 .44231 L
.81596 .42308 L
.81495 .40385 L
.81249 .38462 L
.80804 .36538 L
.80769 .36422 L
.80195 .34615 L
.7945 .32692 L
.78996 .30769 L
.79718 .28846 L
.80769 .27074 L
.8093 .26923 L
.82395 .25 L
.82692 .24611 L
.83845 .23077 L
.84615 .22207 L
.85622 .21154 L
F
0 g
.86538 .20436 m
.88462 .20105 L
.89961 .21154 L
.90385 .2166 L
.91378 .23077 L
.92187 .25 L
.92308 .25367 L
.92835 .26923 L
.93323 .28846 L
.9366 .30769 L
.93881 .32692 L
.94026 .34615 L
.94132 .36538 L
.94229 .38462 L
.94231 .385 L
.94329 .40385 L
.94431 .42308 L
.94525 .44231 L
.94605 .46154 L
.94663 .48077 L
.94698 .5 L
.94708 .51923 L
.94695 .53846 L
.94662 .55769 L
.94612 .57692 L
.94554 .59615 L
.9449 .61538 L
.9442 .63462 L
.94332 .65385 L
.94231 .66952 L
.94203 .67308 L
.94007 .69231 L
.93718 .71154 L
.93319 .73077 L
.92793 .75 L
.92308 .76429 L
.92166 .76923 L
.91433 .78846 L
.90385 .80368 L
.90069 .80769 L
.88462 .81892 L
.86538 .81211 L
.86094 .80769 L
.84642 .78846 L
.84615 .78806 L
.83386 .76923 L
.82692 .75761 L
.82213 .75 L
.80976 .73077 L
.80769 .72817 L
Mistroke
.79951 .71154 L
.79265 .69231 L
.79483 .67308 L
.80087 .65385 L
.80639 .63462 L
.80769 .62934 L
.81068 .61538 L
.81335 .59615 L
.8147 .57692 L
.81519 .55769 L
.81528 .53846 L
.81527 .51923 L
.81534 .5 L
.81555 .48077 L
.81587 .46154 L
.81611 .44231 L
.81596 .42308 L
.81495 .40385 L
.81249 .38462 L
.80804 .36538 L
.80769 .36422 L
.80195 .34615 L
.7945 .32692 L
.78996 .30769 L
.79718 .28846 L
.80769 .27074 L
.8093 .26923 L
.82395 .25 L
.82692 .24611 L
.83845 .23077 L
.84615 .22207 L
.85622 .21154 L
.86538 .20436 L
Mfstroke
.6 g
.86538 .23793 m
.88462 .23693 L
.90026 .25 L
.90385 .25504 L
.91206 .26923 L
.91874 .28846 L
.92273 .30769 L
.92308 .30985 L
.92559 .32692 L
.92748 .34615 L
.92887 .36538 L
.93013 .38462 L
.9314 .40385 L
.93267 .42308 L
.93383 .44231 L
.93478 .46154 L
.93548 .48077 L
.93589 .5 L
.936 .51923 L
.93584 .53846 L
.93542 .55769 L
.93481 .57692 L
.93408 .59615 L
.93328 .61538 L
.93238 .63462 L
.93125 .65385 L
.92961 .67308 L
.92707 .69231 L
.92323 .71154 L
.92308 .71217 L
.91855 .73077 L
.91093 .75 L
.90385 .76095 L
.89741 .76923 L
.88462 .77807 L
.86538 .77379 L
.85978 .76923 L
.84615 .75399 L
.84297 .75 L
.83039 .73077 L
.82692 .72458 L
.82112 .71154 L
.81576 .69231 L
.81523 .67308 L
.81786 .65385 L
.82125 .63462 L
.82403 .61538 L
.82576 .59615 L
.82654 .57692 L
.82671 .55769 L
.82662 .53846 L
.82653 .51923 L
.8266 .5 L
.82689 .48077 L
.82692 .47879 L
.82732 .46154 L
.82779 .44231 L
.82802 .42308 L
.82766 .40385 L
.82692 .39171 L
.82625 .38462 L
.82346 .36538 L
.81968 .34615 L
.8163 .32692 L
.81612 .30769 L
.82168 .28846 L
.82692 .27753 L
.83232 .26923 L
.84615 .25285 L
.84903 .25 L
F
0 g
.86538 .23793 m
.88462 .23693 L
.90026 .25 L
.90385 .25504 L
.91206 .26923 L
.91874 .28846 L
.92273 .30769 L
.92308 .30985 L
.92559 .32692 L
.92748 .34615 L
.92887 .36538 L
.93013 .38462 L
.9314 .40385 L
.93267 .42308 L
.93383 .44231 L
.93478 .46154 L
.93548 .48077 L
.93589 .5 L
.936 .51923 L
.93584 .53846 L
.93542 .55769 L
.93481 .57692 L
.93408 .59615 L
.93328 .61538 L
.93238 .63462 L
.93125 .65385 L
.92961 .67308 L
.92707 .69231 L
.92323 .71154 L
.92308 .71217 L
.91855 .73077 L
.91093 .75 L
.90385 .76095 L
.89741 .76923 L
.88462 .77807 L
.86538 .77379 L
.85978 .76923 L
.84615 .75399 L
.84297 .75 L
.83039 .73077 L
.82692 .72458 L
.82112 .71154 L
.81576 .69231 L
.81523 .67308 L
.81786 .65385 L
.82125 .63462 L
.82403 .61538 L
.82576 .59615 L
.82654 .57692 L
.82671 .55769 L
Mistroke
.82662 .53846 L
.82653 .51923 L
.8266 .5 L
.82689 .48077 L
.82692 .47879 L
.82732 .46154 L
.82779 .44231 L
.82802 .42308 L
.82766 .40385 L
.82692 .39171 L
.82625 .38462 L
.82346 .36538 L
.81968 .34615 L
.8163 .32692 L
.81612 .30769 L
.82168 .28846 L
.82692 .27753 L
.83232 .26923 L
.84615 .25285 L
.84903 .25 L
.86538 .23793 L
Mfstroke
.7 g
.84615 .28729 m
.86538 .26957 L
.88462 .27078 L
.89927 .28846 L
.90385 .29884 L
.90693 .30769 L
.91146 .32692 L
.91421 .34615 L
.91616 .36538 L
.91785 .38462 L
.91941 .40385 L
.9208 .42308 L
.92195 .44231 L
.92282 .46154 L
.92308 .46809 L
.92361 .48077 L
.92414 .5 L
.92428 .51923 L
.92404 .53846 L
.92348 .55769 L
.92308 .568 L
.9228 .57692 L
.92211 .59615 L
.92128 .61538 L
.92028 .63462 L
.91893 .65385 L
.91685 .67308 L
.91339 .69231 L
.90736 .71154 L
.90385 .71907 L
.89713 .73077 L
.88462 .7423 L
.86538 .74039 L
.85444 .73077 L
.84615 .71991 L
.84133 .71154 L
.83452 .69231 L
.83253 .67308 L
.83341 .65385 L
.83537 .63462 L
.83714 .61538 L
.83817 .59615 L
.83847 .57692 L
.83831 .55769 L
.83802 .53846 L
.83784 .51923 L
.83792 .5 L
.83831 .48077 L
.83899 .46154 L
.83983 .44231 L
.84057 .42308 L
.84083 .40385 L
.8402 .38462 L
.83852 .36538 L
.83629 .34615 L
.83495 .32692 L
.83687 .30769 L
.84537 .28846 L
F
0 g
.84615 .28729 m
.86538 .26957 L
.88462 .27078 L
.89927 .28846 L
.90385 .29884 L
.90693 .30769 L
.91146 .32692 L
.91421 .34615 L
.91616 .36538 L
.91785 .38462 L
.91941 .40385 L
.9208 .42308 L
.92195 .44231 L
.92282 .46154 L
.92308 .46809 L
.92361 .48077 L
.92414 .5 L
.92428 .51923 L
.92404 .53846 L
.92348 .55769 L
.92308 .568 L
.9228 .57692 L
.92211 .59615 L
.92128 .61538 L
.92028 .63462 L
.91893 .65385 L
.91685 .67308 L
.91339 .69231 L
.90736 .71154 L
.90385 .71907 L
.89713 .73077 L
.88462 .7423 L
.86538 .74039 L
.85444 .73077 L
.84615 .71991 L
.84133 .71154 L
.83452 .69231 L
.83253 .67308 L
.83341 .65385 L
.83537 .63462 L
.83714 .61538 L
.83817 .59615 L
.83847 .57692 L
.83831 .55769 L
.83802 .53846 L
.83784 .51923 L
.83792 .5 L
.83831 .48077 L
.83899 .46154 L
.83983 .44231 L
Mistroke
.84057 .42308 L
.84083 .40385 L
.8402 .38462 L
.83852 .36538 L
.83629 .34615 L
.83495 .32692 L
.83687 .30769 L
.84537 .28846 L
.84615 .28729 L
Mfstroke
.8 g
.86538 .31657 m
.88462 .32087 L
.8874 .32692 L
.89281 .34615 L
.89604 .36538 L
.89882 .38462 L
.90163 .40385 L
.90385 .41939 L
.90447 .42308 L
.90744 .44231 L
.90972 .46154 L
.91126 .48077 L
.9121 .5 L
.91231 .51923 L
.91191 .53846 L
.91096 .55769 L
.90953 .57692 L
.90777 .59615 L
.90584 .61538 L
.90385 .6339 L
.90378 .63462 L
.90154 .65385 L
.8979 .67308 L
.89081 .69231 L
.88462 .70093 L
.86538 .7006 L
.85961 .69231 L
.85356 .67308 L
.85231 .65385 L
.85285 .63462 L
.85354 .61538 L
.85371 .59615 L
.85333 .57692 L
.85267 .55769 L
.85206 .53846 L
.85174 .51923 L
.85186 .5 L
.85247 .48077 L
.85357 .46154 L
.85507 .44231 L
.85675 .42308 L
.85823 .40385 L
.85909 .38462 L
.85916 .36538 L
.85916 .34615 L
.86161 .32692 L
F
0 g
.86538 .31657 m
.88462 .32087 L
.8874 .32692 L
.89281 .34615 L
.89604 .36538 L
.89882 .38462 L
.90163 .40385 L
.90385 .41939 L
.90447 .42308 L
.90744 .44231 L
.90972 .46154 L
.91126 .48077 L
.9121 .5 L
.91231 .51923 L
.91191 .53846 L
.91096 .55769 L
.90953 .57692 L
.90777 .59615 L
.90584 .61538 L
.90385 .6339 L
.90378 .63462 L
.90154 .65385 L
.8979 .67308 L
.89081 .69231 L
.88462 .70093 L
.86538 .7006 L
.85961 .69231 L
.85356 .67308 L
.85231 .65385 L
.85285 .63462 L
.85354 .61538 L
.85371 .59615 L
.85333 .57692 L
.85267 .55769 L
.85206 .53846 L
.85174 .51923 L
.85186 .5 L
.85247 .48077 L
.85357 .46154 L
.85507 .44231 L
.85675 .42308 L
.85823 .40385 L
.85909 .38462 L
.85916 .36538 L
.85916 .34615 L
.86161 .32692 L
.86538 .31657 L
s
.1 g
.98077 .73392 m
.97843 .75 L
.97528 .76923 L
.97188 .78846 L
.96833 .80769 L
.96464 .82692 L
.96154 .84236 L
.96075 .84615 L
.95657 .86538 L
.95199 .88462 L
.94687 .90385 L
.94231 .91908 L
.94105 .92308 L
.93431 .94231 L
.92588 .96154 L
.92308 .96691 L
.91689 .98077 L
.98077 .98077 L
F
0 g
.98077 .73392 m
.97843 .75 L
.97528 .76923 L
.97188 .78846 L
.96833 .80769 L
.96464 .82692 L
.96154 .84236 L
.96075 .84615 L
.95657 .86538 L
.95199 .88462 L
.94687 .90385 L
.94231 .91908 L
.94105 .92308 L
.93431 .94231 L
.92588 .96154 L
.92308 .96691 L
.91689 .98077 L
s
.98077 .11785 m
.98031 .11538 L
.97654 .09615 L
.97237 .07692 L
.96777 .05769 L
.96268 .03846 L
.96154 .03439 L
.95706 .01923 L
.98077 .01923 L
F
.98077 .11785 m
.98031 .11538 L
.97654 .09615 L
.97237 .07692 L
.96777 .05769 L
.96268 .03846 L
.96154 .03439 L
.95706 .01923 L
s
.98077 .91793 m
.97979 .92308 L
.9759 .94231 L
.97156 .96154 L
.96676 .98077 L
.98077 .98077 L
F
.98077 .91793 m
.97979 .92308 L
.9759 .94231 L
.97156 .96154 L
.96676 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53046 Mtetra
.62323 .53046 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52373 Mtetra
.64556 .52373 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .50321 Mtetra
.71364 .50321 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49626 Mtetra
.663 .741 .908 r
.7367 .49626 .74193 .50267 .7535 .49921 .7483 .49277 Mtetra
.7483 .49277 .7535 .49921 .76511 .49574 .75995 .48927 Mtetra
.662 .741 .909 r
.75995 .48927 .76511 .49574 .77678 .4923 .77165 .48581 Mtetra
.658 .74 .91 r
.77165 .48581 .77678 .4923 .7885 .48893 .78341 .48244 Mtetra
.649 .737 .913 r
.78341 .48244 .7885 .48893 .80029 .48579 .79524 .47932 Mtetra
.63 .731 .92 r
.79524 .47932 .80029 .48579 .81217 .48311 .80716 .47673 Mtetra
.592 .719 .932 r
.80716 .47673 .81217 .48311 .82419 .48128 .81923 .47509 Mtetra
.522 .695 .947 r
.81923 .47509 .82419 .48128 .83639 .48076 .8315 .47493 Mtetra
.404 .649 .957 r
.8315 .47493 .83639 .48076 .84883 .48192 .84404 .47669 Mtetra
.24 .576 .942 r
.84404 .47669 .84883 .48192 .86153 .48478 .85685 .48035 Mtetra
.078 .503 .899 r
.85685 .48035 .86153 .48478 .87444 .48867 .8699 .48518 Mtetra
.013 .496 .872 r
.8699 .48518 .87444 .48867 .88742 .49221 .88302 .48963 Mtetra
.125 .616 .911 r
.88302 .48963 .88742 .49221 .90027 .49367 .89599 .49172 Mtetra
.417 .827 .975 r
.89599 .49172 .90027 .49367 .9128 .4916 .9086 .48981 Mtetra
.701 .952 .953 r
.9086 .48981 .9128 .4916 .92491 .48551 .92073 .48337 Mtetra
.839 .96 .888 r
.92073 .48337 .92491 .48551 .93665 .47614 .93244 .47322 Mtetra
.88 .931 .851 r
.93244 .47322 .93665 .47614 .94817 .46505 .9439 .46114 Mtetra
.874 .897 .846 r
.9439 .46114 .94817 .46505 .95969 .45395 .95535 .44907 Mtetra
.842 .863 .859 r
.95535 .44907 .95969 .45395 .97138 .44409 .96699 .43839 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55084 Mtetra
.52983 .55084 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54427 Mtetra
.55153 .54427 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53765 Mtetra
.57339 .53765 .57909 .54376 .59006 .54045 .58439 .53432 Mtetra
.58439 .53432 .59006 .54045 .60107 .53713 .59543 .53098 Mtetra
.59543 .53098 .60107 .53713 .61213 .5338 .60652 .52762 Mtetra
.60652 .52762 .61213 .5338 .62323 .53046 .61765 .52425 Mtetra
.61765 .52425 .62323 .53046 .63437 .5271 .62882 .52087 Mtetra
.62882 .52087 .63437 .5271 .64556 .52373 .64004 .51747 Mtetra
.64004 .51747 .64556 .52373 .65679 .52034 .65131 .51406 Mtetra
.65131 .51406 .65679 .52034 .66807 .51694 .66261 .51064 Mtetra
.664 .742 .908 r
.66261 .51064 .66807 .51694 .67939 .51353 .67397 .5072 Mtetra
.67397 .5072 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50028 Mtetra
.69682 .50028 .70218 .50666 .71364 .50321 .70831 .4968 Mtetra
.664 .741 .908 r
.70831 .4968 .71364 .50321 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49626 .73144 .4898 Mtetra
.663 .741 .908 r
.73144 .4898 .7367 .49626 .7483 .49277 .74307 .48628 Mtetra
.74307 .48628 .7483 .49277 .75995 .48927 .75475 .48276 Mtetra
.661 .741 .909 r
.75475 .48276 .75995 .48927 .77165 .48581 .76649 .47928 Mtetra
.657 .739 .91 r
.76649 .47928 .77165 .48581 .78341 .48244 .77828 .47591 Mtetra
.647 .736 .914 r
.77828 .47591 .78341 .48244 .79524 .47932 .79015 .47281 Mtetra
.626 .73 .922 r
.79015 .47281 .79524 .47932 .80716 .47673 .80212 .47031 Mtetra
.582 .715 .934 r
.80212 .47031 .80716 .47673 .81923 .47509 .81424 .46888 Mtetra
.5 .685 .95 r
.81424 .46888 .81923 .47509 .8315 .47493 .82658 .46913 Mtetra
.36 .626 .954 r
.82658 .46913 .8315 .47493 .84404 .47669 .83921 .47152 Mtetra
.164 .532 .922 r
.83921 .47152 .84404 .47669 .85685 .48035 .85215 .47606 Mtetra
0 .435 .853 r
.85215 .47606 .85685 .48035 .8699 .48518 .86534 .48191 Mtetra
0 .418 .809 r
.86534 .48191 .8699 .48518 .88302 .48963 .8786 .48733 Mtetra
.024 .553 .857 r
.8786 .48733 .88302 .48963 .89599 .49172 .8917 .4901 Mtetra
.365 .809 .952 r
.8917 .4901 .89599 .49172 .9086 .48981 .90439 .48838 Mtetra
.701 .964 .941 r
.90439 .48838 .9086 .48981 .92073 .48337 .91654 .48156 Mtetra
.854 .97 .871 r
.91654 .48156 .92073 .48337 .93244 .47322 .92822 .47057 Mtetra
.896 .937 .832 r
.92822 .47057 .93244 .47322 .9439 .46114 .93961 .45742 Mtetra
.89 .903 .83 r
.93961 .45742 .9439 .46114 .95535 .44907 .951 .44429 Mtetra
.857 .87 .848 r
.951 .44429 .95535 .44907 .96699 .43839 .96257 .43274 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .58341 Mtetra
.397 .58341 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55786 Mtetra
.663 .741 .908 r
.48099 .55786 .48695 .56382 .49761 .56059 .49168 .55461 Mtetra
.49168 .55461 .49761 .56059 .50831 .55735 .5024 .55135 Mtetra
.5024 .55135 .50831 .55735 .51905 .5541 .51317 .54807 Mtetra
.663 .742 .908 r
.51317 .54807 .51905 .5541 .52983 .55084 .52398 .54478 Mtetra
.52398 .54478 .52983 .55084 .54066 .54756 .53484 .54148 Mtetra
.53484 .54148 .54066 .54756 .55153 .54427 .54573 .53817 Mtetra
.54573 .53817 .55153 .54427 .56244 .54096 .55667 .53485 Mtetra
.55667 .53485 .56244 .54096 .57339 .53765 .56766 .53151 Mtetra
.56766 .53151 .57339 .53765 .58439 .53432 .57868 .52815 Mtetra
.57868 .52815 .58439 .53432 .59543 .53098 .58975 .52479 Mtetra
.58975 .52479 .59543 .53098 .60652 .52762 .60087 .52141 Mtetra
.60087 .52141 .60652 .52762 .61765 .52425 .61203 .51802 Mtetra
.663 .742 .909 r
.61203 .51802 .61765 .52425 .62882 .52087 .62323 .51461 Mtetra
.62323 .51461 .62882 .52087 .64004 .51747 .63448 .51119 Mtetra
.63448 .51119 .64004 .51747 .65131 .51406 .64578 .50775 Mtetra
.64578 .50775 .65131 .51406 .66261 .51064 .65712 .50431 Mtetra
.664 .742 .909 r
.65712 .50431 .66261 .51064 .67397 .5072 .6685 .50084 Mtetra
.6685 .50084 .67397 .5072 .68537 .50374 .67994 .49736 Mtetra
.67994 .49736 .68537 .50374 .69682 .50028 .69141 .49387 Mtetra
.69141 .49387 .69682 .50028 .70831 .4968 .70294 .49036 Mtetra
.70294 .49036 .70831 .4968 .71985 .4933 .71451 .48684 Mtetra
.71451 .48684 .71985 .4933 .73144 .4898 .72613 .48331 Mtetra
.663 .742 .909 r
.72613 .48331 .73144 .4898 .74307 .48628 .7378 .47976 Mtetra
.7378 .47976 .74307 .48628 .75475 .48276 .74952 .47622 Mtetra
.661 .741 .909 r
.74952 .47622 .75475 .48276 .76649 .47928 .76128 .47272 Mtetra
.657 .74 .911 r
.76128 .47272 .76649 .47928 .77828 .47591 .77311 .46934 Mtetra
.645 .736 .915 r
.77311 .46934 .77828 .47591 .79015 .47281 .78502 .46627 Mtetra
.621 .728 .923 r
.78502 .46627 .79015 .47281 .80212 .47031 .79703 .46387 Mtetra
.571 .711 .937 r
.79703 .46387 .80212 .47031 .81424 .46888 .80921 .46267 Mtetra
.475 .674 .952 r
.80921 .46267 .81424 .46888 .82658 .46913 .82162 .46334 Mtetra
.31 .6 .948 r
.82162 .46334 .82658 .46913 .83921 .47152 .83435 .46642 Mtetra
.079 .478 .893 r
.83435 .46642 .83921 .47152 .85215 .47606 .84742 .4719 Mtetra
0 .357 .793 r
.84742 .4719 .85215 .47606 .86534 .48191 .86075 .47885 Mtetra
0 .331 .733 r
.86075 .47885 .86534 .48191 .8786 .48733 .87418 .48532 Mtetra
0 .479 .79 r
.87418 .48532 .8786 .48733 .8917 .4901 .88741 .48883 Mtetra
.307 .784 .922 r
.88741 .48883 .8917 .4901 .90439 .48838 .90018 .4873 Mtetra
.701 .972 .925 r
.90018 .4873 .90439 .48838 .91654 .48156 .91235 .48007 Mtetra
.868 .977 .85 r
.91235 .48007 .91654 .48156 .92822 .47057 .92399 .46817 Mtetra
.911 .941 .812 r
.92399 .46817 .92822 .47057 .93961 .45742 .93531 .45387 Mtetra
.905 .907 .813 r
.93531 .45387 .93961 .45742 .951 .44429 .94662 .4396 Mtetra
.872 .875 .835 r
.94662 .4396 .951 .44429 .96257 .43274 .95813 .42712 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .58341 .39079 .57758 Mtetra
.39079 .57758 .397 .58341 .40736 .58025 .40117 .57441 Mtetra
.40117 .57441 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.663 .741 .908 r
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56803 Mtetra
.42206 .56803 .42819 .57392 .43867 .57073 .43256 .56482 Mtetra
.43256 .56482 .43867 .57073 .44919 .56753 .44311 .5616 Mtetra
.663 .742 .908 r
.44311 .5616 .44919 .56753 .45975 .56432 .45369 .55836 Mtetra
.45369 .55836 .45975 .56432 .47035 .56109 .46432 .55512 Mtetra
.46432 .55512 .47035 .56109 .48099 .55786 .47499 .55186 Mtetra
.47499 .55186 .48099 .55786 .49168 .55461 .4857 .54859 Mtetra
.4857 .54859 .49168 .55461 .5024 .55135 .49646 .54531 Mtetra
.663 .742 .909 r
.49646 .54531 .5024 .55135 .51317 .54807 .50725 .54202 Mtetra
.50725 .54202 .51317 .54807 .52398 .54478 .51809 .53871 Mtetra
.51809 .53871 .52398 .54478 .53484 .54148 .52897 .53539 Mtetra
.663 .743 .909 r
.52897 .53539 .53484 .54148 .54573 .53817 .5399 .53206 Mtetra
.5399 .53206 .54573 .53817 .55667 .53485 .55087 .52872 Mtetra
.55087 .52872 .55667 .53485 .56766 .53151 .56188 .52537 Mtetra
.663 .743 .91 r
.56188 .52537 .56766 .53151 .57868 .52815 .57293 .522 Mtetra
.57293 .522 .57868 .52815 .58975 .52479 .58404 .51861 Mtetra
.663 .744 .91 r
.58404 .51861 .58975 .52479 .60087 .52141 .59518 .51522 Mtetra
.59518 .51522 .60087 .52141 .61203 .51802 .60637 .5118 Mtetra
.60637 .5118 .61203 .51802 .62323 .51461 .61761 .50838 Mtetra
.61761 .50838 .62323 .51461 .63448 .51119 .62889 .50494 Mtetra
.663 .745 .911 r
.62889 .50494 .63448 .51119 .64578 .50775 .64021 .50148 Mtetra
.64021 .50148 .64578 .50775 .65712 .50431 .65158 .49801 Mtetra
.65158 .49801 .65712 .50431 .6685 .50084 .663 .49452 Mtetra
.663 .49452 .6685 .50084 .67994 .49736 .67447 .49101 Mtetra
.664 .745 .911 r
.67447 .49101 .67994 .49736 .69141 .49387 .68598 .48749 Mtetra
.68598 .48749 .69141 .49387 .70294 .49036 .69753 .48396 Mtetra
.664 .745 .91 r
.69753 .48396 .70294 .49036 .71451 .48684 .70914 .4804 Mtetra
.70914 .4804 .71451 .48684 .72613 .48331 .72079 .47684 Mtetra
.663 .744 .91 r
.72079 .47684 .72613 .48331 .7378 .47976 .73249 .47326 Mtetra
.73249 .47326 .7378 .47976 .74952 .47622 .74424 .46969 Mtetra
.661 .743 .911 r
.74424 .46969 .74952 .47622 .76128 .47272 .75605 .46616 Mtetra
.656 .741 .913 r
.75605 .46616 .76128 .47272 .77311 .46934 .76791 .46277 Mtetra
.643 .737 .917 r
.76791 .46277 .77311 .46934 .78502 .46627 .77985 .45973 Mtetra
.616 .728 .926 r
.77985 .45973 .78502 .46627 .79703 .46387 .79191 .45743 Mtetra
.559 .707 .94 r
.79191 .45743 .79703 .46387 .80921 .46267 .80414 .45647 Mtetra
.447 .662 .953 r
.80414 .45647 .80921 .46267 .82162 .46334 .81663 .4576 Mtetra
.252 .568 .938 r
.81663 .4576 .82162 .46334 .83435 .46642 .82946 .4614 Mtetra
0 .417 .853 r
.82946 .4614 .83435 .46642 .84742 .4719 .84266 .46788 Mtetra
0 .274 .722 r
.84266 .46788 .84742 .4719 .86075 .47885 .85615 .476 Mtetra
0 .242 .648 r
.85615 .476 .86075 .47885 .87418 .48532 .86973 .4836 Mtetra
0 .398 .712 r
.86973 .4836 .87418 .48532 .88741 .48883 .8831 .48789 Mtetra
.246 .752 .883 r
.8831 .48789 .88741 .48883 .90018 .4873 .89596 .48657 Mtetra
.701 .979 .907 r
.89596 .48657 .90018 .4873 .91235 .48007 .90815 .47889 Mtetra
.882 .981 .828 r
.90815 .47889 .91235 .48007 .92399 .46817 .91975 .46602 Mtetra
.925 .943 .79 r
.91975 .46602 .92399 .46817 .93531 .45387 .931 .45049 Mtetra
.919 .909 .795 r
.931 .45049 .93531 .45387 .94662 .4396 .94221 .43502 Mtetra
.886 .878 .822 r
.94221 .43502 .94662 .4396 .95813 .42712 .95366 .42154 Mtetra
.663 .741 .908 r
.37417 .5749 .38045 .58074 .39079 .57758 .38454 .57172 Mtetra
.38454 .57172 .39079 .57758 .40117 .57441 .39494 .56852 Mtetra
.663 .742 .908 r
.39494 .56852 .40117 .57441 .4116 .57122 .40539 .56532 Mtetra
.40539 .56532 .4116 .57122 .42206 .56803 .41588 .5621 Mtetra
.41588 .5621 .42206 .56803 .43256 .56482 .42641 .55888 Mtetra
.663 .742 .909 r
.42641 .55888 .43256 .56482 .44311 .5616 .43698 .55564 Mtetra
.43698 .55564 .44311 .5616 .45369 .55836 .44759 .55239 Mtetra
.44759 .55239 .45369 .55836 .46432 .55512 .45825 .54913 Mtetra
.663 .743 .909 r
.45825 .54913 .46432 .55512 .47499 .55186 .46894 .54586 Mtetra
.663 .743 .91 r
.46894 .54586 .47499 .55186 .4857 .54859 .47968 .54258 Mtetra
.47968 .54258 .4857 .54859 .49646 .54531 .49046 .53929 Mtetra
.663 .744 .91 r
.49046 .53929 .49646 .54531 .50725 .54202 .50129 .53599 Mtetra
.663 .744 .911 r
.50129 .53599 .50725 .54202 .51809 .53871 .51215 .53268 Mtetra
.662 .745 .911 r
.51215 .53268 .51809 .53871 .52897 .53539 .52306 .52936 Mtetra
.662 .746 .912 r
.52306 .52936 .52897 .53539 .5399 .53206 .53402 .52603 Mtetra
.662 .746 .913 r
.53402 .52603 .5399 .53206 .55087 .52872 .54502 .52268 Mtetra
.662 .747 .913 r
.54502 .52268 .55087 .52872 .56188 .52537 .55606 .51933 Mtetra
.662 .748 .914 r
.55606 .51933 .56188 .52537 .57293 .522 .56714 .51596 Mtetra
.662 .749 .914 r
.56714 .51596 .57293 .522 .58404 .51861 .57828 .51257 Mtetra
.662 .75 .915 r
.57828 .51257 .58404 .51861 .59518 .51522 .58945 .50918 Mtetra
.662 .75 .916 r
.58945 .50918 .59518 .51522 .60637 .5118 .60067 .50576 Mtetra
.662 .751 .916 r
.60067 .50576 .60637 .5118 .61761 .50838 .61194 .50233 Mtetra
.662 .752 .917 r
.61194 .50233 .61761 .50838 .62889 .50494 .62325 .49888 Mtetra
.663 .752 .917 r
.62325 .49888 .62889 .50494 .64021 .50148 .63461 .4954 Mtetra
.663 .753 .917 r
.63461 .4954 .64021 .50148 .65158 .49801 .64602 .49191 Mtetra
.64602 .49191 .65158 .49801 .663 .49452 .65747 .4884 Mtetra
.65747 .4884 .663 .49452 .67447 .49101 .66896 .48487 Mtetra
.66896 .48487 .67447 .49101 .68598 .48749 .68051 .48132 Mtetra
.664 .753 .917 r
.68051 .48132 .68598 .48749 .69753 .48396 .6921 .47774 Mtetra
.664 .753 .916 r
.6921 .47774 .69753 .48396 .70914 .4804 .70374 .47415 Mtetra
.664 .752 .916 r
.70374 .47415 .70914 .4804 .72079 .47684 .71542 .47054 Mtetra
.71542 .47054 .72079 .47684 .73249 .47326 .72716 .46691 Mtetra
.663 .751 .915 r
.72716 .46691 .73249 .47326 .74424 .46969 .73894 .46329 Mtetra
.661 .749 .916 r
.73894 .46329 .74424 .46969 .75605 .46616 .75078 .45972 Mtetra
.655 .747 .917 r
.75078 .45972 .75605 .46616 .76791 .46277 .76268 .4563 Mtetra
.641 .742 .921 r
.76268 .4563 .76791 .46277 .77985 .45973 .77466 .45327 Mtetra
.61 .73 .931 r
.77466 .45327 .77985 .45973 .79191 .45743 .78676 .45107 Mtetra
.544 .706 .945 r
.78676 .45107 .79191 .45743 .80414 .45647 .79905 .45035 Mtetra
.414 .65 .955 r
.79905 .45035 .80414 .45647 .81663 .4576 .81161 .45195 Mtetra
.186 .532 .923 r
.81161 .45195 .81663 .4576 .82946 .4614 .82454 .4565 Mtetra
0 .348 .802 r
.82454 .4565 .82946 .4614 .84266 .46788 .83787 .46403 Mtetra
0 .187 .641 r
.83787 .46403 .84266 .46788 .85615 .476 .85152 .47339 Mtetra
.414 0 0 r
.85152 .47339 .85615 .476 .86973 .4836 .86527 .48217 Mtetra
.279 0 0 r
.86527 .48217 .86973 .4836 .8831 .48789 .87878 .48729 Mtetra
.182 .713 .836 r
.87878 .48729 .8831 .48789 .89596 .48657 .89173 .48618 Mtetra
.702 .982 .885 r
.89173 .48618 .89596 .48657 .90815 .47889 .90394 .47802 Mtetra
.894 .982 .805 r
.90394 .47802 .90815 .47889 .91975 .46602 .91549 .46411 Mtetra
.938 .942 .768 r
.91549 .46411 .91975 .46602 .931 .45049 .92666 .44727 Mtetra
.932 .91 .775 r
.92666 .44727 .931 .45049 .94221 .43502 .93779 .43052 Mtetra
.899 .881 .807 r
.93779 .43052 .94221 .43502 .95366 .42154 .94916 .41599 Mtetra
.663 .742 .908 r
.36785 .56902 .37417 .5749 .38454 .57172 .37824 .56583 Mtetra
.663 .742 .909 r
.37824 .56583 .38454 .57172 .39494 .56852 .38867 .56262 Mtetra
.38867 .56262 .39494 .56852 .40539 .56532 .39914 .5594 Mtetra
.39914 .5594 .40539 .56532 .41588 .5621 .40966 .55617 Mtetra
.663 .743 .909 r
.40966 .55617 .41588 .5621 .42641 .55888 .42021 .55293 Mtetra
.663 .743 .91 r
.42021 .55293 .42641 .55888 .43698 .55564 .43081 .54969 Mtetra
.662 .744 .91 r
.43081 .54969 .43698 .55564 .44759 .55239 .44145 .54644 Mtetra
.662 .744 .911 r
.44145 .54644 .44759 .55239 .45825 .54913 .45213 .54319 Mtetra
.662 .745 .912 r
.45213 .54319 .45825 .54913 .46894 .54586 .46285 .53993 Mtetra
.661 .746 .913 r
.46285 .53993 .46894 .54586 .47968 .54258 .47362 .53666 Mtetra
.661 .747 .914 r
.47362 .53666 .47968 .54258 .49046 .53929 .48442 .53339 Mtetra
.661 .749 .915 r
.48442 .53339 .49046 .53929 .50129 .53599 .49528 .53012 Mtetra
.66 .75 .917 r
.49528 .53012 .50129 .53599 .51215 .53268 .50617 .52684 Mtetra
.66 .752 .918 r
.50617 .52684 .51215 .53268 .52306 .52936 .51711 .52356 Mtetra
.659 .754 .92 r
.51711 .52356 .52306 .52936 .53402 .52603 .5281 .52027 Mtetra
.659 .756 .922 r
.5281 .52027 .53402 .52603 .54502 .52268 .53912 .51697 Mtetra
.659 .759 .924 r
.53912 .51697 .54502 .52268 .55606 .51933 .5502 .51367 Mtetra
.658 .761 .926 r
.5502 .51367 .55606 .51933 .56714 .51596 .56132 .51035 Mtetra
.658 .764 .928 r
.56132 .51035 .56714 .51596 .57828 .51257 .57248 .50701 Mtetra
.658 .766 .929 r
.57248 .50701 .57828 .51257 .58945 .50918 .58369 .50365 Mtetra
.658 .769 .931 r
.58369 .50365 .58945 .50918 .60067 .50576 .59495 .50028 Mtetra
.658 .771 .933 r
.59495 .50028 .60067 .50576 .61194 .50233 .60625 .49687 Mtetra
.659 .773 .934 r
.60625 .49687 .61194 .50233 .62325 .49888 .6176 .49344 Mtetra
.659 .775 .935 r
.6176 .49344 .62325 .49888 .63461 .4954 .62899 .48998 Mtetra
.66 .776 .935 r
.62899 .48998 .63461 .4954 .64602 .49191 .64043 .48648 Mtetra
.66 .777 .936 r
.64043 .48648 .64602 .49191 .65747 .4884 .65192 .48295 Mtetra
.661 .778 .935 r
.65192 .48295 .65747 .4884 .66896 .48487 .66345 .47938 Mtetra
.662 .778 .935 r
.66345 .47938 .66896 .48487 .68051 .48132 .67503 .47578 Mtetra
.663 .777 .934 r
.67503 .47578 .68051 .48132 .6921 .47774 .68666 .47215 Mtetra
.663 .776 .933 r
.68666 .47215 .6921 .47774 .70374 .47415 .69833 .46848 Mtetra
.664 .775 .932 r
.69833 .46848 .70374 .47415 .71542 .47054 .71005 .46479 Mtetra
.664 .773 .93 r
.71005 .46479 .71542 .47054 .72716 .46691 .72182 .46108 Mtetra
.664 .771 .929 r
.72182 .46108 .72716 .46691 .73894 .46329 .73363 .45736 Mtetra
.662 .767 .928 r
.73363 .45736 .73894 .46329 .75078 .45972 .7455 .4537 Mtetra
.656 .763 .929 r
.7455 .4537 .75078 .45972 .76268 .4563 .75743 .45021 Mtetra
.64 .755 .932 r
.75743 .45021 .76268 .4563 .77466 .45327 .76945 .44715 Mtetra
.603 .741 .942 r
.76945 .44715 .77466 .45327 .78676 .45107 .78159 .445 Mtetra
.526 .71 .955 r
.78159 .445 .78676 .45107 .79905 .45035 .79394 .44449 Mtetra
.372 .638 .958 r
.79394 .44449 .79905 .45035 .81161 .45195 .80658 .44654 Mtetra
.103 .488 .9 r
.80658 .44654 .81161 .45195 .82454 .4565 .81961 .45185 Mtetra
0 .269 .734 r
.81961 .45185 .82454 .4565 .83787 .46403 .83307 .46046 Mtetra
.442 0 0 r
.83307 .46046 .83787 .46403 .85152 .47339 .84688 .47108 Mtetra
.502 0 0 r
.84688 .47108 .85152 .47339 .86527 .48217 .8608 .48109 Mtetra
.369 0 0 r
.8608 .48109 .86527 .48217 .87878 .48729 .87445 .48706 Mtetra
.115 .667 .78 r
.87445 .48706 .87878 .48729 .89173 .48618 .88748 .48616 Mtetra
.701 .984 .861 r
.88748 .48616 .89173 .48618 .90394 .47802 .89971 .47746 Mtetra
.905 .982 .78 r
.89971 .47746 .90394 .47802 .91549 .46411 .91122 .46245 Mtetra
.949 .94 .744 r
.91122 .46245 .91549 .46411 .92666 .44727 .9223 .44423 Mtetra
.944 .909 .756 r
.9223 .44423 .92666 .44727 .93779 .43052 .93333 .42612 Mtetra
.912 .883 .792 r
.93333 .42612 .93779 .43052 .94916 .41599 .94463 .41047 Mtetra
.663 .742 .909 r
.36147 .56313 .36785 .56902 .37824 .56583 .37189 .55992 Mtetra
.662 .743 .91 r
.37189 .55992 .37824 .56583 .38867 .56262 .38235 .55671 Mtetra
.38235 .55671 .38867 .56262 .39914 .5594 .39285 .55349 Mtetra
.662 .744 .911 r
.39285 .55349 .39914 .5594 .40966 .55617 .40339 .55027 Mtetra
.661 .745 .912 r
.40339 .55027 .40966 .55617 .42021 .55293 .41397 .54705 Mtetra
.661 .746 .913 r
.41397 .54705 .42021 .55293 .43081 .54969 .42459 .54383 Mtetra
.66 .747 .915 r
.42459 .54383 .43081 .54969 .44145 .54644 .43525 .54062 Mtetra
.659 .749 .917 r
.43525 .54062 .44145 .54644 .45213 .54319 .44596 .53742 Mtetra
.658 .751 .919 r
.44596 .53742 .45213 .54319 .46285 .53993 .45671 .53422 Mtetra
.657 .754 .922 r
.45671 .53422 .46285 .53993 .47362 .53666 .4675 .53103 Mtetra
.656 .757 .925 r
.4675 .53103 .47362 .53666 .48442 .53339 .47833 .52786 Mtetra
.654 .761 .928 r
.47833 .52786 .48442 .53339 .49528 .53012 .48922 .5247 Mtetra
.653 .765 .932 r
.48922 .5247 .49528 .53012 .50617 .52684 .50014 .52155 Mtetra
.651 .77 .936 r
.50014 .52155 .50617 .52684 .51711 .52356 .51111 .5184 Mtetra
.649 .776 .941 r
.51111 .5184 .51711 .52356 .5281 .52027 .52213 .51527 Mtetra
.648 .782 .946 r
.52213 .51527 .5281 .52027 .53912 .51697 .53319 .51213 Mtetra
.646 .789 .95 r
.53319 .51213 .53912 .51697 .5502 .51367 .5443 .50899 Mtetra
.644 .795 .955 r
.5443 .50899 .5502 .51367 .56132 .51035 .55545 .50583 Mtetra
.642 .802 .96 r
.55545 .50583 .56132 .51035 .57248 .50701 .56665 .50266 Mtetra
.64 .809 .964 r
.56665 .50266 .57248 .50701 .58369 .50365 .5779 .49946 Mtetra
.639 .816 .968 r
.5779 .49946 .58369 .50365 .59495 .50028 .5892 .49621 Mtetra
.638 .822 .971 r
.5892 .49621 .59495 .50028 .60625 .49687 .60054 .49293 Mtetra
.638 .828 .974 r
.60054 .49293 .60625 .49687 .6176 .49344 .61194 .48958 Mtetra
.638 .833 .975 r
.61194 .48958 .6176 .49344 .62899 .48998 .62337 .48618 Mtetra
.639 .836 .976 r
.62337 .48618 .62899 .48998 .64043 .48648 .63486 .48271 Mtetra
.641 .839 .976 r
.63486 .48271 .64043 .48648 .65192 .48295 .64638 .47917 Mtetra
.643 .84 .976 r
.64638 .47917 .65192 .48295 .66345 .47938 .65796 .47556 Mtetra
.647 .84 .975 r
.65796 .47556 .66345 .47938 .67503 .47578 .66958 .47187 Mtetra
.65 .839 .973 r
.66958 .47187 .67503 .47578 .68666 .47215 .68124 .46812 Mtetra
.654 .836 .97 r
.68124 .46812 .68666 .47215 .69833 .46848 .69295 .46431 Mtetra
.657 .832 .967 r
.69295 .46431 .69833 .46848 .71005 .46479 .70471 .46045 Mtetra
.66 .827 .964 r
.70471 .46045 .71005 .46479 .72182 .46108 .71651 .45654 Mtetra
.662 .821 .96 r
.71651 .45654 .72182 .46108 .73363 .45736 .72836 .45263 Mtetra
.661 .814 .957 r
.72836 .45263 .73363 .45736 .7455 .4537 .74026 .44876 Mtetra
.655 .805 .955 r
.74026 .44876 .7455 .4537 .75743 .45021 .75222 .44507 Mtetra
.636 .792 .957 r
.75222 .44507 .75743 .45021 .76945 .44715 .76427 .44186 Mtetra
.592 .77 .965 r
.76427 .44186 .76945 .44715 .78159 .445 .77645 .43966 Mtetra
.497 .727 .975 r
.77645 .43966 .78159 .445 .79394 .44449 .78884 .43927 Mtetra
.306 .629 .962 r
.78884 .43927 .79394 .44449 .80658 .44654 .80155 .44169 Mtetra
0 .43 .857 r
.80155 .44169 .80658 .44654 .81961 .45185 .81468 .44772 Mtetra
0 .177 .638 r
.81468 .44772 .81961 .45185 .83307 .46046 .82827 .45737 Mtetra
.54 0 0 r
.82827 .45737 .83307 .46046 .84688 .47108 .84224 .46926 Mtetra
.583 .018 0 r
.84224 .46926 .84688 .47108 .8608 .48109 .85632 .48048 Mtetra
.453 0 0 r
.85632 .48048 .8608 .48109 .87445 .48706 .87012 .48728 Mtetra
.041 .61 .708 r
.87012 .48728 .87445 .48706 .88748 .48616 .88324 .48655 Mtetra
.698 .982 .83 r
.88324 .48655 .88748 .48616 .89971 .47746 .89548 .47727 Mtetra
.915 .98 .753 r
.89548 .47727 .89971 .47746 .91122 .46245 .90693 .46106 Mtetra
.958 .936 .721 r
.90693 .46106 .91122 .46245 .9223 .44423 .91792 .44136 Mtetra
.954 .907 .735 r
.91792 .44136 .9223 .44423 .93333 .42612 .92886 .42183 Mtetra
.923 .884 .776 r
.92886 .42183 .93333 .42612 .94463 .41047 .94007 .40501 Mtetra
.662 .744 .911 r
.35506 .55724 .36147 .56313 .37189 .55992 .3655 .55404 Mtetra
.661 .744 .912 r
.3655 .55404 .37189 .55992 .38235 .55671 .37598 .55085 Mtetra
.66 .746 .913 r
.37598 .55085 .38235 .55671 .39285 .55349 .3865 .54766 Mtetra
.659 .747 .915 r
.3865 .54766 .39285 .55349 .40339 .55027 .39706 .54449 Mtetra
.658 .749 .918 r
.39706 .54449 .40339 .55027 .41397 .54705 .40766 .54134 Mtetra
.656 .752 .921 r
.40766 .54134 .41397 .54705 .42459 .54383 .41831 .53822 Mtetra
.654 .755 .924 r
.41831 .53822 .42459 .54383 .43525 .54062 .429 .53512 Mtetra
.651 .76 .929 r
.429 .53512 .43525 .54062 .44596 .53742 .43973 .53206 Mtetra
.648 .765 .934 r
.43973 .53206 .44596 .53742 .45671 .53422 .4505 .52904 Mtetra
.645 .771 .94 r
.4505 .52904 .45671 .53422 .4675 .53103 .46132 .52607 Mtetra
.64 .779 .947 r
.46132 .52607 .4675 .53103 .47833 .52786 .47218 .52315 Mtetra
.635 .788 .955 r
.47218 .52315 .47833 .52786 .48922 .5247 .48309 .52027 Mtetra
.628 .798 .964 r
.48309 .52027 .48922 .5247 .50014 .52155 .49405 .51744 Mtetra
.62 .81 .973 r
.49405 .51744 .50014 .52155 .51111 .5184 .50505 .51465 Mtetra
.61 .822 .982 r
.50505 .51465 .51111 .5184 .52213 .51527 .5161 .5119 Mtetra
.597 .835 .989 r
.5161 .5119 .52213 .51527 .53319 .51213 .5272 .50916 Mtetra
.582 .847 .995 r
.5272 .50916 .53319 .51213 .5443 .50899 .53835 .50643 Mtetra
.564 .858 .997 r
.53835 .50643 .5443 .50899 .55545 .50583 .54955 .50369 Mtetra
.543 .867 .994 r
.54955 .50369 .55545 .50583 .56665 .50266 .56081 .50092 Mtetra
.52 .873 .987 r
.56081 .50092 .56665 .50266 .5779 .49946 .57211 .49809 Mtetra
.497 .875 .975 r
.57211 .49809 .5779 .49946 .5892 .49621 .58346 .49519 Mtetra
.475 .875 .959 r
.58346 .49519 .5892 .49621 .60054 .49293 .59486 .4922 Mtetra
.456 .873 .943 r
.59486 .4922 .60054 .49293 .61194 .48958 .60631 .48909 Mtetra
.444 .871 .927 r
.60631 .48909 .61194 .48958 .62337 .48618 .6178 .48584 Mtetra
.438 .871 .916 r
.6178 .48584 .62337 .48618 .63486 .48271 .62934 .48246 Mtetra
.442 .874 .911 r
.62934 .48246 .63486 .48271 .64638 .47917 .64093 .47892 Mtetra
.453 .88 .912 r
.64093 .47892 .64638 .47917 .65796 .47556 .65255 .47522 Mtetra
.472 .888 .919 r
.65255 .47522 .65796 .47556 .66958 .47187 .66422 .47138 Mtetra
.497 .898 .931 r
.66422 .47138 .66958 .47187 .68124 .46812 .67593 .4674 Mtetra
.525 .908 .945 r
.67593 .4674 .68124 .46812 .69295 .46431 .68768 .46328 Mtetra
.555 .914 .959 r
.68768 .46328 .69295 .46431 .70471 .46045 .69948 .45906 Mtetra
.583 .916 .971 r
.69948 .45906 .70471 .46045 .71651 .45654 .71131 .45475 Mtetra
.607 .913 .98 r
.71131 .45475 .71651 .45654 .72836 .45263 .72319 .45039 Mtetra
.623 .904 .985 r
.72319 .45039 .72836 .45263 .74026 .44876 .73511 .44607 Mtetra
.627 .89 .988 r
.73511 .44607 .74026 .44876 .75222 .44507 .7471 .44195 Mtetra
.611 .867 .991 r
.7471 .44195 .75222 .44507 .76427 .44186 .75917 .43835 Mtetra
.557 .832 .997 r
.75917 .43835 .76427 .44186 .77645 .43966 .77138 .43587 Mtetra
.431 .762 .996 r
.77138 .43587 .77645 .43966 .78884 .43927 .78381 .43539 Mtetra
.182 .61 .942 r
.78381 .43539 .78884 .43927 .80155 .44169 .79657 .438 Mtetra
0 .34 .757 r
.79657 .438 .80155 .44169 .81468 .44772 .80979 .44458 Mtetra
.487 0 0 r
.80979 .44458 .81468 .44772 .82827 .45737 .8235 .45516 Mtetra
.633 .084 0 r
.8235 .45516 .82827 .45737 .84224 .46926 .83762 .46822 Mtetra
.653 .099 0 r
.83762 .46822 .84224 .46926 .85632 .48048 .85186 .48058 Mtetra
.528 0 0 r
.85186 .48058 .85632 .48048 .87012 .48728 .86579 .48815 Mtetra
.04 0 0 r
.86579 .48815 .87012 .48728 .88324 .48655 .87899 .4875 Mtetra
.687 .974 .786 r
.87899 .4875 .88324 .48655 .89548 .47727 .89124 .47753 Mtetra
.922 .976 .722 r
.89124 .47753 .89548 .47727 .90693 .46106 .90264 .46002 Mtetra
.966 .932 .695 r
.90264 .46002 .90693 .46106 .91792 .44136 .91353 .43874 Mtetra
.963 .905 .714 r
.91353 .43874 .91792 .44136 .92886 .42183 .92436 .41768 Mtetra
.934 .885 .76 r
.92436 .41768 .92886 .42183 .94007 .40501 .93549 .39962 Mtetra
.659 .746 .914 r
.34858 .5514 .35506 .55724 .3655 .55404 .35905 .54824 Mtetra
.657 .748 .917 r
.35905 .54824 .3655 .55404 .37598 .55085 .36955 .54511 Mtetra
.655 .75 .92 r
.36955 .54511 .37598 .55085 .3865 .54766 .38009 .54202 Mtetra
.653 .753 .924 r
.38009 .54202 .3865 .54766 .39706 .54449 .39068 .53897 Mtetra
.649 .758 .928 r
.39068 .53897 .39706 .54449 .40766 .54134 .4013 .53599 Mtetra
.645 .763 .935 r
.4013 .53599 .40766 .54134 .41831 .53822 .41197 .53307 Mtetra
.639 .77 .942 r
.41197 .53307 .41831 .53822 .429 .53512 .42268 .53023 Mtetra
.632 .779 .951 r
.42268 .53023 .429 .53512 .43973 .53206 .43343 .5275 Mtetra
.622 .789 .962 r
.43343 .5275 .43973 .53206 .4505 .52904 .44422 .52487 Mtetra
.609 .802 .974 r
.44422 .52487 .4505 .52904 .46132 .52607 .45507 .52235 Mtetra
.59 .816 .986 r
.45507 .52235 .46132 .52607 .47218 .52315 .46595 .51996 Mtetra
.563 .83 .996 r
.46595 .51996 .47218 .52315 .48309 .52027 .47689 .51768 Mtetra
.526 .841 .999 r
.47689 .51768 .48309 .52027 .49405 .51744 .48788 .51553 Mtetra
.472 .844 .989 r
.48788 .51553 .49405 .51744 .50505 .51465 .49892 .51347 Mtetra
.398 .83 .955 r
.49892 .51347 .50505 .51465 .5161 .5119 .51001 .51151 Mtetra
.302 .791 .886 r
.51001 .51151 .5161 .5119 .5272 .50916 .52116 .5096 Mtetra
.192 .723 .782 r
.52116 .5096 .5272 .50916 .53835 .50643 .53236 .50772 Mtetra
0 0 0 r
.53236 .50772 .53835 .50643 .54955 .50369 .54362 .50583 Mtetra
.016 0 0 r
.54362 .50583 .54955 .50369 .56081 .50092 .55494 .50388 Mtetra
.093 0 0 r
.55494 .50388 .56081 .50092 .57211 .49809 .56631 .50183 Mtetra
.149 0 0 r
.56631 .50183 .57211 .49809 .58346 .49519 .57774 .49963 Mtetra
.187 0 0 r
.57774 .49963 .58346 .49519 .59486 .4922 .58922 .49724 Mtetra
.209 0 0 r
.58922 .49724 .59486 .4922 .60631 .48909 .60075 .4946 Mtetra
.219 0 0 r
.60075 .4946 .60631 .48909 .6178 .48584 .61233 .4917 Mtetra
.61233 .4917 .6178 .48584 .62934 .48246 .62395 .48849 Mtetra
.209 0 0 r
.62395 .48849 .62934 .48246 .64093 .47892 .63562 .48497 Mtetra
.19 0 0 r
.63562 .48497 .64093 .47892 .65255 .47522 .64732 .48112 Mtetra
.161 0 0 r
.64732 .48112 .65255 .47522 .66422 .47138 .65905 .47697 Mtetra
.121 0 0 r
.65905 .47697 .66422 .47138 .67593 .4674 .67082 .47253 Mtetra
.068 0 0 r
.67082 .47253 .67593 .4674 .68768 .46328 .68262 .46782 Mtetra
0 0 0 r
.68262 .46782 .68768 .46328 .69948 .45906 .69446 .46288 Mtetra
.69446 .46288 .69948 .45906 .71131 .45475 .70632 .45778 Mtetra
.70632 .45778 .71131 .45475 .72319 .45039 .71822 .45257 Mtetra
.71822 .45257 .72319 .45039 .73511 .44607 .73016 .44737 Mtetra
.366 .829 .755 r
.73016 .44737 .73511 .44607 .7471 .44195 .74216 .44237 Mtetra
.41 .861 .84 r
.74216 .44237 .7471 .44195 .75917 .43835 .75424 .43795 Mtetra
.38 .841 .891 r
.75424 .43795 .75917 .43835 .77138 .43587 .76646 .43478 Mtetra
.232 .739 .888 r
.76646 .43478 .77138 .43587 .78381 .43539 .77891 .43383 Mtetra
0 .508 .774 r
.77891 .43383 .78381 .43539 .79657 .438 .79172 .4363 Mtetra
.399 0 0 r
.79172 .4363 .79657 .438 .80979 .44458 .805 .44315 Mtetra
.617 .054 0 r
.805 .44315 .80979 .44458 .8235 .45516 .81882 .4544 Mtetra
.707 .169 0 r
.81882 .4544 .8235 .45516 .83762 .46822 .83307 .46842 Mtetra
.707 .171 0 r
.83307 .46842 .83762 .46822 .85186 .48058 .84745 .48176 Mtetra
.589 .021 0 r
.84745 .48176 .85186 .48058 .86579 .48815 .86151 .48993 Mtetra
.126 0 0 r
.86151 .48993 .86579 .48815 .87899 .4875 .87477 .4892 Mtetra
.664 .954 .723 r
.87477 .4892 .87899 .4875 .89124 .47753 .88702 .47837 Mtetra
.925 .97 .686 r
.88702 .47837 .89124 .47753 .90264 .46002 .89834 .45941 Mtetra
.972 .928 .668 r
.89834 .45941 .90264 .46002 .91353 .43874 .90912 .43642 Mtetra
.971 .903 .692 r
.90912 .43642 .91353 .43874 .92436 .41768 .91984 .41373 Mtetra
.945 .886 .743 r
.91984 .41373 .92436 .41768 .93549 .39962 .93089 .39435 Mtetra
.654 .749 .92 r
.34206 .54565 .34858 .5514 .35905 .54824 .35254 .54259 Mtetra
.651 .752 .924 r
.35254 .54259 .35905 .54824 .36955 .54511 .36306 .53959 Mtetra
.646 .757 .929 r
.36306 .53959 .36955 .54511 .38009 .54202 .37362 .53668 Mtetra
.64 .762 .937 r
.37362 .53668 .38009 .54202 .39068 .53897 .38422 .53387 Mtetra
.632 .77 .946 r
.38422 .53387 .39068 .53897 .4013 .53599 .39487 .53119 Mtetra
.621 .779 .957 r
.39487 .53119 .4013 .53599 .41197 .53307 .40555 .52866 Mtetra
.605 .79 .97 r
.40555 .52866 .41197 .53307 .42268 .53023 .41627 .5263 Mtetra
.582 .804 .984 r
.41627 .5263 .42268 .53023 .43343 .5275 .42704 .52415 Mtetra
.546 .817 .996 r
.42704 .52415 .43343 .5275 .44422 .52487 .43785 .52222 Mtetra
.491 .824 .999 r
.43785 .52222 .44422 .52487 .45507 .52235 .44871 .52052 Mtetra
.405 .815 .977 r
.44871 .52052 .45507 .52235 .46595 .51996 .45962 .51907 Mtetra
.276 .767 .905 r
.45962 .51907 .46595 .51996 .47689 .51768 .47058 .51787 Mtetra
.108 .662 .758 r
.47058 .51787 .47689 .51768 .48788 .51553 .4816 .51691 Mtetra
.068 0 0 r
.4816 .51691 .48788 .51553 .49892 .51347 .49268 .51617 Mtetra
.213 0 0 r
.49268 .51617 .49892 .51347 .51001 .51151 .50382 .5156 Mtetra
.314 0 0 r
.50382 .5156 .51001 .51151 .52116 .5096 .51503 .51516 Mtetra
.379 0 0 r
.51503 .51516 .52116 .5096 .53236 .50772 .5263 .51478 Mtetra
.419 0 .062 r
.5263 .51478 .53236 .50772 .54362 .50583 .53764 .51439 Mtetra
.444 .016 .132 r
.53764 .51439 .54362 .50583 .55494 .50388 .54905 .51389 Mtetra
.457 .052 .182 r
.54905 .51389 .55494 .50388 .56631 .50183 .56052 .51321 Mtetra
.463 .076 .218 r
.56052 .51321 .56631 .50183 .57774 .49963 .57205 .51224 Mtetra
.465 .091 .244 r
.57205 .51224 .57774 .49963 .58922 .49724 .58365 .5109 Mtetra
.462 .098 .262 r
.58365 .5109 .58922 .49724 .60075 .4946 .5953 .5091 Mtetra
.456 .1 .273 r
.5953 .5091 .60075 .4946 .61233 .4917 .607 .50678 Mtetra
.447 .097 .278 r
.607 .50678 .61233 .4917 .62395 .48849 .61874 .50388 Mtetra
.435 .089 .278 r
.61874 .50388 .62395 .48849 .63562 .48497 .63052 .50037 Mtetra
.42 .075 .272 r
.63052 .50037 .63562 .48497 .64732 .48112 .64232 .49626 Mtetra
.402 .057 .261 r
.64232 .49626 .64732 .48112 .65905 .47697 .65415 .49155 Mtetra
.38 .032 .244 r
.65415 .49155 .65905 .47697 .67082 .47253 .666 .48629 Mtetra
.354 0 .219 r
.666 .48629 .67082 .47253 .68262 .46782 .67787 .48054 Mtetra
.321 0 .185 r
.67787 .48054 .68262 .46782 .69446 .46288 .68975 .47437 Mtetra
.279 0 .139 r
.68975 .47437 .69446 .46288 .70632 .45778 .70165 .46788 Mtetra
.228 0 .077 r
.70165 .46788 .70632 .45778 .71822 .45257 .71356 .46119 Mtetra
.165 0 0 r
.71356 .46119 .71822 .45257 .73016 .44737 .72551 .45445 Mtetra
.094 0 0 r
.72551 .45445 .73016 .44737 .74216 .44237 .7375 .44792 Mtetra
.032 0 0 r
.7375 .44792 .74216 .44237 .75424 .43795 .74956 .44206 Mtetra
.019 0 0 r
.74956 .44206 .75424 .43795 .76646 .43478 .76177 .43759 Mtetra
.112 0 0 r
.76177 .43759 .76646 .43478 .77891 .43383 .77421 .43562 Mtetra
.324 0 0 r
.77421 .43562 .77891 .43383 .79172 .4363 .78703 .43744 Mtetra
.55 0 0 r
.78703 .43744 .79172 .4363 .805 .44315 .80036 .44411 Mtetra
.69 .153 0 r
.80036 .44411 .805 .44315 .81882 .4544 .81425 .45566 Mtetra
.747 .234 0 r
.81425 .45566 .81882 .4544 .83307 .46842 .82861 .47032 Mtetra
.737 .226 0 r
.82861 .47032 .83307 .46842 .84745 .48176 .84312 .48435 Mtetra
.627 .087 0 r
.84312 .48435 .84745 .48176 .86151 .48993 .85727 .49287 Mtetra
.198 0 0 r
.85727 .49287 .86151 .48993 .87477 .4892 .87059 .49184 Mtetra
.629 .918 .641 r
.87059 .49184 .87477 .4892 .88702 .47837 .88281 .47994 Mtetra
.923 .96 .644 r
.88281 .47994 .88702 .47837 .89834 .45941 .89405 .45934 Mtetra
.976 .922 .639 r
.89405 .45934 .89834 .45941 .90912 .43642 .90472 .43447 Mtetra
.978 .901 .669 r
.90472 .43447 .90912 .43642 .91984 .41373 .91532 .41003 Mtetra
.955 .887 .725 r
.91532 .41003 .91984 .41373 .93089 .39435 .92627 .38924 Mtetra
.647 .753 .927 r
.33547 .54002 .34206 .54565 .35254 .54259 .34597 .53712 Mtetra
.64 .758 .934 r
.34597 .53712 .35254 .54259 .36306 .53959 .35651 .53433 Mtetra
.631 .764 .943 r
.35651 .53433 .36306 .53959 .37362 .53668 .36708 .53171 Mtetra
.618 .772 .954 r
.36708 .53171 .37362 .53668 .38422 .53387 .3777 .52927 Mtetra
.6 .782 .967 r
.3777 .52927 .38422 .53387 .39487 .53119 .38835 .52707 Mtetra
.572 .793 .983 r
.38835 .52707 .39487 .53119 .40555 .52866 .39904 .52514 Mtetra
.529 .804 .996 r
.39904 .52514 .40555 .52866 .41627 .5263 .40977 .52352 Mtetra
.458 .806 .998 r
.40977 .52352 .41627 .5263 .42704 .52415 .42054 .52227 Mtetra
.342 .781 .964 r
.42054 .52227 .42704 .52415 .43785 .52222 .43136 .52141 Mtetra
.164 .696 .852 r
.43136 .52141 .43785 .52222 .44871 .52052 .44224 .52097 Mtetra
.054 0 0 r
.44224 .52097 .44871 .52052 .45962 .51907 .45316 .52096 Mtetra
.248 0 0 r
.45316 .52096 .45962 .51907 .47058 .51787 .46414 .5214 Mtetra
.381 0 0 r
.46414 .5214 .47058 .51787 .4816 .51691 .47519 .52226 Mtetra
.459 0 .012 r
.47519 .52226 .4816 .51691 .49268 .51617 .48631 .5235 Mtetra
.504 .059 .127 r
.48631 .5235 .49268 .51617 .50382 .5156 .4975 .52506 Mtetra
.528 .118 .207 r
.4975 .52506 .50382 .5156 .51503 .51516 .50878 .52684 Mtetra
.541 .158 .263 r
.50878 .52684 .51503 .51516 .5263 .51478 .52013 .52874 Mtetra
.547 .184 .304 r
.52013 .52874 .5263 .51478 .53764 .51439 .53157 .53063 Mtetra
.548 .202 .333 r
.53157 .53063 .53764 .51439 .54905 .51389 .54309 .53234 Mtetra
.546 .213 .355 r
.54309 .53234 .54905 .51389 .56052 .51321 .5547 .53373 Mtetra
.541 .218 .37 r
.5547 .53373 .56052 .51321 .57205 .51224 .56638 .53462 Mtetra
.534 .22 .381 r
.56638 .53462 .57205 .51224 .58365 .5109 .57813 .53486 Mtetra
.526 .218 .389 r
.57813 .53486 .58365 .5109 .5953 .5091 .58994 .53431 Mtetra
.516 .214 .393 r
.58994 .53431 .5953 .5091 .607 .50678 .6018 .53285 Mtetra
.505 .207 .394 r
.6018 .53285 .607 .50678 .61874 .50388 .6137 .53038 Mtetra
.492 .197 .393 r
.6137 .53038 .61874 .50388 .63052 .50037 .62563 .52687 Mtetra
.478 .184 .388 r
.62563 .52687 .63052 .50037 .64232 .49626 .63758 .52231 Mtetra
.462 .169 .381 r
.63758 .52231 .64232 .49626 .65415 .49155 .64953 .51672 Mtetra
.444 .15 .371 r
.64953 .51672 .65415 .49155 .666 .48629 .66148 .51019 Mtetra
.423 .127 .357 r
.66148 .51019 .666 .48629 .67787 .48054 .67343 .50283 Mtetra
.399 .1 .338 r
.67343 .50283 .67787 .48054 .68975 .47437 .68537 .49477 Mtetra
.37 .066 .312 r
.68537 .49477 .68975 .47437 .70165 .46788 .6973 .48617 Mtetra
.337 .024 .279 r
.6973 .48617 .70165 .46788 .71356 .46119 .70923 .47722 Mtetra
.298 0 .235 r
.70923 .47722 .71356 .46119 .72551 .45445 .72116 .46816 Mtetra
.255 0 .179 r
.72116 .46816 .72551 .45445 .7375 .44792 .73313 .45933 Mtetra
.218 0 .111 r
.73313 .45933 .7375 .44792 .74956 .44206 .74516 .45126 Mtetra
.21 0 .038 r
.74516 .45126 .74956 .44206 .76177 .43759 .75732 .4448 Mtetra
.269 0 0 r
.75732 .4448 .76177 .43759 .77421 .43562 .76973 .44115 Mtetra
.415 0 0 r
.76973 .44115 .77421 .43562 .78703 .43744 .78254 .44174 Mtetra
.588 .077 .005 r
.78254 .44174 .78703 .43744 .80036 .44411 .79588 .44773 Mtetra
.706 .208 .057 r
.79588 .44773 .80036 .44411 .81425 .45566 .80982 .45913 Mtetra
.755 .271 .089 r
.80982 .45913 .81425 .45566 .82861 .47032 .82426 .47406 Mtetra
.745 .259 .085 r
.82426 .47406 .82861 .47032 .84312 .48435 .83886 .48844 Mtetra
.641 .13 .015 r
.83886 .48844 .84312 .48435 .85727 .49287 .8531 .49703 Mtetra
.238 0 0 r
.8531 .49703 .85727 .49287 .87059 .49184 .86644 .49542 Mtetra
.602 .88 .56 r
.86644 .49542 .87059 .49184 .88281 .47994 .87863 .48223 Mtetra
.921 .947 .602 r
.87863 .48223 .88281 .47994 .89405 .45934 .88977 .45978 Mtetra
.979 .915 .61 r
.88977 .45978 .89405 .45934 .90472 .43447 .9003 .43288 Mtetra
.984 .896 .646 r
.9003 .43288 .90472 .43447 .91532 .41003 .91078 .40656 Mtetra
.964 .887 .706 r
.91078 .40656 .91532 .41003 .92627 .38924 .92163 .38427 Mtetra
.636 .755 .934 r
.32883 .53449 .33547 .54002 .34597 .53712 .33934 .5318 Mtetra
.625 .761 .944 r
.33934 .5318 .34597 .53712 .35651 .53433 .34989 .5293 Mtetra
.609 .768 .956 r
.34989 .5293 .35651 .53433 .36708 .53171 .36048 .52705 Mtetra
.586 .776 .97 r
.36048 .52705 .36708 .53171 .3777 .52927 .37109 .52511 Mtetra
.549 .785 .986 r
.37109 .52511 .3777 .52927 .38835 .52707 .38175 .52353 Mtetra
.491 .789 .998 r
.38175 .52353 .38835 .52707 .39904 .52514 .39244 .52238 Mtetra
.394 .778 .99 r
.39244 .52238 .39904 .52514 .40977 .52352 .40317 .52172 Mtetra
.233 .721 .926 r
.40317 .52172 .40977 .52352 .42054 .52227 .41394 .52163 Mtetra
.006 .58 .753 r
.41394 .52163 .42054 .52227 .43136 .52141 .42476 .52215 Mtetra
.23 0 0 r
.42476 .52215 .43136 .52141 .44224 .52097 .43563 .52333 Mtetra
.401 0 0 r
.43563 .52333 .44224 .52097 .45316 .52096 .44656 .52519 Mtetra
.5 0 0 r
.44656 .52519 .45316 .52096 .46414 .5214 .45756 .52773 Mtetra
.552 .096 .124 r
.45756 .52773 .46414 .5214 .47519 .52226 .46863 .53093 Mtetra
.579 .163 .217 r
.46863 .53093 .47519 .52226 .48631 .5235 .47979 .53473 Mtetra
.592 .207 .281 r
.47979 .53473 .48631 .5235 .4975 .52506 .49103 .53903 Mtetra
.597 .235 .326 r
.49103 .53903 .4975 .52506 .50878 .52684 .50238 .54368 Mtetra
.597 .254 .358 r
.50238 .54368 .50878 .52684 .52013 .52874 .51382 .54852 Mtetra
.594 .265 .382 r
.51382 .54852 .52013 .52874 .53157 .53063 .52537 .55333 Mtetra
.588 .271 .4 r
.52537 .55333 .53157 .53063 .54309 .53234 .53703 .55789 Mtetra
.581 .274 .413 r
.53703 .55789 .54309 .53234 .5547 .53373 .54878 .56193 Mtetra
.572 .273 .422 r
.54878 .56193 .5547 .53373 .56638 .53462 .56063 .56521 Mtetra
.562 .269 .428 r
.56063 .56521 .56638 .53462 .57813 .53486 .57257 .56747 Mtetra
.55 .263 .432 r
.57257 .56747 .57813 .53486 .58994 .53431 .58458 .56849 Mtetra
.538 .255 .434 r
.58458 .56849 .58994 .53431 .6018 .53285 .59664 .56809 Mtetra
.524 .245 .433 r
.59664 .56809 .6018 .53285 .6137 .53038 .60873 .56613 Mtetra
.509 .233 .431 r
.60873 .56613 .6137 .53038 .62563 .52687 .62085 .56255 Mtetra
.493 .219 .427 r
.62085 .56255 .62563 .52687 .63758 .52231 .63296 .55733 Mtetra
.475 .203 .42 r
.63296 .55733 .63758 .52231 .64953 .51672 .64507 .55054 Mtetra
.455 .184 .411 r
.64507 .55054 .64953 .51672 .66148 .51019 .65714 .54231 Mtetra
.433 .161 .4 r
.65714 .54231 .66148 .51019 .67343 .50283 .66918 .5328 Mtetra
.409 .135 .384 r
.66918 .5328 .67343 .50283 .68537 .49477 .68119 .52224 Mtetra
.381 .104 .364 r
.68119 .52224 .68537 .49477 .6973 .48617 .69315 .51089 Mtetra
.348 .067 .337 r
.69315 .51089 .6973 .48617 .70923 .47722 .70509 .49903 Mtetra
.311 .023 .304 r
.70509 .49903 .70923 .47722 .72116 .46816 .71701 .48698 Mtetra
.272 0 .261 r
.71701 .48698 .72116 .46816 .73313 .45933 .72893 .4752 Mtetra
.239 0 .209 r
.72893 .4752 .73313 .45933 .74516 .45126 .74091 .46431 Mtetra
.23 0 .153 r
.74091 .46431 .74516 .45126 .75732 .4448 .75302 .45527 Mtetra
.279 0 .106 r
.75302 .45527 .75732 .4448 .76973 .44115 .76538 .44943 Mtetra
.409 0 .086 r
.76538 .44943 .76973 .44115 .78254 .44174 .77814 .44835 Mtetra
.574 .104 .1 r
.77814 .44835 .78254 .44174 .79588 .44773 .79148 .45324 Mtetra
.696 .224 .127 r
.79148 .45324 .79588 .44773 .80982 .45913 .80545 .46417 Mtetra
.75 .285 .143 r
.80545 .46417 .80982 .45913 .82426 .47406 .81996 .47906 Mtetra
.743 .273 .131 r
.81996 .47906 .82426 .47406 .83886 .48844 .83463 .49355 Mtetra
.641 .146 .06 r
.83463 .49355 .83886 .48844 .8531 .49703 .84893 .50197 Mtetra
.234 0 0 r
.84893 .50197 .8531 .49703 .86644 .49542 .86229 .4996 Mtetra
.616 .868 .519 r
.86229 .4996 .86644 .49542 .87863 .48223 .87442 .48495 Mtetra
.927 .934 .574 r
.87442 .48495 .87863 .48223 .88977 .45978 .88546 .46052 Mtetra
.982 .905 .588 r
.88546 .46052 .88977 .45978 .9003 .43288 .89586 .43148 Mtetra
.988 .889 .626 r
.89586 .43148 .9003 .43288 .91078 .40656 .90621 .40321 Mtetra
.97 .883 .688 r
.90621 .40321 .91078 .40656 .92163 .38427 .91695 .37937 Mtetra
.625 .754 .939 r
.32214 .52896 .32883 .53449 .33934 .5318 .33266 .5265 Mtetra
.609 .758 .95 r
.33266 .5265 .33934 .5318 .34989 .5293 .34322 .52431 Mtetra
.585 .764 .964 r
.34322 .52431 .34989 .5293 .36048 .52705 .35381 .52246 Mtetra
.55 .768 .979 r
.35381 .52246 .36048 .52705 .37109 .52511 .36443 .52104 Mtetra
.494 .77 .993 r
.36443 .52104 .37109 .52511 .38175 .52353 .37508 .52012 Mtetra
.402 .758 .994 r
.37508 .52012 .38175 .52353 .39244 .52238 .38577 .5198 Mtetra
.253 .71 .953 r
.38577 .5198 .39244 .52238 .40317 .52172 .39649 .52016 Mtetra
.03 .586 .816 r
.39649 .52016 .40317 .52172 .41394 .52163 .40725 .52129 Mtetra
.223 0 0 r
.40725 .52129 .41394 .52163 .42476 .52215 .41807 .52327 Mtetra
.42 0 0 r
.41807 .52327 .42476 .52215 .43563 .52333 .42893 .52616 Mtetra
.535 .006 0 r
.42893 .52616 .43563 .52333 .44656 .52519 .43986 .52999 Mtetra
.594 .118 .094 r
.43986 .52999 .44656 .52519 .45756 .52773 .45086 .53475 Mtetra
.623 .19 .199 r
.45086 .53475 .45756 .52773 .46863 .53093 .46195 .54043 Mtetra
.636 .236 .27 r
.46195 .54043 .46863 .53093 .47979 .53473 .47313 .54692 Mtetra
.64 .266 .319 r
.47313 .54692 .47979 .53473 .49103 .53903 .48442 .5541 Mtetra
.638 .284 .355 r
.48442 .5541 .49103 .53903 .50238 .54368 .49583 .56178 Mtetra
.633 .295 .381 r
.49583 .56178 .50238 .54368 .51382 .54852 .50735 .56971 Mtetra
.626 .301 .4 r
.50735 .56971 .51382 .54852 .52537 .55333 .51901 .57761 Mtetra
.616 .302 .414 r
.51901 .57761 .52537 .55333 .53703 .55789 .53079 .58515 Mtetra
.605 .3 .425 r
.53079 .58515 .53703 .55789 .54878 .56193 .5427 .59198 Mtetra
.593 .294 .432 r
.5427 .59198 .54878 .56193 .56063 .56521 .55473 .59774 Mtetra
.579 .287 .436 r
.55473 .59774 .56063 .56521 .57257 .56747 .56685 .60209 Mtetra
.564 .277 .439 r
.56685 .60209 .57257 .56747 .58458 .56849 .57905 .60471 Mtetra
.547 .265 .439 r
.57905 .60471 .58458 .56849 .59664 .56809 .59132 .60537 Mtetra
.529 .251 .437 r
.59132 .60537 .59664 .56809 .60873 .56613 .60361 .60386 Mtetra
.509 .234 .433 r
.60361 .60386 .60873 .56613 .62085 .56255 .61592 .6001 Mtetra
.487 .215 .427 r
.61592 .6001 .62085 .56255 .63296 .55733 .62821 .59409 Mtetra
.463 .193 .419 r
.62821 .59409 .63296 .55733 .64507 .55054 .64047 .58593 Mtetra
.436 .169 .408 r
.64047 .58593 .64507 .55054 .65714 .54231 .65268 .57579 Mtetra
.407 .14 .394 r
.65268 .57579 .65714 .54231 .66918 .5328 .66482 .56393 Mtetra
.373 .107 .375 r
.66482 .56393 .66918 .5328 .68119 .52224 .67689 .55067 Mtetra
.335 .068 .351 r
.67689 .55067 .68119 .52224 .69315 .51089 .68889 .53636 Mtetra
.292 .021 .32 r
.68889 .53636 .69315 .51089 .70509 .49903 .70084 .52138 Mtetra
.243 0 .281 r
.70084 .52138 .70509 .49903 .71701 .48698 .71275 .50618 Mtetra
.19 0 .231 r
.71275 .50618 .71701 .48698 .72893 .4752 .72464 .4913 Mtetra
.143 0 .172 r
.72464 .4913 .72893 .4752 .74091 .46431 .73657 .47747 Mtetra
.126 0 .11 r
.73657 .47747 .74091 .46431 .75302 .45527 .74862 .46578 Mtetra
.18 0 .06 r
.74862 .46578 .75302 .45527 .76538 .44943 .76093 .45768 Mtetra
.336 0 .046 r
.76093 .45768 .76538 .44943 .77814 .44835 .77367 .45486 Mtetra
.54 .064 .074 r
.77367 .45486 .77814 .44835 .79148 .45324 .78699 .45864 Mtetra
.685 .208 .112 r
.78699 .45864 .79148 .45324 .80545 .46417 .80099 .46906 Mtetra
.748 .279 .133 r
.80099 .46906 .80545 .46417 .81996 .47906 .81556 .4839 Mtetra
.743 .269 .122 r
.81556 .4839 .81996 .47906 .83463 .49355 .83031 .49848 Mtetra
.634 .133 .044 r
.83031 .49848 .83463 .49355 .84893 .50197 .84467 .50674 Mtetra
.174 0 0 r
.84467 .50674 .84893 .50197 .86229 .4996 .85804 .5036 Mtetra
.695 .903 .547 r
.85804 .5036 .86229 .4996 .87442 .48495 .87014 .48748 Mtetra
.947 .926 .57 r
.87014 .48748 .87442 .48495 .88546 .46052 .88108 .46107 Mtetra
.988 .893 .577 r
.88108 .46107 .88546 .46052 .89586 .43148 .89135 .42991 Mtetra
.991 .878 .613 r
.89135 .42991 .89586 .43148 .90621 .40321 .90158 .39972 Mtetra
.974 .874 .674 r
.90158 .39972 .90621 .40321 .91695 .37937 .91222 .37435 Mtetra
.616 .747 .939 r
.31539 .52328 .32214 .52896 .33266 .5265 .32593 .52099 Mtetra
.597 .749 .95 r
.32593 .52099 .33266 .5265 .34322 .52431 .3365 .51905 Mtetra
.569 .75 .963 r
.3365 .51905 .34322 .52431 .35381 .52246 .3471 .51753 Mtetra
.529 .749 .976 r
.3471 .51753 .35381 .52246 .36443 .52104 .35772 .51652 Mtetra
.467 .742 .988 r
.35772 .51652 .36443 .52104 .37508 .52012 .36837 .51614 Mtetra
.37 .72 .988 r
.36837 .51614 .37508 .52012 .38577 .5198 .37906 .51648 Mtetra
.219 .664 .951 r
.37906 .51648 .38577 .5198 .39649 .52016 .38978 .51765 Mtetra
.003 .545 .837 r
.38978 .51765 .39649 .52016 .40725 .52129 .40054 .51977 Mtetra
.243 0 0 r
.40054 .51977 .40725 .52129 .41807 .52327 .41134 .52291 Mtetra
.445 0 0 r
.41134 .52291 .41807 .52327 .42893 .52616 .4222 .52716 Mtetra
.57 .015 0 r
.4222 .52716 .42893 .52616 .43986 .52999 .43313 .53254 Mtetra
.637 .129 .026 r
.43313 .53254 .43986 .52999 .45086 .53475 .44413 .53907 Mtetra
.669 .204 .139 r
.44413 .53907 .45086 .53475 .46195 .54043 .45522 .5467 Mtetra
.683 .252 .218 r
.45522 .5467 .46195 .54043 .47313 .54692 .46642 .55533 Mtetra
.686 .282 .274 r
.46642 .55533 .47313 .54692 .48442 .5541 .47774 .56478 Mtetra
.684 .3 .314 r
.47774 .56478 .48442 .5541 .49583 .56178 .48919 .57483 Mtetra
.676 .309 .343 r
.48919 .57483 .49583 .56178 .50735 .56971 .50077 .58519 Mtetra
.666 .312 .365 r
.50077 .58519 .50735 .56971 .51901 .57761 .51251 .59549 Mtetra
.653 .31 .38 r
.51251 .59549 .51901 .57761 .53079 .58515 .52439 .60535 Mtetra
.637 .304 .391 r
.52439 .60535 .53079 .58515 .5427 .59198 .53641 .61432 Mtetra
.619 .294 .398 r
.53641 .61432 .5427 .59198 .55473 .59774 .54857 .62198 Mtetra
.598 .28 .401 r
.54857 .62198 .55473 .59774 .56685 .60209 .56083 .6279 Mtetra
.574 .262 .402 r
.56083 .6279 .56685 .60209 .57905 .60471 .5732 .63169 Mtetra
.547 .24 .399 r
.5732 .63169 .57905 .60471 .59132 .60537 .58562 .63306 Mtetra
.517 .215 .394 r
.58562 .63306 .59132 .60537 .60361 .60386 .59808 .63179 Mtetra
.482 .185 .384 r
.59808 .63179 .60361 .60386 .61592 .6001 .61054 .62776 Mtetra
.443 .15 .371 r
.61054 .62776 .61592 .6001 .62821 .59409 .62298 .62099 Mtetra
.398 .109 .353 r
.62298 .62099 .62821 .59409 .64047 .58593 .63537 .61161 Mtetra
.346 .061 .329 r
.63537 .61161 .64047 .58593 .65268 .57579 .64769 .59985 Mtetra
.286 .004 .298 r
.64769 .59985 .65268 .57579 .66482 .56393 .65992 .58604 Mtetra
.217 0 .258 r
.65992 .58604 .66482 .56393 .67689 .55067 .67206 .57056 Mtetra
.135 0 .206 r
.67206 .57056 .67689 .55067 .68889 .53636 .68411 .55386 Mtetra
.041 0 .139 r
.68411 .55386 .68889 .53636 .70084 .52138 .69608 .5364 Mtetra
0 0 .056 r
.69608 .5364 .70084 .52138 .71275 .50618 .70799 .51871 Mtetra
0 0 0 r
.70799 .51871 .71275 .50618 .72464 .4913 .71988 .50141 Mtetra
.71988 .50141 .72464 .4913 .73657 .47747 .73179 .48533 Mtetra
.73179 .48533 .73657 .47747 .74862 .46578 .74382 .47163 Mtetra
.74382 .47163 .74862 .46578 .76093 .45768 .75611 .4619 Mtetra
.06 0 0 r
.75611 .4619 .76093 .45768 .77367 .45486 .76885 .45791 Mtetra
.446 0 0 r
.76885 .45791 .77367 .45486 .78699 .45864 .7822 .46108 Mtetra
.671 .144 0 r
.7822 .46108 .78699 .45864 .80099 .46906 .79625 .47142 Mtetra
.752 .252 .033 r
.79625 .47142 .80099 .46906 .81556 .4839 .8109 .4866 Mtetra
.747 .247 .037 r
.8109 .4866 .81556 .4839 .83031 .49848 .82575 .50161 Mtetra
.619 .084 0 r
.82575 .50161 .83031 .49848 .84467 .50674 .84019 .50998 Mtetra
.019 0 0 r
.84019 .50998 .84467 .50674 .85804 .5036 .8536 .50633 Mtetra
.819 .962 .634 r
.8536 .50633 .85804 .5036 .87014 .48748 .86568 .48898 Mtetra
.972 .917 .588 r
.86568 .48898 .87014 .48748 .88108 .46107 .87654 .46082 Mtetra
.993 .877 .579 r
.87654 .46082 .88108 .46107 .89135 .42991 .88672 .42772 Mtetra
.991 .863 .608 r
.88672 .42772 .89135 .42991 .90158 .39972 .89684 .39575 Mtetra
.975 .861 .664 r
.89684 .39575 .90158 .39972 .91222 .37435 .90741 .36897 Mtetra
.614 .737 .933 r
.30862 .51726 .31539 .52328 .32593 .52099 .31917 .51505 Mtetra
.595 .735 .941 r
.31917 .51505 .32593 .52099 .3365 .51905 .32976 .51321 Mtetra
.569 .731 .951 r
.32976 .51321 .3365 .51905 .3471 .51753 .34037 .51183 Mtetra
.534 .724 .961 r
.34037 .51183 .3471 .51753 .35772 .51652 .35101 .51101 Mtetra
.483 .711 .971 r
.35101 .51101 .35772 .51652 .36837 .51614 .36167 .51085 Mtetra
.412 .69 .976 r
.36167 .51085 .36837 .51614 .37906 .51648 .37237 .51148 Mtetra
.311 .652 .97 r
.37237 .51148 .37906 .51648 .38978 .51765 .38309 .51301 Mtetra
.172 .587 .938 r
.38309 .51301 .38978 .51765 .40054 .51977 .39386 .51554 Mtetra
0 .485 .861 r
.39386 .51554 .40054 .51977 .41134 .52291 .40466 .51919 Mtetra
0 .345 .729 r
.40466 .51919 .41134 .52291 .4222 .52716 .41553 .52401 Mtetra
.392 0 0 r
.41553 .52401 .4222 .52716 .43313 .53254 .42645 .53005 Mtetra
.535 0 0 r
.42645 .53005 .43313 .53254 .44413 .53907 .43746 .53731 Mtetra
.63 .066 0 r
.43746 .53731 .44413 .53907 .45522 .5467 .44856 .54574 Mtetra
.687 .146 0 r
.44856 .54574 .45522 .5467 .46642 .55533 .45976 .55522 Mtetra
.719 .201 0 r
.45976 .55522 .46642 .55533 .47774 .56478 .47109 .56558 Mtetra
.735 .235 .043 r
.47109 .56558 .47774 .56478 .48919 .57483 .48256 .57656 Mtetra
.738 .253 .089 r
.48256 .57656 .48919 .57483 .50077 .58519 .49417 .58784 Mtetra
.733 .258 .119 r
.49417 .58784 .50077 .58519 .51251 .59549 .50594 .59904 Mtetra
.719 .251 .137 r
.50594 .59904 .51251 .59549 .52439 .60535 .51786 .60974 Mtetra
.697 .232 .143 r
.51786 .60974 .52439 .60535 .53641 .61432 .52994 .61946 Mtetra
.665 .2 .138 r
.52994 .61946 .53641 .61432 .54857 .62198 .54215 .62773 Mtetra
.62 .152 .12 r
.54215 .62773 .54857 .62198 .56083 .6279 .55448 .63412 Mtetra
.556 .083 .087 r
.55448 .63412 .56083 .6279 .5732 .63169 .56691 .6382 Mtetra
.465 0 .033 r
.56691 .6382 .5732 .63169 .58562 .63306 .57942 .63967 Mtetra
.334 0 0 r
.57942 .63967 .58562 .63306 .59808 .63179 .59195 .63829 Mtetra
.151 0 0 r
.59195 .63829 .59808 .63179 .61054 .62776 .6045 .63396 Mtetra
0 0 0 r
.6045 .63396 .61054 .62776 .62298 .62099 .61701 .6267 Mtetra
.61701 .6267 .62298 .62099 .63537 .61161 .62948 .61667 Mtetra
.587 .881 .579 r
.62948 .61667 .63537 .61161 .64769 .59985 .64186 .60411 Mtetra
.752 .958 .656 r
.64186 .60411 .64769 .59985 .65992 .58604 .65416 .5894 Mtetra
.851 .983 .698 r
.65416 .5894 .65992 .58604 .67206 .57056 .66636 .57295 Mtetra
.905 .982 .721 r
.66636 .57295 .67206 .57056 .68411 .55386 .67846 .55524 Mtetra
.931 .97 .735 r
.67846 .55524 .68411 .55386 .69608 .5364 .69048 .53678 Mtetra
.942 .955 .746 r
.69048 .53678 .69608 .5364 .70799 .51871 .70243 .51811 Mtetra
.941 .942 .761 r
.70243 .51811 .70799 .51871 .71988 .50141 .71435 .49989 Mtetra
.929 .933 .784 r
.71435 .49989 .71988 .50141 .73179 .48533 .7263 .48301 Mtetra
.901 .929 .825 r
.7263 .48301 .73179 .48533 .74382 .47163 .73836 .46868 Mtetra
.83 .928 .897 r
.73836 .46868 .74382 .47163 .75611 .4619 .7507 .45856 Mtetra
.613 .874 .991 r
.7507 .45856 .75611 .4619 .76885 .45791 .76348 .45453 Mtetra
.025 .53 .871 r
.76348 .45453 .76885 .45791 .7822 .46108 .77691 .45807 Mtetra
.522 0 0 r
.77691 .45807 .7822 .46108 .79625 .47142 .79107 .4692 Mtetra
.705 .175 0 r
.79107 .4692 .79625 .47142 .8109 .4866 .80584 .48543 Mtetra
.721 .191 0 r
.80584 .48543 .8109 .4866 .82575 .50161 .82083 .5015 Mtetra
.561 0 0 r
.82083 .5015 .82575 .50161 .84019 .50998 .83539 .51055 Mtetra
.265 .771 .772 r
.83539 .51055 .84019 .50998 .8536 .50633 .84888 .50689 Mtetra
.915 .979 .722 r
.84888 .50689 .8536 .50633 .86568 .48898 .86098 .48875 Mtetra
.987 .898 .613 r
.86098 .48875 .86568 .48898 .87654 .46082 .87181 .45921 Mtetra
.994 .859 .588 r
.87181 .45921 .87654 .46082 .88672 .42772 .88192 .42449 Mtetra
.989 .846 .608 r
.88192 .42449 .88672 .42772 .89684 .39575 .89198 .39101 Mtetra
.972 .846 .659 r
.89198 .39101 .89684 .39575 .90741 .36897 .90249 .36303 Mtetra
.618 .726 .923 r
.30182 .51083 .30862 .51726 .31917 .51505 .3124 .50856 Mtetra
.603 .72 .927 r
.3124 .50856 .31917 .51505 .32976 .51321 .32301 .50663 Mtetra
.582 .711 .931 r
.32301 .50663 .32976 .51321 .34037 .51183 .33364 .50515 Mtetra
.556 .699 .935 r
.33364 .50515 .34037 .51183 .35101 .51101 .34431 .5042 Mtetra
.523 .683 .939 r
.34431 .5042 .35101 .51101 .36167 .51085 .355 .50389 Mtetra
.481 .661 .941 r
.355 .50389 .36167 .51085 .37237 .51148 .36572 .50432 Mtetra
.43 .632 .939 r
.36572 .50432 .37237 .51148 .38309 .51301 .37647 .50561 Mtetra
.369 .594 .933 r
.37647 .50561 .38309 .51301 .39386 .51554 .38726 .50786 Mtetra
.301 .549 .92 r
.38726 .50786 .39386 .51554 .40466 .51919 .39809 .51115 Mtetra
.228 .496 .9 r
.39809 .51115 .40466 .51919 .41553 .52401 .40897 .51555 Mtetra
.156 .44 .874 r
.40897 .51555 .41553 .52401 .42645 .53005 .41991 .52111 Mtetra
.092 .385 .845 r
.41991 .52111 .42645 .53005 .43746 .53731 .43093 .5278 Mtetra
.043 .337 .817 r
.43093 .5278 .43746 .53731 .44856 .54574 .44204 .53558 Mtetra
.013 .3 .793 r
.44204 .53558 .44856 .54574 .45976 .55522 .45326 .54433 Mtetra
.007 .277 .777 r
.45326 .54433 .45976 .55522 .47109 .56558 .46459 .55388 Mtetra
.024 .271 .769 r
.46459 .55388 .47109 .56558 .48256 .57656 .47605 .56398 Mtetra
.064 .279 .769 r
.47605 .56398 .48256 .57656 .49417 .58784 .48766 .57433 Mtetra
.123 .301 .772 r
.48766 .57433 .49417 .58784 .50594 .59904 .49941 .58456 Mtetra
.195 .332 .776 r
.49941 .58456 .50594 .59904 .51786 .60974 .51132 .59427 Mtetra
.274 .368 .778 r
.51132 .59427 .51786 .60974 .52994 .61946 .52337 .60302 Mtetra
.353 .405 .777 r
.52337 .60302 .52994 .61946 .54215 .62773 .53556 .61038 Mtetra
.426 .44 .771 r
.53556 .61038 .54215 .62773 .55448 .63412 .54787 .61592 Mtetra
.492 .472 .763 r
.54787 .61592 .55448 .63412 .56691 .6382 .56027 .61927 Mtetra
.548 .5 .754 r
.56027 .61927 .56691 .6382 .57942 .63967 .57275 .62015 Mtetra
.596 .523 .743 r
.57275 .62015 .57942 .63967 .59195 .63829 .58527 .61835 Mtetra
.636 .544 .733 r
.58527 .61835 .59195 .63829 .6045 .63396 .59779 .61379 Mtetra
.669 .561 .724 r
.59779 .61379 .6045 .63396 .61701 .6267 .61031 .60649 Mtetra
.697 .576 .716 r
.61031 .60649 .61701 .6267 .62948 .61667 .62277 .5966 Mtetra
.72 .59 .71 r
.62277 .5966 .62948 .61667 .64186 .60411 .63518 .58438 Mtetra
.739 .602 .705 r
.63518 .58438 .64186 .60411 .65416 .5894 .6475 .57017 Mtetra
.754 .613 .702 r
.6475 .57017 .65416 .5894 .66636 .57295 .65974 .55436 Mtetra
.767 .623 .701 r
.65974 .55436 .66636 .57295 .67846 .55524 .6719 .5374 Mtetra
.777 .633 .701 r
.6719 .5374 .67846 .55524 .69048 .53678 .68398 .51977 Mtetra
.785 .643 .704 r
.68398 .51977 .69048 .53678 .70243 .51811 .696 .50199 Mtetra
.788 .651 .71 r
.696 .50199 .70243 .51811 .71435 .49989 .708 .48471 Mtetra
.786 .658 .722 r
.708 .48471 .71435 .49989 .7263 .48301 .72004 .46878 Mtetra
.77 .661 .742 r
.72004 .46878 .7263 .48301 .73836 .46868 .7322 .45546 Mtetra
.729 .655 .776 r
.7322 .45546 .73836 .46868 .7507 .45856 .74464 .44646 Mtetra
.622 .622 .829 r
.74464 .44646 .7507 .45856 .76348 .45453 .75754 .44372 Mtetra
.352 .499 .866 r
.75754 .44372 .76348 .45453 .77691 .45807 .7711 .44878 Mtetra
0 .209 .735 r
.7711 .44878 .77691 .45807 .79107 .4692 .78541 .46167 Mtetra
0 0 .491 r
.78541 .46167 .79107 .4692 .80584 .48543 .80035 .4798 Mtetra
.592 .1 0 r
.80035 .4798 .80584 .48543 .82083 .5015 .81552 .49764 Mtetra
0 .146 .588 r
.81552 .49764 .82083 .5015 .83539 .51055 .83024 .50801 Mtetra
.495 .861 .987 r
.83024 .50801 .83539 .51055 .84888 .50689 .84386 .50491 Mtetra
.94 .94 .764 r
.84386 .50491 .84888 .50689 .86098 .48875 .85601 .4865 Mtetra
.987 .871 .632 r
.85601 .4865 .86098 .48875 .87181 .45921 .86686 .45603 Mtetra
.99 .839 .597 r
.86686 .45603 .87181 .45921 .88192 .42449 .87695 .42009 Mtetra
.984 .829 .61 r
.87695 .42009 .88192 .42449 .89198 .39101 .88697 .38542 Mtetra
.967 .83 .655 r
.88697 .38542 .89198 .39101 .90249 .36303 .89746 .35646 Mtetra
.627 .718 .912 r
.29499 .50402 .30182 .51083 .3124 .50856 .3056 .50155 Mtetra
.615 .709 .912 r
.3056 .50155 .3124 .50856 .32301 .50663 .31625 .49938 Mtetra
.601 .698 .911 r
.31625 .49938 .32301 .50663 .33364 .50515 .32692 .49758 Mtetra
.583 .683 .909 r
.32692 .49758 .33364 .50515 .34431 .5042 .33762 .49623 Mtetra
.562 .664 .906 r
.33762 .49623 .34431 .5042 .355 .50389 .34835 .49542 Mtetra
.538 .641 .899 r
.34835 .49542 .355 .50389 .36572 .50432 .35912 .49523 Mtetra
.511 .613 .89 r
.35912 .49523 .36572 .50432 .37647 .50561 .36991 .49577 Mtetra
.483 .581 .877 r
.36991 .49577 .37647 .50561 .38726 .50786 .38074 .4971 Mtetra
.456 .547 .861 r
.38074 .4971 .38726 .50786 .39809 .51115 .39161 .49931 Mtetra
.431 .512 .841 r
.39161 .49931 .39809 .51115 .40897 .51555 .40254 .50244 Mtetra
.411 .478 .819 r
.40254 .50244 .40897 .51555 .41991 .52111 .41352 .50652 Mtetra
.397 .447 .796 r
.41352 .50652 .41991 .52111 .43093 .5278 .42457 .51153 Mtetra
.39 .421 .773 r
.42457 .51153 .43093 .5278 .44204 .53558 .4357 .51743 Mtetra
.39 .401 .751 r
.4357 .51743 .44204 .53558 .45326 .54433 .44693 .52412 Mtetra
.396 .387 .732 r
.44693 .52412 .45326 .54433 .46459 .55388 .45827 .53143 Mtetra
.408 .379 .715 r
.45827 .53143 .46459 .55388 .47605 .56398 .46972 .53916 Mtetra
.425 .376 .7 r
.46972 .53916 .47605 .56398 .48766 .57433 .4813 .54706 Mtetra
.443 .376 .687 r
.4813 .54706 .48766 .57433 .49941 .58456 .49301 .55481 Mtetra
.464 .381 .677 r
.49301 .55481 .49941 .58456 .51132 .59427 .50486 .56208 Mtetra
.485 .387 .669 r
.50486 .56208 .51132 .59427 .52337 .60302 .51683 .56851 Mtetra
.506 .395 .662 r
.51683 .56851 .52337 .60302 .53556 .61038 .52893 .57375 Mtetra
.527 .404 .656 r
.52893 .57375 .53556 .61038 .54787 .61592 .54114 .57746 Mtetra
.547 .414 .651 r
.54114 .57746 .54787 .61592 .56027 .61927 .55344 .57934 Mtetra
.566 .425 .648 r
.55344 .57934 .56027 .61927 .57275 .62015 .56582 .57916 Mtetra
.584 .435 .645 r
.56582 .57916 .57275 .62015 .58527 .61835 .57823 .57677 Mtetra
.601 .446 .643 r
.57823 .57677 .58527 .61835 .59779 .61379 .59067 .57211 Mtetra
.617 .456 .642 r
.59067 .57211 .59779 .61379 .61031 .60649 .60311 .56521 Mtetra
.631 .467 .642 r
.60311 .56521 .61031 .60649 .62277 .5966 .61552 .5562 Mtetra
.645 .478 .643 r
.61552 .5562 .62277 .5966 .63518 .58438 .62789 .54529 Mtetra
.657 .488 .644 r
.62789 .54529 .63518 .58438 .6475 .57017 .64021 .53275 Mtetra
.669 .499 .646 r
.64021 .53275 .6475 .57017 .65974 .55436 .65247 .51892 Mtetra
.68 .51 .649 r
.65247 .51892 .65974 .55436 .6719 .5374 .66467 .50416 Mtetra
.689 .521 .654 r
.66467 .50416 .6719 .5374 .68398 .51977 .67683 .48888 Mtetra
.697 .531 .659 r
.67683 .48888 .68398 .51977 .696 .50199 .68894 .47351 Mtetra
.703 .542 .667 r
.68894 .47351 .696 .50199 .708 .48471 .70105 .45864 Mtetra
.702 .55 .677 r
.70105 .45864 .708 .48471 .72004 .46878 .71321 .44509 Mtetra
.691 .553 .693 r
.71321 .44509 .72004 .46878 .7322 .45546 .72551 .4341 Mtetra
.656 .545 .717 r
.72551 .4341 .7322 .45546 .74464 .44646 .73809 .42741 Mtetra
.571 .512 .75 r
.73809 .42741 .74464 .44646 .75754 .44372 .75115 .427 Mtetra
.378 .419 .777 r
.75115 .427 .75754 .44372 .7711 .44878 .76488 .43447 Mtetra
.027 .223 .728 r
.76488 .43447 .7711 .44878 .78541 .46167 .77937 .44987 Mtetra
0 .01 .583 r
.77937 .44987 .78541 .46167 .80035 .4798 .79452 .47051 Mtetra
0 0 .517 r
.79452 .47051 .80035 .4798 .81552 .49764 .80989 .49067 Mtetra
0 .189 .701 r
.80989 .49067 .81552 .49764 .83024 .50801 .8248 .50283 Mtetra
.543 .788 .989 r
.8248 .50283 .83024 .50801 .84386 .50491 .83857 .50075 Mtetra
.927 .891 .775 r
.83857 .50075 .84386 .50491 .85601 .4865 .85082 .48249 Mtetra
.978 .846 .642 r
.85082 .48249 .85601 .4865 .86686 .45603 .86171 .45149 Mtetra
.984 .822 .602 r
.86171 .45149 .86686 .45603 .87695 .42009 .87181 .41466 Mtetra
.979 .816 .611 r
.87181 .41466 .87695 .42009 .88697 .38542 .88183 .37906 Mtetra
.963 .818 .653 r
.88183 .37906 .88697 .38542 .89746 .35646 .89233 .34936 Mtetra
.637 .715 .904 r
.28812 .49696 .29499 .50402 .3056 .50155 .29878 .49422 Mtetra
.628 .705 .901 r
.29878 .49422 .3056 .50155 .31625 .49938 .30946 .49171 Mtetra
.618 .693 .897 r
.30946 .49171 .31625 .49938 .32692 .49758 .32018 .48947 Mtetra
.607 .678 .892 r
.32018 .48947 .32692 .49758 .33762 .49623 .33093 .48756 Mtetra
.593 .659 .884 r
.33093 .48756 .33762 .49623 .34835 .49542 .34171 .48606 Mtetra
.578 .636 .873 r
.34171 .48606 .34835 .49542 .35912 .49523 .35253 .48502 Mtetra
.562 .611 .859 r
.35253 .48502 .35912 .49523 .36991 .49577 .36338 .48452 Mtetra
.546 .583 .843 r
.36338 .48452 .36991 .49577 .38074 .4971 .37427 .4846 Mtetra
.53 .553 .823 r
.37427 .4846 .38074 .4971 .39161 .49931 .3852 .48533 Mtetra
.517 .524 .802 r
.3852 .48533 .39161 .49931 .40254 .50244 .39618 .48673 Mtetra
.505 .495 .78 r
.39618 .48673 .40254 .50244 .41352 .50652 .40721 .48883 Mtetra
.497 .47 .757 r
.40721 .48883 .41352 .50652 .42457 .51153 .41831 .4916 Mtetra
.493 .448 .736 r
.41831 .4916 .42457 .51153 .4357 .51743 .42948 .495 Mtetra
.491 .43 .716 r
.42948 .495 .4357 .51743 .44693 .52412 .44074 .49896 Mtetra
.493 .417 .699 r
.44074 .49896 .44693 .52412 .45827 .53143 .45208 .50334 Mtetra
.497 .407 .683 r
.45208 .50334 .45827 .53143 .46972 .53916 .46352 .508 Mtetra
.504 .4 .67 r
.46352 .508 .46972 .53916 .4813 .54706 .47507 .51274 Mtetra
.511 .397 .659 r
.47507 .51274 .4813 .54706 .49301 .55481 .48673 .51734 Mtetra
.52 .395 .65 r
.48673 .51734 .49301 .55481 .50486 .56208 .49851 .52155 Mtetra
.53 .396 .643 r
.49851 .52155 .50486 .56208 .51683 .56851 .51039 .5251 Mtetra
.54 .399 .637 r
.51039 .5251 .51683 .56851 .52893 .57375 .52238 .52775 Mtetra
.551 .402 .632 r
.52238 .52775 .52893 .57375 .54114 .57746 .53446 .52926 Mtetra
.561 .407 .629 r
.53446 .52926 .54114 .57746 .55344 .57934 .54663 .52942 Mtetra
.572 .412 .626 r
.54663 .52942 .55344 .57934 .56582 .57916 .55886 .52807 Mtetra
.582 .418 .625 r
.55886 .52807 .56582 .57916 .57823 .57677 .57114 .5251 Mtetra
.592 .425 .624 r
.57114 .5251 .57823 .57677 .59067 .57211 .58345 .52049 Mtetra
.601 .431 .624 r
.58345 .52049 .59067 .57211 .60311 .56521 .59578 .51426 Mtetra
.611 .439 .625 r
.59578 .51426 .60311 .56521 .61552 .5562 .60811 .50651 Mtetra
.62 .446 .626 r
.60811 .50651 .61552 .5562 .62789 .54529 .62042 .49738 Mtetra
.629 .455 .628 r
.62042 .49738 .62789 .54529 .64021 .53275 .63271 .48708 Mtetra
.637 .463 .631 r
.63271 .48708 .64021 .53275 .65247 .51892 .64498 .47586 Mtetra
.645 .472 .635 r
.64498 .47586 .65247 .51892 .66467 .50416 .65722 .46397 Mtetra
.652 .482 .64 r
.65722 .46397 .66467 .50416 .67683 .48888 .66943 .45171 Mtetra
.659 .492 .646 r
.66943 .45171 .67683 .48888 .68894 .47351 .68164 .43944 Mtetra
.663 .501 .654 r
.68164 .43944 .68894 .47351 .70105 .45864 .69387 .42766 Mtetra
.662 .508 .665 r
.69387 .42766 .70105 .45864 .71321 .44509 .70616 .41713 Mtetra
.65 .51 .679 r
.70616 .41713 .71321 .44509 .72551 .4341 .7186 .40906 Mtetra
.613 .5 .7 r
.7186 .40906 .72551 .4341 .73809 .42741 .73134 .40519 Mtetra
.526 .462 .727 r
.73134 .40519 .73809 .42741 .75115 .427 .74456 .40755 Mtetra
.338 .366 .743 r
.74456 .40755 .75115 .427 .76488 .43447 .75846 .41779 Mtetra
.012 .18 .692 r
.75846 .41779 .76488 .43447 .77937 .44987 .77315 .43597 Mtetra
0 0 .567 r
.77315 .43597 .77937 .44987 .79452 .47051 .78849 .45934 Mtetra
0 0 .516 r
.78849 .45934 .79452 .47051 .80989 .49067 .80406 .48198 Mtetra
0 .16 .694 r
.80406 .48198 .80989 .49067 .8248 .50283 .81917 .49611 Mtetra
.519 .721 .965 r
.81917 .49611 .8248 .50283 .83857 .50075 .8331 .49523 Mtetra
.911 .861 .778 r
.8331 .49523 .83857 .50075 .85082 .48249 .84547 .47734 Mtetra
.971 .831 .647 r
.84547 .47734 .85082 .48249 .86171 .45149 .85643 .44604 Mtetra
.979 .811 .605 r
.85643 .44604 .86171 .45149 .87181 .41466 .86656 .40854 Mtetra
.975 .807 .611 r
.86656 .40854 .87181 .41466 .88183 .37906 .8766 .37221 Mtetra
.96 .81 .65 r
.8766 .37221 .88183 .37906 .89233 .34936 .88711 .3419 Mtetra
.646 .717 .9 r
.28121 .48982 .28812 .49696 .29878 .49422 .2919 .48681 Mtetra
.64 .708 .896 r
.2919 .48681 .29878 .49422 .30946 .49171 .30263 .48394 Mtetra
.634 .697 .891 r
.30263 .48394 .30946 .49171 .32018 .48947 .3134 .48125 Mtetra
.626 .683 .884 r
.3134 .48125 .32018 .48947 .33093 .48756 .3242 .47878 Mtetra
.617 .667 .875 r
.3242 .47878 .33093 .48756 .34171 .48606 .33504 .47657 Mtetra
.607 .647 .864 r
.33504 .47657 .34171 .48606 .35253 .48502 .34591 .47467 Mtetra
.597 .625 .85 r
.34591 .47467 .35253 .48502 .36338 .48452 .35682 .47311 Mtetra
.586 .6 .833 r
.35682 .47311 .36338 .48452 .37427 .4846 .36778 .47194 Mtetra
.575 .574 .814 r
.36778 .47194 .37427 .4846 .3852 .48533 .37877 .47118 Mtetra
.565 .548 .794 r
.37877 .47118 .3852 .48533 .39618 .48673 .38981 .47087 Mtetra
.557 .523 .773 r
.38981 .47087 .39618 .48673 .40721 .48883 .40091 .47099 Mtetra
.55 .5 .753 r
.40091 .47099 .40721 .48883 .41831 .4916 .41206 .47154 Mtetra
.544 .479 .733 r
.41206 .47154 .41831 .4916 .42948 .495 .42328 .47249 Mtetra
.541 .461 .714 r
.42328 .47249 .42948 .495 .44074 .49896 .43456 .47379 Mtetra
.54 .447 .698 r
.43456 .47379 .44074 .49896 .45208 .50334 .44592 .47534 Mtetra
.54 .435 .683 r
.44592 .47534 .45208 .50334 .46352 .508 .45737 .47705 Mtetra
.542 .426 .671 r
.45737 .47705 .46352 .508 .47507 .51274 .4689 .47878 Mtetra
.545 .42 .66 r
.4689 .47878 .47507 .51274 .48673 .51734 .48052 .48038 Mtetra
.549 .416 .651 r
.48052 .48038 .48673 .51734 .49851 .52155 .49223 .48171 Mtetra
.554 .413 .644 r
.49223 .48171 .49851 .52155 .51039 .5251 .50403 .48259 Mtetra
.56 .413 .638 r
.50403 .48259 .51039 .5251 .52238 .52775 .51592 .48285 Mtetra
.565 .413 .633 r
.51592 .48285 .52238 .52775 .53446 .52926 .52789 .48236 Mtetra
.572 .415 .63 r
.52789 .48236 .53446 .52926 .54663 .52942 .53993 .48098 Mtetra
.578 .417 .628 r
.53993 .48098 .54663 .52942 .55886 .52807 .55203 .47862 Mtetra
.584 .421 .626 r
.55203 .47862 .55886 .52807 .57114 .5251 .56418 .47521 Mtetra
.591 .425 .625 r
.56418 .47521 .57114 .5251 .58345 .52049 .57638 .47073 Mtetra
.598 .43 .625 r
.57638 .47073 .58345 .52049 .59578 .51426 .5886 .46522 Mtetra
.604 .435 .626 r
.5886 .46522 .59578 .51426 .60811 .50651 .60084 .45872 Mtetra
.611 .442 .628 r
.60084 .45872 .60811 .50651 .62042 .49738 .6131 .45134 Mtetra
.617 .448 .631 r
.6131 .45134 .62042 .49738 .63271 .48708 .62536 .44321 Mtetra
.624 .456 .634 r
.62536 .44321 .63271 .48708 .64498 .47586 .63762 .43448 Mtetra
.63 .464 .639 r
.63762 .43448 .64498 .47586 .65722 .46397 .64988 .42533 Mtetra
.636 .473 .645 r
.64988 .42533 .65722 .46397 .66943 .45171 .66216 .41596 Mtetra
.641 .482 .652 r
.66216 .41596 .66943 .45171 .68164 .43944 .67444 .40665 Mtetra
.644 .491 .661 r
.67444 .40665 .68164 .43944 .69387 .42766 .68677 .3978 Mtetra
.641 .498 .672 r
.68677 .3978 .69387 .42766 .70616 .41713 .69918 .39014 Mtetra
.625 .498 .688 r
.69918 .39014 .70616 .41713 .7186 .40906 .71176 .38483 Mtetra
.58 .483 .709 r
.71176 .38483 .7186 .40906 .73134 .40519 .72463 .38363 Mtetra
.475 .435 .733 r
.72463 .38363 .73134 .40519 .74456 .40755 .738 .3886 Mtetra
.252 .315 .734 r
.738 .3886 .74456 .40755 .75846 .41779 .75206 .40142 Mtetra
0 .104 .649 r
.75206 .40142 .75846 .41779 .77315 .43597 .76691 .42217 Mtetra
0 0 .503 r
.76691 .42217 .77315 .43597 .78849 .45934 .78242 .44807 Mtetra
0 0 .456 r
.78242 .44807 .78849 .45934 .80406 .48198 .79818 .473 Mtetra
0 .095 .642 r
.79818 .473 .80406 .48198 .81917 .49611 .81345 .48895 Mtetra
.472 .685 .959 r
.81345 .48895 .81917 .49611 .8331 .49523 .82753 .48919 Mtetra
.902 .85 .782 r
.82753 .48919 .8331 .49523 .84547 .47734 .84001 .47167 Mtetra
.968 .824 .648 r
.84001 .47167 .84547 .47734 .85643 .44604 .85105 .44013 Mtetra
.977 .806 .604 r
.85105 .44013 .85643 .44604 .86656 .40854 .86123 .40207 Mtetra
.974 .802 .609 r
.86123 .40207 .86656 .40854 .8766 .37221 .8713 .36511 Mtetra
.96 .807 .648 r
.8713 .36511 .8766 .37221 .88711 .3419 .88184 .33428 Mtetra
.653 .722 .9 r
.27424 .48274 .28121 .48982 .2919 .48681 .28497 .4795 Mtetra
.65 .715 .896 r
.28497 .4795 .2919 .48681 .30263 .48394 .29574 .47633 Mtetra
.646 .707 .891 r
.29574 .47633 .30263 .48394 .3134 .48125 .30655 .47326 Mtetra
.641 .696 .885 r
.30655 .47326 .3134 .48125 .3242 .47878 .3174 .47032 Mtetra
.635 .683 .877 r
.3174 .47032 .3242 .47878 .33504 .47657 .32829 .46753 Mtetra
.629 .667 .867 r
.32829 .46753 .33504 .47657 .34591 .47467 .33922 .46491 Mtetra
.622 .649 .855 r
.33922 .46491 .34591 .47467 .35682 .47311 .35019 .46248 Mtetra
.615 .629 .841 r
.35019 .46248 .35682 .47311 .36778 .47194 .3612 .46028 Mtetra
.608 .607 .825 r
.3612 .46028 .36778 .47194 .37877 .47118 .37226 .45831 Mtetra
.6 .585 .807 r
.37226 .45831 .37877 .47118 .38981 .47087 .38336 .45659 Mtetra
.593 .562 .789 r
.38336 .45659 .38981 .47087 .40091 .47099 .39452 .45512 Mtetra
.587 .541 .77 r
.39452 .45512 .40091 .47099 .41206 .47154 .40572 .45389 Mtetra
.581 .52 .752 r
.40572 .45389 .41206 .47154 .42328 .47249 .41698 .45288 Mtetra
.577 .502 .734 r
.41698 .45288 .42328 .47249 .43456 .47379 .42831 .45205 Mtetra
.574 .486 .718 r
.42831 .45205 .43456 .47379 .44592 .47534 .4397 .45136 Mtetra
.572 .473 .704 r
.4397 .45136 .44592 .47534 .45737 .47705 .45115 .45074 Mtetra
.571 .462 .691 r
.45115 .45074 .45737 .47705 .4689 .47878 .46268 .45011 Mtetra
.571 .453 .68 r
.46268 .45011 .4689 .47878 .48052 .48038 .47428 .44939 Mtetra
.572 .446 .67 r
.47428 .44939 .48052 .48038 .49223 .48171 .48595 .4485 Mtetra
.574 .442 .662 r
.48595 .4485 .49223 .48171 .50403 .48259 .4977 .44732 Mtetra
.577 .438 .656 r
.4977 .44732 .50403 .48259 .51592 .48285 .50952 .44578 Mtetra
.58 .437 .651 r
.50952 .44578 .51592 .48285 .52789 .48236 .52141 .44379 Mtetra
.584 .436 .647 r
.52141 .44379 .52789 .48236 .53993 .48098 .53336 .44127 Mtetra
.588 .437 .644 r
.53336 .44127 .53993 .48098 .55203 .47862 .54537 .43817 Mtetra
.592 .438 .642 r
.54537 .43817 .55203 .47862 .56418 .47521 .55743 .43447 Mtetra
.596 .441 .641 r
.55743 .43447 .56418 .47521 .57638 .47073 .56954 .43015 Mtetra
.601 .445 .642 r
.56954 .43015 .57638 .47073 .5886 .46522 .58169 .42523 Mtetra
.606 .449 .643 r
.58169 .42523 .5886 .46522 .60084 .45872 .59387 .41974 Mtetra
.611 .455 .645 r
.59387 .41974 .60084 .45872 .6131 .45134 .60608 .41374 Mtetra
.616 .461 .648 r
.60608 .41374 .6131 .45134 .62536 .44321 .61832 .40731 Mtetra
.621 .468 .653 r
.61832 .40731 .62536 .44321 .63762 .43448 .63058 .40053 Mtetra
.627 .476 .658 r
.63058 .40053 .63762 .43448 .64988 .42533 .64287 .39352 Mtetra
.631 .485 .665 r
.64287 .39352 .64988 .42533 .66216 .41596 .65518 .3864 Mtetra
.635 .495 .673 r
.65518 .3864 .66216 .41596 .67444 .40665 .66754 .37938 Mtetra
.636 .503 .684 r
.66754 .37938 .67444 .40665 .68677 .3978 .67994 .37282 Mtetra
.63 .509 .697 r
.67994 .37282 .68677 .3978 .69918 .39014 .69245 .36739 Mtetra
.607 .507 .715 r
.69245 .36739 .69918 .39014 .71176 .38483 .70513 .36424 Mtetra
.546 .485 .738 r
.70513 .36424 .71176 .38483 .72463 .38363 .71812 .36513 Mtetra
.403 .415 .759 r
.71812 .36513 .72463 .38363 .738 .3886 .7316 .37216 Mtetra
.107 .248 .728 r
.7316 .37216 .738 .3886 .75206 .40142 .74578 .38704 Mtetra
0 0 .574 r
.74578 .38704 .75206 .40142 .76691 .42217 .76075 .40988 Mtetra
0 0 .403 r
.76075 .40988 .76691 .42217 .78242 .44807 .7764 .43782 Mtetra
0 0 .365 r
.7764 .43782 .78242 .44807 .79818 .473 .7923 .46462 Mtetra
0 .019 .567 r
.7923 .46462 .79818 .473 .81345 .48895 .80772 .48204 Mtetra
.417 .666 .963 r
.80772 .48204 .81345 .48895 .82753 .48919 .82192 .48315 Mtetra
.9 .852 .786 r
.82192 .48315 .82753 .48919 .84001 .47167 .8345 .46587 Mtetra
.967 .822 .647 r
.8345 .46587 .84001 .47167 .85105 .44013 .8456 .43406 Mtetra
.977 .804 .603 r
.8456 .43406 .85105 .44013 .86123 .40207 .85584 .39545 Mtetra
.974 .8 .607 r
.85584 .39545 .86123 .40207 .8713 .36511 .86595 .3579 Mtetra
.96 .806 .645 r
.86595 .3579 .8713 .36511 .88184 .33428 .87653 .3266 Mtetra
.658 .728 .901 r
.26721 .47578 .27424 .48274 .28497 .4795 .27798 .47236 Mtetra
.656 .724 .899 r
.27798 .47236 .28497 .4795 .29574 .47633 .28878 .46898 Mtetra
.654 .718 .895 r
.28878 .46898 .29574 .47633 .30655 .47326 .29963 .46564 Mtetra
.651 .71 .891 r
.29963 .46564 .30655 .47326 .3174 .47032 .31053 .46236 Mtetra
.648 .701 .885 r
.31053 .46236 .3174 .47032 .32829 .46753 .32146 .45915 Mtetra
.645 .69 .878 r
.32146 .45915 .32829 .46753 .33922 .46491 .33244 .45603 Mtetra
.641 .677 .869 r
.33244 .45603 .33922 .46491 .35019 .46248 .34346 .453 Mtetra
.636 .662 .858 r
.34346 .453 .35019 .46248 .3612 .46028 .35452 .45008 Mtetra
.631 .646 .846 r
.35452 .45008 .3612 .46028 .37226 .45831 .36563 .44727 Mtetra
.626 .628 .832 r
.36563 .44727 .37226 .45831 .38336 .45659 .37679 .44458 Mtetra
.621 .61 .818 r
.37679 .44458 .38336 .45659 .39452 .45512 .38799 .44202 Mtetra
.616 .591 .802 r
.38799 .44202 .39452 .45512 .40572 .45389 .39925 .43956 Mtetra
.612 .573 .786 r
.39925 .43956 .40572 .45389 .41698 .45288 .41055 .43722 Mtetra
.607 .555 .771 r
.41055 .43722 .41698 .45288 .42831 .45205 .42192 .43495 Mtetra
.604 .539 .755 r
.42192 .43495 .42831 .45205 .4397 .45136 .43333 .43274 Mtetra
.601 .525 .741 r
.43333 .43274 .4397 .45136 .45115 .45074 .44481 .43056 Mtetra
.598 .512 .728 r
.44481 .43056 .45115 .45074 .46268 .45011 .45635 .42836 Mtetra
.597 .502 .717 r
.45635 .42836 .46268 .45011 .47428 .44939 .46795 .42611 Mtetra
.596 .493 .707 r
.46795 .42611 .47428 .44939 .48595 .4485 .47961 .42374 Mtetra
.596 .486 .698 r
.47961 .42374 .48595 .4485 .4977 .44732 .49134 .42122 Mtetra
.597 .481 .691 r
.49134 .42122 .4977 .44732 .50952 .44578 .50312 .4185 Mtetra
.598 .477 .685 r
.50312 .4185 .50952 .44578 .52141 .44379 .51497 .41553 Mtetra
.6 .474 .681 r
.51497 .41553 .52141 .44379 .53336 .44127 .52687 .41228 Mtetra
.602 .474 .678 r
.52687 .41228 .53336 .44127 .54537 .43817 .53883 .40873 Mtetra
.605 .474 .676 r
.53883 .40873 .54537 .43817 .55743 .43447 .55085 .40486 Mtetra
.608 .475 .675 r
.55085 .40486 .55743 .43447 .56954 .43015 .56291 .40066 Mtetra
.611 .478 .675 r
.56291 .40066 .56954 .43015 .58169 .42523 .57502 .39615 Mtetra
.615 .482 .677 r
.57502 .39615 .58169 .42523 .59387 .41974 .58717 .39134 Mtetra
.619 .487 .68 r
.58717 .39134 .59387 .41974 .60608 .41374 .59936 .38626 Mtetra
.623 .493 .683 r
.59936 .38626 .60608 .41374 .61832 .40731 .61159 .38096 Mtetra
.627 .501 .689 r
.61159 .38096 .61832 .40731 .63058 .40053 .62387 .37547 Mtetra
.632 .509 .695 r
.62387 .37547 .63058 .40053 .64287 .39352 .63618 .36987 Mtetra
.636 .519 .703 r
.63618 .36987 .64287 .39352 .65518 .3864 .64853 .36423 Mtetra
.638 .528 .713 r
.64853 .36423 .65518 .3864 .66754 .37938 .66094 .35873 Mtetra
.637 .537 .725 r
.66094 .35873 .66754 .37938 .67994 .37282 .6734 .35367 Mtetra
.625 .542 .74 r
.6734 .35367 .67994 .37282 .69245 .36739 .68598 .34972 Mtetra
.591 .535 .761 r
.68598 .34972 .69245 .36739 .70513 .36424 .69874 .34801 Mtetra
.502 .5 .786 r
.69874 .34801 .70513 .36424 .71812 .36513 .71181 .35031 Mtetra
.295 .393 .793 r
.71181 .35031 .71812 .36513 .7316 .37216 .72537 .35875 Mtetra
0 .156 .693 r
.72537 .35875 .7316 .37216 .74578 .38704 .73963 .37509 Mtetra
0 0 .464 r
.73963 .37509 .74578 .38704 .76075 .40988 .7547 .39942 Mtetra
.665 .261 0 r
.7547 .39942 .76075 .40988 .7764 .43782 .77045 .42885 Mtetra
.688 .261 0 r
.77045 .42885 .7764 .43782 .7923 .46462 .78644 .45702 Mtetra
0 0 .491 r
.78644 .45702 .7923 .46462 .80772 .48204 .80196 .47549 Mtetra
.367 .652 .966 r
.80196 .47549 .80772 .48204 .82192 .48315 .81626 .47719 Mtetra
.901 .856 .788 r
.81626 .47719 .82192 .48315 .8345 .46587 .82893 .45997 Mtetra
.968 .822 .646 r
.82893 .45997 .8345 .46587 .8456 .43406 .8401 .42783 Mtetra
.977 .802 .601 r
.8401 .42783 .8456 .43406 .85584 .39545 .85039 .3887 Mtetra
.974 .799 .605 r
.85039 .3887 .85584 .39545 .86595 .3579 .86055 .35061 Mtetra
.961 .805 .643 r
.86055 .35061 .86595 .3579 .87653 .3266 .87117 .31886 Mtetra
.661 .734 .904 r
.26011 .46892 .26721 .47578 .27798 .47236 .27091 .46539 Mtetra
.66 .731 .902 r
.27091 .46539 .27798 .47236 .28878 .46898 .28175 .46187 Mtetra
.659 .727 .9 r
.28175 .46187 .28878 .46898 .29963 .46564 .29264 .45836 Mtetra
.658 .723 .897 r
.29264 .45836 .29963 .46564 .31053 .46236 .30357 .45486 Mtetra
.656 .717 .893 r
.30357 .45486 .31053 .46236 .32146 .45915 .31454 .4514 Mtetra
.654 .711 .889 r
.31454 .4514 .32146 .45915 .33244 .45603 .32556 .44796 Mtetra
.652 .702 .883 r
.32556 .44796 .33244 .45603 .34346 .453 .33662 .44456 Mtetra
.65 .693 .877 r
.33662 .44456 .34346 .453 .35452 .45008 .34773 .4412 Mtetra
.648 .682 .869 r
.34773 .4412 .35452 .45008 .36563 .44727 .35888 .43789 Mtetra
.645 .67 .86 r
.35888 .43789 .36563 .44727 .37679 .44458 .37008 .43462 Mtetra
.642 .657 .85 r
.37008 .43462 .37679 .44458 .38799 .44202 .38133 .4314 Mtetra
.639 .644 .839 r
.38133 .4314 .38799 .44202 .39925 .43956 .39263 .42822 Mtetra
.636 .63 .827 r
.39263 .42822 .39925 .43956 .41055 .43722 .40397 .42508 Mtetra
.633 .616 .815 r
.40397 .42508 .41055 .43722 .42192 .43495 .41537 .42197 Mtetra
.63 .602 .803 r
.41537 .42197 .42192 .43495 .43333 .43274 .42682 .41888 Mtetra
.627 .589 .791 r
.42682 .41888 .43333 .43274 .44481 .43056 .43833 .41578 Mtetra
.625 .577 .78 r
.43833 .41578 .44481 .43056 .45635 .42836 .44989 .41267 Mtetra
.623 .566 .769 r
.44989 .41267 .45635 .42836 .46795 .42611 .4615 .40952 Mtetra
.622 .556 .76 r
.4615 .40952 .46795 .42611 .47961 .42374 .47317 .40631 Mtetra
.621 .548 .752 r
.47317 .40631 .47961 .42374 .49134 .42122 .4849 .40301 Mtetra
.621 .542 .744 r
.4849 .40301 .49134 .42122 .50312 .4185 .49668 .39961 Mtetra
.621 .537 .738 r
.49668 .39961 .50312 .4185 .51497 .41553 .50852 .39609 Mtetra
.621 .533 .734 r
.50852 .39609 .51497 .41553 .52687 .41228 .52041 .39243 Mtetra
.622 .531 .73 r
.52041 .39243 .52687 .41228 .53883 .40873 .53236 .38863 Mtetra
.624 .531 .728 r
.53236 .38863 .53883 .40873 .55085 .40486 .54436 .38466 Mtetra
.626 .532 .728 r
.54436 .38466 .55085 .40486 .56291 .40066 .55641 .38054 Mtetra
.628 .534 .728 r
.55641 .38054 .56291 .40066 .57502 .39615 .56851 .37626 Mtetra
.631 .537 .73 r
.56851 .37626 .57502 .39615 .58717 .39134 .58065 .37184 Mtetra
.634 .542 .733 r
.58065 .37184 .58717 .39134 .59936 .38626 .59285 .36728 Mtetra
.637 .548 .738 r
.59285 .36728 .59936 .38626 .61159 .38096 .60509 .36262 Mtetra
.64 .555 .743 r
.60509 .36262 .61159 .38096 .62387 .37547 .61739 .35787 Mtetra
.643 .564 .75 r
.61739 .35787 .62387 .37547 .63618 .36987 .62973 .35306 Mtetra
.646 .573 .758 r
.62973 .35306 .63618 .36987 .64853 .36423 .64212 .34827 Mtetra
.646 .582 .768 r
.64212 .34827 .64853 .36423 .66094 .35873 .65456 .34362 Mtetra
.641 .589 .781 r
.65456 .34362 .66094 .35873 .6734 .35367 .66708 .33942 Mtetra
.622 .591 .797 r
.66708 .33942 .6734 .35367 .68598 .34972 .67971 .3363 Mtetra
.571 .577 .82 r
.67971 .3363 .68598 .34972 .69874 .34801 .69252 .33543 Mtetra
.444 .521 .843 r
.69252 .33543 .69874 .34801 .71181 .35031 .70565 .33856 Mtetra
.154 .36 .814 r
.70565 .33856 .71181 .35031 .72537 .35875 .71927 .34785 Mtetra
0 .056 .619 r
.71927 .34785 .72537 .35875 .73963 .37509 .73359 .3651 Mtetra
.614 .204 0 r
.73359 .3651 .73963 .37509 .7547 .39942 .74871 .39041 Mtetra
.736 .312 0 r
.74871 .39041 .7547 .39942 .77045 .42885 .76452 .42084 Mtetra
.737 .299 0 r
.76452 .42084 .77045 .42885 .78644 .45702 .78057 .44991 Mtetra
.554 .087 0 r
.78057 .44991 .78644 .45702 .80196 .47549 .79617 .46906 Mtetra
.338 .642 .965 r
.79617 .46906 .80196 .47549 .81626 .47719 .81054 .47109 Mtetra
.9 .854 .788 r
.81054 .47109 .81626 .47719 .82893 .45997 .82328 .45382 Mtetra
.966 .818 .645 r
.82328 .45382 .82893 .45997 .8401 .42783 .83452 .42133 Mtetra
.976 .799 .6 r
.83452 .42133 .8401 .42783 .85039 .3887 .84487 .38171 Mtetra
.973 .796 .604 r
.84487 .38171 .85039 .3887 .86055 .35061 .85508 .34315 Mtetra
.961 .803 .641 r
.85508 .34315 .86055 .35061 .87117 .31886 .86576 .31103 Mtetra
.662 .737 .906 r
.25295 .46212 .26011 .46892 .27091 .46539 .26378 .45852 Mtetra
.662 .736 .905 r
.26378 .45852 .27091 .46539 .28175 .46187 .27465 .45491 Mtetra
.662 .734 .904 r
.27465 .45491 .28175 .46187 .29264 .45836 .28557 .4513 Mtetra
.661 .732 .902 r
.28557 .4513 .29264 .45836 .30357 .45486 .29653 .44768 Mtetra
.66 .729 .9 r
.29653 .44768 .30357 .45486 .31454 .4514 .30754 .44407 Mtetra
.66 .725 .898 r
.30754 .44407 .31454 .4514 .32556 .44796 .31859 .44046 Mtetra
.659 .721 .895 r
.31859 .44046 .32556 .44796 .33662 .44456 .32969 .43686 Mtetra
.658 .716 .891 r
.32969 .43686 .33662 .44456 .34773 .4412 .34083 .43326 Mtetra
.657 .71 .887 r
.34083 .43326 .34773 .4412 .35888 .43789 .35202 .42968 Mtetra
.656 .703 .882 r
.35202 .42968 .35888 .43789 .37008 .43462 .36326 .4261 Mtetra
.654 .696 .877 r
.36326 .4261 .37008 .43462 .38133 .4314 .37455 .42253 Mtetra
.653 .688 .87 r
.37455 .42253 .38133 .4314 .39263 .42822 .38588 .41897 Mtetra
.651 .679 .863 r
.38588 .41897 .39263 .42822 .40397 .42508 .39727 .41542 Mtetra
.65 .67 .856 r
.39727 .41542 .40397 .42508 .41537 .42197 .4087 .41187 Mtetra
.648 .661 .848 r
.4087 .41187 .41537 .42197 .42682 .41888 .42018 .40831 Mtetra
.647 .652 .841 r
.42018 .40831 .42682 .41888 .43833 .41578 .43172 .40474 Mtetra
.646 .643 .833 r
.43172 .40474 .43833 .41578 .44989 .41267 .4433 .40116 Mtetra
.645 .635 .826 r
.4433 .40116 .44989 .41267 .4615 .40952 .45494 .39755 Mtetra
.644 .627 .819 r
.45494 .39755 .4615 .40952 .47317 .40631 .46663 .3939 Mtetra
.643 .62 .812 r
.46663 .3939 .47317 .40631 .4849 .40301 .47838 .39021 Mtetra
.643 .615 .807 r
.47838 .39021 .4849 .40301 .49668 .39961 .49018 .38646 Mtetra
.642 .61 .802 r
.49018 .38646 .49668 .39961 .50852 .39609 .50203 .38266 Mtetra
.643 .607 .798 r
.50203 .38266 .50852 .39609 .52041 .39243 .51393 .37878 Mtetra
.643 .604 .795 r
.51393 .37878 .52041 .39243 .53236 .38863 .52589 .37484 Mtetra
.644 .603 .794 r
.52589 .37484 .53236 .38863 .54436 .38466 .53789 .37082 Mtetra
.645 .604 .793 r
.53789 .37082 .54436 .38466 .55641 .38054 .54995 .36672 Mtetra
.646 .605 .794 r
.54995 .36672 .55641 .38054 .56851 .37626 .56207 .36255 Mtetra
.648 .608 .795 r
.56207 .36255 .56851 .37626 .58065 .37184 .57423 .35831 Mtetra
.65 .612 .798 r
.57423 .35831 .58065 .37184 .59285 .36728 .58645 .35401 Mtetra
.651 .617 .802 r
.58645 .35401 .59285 .36728 .60509 .36262 .59871 .34966 Mtetra
.653 .623 .807 r
.59871 .34966 .60509 .36262 .61739 .35787 .61103 .34526 Mtetra
.655 .63 .812 r
.61103 .34526 .61739 .35787 .62973 .35306 .6234 .34083 Mtetra
.656 .637 .819 r
.6234 .34083 .62973 .35306 .64212 .34827 .63583 .33644 Mtetra
.654 .643 .827 r
.63583 .33644 .64212 .34827 .65456 .34362 .64831 .3322 Mtetra
.644 .647 .838 r
.64831 .3322 .65456 .34362 .66708 .33942 .66087 .32841 Mtetra
.617 .643 .854 r
.66087 .32841 .66708 .33942 .67971 .3363 .67355 .32571 Mtetra
.548 .619 .875 r
.67355 .32571 .67971 .3363 .69252 .33543 .6864 .32524 Mtetra
.379 .537 .887 r
.6864 .32524 .69252 .33543 .70565 .33856 .69957 .3288 Mtetra
.02 .319 .806 r
.69957 .3288 .70565 .33856 .71927 .34785 .71324 .33856 Mtetra
0 0 .541 r
.71324 .33856 .71927 .34785 .73359 .3651 .72758 .35632 Mtetra
.682 .25 0 r
.72758 .35632 .73359 .3651 .74871 .39041 .74273 .3822 Mtetra
.769 .337 0 r
.74273 .3822 .74871 .39041 .76452 .42084 .75857 .41322 Mtetra
.757 .316 0 r
.75857 .41322 .76452 .42084 .78057 .44991 .77466 .44284 Mtetra
.57 .101 0 r
.77466 .44284 .78057 .44991 .79617 .46906 .7903 .46237 Mtetra
.338 .635 .962 r
.7903 .46237 .79617 .46906 .81054 .47109 .80473 .46454 Mtetra
.896 .844 .786 r
.80473 .46454 .81054 .47109 .82328 .45382 .81753 .44715 Mtetra
.963 .812 .645 r
.81753 .44715 .82328 .45382 .83452 .42133 .82885 .41436 Mtetra
.974 .795 .601 r
.82885 .41436 .83452 .42133 .84487 .38171 .83927 .37436 Mtetra
.972 .793 .604 r
.83927 .37436 .84487 .38171 .85508 .34315 .84955 .33544 Mtetra
.959 .8 .64 r
.84955 .33544 .85508 .34315 .86576 .31103 .86029 .30303 Mtetra
.663 .74 .907 r
.24573 .45535 .25295 .46212 .26378 .45852 .25659 .45169 Mtetra
.663 .739 .907 r
.25659 .45169 .26378 .45852 .27465 .45491 .26749 .44803 Mtetra
.663 .738 .906 r
.26749 .44803 .27465 .45491 .28557 .4513 .27844 .44436 Mtetra
.663 .737 .905 r
.27844 .44436 .28557 .4513 .29653 .44768 .28943 .44067 Mtetra
.662 .736 .905 r
.28943 .44067 .29653 .44768 .30754 .44407 .30046 .43698 Mtetra
.662 .734 .903 r
.30046 .43698 .30754 .44407 .31859 .44046 .31155 .43328 Mtetra
.662 .733 .902 r
.31155 .43328 .31859 .44046 .32969 .43686 .32268 .42957 Mtetra
.661 .73 .901 r
.32268 .42957 .32969 .43686 .34083 .43326 .33385 .42586 Mtetra
.661 .728 .899 r
.33385 .42586 .34083 .43326 .35202 .42968 .34508 .42214 Mtetra
.66 .725 .897 r
.34508 .42214 .35202 .42968 .36326 .4261 .35635 .41841 Mtetra
.66 .721 .894 r
.35635 .41841 .36326 .4261 .37455 .42253 .36767 .41467 Mtetra
.66 .717 .891 r
.36767 .41467 .37455 .42253 .38588 .41897 .37904 .41093 Mtetra
.659 .713 .888 r
.37904 .41093 .38588 .41897 .39727 .41542 .39045 .40718 Mtetra
.658 .709 .885 r
.39045 .40718 .39727 .41542 .4087 .41187 .40192 .40342 Mtetra
.658 .704 .881 r
.40192 .40342 .4087 .41187 .42018 .40831 .41343 .39965 Mtetra
.658 .699 .877 r
.41343 .39965 .42018 .40831 .43172 .40474 .425 .39587 Mtetra
.657 .694 .873 r
.425 .39587 .43172 .40474 .4433 .40116 .43662 .39206 Mtetra
.657 .69 .869 r
.43662 .39206 .4433 .40116 .45494 .39755 .44828 .38824 Mtetra
.656 .686 .866 r
.44828 .38824 .45494 .39755 .46663 .3939 .46 .38439 Mtetra
.656 .682 .862 r
.46 .38439 .46663 .3939 .47838 .39021 .47177 .38051 Mtetra
.656 .678 .859 r
.47177 .38051 .47838 .39021 .49018 .38646 .4836 .3766 Mtetra
.656 .675 .856 r
.4836 .3766 .49018 .38646 .50203 .38266 .49547 .37265 Mtetra
.656 .673 .854 r
.49547 .37265 .50203 .38266 .51393 .37878 .5074 .36867 Mtetra
.657 .672 .853 r
.5074 .36867 .51393 .37878 .52589 .37484 .51938 .36465 Mtetra
.657 .671 .852 r
.51938 .36465 .52589 .37484 .53789 .37082 .53141 .36059 Mtetra
.658 .671 .852 r
.53141 .36059 .53789 .37082 .54995 .36672 .5435 .35649 Mtetra
.658 .672 .852 r
.5435 .35649 .54995 .36672 .56207 .36255 .55563 .35235 Mtetra
.659 .674 .853 r
.55563 .35235 .56207 .36255 .57423 .35831 .56782 .34817 Mtetra
.66 .676 .855 r
.56782 .34817 .57423 .35831 .58645 .35401 .58007 .34396 Mtetra
.661 .679 .857 r
.58007 .34396 .58645 .35401 .59871 .34966 .59236 .33972 Mtetra
.661 .683 .86 r
.59236 .33972 .59871 .34966 .61103 .34526 .60472 .33545 Mtetra
.662 .686 .863 r
.60472 .33545 .61103 .34526 .6234 .34083 .61712 .33117 Mtetra
.661 .69 .867 r
.61712 .33117 .6234 .34083 .63583 .33644 .62958 .32693 Mtetra
.656 .693 .872 r
.62958 .32693 .63583 .33644 .64831 .3322 .64211 .32285 Mtetra
.644 .692 .88 r
.64211 .32285 .64831 .3322 .66087 .32841 .65471 .31922 Mtetra
.61 .683 .893 r
.65471 .31922 .66087 .32841 .67355 .32571 .66742 .31667 Mtetra
.527 .648 .911 r
.66742 .31667 .67355 .32571 .6864 .32524 .68031 .31637 Mtetra
.327 .545 .91 r
.68031 .31637 .6864 .32524 .69957 .3288 .69351 .32011 Mtetra
0 .287 .786 r
.69351 .32011 .69957 .3288 .71324 .33856 .7072 .33007 Mtetra
0 0 .492 r
.7072 .33007 .71324 .33856 .72758 .35632 .72157 .34807 Mtetra
.71 .27 0 r
.72157 .34807 .72758 .35632 .74273 .3822 .73673 .37422 Mtetra
.779 .346 0 r
.73673 .37422 .74273 .3822 .75857 .41322 .75257 .40553 Mtetra
.76 .319 0 r
.75257 .40553 .75857 .41322 .77466 .44284 .76867 .43539 Mtetra
.559 .096 0 r
.76867 .43539 .77466 .44284 .7903 .46237 .78433 .45509 Mtetra
.357 .628 .955 r
.78433 .45509 .7903 .46237 .80473 .46454 .79881 .45727 Mtetra
.889 .829 .781 r
.79881 .45727 .80473 .46454 .81753 .44715 .81168 .43976 Mtetra
.958 .803 .646 r
.81168 .43976 .81753 .44715 .82885 .41436 .82307 .40676 Mtetra
.97 .789 .602 r
.82307 .40676 .82885 .41436 .83927 .37436 .83358 .36652 Mtetra
.969 .788 .605 r
.83358 .36652 .83927 .37436 .84955 .33544 .84394 .32739 Mtetra
.957 .796 .641 r
.84394 .32739 .84955 .33544 .86029 .30303 .85476 .29481 Mtetra
.663 .741 .908 r
.23846 .44856 .24573 .45535 .25659 .45169 .24934 .44487 Mtetra
.24934 .44487 .25659 .45169 .26749 .44803 .26027 .44117 Mtetra
.663 .74 .908 r
.26027 .44117 .26749 .44803 .27844 .44436 .27124 .43746 Mtetra
.663 .74 .907 r
.27124 .43746 .27844 .44436 .28943 .44067 .28226 .43374 Mtetra
.28226 .43374 .28943 .44067 .30046 .43698 .29333 .43 Mtetra
.663 .739 .907 r
.29333 .43 .30046 .43698 .31155 .43328 .30444 .42626 Mtetra
.30444 .42626 .31155 .43328 .32268 .42957 .3156 .4225 Mtetra
.662 .738 .906 r
.3156 .4225 .32268 .42957 .33385 .42586 .3268 .41873 Mtetra
.662 .737 .906 r
.3268 .41873 .33385 .42586 .34508 .42214 .33806 .41495 Mtetra
.662 .737 .905 r
.33806 .41495 .34508 .42214 .35635 .41841 .34936 .41116 Mtetra
.662 .736 .905 r
.34936 .41116 .35635 .41841 .36767 .41467 .36071 .40735 Mtetra
.662 .734 .904 r
.36071 .40735 .36767 .41467 .37904 .41093 .37211 .40354 Mtetra
.661 .733 .903 r
.37211 .40354 .37904 .41093 .39045 .40718 .38356 .39971 Mtetra
.661 .732 .902 r
.38356 .39971 .39045 .40718 .40192 .40342 .39505 .39587 Mtetra
.661 .73 .901 r
.39505 .39587 .40192 .40342 .41343 .39965 .4066 .39201 Mtetra
.661 .729 .9 r
.4066 .39201 .41343 .39965 .425 .39587 .4182 .38814 Mtetra
.661 .727 .898 r
.4182 .38814 .425 .39587 .43662 .39206 .42984 .38425 Mtetra
.661 .726 .897 r
.42984 .38425 .43662 .39206 .44828 .38824 .44154 .38034 Mtetra
.661 .724 .896 r
.44154 .38034 .44828 .38824 .46 .38439 .45329 .3764 Mtetra
.661 .723 .895 r
.45329 .3764 .46 .38439 .47177 .38051 .4651 .37245 Mtetra
.662 .722 .893 r
.4651 .37245 .47177 .38051 .4836 .3766 .47695 .36846 Mtetra
.662 .721 .893 r
.47695 .36846 .4836 .3766 .49547 .37265 .48885 .36445 Mtetra
.662 .72 .892 r
.48885 .36445 .49547 .37265 .5074 .36867 .50081 .36041 Mtetra
.662 .719 .891 r
.50081 .36041 .5074 .36867 .51938 .36465 .51282 .35634 Mtetra
.663 .719 .891 r
.51282 .35634 .51938 .36465 .53141 .36059 .52489 .35225 Mtetra
.663 .719 .89 r
.52489 .35225 .53141 .36059 .5435 .35649 .537 .34812 Mtetra
.663 .719 .891 r
.537 .34812 .5435 .35649 .55563 .35235 .54917 .34397 Mtetra
.664 .72 .891 r
.54917 .34397 .55563 .35235 .56782 .34817 .5614 .33978 Mtetra
.664 .721 .891 r
.5614 .33978 .56782 .34817 .58007 .34396 .57367 .33557 Mtetra
.664 .722 .892 r
.57367 .33557 .58007 .34396 .59236 .33972 .58601 .33134 Mtetra
.664 .723 .893 r
.58601 .33134 .59236 .33972 .60472 .33545 .59839 .32708 Mtetra
.664 .724 .894 r
.59839 .32708 .60472 .33545 .61712 .33117 .61083 .32283 Mtetra
.662 .725 .896 r
.61083 .32283 .61712 .33117 .62958 .32693 .62333 .31861 Mtetra
.657 .725 .899 r
.62333 .31861 .62958 .32693 .64211 .32285 .63589 .31455 Mtetra
.642 .721 .905 r
.63589 .31455 .64211 .32285 .65471 .31922 .64853 .31094 Mtetra
.605 .707 .916 r
.64853 .31094 .65471 .31922 .66742 .31667 .66128 .30841 Mtetra
.513 .666 .931 r
.66128 .30841 .66742 .31667 .68031 .31637 .67421 .30814 Mtetra
.297 .549 .92 r
.67421 .30814 .68031 .31637 .69351 .32011 .68744 .3119 Mtetra
0 .271 .773 r
.68744 .3119 .69351 .32011 .7072 .33007 .70114 .32189 Mtetra
0 0 .472 r
.70114 .32189 .7072 .33007 .72157 .34807 .71551 .33994 Mtetra
.717 .274 0 r
.71551 .33994 .72157 .34807 .73673 .37422 .73067 .36613 Mtetra
.778 .345 0 r
.73067 .36613 .73673 .37422 .75257 .40553 .74649 .39747 Mtetra
.751 .313 0 r
.74649 .39747 .75257 .40553 .76867 .43539 .76259 .42734 Mtetra
0 0 .463 r
.76259 .42734 .76867 .43539 .78433 .45509 .77826 .44701 Mtetra
.384 .62 .945 r
.77826 .44701 .78433 .45509 .79881 .45727 .79277 .44913 Mtetra
.88 .811 .776 r
.79277 .44913 .79881 .45727 .81168 .43976 .8057 .43153 Mtetra
.952 .794 .648 r
.8057 .43153 .81168 .43976 .82307 .40676 .81718 .39844 Mtetra
.966 .783 .605 r
.81718 .39844 .82307 .40676 .83358 .36652 .82779 .35813 Mtetra
.966 .783 .607 r
.82779 .35813 .83358 .36652 .84394 .32739 .83825 .31894 Mtetra
.955 .792 .642 r
.83825 .31894 .84394 .32739 .85476 .29481 .84916 .28633 Mtetra
.663 .742 .909 r
.23112 .44175 .23846 .44856 .24934 .44487 .24203 .43804 Mtetra
.24203 .43804 .24934 .44487 .26027 .44117 .25298 .43432 Mtetra
.25298 .43432 .26027 .44117 .27124 .43746 .26398 .43059 Mtetra
.26398 .43059 .27124 .43746 .28226 .43374 .27503 .42685 Mtetra
.662 .743 .91 r
.27503 .42685 .28226 .43374 .29333 .43 .28612 .4231 Mtetra
.28612 .4231 .29333 .43 .30444 .42626 .29726 .41934 Mtetra
.662 .744 .911 r
.29726 .41934 .30444 .42626 .3156 .4225 .30845 .41558 Mtetra
.30845 .41558 .3156 .4225 .3268 .41873 .31968 .4118 Mtetra
.661 .745 .912 r
.31968 .4118 .3268 .41873 .33806 .41495 .33096 .40801 Mtetra
.33096 .40801 .33806 .41495 .34936 .41116 .34229 .40422 Mtetra
.661 .746 .913 r
.34229 .40422 .34936 .41116 .36071 .40735 .35367 .40042 Mtetra
.661 .747 .914 r
.35367 .40042 .36071 .40735 .37211 .40354 .3651 .3966 Mtetra
.661 .748 .915 r
.3651 .3966 .37211 .40354 .38356 .39971 .37658 .39278 Mtetra
.66 .749 .916 r
.37658 .39278 .38356 .39971 .39505 .39587 .3881 .38894 Mtetra
.66 .75 .916 r
.3881 .38894 .39505 .39587 .4066 .39201 .39968 .38509 Mtetra
.66 .751 .917 r
.39968 .38509 .4066 .39201 .4182 .38814 .41131 .38122 Mtetra
.66 .752 .918 r
.41131 .38122 .4182 .38814 .42984 .38425 .42299 .37733 Mtetra
.661 .753 .919 r
.42299 .37733 .42984 .38425 .44154 .38034 .43472 .37341 Mtetra
.661 .754 .919 r
.43472 .37341 .44154 .38034 .45329 .3764 .4465 .36947 Mtetra
.661 .755 .919 r
.4465 .36947 .45329 .3764 .4651 .37245 .45834 .36551 Mtetra
.662 .756 .92 r
.45834 .36551 .4651 .37245 .47695 .36846 .47023 .36151 Mtetra
.47023 .36151 .47695 .36846 .48885 .36445 .48217 .35748 Mtetra
.663 .757 .92 r
.48217 .35748 .48885 .36445 .50081 .36041 .49416 .35341 Mtetra
.49416 .35341 .50081 .36041 .51282 .35634 .50621 .34931 Mtetra
.664 .757 .92 r
.50621 .34931 .51282 .35634 .52489 .35225 .51831 .34517 Mtetra
.664 .757 .919 r
.51831 .34517 .52489 .35225 .537 .34812 .53046 .341 Mtetra
.665 .757 .919 r
.53046 .341 .537 .34812 .54917 .34397 .54267 .33679 Mtetra
.666 .757 .918 r
.54267 .33679 .54917 .34397 .5614 .33978 .55493 .33255 Mtetra
.666 .756 .918 r
.55493 .33255 .5614 .33978 .57367 .33557 .56725 .32828 Mtetra
.666 .755 .917 r
.56725 .32828 .57367 .33557 .58601 .33134 .57962 .32398 Mtetra
.666 .755 .916 r
.57962 .32398 .58601 .33134 .59839 .32708 .59204 .31966 Mtetra
.666 .753 .916 r
.59204 .31966 .59839 .32708 .61083 .32283 .60452 .31533 Mtetra
.664 .752 .916 r
.60452 .31533 .61083 .32283 .62333 .31861 .61706 .31105 Mtetra
.658 .749 .917 r
.61706 .31105 .62333 .31861 .63589 .31455 .62965 .30691 Mtetra
.643 .742 .921 r
.62965 .30691 .63589 .31455 .64853 .31094 .64233 .30324 Mtetra
.603 .725 .931 r
.64233 .30324 .64853 .31094 .66128 .30841 .65511 .30064 Mtetra
.507 .68 .944 r
.65511 .30064 .66128 .30841 .67421 .30814 .66807 .30029 Mtetra
.282 .554 .927 r
.66807 .30029 .67421 .30814 .68744 .3119 .68132 .30397 Mtetra
0 .267 .768 r
.68132 .30397 .68744 .3119 .70114 .32189 .69504 .31386 Mtetra
0 0 .466 r
.69504 .31386 .70114 .32189 .71551 .33994 .70941 .33177 Mtetra
.715 .272 0 r
.70941 .33177 .71551 .33994 .73067 .36613 .72454 .35779 Mtetra
.771 .339 0 r
.72454 .35779 .73067 .36613 .74649 .39747 .74034 .38893 Mtetra
.737 .302 0 r
.74034 .38893 .74649 .39747 .76259 .42734 .75641 .41859 Mtetra
0 0 .498 r
.75641 .41859 .76259 .42734 .77826 .44701 .77206 .43806 Mtetra
.411 .611 .931 r
.77206 .43806 .77826 .44701 .79277 .44913 .7866 .44005 Mtetra
.871 .792 .771 r
.7866 .44005 .79277 .44913 .8057 .43153 .7996 .42242 Mtetra
.945 .784 .65 r
.7996 .42242 .8057 .43153 .81718 .39844 .81118 .38938 Mtetra
.961 .776 .608 r
.81118 .38938 .81718 .39844 .82779 .35813 .8219 .34917 Mtetra
.962 .779 .609 r
.8219 .34917 .82779 .35813 .83825 .31894 .83248 .3101 Mtetra
.951 .788 .644 r
.83248 .3101 .83825 .31894 .84916 .28633 .84349 .27758 Mtetra
.662 .743 .91 r
.22372 .43494 .23112 .44175 .24203 .43804 .23465 .43122 Mtetra
.662 .744 .911 r
.23465 .43122 .24203 .43804 .25298 .43432 .24563 .42751 Mtetra
.662 .744 .912 r
.24563 .42751 .25298 .43432 .26398 .43059 .25666 .42378 Mtetra
.661 .745 .913 r
.25666 .42378 .26398 .43059 .27503 .42685 .26773 .42006 Mtetra
.661 .747 .914 r
.26773 .42006 .27503 .42685 .28612 .4231 .27884 .41633 Mtetra
.66 .748 .915 r
.27884 .41633 .28612 .4231 .29726 .41934 .29001 .41261 Mtetra
.659 .75 .917 r
.29001 .41261 .29726 .41934 .30845 .41558 .30122 .40889 Mtetra
.658 .752 .919 r
.30122 .40889 .30845 .41558 .31968 .4118 .31248 .40517 Mtetra
.658 .754 .921 r
.31248 .40517 .31968 .4118 .33096 .40801 .32378 .40146 Mtetra
.657 .757 .924 r
.32378 .40146 .33096 .40801 .34229 .40422 .33514 .39775 Mtetra
.656 .761 .927 r
.33514 .39775 .34229 .40422 .35367 .40042 .34654 .39404 Mtetra
.655 .764 .93 r
.34654 .39404 .35367 .40042 .3651 .3966 .358 .39033 Mtetra
.654 .768 .933 r
.358 .39033 .3651 .3966 .37658 .39278 .3695 .38662 Mtetra
.654 .773 .936 r
.3695 .38662 .37658 .39278 .3881 .38894 .38106 .3829 Mtetra
.653 .777 .94 r
.38106 .3829 .3881 .38894 .39968 .38509 .39266 .37917 Mtetra
.652 .782 .943 r
.39266 .37917 .39968 .38509 .41131 .38122 .40432 .37542 Mtetra
.652 .787 .946 r
.40432 .37542 .41131 .38122 .42299 .37733 .41603 .37165 Mtetra
.652 .792 .949 r
.41603 .37165 .42299 .37733 .43472 .37341 .4278 .36784 Mtetra
.652 .797 .952 r
.4278 .36784 .43472 .37341 .4465 .36947 .43962 .364 Mtetra
.652 .801 .954 r
.43962 .364 .4465 .36947 .45834 .36551 .45149 .36011 Mtetra
.653 .805 .956 r
.45149 .36011 .45834 .36551 .47023 .36151 .46342 .35617 Mtetra
.654 .808 .958 r
.46342 .35617 .47023 .36151 .48217 .35748 .4754 .35217 Mtetra
.655 .811 .958 r
.4754 .35217 .48217 .35748 .49416 .35341 .48744 .34812 Mtetra
.656 .813 .959 r
.48744 .34812 .49416 .35341 .50621 .34931 .49953 .344 Mtetra
.658 .814 .958 r
.49953 .344 .50621 .34931 .51831 .34517 .51167 .33982 Mtetra
.66 .814 .957 r
.51167 .33982 .51831 .34517 .53046 .341 .52387 .33557 Mtetra
.662 .813 .956 r
.52387 .33557 .53046 .341 .54267 .33679 .53612 .33126 Mtetra
.664 .811 .954 r
.53612 .33126 .54267 .33679 .55493 .33255 .54842 .3269 Mtetra
.666 .809 .952 r
.54842 .3269 .55493 .33255 .56725 .32828 .56078 .32249 Mtetra
.667 .805 .949 r
.56078 .32249 .56725 .32828 .57962 .32398 .57319 .31802 Mtetra
.668 .801 .946 r
.57319 .31802 .57962 .32398 .59204 .31966 .58566 .31353 Mtetra
.669 .797 .943 r
.58566 .31353 .59204 .31966 .60452 .31533 .59818 .30902 Mtetra
.667 .792 .941 r
.59818 .30902 .60452 .31533 .61706 .31105 .61076 .30454 Mtetra
.662 .785 .94 r
.61076 .30454 .61706 .31105 .62965 .30691 .6234 .30022 Mtetra
.645 .774 .942 r
.6234 .30022 .62965 .30691 .64233 .30324 .63611 .29635 Mtetra
.603 .753 .949 r
.63611 .29635 .64233 .30324 .65511 .30064 .64892 .29356 Mtetra
.501 .702 .96 r
.64892 .29356 .65511 .30064 .66807 .30029 .66191 .293 Mtetra
.265 .565 .936 r
.66191 .293 .66807 .30029 .68132 .30397 .67518 .29646 Mtetra
0 .266 .763 r
.67518 .29646 .68132 .30397 .69504 .31386 .68891 .30609 Mtetra
0 0 .461 r
.68891 .30609 .69504 .31386 .70941 .33177 .70326 .32368 Mtetra
.713 .267 0 r
.70326 .32368 .70941 .33177 .72454 .35779 .71836 .34931 Mtetra
.764 .332 0 r
.71836 .34931 .72454 .35779 .74034 .38893 .73411 .38 Mtetra
.72 .289 0 r
.73411 .38 .74034 .38893 .75641 .41859 .75013 .40921 Mtetra
0 0 .532 r
.75013 .40921 .75641 .41859 .77206 .43806 .76577 .42831 Mtetra
.435 .604 .918 r
.76577 .42831 .77206 .43806 .7866 .44005 .78032 .4301 Mtetra
.861 .776 .766 r
.78032 .4301 .7866 .44005 .7996 .42242 .79339 .41247 Mtetra
.938 .774 .652 r
.79339 .41247 .7996 .42242 .81118 .38938 .80507 .3796 Mtetra
.956 .77 .611 r
.80507 .3796 .81118 .38938 .8219 .34917 .81592 .33966 Mtetra
.958 .774 .613 r
.81592 .33966 .8219 .34917 .83248 .3101 .82663 .30087 Mtetra
.948 .785 .646 r
.82663 .30087 .83248 .3101 .84349 .27758 .83775 .26857 Mtetra
.66 .745 .913 r
.21625 .42816 .22372 .43494 .23465 .43122 .22721 .42447 Mtetra
.66 .747 .915 r
.22721 .42447 .23465 .43122 .24563 .42751 .23821 .4208 Mtetra
.658 .749 .917 r
.23821 .4208 .24563 .42751 .25666 .42378 .24926 .41713 Mtetra
.657 .751 .919 r
.24926 .41713 .25666 .42378 .26773 .42006 .26035 .41348 Mtetra
.656 .754 .922 r
.26035 .41348 .26773 .42006 .27884 .41633 .27148 .40986 Mtetra
.654 .757 .925 r
.27148 .40986 .27884 .41633 .29001 .41261 .28267 .40626 Mtetra
.652 .761 .93 r
.28267 .40626 .29001 .41261 .30122 .40889 .29389 .40269 Mtetra
.65 .766 .934 r
.29389 .40269 .30122 .40889 .31248 .40517 .30517 .39915 Mtetra
.647 .772 .94 r
.30517 .39915 .31248 .40517 .32378 .40146 .31649 .39565 Mtetra
.644 .779 .946 r
.31649 .39565 .32378 .40146 .33514 .39775 .32787 .39218 Mtetra
.64 .788 .953 r
.32787 .39218 .33514 .39775 .34654 .39404 .33929 .38874 Mtetra
.636 .797 .96 r
.33929 .38874 .34654 .39404 .358 .39033 .35076 .38532 Mtetra
.631 .806 .967 r
.35076 .38532 .358 .39033 .3695 .38662 .36229 .38193 Mtetra
.625 .817 .974 r
.36229 .38193 .3695 .38662 .38106 .3829 .37386 .37855 Mtetra
.619 .828 .981 r
.37386 .37855 .38106 .3829 .39266 .37917 .3855 .37516 Mtetra
.612 .839 .986 r
.3855 .37516 .39266 .37917 .40432 .37542 .39718 .37176 Mtetra
.605 .85 .99 r
.39718 .37176 .40432 .37542 .41603 .37165 .40893 .36832 Mtetra
.597 .861 .993 r
.40893 .36832 .41603 .37165 .4278 .36784 .42073 .36484 Mtetra
.59 .87 .994 r
.42073 .36484 .4278 .36784 .43962 .364 .43259 .36128 Mtetra
.583 .878 .993 r
.43259 .36128 .43962 .364 .45149 .36011 .4445 .35765 Mtetra
.578 .885 .991 r
.4445 .35765 .45149 .36011 .46342 .35617 .45648 .35391 Mtetra
.575 .891 .989 r
.45648 .35391 .46342 .35617 .4754 .35217 .46851 .35007 Mtetra
.575 .896 .986 r
.46851 .35007 .4754 .35217 .48744 .34812 .4806 .3461 Mtetra
.577 .9 .984 r
.4806 .3461 .48744 .34812 .49953 .344 .49274 .342 Mtetra
.583 .903 .983 r
.49274 .342 .49953 .344 .51167 .33982 .50494 .33776 Mtetra
.592 .905 .983 r
.50494 .33776 .51167 .33982 .52387 .33557 .5172 .3334 Mtetra
.602 .907 .983 r
.5172 .3334 .52387 .33557 .53612 .33126 .52951 .32891 Mtetra
.614 .906 .984 r
.52951 .32891 .53612 .33126 .54842 .3269 .54187 .3243 Mtetra
.627 .904 .985 r
.54187 .3243 .54842 .3269 .56078 .32249 .55428 .31959 Mtetra
.638 .899 .985 r
.55428 .31959 .56078 .32249 .57319 .31802 .56675 .31479 Mtetra
.649 .892 .983 r
.56675 .31479 .57319 .31802 .58566 .31353 .57927 .30992 Mtetra
.657 .883 .981 r
.57927 .30992 .58566 .31353 .59818 .30902 .59183 .30502 Mtetra
.662 .872 .978 r
.59183 .30502 .59818 .30902 .61076 .30454 .60446 .30012 Mtetra
.66 .858 .975 r
.60446 .30012 .61076 .30454 .6234 .30022 .61713 .29538 Mtetra
.644 .84 .975 r
.61713 .29538 .6234 .30022 .63611 .29635 .62989 .2911 Mtetra
.599 .81 .981 r
.62989 .2911 .63611 .29635 .64892 .29356 .64274 .28789 Mtetra
.485 .747 .987 r
.64274 .28789 .64892 .29356 .66191 .293 .65575 .28692 Mtetra
.229 .588 .946 r
.65575 .28692 .66191 .293 .67518 .29646 .66904 .28993 Mtetra
0 .261 .745 r
.66904 .28993 .67518 .29646 .68891 .30609 .68276 .29906 Mtetra
.556 .079 0 r
.68276 .29906 .68891 .30609 .70326 .32368 .69709 .31607 Mtetra
.719 .265 0 r
.69709 .31607 .70326 .32368 .71836 .34931 .71214 .34103 Mtetra
.762 .325 0 r
.71214 .34103 .71836 .34931 .73411 .38 .72783 .37098 Mtetra
.708 .276 0 r
.72783 .37098 .73411 .38 .75013 .40921 .74379 .39946 Mtetra
0 .003 .561 r
.74379 .39946 .75013 .40921 .76577 .42831 .75938 .41798 Mtetra
.455 .603 .908 r
.75938 .41798 .76577 .42831 .78032 .4301 .77394 .41945 Mtetra
.854 .764 .762 r
.77394 .41945 .78032 .4301 .79339 .41247 .78707 .40182 Mtetra
.932 .767 .654 r
.78707 .40182 .79339 .41247 .80507 .3796 .79887 .36922 Mtetra
.952 .765 .615 r
.79887 .36922 .80507 .3796 .81592 .33966 .80986 .32969 Mtetra
.954 .771 .616 r
.80986 .32969 .81592 .33966 .82663 .30087 .82071 .29131 Mtetra
.945 .782 .649 r
.82071 .29131 .82663 .30087 .83775 .26857 .83195 .25935 Mtetra
.657 .749 .918 r
.20871 .42149 .21625 .42816 .22721 .42447 .21969 .41788 Mtetra
.655 .752 .921 r
.21969 .41788 .22721 .42447 .23821 .4208 .2307 .4143 Mtetra
.652 .755 .925 r
.2307 .4143 .23821 .4208 .24926 .41713 .24176 .41078 Mtetra
.649 .76 .93 r
.24176 .41078 .24926 .41713 .26035 .41348 .25287 .40731 Mtetra
.645 .765 .936 r
.25287 .40731 .26035 .41348 .27148 .40986 .26401 .4039 Mtetra
.64 .772 .943 r
.26401 .4039 .27148 .40986 .28267 .40626 .27521 .40058 Mtetra
.634 .78 .951 r
.27521 .40058 .28267 .40626 .29389 .40269 .28644 .39734 Mtetra
.626 .79 .961 r
.28644 .39734 .29389 .40269 .30517 .39915 .29772 .39419 Mtetra
.616 .802 .971 r
.29772 .39419 .30517 .39915 .31649 .39565 .30905 .39114 Mtetra
.602 .815 .982 r
.30905 .39114 .31649 .39565 .32787 .39218 .32042 .38818 Mtetra
.585 .829 .991 r
.32042 .38818 .32787 .39218 .33929 .38874 .33185 .38532 Mtetra
.561 .842 .997 r
.33185 .38532 .33929 .38874 .35076 .38532 .34333 .38254 Mtetra
.53 .853 .997 r
.34333 .38254 .35076 .38532 .36229 .38193 .35486 .37983 Mtetra
.49 .858 .987 r
.35486 .37983 .36229 .38193 .37386 .37855 .36645 .37716 Mtetra
.44 .853 .962 r
.36645 .37716 .37386 .37855 .3855 .37516 .3781 .37452 Mtetra
.38 .835 .92 r
.3781 .37452 .3855 .37516 .39718 .37176 .38981 .37186 Mtetra
.315 .804 .861 r
.38981 .37186 .39718 .37176 .40893 .36832 .40158 .36917 Mtetra
.25 .763 .79 r
.40158 .36917 .40893 .36832 .42073 .36484 .41342 .36639 Mtetra
.191 .717 .715 r
.41342 .36639 .42073 .36484 .43259 .36128 .42532 .36349 Mtetra
0 0 0 r
.42532 .36349 .43259 .36128 .4445 .35765 .43729 .36043 Mtetra
.43729 .36043 .4445 .35765 .45648 .35391 .44932 .35717 Mtetra
.44932 .35717 .45648 .35391 .46851 .35007 .46142 .35369 Mtetra
.46142 .35369 .46851 .35007 .4806 .3461 .47358 .34996 Mtetra
.47358 .34996 .4806 .3461 .49274 .342 .48581 .34596 Mtetra
.48581 .34596 .49274 .342 .50494 .33776 .49809 .34169 Mtetra
.49809 .34169 .50494 .33776 .5172 .3334 .51043 .33715 Mtetra
.51043 .33715 .5172 .3334 .52951 .32891 .52282 .33235 Mtetra
.52282 .33235 .52951 .32891 .54187 .3243 .53526 .3273 Mtetra
.53526 .3273 .54187 .3243 .55428 .31959 .54775 .32203 Mtetra
.321 .792 .693 r
.54775 .32203 .55428 .31959 .56675 .31479 .56029 .31658 Mtetra
.392 .844 .761 r
.56029 .31658 .56675 .31479 .57927 .30992 .57287 .31099 Mtetra
.461 .887 .826 r
.57287 .31099 .57927 .30992 .59183 .30502 .5855 .3053 Mtetra
.521 .918 .882 r
.5855 .3053 .59183 .30502 .60446 .30012 .59818 .2996 Mtetra
.563 .931 .925 r
.59818 .2996 .60446 .30012 .61713 .29538 .61091 .29404 Mtetra
.577 .924 .957 r
.61091 .29404 .61713 .29538 .62989 .2911 .6237 .28893 Mtetra
.543 .892 .98 r
.6237 .28893 .62989 .2911 .64274 .28789 .63658 .28492 Mtetra
.419 .811 .987 r
.63658 .28492 .64274 .28789 .65575 .28692 .64962 .28314 Mtetra
.131 .607 .919 r
.64962 .28314 .65575 .28692 .66904 .28993 .66292 .28533 Mtetra
0 .239 .676 r
.66292 .28533 .66904 .28993 .68276 .29906 .67664 .29359 Mtetra
.605 .095 0 r
.67664 .29359 .68276 .29906 .69709 .31607 .69093 .30964 Mtetra
.739 .269 0 r
.69093 .30964 .69709 .31607 .71214 .34103 .70592 .33354 Mtetra
.769 .323 0 r
.70592 .33354 .71214 .34103 .72783 .37098 .72153 .36237 Mtetra
.707 .267 0 r
.72153 .36237 .72783 .37098 .74379 .39946 .7374 .38976 Mtetra
0 .028 .582 r
.7374 .38976 .74379 .39946 .75938 .41798 .75294 .40741 Mtetra
.476 .61 .905 r
.75294 .40741 .75938 .41798 .77394 .41945 .76749 .40839 Mtetra
.851 .758 .76 r
.76749 .40839 .77394 .41945 .78707 .40182 .78068 .39071 Mtetra
.928 .763 .656 r
.78068 .39071 .78707 .40182 .79887 .36922 .79259 .35841 Mtetra
.948 .762 .618 r
.79259 .35841 .79887 .36922 .80986 .32969 .80372 .31938 Mtetra
.951 .768 .62 r
.80372 .31938 .80986 .32969 .82071 .29131 .81472 .28152 Mtetra
.942 .781 .652 r
.81472 .28152 .82071 .29131 .83195 .25935 .8261 .24998 Mtetra
.65 .754 .925 r
.20109 .41497 .20871 .42149 .21969 .41788 .21208 .4115 Mtetra
.645 .758 .931 r
.21208 .4115 .21969 .41788 .2307 .4143 .2231 .40812 Mtetra
.64 .764 .938 r
.2231 .40812 .2307 .4143 .24176 .41078 .23417 .40485 Mtetra
.632 .771 .946 r
.23417 .40485 .24176 .41078 .25287 .40731 .24527 .4017 Mtetra
.622 .78 .957 r
.24527 .4017 .25287 .40731 .26401 .4039 .25641 .3987 Mtetra
.609 .791 .968 r
.25641 .3987 .26401 .4039 .27521 .40058 .2676 .39587 Mtetra
.59 .803 .981 r
.2676 .39587 .27521 .40058 .28644 .39734 .27882 .39321 Mtetra
.564 .817 .993 r
.27882 .39321 .28644 .39734 .29772 .39419 .29009 .39076 Mtetra
.525 .828 1 r
.29009 .39076 .29772 .39419 .30905 .39114 .3014 .38851 Mtetra
.468 .832 .994 r
.3014 .38851 .30905 .39114 .32042 .38818 .31275 .38647 Mtetra
.387 .818 .962 r
.31275 .38647 .32042 .38818 .33185 .38532 .32416 .38463 Mtetra
.277 .773 .889 r
.32416 .38463 .33185 .38532 .34333 .38254 .33562 .38298 Mtetra
.146 .69 .767 r
.33562 .38298 .34333 .38254 .35486 .37983 .34714 .38149 Mtetra
0 0 0 r
.34714 .38149 .35486 .37983 .36645 .37716 .35872 .38012 Mtetra
.103 0 0 r
.35872 .38012 .36645 .37716 .3781 .37452 .37037 .37882 Mtetra
.191 0 0 r
.37037 .37882 .3781 .37452 .38981 .37186 .38209 .37753 Mtetra
.253 0 0 r
.38209 .37753 .38981 .37186 .40158 .36917 .39388 .37619 Mtetra
.295 0 0 r
.39388 .37619 .40158 .36917 .41342 .36639 .40575 .37471 Mtetra
.321 0 0 r
.40575 .37471 .41342 .36639 .42532 .36349 .4177 .37303 Mtetra
.336 0 .024 r
.4177 .37303 .42532 .36349 .43729 .36043 .42974 .37106 Mtetra
.343 0 .06 r
.42974 .37106 .43729 .36043 .44932 .35717 .44185 .36874 Mtetra
.343 0 .084 r
.44185 .36874 .44932 .35717 .46142 .35369 .45403 .36599 Mtetra
.338 0 .099 r
.45403 .36599 .46142 .35369 .47358 .34996 .4663 .36277 Mtetra
.328 0 .106 r
.4663 .36277 .47358 .34996 .48581 .34596 .47863 .35904 Mtetra
.313 0 .105 r
.47863 .35904 .48581 .34596 .49809 .34169 .49103 .35479 Mtetra
.294 0 .096 r
.49103 .35479 .49809 .34169 .51043 .33715 .50348 .35 Mtetra
.27 0 .079 r
.50348 .35 .51043 .33715 .52282 .33235 .51599 .3447 Mtetra
.24 0 .053 r
.51599 .3447 .52282 .33235 .53526 .3273 .52855 .33893 Mtetra
.202 0 .017 r
.52855 .33893 .53526 .3273 .54775 .32203 .54116 .33273 Mtetra
.156 0 0 r
.54116 .33273 .54775 .32203 .56029 .31658 .5538 .32617 Mtetra
.099 0 0 r
.5538 .32617 .56029 .31658 .57287 .31099 .56648 .31933 Mtetra
.028 0 0 r
.56648 .31933 .57287 .31099 .5855 .3053 .5792 .3123 Mtetra
0 0 0 r
.5792 .3123 .5855 .3053 .59818 .2996 .59195 .30519 Mtetra
.59195 .30519 .59818 .2996 .61091 .29404 .60474 .29819 Mtetra
.60474 .29819 .61091 .29404 .6237 .28893 .61758 .29164 Mtetra
.61758 .29164 .6237 .28893 .63658 .28492 .63051 .28621 Mtetra
.184 .711 .708 r
.63051 .28621 .63658 .28492 .64962 .28314 .64357 .28304 Mtetra
.067 0 0 r
.64357 .28304 .64962 .28314 .66292 .28533 .65687 .28385 Mtetra
.419 0 0 r
.65687 .28385 .66292 .28533 .67664 .29359 .67057 .29071 Mtetra
.662 .12 0 r
.67057 .29071 .67664 .29359 .69093 .30964 .68482 .30528 Mtetra
.766 .276 0 r
.68482 .30528 .69093 .30964 .70592 .33354 .69973 .32761 Mtetra
.786 .323 0 r
.69973 .32761 .70592 .33354 .72153 .36237 .71524 .35482 Mtetra
.717 .261 0 r
.71524 .35482 .72153 .36237 .7374 .38976 .73101 .38069 Mtetra
0 .052 .597 r
.73101 .38069 .7374 .38976 .75294 .40741 .74647 .3971 Mtetra
.499 .631 .911 r
.74647 .3971 .75294 .40741 .76749 .40839 .761 .39732 Mtetra
.853 .759 .759 r
.761 .39732 .76749 .40839 .78068 .39071 .77424 .37944 Mtetra
.926 .762 .658 r
.77424 .37944 .78068 .39071 .79259 .35841 .78626 .34742 Mtetra
.946 .762 .621 r
.78626 .34742 .79259 .35841 .80372 .31938 .79754 .30892 Mtetra
.949 .768 .623 r
.79754 .30892 .80372 .31938 .81472 .28152 .80868 .27163 Mtetra
.94 .781 .656 r
.80868 .27163 .81472 .28152 .8261 .24998 .82019 .24056 Mtetra
.639 .758 .934 r
.19339 .40861 .20109 .41497 .21208 .4115 .20437 .40537 Mtetra
.631 .763 .942 r
.20437 .40537 .21208 .4115 .2231 .40812 .2154 .40228 Mtetra
.619 .771 .953 r
.2154 .40228 .2231 .40812 .23417 .40485 .22646 .39939 Mtetra
.603 .78 .965 r
.22646 .39939 .23417 .40485 .24527 .4017 .23755 .39672 Mtetra
.581 .791 .979 r
.23755 .39672 .24527 .4017 .25641 .3987 .24867 .39431 Mtetra
.547 .802 .992 r
.24867 .39431 .25641 .3987 .2676 .39587 .25983 .3922 Mtetra
.497 .809 1 r
.25983 .3922 .2676 .39587 .27882 .39321 .27102 .39042 Mtetra
.419 .805 .99 r
.27102 .39042 .27882 .39321 .29009 .39076 .28224 .389 Mtetra
.301 .77 .939 r
.28224 .389 .29009 .39076 .3014 .38851 .29351 .38795 Mtetra
.141 .684 .821 r
.29351 .38795 .3014 .38851 .31275 .38647 .30482 .38728 Mtetra
.038 0 0 r
.30482 .38728 .31275 .38647 .32416 .38463 .31618 .38699 Mtetra
.195 0 0 r
.31618 .38699 .32416 .38463 .33562 .38298 .32759 .38705 Mtetra
.309 0 0 r
.32759 .38705 .33562 .38298 .34714 .38149 .33907 .38741 Mtetra
.383 0 0 r
.33907 .38741 .34714 .38149 .35872 .38012 .35061 .38802 Mtetra
.428 0 .029 r
.35061 .38802 .35872 .38012 .37037 .37882 .36224 .3888 Mtetra
.455 .013 .108 r
.36224 .3888 .37037 .37882 .38209 .37753 .37394 .38963 Mtetra
.47 .053 .166 r
.37394 .38963 .38209 .37753 .39388 .37619 .38574 .39041 Mtetra
.476 .08 .208 r
.38574 .39041 .39388 .37619 .40575 .37471 .39764 .391 Mtetra
.478 .097 .239 r
.39764 .391 .40575 .37471 .4177 .37303 .40964 .39127 Mtetra
.475 .108 .262 r
.40964 .39127 .4177 .37303 .42974 .37106 .42174 .39107 Mtetra
.469 .113 .278 r
.42174 .39107 .42974 .37106 .44185 .36874 .43394 .39028 Mtetra
.461 .113 .288 r
.43394 .39028 .44185 .36874 .45403 .36599 .44624 .38877 Mtetra
.45 .109 .294 r
.44624 .38877 .45403 .36599 .4663 .36277 .45863 .38644 Mtetra
.438 .101 .296 r
.45863 .38644 .4663 .36277 .47863 .35904 .47111 .38324 Mtetra
.423 .09 .295 r
.47111 .38324 .47863 .35904 .49103 .35479 .48367 .37911 Mtetra
.406 .076 .289 r
.48367 .37911 .49103 .35479 .50348 .35 .49629 .37405 Mtetra
.387 .058 .28 r
.49629 .37405 .50348 .35 .51599 .3447 .50897 .36808 Mtetra
.365 .035 .267 r
.50897 .36808 .51599 .3447 .52855 .33893 .5217 .36128 Mtetra
.34 .008 .248 r
.5217 .36128 .52855 .33893 .54116 .33273 .53446 .35371 Mtetra
.31 0 .223 r
.53446 .35371 .54116 .33273 .5538 .32617 .54725 .34551 Mtetra
.276 0 .191 r
.54725 .34551 .5538 .32617 .56648 .31933 .56007 .33679 Mtetra
.234 0 .149 r
.56007 .33679 .56648 .31933 .5792 .3123 .5729 .32772 Mtetra
.184 0 .095 r
.5729 .32772 .5792 .3123 .59195 .30519 .58576 .31846 Mtetra
.128 0 .026 r
.58576 .31846 .59195 .30519 .60474 .29819 .59863 .30926 Mtetra
.071 0 0 r
.59863 .30926 .60474 .29819 .61758 .29164 .61154 .30051 Mtetra
.034 0 0 r
.61154 .30051 .61758 .29164 .63051 .28621 .62451 .29292 Mtetra
.064 0 0 r
.62451 .29292 .63051 .28621 .64357 .28304 .6376 .28764 Mtetra
.217 0 0 r
.6376 .28764 .64357 .28304 .65687 .28385 .65091 .28639 Mtetra
.471 0 0 r
.65091 .28639 .65687 .28385 .67057 .29071 .66458 .29118 Mtetra
.679 .133 0 r
.66458 .29118 .67057 .29071 .68482 .30528 .67878 .30365 Mtetra
.778 .274 0 r
.67878 .30365 .68482 .30528 .69973 .32761 .6936 .32382 Mtetra
.799 .318 0 r
.6936 .32382 .69973 .32761 .71524 .35482 .70899 .34884 Mtetra
.731 .253 0 r
.70899 .34884 .71524 .35482 .73101 .38069 .72463 .37266 Mtetra
0 .082 .611 r
.72463 .37266 .73101 .38069 .74647 .3971 .73999 .3874 Mtetra
.53 .665 .923 r
.73999 .3874 .74647 .3971 .761 .39732 .75449 .38655 Mtetra
.86 .767 .759 r
.75449 .38655 .761 .39732 .77424 .37944 .76776 .36829 Mtetra
.927 .764 .66 r
.76776 .36829 .77424 .37944 .78626 .34742 .77989 .33646 Mtetra
.946 .763 .624 r
.77989 .33646 .78626 .34742 .79754 .30892 .79131 .29847 Mtetra
.949 .77 .626 r
.79131 .29847 .79754 .30892 .80868 .27163 .8026 .26176 Mtetra
.94 .783 .659 r
.8026 .26176 .80868 .27163 .82019 .24056 .81425 .23117 Mtetra
.626 .758 .942 r
.1856 .40232 .19339 .40861 .20437 .40537 .19659 .39935 Mtetra
.612 .764 .952 r
.19659 .39935 .20437 .40537 .2154 .40228 .2076 .39663 Mtetra
.592 .771 .965 r
.2076 .39663 .2154 .40228 .22646 .39939 .21864 .39419 Mtetra
.564 .779 .979 r
.21864 .39419 .22646 .39939 .23755 .39672 .22971 .39211 Mtetra
.522 .786 .993 r
.22971 .39211 .23755 .39672 .24867 .39431 .2408 .39043 Mtetra
.456 .786 .999 r
.2408 .39043 .24867 .39431 .25983 .3922 .25191 .38921 Mtetra
.353 .767 .98 r
.25191 .38921 .25983 .3922 .27102 .39042 .26305 .38851 Mtetra
.2 .705 .905 r
.26305 .38851 .27102 .39042 .28224 .389 .27422 .38836 Mtetra
.001 .577 .743 r
.27422 .38836 .28224 .389 .29351 .38795 .28542 .38881 Mtetra
.197 0 0 r
.28542 .38881 .29351 .38795 .30482 .38728 .29666 .38986 Mtetra
.347 0 0 r
.29666 .38986 .30482 .38728 .31618 .38699 .30794 .39152 Mtetra
.441 0 0 r
.30794 .39152 .31618 .38699 .32759 .38705 .31928 .39374 Mtetra
.495 .011 .035 r
.31928 .39374 .32759 .38705 .33907 .38741 .33068 .39648 Mtetra
.525 .077 .13 r
.33068 .39648 .33907 .38741 .35061 .38802 .34216 .39965 Mtetra
.54 .122 .197 r
.34216 .39965 .35061 .38802 .36224 .3888 .35373 .40311 Mtetra
.546 .152 .246 r
.35373 .40311 .36224 .3888 .37394 .38963 .3654 .40673 Mtetra
.547 .172 .281 r
.3654 .40673 .37394 .38963 .38574 .39041 .37718 .41031 Mtetra
.543 .183 .307 r
.37718 .41031 .38574 .39041 .39764 .391 .38908 .41366 Mtetra
.536 .189 .326 r
.38908 .41366 .39764 .391 .40964 .39127 .40112 .41656 Mtetra
.528 .191 .34 r
.40112 .41656 .40964 .39127 .42174 .39107 .41328 .41878 Mtetra
.517 .189 .35 r
.41328 .41878 .42174 .39107 .43394 .39028 .42558 .42012 Mtetra
.505 .183 .356 r
.42558 .42012 .43394 .39028 .44624 .38877 .438 .42037 Mtetra
.491 .175 .359 r
.438 .42037 .44624 .38877 .45863 .38644 .45055 .41938 Mtetra
.476 .165 .359 r
.45055 .41938 .45863 .38644 .47111 .38324 .46321 .41701 Mtetra
.459 .152 .357 r
.46321 .41701 .47111 .38324 .48367 .37911 .47596 .41319 Mtetra
.441 .137 .353 r
.47596 .41319 .48367 .37911 .49629 .37405 .48879 .40791 Mtetra
.421 .119 .345 r
.48879 .40791 .49629 .37405 .50897 .36808 .50168 .4012 Mtetra
.398 .098 .335 r
.50168 .4012 .50897 .36808 .5217 .36128 .51462 .39314 Mtetra
.374 .074 .321 r
.51462 .39314 .5217 .36128 .53446 .35371 .52759 .38388 Mtetra
.347 .045 .303 r
.52759 .38388 .53446 .35371 .54725 .34551 .54058 .37358 Mtetra
.316 .012 .281 r
.54058 .37358 .54725 .34551 .56007 .33679 .55357 .36246 Mtetra
.281 0 .252 r
.55357 .36246 .56007 .33679 .5729 .32772 .56655 .35074 Mtetra
.24 0 .215 r
.56655 .35074 .5729 .32772 .58576 .31846 .57954 .33869 Mtetra
.195 0 .168 r
.57954 .33869 .58576 .31846 .59863 .30926 .59252 .32662 Mtetra
.149 0 .112 r
.59252 .32662 .59863 .30926 .61154 .30051 .60552 .315 Mtetra
.118 0 .047 r
.60552 .315 .61154 .30051 .62451 .29292 .61855 .30459 Mtetra
.13 0 0 r
.61855 .30459 .62451 .29292 .6376 .28764 .63167 .29655 Mtetra
.232 0 0 r
.63167 .29655 .6376 .28764 .65091 .28639 .64499 .29261 Mtetra
.434 0 0 r
.64499 .29261 .65091 .28639 .66458 .29118 .65864 .29475 Mtetra
.641 .113 0 r
.65864 .29475 .66458 .29118 .67878 .30365 .67277 .30455 Mtetra
.76 .251 0 r
.67277 .30455 .67878 .30365 .6936 .32382 .68749 .32201 Mtetra
.793 .298 0 r
.68749 .32201 .6936 .32382 .70899 .34884 .70275 .34433 Mtetra
.729 .229 0 r
.70275 .34433 .70899 .34884 .72463 .37266 .71826 .36563 Mtetra
0 .136 .642 r
.71826 .36563 .72463 .37266 .73999 .3874 .73351 .3783 Mtetra
.573 .704 .931 r
.73351 .3783 .73999 .3874 .75449 .38655 .74795 .3761 Mtetra
.868 .775 .757 r
.74795 .3761 .75449 .38655 .76776 .36829 .76125 .35727 Mtetra
.929 .767 .66 r
.76125 .35727 .76776 .36829 .77989 .33646 .77347 .32554 Mtetra
.946 .765 .626 r
.77347 .32554 .77989 .33646 .79131 .29847 .78504 .28805 Mtetra
.948 .772 .63 r
.78504 .28805 .79131 .29847 .8026 .26176 .79649 .25193 Mtetra
.939 .785 .663 r
.79649 .25193 .8026 .26176 .81425 .23117 .80827 .22182 Mtetra
.613 .753 .944 r
.17776 .39592 .1856 .40232 .19659 .39935 .18874 .39321 Mtetra
.594 .756 .956 r
.18874 .39321 .19659 .39935 .2076 .39663 .19975 .39082 Mtetra
.568 .76 .969 r
.19975 .39082 .2076 .39663 .21864 .39419 .21077 .38883 Mtetra
.529 .763 .983 r
.21077 .38883 .21864 .39419 .22971 .39211 .22181 .38731 Mtetra
.47 .761 .994 r
.22181 .38731 .22971 .39211 .2408 .39043 .23287 .38634 Mtetra
.38 .746 .991 r
.23287 .38634 .2408 .39043 .25191 .38921 .24393 .386 Mtetra
.243 .7 .952 r
.24393 .386 .25191 .38921 .26305 .38851 .25502 .38635 Mtetra
.052 .598 .839 r
.25502 .38635 .26305 .38851 .27422 .38836 .26612 .38748 Mtetra
.165 0 0 r
.26612 .38748 .27422 .38836 .28542 .38881 .27724 .38941 Mtetra
.349 0 0 r
.27724 .38941 .28542 .38881 .29666 .38986 .28839 .3922 Mtetra
.471 0 0 r
.28839 .3922 .29666 .38986 .30794 .39152 .29959 .39583 Mtetra
.541 .025 0 r
.29959 .39583 .30794 .39152 .31928 .39374 .31083 .40028 Mtetra
.577 .103 .093 r
.31083 .40028 .31928 .39374 .33068 .39648 .32215 .40547 Mtetra
.595 .155 .174 r
.32215 .40547 .33068 .39648 .34216 .39965 .33354 .4113 Mtetra
.601 .188 .232 r
.33354 .4113 .34216 .39965 .35373 .40311 .34503 .4176 Mtetra
.6 .209 .274 r
.34503 .4176 .35373 .40311 .3654 .40673 .35665 .42417 Mtetra
.594 .221 .304 r
.35665 .42417 .3654 .40673 .37718 .41031 .36839 .43078 Mtetra
.586 .227 .327 r
.36839 .43078 .37718 .41031 .38908 .41366 .38028 .43713 Mtetra
.574 .227 .343 r
.38028 .43713 .38908 .41366 .40112 .41656 .39233 .44293 Mtetra
.561 .224 .355 r
.39233 .44293 .40112 .41656 .41328 .41878 .40454 .44787 Mtetra
.545 .217 .363 r
.40454 .44787 .41328 .41878 .42558 .42012 .41692 .45164 Mtetra
.528 .208 .368 r
.41692 .45164 .42558 .42012 .438 .42037 .42947 .45396 Mtetra
.51 .195 .369 r
.42947 .45396 .438 .42037 .45055 .41938 .44216 .45457 Mtetra
.49 .18 .369 r
.44216 .45457 .45055 .41938 .46321 .41701 .455 .4533 Mtetra
.468 .163 .365 r
.455 .4533 .46321 .41701 .47596 .41319 .46795 .45001 Mtetra
.444 .144 .36 r
.46795 .45001 .47596 .41319 .48879 .40791 .481 .44467 Mtetra
.419 .121 .351 r
.481 .44467 .48879 .40791 .50168 .4012 .49412 .43732 Mtetra
.391 .096 .34 r
.49412 .43732 .50168 .4012 .51462 .39314 .50729 .42806 Mtetra
.36 .067 .325 r
.50729 .42806 .51462 .39314 .52759 .38388 .52049 .41708 Mtetra
.327 .035 .307 r
.52049 .41708 .52759 .38388 .54058 .37358 .53369 .40463 Mtetra
.29 0 .284 r
.53369 .40463 .54058 .37358 .55357 .36246 .54688 .39099 Mtetra
.248 0 .255 r
.54688 .39099 .55357 .36246 .56655 .35074 .56004 .37648 Mtetra
.201 0 .218 r
.56004 .37648 .56655 .35074 .57954 .33869 .57318 .36145 Mtetra
.149 0 .173 r
.57318 .36145 .57954 .33869 .59252 .32662 .5863 .34631 Mtetra
.097 0 .119 r
.5863 .34631 .59252 .32662 .60552 .315 .59939 .3316 Mtetra
.058 0 .057 r
.59939 .3316 .60552 .315 .61855 .30459 .6125 .31813 Mtetra
.058 0 0 r
.6125 .31813 .61855 .30459 .63167 .29655 .62568 .30711 Mtetra
.143 0 0 r
.62568 .30711 .63167 .29655 .64499 .29261 .63901 .30025 Mtetra
.339 0 0 r
.63901 .30025 .64499 .29261 .65864 .29475 .65264 .29949 Mtetra
.57 .043 0 r
.65264 .29949 .65864 .29475 .67277 .30455 .66672 .30636 Mtetra
.719 .196 0 r
.66672 .30636 .67277 .30455 .68749 .32201 .68134 .32083 Mtetra
.764 .251 0 r
.68134 .32083 .68749 .32201 .70275 .34433 .69647 .34019 Mtetra
.688 .17 0 r
.69647 .34019 .70275 .34433 .71826 .36563 .71184 .35873 Mtetra
0 .237 .724 r
.71184 .35873 .71826 .36563 .73351 .3783 .72697 .36914 Mtetra
.622 .727 .922 r
.72697 .36914 .73351 .3783 .74795 .3761 .74135 .36545 Mtetra
.871 .773 .751 r
.74135 .36545 .74795 .3761 .76125 .35727 .75468 .34601 Mtetra
.927 .765 .661 r
.75468 .34601 .76125 .35727 .77347 .32554 .767 .3144 Mtetra
.944 .764 .629 r
.767 .3144 .77347 .32554 .78504 .28805 .77871 .27745 Mtetra
.946 .771 .634 r
.77871 .27745 .78504 .28805 .79649 .25193 .79031 .24197 Mtetra
.937 .785 .667 r
.79031 .24197 .79649 .25193 .80827 .22182 .80224 .21239 Mtetra
.606 .742 .94 r
.16988 .38917 .17776 .39592 .18874 .39321 .18087 .38662 Mtetra
.586 .741 .95 r
.18087 .38662 .18874 .39321 .19975 .39082 .19188 .38445 Mtetra
.557 .74 .961 r
.19188 .38445 .19975 .39082 .21077 .38883 .20289 .38275 Mtetra
.517 .736 .973 r
.20289 .38275 .21077 .38883 .22181 .38731 .21392 .3816 Mtetra
.46 .726 .983 r
.21392 .3816 .22181 .38731 .23287 .38634 .22495 .38111 Mtetra
.376 .706 .985 r
.22495 .38111 .23287 .38634 .24393 .386 .23599 .38137 Mtetra
.255 .664 .965 r
.23599 .38137 .24393 .386 .25502 .38635 .24704 .38246 Mtetra
.087 .583 .898 r
.24704 .38246 .25502 .38635 .26612 .38748 .25809 .38448 Mtetra
0 .452 .761 r
.25809 .38448 .26612 .38748 .27724 .38941 .26916 .38749 Mtetra
.316 0 0 r
.26916 .38749 .27724 .38941 .28839 .3922 .28024 .39153 Mtetra
.469 0 0 r
.28024 .39153 .28839 .3922 .29959 .39583 .29137 .39661 Mtetra
.565 .003 0 r
.29137 .39661 .29959 .39583 .31083 .40028 .30254 .40271 Mtetra
.619 .094 0 r
.30254 .40271 .31083 .40028 .32215 .40547 .31377 .40975 Mtetra
.645 .155 .072 r
.31377 .40975 .32215 .40547 .33354 .4113 .32509 .41761 Mtetra
.655 .194 .145 r
.32509 .41761 .33354 .4113 .34503 .4176 .33651 .42611 Mtetra
.654 .217 .199 r
.33651 .42611 .34503 .4176 .35665 .42417 .34806 .435 Mtetra
.647 .23 .239 r
.34806 .435 .35665 .42417 .36839 .43078 .35976 .44402 Mtetra
.634 .234 .268 r
.35976 .44402 .36839 .43078 .38028 .43713 .37163 .45281 Mtetra
.618 .231 .288 r
.37163 .45281 .38028 .43713 .39233 .44293 .38367 .46102 Mtetra
.598 .223 .303 r
.38367 .46102 .39233 .44293 .40454 .44787 .39591 .46825 Mtetra
.575 .21 .312 r
.39591 .46825 .40454 .44787 .41692 .45164 .40834 .47413 Mtetra
.549 .193 .317 r
.40834 .47413 .41692 .45164 .42947 .45396 .42096 .47828 Mtetra
.519 .171 .318 r
.42096 .47828 .42947 .45396 .44216 .45457 .43376 .48039 Mtetra
.486 .146 .315 r
.43376 .48039 .44216 .45457 .455 .4533 .44674 .48022 Mtetra
.45 .117 .308 r
.44674 .48022 .455 .4533 .46795 .45001 .45985 .47759 Mtetra
.41 .083 .297 r
.45985 .47759 .46795 .45001 .481 .44467 .47308 .47243 Mtetra
.367 .045 .282 r
.47308 .47243 .481 .44467 .49412 .43732 .4864 .46476 Mtetra
.318 .002 .262 r
.4864 .46476 .49412 .43732 .50729 .42806 .49977 .45473 Mtetra
.265 0 .237 r
.49977 .45473 .50729 .42806 .52049 .41708 .51316 .44254 Mtetra
.206 0 .206 r
.51316 .44254 .52049 .41708 .53369 .40463 .52656 .42848 Mtetra
.141 0 .167 r
.52656 .42848 .53369 .40463 .54688 .39099 .53994 .41291 Mtetra
.069 0 .119 r
.53994 .41291 .54688 .39099 .56004 .37648 .55327 .39622 Mtetra
0 0 .062 r
.55327 .39622 .56004 .37648 .57318 .36145 .56657 .37884 Mtetra
0 0 0 r
.56657 .37884 .57318 .36145 .5863 .34631 .57981 .36123 Mtetra
.57981 .36123 .5863 .34631 .59939 .3316 .59302 .34402 Mtetra
.59302 .34402 .59939 .3316 .6125 .31813 .60621 .32805 Mtetra
.60621 .32805 .6125 .31813 .62568 .30711 .61945 .31454 Mtetra
.61945 .31454 .62568 .30711 .63901 .30025 .63282 .30519 Mtetra
.088 0 0 r
.63282 .30519 .63901 .30025 .65264 .29949 .64645 .3019 Mtetra
.427 0 0 r
.64645 .3019 .65264 .29949 .66672 .30636 .66048 .30613 Mtetra
.636 .074 0 r
.66048 .30613 .66672 .30636 .68134 .32083 .67502 .31784 Mtetra
.685 .152 0 r
.67502 .31784 .68134 .32083 .69647 .34019 .69003 .33439 Mtetra
.559 .047 0 r
.69003 .33439 .69647 .34019 .71184 .35873 .70526 .35031 Mtetra
0 .37 .836 r
.70526 .35031 .71184 .35873 .72697 .36914 .72029 .3586 Mtetra
.659 .711 .886 r
.72029 .3586 .72697 .36914 .74135 .36545 .73463 .35359 Mtetra
.862 .754 .742 r
.73463 .35359 .74135 .36545 .75468 .34601 .74799 .33374 Mtetra
.918 .754 .663 r
.74799 .33374 .75468 .34601 .767 .3144 .76043 .30246 Mtetra
.936 .757 .634 r
.76043 .30246 .767 .3144 .77871 .27745 .77229 .26624 Mtetra
.94 .766 .639 r
.77229 .26624 .77871 .27745 .79031 .24197 .78406 .23156 Mtetra
.931 .78 .672 r
.78406 .23156 .79031 .24197 .80224 .21239 .79613 .20264 Mtetra
.608 .728 .93 r
.16199 .38189 .16988 .38917 .18087 .38662 .173 .37934 Mtetra
.589 .723 .936 r
.173 .37934 .18087 .38662 .19188 .38445 .18403 .37719 Mtetra
.564 .715 .943 r
.18403 .37719 .19188 .38445 .20289 .38275 .19506 .37551 Mtetra
.532 .705 .95 r
.19506 .37551 .20289 .38275 .21392 .3816 .2061 .37442 Mtetra
.489 .691 .957 r
.2061 .37442 .21392 .3816 .22495 .38111 .21714 .37401 Mtetra
.432 .669 .962 r
.21714 .37401 .22495 .38111 .23599 .38137 .22819 .37439 Mtetra
.358 .639 .961 r
.22819 .37439 .23599 .38137 .24704 .38246 .23923 .37564 Mtetra
.262 .594 .949 r
.23923 .37564 .24704 .38246 .25809 .38448 .25028 .37787 Mtetra
.143 .532 .92 r
.25028 .37787 .25809 .38448 .26916 .38749 .26134 .38116 Mtetra
.003 .449 .865 r
.26134 .38116 .26916 .38749 .28024 .39153 .27241 .38554 Mtetra
0 .349 .782 r
.27241 .38554 .28024 .39153 .29137 .39661 .28351 .39105 Mtetra
0 .241 .676 r
.28351 .39105 .29137 .39661 .30254 .40271 .29465 .39766 Mtetra
.42 0 0 r
.29465 .39766 .30254 .40271 .31377 .40975 .30586 .4053 Mtetra
.517 0 0 r
.30586 .4053 .31377 .40975 .32509 .41761 .31715 .41386 Mtetra
.585 .019 0 r
.31715 .41386 .32509 .41761 .33651 .42611 .32854 .42315 Mtetra
.629 .066 0 r
.32854 .42315 .33651 .42611 .34806 .435 .34006 .43292 Mtetra
.651 .093 0 r
.34006 .43292 .34806 .435 .35976 .44402 .35172 .44289 Mtetra
.656 .103 0 r
.35172 .44289 .35976 .44402 .37163 .45281 .36357 .45269 Mtetra
.646 .095 0 r
.36357 .45269 .37163 .45281 .38367 .46102 .3756 .46195 Mtetra
.621 .071 0 r
.3756 .46195 .38367 .46102 .39591 .46825 .38783 .47023 Mtetra
.579 .028 0 r
.38783 .47023 .39591 .46825 .40834 .47413 .40027 .47713 Mtetra
.517 0 0 r
.40027 .47713 .40834 .47413 .42096 .47828 .41292 .48225 Mtetra
.432 0 0 r
.41292 .48225 .42096 .47828 .43376 .48039 .42577 .48524 Mtetra
.32 0 0 r
.42577 .48524 .43376 .48039 .44674 .48022 .4388 .48579 Mtetra
.177 0 0 r
.4388 .48579 .44674 .48022 .45985 .47759 .45199 .48373 Mtetra
.01 0 0 r
.45199 .48373 .45985 .47759 .47308 .47243 .46531 .47894 Mtetra
0 0 0 r
.46531 .47894 .47308 .47243 .4864 .46476 .47873 .47145 Mtetra
.47873 .47145 .4864 .46476 .49977 .45473 .49222 .46136 Mtetra
.503 .835 .544 r
.49222 .46136 .49977 .45473 .51316 .44254 .50574 .44891 Mtetra
.628 .899 .589 r
.50574 .44891 .51316 .44254 .52656 .42848 .51926 .4344 Mtetra
.723 .94 .624 r
.51926 .4344 .52656 .42848 .53994 .41291 .53276 .4182 Mtetra
.792 .964 .652 r
.53276 .4182 .53994 .41291 .55327 .39622 .54622 .40072 Mtetra
.841 .977 .677 r
.54622 .40072 .55327 .39622 .56657 .37884 .55962 .38242 Mtetra
.873 .984 .701 r
.55962 .38242 .56657 .37884 .57981 .36123 .57298 .36381 Mtetra
.891 .986 .728 r
.57298 .36381 .57981 .36123 .59302 .34402 .58628 .34552 Mtetra
.892 .989 .761 r
.58628 .34552 .59302 .34402 .60621 .32805 .59956 .32841 Mtetra
.869 .993 .812 r
.59956 .32841 .60621 .32805 .61945 .31454 .61287 .31369 Mtetra
.791 .988 .89 r
.61287 .31369 .61945 .31454 .63282 .30519 .62628 .30301 Mtetra
.561 .906 .973 r
.62628 .30301 .63282 .30519 .64645 .3019 .63993 .2982 Mtetra
.079 .582 .891 r
.63993 .2982 .64645 .3019 .66048 .30613 .65394 .30067 Mtetra
0 .2 .658 r
.65394 .30067 .66048 .30613 .67502 .31784 .66841 .31036 Mtetra
0 .051 .568 r
.66841 .31036 .67502 .31784 .69003 .33439 .68333 .32473 Mtetra
0 .144 .678 r
.68333 .32473 .69003 .33439 .70526 .35031 .69845 .33858 Mtetra
.228 .445 .864 r
.69845 .33858 .70526 .35031 .72029 .3586 .7134 .34527 Mtetra
.667 .662 .835 r
.7134 .34527 .72029 .3586 .73463 .35359 .72771 .33942 Mtetra
.84 .718 .73 r
.72771 .33942 .73463 .35359 .74799 .33374 .74114 .31961 Mtetra
.9 .733 .665 r
.74114 .31961 .74799 .33374 .76043 .30246 .7537 .28906 Mtetra
.923 .742 .64 r
.7537 .28906 .76043 .30246 .77229 .26624 .76574 .25393 Mtetra
.929 .755 .646 r
.76574 .25393 .77229 .26624 .78406 .23156 .77769 .22035 Mtetra
.921 .77 .678 r
.77769 .22035 .78406 .23156 .79613 .20264 .78992 .1923 Mtetra
.616 .716 .917 r
.1541 .37408 .16199 .38189 .173 .37934 .16514 .37135 Mtetra
.6 .707 .919 r
.16514 .37135 .173 .37934 .18403 .37719 .17621 .36899 Mtetra
.582 .696 .92 r
.17621 .36899 .18403 .37719 .19506 .37551 .18728 .36707 Mtetra
.558 .681 .921 r
.18728 .36707 .19506 .37551 .2061 .37442 .19837 .36567 Mtetra
.53 .662 .921 r
.19837 .36567 .2061 .37442 .21714 .37401 .20946 .36491 Mtetra
.496 .639 .918 r
.20946 .36491 .21714 .37401 .22819 .37439 .22055 .36486 Mtetra
.456 .61 .913 r
.22055 .36486 .22819 .37439 .23923 .37564 .23164 .36563 Mtetra
.412 .576 .905 r
.23164 .36563 .23923 .37564 .25028 .37787 .24274 .36731 Mtetra
.364 .537 .892 r
.24274 .36731 .25028 .37787 .26134 .38116 .25385 .36996 Mtetra
.314 .495 .876 r
.25385 .36996 .26134 .38116 .27241 .38554 .26498 .37365 Mtetra
.267 .451 .857 r
.26498 .37365 .27241 .38554 .28351 .39105 .27613 .37839 Mtetra
.225 .409 .835 r
.27613 .37839 .28351 .39105 .29465 .39766 .28732 .38417 Mtetra
.192 .372 .814 r
.28732 .38417 .29465 .39766 .30586 .4053 .29856 .39093 Mtetra
.17 .342 .794 r
.29856 .39093 .30586 .4053 .31715 .41386 .30988 .39858 Mtetra
.162 .322 .778 r
.30988 .39858 .31715 .41386 .32854 .42315 .3213 .40694 Mtetra
.168 .311 .766 r
.3213 .40694 .32854 .42315 .34006 .43292 .33284 .41579 Mtetra
.187 .31 .758 r
.33284 .41579 .34006 .43292 .35172 .44289 .34452 .42487 Mtetra
.218 .319 .755 r
.34452 .42487 .35172 .44289 .36357 .45269 .35637 .43385 Mtetra
.259 .337 .753 r
.35637 .43385 .36357 .45269 .3756 .46195 .36839 .44237 Mtetra
.308 .361 .754 r
.36839 .44237 .3756 .46195 .38783 .47023 .38061 .45004 Mtetra
.362 .389 .754 r
.38061 .45004 .38783 .47023 .40027 .47713 .39303 .45647 Mtetra
.417 .42 .755 r
.39303 .45647 .40027 .47713 .41292 .48225 .40566 .46128 Mtetra
.472 .452 .754 r
.40566 .46128 .41292 .48225 .42577 .48524 .41848 .46414 Mtetra
.525 .483 .752 r
.41848 .46414 .42577 .48524 .4388 .48579 .43148 .46476 Mtetra
.573 .513 .749 r
.43148 .46476 .4388 .48579 .45199 .48373 .44465 .46294 Mtetra
.617 .541 .746 r
.44465 .46294 .45199 .48373 .46531 .47894 .45796 .45858 Mtetra
.656 .566 .742 r
.45796 .45858 .46531 .47894 .47873 .47145 .47136 .45166 Mtetra
.691 .59 .738 r
.47136 .45166 .47873 .47145 .49222 .46136 .48485 .44228 Mtetra
.721 .611 .734 r
.48485 .44228 .49222 .46136 .50574 .44891 .49838 .43064 Mtetra
.746 .63 .731 r
.49838 .43064 .50574 .44891 .51926 .4344 .51192 .41701 Mtetra
.768 .648 .729 r
.51192 .41701 .51926 .4344 .53276 .4182 .52545 .40171 Mtetra
.786 .664 .728 r
.52545 .40171 .53276 .4182 .54622 .40072 .53895 .38515 Mtetra
.801 .679 .729 r
.53895 .38515 .54622 .40072 .55962 .38242 .55241 .36774 Mtetra
.812 .692 .732 r
.55241 .36774 .55962 .38242 .57298 .36381 .56582 .34997 Mtetra
.818 .704 .739 r
.56582 .34997 .57298 .36381 .58628 .34552 .57919 .33243 Mtetra
.817 .713 .751 r
.57919 .33243 .58628 .34552 .59956 .32841 .59254 .31595 Mtetra
.802 .718 .772 r
.59254 .31595 .59956 .32841 .61287 .31369 .6059 .30168 Mtetra
.76 .712 .807 r
.6059 .30168 .61287 .31369 .62628 .30301 .61937 .2912 Mtetra
.657 .676 .856 r
.61937 .2912 .62628 .30301 .63993 .2982 .63304 .28624 Mtetra
.44 .564 .883 r
.63304 .28624 .63993 .2982 .65394 .30067 .64705 .28814 Mtetra
.142 .368 .824 r
.64705 .28814 .65394 .30067 .66841 .31036 .66148 .29684 Mtetra
0 .232 .747 r
.66148 .29684 .66841 .31036 .68333 .32473 .67632 .30995 Mtetra
.055 .269 .761 r
.67632 .30995 .68333 .32473 .69845 .33858 .69137 .32253 Mtetra
.357 .446 .816 r
.69137 .32253 .69845 .33858 .7134 .34527 .70625 .32833 Mtetra
.654 .605 .788 r
.70625 .32833 .7134 .34527 .72771 .33942 .72058 .32231 Mtetra
.809 .677 .718 r
.72058 .32231 .72771 .33942 .74114 .31961 .73409 .30313 Mtetra
.876 .706 .667 r
.73409 .30313 .74114 .31961 .7537 .28906 .74681 .27384 Mtetra
.905 .724 .647 r
.74681 .27384 .7537 .28906 .76574 .25393 .75904 .24023 Mtetra
.913 .74 .653 r
.75904 .24023 .76574 .25393 .77769 .22035 .7712 .20809 Mtetra
.907 .757 .684 r
.7712 .20809 .77769 .22035 .78992 .1923 .78361 .18119 Mtetra
.626 .71 .906 r
.14618 .36586 .1541 .37408 .16514 .37135 .15728 .36284 Mtetra
.615 .7 .905 r
.15728 .36284 .16514 .37135 .17621 .36899 .1684 .36011 Mtetra
.602 .686 .902 r
.1684 .36011 .17621 .36899 .18728 .36707 .17954 .35773 Mtetra
.585 .67 .897 r
.17954 .35773 .18728 .36707 .19837 .36567 .19069 .35577 Mtetra
.567 .649 .891 r
.19069 .35577 .19837 .36567 .20946 .36491 .20186 .35432 Mtetra
.545 .625 .882 r
.20186 .35432 .20946 .36491 .22055 .36486 .21304 .35346 Mtetra
.522 .597 .87 r
.21304 .35346 .22055 .36486 .23164 .36563 .22423 .35326 Mtetra
.498 .565 .855 r
.22423 .35326 .23164 .36563 .24274 .36731 .23542 .35379 Mtetra
.473 .532 .837 r
.23542 .35379 .24274 .36731 .25385 .36996 .24664 .35512 Mtetra
.451 .498 .817 r
.24664 .35512 .25385 .36996 .26498 .37365 .25787 .3573 Mtetra
.431 .465 .795 r
.25787 .3573 .26498 .37365 .27613 .37839 .26913 .36035 Mtetra
.415 .435 .772 r
.26913 .36035 .27613 .37839 .28732 .38417 .28043 .36425 Mtetra
.405 .409 .75 r
.28043 .36425 .28732 .38417 .29856 .39093 .29178 .36897 Mtetra
.4 .387 .73 r
.29178 .36897 .29856 .39093 .30988 .39858 .3032 .37442 Mtetra
.4 .371 .711 r
.3032 .37442 .30988 .39858 .3213 .40694 .31471 .38048 Mtetra
.405 .36 .695 r
.31471 .38048 .3213 .40694 .33284 .41579 .32633 .38696 Mtetra
.415 .354 .681 r
.32633 .38696 .33284 .41579 .34452 .42487 .33807 .39365 Mtetra
.427 .352 .67 r
.33807 .39365 .34452 .42487 .35637 .43385 .34995 .40029 Mtetra
.443 .354 .66 r
.34995 .40029 .35637 .43385 .36839 .44237 .36199 .40658 Mtetra
.46 .359 .653 r
.36199 .40658 .36839 .44237 .38061 .45004 .3742 .41222 Mtetra
.478 .366 .647 r
.3742 .41222 .38061 .45004 .39303 .45647 .3866 .41687 Mtetra
.498 .375 .643 r
.3866 .41687 .39303 .45647 .40566 .46128 .39917 .42024 Mtetra
.517 .386 .64 r
.39917 .42024 .40566 .46128 .41848 .46414 .41192 .42203 Mtetra
.537 .397 .638 r
.41192 .42203 .41848 .46414 .43148 .46476 .42483 .42202 Mtetra
.556 .41 .637 r
.42483 .42202 .43148 .46476 .44465 .46294 .4379 .42003 Mtetra
.575 .423 .637 r
.4379 .42003 .44465 .46294 .45796 .45858 .45109 .41596 Mtetra
.593 .436 .637 r
.45109 .41596 .45796 .45858 .47136 .45166 .4644 .40979 Mtetra
.611 .45 .639 r
.4644 .40979 .47136 .45166 .48485 .44228 .47778 .40158 Mtetra
.628 .464 .641 r
.47778 .40158 .48485 .44228 .49838 .43064 .49121 .39148 Mtetra
.644 .478 .643 r
.49121 .39148 .49838 .43064 .51192 .41701 .50468 .37969 Mtetra
.659 .492 .647 r
.50468 .37969 .51192 .41701 .52545 .40171 .51815 .36648 Mtetra
.673 .506 .652 r
.51815 .36648 .52545 .40171 .53895 .38515 .53162 .35216 Mtetra
.686 .521 .657 r
.53162 .35216 .53895 .38515 .55241 .36774 .54506 .33708 Mtetra
.698 .535 .664 r
.54506 .33708 .55241 .36774 .56582 .34997 .55847 .32164 Mtetra
.706 .549 .673 r
.55847 .32164 .56582 .34997 .57919 .33243 .57186 .30637 Mtetra
.709 .56 .684 r
.57186 .30637 .57919 .33243 .59254 .31595 .58524 .292 Mtetra
.702 .567 .7 r
.58524 .292 .59254 .31595 .6059 .30168 .59865 .27961 Mtetra
.674 .563 .722 r
.59865 .27961 .6059 .30168 .61937 .2912 .61216 .27063 Mtetra
.607 .537 .749 r
.61216 .27063 .61937 .2912 .63304 .28624 .62586 .26673 Mtetra
.48 .472 .772 r
.62586 .26673 .63304 .28624 .64705 .28814 .63987 .26913 Mtetra
.3 .368 .765 r
.63987 .26913 .64705 .28814 .66148 .29684 .65428 .2778 Mtetra
.17 .284 .739 r
.65428 .2778 .66148 .29684 .67632 .30995 .66906 .29046 Mtetra
.205 .303 .744 r
.66906 .29046 .67632 .30995 .69137 .32253 .68405 .30251 Mtetra
.405 .427 .77 r
.68405 .30251 .69137 .32253 .70625 .32833 .6989 .30809 Mtetra
.634 .561 .755 r
.6989 .30809 .70625 .32833 .72058 .32231 .71326 .30251 Mtetra
.779 .641 .709 r
.71326 .30251 .72058 .32231 .73409 .30313 .72687 .2845 Mtetra
.852 .681 .67 r
.72687 .2845 .73409 .30313 .74681 .27384 .73977 .25694 Mtetra
.885 .705 .653 r
.73977 .25694 .74681 .27384 .75904 .24023 .75222 .22524 Mtetra
.897 .725 .661 r
.75222 .22524 .75904 .24023 .7712 .20809 .76458 .19486 Mtetra
.891 .744 .692 r
.76458 .19486 .7712 .20809 .78361 .18119 .77719 .16933 Mtetra
.637 .711 .9 r
.13821 .35747 .14618 .36586 .15728 .36284 .14937 .35412 Mtetra
.63 .701 .896 r
.14937 .35412 .15728 .36284 .1684 .36011 .16056 .35096 Mtetra
.62 .688 .891 r
.16056 .35096 .1684 .36011 .17954 .35773 .17177 .34804 Mtetra
.609 .672 .885 r
.17177 .34804 .17954 .35773 .19069 .35577 .18301 .34543 Mtetra
.597 .652 .876 r
.18301 .34543 .19069 .35577 .20186 .35432 .19427 .34317 Mtetra
.582 .63 .864 r
.19427 .34317 .20186 .35432 .21304 .35346 .20555 .34133 Mtetra
.567 .604 .85 r
.20555 .34133 .21304 .35346 .22423 .35326 .21685 .33996 Mtetra
.551 .576 .833 r
.21685 .33996 .22423 .35326 .23542 .35379 .22817 .33912 Mtetra
.535 .547 .814 r
.22817 .33912 .23542 .35379 .24664 .35512 .23952 .33885 Mtetra
.52 .517 .793 r
.23952 .33885 .24664 .35512 .25787 .3573 .25089 .33918 Mtetra
.507 .488 .77 r
.25089 .33918 .25787 .3573 .26913 .36035 .2623 .34014 Mtetra
.496 .461 .748 r
.2623 .34014 .26913 .36035 .28043 .36425 .27374 .34173 Mtetra
.488 .437 .727 r
.27374 .34173 .28043 .36425 .29178 .36897 .28524 .3439 Mtetra
.482 .417 .707 r
.28524 .3439 .29178 .36897 .3032 .37442 .2968 .34661 Mtetra
.48 .401 .689 r
.2968 .34661 .3032 .37442 .31471 .38048 .30844 .34976 Mtetra
.481 .388 .673 r
.30844 .34976 .31471 .38048 .32633 .38696 .32016 .35323 Mtetra
.483 .379 .659 r
.32016 .35323 .32633 .38696 .33807 .39365 .332 .35686 Mtetra
.488 .373 .648 r
.332 .35686 .33807 .39365 .34995 .40029 .34395 .36046 Mtetra
.495 .37 .638 r
.34395 .36046 .34995 .40029 .36199 .40658 .35603 .36384 Mtetra
.503 .369 .631 r
.35603 .36384 .36199 .40658 .3742 .41222 .36825 .36675 Mtetra
.512 .37 .625 r
.36825 .36675 .3742 .41222 .3866 .41687 .38062 .36898 Mtetra
.522 .373 .62 r
.38062 .36898 .3866 .41687 .39917 .42024 .39314 .3703 Mtetra
.532 .377 .617 r
.39314 .3703 .39917 .42024 .41192 .42203 .4058 .37051 Mtetra
.543 .383 .614 r
.4058 .37051 .41192 .42203 .42483 .42202 .4186 .36943 Mtetra
.554 .39 .613 r
.4186 .36943 .42483 .42202 .4379 .42003 .43154 .36694 Mtetra
.565 .397 .613 r
.43154 .36694 .4379 .42003 .45109 .41596 .44459 .36295 Mtetra
.576 .405 .613 r
.44459 .36295 .45109 .41596 .4644 .40979 .45774 .35745 Mtetra
.587 .414 .614 r
.45774 .35745 .4644 .40979 .47778 .40158 .47097 .35046 Mtetra
.598 .423 .617 r
.47097 .35046 .47778 .40158 .49121 .39148 .48426 .34208 Mtetra
.608 .433 .62 r
.48426 .34208 .49121 .39148 .50468 .37969 .49759 .33244 Mtetra
.619 .444 .623 r
.49759 .33244 .50468 .37969 .51815 .36648 .51096 .32174 Mtetra
.629 .455 .628 r
.51096 .32174 .51815 .36648 .53162 .35216 .52433 .31018 Mtetra
.639 .467 .634 r
.52433 .31018 .53162 .35216 .54506 .33708 .53771 .29802 Mtetra
.648 .479 .641 r
.53771 .29802 .54506 .33708 .55847 .32164 .55108 .28557 Mtetra
.655 .491 .65 r
.55108 .28557 .55847 .32164 .57186 .30637 .56446 .27325 Mtetra
.657 .501 .66 r
.56446 .27325 .57186 .30637 .58524 .292 .57785 .2617 Mtetra
.65 .506 .674 r
.57785 .2617 .58524 .292 .59865 .27961 .59128 .25187 Mtetra
.626 .502 .692 r
.59128 .25187 .59865 .27961 .61216 .27063 .60481 .24508 Mtetra
.571 .48 .712 r
.60481 .24508 .61216 .27063 .62586 .26673 .61853 .24285 Mtetra
.47 .429 .73 r
.61853 .24285 .62586 .26673 .63987 .26913 .63255 .24633 Mtetra
.333 .351 .73 r
.63255 .24633 .63987 .26913 .65428 .2778 .64693 .25547 Mtetra
.23 .29 .718 r
.64693 .25547 .65428 .2778 .66906 .29046 .66167 .26816 Mtetra
.254 .307 .725 r
.66167 .26816 .66906 .29046 .68405 .30251 .6766 .2801 Mtetra
.416 .411 .746 r
.6766 .2801 .68405 .30251 .6989 .30809 .69143 .28585 Mtetra
.615 .534 .74 r
.69143 .28585 .6989 .30809 .71326 .30251 .70583 .28104 Mtetra
.755 .617 .706 r
.70583 .28104 .71326 .30251 .72687 .2845 .71955 .26453 Mtetra
.832 .664 .675 r
.71955 .26453 .72687 .2845 .73977 .25694 .73263 .23896 Mtetra
.868 .692 .661 r
.73263 .23896 .73977 .25694 .75222 .22524 .7453 .20941 Mtetra
.882 .714 .67 r
.7453 .20941 .75222 .22524 .76458 .19486 .75788 .18097 Mtetra
.877 .734 .7 r
.75788 .18097 .76458 .19486 .77719 .16933 .77068 .15698 Mtetra
.647 .716 .898 r
.13017 .34912 .13821 .35747 .14937 .35412 .14139 .34545 Mtetra
.642 .708 .895 r
.14139 .34545 .14937 .35412 .16056 .35096 .15264 .3419 Mtetra
.636 .697 .889 r
.15264 .3419 .16056 .35096 .17177 .34804 .16392 .3385 Mtetra
.629 .684 .883 r
.16392 .3385 .17177 .34804 .18301 .34543 .17524 .33529 Mtetra
.621 .668 .874 r
.17524 .33529 .18301 .34543 .19427 .34317 .1866 .33229 Mtetra
.611 .649 .863 r
.1866 .33229 .19427 .34317 .20555 .34133 .19798 .32954 Mtetra
.601 .627 .85 r
.19798 .32954 .20555 .34133 .21685 .33996 .20939 .3271 Mtetra
.59 .603 .834 r
.20939 .3271 .21685 .33996 .22817 .33912 .22084 .32498 Mtetra
.578 .578 .816 r
.22084 .32498 .22817 .33912 .23952 .33885 .23232 .32322 Mtetra
.567 .551 .797 r
.23232 .32322 .23952 .33885 .25089 .33918 .24383 .32184 Mtetra
.556 .525 .776 r
.24383 .32184 .25089 .33918 .2623 .34014 .25538 .32086 Mtetra
.546 .5 .755 r
.25538 .32086 .2623 .34014 .27374 .34173 .26698 .32027 Mtetra
.538 .477 .735 r
.26698 .32027 .27374 .34173 .28524 .3439 .27862 .32006 Mtetra
.532 .456 .716 r
.27862 .32006 .28524 .3439 .2968 .34661 .29033 .32019 Mtetra
.528 .439 .698 r
.29033 .32019 .2968 .34661 .30844 .34976 .3021 .3206 Mtetra
.525 .424 .682 r
.3021 .3206 .30844 .34976 .32016 .35323 .31395 .32122 Mtetra
.524 .412 .668 r
.31395 .32122 .32016 .35323 .332 .35686 .32589 .32194 Mtetra
.525 .403 .656 r
.32589 .32194 .332 .35686 .34395 .36046 .33792 .32265 Mtetra
.527 .396 .646 r
.33792 .32265 .34395 .36046 .35603 .36384 .35006 .32322 Mtetra
.53 .392 .637 r
.35006 .32322 .35603 .36384 .36825 .36675 .3623 .32351 Mtetra
.535 .389 .63 r
.3623 .32351 .36825 .36675 .38062 .36898 .37466 .32336 Mtetra
.54 .389 .625 r
.37466 .32336 .38062 .36898 .39314 .3703 .38714 .32265 Mtetra
.545 .389 .62 r
.38714 .32265 .39314 .3703 .4058 .37051 .39974 .32123 Mtetra
.552 .391 .617 r
.39974 .32123 .4058 .37051 .4186 .36943 .41245 .31901 Mtetra
.558 .395 .616 r
.41245 .31901 .4186 .36943 .43154 .36694 .42527 .31588 Mtetra
.565 .399 .615 r
.42527 .31588 .43154 .36694 .44459 .36295 .43818 .3118 Mtetra
.573 .404 .615 r
.43818 .3118 .44459 .36295 .45774 .35745 .45119 .30675 Mtetra
.58 .41 .616 r
.45119 .30675 .45774 .35745 .47097 .35046 .46427 .30073 Mtetra
.588 .417 .618 r
.46427 .30073 .47097 .35046 .48426 .34208 .47742 .29381 Mtetra
.596 .425 .621 r
.47742 .29381 .48426 .34208 .49759 .33244 .49062 .28606 Mtetra
.603 .433 .625 r
.49062 .28606 .49759 .33244 .51096 .32174 .50386 .2776 Mtetra
.611 .443 .629 r
.50386 .2776 .51096 .32174 .52433 .31018 .51713 .26856 Mtetra
.619 .453 .635 r
.51713 .26856 .52433 .31018 .53771 .29802 .53043 .2591 Mtetra
.626 .464 .643 r
.53043 .2591 .53771 .29802 .55108 .28557 .54375 .24945 Mtetra
.631 .474 .652 r
.54375 .24945 .55108 .28557 .56446 .27325 .5571 .23994 Mtetra
.632 .483 .662 r
.5571 .23994 .56446 .27325 .57785 .2617 .57048 .23109 Mtetra
.624 .488 .676 r
.57048 .23109 .57785 .2617 .59128 .25187 .58392 .22374 Mtetra
.599 .483 .692 r
.58392 .22374 .59128 .25187 .60481 .24508 .59747 .21909 Mtetra
.544 .46 .711 r
.59747 .21909 .60481 .24508 .61853 .24285 .6112 .21851 Mtetra
.447 .411 .725 r
.6112 .21851 .61853 .24285 .63255 .24633 .62521 .22306 Mtetra
.321 .339 .724 r
.62521 .22306 .63255 .24633 .64693 .25547 .63956 .23268 Mtetra
.231 .286 .714 r
.63956 .23268 .64693 .25547 .66167 .26816 .65425 .24542 Mtetra
.258 .306 .722 r
.65425 .24542 .66167 .26816 .6766 .2801 .66913 .25728 Mtetra
.411 .405 .742 r
.66913 .25728 .6766 .2801 .69143 .28585 .68394 .26323 Mtetra
.601 .523 .739 r
.68394 .26323 .69143 .28585 .70583 .28104 .69836 .25924 Mtetra
.739 .607 .71 r
.69836 .25924 .70583 .28104 .71955 .26453 .7122 .24425 Mtetra
.818 .656 .682 r
.7122 .24425 .71955 .26453 .73263 .23896 .72546 .22071 Mtetra
.856 .686 .67 r
.72546 .22071 .73263 .23896 .7453 .20941 .73833 .19333 Mtetra
.871 .71 .68 r
.73833 .19333 .7453 .20941 .75788 .18097 .75113 .16686 Mtetra
.866 .73 .71 r
.75113 .16686 .75788 .18097 .77068 .15698 .76413 .14443 Mtetra
.654 .724 .9 r
.12205 .34092 .13017 .34912 .14139 .34545 .13331 .33701 Mtetra
.651 .718 .897 r
.13331 .33701 .14139 .34545 .15264 .3419 .14462 .33316 Mtetra
.648 .71 .893 r
.14462 .33316 .15264 .3419 .16392 .3385 .15597 .32938 Mtetra
.644 .7 .887 r
.15597 .32938 .16392 .3385 .17524 .33529 .16736 .3257 Mtetra
.639 .688 .88 r
.16736 .3257 .17524 .33529 .1866 .33229 .17879 .32214 Mtetra
.633 .674 .872 r
.17879 .32214 .1866 .33229 .19798 .32954 .19026 .31871 Mtetra
.626 .658 .861 r
.19026 .31871 .19798 .32954 .20939 .3271 .20177 .31543 Mtetra
.619 .639 .849 r
.20177 .31543 .20939 .3271 .22084 .32498 .21331 .31234 Mtetra
.611 .619 .834 r
.21331 .31234 .22084 .32498 .23232 .32322 .2249 .30944 Mtetra
.603 .597 .818 r
.2249 .30944 .23232 .32322 .24383 .32184 .23654 .30675 Mtetra
.594 .574 .801 r
.23654 .30675 .24383 .32184 .25538 .32086 .24821 .30428 Mtetra
.586 .552 .783 r
.24821 .30428 .25538 .32086 .26698 .32027 .25994 .30202 Mtetra
.579 .53 .764 r
.25994 .30202 .26698 .32027 .27862 .32006 .27171 .29997 Mtetra
.572 .509 .746 r
.27171 .29997 .27862 .32006 .29033 .32019 .28355 .29811 Mtetra
.567 .49 .729 r
.28355 .29811 .29033 .32019 .3021 .3206 .29544 .2964 Mtetra
.562 .474 .713 r
.29544 .2964 .3021 .3206 .31395 .32122 .3074 .29481 Mtetra
.559 .46 .698 r
.3074 .29481 .31395 .32122 .32589 .32194 .31944 .29328 Mtetra
.557 .448 .685 r
.31944 .29328 .32589 .32194 .33792 .32265 .33155 .29174 Mtetra
.556 .438 .673 r
.33155 .29174 .33792 .32265 .35006 .32322 .34374 .29012 Mtetra
.557 .43 .664 r
.34374 .29012 .35006 .32322 .3623 .32351 .35603 .28834 Mtetra
.558 .425 .656 r
.35603 .28834 .3623 .32351 .37466 .32336 .3684 .28631 Mtetra
.56 .421 .649 r
.3684 .28631 .37466 .32336 .38714 .32265 .38087 .28397 Mtetra
.563 .419 .644 r
.38087 .28397 .38714 .32265 .39974 .32123 .39343 .28122 Mtetra
.566 .418 .64 r
.39343 .28122 .39974 .32123 .41245 .31901 .40608 .27802 Mtetra
.57 .419 .637 r
.40608 .27802 .41245 .31901 .42527 .31588 .41882 .2743 Mtetra
.574 .421 .636 r
.41882 .2743 .42527 .31588 .43818 .3118 .43164 .27004 Mtetra
.579 .424 .635 r
.43164 .27004 .43818 .3118 .45119 .30675 .44454 .26522 Mtetra
.585 .428 .636 r
.44454 .26522 .45119 .30675 .46427 .30073 .45751 .25984 Mtetra
.59 .434 .638 r
.45751 .25984 .46427 .30073 .47742 .29381 .47055 .25393 Mtetra
.596 .44 .641 r
.47055 .25393 .47742 .29381 .49062 .28606 .48365 .24753 Mtetra
.602 .447 .645 r
.48365 .24753 .49062 .28606 .50386 .2776 .49679 .2407 Mtetra
.608 .456 .65 r
.49679 .2407 .50386 .2776 .51713 .26856 .50999 .23353 Mtetra
.614 .465 .656 r
.50999 .23353 .51713 .26856 .53043 .2591 .52323 .2261 Mtetra
.62 .475 .664 r
.52323 .2261 .53043 .2591 .54375 .24945 .53651 .21858 Mtetra
.623 .485 .674 r
.53651 .21858 .54375 .24945 .5571 .23994 .54983 .21121 Mtetra
.622 .494 .685 r
.54983 .21121 .5571 .23994 .57048 .23109 .5632 .20444 Mtetra
.612 .498 .699 r
.5632 .20444 .57048 .23109 .58392 .22374 .57664 .199 Mtetra
.582 .491 .716 r
.57664 .199 .58392 .22374 .59747 .21909 .5902 .19596 Mtetra
.521 .465 .734 r
.5902 .19596 .59747 .21909 .6112 .21851 .60393 .19656 Mtetra
.416 .41 .745 r
.60393 .19656 .6112 .21851 .62521 .22306 .61793 .20178 Mtetra
.287 .335 .738 r
.61793 .20178 .62521 .22306 .63956 .23268 .63225 .21155 Mtetra
.203 .284 .724 r
.63225 .21155 .63956 .23268 .65425 .24542 .64688 .22404 Mtetra
.24 .307 .732 r
.64688 .22404 .65425 .24542 .66913 .25728 .66171 .23557 Mtetra
.4 .408 .753 r
.66171 .23557 .66913 .25728 .68394 .26323 .67648 .24151 Mtetra
.591 .525 .749 r
.67648 .24151 .68394 .26323 .69836 .25924 .69093 .23814 Mtetra
.731 .608 .72 r
.69093 .23814 .69836 .25924 .7122 .24425 .70487 .22449 Mtetra
.81 .656 .693 r
.70487 .22449 .7122 .24425 .72546 .22071 .71828 .20283 Mtetra
.849 .687 .682 r
.71828 .20283 .72546 .22071 .73833 .19333 .73136 .1775 Mtetra
.863 .711 .691 r
.73136 .1775 .73833 .19333 .75113 .16686 .74436 .15291 Mtetra
.858 .731 .722 r
.74436 .15291 .75113 .16686 .76413 .14443 .75753 .13197 Mtetra
.659 .731 .902 r
.11383 .33286 .12205 .34092 .13331 .33701 .12513 .32879 Mtetra
.657 .727 .9 r
.12513 .32879 .13331 .33701 .14462 .33316 .13649 .32474 Mtetra
.656 .722 .898 r
.13649 .32474 .14462 .33316 .15597 .32938 .14789 .32072 Mtetra
.653 .716 .894 r
.14789 .32072 .15597 .32938 .16736 .3257 .15933 .31673 Mtetra
.651 .708 .89 r
.15933 .31673 .16736 .3257 .17879 .32214 .17083 .31279 Mtetra
.647 .699 .884 r
.17083 .31279 .17879 .32214 .19026 .31871 .18236 .3089 Mtetra
.644 .688 .877 r
.18236 .3089 .19026 .31871 .20177 .31543 .19395 .30509 Mtetra
.64 .676 .868 r
.19395 .30509 .20177 .31543 .21331 .31234 .20558 .30136 Mtetra
.635 .661 .858 r
.20558 .30136 .21331 .31234 .2249 .30944 .21725 .29771 Mtetra
.63 .645 .847 r
.21725 .29771 .2249 .30944 .23654 .30675 .22898 .29416 Mtetra
.624 .628 .834 r
.22898 .29416 .23654 .30675 .24821 .30428 .24075 .29071 Mtetra
.619 .61 .82 r
.24075 .29071 .24821 .30428 .25994 .30202 .25257 .28736 Mtetra
.613 .592 .805 r
.25257 .28736 .25994 .30202 .27171 .29997 .26445 .2841 Mtetra
.607 .573 .79 r
.26445 .2841 .27171 .29997 .28355 .29811 .27638 .28093 Mtetra
.602 .556 .775 r
.27638 .28093 .28355 .29811 .29544 .2964 .28837 .27784 Mtetra
.597 .539 .76 r
.28837 .27784 .29544 .2964 .3074 .29481 .30042 .27479 Mtetra
.593 .524 .746 r
.30042 .27479 .3074 .29481 .31944 .29328 .31253 .27177 Mtetra
.59 .51 .733 r
.31253 .27177 .31944 .29328 .33155 .29174 .32471 .26874 Mtetra
.588 .499 .721 r
.32471 .26874 .33155 .29174 .34374 .29012 .33696 .26566 Mtetra
.586 .489 .71 r
.33696 .26566 .34374 .29012 .35603 .28834 .34929 .26249 Mtetra
.585 .481 .701 r
.34929 .26249 .35603 .28834 .3684 .28631 .36169 .2592 Mtetra
.585 .474 .694 r
.36169 .2592 .3684 .28631 .38087 .28397 .37416 .25574 Mtetra
.586 .47 .687 r
.37416 .25574 .38087 .28397 .39343 .28122 .38672 .25208 Mtetra
.587 .467 .682 r
.38672 .25208 .39343 .28122 .40608 .27802 .39934 .24817 Mtetra
.589 .465 .679 r
.39934 .24817 .40608 .27802 .41882 .2743 .41205 .244 Mtetra
.592 .465 .677 r
.41205 .244 .41882 .2743 .43164 .27004 .42482 .23955 Mtetra
.595 .467 .676 r
.42482 .23955 .43164 .27004 .44454 .26522 .43767 .2348 Mtetra
.598 .47 .676 r
.43767 .2348 .44454 .26522 .45751 .25984 .45058 .22976 Mtetra
.602 .474 .678 r
.45058 .22976 .45751 .25984 .47055 .25393 .46356 .22444 Mtetra
.607 .479 .681 r
.46356 .22444 .47055 .25393 .48365 .24753 .4766 .21885 Mtetra
.611 .486 .685 r
.4766 .21885 .48365 .24753 .49679 .2407 .4897 .21303 Mtetra
.616 .494 .691 r
.4897 .21303 .49679 .2407 .50999 .23353 .50285 .20703 Mtetra
.621 .503 .697 r
.50285 .20703 .50999 .23353 .52323 .2261 .51605 .20089 Mtetra
.625 .513 .706 r
.51605 .20089 .52323 .2261 .53651 .21858 .52931 .19472 Mtetra
.627 .522 .716 r
.52931 .19472 .53651 .21858 .54983 .21121 .54262 .18873 Mtetra
.623 .53 .728 r
.54262 .18873 .54983 .21121 .5632 .20444 .556 .18329 Mtetra
.608 .532 .743 r
.556 .18329 .5632 .20444 .57664 .199 .56945 .17904 Mtetra
.572 .521 .76 r
.56945 .17904 .57664 .199 .5902 .19596 .58301 .17694 Mtetra
.498 .489 .777 r
.58301 .17694 .5902 .19596 .60393 .19656 .59675 .17814 Mtetra
.379 .425 .782 r
.59675 .17814 .60393 .19656 .61793 .20178 .61073 .18349 Mtetra
.241 .34 .765 r
.61073 .18349 .61793 .20178 .63225 .21155 .62501 .19293 Mtetra
.164 .287 .744 r
.62501 .19293 .63225 .21155 .64688 .22404 .63959 .20478 Mtetra
.217 .316 .751 r
.63959 .20478 .64688 .22404 .66171 .23557 .65435 .21564 Mtetra
.39 .42 .771 r
.65435 .21564 .66171 .23557 .67648 .24151 .66909 .22125 Mtetra
.587 .536 .765 r
.66909 .22125 .67648 .24151 .69093 .23814 .68355 .21821 Mtetra
.727 .616 .733 r
.68355 .21821 .69093 .23814 .70487 .22449 .69757 .20564 Mtetra
.805 .662 .705 r
.69757 .20564 .70487 .22449 .71828 .20283 .71113 .18563 Mtetra
.844 .692 .694 r
.71113 .18563 .71828 .20283 .73136 .1775 .72438 .16216 Mtetra
.857 .715 .704 r
.72438 .16216 .73136 .1775 .74436 .15291 .73757 .13929 Mtetra
.851 .735 .734 r
.73757 .13929 .74436 .15291 .75753 .13197 .75092 .11972 Mtetra
.661 .736 .905 r
.10552 .32491 .11383 .33286 .12513 .32879 .11686 .32074 Mtetra
.661 .734 .904 r
.11686 .32074 .12513 .32879 .13649 .32474 .12826 .31656 Mtetra
.66 .731 .902 r
.12826 .31656 .13649 .32474 .14789 .32072 .1397 .31238 Mtetra
.659 .728 .9 r
.1397 .31238 .14789 .32072 .15933 .31673 .15119 .30821 Mtetra
.658 .724 .898 r
.15119 .30821 .15933 .31673 .17083 .31279 .16273 .30405 Mtetra
.656 .718 .894 r
.16273 .30405 .17083 .31279 .18236 .3089 .17432 .2999 Mtetra
.654 .712 .89 r
.17432 .2999 .18236 .3089 .19395 .30509 .18595 .29577 Mtetra
.652 .705 .886 r
.18595 .29577 .19395 .30509 .20558 .30136 .19764 .29167 Mtetra
.65 .696 .88 r
.19764 .29167 .20558 .30136 .21725 .29771 .20938 .28759 Mtetra
.647 .687 .873 r
.20938 .28759 .21725 .29771 .22898 .29416 .22117 .28355 Mtetra
.645 .676 .865 r
.22117 .28355 .22898 .29416 .24075 .29071 .23301 .27954 Mtetra
.641 .664 .856 r
.23301 .27954 .24075 .29071 .25257 .28736 .24491 .27556 Mtetra
.638 .651 .847 r
.24491 .27556 .25257 .28736 .26445 .2841 .25686 .27162 Mtetra
.635 .638 .836 r
.25686 .27162 .26445 .2841 .27638 .28093 .26886 .2677 Mtetra
.631 .625 .825 r
.26886 .2677 .27638 .28093 .28837 .27784 .28092 .26381 Mtetra
.628 .611 .814 r
.28092 .26381 .28837 .27784 .30042 .27479 .29304 .25993 Mtetra
.625 .598 .803 r
.29304 .25993 .30042 .27479 .31253 .27177 .30521 .25604 Mtetra
.622 .586 .792 r
.30521 .25604 .31253 .27177 .32471 .26874 .31745 .25215 Mtetra
.619 .575 .782 r
.31745 .25215 .32471 .26874 .33696 .26566 .32975 .24823 Mtetra
.617 .564 .773 r
.32975 .24823 .33696 .26566 .34929 .26249 .34212 .24425 Mtetra
.616 .556 .764 r
.34212 .24425 .34929 .26249 .36169 .2592 .35455 .24021 Mtetra
.615 .548 .756 r
.35455 .24021 .36169 .2592 .37416 .25574 .36705 .23609 Mtetra
.614 .542 .75 r
.36705 .23609 .37416 .25574 .38672 .25208 .37962 .23187 Mtetra
.615 .538 .745 r
.37962 .23187 .38672 .25208 .39934 .24817 .39225 .22752 Mtetra
.615 .535 .741 r
.39225 .22752 .39934 .24817 .41205 .244 .40495 .22305 Mtetra
.616 .534 .738 r
.40495 .22305 .41205 .244 .42482 .23955 .41772 .21844 Mtetra
.618 .534 .737 r
.41772 .21844 .42482 .23955 .43767 .2348 .43055 .21368 Mtetra
.62 .536 .737 r
.43055 .21368 .43767 .2348 .45058 .22976 .44345 .20878 Mtetra
.623 .538 .739 r
.44345 .20878 .45058 .22976 .46356 .22444 .45641 .20374 Mtetra
.626 .543 .741 r
.45641 .20374 .46356 .22444 .4766 .21885 .46943 .19857 Mtetra
.629 .549 .745 r
.46943 .19857 .4766 .21885 .4897 .21303 .48251 .19328 Mtetra
.632 .555 .75 r
.48251 .19328 .4897 .21303 .50285 .20703 .49565 .1879 Mtetra
.635 .563 .757 r
.49565 .1879 .50285 .20703 .51605 .20089 .50886 .18245 Mtetra
.637 .572 .764 r
.50886 .18245 .51605 .20089 .52931 .19472 .52212 .17702 Mtetra
.637 .58 .774 r
.52212 .17702 .52931 .19472 .54262 .18873 .53544 .17177 Mtetra
.63 .585 .785 r
.53544 .17177 .54262 .18873 .556 .18329 .54883 .16702 Mtetra
.61 .584 .799 r
.54883 .16702 .556 .18329 .56945 .17904 .56229 .16336 Mtetra
.564 .569 .816 r
.56229 .16336 .56945 .17904 .58301 .17694 .57587 .16165 Mtetra
.478 .527 .83 r
.57587 .16165 .58301 .17694 .59675 .17814 .58962 .16291 Mtetra
.344 .45 .826 r
.58962 .16291 .59675 .17814 .61073 .18349 .60358 .16795 Mtetra
.201 .356 .796 r
.60358 .16795 .61073 .18349 .62501 .19293 .61783 .17667 Mtetra
.134 .301 .769 r
.61783 .17667 .62501 .19293 .63959 .20478 .63235 .18753 Mtetra
.203 .334 .775 r
.63235 .18753 .63959 .20478 .65435 .21564 .64705 .19741 Mtetra
.387 .439 .793 r
.64705 .19741 .65435 .21564 .66909 .22125 .66175 .20241 Mtetra
.587 .551 .781 r
.66175 .20241 .66909 .22125 .68355 .21821 .67622 .19945 Mtetra
.725 .626 .747 r
.67622 .19945 .68355 .21821 .69757 .20564 .6903 .18772 Mtetra
.802 .67 .717 r
.6903 .18772 .69757 .20564 .71113 .18563 .70399 .16913 Mtetra
.84 .698 .706 r
.70399 .16913 .71113 .18563 .72438 .16216 .71741 .14732 Mtetra
.852 .72 .717 r
.71741 .14732 .72438 .16216 .73757 .13929 .73077 .12601 Mtetra
.845 .739 .747 r
.73077 .12601 .73757 .13929 .75092 .11972 .74427 .10769 Mtetra
.663 .739 .906 r
.09713 .317 .10552 .32491 .11686 .32074 .10851 .31276 Mtetra
.662 .738 .906 r
.10851 .31276 .11686 .32074 .12826 .31656 .11993 .3085 Mtetra
.662 .737 .905 r
.11993 .3085 .12826 .31656 .1397 .31238 .13141 .30423 Mtetra
.662 .735 .904 r
.13141 .30423 .1397 .31238 .15119 .30821 .14294 .29996 Mtetra
.661 .733 .903 r
.14294 .29996 .15119 .30821 .16273 .30405 .15451 .29567 Mtetra
.661 .731 .901 r
.15451 .29567 .16273 .30405 .17432 .2999 .16614 .29138 Mtetra
.66 .728 .899 r
.16614 .29138 .17432 .2999 .18595 .29577 .17782 .28708 Mtetra
.659 .724 .897 r
.17782 .28708 .18595 .29577 .19764 .29167 .18956 .28278 Mtetra
.658 .72 .894 r
.18956 .28278 .19764 .29167 .20938 .28759 .20134 .27848 Mtetra
.657 .715 .891 r
.20134 .27848 .20938 .28759 .22117 .28355 .21318 .27418 Mtetra
.656 .709 .887 r
.21318 .27418 .22117 .28355 .23301 .27954 .22507 .26988 Mtetra
.654 .703 .882 r
.22507 .26988 .23301 .27954 .24491 .27556 .23702 .26558 Mtetra
.653 .696 .877 r
.23702 .26558 .24491 .27556 .25686 .27162 .24902 .26128 Mtetra
.651 .688 .872 r
.24902 .26128 .25686 .27162 .26886 .2677 .26108 .25698 Mtetra
.65 .68 .866 r
.26108 .25698 .26886 .2677 .28092 .26381 .27319 .25268 Mtetra
.648 .672 .859 r
.27319 .25268 .28092 .26381 .29304 .25993 .28536 .24837 Mtetra
.647 .664 .853 r
.28536 .24837 .29304 .25993 .30521 .25604 .29759 .24405 Mtetra
.645 .656 .846 r
.29759 .24405 .30521 .25604 .31745 .25215 .30987 .23971 Mtetra
.644 .648 .839 r
.30987 .23971 .31745 .25215 .32975 .24823 .32222 .23535 Mtetra
.642 .64 .833 r
.32222 .23535 .32975 .24823 .34212 .24425 .33463 .23095 Mtetra
.641 .633 .827 r
.33463 .23095 .34212 .24425 .35455 .24021 .34709 .22652 Mtetra
.64 .627 .821 r
.34709 .22652 .35455 .24021 .36705 .23609 .35962 .22204 Mtetra
.64 .622 .817 r
.35962 .22204 .36705 .23609 .37962 .23187 .37222 .21751 Mtetra
.64 .618 .813 r
.37222 .21751 .37962 .23187 .39225 .22752 .38487 .21292 Mtetra
.64 .615 .81 r
.38487 .21292 .39225 .22752 .40495 .22305 .39759 .20826 Mtetra
.64 .614 .807 r
.39759 .20826 .40495 .22305 .41772 .21844 .41037 .20354 Mtetra
.641 .613 .806 r
.41037 .20354 .41772 .21844 .43055 .21368 .42322 .19874 Mtetra
.642 .614 .806 r
.42322 .19874 .43055 .21368 .44345 .20878 .43613 .19388 Mtetra
.643 .615 .807 r
.43613 .19388 .44345 .20878 .45641 .20374 .4491 .18894 Mtetra
.645 .618 .809 r
.4491 .18894 .45641 .20374 .46943 .19857 .46213 .18394 Mtetra
.647 .622 .811 r
.46213 .18394 .46943 .19857 .48251 .19328 .47523 .17887 Mtetra
.648 .627 .815 r
.47523 .17887 .48251 .19328 .49565 .1879 .48838 .17376 Mtetra
.65 .633 .82 r
.48838 .17376 .49565 .1879 .50886 .18245 .5016 .16862 Mtetra
.65 .638 .825 r
.5016 .16862 .50886 .18245 .52212 .17702 .51488 .16352 Mtetra
.647 .643 .832 r
.51488 .16352 .52212 .17702 .53544 .17177 .52823 .15859 Mtetra
.637 .645 .841 r
.52823 .15859 .53544 .17177 .54883 .16702 .54164 .15413 Mtetra
.612 .639 .853 r
.54164 .15413 .54883 .16702 .56229 .16336 .55514 .15065 Mtetra
.56 .618 .867 r
.55514 .15065 .56229 .16336 .57587 .16165 .56874 .14894 Mtetra
.465 .569 .876 r
.56874 .14894 .57587 .16165 .58962 .16291 .58249 .14994 Mtetra
.324 .483 .863 r
.58249 .14994 .58962 .16291 .60358 .16795 .59645 .15436 Mtetra
.184 .383 .825 r
.59645 .15436 .60358 .16795 .61783 .17667 .61066 .1621 Mtetra
.129 .328 .794 r
.61066 .1621 .61783 .17667 .63235 .18753 .62513 .17176 Mtetra
.208 .361 .798 r
.62513 .17176 .63235 .18753 .64705 .19741 .63977 .18046 Mtetra
.395 .462 .812 r
.63977 .18046 .64705 .19741 .66175 .20241 .65443 .18469 Mtetra
.59 .566 .795 r
.65443 .18469 .66175 .20241 .67622 .19945 .66891 .18162 Mtetra
.723 .635 .759 r
.66891 .18162 .67622 .19945 .6903 .18772 .68305 .17055 Mtetra
.798 .676 .729 r
.68305 .17055 .6903 .18772 .70399 .16913 .69685 .1532 Mtetra
.834 .703 .719 r
.69685 .1532 .70399 .16913 .71741 .14732 .71042 .13289 Mtetra
.846 .725 .729 r
.71042 .13289 .71741 .14732 .73077 .12601 .72395 .11301 Mtetra
.838 .743 .759 r
.72395 .11301 .73077 .12601 .74427 .10769 .7376 .09583 Mtetra
.663 .74 .907 r
.08867 .30908 .09713 .317 .10851 .31276 .10007 .30479 Mtetra
.10007 .30479 .10851 .31276 .11993 .3085 .11153 .30048 Mtetra
.663 .739 .907 r
.11153 .30048 .11993 .3085 .13141 .30423 .12304 .29615 Mtetra
.663 .739 .906 r
.12304 .29615 .13141 .30423 .14294 .29996 .1346 .29181 Mtetra
.663 .738 .906 r
.1346 .29181 .14294 .29996 .15451 .29567 .14621 .28745 Mtetra
.662 .737 .905 r
.14621 .28745 .15451 .29567 .16614 .29138 .15787 .28308 Mtetra
.662 .736 .904 r
.15787 .28308 .16614 .29138 .17782 .28708 .16959 .27869 Mtetra
.662 .734 .903 r
.16959 .27869 .17782 .28708 .18956 .28278 .18136 .27428 Mtetra
.662 .732 .902 r
.18136 .27428 .18956 .28278 .20134 .27848 .19318 .26987 Mtetra
.661 .73 .901 r
.19318 .26987 .20134 .27848 .21318 .27418 .20506 .26544 Mtetra
.661 .728 .899 r
.20506 .26544 .21318 .27418 .22507 .26988 .21699 .26099 Mtetra
.66 .725 .897 r
.21699 .26099 .22507 .26988 .23702 .26558 .22898 .25653 Mtetra
.66 .722 .895 r
.22898 .25653 .23702 .26558 .24902 .26128 .24102 .25206 Mtetra
.659 .719 .892 r
.24102 .25206 .24902 .26128 .26108 .25698 .25312 .24758 Mtetra
.659 .715 .89 r
.25312 .24758 .26108 .25698 .27319 .25268 .26527 .24308 Mtetra
.658 .711 .887 r
.26527 .24308 .27319 .25268 .28536 .24837 .27748 .23857 Mtetra
.657 .707 .884 r
.27748 .23857 .28536 .24837 .29759 .24405 .28975 .23403 Mtetra
.657 .703 .881 r
.28975 .23403 .29759 .24405 .30987 .23971 .30208 .22948 Mtetra
.656 .699 .877 r
.30208 .22948 .30987 .23971 .32222 .23535 .31447 .2249 Mtetra
.656 .695 .874 r
.31447 .2249 .32222 .23535 .33463 .23095 .32691 .2203 Mtetra
.655 .691 .871 r
.32691 .2203 .33463 .23095 .34709 .22652 .33942 .21568 Mtetra
.655 .688 .868 r
.33942 .21568 .34709 .22652 .35962 .22204 .35198 .21102 Mtetra
.655 .685 .866 r
.35198 .21102 .35962 .22204 .37222 .21751 .36461 .20633 Mtetra
.655 .682 .864 r
.36461 .20633 .37222 .21751 .38487 .21292 .37729 .2016 Mtetra
.655 .68 .862 r
.37729 .2016 .38487 .21292 .39759 .20826 .39004 .19684 Mtetra
.655 .679 .861 r
.39004 .19684 .39759 .20826 .41037 .20354 .40285 .19204 Mtetra
.655 .679 .86 r
.40285 .19204 .41037 .20354 .42322 .19874 .41573 .18719 Mtetra
.656 .679 .86 r
.41573 .18719 .42322 .19874 .43613 .19388 .42866 .18231 Mtetra
.42866 .18231 .43613 .19388 .4491 .18894 .44166 .17739 Mtetra
.657 .681 .861 r
.44166 .17739 .4491 .18894 .46213 .18394 .45472 .17242 Mtetra
.658 .683 .862 r
.45472 .17242 .46213 .18394 .47523 .17887 .46784 .16743 Mtetra
.658 .685 .864 r
.46784 .16743 .47523 .17887 .48838 .17376 .48103 .1624 Mtetra
.658 .688 .867 r
.48103 .1624 .48838 .17376 .5016 .16862 .49428 .15736 Mtetra
.657 .691 .87 r
.49428 .15736 .5016 .16862 .51488 .16352 .50759 .15237 Mtetra
.653 .692 .874 r
.50759 .15237 .51488 .16352 .52823 .15859 .52097 .14754 Mtetra
.641 .69 .881 r
.52097 .14754 .52823 .15859 .54164 .15413 .53442 .14313 Mtetra
.614 .681 .89 r
.53442 .14313 .54164 .15413 .55514 .15065 .54795 .13962 Mtetra
.559 .656 .9 r
.54795 .13962 .55514 .15065 .56874 .14894 .56157 .13771 Mtetra
.464 .603 .905 r
.56157 .13771 .56874 .14894 .58249 .14994 .57534 .13826 Mtetra
.328 .516 .889 r
.57534 .13826 .58249 .14994 .59645 .15436 .5893 .1419 Mtetra
.198 .418 .85 r
.5893 .1419 .59645 .15436 .61066 .1621 .60348 .14854 Mtetra
.151 .365 .819 r
.60348 .14854 .61066 .1621 .62513 .17176 .61791 .15689 Mtetra
.232 .394 .819 r
.61791 .15689 .62513 .17176 .63977 .18046 .6325 .16435 Mtetra
.411 .485 .826 r
.6325 .16435 .63977 .18046 .65443 .18469 .64712 .16772 Mtetra
.594 .579 .806 r
.64712 .16772 .65443 .18469 .66891 .18162 .6616 .16445 Mtetra
.721 .642 .769 r
.6616 .16445 .66891 .18162 .68305 .17055 .6758 .15392 Mtetra
.792 .68 .741 r
.6758 .15392 .68305 .17055 .69685 .1532 .68971 .13768 Mtetra
.828 .706 .731 r
.68971 .13768 .69685 .1532 .71042 .13289 .70342 .11875 Mtetra
.839 .727 .742 r
.70342 .11875 .71042 .13289 .72395 .11301 .71709 .10018 Mtetra
.829 .745 .77 r
.71709 .10018 .72395 .11301 .7376 .09583 .73088 .08406 Mtetra
.663 .741 .908 r
.08013 .30111 .08867 .30908 .10007 .30479 .09156 .29678 Mtetra
.09156 .29678 .10007 .30479 .11153 .30048 .10305 .29243 Mtetra
.663 .741 .907 r
.10305 .29243 .11153 .30048 .12304 .29615 .11459 .28806 Mtetra
.663 .74 .907 r
.11459 .28806 .12304 .29615 .1346 .29181 .12618 .28367 Mtetra
.12618 .28367 .1346 .29181 .14621 .28745 .13782 .27926 Mtetra
.13782 .27926 .14621 .28745 .15787 .28308 .14951 .27483 Mtetra
.663 .739 .907 r
.14951 .27483 .15787 .28308 .16959 .27869 .16126 .27039 Mtetra
.663 .739 .906 r
.16126 .27039 .16959 .27869 .18136 .27428 .17307 .26592 Mtetra
.663 .738 .906 r
.17307 .26592 .18136 .27428 .19318 .26987 .18492 .26144 Mtetra
.663 .737 .905 r
.18492 .26144 .19318 .26987 .20506 .26544 .19684 .25693 Mtetra
.663 .736 .905 r
.19684 .25693 .20506 .26544 .21699 .26099 .2088 .25241 Mtetra
.662 .735 .904 r
.2088 .25241 .21699 .26099 .22898 .25653 .22083 .24787 Mtetra
.662 .734 .903 r
.22083 .24787 .22898 .25653 .24102 .25206 .2329 .24332 Mtetra
.662 .733 .902 r
.2329 .24332 .24102 .25206 .25312 .24758 .24504 .23874 Mtetra
.662 .732 .901 r
.24504 .23874 .25312 .24758 .26527 .24308 .25723 .23414 Mtetra
.662 .73 .9 r
.25723 .23414 .26527 .24308 .27748 .23857 .26948 .22952 Mtetra
.662 .728 .899 r
.26948 .22952 .27748 .23857 .28975 .23403 .28179 .22489 Mtetra
.661 .727 .898 r
.28179 .22489 .28975 .23403 .30208 .22948 .29415 .22023 Mtetra
.661 .725 .897 r
.29415 .22023 .30208 .22948 .31447 .2249 .30657 .21555 Mtetra
.661 .724 .895 r
.30657 .21555 .31447 .2249 .32691 .2203 .31905 .21084 Mtetra
.661 .722 .894 r
.31905 .21084 .32691 .2203 .33942 .21568 .3316 .20612 Mtetra
.661 .721 .893 r
.3316 .20612 .33942 .21568 .35198 .21102 .3442 .20136 Mtetra
.661 .719 .892 r
.3442 .20136 .35198 .21102 .36461 .20633 .35686 .19658 Mtetra
.661 .718 .891 r
.35686 .19658 .36461 .20633 .37729 .2016 .36958 .19178 Mtetra
.661 .717 .89 r
.36958 .19178 .37729 .2016 .39004 .19684 .38236 .18695 Mtetra
.38236 .18695 .39004 .19684 .40285 .19204 .39521 .18208 Mtetra
.661 .716 .889 r
.39521 .18208 .40285 .19204 .41573 .18719 .40812 .17719 Mtetra
.40812 .17719 .41573 .18719 .42866 .18231 .42109 .17228 Mtetra
.661 .717 .889 r
.42109 .17228 .42866 .18231 .44166 .17739 .43412 .16733 Mtetra
.662 .717 .89 r
.43412 .16733 .44166 .17739 .45472 .17242 .44722 .16235 Mtetra
.662 .718 .89 r
.44722 .16235 .45472 .17242 .46784 .16743 .46037 .15735 Mtetra
.662 .719 .891 r
.46037 .15735 .46784 .16743 .48103 .1624 .4736 .15232 Mtetra
.661 .72 .892 r
.4736 .15232 .48103 .1624 .49428 .15736 .48689 .14729 Mtetra
.66 .72 .894 r
.48689 .14729 .49428 .15736 .50759 .15237 .50024 .1423 Mtetra
.655 .72 .896 r
.50024 .1423 .50759 .15237 .52097 .14754 .51365 .13746 Mtetra
.643 .716 .901 r
.51365 .13746 .52097 .14754 .53442 .14313 .52714 .13301 Mtetra
.616 .705 .908 r
.52714 .13301 .53442 .14313 .54795 .13962 .5407 .12936 Mtetra
.565 .679 .917 r
.5407 .12936 .54795 .13962 .56157 .13771 .55436 .12716 Mtetra
.476 .629 .92 r
.55436 .12716 .56157 .13771 .57534 .13826 .56815 .12718 Mtetra
.352 .547 .905 r
.56815 .12718 .57534 .13826 .5893 .1419 .5821 .12999 Mtetra
.234 .456 .87 r
.5821 .12999 .5893 .1419 .60348 .14854 .59627 .13551 Mtetra
.193 .405 .841 r
.59627 .13551 .60348 .14854 .61791 .15689 .61066 .14255 Mtetra
.269 .428 .837 r
.61066 .14255 .61791 .15689 .6325 .16435 .62521 .14876 Mtetra
.431 .507 .836 r
.62521 .14876 .6325 .16435 .64712 .16772 .6398 .15125 Mtetra
.599 .589 .813 r
.6398 .15125 .64712 .16772 .6616 .16445 .65428 .14775 Mtetra
.717 .647 .778 r
.65428 .14775 .6616 .16445 .6758 .15392 .66853 .13768 Mtetra
.786 .683 .751 r
.66853 .13768 .6758 .15392 .68971 .13768 .68254 .12247 Mtetra
.82 .709 .742 r
.68254 .12247 .68971 .13768 .70342 .11875 .69638 .10481 Mtetra
.83 .729 .753 r
.69638 .10481 .70342 .11875 .71709 .10018 .7102 .08748 Mtetra
.82 .745 .781 r
.7102 .08748 .71709 .10018 .73088 .08406 .72412 .07234 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29678 .08298 .28872 Mtetra
.08298 .28872 .09156 .29678 .10305 .29243 .09449 .28433 Mtetra
.09449 .28433 .10305 .29243 .11459 .28806 .10606 .27992 Mtetra
.663 .741 .908 r
.10606 .27992 .11459 .28806 .12618 .28367 .11768 .27549 Mtetra
.11768 .27549 .12618 .28367 .13782 .27926 .12935 .27104 Mtetra
.12935 .27104 .13782 .27926 .14951 .27483 .14108 .26657 Mtetra
.663 .741 .907 r
.14108 .26657 .14951 .27483 .16126 .27039 .15286 .26208 Mtetra
.15286 .26208 .16126 .27039 .17307 .26592 .1647 .25757 Mtetra
.663 .74 .907 r
.1647 .25757 .17307 .26592 .18492 .26144 .17659 .25304 Mtetra
.17659 .25304 .18492 .26144 .19684 .25693 .18853 .24848 Mtetra
.18853 .24848 .19684 .25693 .2088 .25241 .20053 .24391 Mtetra
.663 .739 .907 r
.20053 .24391 .2088 .25241 .22083 .24787 .21259 .23932 Mtetra
.663 .739 .906 r
.21259 .23932 .22083 .24787 .2329 .24332 .2247 .2347 Mtetra
.2247 .2347 .2329 .24332 .24504 .23874 .23687 .23007 Mtetra
.663 .738 .906 r
.23687 .23007 .24504 .23874 .25723 .23414 .24909 .22541 Mtetra
.663 .738 .905 r
.24909 .22541 .25723 .23414 .26948 .22952 .26138 .22074 Mtetra
.663 .737 .905 r
.26138 .22074 .26948 .22952 .28179 .22489 .27372 .21604 Mtetra
.27372 .21604 .28179 .22489 .29415 .22023 .28612 .21132 Mtetra
.663 .736 .904 r
.28612 .21132 .29415 .22023 .30657 .21555 .29858 .20657 Mtetra
.663 .735 .904 r
.29858 .20657 .30657 .21555 .31905 .21084 .3111 .20181 Mtetra
.663 .735 .903 r
.3111 .20181 .31905 .21084 .3316 .20612 .32367 .19702 Mtetra
.663 .734 .903 r
.32367 .19702 .3316 .20612 .3442 .20136 .33631 .1922 Mtetra
.33631 .1922 .3442 .20136 .35686 .19658 .34901 .18737 Mtetra
.663 .734 .902 r
.34901 .18737 .35686 .19658 .36958 .19178 .36177 .18251 Mtetra
.663 .733 .902 r
.36177 .18251 .36958 .19178 .38236 .18695 .37459 .17762 Mtetra
.37459 .17762 .38236 .18695 .39521 .18208 .38747 .17271 Mtetra
.38747 .17271 .39521 .18208 .40812 .17719 .40042 .16778 Mtetra
.40042 .16778 .40812 .17719 .42109 .17228 .41343 .16281 Mtetra
.41343 .16281 .42109 .17228 .43412 .16733 .4265 .15783 Mtetra
.4265 .15783 .43412 .16733 .44722 .16235 .43963 .15282 Mtetra
.43963 .15282 .44722 .16235 .46037 .15735 .45283 .14778 Mtetra
.663 .734 .902 r
.45283 .14778 .46037 .15735 .4736 .15232 .46609 .14273 Mtetra
.662 .734 .903 r
.46609 .14273 .4736 .15232 .48689 .14729 .47942 .13766 Mtetra
.661 .734 .904 r
.47942 .13766 .48689 .14729 .50024 .1423 .49281 .13264 Mtetra
.656 .732 .906 r
.49281 .13264 .50024 .1423 .51365 .13746 .50627 .12775 Mtetra
.645 .728 .909 r
.50627 .12775 .51365 .13746 .52714 .13301 .5198 .1232 Mtetra
.62 .717 .915 r
.5198 .1232 .52714 .13301 .5407 .12936 .5334 .11938 Mtetra
.573 .693 .922 r
.5334 .11938 .5407 .12936 .55436 .12716 .54709 .11686 Mtetra
.494 .647 .926 r
.54709 .11686 .55436 .12716 .56815 .12718 .5609 .11634 Mtetra
.384 .574 .914 r
.5609 .11634 .56815 .12718 .5821 .12999 .57486 .11833 Mtetra
.28 .493 .886 r
.57486 .11833 .5821 .12999 .59627 .13551 .58902 .12275 Mtetra
.243 .445 .859 r
.58902 .12275 .59627 .13551 .61066 .14255 .60338 .12851 Mtetra
.309 .462 .85 r
.60338 .12851 .61066 .14255 .62521 .14876 .61789 .13352 Mtetra
.453 .527 .843 r
.61789 .13352 .62521 .14876 .6398 .15125 .63246 .13516 Mtetra
.604 .599 .819 r
.63246 .13516 .6398 .15125 .65428 .14775 .64695 .13142 Mtetra
.714 .651 .785 r
.64695 .13142 .65428 .14775 .66853 .13768 .66125 .12177 Mtetra
.779 .685 .76 r
.66125 .12177 .66853 .13768 .68254 .12247 .67535 .1075 Mtetra
.811 .71 .753 r
.67535 .1075 .68254 .12247 .69638 .10481 .68932 .09103 Mtetra
.821 .73 .765 r
.68932 .09103 .69638 .10481 .7102 .08748 .70326 .07485 Mtetra
.81 .745 .792 r
.70326 .07485 .7102 .08748 .72412 .07234 .71731 .06063 Mtetra
.664 .741 .908 r
.06283 .28501 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27549 .10911 .26725 Mtetra
.10911 .26725 .11768 .27549 .12935 .27104 .12082 .26276 Mtetra
.12082 .26276 .12935 .27104 .14108 .26657 .13257 .25825 Mtetra
.13257 .25825 .14108 .26657 .15286 .26208 .14438 .25372 Mtetra
.14438 .25372 .15286 .26208 .1647 .25757 .15625 .24917 Mtetra
.15625 .24917 .1647 .25757 .17659 .25304 .16817 .2446 Mtetra
.663 .741 .908 r
.16817 .2446 .17659 .25304 .18853 .24848 .18015 .24 Mtetra
.18015 .24 .18853 .24848 .20053 .24391 .19218 .23539 Mtetra
.19218 .23539 .20053 .24391 .21259 .23932 .20427 .23075 Mtetra
.663 .741 .907 r
.20427 .23075 .21259 .23932 .2247 .2347 .21642 .22609 Mtetra
.21642 .22609 .2247 .2347 .23687 .23007 .22862 .22141 Mtetra
.663 .74 .907 r
.22862 .22141 .23687 .23007 .24909 .22541 .24088 .21671 Mtetra
.24088 .21671 .24909 .22541 .26138 .22074 .2532 .21199 Mtetra
.2532 .21199 .26138 .22074 .27372 .21604 .26557 .20724 Mtetra
.26557 .20724 .27372 .21604 .28612 .21132 .27801 .20247 Mtetra
.27801 .20247 .28612 .21132 .29858 .20657 .2905 .19768 Mtetra
.2905 .19768 .29858 .20657 .3111 .20181 .30306 .19286 Mtetra
.663 .739 .907 r
.30306 .19286 .3111 .20181 .32367 .19702 .31567 .18803 Mtetra
.31567 .18803 .32367 .19702 .33631 .1922 .32835 .18317 Mtetra
.663 .739 .906 r
.32835 .18317 .33631 .1922 .34901 .18737 .34108 .17828 Mtetra
.34108 .17828 .34901 .18737 .36177 .18251 .35388 .17337 Mtetra
.35388 .17337 .36177 .18251 .37459 .17762 .36674 .16844 Mtetra
.36674 .16844 .37459 .17762 .38747 .17271 .37966 .16349 Mtetra
.37966 .16349 .38747 .17271 .40042 .16778 .39264 .15851 Mtetra
.39264 .15851 .40042 .16778 .41343 .16281 .40569 .1535 Mtetra
.40569 .1535 .41343 .16281 .4265 .15783 .4188 .14847 Mtetra
.4188 .14847 .4265 .15783 .43963 .15282 .43197 .14342 Mtetra
.43197 .14342 .43963 .15282 .45283 .14778 .44521 .13834 Mtetra
.44521 .13834 .45283 .14778 .46609 .14273 .45852 .13324 Mtetra
.663 .739 .907 r
.45852 .13324 .46609 .14273 .47942 .13766 .47188 .12813 Mtetra
.661 .738 .907 r
.47188 .12813 .47942 .13766 .49281 .13264 .48532 .12306 Mtetra
.657 .737 .909 r
.48532 .12306 .49281 .13264 .50627 .12775 .49882 .1181 Mtetra
.646 .732 .912 r
.49882 .1181 .50627 .12775 .5198 .1232 .51239 .11345 Mtetra
.625 .722 .917 r
.51239 .11345 .5198 .1232 .5334 .11938 .52603 .10945 Mtetra
.583 .701 .923 r
.52603 .10945 .5334 .11938 .54709 .11686 .53975 .10662 Mtetra
.513 .66 .927 r
.53975 .10662 .54709 .11686 .5609 .11634 .55359 .10557 Mtetra
.417 .597 .919 r
.55359 .10557 .5609 .11634 .57486 .11833 .56757 .10677 Mtetra
.326 .526 .897 r
.56757 .10677 .57486 .11833 .58902 .12275 .58172 .11013 Mtetra
.293 .482 .873 r
.58172 .11013 .58902 .12275 .60338 .12851 .59606 .11469 Mtetra
.35 .492 .861 r
.59606 .11469 .60338 .12851 .61789 .13352 .61054 .11855 Mtetra
.475 .546 .849 r
.61054 .11855 .61789 .13352 .63246 .13516 .62509 .1194 Mtetra
.609 .607 .824 r
.62509 .1194 .63246 .13516 .64695 .13142 .63959 .11542 Mtetra
.71 .654 .793 r
.63959 .11542 .64695 .13142 .66125 .12177 .65394 .10616 Mtetra
.771 .687 .77 r
.65394 .10616 .66125 .12177 .67535 .1075 .66813 .09276 Mtetra
.802 .711 .764 r
.66813 .09276 .67535 .1075 .68932 .09103 .68221 .0774 Mtetra
.811 .73 .776 r
.68221 .0774 .68932 .09103 .70326 .07485 .69628 .06228 Mtetra
.8 .745 .802 r
.69628 .06228 .70326 .07485 .71731 .06063 .71044 .04892 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .28501 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .2446 .15968 .23609 Mtetra
.15968 .23609 .16817 .2446 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23539 .18376 .2268 Mtetra
.18376 .2268 .19218 .23539 .20427 .23075 .19588 .22212 Mtetra
.19588 .22212 .20427 .23075 .21642 .22609 .20806 .21742 Mtetra
.20806 .21742 .21642 .22609 .22862 .22141 .2203 .2127 Mtetra
.2203 .2127 .22862 .22141 .24088 .21671 .23259 .20796 Mtetra
.23259 .20796 .24088 .21671 .2532 .21199 .24494 .20319 Mtetra
.24494 .20319 .2532 .21199 .26557 .20724 .25735 .1984 Mtetra
.25735 .1984 .26557 .20724 .27801 .20247 .26982 .19359 Mtetra
.26982 .19359 .27801 .20247 .2905 .19768 .28235 .18875 Mtetra
.28235 .18875 .2905 .19768 .30306 .19286 .29494 .1839 Mtetra
.663 .741 .908 r
.29494 .1839 .30306 .19286 .31567 .18803 .30759 .17901 Mtetra
.30759 .17901 .31567 .18803 .32835 .18317 .32031 .17411 Mtetra
.32031 .17411 .32835 .18317 .34108 .17828 .33308 .16918 Mtetra
.33308 .16918 .34108 .17828 .35388 .17337 .34591 .16423 Mtetra
.663 .741 .907 r
.34591 .16423 .35388 .17337 .36674 .16844 .35881 .15925 Mtetra
.35881 .15925 .36674 .16844 .37966 .16349 .37177 .15425 Mtetra
.37177 .15425 .37966 .16349 .39264 .15851 .38479 .14922 Mtetra
.38479 .14922 .39264 .15851 .40569 .1535 .39788 .14417 Mtetra
.39788 .14417 .40569 .1535 .4188 .14847 .41103 .1391 Mtetra
.41103 .1391 .4188 .14847 .43197 .14342 .42424 .134 Mtetra
.42424 .134 .43197 .14342 .44521 .13834 .43752 .12887 Mtetra
.663 .741 .908 r
.43752 .12887 .44521 .13834 .45852 .13324 .45087 .12373 Mtetra
.663 .74 .908 r
.45087 .12373 .45852 .13324 .47188 .12813 .46428 .11858 Mtetra
.661 .74 .908 r
.46428 .11858 .47188 .12813 .48532 .12306 .47776 .11345 Mtetra
.657 .738 .909 r
.47776 .11345 .48532 .12306 .49882 .1181 .4913 .10842 Mtetra
.648 .734 .912 r
.4913 .10842 .49882 .1181 .51239 .11345 .50491 .10366 Mtetra
.629 .725 .916 r
.50491 .10366 .51239 .11345 .52603 .10945 .51859 .09948 Mtetra
.592 .706 .923 r
.51859 .09948 .52603 .10945 .53975 .10662 .53235 .09635 Mtetra
.531 .671 .927 r
.53235 .09635 .53975 .10662 .55359 .10557 .54622 .0948 Mtetra
.449 .617 .922 r
.54622 .0948 .55359 .10557 .56757 .10677 .56021 .09525 Mtetra
.37 .555 .904 r
.56021 .09525 .56757 .10677 .58172 .11013 .57437 .09763 Mtetra
.339 .515 .884 r
.57437 .09763 .58172 .11013 .59606 .11469 .58869 .10106 Mtetra
.387 .52 .869 r
.58869 .10106 .59606 .11469 .61054 .11855 .60316 .10385 Mtetra
.495 .563 .854 r
.60316 .10385 .61054 .11855 .62509 .1194 .6177 .10394 Mtetra
.614 .616 .829 r
.6177 .10394 .62509 .1194 .63959 .11542 .63221 .09973 Mtetra
.706 .658 .8 r
.63221 .09973 .63959 .11542 .65394 .10616 .64661 .09083 Mtetra
.764 .689 .78 r
.64661 .09083 .65394 .10616 .66813 .09276 .66089 .07825 Mtetra
.793 .712 .775 r
.66089 .07825 .66813 .09276 .68221 .0774 .67507 .06391 Mtetra
.801 .731 .787 r
.67507 .06391 .68221 .0774 .69628 .06228 .68926 .04978 Mtetra
.79 .745 .811 r
.68926 .04978 .69628 .06228 .71044 .04892 .70353 .03722 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .1839 .28676 .17486 Mtetra
.28676 .17486 .29494 .1839 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .17411 .31219 .16498 Mtetra
.31219 .16498 .32031 .17411 .33308 .16918 .325 .16001 Mtetra
.325 .16001 .33308 .16918 .34591 .16423 .33788 .15501 Mtetra
.33788 .15501 .34591 .16423 .35881 .15925 .35081 .14999 Mtetra
.35081 .14999 .35881 .15925 .37177 .15425 .36381 .14494 Mtetra
.36381 .14494 .37177 .15425 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .1391 .40319 .12966 Mtetra
.40319 .12966 .41103 .1391 .42424 .134 .41644 .12451 Mtetra
.663 .741 .908 r
.41644 .12451 .42424 .134 .43752 .12887 .42976 .11934 Mtetra
.42976 .11934 .43752 .12887 .45087 .12373 .44315 .11415 Mtetra
.44315 .11415 .45087 .12373 .46428 .11858 .4566 .10895 Mtetra
.662 .74 .908 r
.4566 .10895 .46428 .11858 .47776 .11345 .47012 .10376 Mtetra
.658 .739 .909 r
.47012 .10376 .47776 .11345 .4913 .10842 .48371 .09866 Mtetra
.65 .735 .912 r
.48371 .09866 .4913 .10842 .50491 .10366 .49736 .0938 Mtetra
.633 .727 .916 r
.49736 .0938 .50491 .10366 .51859 .09948 .51109 .08945 Mtetra
.601 .711 .921 r
.51109 .08945 .51859 .09948 .53235 .09635 .52489 .08603 Mtetra
.548 .68 .926 r
.52489 .08603 .53235 .09635 .54622 .0948 .53878 .08401 Mtetra
.477 .634 .923 r
.53878 .08401 .54622 .0948 .56021 .09525 .5528 .08377 Mtetra
.409 .581 .91 r
.5528 .08377 .56021 .09525 .57437 .09763 .56696 .08522 Mtetra
.382 .544 .892 r
.56696 .08522 .57437 .09763 .58869 .10106 .58128 .08759 Mtetra
.421 .546 .876 r
.58128 .08759 .58869 .10106 .60316 .10385 .59574 .08939 Mtetra
.514 .58 .859 r
.59574 .08939 .60316 .10385 .6177 .10394 .61027 .08878 Mtetra
.619 .624 .834 r
.61027 .08878 .6177 .10394 .63221 .09973 .6248 .08437 Mtetra
.702 .662 .808 r
.6248 .08437 .63221 .09973 .64661 .09083 .63925 .07579 Mtetra
.756 .691 .789 r
.63925 .07579 .64661 .09083 .66089 .07825 .6536 .06395 Mtetra
.784 .713 .786 r
.6536 .06395 .66089 .07825 .67507 .06391 .66789 .05055 Mtetra
.791 .731 .797 r
.66789 .05055 .67507 .06391 .68926 .04978 .68219 .03734 Mtetra
.78 .744 .82 r
.68219 .03734 .68926 .04978 .70353 .03722 .69656 .02551 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22357 Mtetra
.13047 .22357 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12966 .39527 .12013 Mtetra
.39527 .12013 .40319 .12966 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.663 .741 .908 r
.42193 .10972 .42976 .11934 .44315 .11415 .43536 .10448 Mtetra
.43536 .10448 .44315 .11415 .4566 .10895 .44886 .09923 Mtetra
.662 .741 .908 r
.44886 .09923 .4566 .10895 .47012 .10376 .46242 .09399 Mtetra
.659 .739 .909 r
.46242 .09399 .47012 .10376 .48371 .09866 .47605 .08882 Mtetra
.652 .736 .911 r
.47605 .08882 .48371 .09866 .49736 .0938 .48975 .08386 Mtetra
.637 .729 .915 r
.48975 .08386 .49736 .0938 .51109 .08945 .50351 .07935 Mtetra
.609 .714 .92 r
.50351 .07935 .51109 .08945 .52489 .08603 .51735 .07566 Mtetra
.563 .688 .924 r
.51735 .07566 .52489 .08603 .53878 .08401 .53128 .0732 Mtetra
.502 .649 .923 r
.53128 .0732 .53878 .08401 .5528 .08377 .54533 .0723 Mtetra
.444 .603 .913 r
.54533 .0723 .5528 .08377 .56696 .08522 .5595 .0729 Mtetra
.42 .57 .897 r
.5595 .0729 .56696 .08522 .58128 .08759 .57382 .0743 Mtetra
.452 .569 .882 r
.57382 .0743 .58128 .08759 .59574 .08939 .58828 .07518 Mtetra
.531 .595 .863 r
.58828 .07518 .59574 .08939 .61027 .08878 .60281 .07393 Mtetra
.623 .633 .84 r
.60281 .07393 .61027 .08878 .6248 .08437 .61736 .06931 Mtetra
.699 .667 .815 r
.61736 .06931 .6248 .08437 .63925 .07579 .63186 .06103 Mtetra
.749 .694 .799 r
.63186 .06103 .63925 .07579 .6536 .06395 .64628 .04987 Mtetra
.775 .715 .796 r
.64628 .04987 .6536 .06395 .66789 .05055 .66067 .03734 Mtetra
.781 .732 .808 r
.66067 .03734 .66789 .05055 .68219 .03734 .67506 .02496 Mtetra
.77 .744 .829 r
.67506 .02496 .68219 .03734 .69656 .02551 .68954 .0138 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 0 1 r
.005 w
.887 .2345 m
.90204 .242 L
.9128 .25867 L
.91686 .2678 L
.92551 .2936 L
.93181 .3194 L
.93668 .3452 L
.9386 .35731 L
.94068 .371 L
.94393 .3968 L
.9464 .4226 L
.94818 .4484 L
.94935 .4742 L
.94997 .5 L
.95004 .5258 L
.94957 .5516 L
.94854 .5774 L
.94691 .6032 L
.94459 .629 L
.94149 .6548 L
.9386 .67397 L
.93755 .6806 L
.93283 .7064 L
.92667 .7322 L
.91817 .758 L
.9128 .7699 L
.9036 .7838 L
.887 .79133 L
.87519 .7838 L
.8612 .75973 L
.86017 .758 L
.84843 .7322 L
.84162 .7064 L
.83788 .6806 L
.83594 .6548 L
.8354 .64282 L
.83378 .629 L
.83131 .6032 L
.82951 .5774 L
.82833 .5516 L
.82771 .5258 L
.82764 .5 L
.82813 .4742 L
.82918 .4484 L
.83084 .4226 L
.83317 .3968 L
.8354 .37758 L
.83563 .371 L
.83715 .3452 L
.84036 .3194 L
Mistroke
.8467 .2936 L
.85843 .2678 L
.8612 .26337 L
.87403 .242 L
.887 .2345 L
Mfstroke
.3968 .65034 m
.4226 .64437 L
.4484 .64073 L
.4742 .63879 L
.5 .63819 L
.5258 .63884 L
.5516 .64081 L
.5774 .64436 L
.6032 .64998 L
.61919 .6548 L
.629 .65801 L
.6548 .66959 L
.66929 .6806 L
.67538 .7064 L
.6548 .72565 L
.64134 .7322 L
.629 .73779 L
.6032 .74573 L
.5774 .75031 L
.5516 .75287 L
.5258 .75406 L
.5 .75416 L
.4742 .75321 L
.4484 .75102 L
.4226 .74716 L
.3968 .74079 L
.37436 .7322 L
.371 .73084 L
.3452 .7164 L
.33582 .7064 L
.33745 .6806 L
.3452 .67305 L
.371 .65909 L
.38308 .6548 L
.3968 .65034 L
s
.3968 .25979 m
.4226 .25364 L
.4484 .24973 L
.4742 .2474 L
.5 .24626 L
.5258 .2461 L
.5516 .24692 L
.5774 .24891 L
.6032 .25257 L
.629 .25903 L
.65018 .2678 L
.6548 .26979 L
.6806 .28799 L
.68379 .2936 L
.6806 .31292 L
.67465 .3194 L
.6548 .33199 L
.629 .34194 L
.61778 .3452 L
.6032 .34914 L
.5774 .35439 L
.5516 .35783 L
.5258 .35984 L
.5 .36062 L
.4742 .36024 L
.4484 .35861 L
.4226 .35545 L
.3968 .35021 L
.3798 .3452 L
.371 .34239 L
.3452 .3307 L
.33188 .3194 L
.33167 .2936 L
.3452 .28157 L
.371 .26901 L
.37427 .2678 L
.3968 .25979 L
s
0 g
.03 w
.88872 .51301 Mdot
.50472 .69622 Mdot
.50604 .30341 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
0 g
.5 Mabswid
.48039 .67543 m
.5 .67356 L
.51961 .67457 L
.5307 .67647 L
.53922 .67803 L
.55882 .68444 L
.57102 .69608 L
.55882 .70903 L
.53922 .71507 L
.53587 .71569 L
.51961 .71847 L
.5 .71891 L
.48039 .71646 L
.47613 .71569 L
.46078 .71195 L
.44118 .7013 L
.43853 .69608 L
.44118 .69 L
.46078 .67965 L
.47363 .67647 L
.48039 .67543 L
s
.48039 .29467 m
.5 .29147 L
.51961 .29175 L
.53922 .29642 L
.54632 .30392 L
.53922 .30936 L
.51961 .3146 L
.5 .31555 L
.48039 .31302 L
.46482 .30392 L
.48039 .29467 L
s
.42157 .674 m
.44118 .66542 L
.46078 .66171 L
.48039 .66015 L
.5 .65971 L
.51961 .66015 L
.53922 .66164 L
.55882 .66485 L
.57843 .6713 L
.58805 .67647 L
.59804 .68209 L
.60879 .69608 L
.59804 .71213 L
.59204 .71569 L
.57843 .7237 L
.55882 .72936 L
.53922 .73175 L
.51961 .73266 L
.5 .73266 L
.48039 .73179 L
.46078 .72966 L
.44118 .7252 L
.42157 .71616 L
.42084 .71569 L
.40196 .70034 L
.40066 .69608 L
.40196 .69027 L
.41801 .67647 L
.42157 .674 L
s
.44118 .28385 m
.46078 .27693 L
.48039 .27325 L
.5 .27153 L
.51961 .27123 L
.53922 .2724 L
.55882 .27591 L
.57843 .28426 L
.57851 .28431 L
.59804 .30008 L
.59818 .30392 L
.59804 .30438 L
.57843 .32 L
.56886 .32353 L
.55882 .32715 L
.53922 .33182 L
.51961 .33421 L
.5 .335 L
.48039 .33435 L
.46078 .33179 L
.44118 .32583 L
.43632 .32353 L
.42157 .31626 L
.41368 .30392 L
.42157 .29343 L
.44018 .28431 L
.44118 .28385 L
s
.44118 .65668 m
.46078 .65394 L
.48039 .65239 L
.5 .65186 L
.51961 .6523 L
.53922 .65373 L
.55882 .65625 L
.56258 .65686 L
.57843 .65861 L
.59804 .6628 L
.61765 .67209 L
.62327 .67647 L
.63725 .69027 L
.63915 .69608 L
.63725 .70456 L
.6271 .71569 L
.61765 .72416 L
.59804 .73215 L
.57843 .73478 L
.57113 .73529 L
.55882 .73725 L
.53922 .73939 L
.51961 .74044 L
.5 .74049 L
.48039 .73959 L
.46078 .73765 L
.44511 .73529 L
.44118 .73493 L
.42157 .73223 L
.40196 .72624 L
.38574 .71569 L
.38235 .71332 L
.3703 .69608 L
.38235 .67678 L
.38277 .67647 L
.40196 .66324 L
.42157 .65858 L
.44012 .65686 L
.44118 .65668 L
s
.87255 .31297 m
.89216 .31736 L
.895 .32353 L
.90051 .34314 L
.9038 .36275 L
.90664 .38235 L
.9095 .40196 L
.91176 .41781 L
.9124 .42157 L
.91543 .44118 L
.91775 .46078 L
.91932 .48039 L
.92018 .5 L
.92039 .51961 L
.91999 .53922 L
.91902 .55882 L
.91756 .57843 L
.91577 .59804 L
.9138 .61765 L
.91176 .63653 L
.91169 .63725 L
.90941 .65686 L
.90571 .67647 L
.89848 .69608 L
.89216 .70487 L
.87255 .70454 L
.86666 .69608 L
.86049 .67647 L
.85922 .65686 L
.85977 .63725 L
.86047 .61765 L
.86064 .59804 L
.86025 .57843 L
.85958 .55882 L
.85896 .53922 L
.85864 .51961 L
.85875 .5 L
.85938 .48039 L
.86051 .46078 L
.86203 .44118 L
.86374 .42157 L
.86525 .40196 L
.86613 .38235 L
.8662 .36275 L
.8662 .34314 L
.86871 .32353 L
.87255 .31297 L
s
.5 .26365 m
.51961 .26349 L
.53922 .26434 L
.54505 .26471 L
.55882 .26514 L
.57843 .26628 L
.59804 .26966 L
.61765 .28214 L
.62143 .28431 L
.63358 .30392 L
.61765 .32088 L
.61279 .32353 L
.59804 .33124 L
.57843 .33719 L
.55882 .34039 L
.53922 .34212 L
.51961 .34297 L
.5118 .34314 L
.5 .34334 L
.48649 .34314 L
.48039 .34303 L
.46078 .3424 L
.44118 .34113 L
.42157 .33828 L
.40196 .3309 L
.39232 .32353 L
.38235 .31521 L
.37836 .30392 L
.38235 .29578 L
.39729 .28431 L
.40196 .28118 L
.42157 .2724 L
.44118 .26801 L
.46078 .26581 L
.48039 .26474 L
.48149 .26471 L
.5 .26365 L
s
.40196 .65388 m
.42157 .64945 L
.44118 .64635 L
.46078 .6443 L
.48039 .64312 L
.5 .64273 L
.51961 .64311 L
.53922 .64428 L
.55882 .64628 L
.57843 .64923 L
.59804 .65337 L
.61081 .65686 L
.61765 .65809 L
.63725 .66431 L
.65378 .67647 L
.65686 .67906 L
.66712 .69608 L
.65753 .71569 L
.65686 .71666 L
.63725 .73191 L
.6185 .73529 L
.61765 .73557 L
.59804 .7409 L
.57843 .74463 L
.55882 .74719 L
.53922 .74881 L
.51961 .7496 L
.5 .74962 L
.48039 .74886 L
.46078 .74731 L
.44118 .74487 L
.42157 .74139 L
.40196 .73656 L
.3977 .73529 L
.38235 .73204 L
.36275 .72245 L
.35541 .71569 L
.34314 .69921 L
.34253 .69608 L
.34314 .69041 L
.35235 .67647 L
.36275 .66562 L
.38235 .65809 L
.39182 .65686 L
.40196 .65388 L
s
.85294 .28311 m
.87255 .26505 L
.89216 .26628 L
.9071 .28431 L
.91176 .2949 L
.91491 .30392 L
.91953 .32353 L
.92233 .34314 L
.92432 .36275 L
.92604 .38235 L
.92763 .40196 L
.92905 .42157 L
.93022 .44118 L
.93111 .46078 L
.93137 .46746 L
.93192 .48039 L
.93245 .5 L
.93259 .51961 L
.93236 .53922 L
.93178 .55882 L
.93137 .56933 L
.93109 .57843 L
.93038 .59804 L
.92954 .61765 L
.92852 .63725 L
.92714 .65686 L
.92502 .67647 L
.9215 .69608 L
.91535 .71569 L
.91176 .72337 L
.90492 .73529 L
.89216 .74705 L
.87255 .7451 L
.86139 .73529 L
.85294 .72422 L
.84802 .71569 L
.84108 .69608 L
.83905 .67647 L
.83994 .65686 L
.84194 .63725 L
.84375 .61765 L
.8448 .59804 L
.84511 .57843 L
.84494 .55882 L
.84465 .53922 L
.84447 .51961 L
.84455 .5 L
.84495 .48039 L
.84564 .46078 L
.84649 .44118 L
Mistroke
.84725 .42157 L
.84752 .40196 L
.84687 .38235 L
.84516 .36275 L
.84288 .34314 L
.84152 .32353 L
.84348 .30392 L
.85214 .28431 L
.85294 .28311 L
Mfstroke
.42157 .26285 m
.44118 .25915 L
.46078 .25652 L
.48039 .25477 L
.5 .25382 L
.51961 .25363 L
.53922 .25419 L
.55882 .25557 L
.57843 .25788 L
.59804 .26134 L
.61193 .26471 L
.61765 .26631 L
.63725 .27335 L
.65579 .28431 L
.65686 .2853 L
.66468 .30392 L
.65686 .31629 L
.64754 .32353 L
.63725 .33056 L
.61765 .33848 L
.59804 .34256 L
.59411 .34314 L
.57843 .34635 L
.55882 .34937 L
.53922 .35145 L
.51961 .35271 L
.5 .35319 L
.48039 .35292 L
.46078 .35185 L
.44118 .34991 L
.42157 .34692 L
.40421 .34314 L
.40196 .34298 L
.38235 .34024 L
.36275 .32951 L
.35765 .32353 L
.34744 .30392 L
.36275 .28453 L
.36306 .28431 L
.38235 .27219 L
.40196 .26656 L
.41359 .26471 L
.42157 .26285 L
s
.44118 .63697 m
.46078 .63526 L
.48039 .63427 L
.5 .63396 L
.51961 .63432 L
.53922 .63534 L
.55882 .63706 L
.56069 .63725 L
.57843 .63949 L
.59804 .64277 L
.61765 .6471 L
.63725 .65283 L
.64821 .65686 L
.65686 .65912 L
.67647 .66953 L
.68327 .67647 L
.69525 .69608 L
.68702 .71569 L
.67647 .72855 L
.65686 .73518 L
.65572 .73529 L
.63725 .74219 L
.61765 .74749 L
.59804 .7514 L
.57843 .75428 L
.57347 .7549 L
.55882 .75638 L
.53922 .75774 L
.51961 .75839 L
.5 .75838 L
.48039 .75771 L
.46078 .75636 L
.44613 .7549 L
.44118 .7543 L
.42157 .75148 L
.40196 .74773 L
.38235 .74278 L
.36275 .73615 L
.36062 .73529 L
.34314 .72953 L
.3265 .71569 L
.32353 .71265 L
.31532 .69608 L
.32339 .67647 L
.32353 .67622 L
.34314 .65905 L
.35451 .65686 L
.36275 .65353 L
.38235 .64731 L
.40196 .64278 L
Mistroke
.42157 .63942 L
.43852 .63725 L
.44118 .63697 L
Mfstroke
.87255 .23279 m
.89216 .23177 L
.9081 .2451 L
.91176 .25024 L
.92014 .26471 L
.92695 .28431 L
.93102 .30392 L
.93137 .30612 L
.93393 .32353 L
.93586 .34314 L
.93728 .36275 L
.93856 .38235 L
.93986 .40196 L
.94115 .42157 L
.94233 .44118 L
.94331 .46078 L
.94402 .48039 L
.94444 .5 L
.94455 .51961 L
.94438 .53922 L
.94396 .55882 L
.94334 .57843 L
.94259 .59804 L
.94177 .61765 L
.94086 .63725 L
.93971 .65686 L
.93803 .67647 L
.93544 .69608 L
.93153 .71569 L
.93137 .71633 L
.92676 .73529 L
.91898 .7549 L
.91176 .76607 L
.9052 .77451 L
.89216 .78352 L
.87255 .77916 L
.86683 .77451 L
.85294 .75897 L
.84969 .7549 L
.83687 .73529 L
.83333 .72899 L
.82741 .71569 L
.82195 .69608 L
.82141 .67647 L
.82409 .65686 L
.82755 .63725 L
.83039 .61765 L
.83215 .59804 L
.83295 .57843 L
.83312 .55882 L
Mistroke
.83302 .53922 L
.83293 .51961 L
.833 .5 L
.83329 .48039 L
.83333 .47838 L
.83374 .46078 L
.83421 .44118 L
.83446 .42157 L
.83408 .40196 L
.83333 .38959 L
.83264 .38235 L
.8298 .36275 L
.82595 .34314 L
.8225 .32353 L
.82232 .30392 L
.82799 .28431 L
.83333 .27317 L
.83883 .26471 L
.85294 .24801 L
.85588 .2451 L
.87255 .23279 L
Mfstroke
.5 .24476 m
.51961 .24455 L
.53922 .24498 L
.54296 .2451 L
.55882 .24605 L
.57843 .24781 L
.59804 .25036 L
.61765 .25389 L
.63725 .25874 L
.65467 .26471 L
.65686 .26556 L
.67647 .27523 L
.68816 .28431 L
.69534 .30392 L
.67996 .32353 L
.67647 .3266 L
.65686 .3378 L
.63807 .34314 L
.63725 .34341 L
.61765 .34901 L
.59804 .3533 L
.57843 .35658 L
.55882 .35903 L
.53922 .36077 L
.51961 .36184 L
.5 .36228 L
.48039 .3621 L
.46078 .36129 L
.44118 .35979 L
.42157 .35755 L
.40196 .3544 L
.38235 .35008 L
.36275 .34406 L
.36029 .34314 L
.34314 .3402 L
.32572 .32353 L
.32353 .32103 L
.31781 .30392 L
.32353 .29207 L
.33137 .28431 L
.34314 .27471 L
.36275 .26661 L
.37098 .26471 L
.38235 .26106 L
.40196 .256 L
.42157 .25215 L
.44118 .24921 L
.46078 .24706 L
.48039 .24559 L
.49031 .2451 L
Mistroke
.5 .24476 L
Mfstroke
.38235 .63599 m
.40196 .6323 L
.42157 .62945 L
.44118 .62733 L
.46078 .62587 L
.48039 .62503 L
.5 .62478 L
.51961 .62512 L
.53922 .62604 L
.55882 .62757 L
.57843 .62973 L
.59804 .63258 L
.61765 .6362 L
.62264 .63725 L
.63725 .64068 L
.65686 .64633 L
.67647 .65362 L
.68365 .65686 L
.69608 .6612 L
.71569 .67647 L
.71569 .67647 L
.72755 .69608 L
.71924 .71569 L
.71569 .72199 L
.69608 .73471 L
.69122 .73529 L
.67647 .74212 L
.65686 .74897 L
.63725 .75417 L
.63407 .7549 L
.61765 .75834 L
.59804 .76161 L
.57843 .76409 L
.55882 .76589 L
.53922 .76705 L
.51961 .7676 L
.5 .76757 L
.48039 .76695 L
.46078 .76574 L
.44118 .76391 L
.42157 .76143 L
.40196 .75822 L
.38557 .7549 L
.38235 .75418 L
.36275 .74917 L
.34314 .74272 L
.32602 .73529 L
.32353 .73457 L
.30392 .72366 L
.2972 .71569 L
Mistroke
.28729 .69608 L
.29405 .67647 L
.30392 .66263 L
.31979 .65686 L
.32353 .65489 L
.34314 .64662 L
.36275 .64062 L
.37661 .63725 L
.38235 .63599 L
Mfstroke
.42157 .24198 m
.44118 .23945 L
.46078 .23753 L
.48039 .2362 L
.5 .23542 L
.51961 .23519 L
.53922 .23551 L
.55882 .2364 L
.57843 .23789 L
.59804 .24003 L
.61765 .24289 L
.62986 .2451 L
.63725 .24657 L
.65686 .2512 L
.67647 .25733 L
.6939 .26471 L
.69608 .26574 L
.71569 .27723 L
.7235 .28431 L
.73113 .30392 L
.71569 .32297 L
.71491 .32353 L
.69608 .33639 L
.67735 .34314 L
.67647 .34349 L
.65686 .35041 L
.63725 .35586 L
.61765 .36021 L
.60389 .36275 L
.59804 .3637 L
.57843 .36648 L
.55882 .36863 L
.53922 .37018 L
.51961 .37117 L
.5 .37161 L
.48039 .3715 L
.46078 .37083 L
.44118 .36957 L
.42157 .3677 L
.40196 .36512 L
.38761 .36275 L
.38235 .36177 L
.36275 .35752 L
.34314 .35191 L
.32353 .34409 L
.32159 .34314 L
.30392 .33274 L
.29395 .32353 L
.28768 .30392 L
.29978 .28431 L
Mistroke
.30392 .27987 L
.32353 .2677 L
.33291 .26471 L
.34314 .26059 L
.36275 .25419 L
.38235 .24919 L
.40196 .2452 L
.40252 .2451 L
.42157 .24198 L
Mfstroke
.87255 .19856 m
.89216 .19519 L
.90744 .20588 L
.91176 .21104 L
.92189 .22549 L
.93014 .2451 L
.93137 .24884 L
.93675 .26471 L
.94172 .28431 L
.94516 .30392 L
.94741 .32353 L
.94889 .34314 L
.94998 .36275 L
.95096 .38235 L
.95098 .38275 L
.95198 .40196 L
.95302 .42157 L
.95398 .44118 L
.95479 .46078 L
.95539 .48039 L
.95574 .5 L
.95585 .51961 L
.95572 .53922 L
.95537 .55882 L
.95487 .57843 L
.95427 .59804 L
.95363 .61765 L
.95291 .63725 L
.95201 .65686 L
.95098 .67284 L
.95069 .67647 L
.9487 .69608 L
.94576 .71569 L
.94168 .73529 L
.93632 .7549 L
.93137 .76947 L
.92992 .77451 L
.92245 .79412 L
.91176 .80963 L
.90855 .81373 L
.89216 .82517 L
.87255 .81823 L
.86801 .81373 L
.85321 .79412 L
.85294 .79371 L
.8404 .77451 L
.83333 .76266 L
.82845 .7549 L
.81583 .73529 L
.81373 .73264 L
Mistroke
.80538 .71569 L
.79839 .69608 L
.80061 .67647 L
.80677 .65686 L
.81239 .63725 L
.81373 .63188 L
.81677 .61765 L
.8195 .59804 L
.82087 .57843 L
.82137 .55882 L
.82146 .53922 L
.82145 .51961 L
.82152 .5 L
.82174 .48039 L
.82206 .46078 L
.82231 .44118 L
.82216 .42157 L
.82112 .40196 L
.81862 .38235 L
.81408 .36275 L
.81373 .36155 L
.80788 .34314 L
.80027 .32353 L
.79564 .30392 L
.80301 .28431 L
.81373 .26624 L
.81536 .26471 L
.83031 .2451 L
.83333 .24113 L
.84508 .22549 L
.85294 .21662 L
.8632 .20588 L
.87255 .19856 L
Mfstroke
.87255 .15392 m
.89216 .14866 L
.91176 .16403 L
.91414 .16667 L
.92618 .18627 L
.93137 .2002 L
.93378 .20588 L
.94113 .22549 L
.94727 .2451 L
.95098 .25911 L
.9523 .26471 L
.95619 .28431 L
.95897 .30392 L
.9608 .32353 L
.96198 .34314 L
.96284 .36275 L
.96363 .38235 L
.96447 .40196 L
.96533 .42157 L
.96615 .44118 L
.96684 .46078 L
.96736 .48039 L
.96767 .5 L
.96777 .51961 L
.96767 .53922 L
.96739 .55882 L
.96697 .57843 L
.96649 .59804 L
.96597 .61765 L
.9654 .63725 L
.96468 .65686 L
.96361 .67647 L
.96195 .69608 L
.95952 .71569 L
.95624 .73529 L
.95212 .7549 L
.95098 .75975 L
.94729 .77451 L
.94175 .79412 L
.93531 .81373 L
.93137 .82416 L
.92878 .83333 L
.91961 .85294 L
.91176 .86231 L
.90129 .87255 L
.89216 .87644 L
.87769 .87255 L
.87255 .86846 L
.86063 .85294 L
.85294 .83926 L
Mistroke
.8498 .83333 L
.84032 .81373 L
.83333 .79869 L
.831 .79412 L
.81992 .77451 L
.81373 .76519 L
.8065 .7549 L
.79412 .74245 L
.78525 .73529 L
.77451 .73223 L
.7549 .73224 L
.73529 .73525 L
.73454 .73529 L
.71569 .74326 L
.69608 .75057 L
.68248 .7549 L
.67647 .75672 L
.65686 .76195 L
.63725 .76624 L
.61765 .76974 L
.59804 .77253 L
.5802 .77451 L
.57843 .77467 L
.55882 .77614 L
.53922 .77708 L
.51961 .77753 L
.5 .77748 L
.48039 .77693 L
.46078 .7759 L
.44276 .77451 L
.44118 .77435 L
.42157 .77214 L
.40196 .76932 L
.38235 .76583 L
.36275 .76159 L
.34314 .75645 L
.3379 .7549 L
.32353 .75021 L
.30392 .74225 L
.29069 .73529 L
.28431 .73276 L
.26581 .71569 L
.26471 .71428 L
.25695 .69608 L
.26263 .67647 L
.26471 .67166 L
.28431 .65687 L
.28436 .65686 L
.30392 .64633 L
.32353 .63888 L
Mistroke
.3286 .63725 L
.34314 .63297 L
.36275 .62818 L
.38235 .62429 L
.40196 .62117 L
.42157 .61872 L
.4321 .61765 L
.44118 .61693 L
.46078 .61574 L
.48039 .61505 L
.5 .61487 L
.51961 .61517 L
.53922 .61597 L
.55882 .61726 L
.56367 .61765 L
.57843 .61916 L
.59804 .62168 L
.61765 .62484 L
.63725 .62869 L
.65686 .63332 L
.67119 .63725 L
.67647 .63881 L
.69608 .64527 L
.71569 .65276 L
.72297 .65686 L
.73529 .65916 L
.7549 .66296 L
.77451 .65874 L
.77929 .65686 L
.79397 .63725 L
.79412 .6368 L
.80181 .61765 L
.80609 .59804 L
.80826 .57843 L
.80919 .55882 L
.8095 .53922 L
.80958 .51961 L
.80966 .5 L
.80982 .48039 L
.81 .46078 L
.80998 .44118 L
.80937 .42157 L
.80753 .40196 L
.8035 .38235 L
.79561 .36275 L
.79412 .36022 L
.78014 .34314 L
.77451 .34037 L
.7549 .33633 L
.73529 .33974 L
Mistroke
.71883 .34314 L
.71569 .34539 L
.69608 .35224 L
.67647 .35832 L
.65992 .36275 L
.65686 .3635 L
.63725 .36788 L
.61765 .37156 L
.59804 .37461 L
.57843 .37708 L
.55882 .37901 L
.53922 .38043 L
.51961 .38135 L
.5 .38178 L
.48039 .38173 L
.46078 .38118 L
.44118 .38012 L
.42157 .37853 L
.40196 .37636 L
.38235 .37357 L
.36275 .37007 L
.34314 .36571 L
.33189 .36275 L
.32353 .36035 L
.30392 .35354 L
.28431 .34389 L
.28308 .34314 L
.26471 .32893 L
.26033 .32353 L
.25535 .30392 L
.26471 .28604 L
.26629 .28431 L
.28431 .26906 L
.29481 .26471 L
.30392 .26032 L
.32353 .25264 L
.34314 .24658 L
.34861 .2451 L
.36275 .24161 L
.38235 .23746 L
.40196 .23401 L
.42157 .23118 L
.44118 .22892 L
.46078 .22719 L
.48039 .22596 L
.4915 .22549 L
.5 .22525 L
.51961 .22502 L
.53922 .22525 L
.54762 .22549 L
Mistroke
.55882 .22598 L
.57843 .22724 L
.59804 .22904 L
.61765 .23144 L
.63725 .23448 L
.65686 .23826 L
.67647 .24288 L
.68468 .2451 L
.69608 .24829 L
.71569 .25456 L
.73529 .26147 L
.74547 .26471 L
.7549 .26671 L
.77451 .26566 L
.77733 .26471 L
.79412 .25486 L
.80585 .2451 L
.81373 .23579 L
.82188 .22549 L
.83333 .20882 L
.83507 .20588 L
.84699 .18627 L
.85294 .17743 L
.86054 .16667 L
.87255 .15392 L
Mfstroke
.87255 .09406 m
.89216 .08889 L
.91176 .10298 L
.91629 .10784 L
.92775 .12745 L
.93137 .13786 L
.9352 .14706 L
.94231 .16667 L
.94851 .18627 L
.95098 .19462 L
.95423 .20588 L
.95957 .22549 L
.96443 .2451 L
.9686 .26471 L
.97059 .27578 L
.97188 .28431 L
.97421 .30392 L
.97569 .32353 L
.9766 .34314 L
.97722 .36275 L
.97781 .38235 L
.97846 .40196 L
.97916 .42157 L
.97985 .44118 L
.98044 .46078 L
.98088 .48039 L
.98115 .5 L
.98124 .51961 L
.98116 .53922 L
.98094 .55882 L
.98061 .57843 L
.98024 .59804 L
.97985 .61765 L
.97944 .63725 L
.97891 .65686 L
.97807 .67647 L
.97671 .69608 L
.97466 .71569 L
.97188 .73529 L
.97059 .74312 L
.96845 .7549 L
.96451 .77451 L
.96022 .79412 L
.95564 .81373 L
.95098 .83223 L
.9507 .83333 L
.94532 .85294 L
.93905 .87255 L
.93137 .89198 L
.93132 .89216 L
Mistroke
.92352 .91176 L
.91176 .92536 L
.90537 .93137 L
.89216 .93744 L
.87405 .93137 L
.87255 .93016 L
.85798 .91176 L
.85294 .90271 L
.84769 .89216 L
.83979 .87255 L
.83333 .85348 L
.83315 .85294 L
.82638 .83333 L
.81885 .81373 L
.81373 .80243 L
.80948 .79412 L
.79546 .77451 L
.79412 .77315 L
.77451 .75912 L
.7549 .75525 L
.73529 .75733 L
.71569 .7619 L
.69608 .76701 L
.67647 .77183 L
.66438 .77451 L
.65686 .77598 L
.63725 .77939 L
.61765 .78226 L
.59804 .78459 L
.57843 .78641 L
.55882 .78775 L
.53922 .78861 L
.51961 .789 L
.5 .78893 L
.48039 .7884 L
.46078 .7874 L
.44118 .78595 L
.42157 .78402 L
.40196 .7816 L
.38235 .77868 L
.36275 .77523 L
.359 .77451 L
.34314 .77094 L
.32353 .76581 L
.30392 .75973 L
.29052 .7549 L
.28431 .75245 L
.26471 .74329 L
.25158 .73529 L
.2451 .7321 L
Mistroke
.22996 .71569 L
.22549 .70821 L
.222 .69608 L
.22549 .67891 L
.22675 .67647 L
.2451 .65692 L
.24518 .65686 L
.26471 .64456 L
.28103 .63725 L
.28431 .63592 L
.30392 .62894 L
.32353 .62321 L
.34314 .61844 L
.34676 .61765 L
.36275 .61464 L
.38235 .6115 L
.40196 .60891 L
.42157 .60684 L
.44118 .60528 L
.46078 .60419 L
.48039 .60358 L
.5 .60343 L
.51961 .60374 L
.53922 .60451 L
.55882 .60574 L
.57843 .60744 L
.59804 .60961 L
.61765 .61228 L
.63725 .61544 L
.64931 .61765 L
.65686 .61924 L
.67647 .62378 L
.69608 .62878 L
.71569 .63379 L
.73264 .63725 L
.73529 .63762 L
.7549 .63747 L
.75593 .63725 L
.77451 .627 L
.7823 .61765 L
.79005 .59804 L
.79353 .57843 L
.79412 .57453 L
.79521 .55882 L
.79589 .53922 L
.79612 .51961 L
.79624 .5 L
.79634 .48039 L
.79635 .46078 L
.79597 .44118 L
Mistroke
.79459 .42157 L
.79412 .41704 L
.79144 .40196 L
.78432 .38235 L
.77451 .37049 L
.76183 .36275 L
.7549 .36081 L
.73529 .36048 L
.72116 .36275 L
.71569 .36389 L
.69608 .36847 L
.67647 .37312 L
.65686 .37741 L
.63725 .38118 L
.63049 .38235 L
.61765 .38425 L
.59804 .38678 L
.57843 .38888 L
.55882 .39056 L
.53922 .39182 L
.51961 .39266 L
.5 .39308 L
.48039 .39308 L
.46078 .39265 L
.44118 .39179 L
.42157 .39048 L
.40196 .38872 L
.38235 .38648 L
.36275 .38372 L
.35427 .38235 L
.34314 .38025 L
.32353 .37596 L
.30392 .3708 L
.28431 .36451 L
.27952 .36275 L
.26471 .3568 L
.2451 .34603 L
.24109 .34314 L
.22549 .32843 L
.22224 .32353 L
.21837 .30392 L
.22549 .28791 L
.22831 .28431 L
.2451 .26862 L
.25313 .26471 L
.26471 .25835 L
.28431 .24974 L
.29712 .2451 L
.30392 .24286 L
.32353 .23709 L
Mistroke
.34314 .23216 L
.36275 .22793 L
.3757 .22549 L
.38235 .22442 L
.40196 .22159 L
.42157 .2192 L
.44118 .21725 L
.46078 .21572 L
.48039 .21461 L
.5 .21393 L
.51961 .21367 L
.53922 .21384 L
.55882 .21443 L
.57843 .21547 L
.59804 .21696 L
.61765 .21891 L
.63725 .22135 L
.65686 .22431 L
.66386 .22549 L
.67647 .22793 L
.69608 .23212 L
.71569 .23654 L
.73529 .2404 L
.7549 .24199 L
.77451 .23841 L
.79412 .22627 L
.79503 .22549 L
.81142 .20588 L
.81373 .20218 L
.82245 .18627 L
.83137 .16667 L
.83333 .16203 L
.8393 .14706 L
.84825 .12745 L
.85294 .11902 L
.85993 .10784 L
.87255 .09406 L
Mfstroke
.9902 .7385 m
.98781 .7549 L
.9846 .77451 L
.98113 .79412 L
.97751 .81373 L
.97375 .83333 L
.97059 .84907 L
.96979 .85294 L
.96553 .87255 L
.96085 .89216 L
.95563 .91176 L
.95098 .92729 L
.9497 .93137 L
.94283 .95098 L
.93423 .97059 L
.93137 .97606 L
.92507 .9902 L
s
.9902 .27904 m
.98814 .26471 L
.98468 .2451 L
.98064 .22549 L
.97628 .20588 L
.97179 .18627 L
.97059 .18106 L
.96721 .16667 L
.96246 .14706 L
.95739 .12745 L
.9518 .10784 L
.95098 .10517 L
.94549 .08824 L
.93798 .06863 L
.93137 .05446 L
.92926 .04902 L
.91672 .02941 L
.91176 .02481 L
.89216 .0127 L
.87255 .01695 L
.85926 .02941 L
.85294 .03812 L
.84619 .04902 L
.8371 .06863 L
.83333 .07872 L
.82986 .08824 L
.82343 .10784 L
.81757 .12745 L
.81373 .14042 L
.81174 .14706 L
.80506 .16667 L
.79563 .18627 L
.79412 .18874 L
.77982 .20588 L
.77451 .20947 L
.7549 .21729 L
.73529 .2185 L
.71569 .21669 L
.69608 .21372 L
.67647 .21055 L
.65686 .2076 L
.6441 .20588 L
.63725 .20516 L
.61765 .20333 L
.59804 .20183 L
.57843 .20068 L
.55882 .19989 L
.53922 .19945 L
.51961 .19936 L
.5 .19962 L
Mistroke
.48039 .20023 L
.46078 .20117 L
.44118 .20244 L
.42157 .20402 L
.40206 .20588 L
.40196 .20589 L
.38235 .20855 L
.36275 .21166 L
.34314 .21521 L
.32353 .21921 L
.30392 .22367 L
.2965 .22549 L
.28431 .22896 L
.26471 .23521 L
.2451 .24243 L
.2386 .2451 L
.22549 .25108 L
.20588 .26216 L
.20216 .26471 L
.18627 .27669 L
.18066 .28431 L
.17164 .30392 L
.17448 .32353 L
.18627 .33976 L
.18987 .34314 L
.20588 .35511 L
.22041 .36275 L
.22549 .36516 L
.2451 .37324 L
.26471 .37988 L
.27298 .38235 L
.28431 .38531 L
.30392 .38988 L
.32353 .39384 L
.34314 .39727 L
.36275 .40018 L
.37679 .40196 L
.38235 .4025 L
.40196 .40418 L
.42157 .40552 L
.44118 .40652 L
.46078 .40716 L
.48039 .40746 L
.5 .40742 L
.51961 .40703 L
.53922 .4063 L
.55882 .40526 L
.57843 .4039 L
.59804 .40224 L
.60111 .40196 L
Mistroke
.61765 .39992 L
.63725 .39712 L
.65686 .39393 L
.67647 .39047 L
.69608 .38703 L
.71569 .38424 L
.73529 .38359 L
.7549 .3889 L
.76895 .40196 L
.77451 .41814 L
.77532 .42157 L
.77839 .44118 L
.77947 .46078 L
.77975 .48039 L
.77973 .5 L
.77954 .51961 L
.77901 .53922 L
.77757 .55882 L
.77451 .57682 L
.77406 .57843 L
.7668 .59804 L
.7549 .60819 L
.73529 .61386 L
.71569 .61303 L
.69608 .60993 L
.67647 .60619 L
.65686 .6025 L
.63725 .59916 L
.63002 .59804 L
.61765 .59654 L
.59804 .59441 L
.57843 .59263 L
.55882 .5912 L
.53922 .59015 L
.51961 .58947 L
.5 .58919 L
.48039 .58929 L
.46078 .58978 L
.44118 .59066 L
.42157 .59193 L
.40196 .59358 L
.38235 .59561 L
.36275 .59801 L
.36255 .59804 L
.34314 .60131 L
.32353 .60519 L
.30392 .60966 L
.28431 .6148 L
.27451 .61765 L
.26471 .62091 L
Mistroke
.2451 .62838 L
.22604 .63725 L
.22549 .63753 L
.20588 .64934 L
.19691 .65686 L
.18627 .66857 L
.18149 .67647 L
.17763 .69608 L
.18472 .71569 L
.18627 .71868 L
.20336 .73529 L
.20588 .73729 L
.22549 .74977 L
.23568 .7549 L
.2451 .75919 L
.26471 .76698 L
.28431 .77362 L
.28719 .77451 L
.30392 .77904 L
.32353 .78379 L
.34314 .788 L
.36275 .79168 L
.37764 .79412 L
.38235 .79472 L
.40196 .79702 L
.42157 .79898 L
.44118 .80059 L
.46078 .80183 L
.48039 .80269 L
.5 .80317 L
.51961 .80325 L
.53922 .80295 L
.55882 .80226 L
.57843 .80117 L
.59804 .7997 L
.61765 .79784 L
.63725 .79562 L
.649 .79412 L
.65686 .79286 L
.67647 .78943 L
.69608 .78573 L
.71569 .78224 L
.73529 .77997 L
.7549 .78104 L
.77451 .7897 L
.78018 .79412 L
.79382 .81373 L
.79412 .81436 L
.80219 .83333 L
.80816 .85294 L
Mistroke
.81321 .87255 L
.81373 .8746 L
.81829 .89216 L
.82374 .91176 L
.82985 .93137 L
.83333 .94138 L
.8368 .95098 L
.84528 .97059 L
.85294 .98412 L
.85689 .9902 L
Mfstroke
.9902 .92612 m
.9892 .93137 L
.98523 .95098 L
.98081 .97059 L
.97591 .9902 L
s
.9902 .11035 m
.98973 .10784 L
.98588 .08824 L
.98163 .06863 L
.97694 .04902 L
.97175 .02941 L
.97059 .02526 L
.96602 .0098 L
s
.8041 .9902 m
.7991 .97059 L
.79449 .95098 L
.79412 .94934 L
.79053 .93137 L
.78675 .91176 L
.78296 .89216 L
.77878 .87255 L
.77451 .85675 L
.77349 .85294 L
.76527 .83333 L
.7549 .82197 L
.73588 .81373 L
.73529 .8136 L
.71569 .81217 L
.69608 .81371 L
.69596 .81373 L
.67647 .81561 L
.65686 .81773 L
.63725 .81979 L
.61765 .82165 L
.59804 .82322 L
.57843 .82448 L
.55882 .8254 L
.53922 .82598 L
.51961 .82621 L
.5 .8261 L
.48039 .82564 L
.46078 .82484 L
.44118 .82371 L
.42157 .82226 L
.40196 .82052 L
.38235 .81852 L
.36275 .81632 L
.34314 .81401 L
.34075 .81373 L
.32353 .81062 L
.30392 .80667 L
.28431 .80235 L
.26471 .79775 L
.24981 .79412 L
.2451 .7927 L
.22549 .78638 L
.20588 .7794 L
.19321 .77451 L
.18627 .77145 L
.16667 .76178 L
.15465 .7549 L
.14706 .75006 L
.1288 .73529 L
Mistroke
.12745 .73437 L
.11338 .71569 L
.10784 .70038 L
.10723 .69608 L
.10784 .68477 L
.1101 .67647 L
.1223 .65686 L
.12745 .65114 L
.14488 .63725 L
.14706 .63577 L
.16667 .62429 L
.18026 .61765 L
.18627 .61509 L
.20588 .60744 L
.22549 .60066 L
.2338 .59804 L
.2451 .59511 L
.26471 .59028 L
.28431 .58582 L
.30392 .58177 L
.32213 .57843 L
.32353 .57826 L
.34314 .57588 L
.36275 .57367 L
.38235 .57168 L
.40196 .56996 L
.42157 .56855 L
.44118 .56747 L
.46078 .56672 L
.48039 .56633 L
.5 .56627 L
.51961 .56656 L
.53922 .5672 L
.55882 .56817 L
.57843 .56946 L
.59804 .57106 L
.61765 .57292 L
.63725 .57497 L
.65686 .57709 L
.66936 .57843 L
.67647 .57936 L
.69608 .58158 L
.71569 .58156 L
.72806 .57843 L
.73529 .57513 L
.74794 .55882 L
.75203 .53922 L
.75334 .51961 L
.75371 .5 L
.75355 .48039 L
Mistroke
.75259 .46078 L
.74941 .44118 L
.73529 .42187 L
.73467 .42157 L
.71569 .4147 L
.69608 .41461 L
.67647 .4167 L
.65686 .41938 L
.6408 .42157 L
.63725 .42188 L
.61765 .42357 L
.59804 .42518 L
.57843 .42662 L
.55882 .42785 L
.53922 .42883 L
.51961 .42953 L
.5 .42994 L
.48039 .43004 L
.46078 .42985 L
.44118 .42935 L
.42157 .42855 L
.40196 .42747 L
.38235 .42612 L
.36275 .42454 L
.34314 .42277 L
.33079 .42157 L
.32353 .42051 L
.30392 .41737 L
.28431 .41382 L
.26471 .40988 L
.2451 .40561 L
.22944 .40196 L
.22549 .40084 L
.20588 .39483 L
.18627 .38805 L
.17159 .38235 L
.16667 .38019 L
.14706 .37042 L
.1344 .36275 L
.12745 .35814 L
.11132 .34314 L
.10784 .33882 L
.09958 .32353 L
.09789 .30392 L
.10586 .28431 L
.10784 .28091 L
.12388 .26471 L
.12745 .26175 L
.14706 .24851 L
.15312 .2451 L
Mistroke
.16667 .23823 L
.18627 .2295 L
.19627 .22549 L
.20588 .22217 L
.22549 .21577 L
.2451 .20988 L
.25955 .20588 L
.26471 .20478 L
.28431 .20064 L
.30392 .19665 L
.32353 .1929 L
.34314 .18949 L
.36275 .18644 L
.3639 .18627 L
.38235 .18452 L
.40196 .18273 L
.42157 .18111 L
.44118 .17969 L
.46078 .17852 L
.48039 .17762 L
.5 .17702 L
.51961 .17673 L
.53922 .17674 L
.55882 .17706 L
.57843 .17769 L
.59804 .17862 L
.61765 .17983 L
.63725 .1813 L
.65686 .18296 L
.67647 .18468 L
.69608 .18621 L
.69702 .18627 L
.71569 .18734 L
.73247 .18627 L
.73529 .18587 L
.7549 .1782 L
.76635 .16667 L
.77451 .14902 L
.77524 .14706 L
.78116 .12745 L
.78561 .10784 L
.78964 .08824 L
.79369 .06863 L
.79412 .0666 L
.79832 .04902 L
.80339 .02941 L
.80894 .0098 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo08kooooo00<0
0000ooooooooool02_ooool4000000_ooooo00?o0000ooooooooool01Oooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon>000000X06ATI0P00000403<c<`030000000I
6AT06ATI00P06ATI00Co000000000000000000001?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003ooooooooooooooon=000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`0000006ATI
01TI6@0801TI6@03o`0000000000000000Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000ooooooooooooooooS@00000901TI6@030000000c<c<0<c<c00L0<c<c00?o000001TI6@0I6AT0
1`0I6AT00ol00000000000000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooohd000002@0I6AT00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00L06ATI
00?o00000000000000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooon=000000P06ATI00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0601TI6@03o`00
00000000000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
S000000901TI6@030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT01P0I6AT00ol000000000
ooooo`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooh`00000
200I6AT00`000000<c<c03<c<`0<03<c<`030000000I6AT06ATI00D06ATI00?o000000000?ooool0
0oooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon<000000P06ATI
00<0000003<c<`0c<c<0300c<c<00ol000006ATI01TI6@0501TI6@03o`000000003ooooo00?ooooo
00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooS000000701TI6@030000
000c<c<0<c<c00d0<c<c00<0000001TI6@0I6AT01P0I6AT00ol0003oooooooooo`02ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooh`000001P0I6AT00`000000<c<c
03<c<`0?03<c<`030000000I6AT06ATI00D06ATI00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003ooooooooooooooon<000000H06ATI00<0000003<c<`0c<c<0
3`0c<c<00`0000006ATI01TI6@0501TI6@03o`000?oooooooooo00;ooooo00<00000ooooooooool0
coooool000Wooooo00@00000ooooooooooooooooS000000601TI6@030000000c<c<0<c<c00l0<c<c
00<0000001TI6@0I6AT01@0I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?oooooooooooooooh/000001`0I6AT00`000000<c<c03<c<`0@03<c<`030000
000I6AT06ATI00D06ATI00Go0000oooooooooooooooo0000002=ooooo`;o0000@_ooool000Wooooo
00@00000ooooooooooooooooR`00000601TI6@030000000c<c<0<c<c00H0<c<c1000000703<c<`03
0000000I6AT06ATI00D06ATI00Go0000oooooooooooooooo0000002:ooooo`?o000000?oooooo`00
0?ooool0@Oooool000Wooooo00@00000ooooooooooooooooR`00000601TI6@030000000c<c<0<c<c
00@0<c<c0P00000404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01@0I6AT01Ol0
003oooooooooooooool0000008Sooooo0_l00004ooooo`;o0000@Oooool000Wooooo00@00000oooo
ooooooooooooRP00000601TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`01@1<C4`0
0ol00000<c<c03<c<`0403<c<`030000000I6AT06ATI00@06ATI00Go0000oooooooooooooooo0000
0025ooooo`?o00001_ooool00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooooooo
oon:000000H06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00704a<C0030000000c
<c<0<c<c00<0<c<c00<00000o`00000I6AT0100I6AT01Ol0003oooooooooooooool0000008;ooooo
0ol00008ooooo`04olFne?l0003oooooo`00043ooooo0009ooooo`0400000?ooooooooooooooohX0
00001P0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c
<c<0100c<c<00`0000006ATI01TI6@0301TI6@Cooooo00<00000ooooooooool0O_ooool2o`0000[o
oooo0_o5_]@01?l0003oooooooooool0000oooooo`002Oooool01000003ooooooooooooooon90000
00H06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooooooo07_ooooo0ol0000;oooo
o`?oaKkD00Go0000ooooooooooooooooo`00000nooooo`002Oooool01000003ooooooooooooooon9
000000H06ATI00<0000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00;04a<C0030000000c<c<0
<c<c00<0<c<c00<0000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooooooo07Wooooo0_l0000=
ooooo`;oak_>00CoaKkDolNndOl0003oakkA0_ooool00ol0003oooooooooo`0looooo`002Oooool0
1000003ooooooooooooooon9000000H06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<
C00;04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT00P0I6AT4ooooo`0300000?oo
oooooooo07Kooooo0ol0000=ooooo`09olJgboo7^lkoak_>olNkc_o:^lcoakkAo`000?o7_]7ob[k?
00;ooooo00?o0000ooooooooool0>oooool000Wooooo00@00000ooooooooooooooooR@00000501TI
6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`0301<C4`00`000000<c<c03<c<`0203<c
<`030000000I6AT06ATI00806ATI1?ooool00`00003oooooooooo`1dooooo`;o00003oooool3olJg
b`05olNkc_o:^lcob[_<olZkc?l000000oo:_/l00ooooooo0000ooooo`0looooo`002Oooool01000
003ooooooooooooooon8000000H06ATI00?o000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00=
04a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00P0I6AT4ooooo`0300000?oooooo
oooo077ooooo0ol0000?ooooo`03oknac?o6]l_oa[O;00;oa[O;1?o:^l`01?l0003ob[k?olZncoo<
_/d2ooooo`03o`000?oooooooooo03[ooooo0009ooooo`0400000?ooooooooooooooohP000001P0I
6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<00@0C4a<0`00000704a<C0050000000c
<c<0<c<c03<c<`000000100I6AT4ooooo`0300000?oooooooooo06kooooo0ol0000Aooooo`?o_k7<
0_o6]l/2olRfb@;ob[_<00?ocK_9o`000?o:_/l00oo<_/d2ooooo`03o`000?oooooooooo03Wooooo
0009ooooo`0400000?ooooooooooooooohP000001P0I6AT00`000000<c<c03<c<`0203<c<`030000
001<C4`0C4a<0080C4a<0P00000306IVIP030000001<C4`0C4a<00@0C4a<00D0000003<c<`0c<c<0
<c<c0000000401TI6@Cooooo00<00000ooooooooool0K?ooool2o`0001?ooooo1?no/L`01Oo6]l_o
b;K9olRfbOo8]/Wob[_<00?ocK_900Co0000olbncOo<_/goc;k=0_ooool00ol0003oooooooooo`0i
ooooo`002Oooool01000003ooooooooooooooon7000000H06ATI00<0000003<c<`0c<c<00P0c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`0
1@000000<c<c03<c<`0c<c<0000000<06ATI1?ooool00`00003oooooooooo`1Yooooo`?o00005?oo
ool2ok:Zd0?o_k7<00Co`K39olRfbOo8]/Wob;K90oo=^lT01?o?^/Ko0000olbncOo<_/d2olnnbP;o
oooo00?o0000ooooooooool0>?ooool000Wooooo00@00000ooooooooooooooooQ`00000601TI6@06
0000000c<c<0<c<c03<c<ol0000000000`1<C4`00`000000IVIV06IVIP0606IVIP03o`0000000000
C4a<00<0C4a<00D0000003<c<`0c<c<0<c<c0000000301TI6@Cooooo00<00000ooooooooool0Iooo
ool2o`0000Gooooo00CoT;3/oh2Vk?n0Y^coP:K/0_maV^T3of^Ai@Cooooo00CoQiSLoinReonOX]Oo
Wj;G1?nbZ]001Ono/Lco`K39ol6`bOo1/<Wob;K900;obkK600GocK_9olnja_o?^/Ko0000olbnc@03
olnnbP?ooooo00?o0000ooooooooool0=oooool000Wooooo00@00000ooooooooooooooooQP000007
01TI6@050000000c<c<0<c<c03<c<`000000101<C4`00`000000IVIV06IVIP0706IVIP030000001<
C4`0C4a<0080C4a<00D0000003<c<`0c<c<0<c<c0000000301TI6@Cooooo00<00000ooooooooool0
I?ooool3o`0000;ooooo00CoXk[Zoi^fjonK]^_oVkK[0on@/>`3oh2Vk0;oLI[Y0_m[TND3og>Ah@?o
QiSL0onOX]L2ok:Zd003ok>Yc_o1/<Wo`K3900;o`K390oo;]/H3olnjaP03o`000?oB^/?ockk:00;o
ckk:00CodKk7oooooooooooo0000>Oooool000Wooooo00@00000ooooooooooooooooQ@00000701TI
6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000;06IVIP050000001<C4`0
C4a<04a<C0000000100c<c<00`0000006ATI01TI6@04ooooo`0300000?oooooooooo06;ooooo0_l0
0003ooooo`04ojJljOnS^^[oXk[Zoj>jjP?oVkK[00?oT;3/ohb^kOn<[^d00_mjX^`3ofRDj0;oJi7U
0omcTN42ohNHg0;oWj;G00?oWYoEok>Yc_ncZLh00_ncZLh2ol6`b@;o`k370_o;]/H01?o=]/?ock[6
olnja_l00002om:j``03olnnb_oA_/OodKk700?ooooo00?o0000ooooooooool0=_ooool000Wooooo
00@00000ooooooooooooooooDP00000E01TI6A`000002@0I6AT01@000000<c<c03<c<`0c<c<00000
00@0C4a<00<0000006IVIP1VIVH02@1VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c
03<c<`0000000P0I6AT4ooooo`0300000?oooooooooo05oooooo0ol00002ooooo`;oZ;gX0onV_>T0
0onS^^[oX[[Zoj:jjP02oiVfj`CoS:k]0_mjX^`2ofRDj0?oHH_T0_m[Rn02oh>Df`CoWYoE0oncZLh0
1Oo1/<Wo`k37ol>`aoo3/<OobkK600?ocKK300Cock[6o`000?oB^/?od[[30ooA_/L01OoD_/Gooooo
oooooooooooo000003Oooooo0009ooooo`0400000?oooooooooooooood@00000<@0I6AT<000000X0
6ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000d0IVIV00D0000004a<
C01<C4`0C4a<o`00000303<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0GOooool2
o`0000?ooooo00?oZKgXojRmj?nX_NP00_nX_NP2ojJlj@CoX[[Z0_nI]^/2ohb^k@04ohN[kOmbWNco
LYg/og:Mk0;oGXkW0omQRn@2of^;h0;oPiCK0onNWmD2ok>YcP05okBXc?o3/<Oo`k37ol>`aoo5[lD0
1?o=]/<00ooB^/?o0000om:j``02omBj`003om6naooD_/Goe;k500?ooooo00?o0000ooooooooool0
=Oooool000Wooooo00@00000oooooooooooooooo>@00001A01TI6@030000000c<c<0<c<c00<0<c<c
00D0000004a<C01<C4`0C4a<0000000506IVIP@00000101VIVH01@000000C4a<04a<C01<C4`00000
00<0<c<c00<0000001TI6@0I6AT01?ooool00`00003oooooooooo`1Jooooo`?o00000_ooool5ojVm
j0?oZ;gX0onV_>T2oj:jjP03oj6ij_nG]>coUkC/00;oUkC/0_n7Znd3og:Mk004oej>iomFPn;oEX?R
oeJ3hP;oHhGN0on3U=/00onNWmGoWIgDokBXc003okBXc004ol>`aoo5[lGoaJo5olF_a@;ocKK30_o?
]L001?l0003oe;[0omBj`?oD^/03omBna@05omJn`_ooooooooooooooool00000=_ooool000Wooooo
00@00000oooooooooooooooo=P00000L01TI6AD000008P0I6AT00`000000<c<c03<c<`0303<c<`05
0000001<C4`0C4a<04a<C0000000101VIVH00ol00000000007moO`0307moO`030000001VIVH0IVIV
0080IVIV00Co000004a<C01<C4`00000100c<c<00`0000006ATIooooo`03ooooo`0300000?oooooo
oooo05Oooooo0ol00003ooooo`OoZKgX1?nX_NP00onV_>WoYK_YojFkj@03oj6ijP;oUkC/00?oUK?/
oh>XkOn3Z>d00omZV>/2oe>6i@?oEX?R00CoHhGNogj@f_mnT=[oOY3J0onMWM@3okBXc0CoaJo500Go
cKK3olne`?o?]L3ockG0o`000003omBj`003omJj_OoD_/Goe[k200;oe[k20oooool00ol0003ooooo
ooooo`0cooooo`002Oooool01000003oooooooooooooool/00000003o`0000000000000001D06ATI
3P00000E03<c<`T0000000?o00000000000I6AT05@0I6AT00ol00000<c<c03<c<`0303<c<`050000
001<C4`0C4a<04a<C0000000101VIVH00ol00000Ogmo07moO`0507moO`05o`00001VIVH0IVIV06IV
IP0000000`1<C4`01P000000<c<c03<c<`0c<c<0000001TI6@Cooooo00<00000ooooooooool0EOoo
ool2o`0000?ooooo2onY_NP2ojRmj0;oZ;cX0onU^nT00onQ^N[oWkSZoinhjP03oiFck0;oPjS]0omZ
V>/2oe>6i@;oBg_O0_mSQMh3ogj@fP?oWIgD00?o]:S<okFWboneYl/00oo5[lD3olne`004om6e_Ol0
003oe;[0omBj`0;oe[Zm00Coe;k5omJn`_oF_/;oe[k20oooool00ol0003oooooooooo`0cooooo`00
2Oooool01000003oooooooooooooool[000001806ATI1`00000^03<c<`L000003@0I6AT2000000H0
<c<c00D0000004a<C01<C4`0C4a<o`00000306IVIP030000001oOgl0Ogmo00H0Ogmo00D0000006IV
IP1VIVH0IVIV0000000304a<C0060000000c<c<0<c<c03<c<`0000006ATI1?ooool00`00003ooooo
ooooo`1Booooo`?o00000oooool?ojVmj0?oZ;cX0onU^nT3oinhjP03oiFck?nB/NcoOZG]00;oOZG]
0_mRT^T3oe>6i@03od]kgomIOMcoFGgL00?oOY3J0_nMWM@00onKVm;o]JO;okFWb`02okFWb`04olF_
aOo7[l;oajo2olne`0;odKFm00?o0000omBj`?oF^[d00_oF^[d3omJn`P;of;fo0oooool00ol0003o
ooooooooo`0booooo`002Oooool01000003ooooooooooooooolX000001406ATI1000000>03<c<b00
00003P0c<c<7000000806ATI1000000703<c<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1V
IVH000002@1oOgl00`000000IVIV06IVIP0206IVIP040000001<C4`0C4a<000000<0<c<c00<00000
01TI6Oooool00oooool00`00003oooooooooo`1@ooooo`;o00001?ooool@ojVmj003ojVlj?nX_>So
Z;cX00;oZ;cX00?oYK_YojFjj?nN]nX00_nN]nX3oi:ak0?oOZG]00CoHY;YodMnh_m7O^;oAgkR0_ln
LM/2oeUmg0;oNH_I1?nKVm82okFWb`04okJVb?o7[l;oajo2olN_`P?odKFm00?o0000om>d^ooF^[d0
0_oF^[d00ooH^K[oe[k2omRm_`02omRm_`?ooooo00?o0000ooooooooool0<_ooool000Wooooo00@0
0000oooooooooooooooo9000000B01TI6@<000002`0c<c<700000200C4a<1`00000>03<c<`800000
2P0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000002P1oOgl01@000000
IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c<c<0<c<c00000004ooooo`0300000?oooooo
oooo04gooooo0ol00003oooooa;oZKgX0onY_>P2ojRlj004ojNkionU^^SoYK[XojFjj0?oW[OZ00?o
T[7/oi2]j_n@[NX00_miXN/2oeZ<i`?oAgkR00Co?W7KodmffOm?M]WoCgKI0_miRmT3oi^KdP04okFW
bonfY/So]ZK8okJVb0;oajo200CobJk0om6e_OoA]Kgo00000_oC];/00ooF^[gof;VjomRi^P03omRm
_`;ofKbk0oooool00ol0003oooooooooo`0aooooo`002Oooool01000003ooooooooooooooolQ0000
0003o`00000I6AT06ATI00/06ATI1`00000703<c<`L000001`1<C4`:00000003o`00000000000000
01<000001`1<C4`700000140<c<c0P00000404a<C0050000001VIVH0IVIV06IVIP000000301oOgl0
1@000000IVIV06IVIP1VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c00000004ooooo`030000
0?oooooooooo04_ooooo0_l00004oooooa3oZKgX00?oZKgWojVmj?nY_NP00_nY_NP00onY_>SoZK_W
ojVki`03ojNki`03ojFjj?nT]nKoY;OV00?oWKCX0on@[NX2ogVQj`;oFXcW0_lkM=h2ociaf`;oCgKI
0_mcQ]L2oi^KdP03oiZIdOnfY/So]ZK800;o]ZK800Koajo2olV^`?o9[/3obJk0om6e_Ol00002om>d
^`?of;Vj00?of[RgomRm_ooI_;/00_oI_;/4ooooo`03o`000?oooooooooo033ooooo0009ooooo`04
00000?ooooooooooooooob0000003P0I6AT00`000000<c<c03<c<`0803<c<`@000001`1<C4`70000
0200IVIV1`00000704a<C0<00000300c<c<2000000D0C4a<00<0000006IVIP1VIVH00P1VIVH01000
0000Ogmo07moO`1oOgl6000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0050000000c
<c<0<c<c03<c<`0000001?ooool00`00003oooooooooo`18ooooo`?o00000ooooolAojVmj0CoZKgW
0_nY_NP5ojVki`03ojNkionW^>GoY;OV00?oY;OV00?oWKCXoif^hon?YnH00_n?YnH2ogJJi`?oDhCS
00?o>gCNoc5WeolaImL00om?M]T2og>6e`?oVYWA0_nfY/P00ongYLOobJk0olV^`002olV^`006om>d
^ol0003odkBkom>d^ooE/kSof;Vj0_oJ^;L4omVl^`05om^k^?ooooooooooooooool00000<_ooool0
00Wooooo00@00000oooooooooooooooo7@00000>01TI6@<00000200c<c<3000000L0C4a<10000007
06IVIR0000001`1VIVH3000000L0C4a<1`00000303<c<`8000001P1<C4`00`000000IVIV06IVIP02
06IVIP050000001oOgl0Ogmo07moO`0000001P2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV
00@0000004a<C01<C4`000000P0c<c<00`00003oooooooooo`02ooooo`0300000?oooooooooo04Go
oooo0ol00002oooooa;oZKgX1_nY_NL2ojVkiPGoZK_W00CoZ;STojNhiOnW^>GoYkSU0_nT]nH01?nT
/>7oWJkSoif^honM[^<3ohnWiP;oMY[W0_mCQ><2oc9[f@04oc5Weom4KMKoA6gFodA]eP?oLhKG0_nJ
VM401?nfY/So]jG7okNUaongYLL2olV^`0;obZjm00Go0000om>d^ooE/kSoeK>homRi^P02omZh]`03
om^g]?oI_;_ofKbk00;ofk^h1?ooool00ol0003oooooooooo`0_ooooo`002Oooool01000003ooooo
oooooooooolJ000000d06ATI0P0000000ol00000000003<c<`0603<c<`0400000?l0000000000000
00H0C4a<1000000406IVIPL000001`1oOgl3000000;o00001P0000000ol000000000000000040000
00L0Ogmo1000000606IVIP0400000?l000000000000000X0C4a<0`00000704a<C006o`00001VIVH0
IVIV06IVI_l0000000000`1oOgl00`000000VIVI09VIV@0609VIV@05o`00001oOgl0Ogmo07moOol0
00000P1VIVH010000000C4a<04a<C000000203<c<`0300000?oooooooooo00;ooooo00<00000oooo
ooooool0@oooool2o`0000;ooooo4onY_NP6ojVmi`GoZK_V00?oZK_WojVhi?nX^>@00onX^>@00onW
^>GoYk7OojNag`03ojB`h@03oif^honLXm[oSikM00;oSikM0_mgTN03oe9kg003oc9[fOlVGM7o9UgA
00;oA6gF0om^PMH2oiVFd0Co]jG700GobJk0olZ^_Oo:[[gobZjmo`000003omFc^0;of[Rg0ooK]k@0
1?oI_;_ofk^hom^k^?oM^[D4ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?oooooo
oooooooooaP0000000?o000001TI6@0I6AT02P0I6AT2000000P0<c<c0`00000704a<C080000000?o
000006IVIP1VIVH00P1VIVH4000000L0Ogmo1`00000B09VIV@L00000101oOgl6000000@0IVIV0`00
000@04a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmoo`00000909VIV@050000
001oOgl0Ogmo07moO`0000000P1VIVH010000000C4a<04a<C000000203<c<`0300000?oooooooooo
00;ooooo00<00000ooooooooool0@?ooool3o`0000;ooooo4_nY_NP7ojVmi`KoZK_V1?nY^>@2ojRh
i003ojR`g_nW/MooYk7O00;oYk7O00?oY;3Qoj>UeonLXmX00_nLXmX3ohnNg@;oMi7P0_mBNm`2obmR
d`;o9UgA0_m4KMH3ofj1eP;oVIK@0ongYLL4olZ^_@06o`000?oE/kSoeK>homFc^?oG/[Cof[Rg0ooK
]k@2om^k^0;ogKZe1?ooool00ol0003oooooooooo`0^ooooo`002Oooool01000003ooooooooooooo
oolG000000`06ATI0P00000903<c<`030000001<C4`0C4a<00D0C4a<0`00000406IVIP<00000101o
Ogl7000000<0VIVI5_l0000709VIV@<000001`1oOgl3000000@0IVIV1000000:04a<C0800000101V
IVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00L0VIVI00D0000007moO`1oOgl0Ogmo
0000000206IVIP040000001<C4`0C4a<00000080<c<c00<00000ooooooooool00_ooool00`00003o
ooooooooo`0nooooo`;o00000ooooolBojVmj0KoZKgW1?nY^nH5ojVgh`03ojVhi?nX[mgoZ;3M00;o
Z;3M0onX/=h2ojNag`04ojFTe?nSYMOoXjGGoj>Ue`?oW:?J00?oSikMoi2Ad?mjQ]@00_mjQ]@2oe9k
g003obmRdolQDl_o8E?;00;o>fCA0om^PMH3oiVFd003okNUaonhY<Co^:C400?obZjm00?o0000omFc
^?oE/kP00_oG/[@4om^g]005ombf/?oK^kSogKZeomfj]OoP^k<01?ooool00ol0003oooooooooo`0]
ooooo`002Oooool01000003ooooooooooooooolE000000d06ATI00?o000003<c<`0c<c<01`0c<c<2
000000D0C4a<0`00000406IVIP<00000101oOgl3000000@0VIVI1_l0000F0;>c/`Ko0000102IVIT4
000000H0Ogmo00<0000006IVIP1VIVH01@1VIVH2000000L0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00T0VIVI00L0000007moO`1oOgl0Ogmo0000
001VIVKo000000<0C4a<00@0000003<c<`0c<c<000000oooool00`00003oooooooooo`0kooooo`?o
00000_oooolCojVmj0?oZKgW1onY^nH6ojVgh`04ojR^g?nX[mgoZ:oMojR_g@?oZ;3M00?oZ;3NojJS
donUY=@00onUY=@00onSYMOoXIG8oibEc002oibEc0?oT97@0_mjQ]@2oeQcd`;o;f;C0_lQDl/01?lk
I=7oJGcCofUldomYO=<3oiRDcPCo^:C400CobZjmolb]^_l0003oeK>h0ooG/[@00ooH/K7ofkNdom^g
]002ombf/0?ogKZe0_oP^k<4ooooo`03o`000?oooooooooo02cooooo0009ooooo`0400000?oooooo
oooooooooa@0000000?o000001TI6@0I6AT02P0I6AT2000000H0<c<c0`00000504a<C08000000`1V
IVH4000000<0Ogmo1000000309VIV@Co00000`2c/k<Lo`0000<0/k>c1?l0000409VIV@8000001@1o
Ogl2000000L0IVIV1@0000000ol00000000006IVIP0406IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00P2IVIT5000000@0VIVI00@0000007moO`1oOgl000000P1VIVH010000000C4a<
04a<C000000203<c<`0500000?ooooooooooooooo`000000>oooool2o`0000?ooooo4?nY_NP6ojVm
i`KoZK_V1_nY]n<5ojR^g0;oZ:oM0_nX/=d01?nVX]7oYZ?CojJSdonVXm<2ojFTe004oj>Da_nQULSo
XIG8oj6Eb0?oW9G<0_n@TM03ogZ6e0;oF7?C0_lcFl/00olQDl_o=Ec<ocELc002ofUld`CoV9C>0_nh
Y<@01?niX/;oc:fjolb]^_l00003omNb]0;of;6a00KofkNdombf/?oL][3og;J`omje[_oM^[D3on2k
/`Cooooo00?o0000ooooooooool0;?ooool000Wooooo00@00000oooooooooooooooo5000000<01TI
6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`2000000@0IVIV00<0000007mo
O`1oOgl0101oOgl00`000000VIVI09VIV@0209VIV@?o0000102c/k<3o`0000L0c<c<3_l000070<c<
c0?o0000102c/k<3o`0000<0VIVI0P00000507moO`8000004@1VIVH01@000000Ogmo07moO`1oOgoo
000000@0VIVI00<000000;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00@0
000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<`000003ooooo`0300000?oooooooooo03Ko
oooo0ol00003oooooa3oZKgX1_nY_NL6ojVkiPKoZKOS00?oYjgLojR^g?nX[]`00onX[]`01?nUWloo
YJ3@ojFPd?nUX=03ojJRd@03ojJSdonST/?oXiC600?oXiC60onQULP2oibEc003oi2Ad?nBQL;oOgg6
00;oOgg60omQK<P00olcFl_o8Tg4ob5Cb`02ocELc0;oJGcC0onHU<h01onhY<Co^J;2okVR`_niX/;o
c:fjo`000?o=ZkL00_oG/[@2omRa/@?og;J`0_oN]Jh01OoM^[Goh;^con2k/ooP^k?oi;ja00Cooooo
00?o0000ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo4`00000<01TI6@03o`00
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo00<0Ogmo0P00000309VIV@;o00001@2c/k<2o`0000H0c<c<1?l0000>0>KViPCo0000
1P3<c<`00ol00000/k>c0;>c/`040;>c/`03o`00002IVIT0VIVI0080VIVI0P00000507moO`03o`00
001VIVH0IVIV00d0IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000L0
/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`030000001VIVH000000080C4a<00Co000003<c
<`0c<c<000000oooool00`00003oooooooooo`0cooooo`?o00001?oooolAojVmj0CoZKgW1onY^nH6
ojVgh`CoYjgL0_nX[]`01?nUW/ooYIo?ojFOconUWll3ojFPd003ojJRdOnRT<7oXi;300;oXi;30onS
U<H2oj6Eb003oin7^_nKR;koVhRn00?oTXG20_moOLH3of5/b003oceG`olcFl_o8Tg400;o=Ec<0_mU
M/l2oiRDcP03oiN@boniX/;o^J;200;o^J;200Goc:fjo`000?o=ZkOocJ^gomNb]002omRa/@03omV_
[_oL][3og;J`00;og[F^0ooP^k<2onBn/@Cooooo00?o0000ooooooooool0:oooool000Wooooo00@0
0000oooooooooooooooo4P00000<01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0
101<C4`00`000000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0
0P2IVIT00ol00000/k>c0;>c/`030;>c/`;o00001@3<c<`3o`0001H0i^KV0_l000050<c<c0;o0000
1@2c/k<00ol00000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0
2`1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl000002@2c/k<010000000
VIVI09VIV@00000207moO`030000001VIVH000000080C4a<00<0000003<c<`0c<c<01?ooool00`00
003oooooooooo`0aooooo`;o00001?oooolEojVmj003ojVmionY^nOoZK_W00CoZK_V1_nY]n<6ojN]
g003ojBMc_nUW/ooYIk?00;oYIk?0_nUWll2ojFPd004oj6>_onRT<7oXY31oj:@`@?oXi;300?oXiC6
oj25]onOQkX00_nOQkX3oi^8_P;oTXG20omoOLH2of5/b0;o?EO300Go8Tg4oc=Ea_lcELKo=Ec<ofEf
c`04oiN@b`;o^J;200Go^J2oolf[]oo=ZkOo0000olf[]`02omRa/@?ofJn^00Gog;J`omje[_oN]Jko
hKJ[on2k/`03onBn/@03onS1[ooooooooooo00;ooooo00?o0000ooooooooool0:_ooool000Wooooo
00@00000oooooooooooooooo4P00000<01TI6@030000000c<c<0<c<c00D0<c<c00?o000004a<C01<
C4`0101<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00`2IVIT00ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00@0c<c<00?o00000>KViP3V
i^H06@3Vi^H00ol00000c<c<0<c<c0030<c<c003o`00002c/k<0/k>c00<0/k>c00?o000009VIV@2I
VIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00/0IVIV00<0000007moO`1o
Ogl00P1oOgl01@000000VIVI09VIV@2IVIT0000000T0/k>c00@0000009VIV@2IVIT000000P1oOgl0
0`000000IVIV0000000204a<C0030000000c<c<0<c<c00Cooooo00<00000ooooooooool0;_ooool3
o`0000;ooooo6?nY_NP5ojVki`03ojVki_nY]nCoZKOS00CoZKOS1_nW[M`4ojBMcP?oYIk?00?oYIo?
oj6<__nQS[l00_nQS[l3oj:@`@;oXi;300?oWh>doj25]onPQKL01?nOQkX2oi^8_P?oTXG20_moOLH3
of5/b003oceG`olYBKko:DVn00;o<eG60_mUM/l3oiN@b`06okVR`_niX;oo^J2ookVP_oo=ZkOo0000
0_o>ZK@01?oH/K7ofJn^omV_[_oI[jh2omje[P;ohKJ[0ooT_[42onS1[`Gooooo00?o0000oooooooo
ool0:Oooool000Wooooo00@00000oooooooooooooooo4@00000<01TI6@030000000c<c<0<c<c00H0
<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080
Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00@0
c<c<00?o00000>KViP3Vi^H01P3Vi^H<o`0000T0i^KV00?o00000<c<c03<c<`00`3<c<`00ol00000
/k>c0;>c/`030;>c/`03o`00002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000
IVIV06IVIP0;06IVIP030000001oOgl0Ogmo0080Ogmo00@0000009VIV@2IVIT000002P2c/k<01000
0000VIVI09VIV@00000207moO`030000001VIVH000000080C4a<00<0000003<c<`0c<c<01?ooool0
0`00003oooooooooo`0/ooooo`;o00000ooooolHojVmj0;oZKcW1?nY^nL2ojVhi0;oZKOT0_nY]n<0
0onW[]coYjgLojN]g003ojN]g003ojBLc_nTWLkoY9g>00CoY9g>00?oYIk?oj2;_OnQS;h00_nQS;h3
oj6>_`;oXY310onOPk@3oj25]`?oWhNj00?oVhRnoiao/_nDOKL00_nDOKL2ohEg^`?oJVRn0_lmEl<2
obU9_P06oc=Ea_mSL<_oHg3;of=`bonGT<_oUXg71?niX;l01Oo=ZkOo0000oljY]?o>ZKCof;6a00?o
fJn^00Gofjn[omje[_oQ]Z_ohKJ[onFiZ@02onBn/@;oj<6_00?ojlF]ooooooooool00_ooool00ol0
003oooooooooo`0Yooooo`002Oooool01000003ooooooooooooooolA000000`06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007mo
O`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00?o00000<c<
c03<c<`00`3<c<`00ol00000i^KV0>KViP060>KViP03o`00003oool0oooo00X0oooo00?o00000>KV
iP3Vi^H01`3Vi^H00ol00000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c00<0/k>c00?o000009VI
V@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00T0IVIV00<0000007mo
O`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000X0/k>c00L0000009VIV@2IVIT0VIVI0000
001oOgl000000080IVIV00D0000004a<C01<C4`0000003<c<`04ooooo`0300000?oooooooooo02Wo
oooo0ol00002oooooaKoZKgX1_nY_>L6ojVhi004ojN_gOnW[]goYjkMojN^g@?oYjkL00?oYjgLoj>M
c_nTW<h00onTW<h4ojBMcP03oin9_OnPRkgoX8^m00?oXHbn0onQS[l00onRT<7oWX2boij0/P03oin3
]0;oX8Fg0_nOQkX01?nOOZooW7nboiao/_nLOk82oiAm]`?oQGNk0_mZJ;h2odUE_0;o:DVn00Co=e30
oc=Ea_mSL<_oHg3;0onFSLL3okVP_`04oljY]?l0003ocZVdoljY]0?ofJn^0_oK[j/00ooN]JkohKJ[
onFiZ@02onFiZ@04onBn/OoX`JoojlF]on_5[@Gooooo00?o0000ooooooooool0:?ooool000Wooooo
00@00000oooooooooooooooo4000000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H01P3Vi^H3o`0000/0oooo0_l000070>KViP;o00001@3<c<`00ol00000/k>c0;>c/`030;>c/`03
o`00002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0906IVIP03
0000001oOgl0Ogmo0080Ogmo00@0000009VIV@2IVIT00000302c/k<01P000000VIVI09VIV@000000
Ogmo00000080IVIV00D0000004a<C01<C4`0000003<c<`04ooooo`0300000?oooooooooo02Oooooo
0_l00003oooooaKoZKgX1_nY_>L00onY^NGoZKSTojVhi003ojVhi004ojN`g_nW[mgoYjoMojN_g@?o
YjkM00?oYjkLoj>MconSWLh00_nSWLh3ojBLcP03ojBMc_nNRKcoWhVm00;oWhVm0onPRkd3oj6<_P03
oj6>_onMO[3oWX2b00;oWX2b0onOPk@2oj25]`?oWgj_0onLOk83oiAm]`;oQGNk0omZJ;h00om9EKco
<dRiobU9_P02ocM@`0?oHg3;0_nFSLL3okVP_`06okZM^ol0003ocZVdoljY]?o?Yk7ofJn^0ooK[j/2
on6fZ`?oiKVY0_oX`Jl2on_5[@03onk7[?oooooooooo00?ooooo00?o0000ooooooooool09oooool0
00Wooooo00@00000oooooooooooooooo4000000<01TI6@030000000c<c<0<c<c00H0<c<c00<00000
04a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00@0c<c<00?o0000
0>KViP3Vi^H0203Vi^H3o`0000H0oooo0_l000080>KViP03o`00003<c<`0c<c<00@0c<c<00?o0000
0;>c/`2c/k<00`2c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00@0Ogmo00<00000
06IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0207moO`040000002IVIT0VIVI000000@0/k>c0ol0
00050;>c/`060000002IVIT0VIVI0000001oOgl000000P1VIVH01@000000C4a<04a<C0000000<c<c
00Cooooo00<00000ooooooooool09?ooool3o`0000?ooooo5_nY_NP5ojVli`GoZKWU00?oZKSTojN`
g_nW/=h00onW/=h00onW[mgoXioAoj>Nd002oj>Nd0?oXig?0onSWLh00onTW<koWXRloij9_002oij9
_0?oWhVm0_nPRkd2oj6<_P03oial[onMO[3oWGj`00?oWX2b0onOPk@00onPQKOoWgb/oiml[003oimn
[`;oW7nb0onDOKL3ohEg^`;oJVRn0_m9EK`00olcB;Wo:DVnocM@`003of=[a@?oUXg700Go^J2ookZM
^onjWK_o0000oljY]002olnW/@06omV_[_oK[j_ofjn[om^_ZooN/JWohKJ[0ooU^JT00ooY_JOoj<6_
on_5[@02onk7[003ono8Z_oooooooooo00;ooooo00?o0000ooooooooool09oooool000Wooooo00@0
0000oooooooooooooooo4@00000<01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0
101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT0
0P2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00@0c<c<0_l0000;0>KViPKo0000
2@3Vi^H00ol00000c<c<0<c<c0040<c<c003o`00002c/k<0/k>c00<0/k>c00?o000009VIV@2IVIT0
0P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00/0IVIV00D0000007moO`1oOgl0
Ogmo0000000209VIV@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`00_l000040;>c/`03
0000002IVIT000000080Ogmo00<0000006IVIP0000000P1<C4`00`000000<c<cooooo`03ooooo`03
00000?oooooooooo02;ooooo0_l00004oooooaGoZKgX1_nY_>L2ojVji@CoZKWU0_nW/Ml4ojN`gP04
oj>Pd_nSWm7oXioAoj>Od@?oXik@00?oXig?oif8_OnMR;`00_nMR;`2oij8_0?oWXVl0onORKd00onP
RkgoVgZ^oial[`02oial[`?oWGj`0onNP;800onOPkCoWWVYoiml[002oiml[0?oWgj_0onLOk800onD
OKOoVG^aoh]e]P02oh]e]P;oLVVi0_mBE[T2oc=8^@;o=e300_mSJlD3oiJ9``?o^Yfk00Co0000oljY
]?o?Yk7ocjNa0ooK[j/2omjaZ@?oiKVY0_oY_JL2on_5[@;ok/N/00?oklRZooooooooool00oooool0
0ol0003oooooooooo`0Vooooo`002Oooool01000003ooooooooooooooolA000000`06ATI00<00000
03<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00P1oOgl00`00003o000009VIV@0309VIV@03o`00002c/k<0/k>c00<0/k>c00?o0000
0<c<c03<c<`01@3<c<`00ol00000i^KV0>KViP0D0>KViP?o00001@3<c<`2o`0000@0/k>c0_l00004
09VIV@03o`00001oOgl0Ogmo00<0Ogmo0P00000>06IVIP050000001oOgl0Ogmo07moO`0000000P2I
VIT00`000000/k>c0;>c/`020;>c/`05o`00003<c<`0c<c<0<c<c?l00000102c/k<00`000000VIVI
0000000207moO`030000001VIVH000000080C4a<00<0000003<c<oooool00oooool00`00003ooooo
ooooo`0Oooooo`?o000000?oooooojVmj?nY_NP05_nY_NP6ojVli`;oZK[V0onY^^D00onY^NGoYk;P
ojNag`03ojNag`03ojN`g_nTX]?oXj3B00;oXj3B0onSWm400onSW]3oWHVnoif8_@02oif8_@?oWHRl
0_nNR;`3oij9_003oin9_OnJNJgoVgZ^00;oVgZ^0onLO:l2oien/0;oWX2b00?oWGNWoiiiZOnNNJT0
0onOO:`3oimn[`;oW7nb00?oWgb]oiUk/OnINk400on;MKH2og9Y^@?oDUJi00?o<dRioce>^olmC[/0
0_mSJlD4oiJ9``;o^Yfk00Go0000olnW/Oo?Yk7ocjNaom6W[P02om^_Z`;og[6Y0ooU^JT2onVmY`03
ong1YOo[aJgok/N/00;oklRZ00?ol<RYooooooooool00oooool00ol0003oooooooooo`0Uooooo`00
2Oooool01000003ooooooooooooooolA000000`06ATI00<0000003<c<`0c<c<01P0c<c<00ol00000
C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000
VIVI09VIV@0209VIV@;o0000102c/k<00ol00000c<c<0<c<c0050<c<c0?o0000403Vi^H3o`0000L0
c<c<00?o00000;>c/`2c/k<00P2c/k<2o`0000D0VIVI0P00000407moO`030000001VIVH0IVIV00h0
IVIV00D0000007moO`1oOgl0Ogmo0000000209VIV@030000002c/k<0/k>c0080/k>c00Go00000<c<
c03<c<`0c<c<o`0000040;>c/`030000002IVIT000000080Ogmo00<0000006IVIP0000000P1<C4`0
0`000000<c<cooooo`03ooooo`0300000?oooooooooo01cooooo0ol00002oooooaSoZKgX0_nY_NL2
ojVli`03ojVki_nY^^KoZK[V00;oZK[V0_nX]>83ojRch@;oYk;P0_nW/Ml01?nTXmGoY:;CojBRdonT
X]<2oj>PdP;oXioA00?oWHZooif9__nMRKh00onMR;d3oif8_0;oWXRl0_nNRK`00onIN:goVWV]oiYi
[@03oi]j[P?oW7b_0_nMO[03oiegY`?oWWVY0onOO:`2oimn[`?oWgb]0onINk43oh]e]P;oLVVi0_mB
E[T01?lcB;Wo?Djkoce>^olmC[/2of=[a@?oUXW300Go^Yfkok^K^?l0003o^i^holnW/@03om6W[P05
om^_ZooN/JWog[6Yon:dYooU^JT00_oY_JL2ong1Y@;ok/N/00?oklRZoo38ZOo`b:T01Oooool00ol0
003oooooooooo`0Uooooo`002Oooool01000003ooooooooooooooolB000000`06ATI00<0000003<c
<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV0P00000407mo
O`030000002IVIT0VIVI00<0VIVI0_l000030;>c/`?o00001`3<c<`@o`0000L0c<c<0ol000030;>c
/`;o00001@2IVIT2000000D0Ogmo00<0000006IVIP1VIVH01@1VIVH5000000D0IVIV00D0000007mo
O`1oOgl0Ogmo0000000209VIV@030000002c/k<0/k>c0080/k>c00Go00000<c<c03<c<`0c<c<o`00
00040;>c/`030000002IVIT000000080Ogmo00<0000006IVIP0000000P1<C4`00`000000<c<coooo
o`03ooooo`0300000?oooooooooo01[ooooo0_l00003oooooaOoZKgX1?nY_NL5ojVkiP03ojVji_nX
]^?oZ;KS00?oZ;CR00?oZ;?QojFWf?nTYMH00_nTYMH3ojBSe@;oY:;C00?oXj3Boif<`OnMR[l00_nM
R[l3oif9_P?oWHRm00CoWHRloiMg[OnHMjgoV7N]0onIN:d3oiYi[@;oVgZ^0onLO:l00onMO[3oVgBV
oiegY`02oiegY`?oWWVY0onOO:`00onOOZooXG^Yoj5kZ@03oiml[@;oVG^a0on;MKH2og9Y^@;oDUJi
00Co>dVfoc=8^OlmC[_o?Djk0_mVJ<02oiJ9``06oiN6_onkVkSo^i^ho`000?nkVkSocjNa0ooAYjh2
omjaZ@;oh[BW00?oiKVYonVmYooY_JL00_o]`JD00oo`a:?ok/N/ono8ZP02oo38Z@03oo38Z?oooooo
oooo00?ooooo00?o0000ooooooooool09?ooool000Wooooo00@00000oooooooooooooooo4P00000=
01TI6@03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo0080Ogmo0`00000409VIV@?o00000`2c/k<7o`000100c<c<1ol00004
0;>c/`;o00001@2IVIT2000000D0Ogmo0P00000506IVIP<000001@1<C4`00`000000IVIV06IVIP03
06IVIP040000001oOgl0Ogmo00000080VIVI00D000000;>c/`2c/k<0/k>co`0000050<c<c005o`00
002c/k<0/k>c0;>c/`0000000P2IVIT01@000000Ogmo0000001VIVH000000080C4a<00<0000003<c
<oooool00oooool00`00003oooooooooo`0Gooooo`?o00000ooooolJojVmj003ojVmionY^nOoZK_W
00CoZK_V00?oZ;OSojRfhonX]^<00_nX]^<00onX]>;oYJWJojFWf002ojFWf0?oY:GF00CoY:?Eoif@
aOnMS/?oWHk30onMS<43oif:_`;oWHVn0_nMR;d00onFMjgoUgN]oiMg[@02oiQg[@CoVGR]0_nJNJd3
oi]j[P03oial[onJLZGoVgBV00;oVgBV0onMMjL2oiiiZ@;oWgb/00CoXGVVoj5kZOnQNjWoXG^Y0onO
O:d2oiUk/@?oTWZf0_mhKKX3oe9F^@03oc]9]_lmC[_o?Djk00;oIVS00onGQ[l01?nkVkSo0000o`00
0?nkVkP4om6W[P;og[6Y0_oR]:L01?oW^JGojKfWonVmYoo]`JD2oo34X`;oklRZ00Col<RYoo38Z?o`
b:Sol<NW1Oooool00ol0003oooooooooo`0Sooooo`002Oooool01000003ooooooooooooooolB0000
0003o`00000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<2000000D0C4a<0P00000506IV
IP<00000101oOgl3000000@0VIVI1ol000030;>c/a3o0000102c/k<7o`0000<0VIVI1000000307mo
O`@000000`1VIVH4000000T0C4a<00?o000006IVIP1VIVH00P1VIVH010000000Ogmo07moO`000002
09VIV@050000002c/k<0/k>c0;>c/ol000001@3<c<`01Ol00000/k>c0;>c/`2c/k<000000080VIVI
00D0000007moO`000000IVIV0000000204a<C0030000000c<c?ooooo00?ooooo00<00000oooooooo
ool05_ooool2o`0000?ooooo6onY_NP00onY_>OoZK_WojVki`02ojVki`03ojVki_nX^>CoZ;OS00;o
Z;OS0_nX]^<01?nU[=_oYJWJojFYf_nUZMX2ojFWf0;oY:GF00?oWY?8oif@aOnMT<D00onMS/<3oif<
`@;oWHZo00?oWHVnoiIg[_nFMjd00_nFMjd2oiMg[@?oV7N]0onIN:d2oiYi[@;oVgZ^00?oV72ToiYb
YOnJLZD00onKM:H3oiegY`;oWWVY0onQNJH3oj5kZ@?oWgb]00?oVG^aoj20/OnPP;400_nBN[H2ogQ]
^P?oEEVj00Co>dVfod9>^?m2C[So?Djk0_mVJ<03o`000003ok^K^?l0003o_I^e00?odJN^0_oDZJ`0
0ooN/JWoh[BWon:dY`02onNiY@;okL6U0_o`a:<00oobaJ;ol<RYoo38Z@02oo38Z003oo37YooaajKo
oooo00?ooooo00?o0000ooooooooool08oooool000Wooooo00@00000oooooooooooooooo5000000=
01TI6@030000000c<c<0<c<c00L0<c<c0P00000504a<C08000001P1VIVH4000000<0Ogmo10000007
09VIVAOo00001`2IVIT3000000@0Ogmo0`00000406IVIP<000003P1<C4`01@000000IVIV06IVIP1V
IVH000000080Ogmo00@0000009VIV@2IVIT000000`2c/k<00ol00000c<c<0<c<c0030<c<c005o`00
002c/k<0/k>c0;>c/`0000000P2IVIT01@000000Ogmo0000001VIVH000000080C4a<00<0000003<c
<oooool00oooool00`00003oooooooooo`0Fooooo`03o`000?nY_NSoZKgX01_oZKgX1?nY_>L2ojVk
i`;oZ;SU0_nX^>@00onX]n?oYZkMojJ^g@03ojF/f`04ojFYf_nOVLgoWiK:oinFbPCoWY?80_nMT<D2
oif>``;oWHc100?oUGVaoiIh[onFN:l00_nFMjh3oiIg[@?oUgN]0_nHMjd3oiUh[@03oiYi[OnGKj?o
V72T00;oV72T0_nJLZD3oi]dYP?oWGNW00?oWWVYoj1fY?nQNJH00_nQNJH4oj5kZ@03oiml[OnVPJco
X82a00;oX82a0onBN[H2ogQ]^P;oEEVj00?o>TZgoc]9]_m2C[P00ol00003oiN6_`05ok^K^?nmVkGo
0000okfK]OoAYjh00ooDZJ`2on:dY`?oikVU0_o]`JD01_o`a:?ol/FRoo;5X_obaJ7ol<RYoo38Z0;o
l<NW0_oaajH4ooooo`03o`000?oooooooooo02;ooooo0009ooooo`0400000?oooooooooooooooaH0
0000300I6AT3000000P0<c<c0P00000504a<C0<000001`1VIVH3000000@0Ogmo1`00000G09VIV@L0
00000`1oOgl4000000@0IVIV0`00000B04a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01000
0000VIVI09VIV@0000020;>c/`03o`00003<c<`0c<c<00@0c<c<00_o00000;>c/`2c/k<0/k>c0000
002IVIT0000007moO`000000IVIV0000000204a<C0030000000c<c?ooooo00?ooooo00<00000oooo
ooooool05_ooool00ol0003oZKgXojVmj00FojVmj0KoZKcW0_nY^^H3ojRii@03ojRhiOnW/^3oY[3O
00;oY[3O0onV[]d00onU[=_oX9c@oinIc@02oinIc@;oWiK:0onNTlP2oif@a@03oif>`onENk?oUGVa
00;oUGVa0_nFN:l3oiIg[P?oUWN]0_nGMjd2oiQg[@;oVGR]00?oUFfRoiM_XonGKj<00onHL:@3oiYb
Y@?oVgBV0_nMMjL3oj1fY0?oXGVV0onQNjT2ojJ1[0?oX82a0onBN[H2ogQ]^P;oEEVj0ol000001_m2
C[SoJFNmofUW_OmYIkgoUhJooiV5_@?o_I^e00?o0000om6W[_oDZJ`00_oDZJ`2on:dY`?oikVU00?o
k;fSoo34Xoo`a:<00_obaJ801?obaJ7ol<RXoo38Z?o`ajL3oo77YPCooooo00?o0000ooooooooool0
8_ooool000Wooooo00@00000oooooooooooooooo5`00000>01TI6@03o`00000c<c<0<c<c00L0<c<c
00<00000o`00000000001@1<C4`4000000H0IVIV0P0000000ol00000000007moO`0607moOaL00000
0`1oOgl300000004o`00000000000000000000@0IVIV0P0000000ol00000000004a<C00504a<C0<0
000000?o0000000000000000100000000ol00000C4a<04a<C00304a<C0040000001VIVH0IVIV0000
0080Ogmo00@0000009VIV@2IVIT000000P2c/k<00ol00000c<c<0<c<c0040<c<c00;o`00002c/k<0
/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP0000000P1<C4`00`000000<c<cooooo`03oooo
o`0300000?oooooooooo01Kooooo00?o0000ojVmj?nY_NP05?nY_NP2ojVmi`CoZKcW1OnY^^H00onX
^NGoYk?QojNbh002ojNbh0?oY[3O00?oYZkMoj6OdonPW=000_nPW=03oinIc@;oWiK:00CoWY?8oiIo
^?nFOKGoUWfe0onENk<3oiEi/@;oUWR_0_nFMjh3oiIg[@;oUgN]00?oV7N]oiA/X_nEKJ800_nEKJ82
oiM_X`CoV72T0_nJLZD3oi]dYP03oiegYonNLj;oX7JT00;oX7JT0onQNJH2oj5kZ@04ojR0Z?nVPJco
YX6/ojJ1[0?oX82a00?oTWZfoi^9_omjN<D00ol000001?mEFK[o>TZgocY:]om2C[P3ofUW_@?oVHFm
0onmVkD01_l0003oe:V/omBY[?oDZJcofZj[on:dY`;oikVU0_o/_J<2oo34X`06oo;5X_obaJ7ol/FQ
oo;5X?o`b:Sol<NW0ooaajH00ooab:Koooooooooo`02ooooo`03o`000?oooooooooo027ooooo0009
ooooo`0400000?oooooooooooooooaP000003P0I6AT3000000T0<c<c0P00000704a<C0H00000101V
IVH:000000d0Ogmo2P00000706IVIP@000001`1<C4`3000000/0<c<c00<0000004a<C01<C4`00P1<
C4`010000000IVIV06IVIP00000207moO`040000002IVIT0VIVI00000080/k>c00?o00000<c<c03<
c<`0103<c<`02ol00000/k>c0;>c/`2c/k<0000009VIV@000000Ogmo0000001VIVH000000080C4a<
00<0000003<c<oooool00oooool00`00003oooooooooo`0Eooooo`04o`000?oooooooooooooooaCo
ZKgX0onY_NL00onY_>OoZK_VojVjiP04ojVjiP06ojNehonW/n7oYk?QojNchOnW/^3oXjKH0onRXmH3
oj6Od`;oX9c@0_nOVLd00onGQ[koUh:koiN2^`02oiIo^0;oUWfe0onENk<3oiEi/@;oUWR_0_nFMjh3
oiIg[@04oiMg[OnBJj;oU6bRoiA/XP?oUFfR0onGKj<3oiQ`Y0;oVW:U0_nKM:H00onLLJ7oWW>Roiic
XP03oj1fY0?oXGVV00?oXG^YojR0Z?nXP:P00onVPJ`2oj20/@04ojb@^?l0003o0000o`0000;oNWS5
0_m<G/<2ocY:]`04od5>^Om2C[SoJFNmofUW_@?oVHFm0onmVkD00ol0003oe:V/omBY[002omZ^Z`?o
ikVU0_o/_J<00oo_`J;ol/FRoo;5XP02oo;5X@03oo;5X?o`ajOol<NW00;olLNV0_oab:H00oobb:Go
ooooooooo`02ooooo`03o`000?oooooooooo023ooooo0009ooooo`0400000?oooooooooooooooa/0
00003P0I6AT3000000P0<c<c0`00000:04a<C0@000002P1VIVH=000000X0IVIV1`00000704a<C0@0
00003`0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000P2IVIT0
10000000/k>c0;>c/ol000060<c<c00;o`00002c/k<0/k>c0;>c/`000000VIVI0000001oOgl00000
06IVIP0000000P1<C4`00`000000<c<cooooo`03ooooo`0300000?oooooooooo01Gooooo00Co0000
oooooooooooooooo5OnY_NP00onY_NOoZK_WojVki`02ojVkiP;oZK[V0_nX]n@2ojNeh`03ojNchOnT
ZM_oY:WK00;oXjKH0onRXmH01?nQWm?oVXk6oiR9`_nHRL83oiN6_P;oUh:k0onFOkP2oiIm]@;oUG^c
0onENK42oiIh[`03oiIg[_n@Jj?oTF^S00;oTF^S0_nBJj83oiA/XP;oUFfR0onGKj<3oiQ`Y0;oVW:U
0onLLJ43oiicXP?oX7JT0_nQNJH4ojR0Z0;oYX6/0ol00003oi^9_`?oNWS500?oC5k3ob]8_OljB[L0
0_m1C[T3ofUW_@?oVHFm00Go_I^eol6M]?o1WKCo0000omBY[002omZ^Z`;oikVU0oo/_J<01?o_`J;o
l/FRoo;5X_obaJ42oo;5X004oo;4WooaajKolLNVoo77YP;olLRV00?ol/RUooooooooool00_ooool0
0ol0003oooooooooo`0Pooooo`002Oooool01000003ooooooooooooooolL000001006ATI00<00000
o`00000c<c<0200c<c<6000000P0C4a<3P00000506IVIPh000002@1<C4`00ol00000000000000002
000001@0<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP030000001oOgl000000080VIVI00@0
00000;>c/`2c/k?o00001`3<c<`02?l00000/k>c0;>c/`000000VIVI0000001oOgl000000P1VIVH0
10000000C4a<0000000c<c<4ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00_oo
oolAojVmj0CoZKcW00?oZK_WojRiiOnX^ND00onX^>@00onX]nCoYJoOojF]g@02ojF]g@?oY:WK0_nS
Y]P01?nRXmKoVi;:oiZ>a_nJS/H3oiR9`P?oUhJn0_nGP[/2oiIo^0;oUWfe0onENk<01?nENK7oSf^V
oi1[Y?n@Jj@2oi1[X`?oTF^S0_nBJj83oiA/XP?oUFfR0_nGKj<3oiQ`Y003oiYbYOnJKYooW76Q00;o
W76Q0onNLj83oj1fY003oj5iY_nWOJKoZ82X00;oZ82X0ol00004ojb@^0?oVhVo0_mjN<D2odaN``03
ob]8_OljB[Oo@Dji00?oJVVn0_nIQKd00onMR;go`Ifdol6M]002ol6M]005o`000?oJ[Z_ofZj[on2d
Z_oW^JD00_o/_J<2ono1XP03oo73XOobaJ7ol/FQ00;ol/FP00?ol/BOoo77Y_oaajH00_oab:H2oo;8
Y@03oo?9Y?oooooooooo00;ooooo00?o0000ooooooooool07oooool000Wooooo00@00000oooooooo
oooooooo700000000ol0000000000000000?01TI6@D000002P0c<c<00`00003o0000000000050000
00h0C4a<1@00000>04a<C0T000002@0c<c<;000000H0<c<c00@0000004a<C01<C4`000000P1VIVH0
0`000000Ogmo0000000209VIV@040000002c/k<0/k>co`0000L0c<c<00So00000;>c/`2c/k<00000
09VIV@000000Ogmo00000080IVIV00@0000004a<C0000000<c<c1?ooool00`00003oooooooooo`0E
ooooo`03o`000?oooooooooo00Cooooo3?nY_NP6ojVli`;oZ;[V0onX^ND00onX^>CoY[;QojF_g`02
ojF_g`?oYJgM00CoY:WKoijLdOnLUlkoW9O>0onKT/X2oiZ>aP?oV8W20_nGQ[h2oiN2^`;oUWnh00?o
UWfeohi^ZOn>K:L00_n>K:L2ohm[YP;oT6^T0on@Jj<2oi5[X`;oTV^R0onDK:83oiE]XP;oUfnS0_nH
L:@00onHK9koVVjOoiY^W`04oiaaX@;oWW>R0_nPMZ@00onUNZCoYgfVojMmYP03o`000004ojR0Z?nV
PJco/i6cok>A/`?o[92h0_nKRKl00onX[M_oL93Rog2@hP02obANdP;o:dRm0_m1C[T2ofYY_P?oWHRm
1?o1WK@01?oJ[Z_o0000on2dZ_oP]:X3onbmX`;okl6R00ColL>Qoo;5XOobaJ7ol/FP0_oba9l01Ooc
a9kolLNVoo78Y_oab:Kol/RU00;ollVT00?om<ZTooooooooool00_ooool00ol0003oooooooooo`0N
ooooo`002Oooool01000003ooooooooooooooolR000001406ATI1000000>03<c<`h000001@1<C4`>
000000h0<c<c1000000;01TI6@800000100c<c<010000000C4a<04a<C000000206IVIP060000001o
Ogl0Ogmoo`00002IVIT000000P2c/k<00ol00000c<c<0<c<c0050<c<c008o`00002c/k<0/k>c0000
002IVIT0000007moO`00000206IVIP040000001<C4`0000003<c<`Cooooo00<00000ooooooooool0
5Oooool00ol0003oooooooooo`05ooooo`WoZKgX0onY_NL3ojVli`?oZK_V0_nX^^H00onX^NGoY[CR
ojJbh@02ojJbh@03ojF_gonQYMSoWj3E00;oWj3E0onNW=42oibGcP;oVi;:0_nJS/H2oiR9`P03ohmi
]_n?MK;oSgFb00;oSW:_0_n>L:`2ohi^Z@?oSVbW0_n?JjH2oi1[Y0?oT6^S0onAJj<2oi9[XP;oU6bR
0onEKJ82oiM_X`?oV6bN0_nJKYl4oiaaX@;oWW>R00?oX7JTojEjY?nUNZ@00_l000001?nWOJKoZ82X
ojR0Z?nXP:P3ok>A/`?o[92h1?nX[M/2og2@hP;o95kB00?o:dRmocA=__ldCKh00_mZJKh4oif8_@;o
`Ifd0_o7Y;D01?l0003oh;BZon2dZ_oV^jX2onbmX`04ono1X_oa`j7olL>Qoo;3X0;ol/FP0_oba9l0
1Ooca9kom<FMoo78Y_oab:Kol/RU00;ollVT00?om<ZTooooooooool00_ooool00ol0003ooooooooo
o`0Nooooo`002Oooool01000003ooooooooooooooolU000001806ATI1`00000E03<c<`D000005@0c
<c<7000001406ATI00<0000003<c<`0c<c<00P0c<c<01P000000C4a<04a<C0000000IVIV00000080
Ogmo00<0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0050<c<c006o`00002c/k<0/k>c0000
002IVIT000000P1oOgl01P000000IVIV0000001<C4`0000003<c<`Cooooo00<00000ooooooooool0
5Oooool00ol0003oooooooooo`06ooooo`WoZKgX00?oZKgWojVlionY^nL00_nY^nL2ojVkiP04ojNg
i?nW]^?oYkKSojNfh`;oY[CR00?oY[;Qoj:YfonRZM/00_nQYMP3oinPe@;oWYcA00CoW9O>oiB7`onB
P[koTX:n0_nAOKX3ohmi]P;oSgFb0_n>LZl2ohi`[0?oSVjY0_n>K:L3ohm[YP;oT6^T0_n@Jj<3oi5[
X`;oTV^R0onDK:82oiE]XP03oiM_XonFJYkoV6bN00;oV6bN0onJKYl3oiaaX@;oWW>R0ol00003ojMm
YP;oZ82X00?o]Hn_ok>A/oncTK<00_ncTK<00on/T;So`[K>ol:fcP02ojR]f`;oSnOi00Go59CTobAN
d_lTG];o03^oob]8_@02ocA=_P;oJVVn0onMR;d01_o1WKCoajBeolNT]Oo7Y;GofZj[o`0000?oi[^Z
0_o_`J82oo73X@04oo;3X?obaJ3ol/FPoo;4W`;ollBN0_odaId2oo;8Y@04oo?9Y?odbZCom<ZTooC;
Y0Cooooo00?o0000ooooooooool07Oooool000Wooooo00@00000oooooooooooooooo9`0000000ol0
0000000001TI6@0D01TI6@<0000000Co000000000000000000007P0c<c<:000001T06ATI00D00000
03<c<`0c<c<0<c<c0000000204a<C0030000001VIVH000000080Ogmo00<0000009VIV@0000000P2c
/k<00ol00000c<c<0<c<c0050<c<c006o`00002c/k<0/k>c0000002IVIT000000P1oOgl01P000000
IVIV0000001<C4`0000003<c<`Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`OoZKgX1?nY_>L00onY^nOoZ;WUojRii@03ojNgi003ojNfhonT/>3oY;3P00;oXjgN0onRZM/2
oj6Uf004oinPeOnHT/goUXg8oiJ=b0;oU8O30onBP[h2oi5m^P?oSgVf0_n?MK82ohib[`04ohi`[?n>
KZWoSVjYohi^Z@?oSVbW0_n?JjH2oi1[Y0;oT6^S0onAJj<2oi9[XP?oU6bR00?oUFfRoiAXWOnFJYh0
0_nFJYh2oiQ/WP?oVVjO0_nLLJ43o`0000CoYGZT0_nWOJH01?nXP:So]Hn_okF?[oneSjl2ok>A/`06
olfgaOo2]/ko`[K>ol:fc_o:o>?oYLKa0_nT_N/3oiZikP04o`0cZ?l0>koo=4fnocA=_P;oIfg50_nM
R;d00onRSl7oajBeolNT]@02olNT]@;oh;BZ00?o0000onJkZ_oV^jX00_o_`J801?oa`j7ol/>Poo;3
X?ob`il2oo;4W`;ollBN0_odaId01?oeaYcollVToo?9Y?odbZ@2ooC;Y003ooG<Xooooooooooo00;o
oooo00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooooooooooo;000000I01TI6Ah0
00008`0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP0000000P1oOgl00`00
0000VIVI000000020;>c/`03o`00003<c<`0c<c<00D0c<c<00Ko00000;>c/`2c/k<0000009VIV@00
000207moO`060000001VIVH0000004a<C0000000<c<c1?ooool00`00003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo0onY_NP5ojVli`?oZ;[V0_nX^ND00onW]nCoYK;RojB`h003ojB`h0;o
XjgN00CoXZWKoibNeOnJV=7oVYSA0onHT/d2oiJ=b0;oU8O30_nBP[h2oi5m^P?oSgVf0_n?MK82ohib
[`;oSW2/0_n>KZT3ohi/Y`;oSf^V0_n@Jj@3oi1[X`;oTF^S0_nBJj82oiA/XP03oi9WWOnDJ9goU6RM
00?oUVZN0onHK9h01OnJKYoo0000o`000?l0003oXGBP00?oXgNR0onUNZ@2ojMmYPCo]Hn_00Ko/i6c
olfgaOo=]lGocKO5ol:fc_o:o><2ojRojP03ojBmjonT^>OoV[CZ00?oV[CZ00Go00fAo`i4`_l>A<;o
=4fnofM]a@04oj:?`@;oajBe0_o?[KL01OoP]:[oi[^Zo`000?oV^j[ojl6Y00;olL>Q0_ob`j000oob
`iool/BOoo;4W`02oo?4WP;om<FM00ComLJLoo?9Y?ocbJCom<ZT0_odbj@00ooec:?oooooooooo`02
ooooo`03o`000?oooooooooo01cooooo0009ooooo`0400000?oooooooooooooooc<00000A@0I6AT7
000000P06ATI00T0000003<c<`0c<c<0<c<c0000001<C4`0000006IVIP0000000P1oOgl00`000000
VIVI000000020;>c/`03o`00003<c<`0c<c<00D0c<c<00Ko00000;>c/`2c/k<0000009VIV@000002
07moO`060000001VIVH0000004a<C0000000<c<c1?ooool00`00003oooooooooo`0Dooooo`03o`00
0?oooooooooo00[ooooo0onY_NL00onY_>OoZK_WojVki`03ojRkiP03ojRji_nW]nCoY[GS00;oY[GS
0_nU/^82ojB`h003oj2Xg?nNXmWoWZ?I00?oW9kE0_nJV=42oiRBc@;oUXg80_nDQl<3oi:2_P;oTGfj
0_n?NKH2ohme/P;oSW:_0_n>L:`3ohi^Z@;oSVbW0_n?JjH2oi1[Y0?oT6^S00CoTF^SohiUWOn@IYgo
T6JM0onBIid2oiAXW@?oUVZN00KoV6bNo`000?l0003o0000oiY^WonLLJ42oj5dX0?oXgNR0onUNZ@0
0onWOJKo]8b/okB<[003okF?[`CocKO500Cog_k?ojW0j_nX_n[oZ;WV0onT^>L2oiZdjP03oib^i?n6
YNWo00fA00;o3TC20_mWKLD3oj:?`@04olNT]Oo?[KOocjfgoln]]`;oi[^Z00?o0000on_1ZOo[`JT0
0_oa`j401?ob`j3ol/>Ooo;3Woob`ih2oo?4WP?om<FM00GomLJLooK7VoodbZCom<ZTooC;Y002ooG<
X`03ooK=Y?oooooooooo00;ooooo00?o0000ooooooooool06oooool000Wooooo00@00000oooooooo
oooooooo>000000i01TI6@l000001`0I6AT01ol00000<c<c03<c<`0c<c<0000004a<C00000000P1V
IVH01@000000Ogmo0000002IVIT000000080/k>c00?o00000<c<c03<c<`01@3<c<`03_l00000/k>c
0;>c/`2c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C0000000<c<c1?ooool00`00003o
ooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?oZKgWojVlionY_>L00onY^nL00onX^nKo
YkSUojNgi002ojNgi003ojJehonS/>7oXk3Q00;oXZcO0onPZ=`2oijSf@;oW9kE00CoVYSAoi6=c?n>
Q/KoSXK60_n;Ol42ohUj_0?oR7Bg0_n7L;82ohI/[P;oQVV[0_n6IjL2ohIUY@?oSVjY0_n>K:L01?n?
JjKoRV>Ooh]SW_n;Hih3oheTW@;oSVFM0_n@IYd3oi9WW@;oU6RM00CoUVZNo`000?l0003o00000_nH
K9h2oiY^W`?oXGBP0onSMj83ojEjY0?o]8b/0oneSjl01OoA]/3ocKO5olfgaOoNo/ooZL3Z00;oZKWU
0_nX^NH00onT^>OoY;7QojBah@03oib^i003ohJUjOl03I7o3TC200;oFg;@0onRSl44oln]]`?oi[^Z
00?o0000on_1ZOo]`jT00_ob`j02oo;3W`;ol/>N00?ollBNooC5WOodaId00_oeaY`01Oofai_omlRK
ooC;Y?odbjComLbS00;om/fT00?om/jTooooooooool00_ooool00ol0003oooooooooo`0Jooooo`00
2Oooool01000003ooooooooooooooolh00000003o`0000000000000000X000007P0I6ATN000000H0
6ATI00L0000003<c<`0c<c<0<c<co`00001<C4`000000080IVIV00D0000007moO`000000VIVI0000
00020;>c/`03o`00003<c<`0c<c<00H0c<c<00go00000;>c/`2c/k<0000009VIV@000000Ogmo0000
001VIVH0000004a<C0000000<c<c00Cooooo00<00000ooooooooool05?ooool00ol0003ooooooooo
o`0=ooooo`;oZKcW00?oZK_WojRji_nX^^H00_nW^>D00onW]nCoY;?SojBch`03oj>`h@;oXZcO00Co
X:SLoiVPfOnGV]GoUi[E0_nCTm03oi6=c004ohj6a_n;Ol7oRgo1oh]o`@;oRGZl0_n8M;L2ohM`/P;o
QVb^0_n6JJ/2ohIWY`;oQVFU0on7I:<2ohQSX@;oRV>O0_n;Hih3oheTW@;oSVFM0_n@IYd3oi9WW@?o
00000_nFJYh3oiQ/WP03oiY^WonNLIooXGBP00;oXGBP1?nSMj82ojEjY0Co]8b/00Go]Hn_om6f`?oA
]/3ocKO5onCm`P02ojVii003ojViiOnY/=goYk7O00;oYk7O0onT/N401_nL[^CoWJCJohbNgon<W]oo
02B]o`i4`P;oFg;@00?oXXo1ojNJbOnWV/T00oo?[KL01_oG]k[oi[^Zon_1ZOo[`JWo0000ong3Z@;o
l/>P00?ol/>Ooo;3W_ob`ih00_ob`ih2ooC5W@04ooG6W?ofai_om/NKooO8V`;om<^T00ComLbSooK=
Y?ofcJCom/jT1?ooool00ol0003oooooooooo`0Jooooo`002Oooool01000003ooooooooooooooon2
000000D06ATI00L0000003<c<`0c<c<0<c<c0000001<C4`000000080IVIV00D0000007moO`000000
VIVI000000020;>c/`03o`00003<c<`0c<c<00H0c<c<00go00000;>c/`2c/k<0000009VIV@000000
Ogmo0000001VIVH0000004a<C0000000<c<c00Cooooo00<00000ooooooooool05?ooool00ol0003o
ooooooooo`0=ooooo`?oZ;_V00?oZ;[VojJgiOnV]nD00onU]N@2ojBch`04oj>`hOnNZmooW:KLoibV
g0?oVJ3I0_nGV]D2oi>Cd0;oTHg<0_n>Q/H2oh]o`@;oRGZl0on8M;L2ohM`/P03ohI/[_n6JJ_oQVV[
00;oQVNW0_n6IJD3ohMTX`;oR6>Q0_n:Hil2oh]SWP?oSFBM0_n>IId2oi1VW@?o000000?oTVNMoiAX
WOnDJ9d00onFJYh2oiQ/WP?oWW6O0onQM:03oj=gXP03ojEjY?nbR:Wo/XRY00?o]8b/0ooA]/001?oT
oL;oZKWTojVii?nY[m`3ojV`g@03ojNagonWY=?oY:GF00;oY:GF0onMY=X2ohbNg`03o`0T[OmKL]3o
Fg;@00?oYi[90_o?[KL2omNg^P06onJkZ_o[`JWojl6Yo`000?o]`jWokLBX0_ob`il4oo;3WP;om<FM
00GomLJLooK7Voofai_omlRKooS9VP02ooG<X`04ooK=Y?ofcZCom/jTooG>Y@Cooooo00?o0000oooo
ooooool06Oooool000Wooooo00@00000ooooooooooooooooP`00000501TI6@060000000c<c<0<c<c
0000001<C4`000000P1VIVH01@000000Ogmo0000002IVIT000000080/k>c00?o00000<c<c03<c<`0
1P3<c<`02_l00000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C00300000?oo
oooooooo00;ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03ojRki_nW
^NKoYkWV00?oY[OU00CoYKGToj:bhonQ[n;oXJoR0onNZml2oibVg0;oVJ3I00CoUi[EohfCeOn8S=3o
R8c@0_n5Q</2oh5la@?oRgo10_n9N[`2ohQd]`;oQg2b0_n6K:h2ohIYZ`;oQVNW00CoQVFUohMTXon7
I:?oQfBS0_n8Hj42ohYSW`;oRf>N0on=I9d01On>IIgo0000o`000?l0003oT6JM00?oTVNM0_nDJ9d3
oiIZWP03oiQ/W_nKKYkoWW6O00;oWW6O0onQM:03oj=gXP?o/XRY0_ndS:`2om6d_@;odKK00_nY[]`3
ojV_g003ojV`gOnWXm7oYjCC00;oYjCC0onTYMH02?nMY=[oWiO<oi:CdOnBTm7oLHGGohl<0?ljLMgo
Fg;@0onWV/T01?o?[KOoekNjomNg^_oL`Kd2on_1Z@03ong3ZOl0003okLBX00;ol/>O1?ob`ih01?oc
`igomLJLooG6W?ofai/2ooO8V`05ooS9V_ohbi[om/fTooK=Y?ofcZ@00ooecZD3ooooo`03o`000?oo
oooooooo01Wooooo0009ooooo`0400000?oooooooooooooooh@00000100I6AT01P000000<c<c03<c
<`000000C4a<00000080IVIV00D0000007moO`000000VIVI000000020;>c/`03o`00003<c<`0c<c<
00H0c<c<00[o00000;>c/`2c/k<0000009VIV@000000Ogmo0000001VIVH000000P1<C4`00`00003o
ooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool2ojNiiP03
ojJgiOnT]NGoX[;S00;oX[;S0_nQ[n800onNZmooV:KPoiRVh002oiBQg@;oTI[I0_n=TmD2ohR<d0;o
QHC;00CoPGc5ogif_omnM[ooOWJo0_mlKkX2og]Z]0;oQg2b0_n6K:h2ohIYZ`;oQVNW0_n6IJD3ohMT
X`04ohQSXOn:HiooRV>OohYSW`;oRf>N00?oSFBMo`000?l000000_n>IId2oi1VW@?oTVNM0_nDJ9d2
oiIZWP03oiU/WOnKKYkoVfjN00?oWW6O0onQM:02oj=gXP05ojn5Z?nbR:Wo/XRYok:8ZOndS:`00ooA
];d00ooA]/3oZJgKojV^g002ojV^g003ojV_g?nWXLooYj?A00;oYj?A00?oYjCCojFDa?nTU/L00_nT
U/L3oinGc0;oTY?A00?oLHGGohl<0?ljLMd00_nWV/T01?nZZMGoekNjomNg^_oG]kX2omc1_@;okL>Y
00?okLBXo`000?o]`jP01Oob`ih01Ooc`igom<FLooK7Voofai_omlRK00;on<VJ00Con<^JooK=Y?of
cJCom/jT0ooecZD4ooooo`03o`000?oooooooooo01Sooooo0009ooooo`0400000?oooooooooooooo
oh@00000100I6AT01P000000<c<c03<c<`000000C4a<00000080IVIV00D0000007moO`000000VIVI
000000020;>c/`03o`00003<c<`0c<c<00H0c<c<00[o00000;>c/`2c/k<0000009VIV@000000Ogmo
0000001VIVH000000P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool3ojFgi@;oY;GU00?oX[;Soij`i?nK[>800onK[>82oiRVh0;oU:7M0_nA
V]T2ohfCe@;oR8c@00?oQHC;oh5laOn1O<D00_mnM[l2oga_^P;oNfZd0_mjI[02og]S[0;oQVV[0_n6
IjL2ohIUY@?oQfBS0_n8Hj42ohYSW`?o00000_n=I9d2ohiUW@;oT6JM0onBIid2oiAXW@03oiIZW_nI
K9goVFbM00;oVfjN0onNLIl3oj5dX003oj=gX_n_QJSo[hFX00?o/XRY1?oA];d00ooTo;[oYYg=ojNO
cP02ojNOcP?oYj7?00?oYj?AojFB`_nUU<@00_nUU<@3ojBFa`04oinGc?nOR[goUhS2oiN8`P;oP7o9
00?o05kFojZYeOnZZMD00_nZZMD01?oG]k[og<6momc1_OoL`Kd2ong3Z@03ong4Z?o]`jSo000000Co
l/>N0_oc`id01?odaIcom/NKooK7Voogb9/2ooS9VP04ooS;V_oibi[om/jTooK>Y0?omLjU1Oooool0
0ol0003oooooooooo`0Gooooo`002Oooool01000003ooooooooooooooon4000000@06ATI00H00000
03<c<`0c<c<0000004a<C000000206IVIP050000001oOgl0000009VIV@0000000P2c/k<00ol00000
c<c<0<c<c0060<c<c00:o`00002c/k<0/k>c0000002IVIT0000007moO`000000IVIV00000080C4a<
00<00000ooooooooool00_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?oYKOUoj>fi_nQ/nD00_nQ/nD2oij`i0;oVjcR00?oUJ_Uoi6Vi?nAY^@00_n;Wn42ohFHgP;oOi3J
0_miR=H2og=od@;oPGc50_mnM[l2oga_^P03og]Z]?mjI[3oNVJ`00;oNf>/0_mkHJP2ohIWY`;oQVFU
0on7I:<01?n8Hj7o0000o`000?l00002oh]SWP?oSFBM0_n>IId2oi1VW@?oTVNM00?oU6RMoiIYWOnI
K9d00_nIK9d3oi]^WP?oWW6O0_nQM:04ojn5Z0;o/XRY00Cock6kom6d_OoA];godKBm0onVWLd3ojNO
cP03ojNQconTT;ooYI;200;oYI;20onUU<@01?nTU/OoXhVioin:_OnOR[d3oiN8`P;oP7o900Co05kF
ojZYeOnZZMGoZ;KR0ooL`Kd2omk5`0;okLBX00?okL>Xo`000?o]`jP00oob`ih2oo?3W@05ooC5W?of
aY_omlRKooO8VoohbIX00_ohbiX00ooibi[onLbJooG>Y@02ooG>Y@03ooG?Y_ofdJOooooo00?ooooo
00?o0000ooooooooool05oooool000Wooooo00@00000ooooooooooooooooQ000000401TI6@060000
000c<c<0<c<c0000001<C4`000000P1VIVH01`000000Ogmo0000002IVIT000000;>c/ol000002P3<
c<`02Ol00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C00300000?oooooooooo
00;ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`;oXkKV00?oXK?Uoifc
ionM/nL00_nJ[nH3oiF[i@;oTJKT0_n;Wn42ohFHgP;oOi3J0_miR=H00omcOm7oKWO;ofigb`02ofY_
a@;oO6nj0_mkJ[@00omjI[3oNf>/og]S[002og]QZ0;oO5nU0_mnGZ<01On7I:?o0000o`000?l0003o
R6>Q00;oRV>O0_n;Hih3oheTW@;oSVFM0_n@IYd2oi9WW@03oi=WW?nFJIgoUVVM00?oVFbM0onKKYh3
oiiaW`03oj5dX?n/PJKo[86V00?o[hFX00Go/XRYolna^oo?/K_ock6kom6d_@02ojJLc0;oYYg=0_nW
Wlh01?nSS[koY92oojB@_onTT;l2ojFB`P;oYIC400?oXhNfoj>9^OnSRKT00onOR[d3oiN8`P;oP7o9
00Go03biojRfh_nX]^;oZ;KRomc1_@03omk5`0;okLBX0_o]`jP01Ol0003okL>Woo;3W_ob`ikoll>M
00;om<FL00Gom/JKooO8V_ohbI[on<VJooS;VP02ooW;VP07ooW<V_oic9_omLjUooG>YOoecjKom]6W
ooODY`04ooooo`03o`000?oooooooooo01Kooooo0009ooooo`0400000?oooooooooooooooh@00000
100I6AT01P000000<c<c03<c<`000000C4a<00000080IVIV00L0000007moO`000000VIVI0000002c
/k?o000000X0c<c<00Wo00000;>c/ol00000VIVI0000001oOgl0000006IVIP0000000P1<C4`00`00
003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool3oj2e
i`;oWK?W0_nJ[nH01?nEZnGoSZk[ohNYjon7ZN/2ogjSj`;oM9cY0_mYTnL2ogV8eP;oLgoA00?oKWO;
ofY_aOmZKlD00_mWJ;l2og]Z]0;oNVJ`00?oNf>/og]QZ?mkHJP00_mlGjD3o`0000;oP5jQ0_n3GYl2
ohYSW`;oRf>N0on=I9d2ohiUW@03oi1VWOn@IIcoTfNL00;oTfNL0_nFJId4oiU/W@;oVfjN0onNLIl3
ojb1YP?o[hFX00Go/XRYolna^oo?/K_ock6komok/`02ojJLc003ojJMcOnSS;coXhjn00?oXhjn0_nT
T;l00onUT/;oXXBcoj>7]P02oj>7]P?oXhVi0_nOR[d2oiN8`P07oi^1]on;O;coRgblo`0RY?l0?;Wo
Z;KRoinjk003omk5`0;og/K11?o]`jP01Ol0003okL>Woo?3WOoc`igom<FL00;om/JK00GomlRJooS9
V_ohbI[on<^JooW;VP02ooW<VP07ooW<VooicI_omLjUooG?Y_ofdJOommBWooSHZ004ooooo`03o`00
0?oooooooooo01Gooooo0009ooooo`0400000?oooooooooooooooh@00000100I6AT01P000000<c<c
03<c<`000000C4a<00000080IVIV00L0000007moO`000000VIVI0000002c/k?o000000X0c<c<00Wo
00000;>c/`000000VIVI0000001oOgl0000006IVIP0000000P1<C4`00`00003oooooooooo`02oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00onP]NOoWKOZoiVdj`02oiVd
j`;oU;;[0_n>[^/2ohNYj`;oOZ?[0_mdW>T2ofVCi`03oef9i?m@O^3oD7kP00;oKWO;00?oJVo5ofMX
_omWJ;l00_mVHkX2ogYV/0;oNf>/0ol00002ogiNX`?oP5jQ0_n3GYl2ohEOWP;oR62M0on;HYd2oheS
W0;oT6FL0onCIi`2oiIYW@CoVFbM0_nKKYh2oiiaW`04ojQmYOn/PJKo[86Vojb1YP?o[hFX0oo?/K/0
1?oOnk?oXHVjoj::^onRR[/3oj><_0?oXhjn00?oY92ooj62/OnRQ;<00_nRQ;<3oj>7]P;oXhVi00?o
WhZmoj62/_nKPKL00_nKPKL2oh]l_003ofMZ`_l08ZCoWk[/00;oWk[/00Cog/G0omk6`OoNa/7og/K1
0oo]`jP2ong3Y`04o`000?oc`igoll>MooC5W0;om/JK00GomlRJooS9V_ohbi[on<^JooW;VP02ooW<
VP04ooW<VooicI_omLnVooKAY`;ommBW00?on=RXooWLZOooool00_ooool00ol0003oooooooooo`0E
ooooo`002Oooool01000003ooooooooooooooon4000000@06ATI00P0000003<c<`0c<c<0000004a<
C0000000IVIV00000080Ogmo00D0000009VIV@000000/k>co`00000:0<c<c009o`00002c/k<00000
09VIV@000000Ogmo0000001VIVH000000080C4a<00<00000ooooooooool00_ooool00`00003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Oooooo0_nM]nX00onI]>_oU[W_oiJik`03oi2gl@;oR;Cc
0_mm/?@2ofj[mP;oFj?f00?o@iSbobB8jom@O^000_m4Lm/2ofY_a@04ofMX_omVHk[oIV>jofIN]P?o
00000_mkHJP00omlGjGoOUjSogiNX`03oh1NX@;oPejO0_n5Gih2ohQPW@?oRf:M0_n=Hi`3oi1UW0;o
TfNL0onFJId3oiU/W@;oVfjN00?oWW6OojQmYOnXOJD01?n/PJH2ojn5Z005olf]^_o?/K_ogo^comok
/onQRKX00onRR[/3oj><_004oj>>__nPP;3oXH:aoj62/@?oXXBc0onSQkH00onSRKWoXX2_oj62/P02
oj62/P?oVh6g0_n;O;`00omWJ/;o01BLoinjk002oi:dkP?og/K100?og<C2ong3Z?o]`jP00_o]`jL0
1Ol0003ok/BWooC5W?odaIcom/JK00;omlRJ00Gon<VJooW;VOoibi[onL^JooW<VP02ooW<V`04ooW=
VooicYcom]6WooODY`;on=RX00?onMbYooWO[?ooool00_ooool00ol0003oooooooooo`0Dooooo`00
2Oooool01000003ooooooooooooooon4000000@06ATI00P0000003<c<`0c<c<0000004a<C0000000
IVIV00000080Ogmo00D0000009VIV@000000/k>co`00000:0<c<c009o`00002c/k<0000009VIV@00
0000Ogmo0000001VIVH000000080C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0B
ooooo`03o`000?oooooooooo01Sooooo0onK^^h2oiJik`03oi2glOn>_OKoS[gf00;oQ;ci0_me^O/2
of2do0;o@JWg00Co5YGUobB8jolTR>_oA7?K0_liJ=D01OmWJ;oo0000o`000?l0003oIUjf00;oIeba
0_mkHJP2ogaOY@04ogiNXon0GZ7oP5jQoh1NX@;oPejO0_n5Gih3ohQPW@;oRf:M0_n=Hi`3oi1UW0?o
TfNL0_nFJId3oiU/W@;oVfjN1?nXOJD3ojb1YP03ojn5Z?o=[K[ocJfj00;oeoZ]0onQRKX2oj::^`;o
Xhbl00?oWgj^oj20/?nPP;000onQP[43oj:4/`04oj>7]_nROZcoXX2_oj:0[`?oXH:b0onKPKL2oh]l
_003ofMZ`_l03ISo01BL00?oT[C^00?og/K1omc4`_oLa<800_o]`jP2ong3Y`06onk4Yol0003om<FL
ooC5W?ofaY_omlRJ0_ohbIX01OoibiWonLbIooW<V_oic9[onLbK00;onLfK00ConLjLooKAYooge:Oo
n=RX0_oig:T00ooigjcon>:`ooooo`02ooooo`03o`000?oooooooooo01?ooooo0009ooooo`040000
0?oooooooooooooooh@00000100I6AT020000000<c<c03<c<`000000C4a<0000001VIVH000000P1o
Ogl01@000000VIVI0000002c/k?o000000X0c<c<00Wo00000;>c/`000000VIVI0000001oOgl00000
06IVIP0000000P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo01;ooooo00?o0000
ooooooooool06Oooool00onK^^koVkg`oi^ml002oiJml`04ohjmm_nA`_SoTL;hoi72n0;oQl?k0_mh
`_h2of6no@05ocjclomJa?[oF/Cjoc>diom@00000_l000001?laGm3oIV>jofIS^_mVG[H2ofML/@;o
JUZ^0_mlGjD2ogiNX`?oP5jQ00?oPejOohEOW_n5Gih00on8H9d2oh]RW@;oSF>L0on@II`3oi=WW0;o
UVVM0onIK9d00onKKYkoY7ZTojQmY@03ojQmY@?o[86V0oo=[KX00ooGnZgoX8Rjoj28^P02oj69^P03
oj::^onNO:koWgj^00;oWgj^0onPP;02oj62/@;oXXBc00?oXGbZoj9n[?nROZ`00onRP:l3oj62/P04
oi^1]onOOk3oU7^eoiAk]@;oNFnk00Co00fHohNZk?n7Z^coQj[/0ooLa<801?oJ`/;okL>Wong3Yoo]
`jL2onk4Y`04o`000?ofaY_om/JKooO8VP;on<VJ00KonL^IooW<VOoic9[onLbJooW<VooicI/2ooW>
W004oo_DW?oge:Oon=RXooWLZ@;onMn/00Gon>:`ooKS]?ooooooooooo`00000Eooooo`002Oooool0
1000003ooooooooooooooon4000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV0000
001oOgl000000P2IVIT00`000000/k>co`00000:0<c<c009o`00002c/k<0000009VIV@000000Ogmo
0000001VIVH000000080C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0Booooo`03
o`000?oooooooooo01[ooooo00CoVkg`oic0lOnL`?7oW<3a0_nH`O@00onA`_SoUlGgoiO5m`02oi37
nP03ohG9o_nDb_[oU<[j00;oS<gm0ol000000onGcO_oT=7noc5Od002ob]Gb`;oIUjf00GoIebaofYJ
[_mZFZkoKEZ[ogaOY@02ogiNX`?oP5jQ0_n3GYl2ohEOWP;oR62M0on;HYd2oheSW0;oT6FL0onCIi`2
oiIYW@;oVFbM00CoX7JTojAjY?nTNZCoY7ZT0onXOJD2ojb1YP;obJVj00?ocJfjomOj[OnPR;X00_nP
R;X00onQRK[oWG^]oiil[P02oiil[P?oWgj^0_nPP;02oj62/@?oXGbZ0onROZ`2oj:0[`;oXH:b00?o
Y7n/oimo/?nOOk000onDNkD2ogU_^`05o`0=V?n7Z^coQj[/ohNZk?oLa<800_oJ`/82ong3Y`;ok/BW
0_o`aZH01?l0003omlRJooO8V_ohbIX2ooW;V@0<ooW<VOojcIWonLbKooW<VooicI_onLjLoo[@W?ok
e9cooMRKooSHZ?oig:WonMn/0_ohh[001OofhkColN:noooooooooooo000001Cooooo0009ooooo`04
00000?oooooooooooooooh@00000100I6AT02P000000<c<c03<c<`000000C4a<0000001VIVH00000
07moO`00000209VIV@030000002c/k?o000000X0c<c<00Wo00000;>c/`000000VIVI0000001oOgl0
000006IVIP0000000P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo01;ooooo00?o
0000ooooooooool07?ooool00onL`?7oX<;aoj32l@02oic3l`03oiO5monNaO?oW/Gc00;oV/Og00Co
U<[jo`000?l0003o00000_nKb_L02?nGcO_oX/Ocoj;7lonPb_KoY/C_ob]GbolYD/OoIUjf0_mWG;40
0omZFZkoKEZ[ofeJZ`02ogiNX`?oP5jQ0_n3GYl2ohEOWP;oR62M0on;HYd2oheSW0;oT6FL0onCIi`2
oiIYW@03oiU/WOnPMZCoX7JT00?oY7ZT0onXOJD01On/PJKobJVjolVY^_o9ZK[ocJfj00?oX8Rj00?o
W7Z/oiek[OnMNjd00onNO:h3oimn[P;oX82`00?oXH:aoj1iZ?nPNJP00onQO:X2oj9n[0;oXX2_0onT
Oj`3oimo/0;oU7^e0omiKk/3ognQj@?of/;200CofL;2ong3Yoo^a:Ook/BW0_o`aZH01Ol0003omlRJ
ooO8V_ohbI[onL^I00;onLbI00con/fIoo[=V_oicI_onLfKooW>W?ojd9conmBLoogHVoomg9_ooN2L
ooWO[?ohh[02ooKS]004oo7R__o_h/;oooooo`0001Cooooo0009ooooo`0400000?oooooooooooooo
oh@00000100I6AT02P000000<c<c03<c<`000000C4a<0000001VIVH0000007moO`00000209VIV@03
0000002c/k?o000000X0c<c<00Wo00000;>c/`000000VIVI0000001oOgl0000006IVIP0000000P1<
C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07Ooo
ool00onP`_7oXl;_oj73l@02oj73l@03oik5lonS`o3o000000;o000000CoXLGboio7m?nU`nooYL?_
0_nSaO401onRao?oY/;^ojK2k_nV`^koY/C_ob]GbolYD/L00_mWG;400omZFZkoKEZ[ofeJZ`02og5J
Z0?oP5jQ0_n3GYl2ohEOWP;oR62M0on;HYd2oheSW0?oT6FL0_nCIi`00onFJIgoW7>Soj1fY002oj1f
Y0?oY7ZT0onXOJD4olVY^P03ol[fY_nKNJcoVgV/00;oW7Z/0onMNjd2oiil[P?oWgj^00?oX82`oiig
YonPNJP00_nPNJP3oj5lZP;oXWj/00?oXX2_ojAmZOnTOJT00onTOj`2oimo/003oiAk]OnLOk?oQWJj
00;oQWJj00Go@52kognQjOmoXNWoOj7Yom[2`P02omW2`P04om[3`oo^a:Ook/BWoo36YP;olLRV00Go
0000ooS9V_ohbI[onL^IooW<V@02oo[=V@0<oo[=V_ojcY[onLjLooW>W?ojd9conmBLoogHVoomg9_o
oN2LoocSX?ohh[3om^>d0_oah[h01?o_h/;ok>;6ooooool0000Cooooo`002Oooool01000003ooooo
oooooooooon4000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl00000
0P2IVIT00`000000/k>co`00000:0<c<c009o`00002c/k<0000009VIV@000000Ogmo0000001VIVH0
00000080C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01oooooo0_nS`^l01_nQ`o7o0000o`000?l0003oXl?`ojK1k0?oY/;^00?oYL?_ojO1k?nW`N`0
0_nW`N`2ojK2kP;oZ;oZ00CoZ<3[obUBaol[ClCo:do40_mZFZh00om]FZ_oLEZXog5JZ003ogEKY`;o
PejO0_n5Gih3ohQPW@;oRf:M0_n=Hi`3oi1UW004oi=WW?nGKj?oW7>SoiacX`CoX7JT0onTNZ@2ojQm
Y@05olBU^_o9ZK[obJVjol[fY_nJNJd00_nKNJ`3oiaj[0;oWG^]0onNO:h01?nOOZkoWGJUoiigYonN
MjL3oj1iZ0?oXGbZ00?oXWj/ojAkY_nTOJT00_nTOJT3ojAo[0;oWgn`0onLOk<2ohIf^P04oeIM__mi
W>OoNIcWogVLi`?ofL;20_oJ`l<2oo36YP04oo78Y_ocbjGoll^Uo`0000;onL^I00OonLbIoo[=VOoj
cIWon/fJoo[>V_ojci[on]2L00;onmBL00OooMbKoogPW?omh9coo>>Poo_UYOodhkWolN:n00;okn;2
00Cok>;6onWRb_oooooo00004_ooool000Wooooo00@00000ooooooooooooooooQ000000401TI6@0:
0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo00000080VIVI00<000000;>c/ol00000
2P3<c<`02Ol00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C00300000?oooooo
oooo00;ooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`?o000000CoY/7/
ojG2k_nW`>_oYl3[0_nV`N`01?nV`^koZ<3[ojS0jonW`N`2ojVoj@CoZ;oZ0onY_^T01OlYD/Oo:do4
obm?`_mZFZkoKEZ[00?oLEZX0_meFjL2ogYMY@;oQEnN0on8H9d2oh]RW@;oSF>L0_n@II`00onCK:?o
UfnSoiM_X`03oiacX`?oX7JT0onTNZ@01OnXOJGoa:FjolBU^_o9ZK[o^O2O00;oVWV]0onKNJ`2oiaj
[0;oWG^]0_nNO:h00onLM:GoWGJUoiefY@02oiigY`CoX7VX0_nQO:X2ojAkYP?oY7fY0onTOj`00onO
Ok3oYX:]oiao/`02oiao/`?oQWJj00GoEUfnogVLiomiW>OoNIcWomW2`P03om[3``;ol<JV00GolLRV
oo?;YOocbjGomLfUo`000002ooW<V@0:oo[=VOojcI[on/fJoo[>V_ojci[onm:Joo_DW?omf9_ooMbK
oogPW0;oo>>P00ConnFUooSW/Ooah[kokn;20_o/h/H00ooYh/[oi^7>o`00000Booooo`002Oooool0
1000003ooooooooooooooon4000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV0000
001oOgl000000P2IVIT00`000000/k>co`00000:0<c<c009o`00002c/k<0000009VIV@000000Ogmo
0000001VIVH000000080C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo0ol00002ooooo`?oZ;o[00?oYl3[ojRoj_nX_nX00_nX_nX01?nX`>_o
ZKkYojVnjOnY_^T2ojVoj@03ojRoj_nY_^SoZKkX00?oZKkY00CoZKcWob]?a?l[ClCo;do20_m]FZ/2
og5JZ0;oME^W0_mjGJD2ogmOY0?oQ6:S0_n9IJ<2ohiXX`?oTfbS0_nGKj<3oiacX`?oX7JT0_nTNZ@0
1OnnXK_oa:FjolBU^_o4YK[o^O2O00CoVWV]0_nKNJ`2oiaj[003oiek[OnKLZCoW7BU00;oW7BU0_nM
MZD3oiigY`?oX7VX00CoXGbZoj9iYOnTNjKoY7^V1?nTOJT00onTOjcoZH:ZojJ2[@02ojJ2[@?oW7nc
0_n6M[X01?mFGKko0bjaogBJj?mdV^P3om[3``;og<K40_oab:H01?ocbjGomLfUooG=YOl00002ooW<
V@0Aoo[=VOojcI[on/jJoo[>V_ojci[onm:JoogFV?omf9_ooMbKoogPW?olhj3onnFUoo[VZoohik7o
m^NfooCX_?o/h/H00_oYh/X00ooVhLkoooooo`00000Aooooo`002Oooool01000003ooooooooooooo
oon4000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl000000P2IVIT0
0`000000/k>co`00000:0<c<c009o`00002c/k<0000009VIV@000000Ogmo0000001VIVH000000080
C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Wo
oooo0ol00006ooooo`04ojRojonX_^WoZ;kYojRojPKoZKkY00?oZKgXojVnj?nY_^P00_nY_^P4ojVm
j006ojVlionY^^KoZK[VojVji_lgDL7oKEZ[0_maFZP2ogEKY`;oNUfU0_moGj@3ohARX`;oRFFS0_n>
J:<3oi=/X`;oUfnS0onLLj<3oj1fY004ojAjY?nnXK_o_Z6kokjQ^`;oa:Fj1OnJNJd2oi]i[004oiaj
[?nILJCoVg:Toi]bY0?oW7BU0onMMZD2oiigY`;oX7VX00?oXGJSoj9iYOnRNJD00onTNjH3ojAmZ@;o
ZH:Z0onVPZd2oiao/`06ojN;]onBPkooTX>oof1[a_mFGKko001o0_mdV^P01OoJ`l?og<K4omc6a?oL
a/Cog/[500;oll^U00ComLfUooK?YOofcjGo00000_ojcIT01oojcI[on/jJoo[?V_ojci[onm:JoogF
V?omg9/00_omh9`02oolhj3onnFUooSW/Oohik7om^NfooCX_?oaj<7ojN;:onKQc_oRh=;ogmoE00;o
00004?ooool000Wooooo00@00000ooooooooooooooooQ000000401TI6@0:0000000c<c<0<c<c0000
001<C4`0000006IVIP000000Ogmo00000080VIVI00<000000;>c/ol000002P3<c<`02Ol00000/k>c
0000002IVIT0000007moO`000000IVIV0000000204a<C00300000?oooooooooo00;ooooo00<00000
ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`?o00002_ooool01?nX_^WoZKkXojVnj?nY
_^P3ojVnj@CoZKgX00?oZKkXojVmj?nY_NP00onY_NP3ojVkiP?oZK[V00Co=e71og5JZ?maFZSoLEZX
0_meFjL00omjGJGoOenTogmOY003ohARX`;oRFFS0_n>J:<3oi=/X`?oUfnS0onLLj<2oj1fY0Co_Z6k
00?oa:FjoiUi[_nJNJd01?nJNJd01?nKNJcoV72ToiUaY?nILJ@3oi]bY0?oW7BU0_nMMZD2oiigY`03
oj1iZ?nQMZ?oXGJS00?oXWVU0_nTNjH2ojAmZ@04ojV0YonYPZ[oZH:ZojV2ZP;oYX:]00?oW7ncojN;
]onWRkL00onBPkl01?mPJlKo0bjao`00Oom_V^/3omc6a0;og/[50_ocbjD01OoecJGom/nUooOAYOog
dJGo000000;on/fJ00con/jJoo[?V_okdY[onm:JoogFV?onh9Coo>BCoo_WU_ojjYconnFUooSW/Oof
ikH2ooCX_007oo7X`OoVhLkoh^3Bon;Pd_oOgmGofmkIo`00000@ooooo`002Oooool01000003ooooo
oooooooooon4000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl00000
0P2IVIT00`000000/k>co`00000:0<c<c009o`00002c/k<0000009VIV@000000Ogmo0000001VIVH0
00000080C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Cooooo0_l0000?ooooo`03ojVnj?nY_NSoZKgX00SoZKgX0onY_>L2ojVki`03ojVki_nX^>Go
Z;OT00;oZ;OT00CoZ;GSod9F`?m2E/3o@UK00_meFjL2ogYMY@04ogmOY?n4HZ?oQ6:SohARX`;oRFFS
0_n>J:<4oi=/X`;oUfnS0onLLj<00onPMZCo^9bkokRL^`03okjQ^`?oVGV^00CoVWV]oiI_Y?nGL:Co
Ug2T0_nHL:@3oiUaY0;oVg:T0onLM:D2oiefY@03oiigYonOM:;oXGJS00;oXGJS0onRNJD2ojAkYP03
ojAmZOnYP:OoZH2W00?oZH:Z0_nVPZd4ojN;]`;oTX>o0_mPJlH01?l3;[7oJIc^ofVLk_oLa/@2omk:
a@;ohLo60_oecJD01OofcjGomm6UooOAYOogdZGo000000;on/jJ00con/nJoo_BV_omeYSoo]^FookP
U?oli9?onnNFoo[ZW?ohkJ_omnjaooKW]_odj;`2oo7X`@06on_XbooRh=;ogmoEomoOeOoKg]Wo0000
4?ooool000Wooooo00@00000ooooooooooooooooQ000000401TI6@0:0000000c<c<0<c<c0000001<
C4`0000006IVIP000000Ogmo00000080VIVI00<000000;>c/ol000002P3<c<`02Ol00000/k>c0000
002IVIT0000007moO`000000IVIV0000000204a<C00300000?oooooooooo00;ooooo00<00000oooo
ooooool04?ooool00ol0003oooooooooo`0Booooo`?o00004_ooool8ojVmj0CoZKcW00CoZ;[VojRi
iOnX^NGoZ;WU0_nX^>D01?nX]nCoY[7PojF^g_nU[]h2od9F`004odiL`OmeFjOoNUfUogYMY@;oOenT
0on4HZ<2ohUUX`;oSVRS0onCK:<2oiM_X`;oW7>S00?o/9NlokRL^onhW;/00_nhW;/00onnXK_oU6nV
oiE_Y@02oiE_Y@;oUVnT0_nGL:@2oiQ`Y0?oVG6T0_nKLZ@3oiadY@;oWGJU0_nOM:84oj5fX`;oXWVU
0_nTNjH4ojV0Y`;oZH:Z00?oYX:]ok2=/OnWRkL00onWRkL00onBPkooWioDoeYog@02oeYog@04ohlH
0?mYW>koJIc^omk:a@?ohLo600CohmC7ooK?YOofcjGomm6U0_ogdZD02Ol0003omm:Uoo[?V_ojci[o
nm:JoogFV?onfiKoo>BCoo_WUP02oo[ZW00<ooS]Zoogk[7omNnhoo;`__oaj<7ok^S6on_XbooWj=3o
gmoEom_NfOoGg=_o00004?ooool000Wooooo00@00000ooooooooooooooooQ000000401TI6@0:0000
000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo00000080VIVI00<000000;>c/ol000002P3<
c<`02Ol00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C00300000?oooooooooo
00;ooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`?o00005Oooool7ojVm
j0?oZKcW0_nY^nH2ojRjiP03ojRiiOnW]^?oY[?R00;oY[?R0_nV/N000onU[]koXJGHod9F`002odiL
`@;oNUfU0_moGj@3ohARX`;oRFFS0_n>J:<3oi=/X`;oUfnS00?oW7>Sok2G_?n`Uk`01?nhW;/2oiA_
YP?oUFnU0_nFKj@2oiM`Y0?oV72T0_nILJ@3oi]bY0;oW7BU00?oWGJUoiebXOnOM:800_nOM:83oj5f
X`;oXWVU00?oY7^VojQmYOnXOJD00onYP:L2ojV2ZP?o/8fa0_nWRkL01?njYlKoWioDoinOe?nOWm@2
oeYog@04o`Hi^_n?603oHYkaof:Nl@?ohLo600CohmC7onGHbOogdJGomm6U0oogdZD02_l0003on=BU
oo_BV_okdY[ooMJHookPU?oli9?onnNFoo[ZW?oik:<2ooO^/@04ooG_^?obl;kok^S6on_Xb`;oinS@
00GohnODomoUf?oGg=_oooooo`00000?ooooo`002Oooool01000003ooooooooooooooon3000000D0
6ATI00P0000003<c<`0c<c<0000004a<C0000000IVIV00000080Ogmo00D0000009VIV@000000/k>c
o`00000:0<c<c009o`00002c/k<0000009VIV@000000Ogmo0000001VIVH000000080C4a<00<00000
ooooooooool00_ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0000I
ooooo`GoZKgX00KoZKcWojVkionY^nOoZK_WojVki_nX^ND3ojNgi0;oYkKS00?oY[?RojB]g_nRZM/0
0_nRZM/2oj6Uf004od9F`?m>G<7oG6?1oeaS`@;oOenT0on4HZ<2ohUUX`;oSVRS0onCK:<00onGKj?o
Yi2mok2G_003ok2G_0;o^9bk00CoTg2WoiA_Y_nDKjKoU6nV0_nEKjD2oiI_Y0?oUg2T0_nHL:@3oiUa
Y0;oVg:T00CoW7BUoiaaX?nMLZ7oWG:Q0onOM:83oj5fX`;oXWVU0onXOJD3ojV0Y`03ojV2Z_ncS:go
/8fa00;o/8fa00GoYh^gokZWa_njYlKo^ZO6oinOe002oicOo@;o1XON00Go00:Eoe^Pm?mKX?CoFj3d
on7?aP02on?Da`03onGHbOoVf/Womm6U00Comm:U00_o0000oo[HY?omeYSoo]^FookPU?oli9?onnNF
oo[ZW?ohkJ_omnjaooG_^002oo;`_P03oncab_oYl<ooinS@00;ohnOD00CognGHoooooooooooo0000
3oooool000Wooooo00@00000ooooooooooooooooP`00000501TI6@080000000c<c<0<c<c0000001<
C4`0000006IVIP00000207moO`050000002IVIT000000;>c/ol000002P3<c<`02Ol00000/k>c0000
002IVIT0000007moO`000000IVIV0000000204a<C00300000?oooooooooo00;ooooo00<00000oooo
ooooool04?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool00onY_NSoZKcWojVli`02ojVl
i`03ojVkionX^^KoZ;[V00;oZ;WU00?oYkOTojFch_nU/>000_nU/>02ojB]gP03oj:YfonMXMOoVi_C
00;oVi_C0_m>G<400omLHl7oJV_1ofY[`@03ohARX`;oRFFS0_n>J:<2oi=/X`04oif:__nWT;goYi2m
ojN@_@?o/9Nl00?o^9bkoi=`YonCL:L00onDKjH3oiE_Y@;oUVnT0_nGL:@2oiQ`Y0?oVG6T00CoVg:T
oiY_X?nLLJ3oW76P0_nMLZ43oimdXP?oXGJS00?oXWVUojIkXonXOJD00_nXOJD3ojV0Y`?o/hb]0_n`
SK402?o5ZKgo^ZO6okZWa_njYlKoe>gUoicOoOnW_n[oY;g[0_nT_>X01Ol00YGoFj3doe^Pm?mKX?Co
hmC700;oiMS900?oi][9onKKbOogdZD00_ogdZD03Oohe:Go0000oo[HY?olgZ7oo>FLoocTToo]ki;o
jo:JonceY?o/nKSomnjaooG_^?obl;h00_o/lLX01?oYl<ooiNoDon?We?oOiMP3ooooo`03o`000?oo
oooooooo00gooooo0009ooooo`0400000?oooooooooooooooh<000001@0I6AT020000000<c<c03<c
<`000000C4a<0000001VIVH000000P1oOgl01@000000VIVI0000002c/k?o000000X0c<c<00Wo0000
0;>c/`000000VIVI0000001oOgl0000006IVIP0000000P1<C4`00`00003oooooooooo`02ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`0002;ooooo00?oZKcWojVkionX
^nH00_nX^nH00onX^^KoYkOUojJei002ojJei0;oYK?R00?oYK3Poj6ZgOnQZ]d00_nOY]X2oifQe`?o
Vi_C00CoVIG>oeaS`OmLHl7oJV_10omhLl42ohIk`0;oTX>o0onMR[h4ojN@_@04ok2G_?nBLZ_oTW6Y
oi9aZ@;oTg2W0_nDKjH3oiE_Y@;oUVnT0_nGL:@2oiQ`Y0;oVG6T00?oVFjOoiY_X?nJKj000_nLLJ03
oiebX@?oWgBR0_nQMZ<2ojIkX`CoZ7fU0_nYP:L3ok><[@07ok2=/Oo5ZKgoaJVmolFY_OnjYlKoe>gU
ojVnj@03ojNmj@04ojBlj_nU_>[oW[[/o`04T@?oEZ;f00GoiMS9onKJbOoVf/Woi]_9onKJb@02ooOB
Y@0?ooSDYOojf:Co0000oocNXOoliIcol^fAong_T_o[lY[ok?FTonci^?oZn/3oio_7on7kdoo/lL[o
jO3?00;oiNoD1Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooom;
000001D06ATI8P00000501TI6@0;0000000c<c<0<c<c03<c<`000000C4a<0000001VIVH0000007mo
O`0000000P2IVIT00`000000/k>co`0000090<c<c00:o`00002c/k<0/k>co`00002IVIT0000007mo
O`000000IVIV00000080C4a<00<00000ooooooooool00_ooool00`00003oooooooooo`0@ooooo`03
o`000?oooooooooo00?ooooo0ol0000Vooooo`;oZK_W00KoZ;_VojNii_nW^NKoYkWVojNgiOnV]N@2
ojBbhP?oXZkP0_nQZ]d2oinVfP;oWJ7G00GoVi_Coi>Bd?n@S<_oT8c;ohj5a@02ofY[`@;oN7?10_n6
Nl03oi:3_`?oWHZn0_nWT;d00ol0003oTW:[oi9bZ`02oi9aZ@;oTg2W0onDKjH2oiE_Y@;oUVnT0_nG
L:@00onHL:CoUfbOoiU^W`02oiU^W`;oVVnP0_nLLJ03oiebX@?oWgBR00?oXGJSojEhX_nVNj<00_nV
Nj<3ojQmY@03ojV0YoncRZ[o/hZZ00;o/hb]1?o5ZKd01OoVkM?oZKkXojVnjOnY_^WoYkgY00;oZ;gY
0_nU_>X00onN^^co00BAoeJTm`02oeJTm`0?onKJbOoVflWoi]_9onKJbOoVfLSomm:UooSDYOojf:Co
o=jQo`000?ohjYKokNnBon_bV_o/mJCok?Vh00;oj_[000Goio_7on7kdooNn]Wof_SNonG_e006oooo
o`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooood000000;P0I6ATA0000
0003o`00000000006ATI00D06ATI00/0000003<c<`0c<c?o00000000001<C4`0000006IVIP000000
Ogmo0000000209VIV@030000002c/k?o000000T0c<c<00[o00000;>c/`2c/k<0000009VIV@000000
Ogmo0000001VIVH000000P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo00oooooo
00Co0000oooooooooooooooo0ol0000[ooooo`;oZ;[V00?oYkWVojJgiOnU]>@00_nU]>@2ojBbhP04
oj:^h?nMZ]ooVjGMoi^Ug@;oV9oI0_nFVMD3oi>Bd0;oT8c;00?oSXG5ohao`?n<Ol000_mhLl42ohIk
`0;oTX>o0onMR[h00onWT;goTW>^oi9c[P02oi9bZ`;oTW6Y0_nCL:L3oiA_YP;oUFnU0_nFKj@01?nG
L:CoUF^PoiM/WonGK9l3oiU^W`;oVVnP0onLLJ02oiebX@;oWgBR00?oXgJQojEhX_nUN:800onVNj<3
ojQmY@?o/hZZ0_ncS:d01Oo9Z;SoaJVmolFY_OoVkM?oZKkX00CoZKgX00?oZ;gYojRmj?nX_NP00_nU
_>T01?nP^^co00BAoefVmomMY_L2onKKb@;oi][900ooi]W8onWLaoohe:Gon]RToocNXOoliIco0000
ong_T_o[lY[ok?R_ok;ke?oZn/3oio_7on7kdooNn]T00_oJn=h7ooooo`03o`000?oooooooooo00go
oooo0009ooooo`0400000?ooooooooooooooocH00000@00I6AT8000000T06ATI00@0000003<c<`0c
<c<000000P1<C4`01@000000IVIV0000001oOgl000000080VIVI00<000000;>c/ol000002@3<c<`0
2_l00000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C00300000?oooooooooo
00;ooooo00<00000ooooooooool03oooool4o`0002kooooo0onW^>H2ojJgi@03ojFdi?nR/^CoX:kR
00;oX:kR0_nMZ]l2oi^Ug@;oV9oI0_nFVMD2oi>Bd0;oT8c;0_n>QLD2ohao`003oh]j^on6Nl3oQW_0
00?oTX>o00?oWHZnohY]Zon:KJ/00_n;JjP2ohaZYP;oSFVT0_n?JJ<3oi1YXP;oTVZQ0_nCJZ02oiE[
X0?oUfbO0_nIKYl3oiY_X0;oW76P0_nMLZ400onOM:;oXgJQoj=fX@03ojEhXP;oYW^S0_nXOJD01Onb
QjSo/hZZok>:Z_ncRZ[o/hb]00;obJRh00?oaJVmonK]donY_NP01_nY_NP2ojRmj0?oY[cY00KoXK_[
ofZZm_mZZ_KoJZ[fonKKbOoVf/T2onKIb00<onWLaoo]i<Kon]RToocNXOoliIco0000oi[QSon_nLWo
/__Dok?kg?ncn^So/oS/0_ncm_000ooJn=koooooooooo`06ooooo`03o`000?oooooooooo00gooooo
0009ooooo`0400000?oooooooooooooooc800000700I6ATB000002L06ATI00@0000003<c<`0c<c<0
00000P1<C4`01@000000IVIV0000001oOgl000000080VIVI00<000000;>c/ol000002@3<c<`02_l0
0000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C00300000?oooooooooo00;o
oooo00<00000ooooooooool03oooool2o`00037ooooo00?oYkSVojFgi_nS]ND00_nS]ND2oj:bi004
oj2^h_nK[NCoUjSRoiNXhP;oTj;O0_n?W=/2oh^Ee`;oQhgB0_n4Q/d2oh5na`;oS7o00_n;N[/2ohYf
]P;oRW:b00?oRVn^ohY]Zon:KJ/00_n;JjP2ohaZYP;oSFVT0_n?JJ<3oi1YXP;oTVZQ0_nCJZ02oiE[
X0?oUfbO0onIKYl2oiY_X0;oW76P0_nMLZ43oj=fX@?oYGRR0_nVNj<01?nXOJGo/XNXok:7Z?nbQjP2
ok>:ZP?obJRh00?okNk8ojVmj?nY_NP01onY_NP2ojRmj004ojJljOooooooooooooooo`?oJZ[f00ko
i][9onKIb?oYg<OojMc7ongTa_o`l<?oo>FLok7WS?nMgXCo0000o`J=foln`>;oC/S/oeg?l`;o/oK`
2oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool[000001D06ATI
3P00000B03<c<`/000006`0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00D0000006IVIP00
0000Ogmo0000000209VIV@030000002c/k?o000000T0c<c<00[o00000;>c/`2c/k<0000009VIV@00
0000Ogmo0000001VIVH000000P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo017o
oooo00?o0000ooooooooool0;oooool2ojFgiP03oj>eiOnP]>KoX;CV00;oW[7U0_nK[N@2oiNXhP;o
Tj;O0_n?W=/2oh^Ee`;oQhgB0_n4Q/d00on1O/OoOgS1ogmh`@02ogib_0;oRWJf0_n:L[82ohY_[P03
ohY]Zon;JjSoRf^X00;oS6ZV0_n=JJ@3ohmYX`;oT6VR0_nBJZ42oi=ZX0;oUF^P0onGK9l3oiU^W`;o
VVnP0_nLLJ000onMLZ7oXGBPoj=fX@02oj=fX@?oYGRR0_nVNj<4ok:7Z0;o/hZZ00CobJJeolVX^?o9
Z;SokNk82?nY_NP8ooooo`?oN:oe00Ooi]W8onWLaoo]i<KokNC6oo3``ooZn[So/NN<00;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooo
oolV00000003o`00000000006ATI01006ATI1`00000[03<c<`@0000000?o0000000000000000500I
6AT01@000000<c<c03<c<`0c<c<000000080C4a<00D0000006IVIP000000Ogmo0000000209VIV@03
0000002c/k?o000000T0c<c<00[o00000;>c/`2c/k<0000009VIV@000000Ogmo0000001VIVH00000
0P1<C4`00`00003oooooooooo`02ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool0
;oooool2oj>gi`04oj2di_nM]NWoVK;YoiVbj@?oUJkX0_n?ZNL2ohVTiP03oh:LhomkU>3oNiCP00;o
M8cL0_m^PmL2oh5na`03ogmh`OmnL[coOW:l00;oOFjg0_mnJ[82ohY_[P;oRVf[0_n;JjP2ohaZYP04
oheYY?n?JJ?oSfVSohmYX`;oT6VR0_nBJZ42oi=ZX0?oUF^P0_nGK9l3oiU^W`;oVVnP0_nLLJ03oj5d
X0?oXgJQ0_nUN:800onVNj?o/8FWok25Y`03ok:7Z005ok>:Z_o9Y[GobJJeolVX^?o]k/P01?nY_NP>
ooooo`?oQ;Sg00GojMc7ongTa_o`l<?ol?33ok7WS004ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo9@00000A01TI6@<000003P0c
<c<M000000h0<c<c1`00000<01TI6@030000000c<c<0<c<c0080<c<c00P0000004a<C01<C4`00000
06IVIP000000Ogmo00000080VIVI00<000000;>c/ol000002@3<c<`02_l00000/k>c0;>c/`000000
VIVI0000001oOgl0000006IVIP00000204a<C00300000?oooooooooo00;ooooo00<00000oooooooo
ool04oooool00ol0003oooooooooo`0_ooooo`?oX;OY00CoWKGYoiVbjOnI/^WoUJkX0_n>/^l00on5
[_3oNjW`og^Yl002ofjQl0;oNiCP0_mdS=`00om^PmOoJG[AofUjd@02ogmh`@03ogib_?mmK[OoOFjg
00;oOVZb0_moJ:h2ohY]Z`;oRf^X0_n<JZH2oheYY0;oSfVS0on@JJ82oi9ZX@;oTfZP0_nEJj02oiM/
W`?oVFjO0_nJKj000onLLJ3oWW:Poj5dX002oj5dX0?oXgJQ0_nUN:83ok25Y`?o/XNX0oo9Y[D01?o`
lL;oZKgXojVmj?nY_NPAooooo`;oRlWm0_mng?`00oo`l<?oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo8`00000?
01TI6@@000002P0c<c<7000001d0C4a<2P00000;03<c<`<000001P0I6AT3000000@0<c<c00@00000
04a<C01<C4`000000P1VIVH01@000000Ogmo0000002IVIT000000080/k>c00?o00000<c<c03<c<`0
1`3<c<`02_l00000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C00300000?oo
oooooooo00;ooooo00<00000ooooooooool05?ooool2o`00033ooooo00?oX;OYoijik?nN^N`00_nJ
^>d2oiBfkP;oS[;_00?oQJk`og^Yl?mkZO000_m^XO02oejHkP04odf<jom^PmOoKX?GofUjd@;oIG;;
0_mnL[`2oge^]`03ogiZ/_moJ:koOfR^00;oPFJ[0_n;JjP2ohaZYP;oSFVT0_n?JJ<3oi1YXP;oTVZQ
0_nCJZ02oiE[X0?oUfbO0_nIKYl00onJKj3oW72OoiibX002oiibX0;oXGBP0onSMZ42ojEhXP03ojj2
Y_n`QJOo/8FW00?o/XNX00Cob:BdolVV]Oo9Y[Gol?728?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooah0000000?o000000000000
00003@0I6AT200000003o`0000000000<c<c00H0<c<c1`00000:04a<C1L0000000?o000000000000
00002P1<C4`300000003o`00000c<c<0<c<c00P0<c<c1P00000603<c<`050000001<C4`0C4a<04a<
C00000000P1VIVH01@000000Ogmo0000002IVIT000000080/k>c00?o00000<c<c03<c<`01`3<c<`0
2_l00000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C00300000?oooooooooo
00;ooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`0^ooooo`03oijik?nM_>koWKc^
00;oV;c`0_nA^o<2ohRimP;oNkKh0_mY/?T2odnVn003obbFl?l0O=co>WkV00;o9g3O00?oIG;;of=[
aOmSJlD00_mmK[L2ogiZ/P03ogmX[_n1IZ_oPFJ[00;oPVFX0_n<JZH2oheYY0;oSfVS0on@JJ82oi9Z
X@;oTfZP0_nEJj03oiM/W`;oVFjO0_nLL9l3oiibX0;oXGBP0onSMZ400onUN:;o[X:Vojj2YP03ok25
Y`05ok:7Z?o8Y;Cob:BdolVV]Oo`lL808_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo0009ooooo`0400000?oooooooooooooooad000003P0I6AT3000000P0<c<c0`00000;
04a<C0D0000000?o000006IVIP1VIVH0601VIVH7000000L0C4a<1`00000?03<c<`050000001<C4`0
C4a<04a<C00000000P1VIVH01@000000Ogmo0000002IVIT000000080/k>c00?o00000<c<c03<c<`0
1`3<c<`02_l00000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C00300000?oo
oooooooo00;ooooo00<00000ooooooooool05oooool00ol0003oooooooooo`0^ooooo`03oiflk_nM
_o3oWKo`00;oV;oc0_nA_oH00on7_oWoS<Cjohc4nP02ogk5oP;oI/;n0_m0]O<01_l7U]3o05RjobM`
golGH]SoIG;;of=[a@;oHfK00_mnJ[800omoJ:koPFJ[oh5VZ`02oh9UZ0;oQFFV0_n7IJ@3ohmYX`;o
T6VR0_nBJZ42oi=ZX0;oUF^P0onGK9l2oiU^W`;oW72O0onNLZ02oj5dX0?oXgJQ0on^PZH3ok25Y`?o
b:Bd00?olOBnooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo0009ooooo`0400000?oooooooooooooooa`00000300I6AT3000000P0<c<c0`00000704a<C0L0
00000`1VIVHP000000@0IVIV1`00000704a<C0<000002P0c<c<2000000@0C4a<00<0000006IVIP00
00000P1oOgl00`000000VIVI000000020;>c/`03o`00003<c<`0c<c<00L0c<c<00[o00000;>c/`2c
/k<0000009VIV@000000Ogmo0000001VIVH000000P1<C4`00`00003oooooooooo`02ooooo`030000
0?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool00onM_o3oWl7`oio1l002oi_2l`03oiG3
m_nKa?CoVlCd00;oU/Kh00?oS<SloiW8monIb?L00_nBbo/01On7cOkoV/[hoi[:n?nDcO_o5f;H00;o
Hf_500?oHfK0ofES^omUHk/00_moJ:h00on1IZ_oPVFXoh9UZ002ohEUYP;oQfFT0on:IZ<2oi1YXP;o
TVZQ0_nCJZ000onEJj3oU6^OoiM/W`02oiM/W`;oVFjO0_nLL9l3oiibX0?oXGBP0_nSMZ44ojj2YP;o
/8FW00CoaZ:colRT]?o8Y;ColOBn9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo0009ooooo`0400000?oooooooooooooooaX000003@0I6AT00`000000<c<c03<c<`0703<c
<`8000001`1<C4`3000000L0IVIV0`00000707moOa8000001`1oOgl4000000L0IVIV0`00000704a<
C0@000001@0c<c<00`000000C4a<04a<C00304a<C0040000001VIVH0IVIV00000080Ogmo00<00000
09VIV@0000000P2c/k<00ol00000c<c<0<c<c0060<c<c004o`00002c/k<0/k>c00000080VIVI00P0
000007moO`000000IVIV0000001<C4`0000003<c<`Cooooo00<00000ooooooooool06Oooool2o`00
02oooooo00CoWl7`oj;1konR`NooX/7_0_nO`_400onKa?CoXL?aoj73l@02oik5m003oiW8monQaO;o
XLGb00;oW/Od00KoV/[hoj?5lOnSaO7oXLOco`]FdOmSI/02ofES^`05ofQQ]omoJ:koPFJ[oh5VZon2
IJP00_n5IJH2ohMUY0?oRVJS0_n=IZ42ohmXX@;oTVVP0_nDJil3oiM/W`;oVFjO0onLL9l2oiibX0?o
XGBP00?oXgJQoj]oYOn^PZH00on^PZH01On`QJOoaZ:colJR/oo8Y;ColOBn02Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolI0000
00`06ATI0P00000803<c<`8000001@1<C4`01000003o000000000000000306IVIP@000000_l00000
10000000Ogmo07moO`1oOgl500000003o`0000000000VIVI0140VIVI1`00000407moO`03o`000000
0000000000@000000`1VIVH01?l00000000000000000000704a<C0D000001P1<C4`010000000IVIV
06IVI_l0000207moO`030000002IVIT000000080/k>c00?o00000<c<c03<c<`01P3<c<`01?l00000
/k>c0;>c/`00000209VIV@080000001oOgl0000006IVIP000000C4a<0000000c<c<4ooooo`030000
0?oooooooooo01_ooooo00?o0000ooooooooool0;_ooool00onR`NooYL3]ojG0k@02oj?2k`03oj73
lOnU`NgoYL7]00;oXl?_00GoXLGbojK2kOnV`^goYL?_ojO0j`03ojO1k004ojK2kOl3C<_oHfK0ofES
^`;oJ66g0_n1IZ/2oh9UZ004ohEUY_n7IJCoQfFTohMUY0;oRVJS0_n=IZ42ohmXX@;oTVVP0onDJil2
oiM/W`?oVFjO0_nLL9l3oiibX0;oXGBP0on[OjD3ojj2YP?oaZ:c00?ok_Rlooooooooool09_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
oooooaL00000300I6AT2000000L0<c<c0`00000404a<C0<00000101VIVH3000000L0Ogmo0`000004
09VIVAWo00000`2IVIT4000000L0Ogmo0P00000506IVIP8000003`1<C4`01@000000IVIV06IVIP1V
IVH000000080Ogmo00<0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0060<c<c004o`00002c
/k<0/k>c00000080VIVI00P0000007moO`000000IVIV0000001<C4`0000003<c<`Cooooo00<00000
ooooooooool07?ooool00ol0003oooooooooo`0^ooooo`03ojG0kOnW_n_oYko[00;oY/3/00?oYL7]
ojNojonW_n/00_nW`>`00onV`^goZ;o[ojRoj`02ojO0j`05ojO1k?nX_n[oZ;oZojRoj_l3C</00_mU
Hk/00omXHKOoK62cofaP/`02oh9UZ0;oQFFV0_n7IJ@2ohYVX`;oSFJQ0_n?J:42oi9YX0?oU6^O0_nG
K9l3oiU^W`;oW72O0onNLZ000onQM:3oZ7bToj]oY@02oj]oY@;o[X:V00Goa9ncolJR/oo6X[?oaZ:c
onkh_00Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00@0
0000oooooooooooooooo5@00000=01TI6@03o`00000c<c<0<c<c00D0<c<c0P00000504a<C0800000
1@1VIVH2000000H0Ogmo1000000309VIV@Co00002P2c/k<8o`0000L0/k>c0ol0000409VIV@<00000
1P1oOgl2000000D0IVIV0P00000<04a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl010000000
VIVI09VIV@0000020;>c/`03o`00003<c<`0c<c<00H0c<c<00Ko00000;>c/`2c/k<0000009VIV@00
000207moO`060000001VIVH0000004a<C0000000<c<c1?ooool00`00003oooooooooo`0Mooooo`03
o`000?oooooooooo02kooooo00?oYko[ojRnjOnX_^T00_nX_nX00onW_n_oZ;kYojRnj@02ojRojP03
ojRojonY_^WoZKkY00;oZKkY00CoZ;oZojVnj?nY_^SoZKkY0_l1A/H01OmXHKOoK62cofaP/omaH:oo
PVFX00;oQFFV0_n7IJ@2ohYVX`;oSFJQ0_n?J:42oi9YX0?oU6^O0onGK9l2oiU^W`;oW72O0_nNLZ00
0onUNZCoZ7bTojQlY003oj]oY@06ojj2Y_o4Wk?oa9ncolBO/oo6X[?ok_Rl:_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooa@00000
00?o000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH00`1VIVH2000000@0Ogmo00@00000o`000000000000000`2IVIT4o`0000@0
/k>c2_l000080<c<c0Oo00000`2c/k<4o`0000<0VIVI0`0000000ol00000Ogmo07moO`0207moO`03
o`0000000000000000@0IVIV00?o0000000000000000201<C4`00`000000IVIV06IVIP0206IVIP04
0000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k?o0000203<c<`01_l00000/k>c0;>c/`00
0000VIVI00000080Ogmo00H0000006IVIP000000C4a<0000000c<c<4ooooo`0300000?oooooooooo
01kooooo0_l0000_ooooo`03ojRnjOnY_^WoZKkY00;oZKkY00?oZ;kYojVnj?nY_^P00onY_^T5ojVn
j0?oZKgX00Co0DK6o`I5a?mXHKOoK62c0_maH:l2ohEUYP;oQfFT0on:IZ<2oheVX@;oSfRQ0_nBJJ02
oiA[W`?oUfbO0_nIKYl2oia`W`03oiibX?nUNZCoYGZT00?oZ7bT0_n[OjD4olBO/`03olJR/ooooooo
oooo02[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`002Oooool01000
003ooooooooooooooolE000000/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV0080IVIV0P00000407moO`800000102IVIT3o`000080/k>c1_l00003
0<c<c1;o0000103<c<`6o`0000040;>c/ol0003o0000o`0000@0VIVI0P00000507moO`8000001@1V
IVH700000003o`00001VIVH0IVIV00<0IVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c
0;>c/ol000080<c<c006o`00002c/k<0/k>c0000002IVIT000000P1oOgl01P000000IVIV0000001<
C4`0000003<c<`Cooooo00<00000ooooooooool08?ooool00ol0003oooooooooo`0]ooooo`03ojVn
jOnY_NSoZKgX00?oZKkX1?nY_NP00onY_^SoZKgXojVmj007ojVmj004o`I5a?m/H;?oK62cog5P[`;o
MV6]0on7IJ@2ohYVX`;oSFJQ0_n?J:42oi9YX0;oU6^O0onGK9l2oiU^W`03oia`WonQMjCoYGZT00;o
YGZT0onXO:@2oj]oY@05ol6L/oo4Wk?oa9ncolBO/ooWnkP0;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooa@000002`0I6AT00`00
0000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI0_l000040;>c/`03o`00003<c<`0c<c<
00@0c<c<0ol0000B0>KViPCo00001P3<c<`01?l00000/k>c0;>c/`2c/k<3o`0000<0VIVI0P000005
07moO`030000001VIVH0IVIV00l0IVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c0;>c
/ol000080<c<c008o`00002c/k<0/k>c0000002IVIT0000007moO`00000206IVIP040000001<C4`0
000003<c<`Cooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0^oooooa?oZKgX00?o
44O4ofaP/omaH:l00_mfHJd3ogaSZ`;oRVJS0_n=IZ42ohmXX@;oTVVP0onDJil2oiM/W`;oVFjO0_nQ
Mj@4ojEjY0;oZ7bT00?oZgnUol6L/oo1W;<00oo4Wk<_ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo4`00000<01TI6@030000000c
<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<
c<`0c<c<00<0c<c<0_l0000:0>KViPOo0000203Vi^H2o`0000D0c<c<00?o00000;>c/`2c/k<00`2c
/k<00ol00000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH03@1V
IVH010000000Ogmo07moO`00000309VIV@040000002c/k<0/k>co`0000L0c<c<00Wo00000;>c/`2c
/k<0/k>c0000002IVIT0000007moOol000000P1VIVH010000000C4a<0000000c<c<4ooooo`030000
0?oooooooooo02;ooooo00?o0000ooooooooool0;_oooolCojVmj003oa17a?maH:ooLF2_00;oMV6]
0_mlHj/2oh5UZ@;oSFJQ0_n?J:42oi9YX0?oU6^O0_nGK9l00onIKYooWGBToj5gY002oj5gY0?oYGZT
0_nXO:@4ol6L/`03olBO/ooooooooooo02kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`002Oooool01000003ooooooooooooooolB000000`06ATI00<0000003<c<`0c<c<0
1@0c<c<00`000000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0
0P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`0
0P3<c<`2o`0000H0i^KV1_l000070?ooo`Co00001P3Vi^H2o`0000@0c<c<0_l000040;>c/`03o`00
002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0<06IVIP040000
001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c/k?o00001`3<c<`02Ol00000/k>c0;>c/`2c/k<0
000009VIV@000000Ogmo0000000206IVIP040000001<C4`0000003<c<`Cooooo00<00000oooooooo
ool08oooool00ol0003oooooooooo`0^oooooa?oZKgX00Co7dg5og5P[omfHJgoMV6]0_mlHj/2oh5U
Z@;oQVNW0_n?J:42oi9YX0;oU6^O00?oUFnUoiUbY?nILZ@00_nMM:@3oj5gY0?oYGZT0_nXO:@4ol6L
/c;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003o
oooooooooooooolA00000003o`00000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`00
0000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`00P3<c<`00ol0
0000i^KV0>KViP040>KViP;o00004@3oool2o`0000H0i^KV00?o00000<c<c03<c<`00`3<c<`01Ol0
0000/k>c0;>c/`2c/k?o000000@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0<
06IVIP040000001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c/k?o00001`3<c<`02Ol00000/k>c
0;>c/`2c/k<0000009VIV@000000Ogmo0000000206IVIP040000001<C4`0000003<c<`Cooooo00<0
0000ooooooooool09?ooool2o`0002oooooo4?nY_NP3ooooo`03oam=aOmfHJgoMV6]00;oO6>[0_n1
IJT2ohIWY`;oS6VV0_n@K:D3oiE_Y@;oVG:T0_nMM:@3oj5gY0?oYGZT00?oZ7bTokfJ]?nmV[@00_o1
W;<dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000
oooooooooooooooo4P00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2I
VIT00ol00000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103V
i^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00`3<
c<`01Ol00000/k>c0;>c/`2c/k?o000000@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV
06IVIP0:06IVIP030000001oOgl0Ogmo0080Ogmo00@0000009VIV@2IVIT000000`2c/k<00ol00000
c<c<0<c<c0030<c<c005o`00002c/k<0/k>c0;>c/`0000000P2IVIT01@000000Ogmo0000001VIVH0
00000080C4a<00<0000003<c<oooool00oooool00`00003oooooooooo`0Vooooo`03o`000?oooooo
oooo02gooooo3OnY_NP6ooooo`;o<EC600CoMV6]ogaSZomlHj_oPFFY0_n6IjL2ohaYYP;oT6bU0onE
KjD2oiUbY0?oWGBT0onQMj@2ojEjY0?o_IZd00?o`Ibcooooooooool0<oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooa8000002`0I
6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00Go00000;>c/`2c/k<0/k>c
o`0000050<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0503oool00ol00000i^KV
0>KViP040>KViP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<00ol00000VIVI
09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH02@1VIVH00`000000Ogmo
07moO`0207moO`040000002IVIT0VIVI000000<0/k>c00?o00000<c<c03<c<`00`3<c<`01Ol00000
/k>c0;>c/`2c/k<000000080VIVI00D0000007moO`000000IVIV0000000204a<C0030000000c<c?o
oooo00?ooooo00<00000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`SoZKgX2oooool2
oc5DaP;oO6>[0_n1IJT00on6IjOoS6VVohaYYP03oi1/Y@;oUFnU0onILZ@2oiedY0?oXGNT00?oYGZT
okRG]OnhUkD00_nmV[@00oo0mJOoooooooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo4@0000000ol000006ATI01TI6@09
01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`02
0;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H2o`0001D0oooo00?o0000
0>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c0080/k>c00?o0000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00T0IVIV00<00000
07moO`1oOgl00P1oOgl010000000VIVI09VIV@0000030;>c/`03o`00003<c<`0c<c<00<0c<c<00Go
00000;>c/`2c/k<0/k>c0000000209VIV@050000001oOgl0000006IVIP0000000P1<C4`00`000000
<c<cooooo`03ooooo`0300000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool3ojVmj13o
oooo00?o<EC6odINaom6G/L00_n1IJT2ohIWY`;oS6VV0_n@K:D3oiE_Y@;oVG:T0_nMM:@2oj5gY006
ok:C]onhUkGo^9NeokRG]OnmV[Co`?FW>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo0009ooooo`0400000?oooooooooooooooa800000300I6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`02
07moO`050000002IVIT0VIVI09VIVOl000001@2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003V
i^H0i^KV00D0i^KV0_l0000B0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00`3<
c<`01Ol00000/k>c0;>c/`2c/k?o000000D0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV
06IVIP0;06IVIP050000001oOgl0Ogmo07moO`0000000P2IVIT00`000000/k>c0;>c/`020;>c/`Go
0000102c/k<020000000VIVI09VIV@000000Ogmo0000001VIVH000000P1<C4`00`000000<c<coooo
o`03ooooo`0300000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo01;ooooo00?o
AUk7oeYWa_n1IJT00_n6IjL2ohaYYP;oT6bU0onEKjD2oiUbY0;oWGBT00?oXGNTok:C]onbTkL00onh
UkD00onFhICoooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool000Wooooo00@00000oooooooooooooooo4`00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0
000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<0080c<c<00?o
00000>KViP3Vi^H01P3Vi^H2o`0000d0oooo0ol000060>KViP03o`00003<c<`0c<c<00<0c<c<00?o
00000;>c/`2c/k<00P2c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0
000006IVIP1VIVH02`1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<0
2@2c/k<01P000000VIVI09VIV@000000Ogmo00000080IVIV00D0000004a<C01<C4`0000003<c<`04
ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0C
ooooo`04odINaomJIlKoQVNWohIWY`;oS6VV0on@K:D2oiE_Y@;oVG:T00?oWGBToj^?^OnbTkL00onb
TkL2okRG]C_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool0
1000003ooooooooooooooolC000000`06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<
C00304a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00ol00000000009VI
V@0209VIV@03o`00002c/k<0/k>c0080/k>c0_l000040<c<c0Co00001P3Vi^H=o`0000L0i^KV0_l0
00040<c<c0;o0000102c/k<00ol00000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00?o
000006IVIP1VIVH03@1VIVH010000000Ogmo07moO`00000309VIV@030000002c/k<0/k>c00T0/k>c
00Ko000009VIV@2IVIT0000007moO`00000206IVIP050000001<C4`0C4a<0000000c<c<01?ooool0
0`00003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool0
0omJIlKoKG35ofe`a@02ohaYYP?oT6bU0_nEKjD00onILZCoXX^koj^?^@02oj^?^@?o/Y>g00?o^9Ne
ooooooooool0>oooool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`0400000?oooooo
oooooooooa<000003@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH00`1VIVH00ol00000000007moO`0307moO`040000002IVIT0VIVI09VIV@;o0000
102c/k<00ol00000c<c<0<c<c0050<c<c0?o0000503Vi^H3o`0000@0c<c<0_l000050;>c/`03o`00
002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl2000000l0IVIV00D0000007moO`1oOgl0
Ogmo0000000309VIV@03o`00002c/k<0/k>c00L0/k>c00L0000009VIV@2IVIT0VIVI0000001oOgl0
00000080IVIV00D0000004a<C01<C4`0000003<c<`04ooooo`0300000?oooooooooo02gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`04oeYWa_m]L<GoOGS3ogeh``?oS7o1
0_nHQKh2oj:;^`?oZhni0onbTkLoooooo`04o`000?ooooooooooo`0000_ooooo0009ooooo`040000
0?oooooooooooooooa@000003@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0207moO`<000000P2IVIT2o`0000<0
/k>c0ol000070<c<c0Co0000303Vi^H4o`0000H0c<c<00?o00000;>c/`2c/k<0102c/k<01?l00000
VIVI09VIV@2IVIT3000000<0Ogmo0P00000B06IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT0
0`000000/k>c0;>c/`060;>c/`040000002IVIT0VIVI00000080Ogmo00<0000006IVIP0000000P1<
C4`00`000000<c<c03<c<`04ooooo`0300000?oooooooooo02kooooo0_l0000Xooooo`03o`000?oo
oooooooo01Kooooo0_m]L<D2ogeh``;oS7o10_nHQKh3oj:;^`?oZhni00?o/Y>gooooooooool0?ooo
ool00ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooooooooolE00000003o`00000I
6AT06ATI00X06ATI00?o000003<c<`0c<c<0100c<c<00`00003o00000000000404a<C00400000?l0
00000000000000<0IVIV00<00000o`0000000000101oOgl200000080VIVI3_l000030<c<c0co0000
0`3<c<`7o`0000030;>c/ol0003o000000Co000000@0VIVI00000000000000000`1oOgl200000003
o`00001VIVH0IVIV00<0IVIV3000000306IVIP050000001oOgl0Ogmo07moOol00000102IVIT00`00
0000/k>c0;>c/`040;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl00`000000IVIV00000002
04a<C0030000000c<c<0<c<c00Cooooo00<00000ooooooooool0<?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Sooooo0_mmN<<3ohao`@;oV8Fn0_nRRk/2oj^?^D?ooooo00?o0000
ooooool000002oooool000Wooooo00@00000oooooooooooooooo5`00000;01TI6@800000200c<c<0
0`000000C4a<04a<C00504a<C0800000101VIVH00`000000Ogmo07moO`0307moO`8000001P2IVIT4
o`0000@0/k>c4_l000040;>c/`Co00000`2IVIT4000000@0Ogmo0P00000706IVIP030000001<C4`0
C4a<00X0C4a<00@0000006IVIP1VIVH000000`1oOgl00`000000VIVI09VIV@0209VIV@030000002c
/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT01P000000Ogmo07moO`000000IVIV00000080
C4a<00@0000003<c<`0c<c?o00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool06oooool2ohao`@;oV8Fn00?oXX^kooooooooool0AOooool00ol0
003oooooo`00000:ooooo`002Oooool01000003ooooooooooooooolH000000`06ATI0P00000703<c
<`<000001P1<C4`00`000000IVIV06IVIP0206IVIP<00000101oOgl6000000@0VIVI1ol0000<0;>c
/`Oo0000102IVIT3000000H0Ogmo0P00000606IVIP<000003@1<C4`01@000000IVIV06IVIP1VIVH0
000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT5000000D0VIVI00H0000007moO`1oOgl0000006IV
IP00000204a<C0040000000c<c<0<c<co`0000?ooooo00<00000ooooooooool0<_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo0_l0000:ooooo`002Oooool01000003ooooo
oooooooooolI000000d06ATI0P00000803<c<`030000001<C4`0C4a<00@0C4a<0`00000406IVIP<0
00001`1oOgl4000000L0VIVI3?l0000709VIV@@000001`1oOgl2000000D0IVIV0`00000A04a<C005
0000001VIVH0IVIV06IVIP0000000P1oOgl00`000000VIVI09VIV@0;09VIV@040000001oOgl0Ogmo
00000080IVIV00@0000004a<C01<C4`000000P0c<c<01Ol0003oooooooooooooool0000003Gooooo
0_l0000Sooooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`002Oooool01000003ooooooooo
oooooolI00000003o`00000000006ATI00`06ATI00?o00000000000000001P0c<c<00ol000000000
0000000604a<C00400000?l000000000000000<0IVIV1`00000407moO`0300000?l00000000001D0
000000?o00000000001oOgl00`1oOgl500000003o`0000000000IVIV0080IVIV0`0000000ol00000
C4a<04a<C00504a<C0X00000101<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00<00000o`00
002IVIT02P2IVIT010000000Ogmo07moO`00000206IVIP03o`00001<C4`0000000<0<c<c00Go0000
oooooooooooooooo0000000gooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hooo
ool4o`0000gooooo0009ooooo`0400000?oooooooooooooooad000003P0I6AT2000000L0<c<c0`00
000704a<C0<000001`1VIVH7000001@0Ogmo1`00000706IVIP<000001`1<C4`4000000X0<c<c00<0
000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVKo00000080Ogmo00<0000009VIV@2IVIT0
202IVIT01`000000Ogmo07moO`1oOgl0000006IVIP0000000P1<C4`01@000000<c<c03<c<`0c<c?o
000000?ooooo00<00000ooooooooool0=_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo063ooooo0ol0000Aooooo`002Oooool01000003ooooooooooooooolO000000h06ATI0`000007
03<c<`<000001`1<C4`7000000L0IVIV5000000706IVIPL000001`1<C4`3000000l0<c<c00D00000
04a<C01<C4`0C4a<0000000306IVIP050000001oOgl0Ogmo07moO`000000202IVIT01Ol00000Ogmo
07moO`1oOgoo00000080IVIV00@0000004a<C01<C4`000000P0c<c<00ol0003oooooooooo`02oooo
o`0300000?oooooooooo03Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Loooo
o`Co00005?ooool000Wooooo00@00000oooooooooooooooo800000000ol00000000001TI6@0=01TI
6@04o`00000000000000000000H0<c<c100000000ol0000000000000000704a<C0/00000301VIVH6
00000003o`00000000000000008000001`1<C4`7000001<0<c<c00D0000004a<C01<C4`0C4a<0000
000306IVIP050000001oOgl0Ogmo07moO`0000001P2IVIT00`000000Ogmo07moO`0207moO`040000
001VIVH0IVIV00000080C4a<00@0000003<c<`0c<c?o00001?ooool00`00003oooooooooo`0hoooo
o`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@00000oooooooo
oooooooo9@00000?01TI6@<000002P0c<c<7000000/0C4a<3000000>04a<C0@000003P0c<c<70000
00D0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP030000001oOgl0Ogmo0080Ogmo00?o0000
0000000000000P2IVIT00`000000Ogmo07moO`0307moO`040000001VIVH0IVIV00000080C4a<00@0
000003<c<`0c<c?o00001?ooool00`00003oooooooooo`0jooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0E?ooool4o`0001cooooo0009ooooo`0400000?ooooooooooooooobT00000
3P0I6AT3000000h0<c<c2`00000<04a<C0h000002`0c<c<7000000L06ATI00<0000003<c<`0c<c<0
0`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00<0000007moO`1oOgl0101oOgl2000000D0
Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0040000000c<c<0<c<co`0000Cooooo00<00000
ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000P
ooooo`002Oooool01000003ooooooooooooooolZ000001006ATI1`00000B03<c<``000004`0c<c<6
000000l06ATI00?o000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00<0
000007moO`1oOgl02`1oOgl010000000IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<ol0
00001?ooool00`00003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0COooool4o`0002?ooooo0009ooooo`0400000?ooooooooooooooobX0000000?o000000000000
00000`00000A01TI6@03o`0000000000000000P000007P0c<c<700000003o`00000I6AT06ATI01@0
6ATI00<0000003<c<`0c<c<00P0c<c<01P000000C4a<04a<C01<C4`00000o`000080IVIV00<00000
07moO`1oOgl02@1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c
o`000004ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo
1?l0000Wooooo`002Oooool01000003ooooooooooooooolc000001T06ATI7P00000O01TI6@030000
000c<c<0<c<c0080<c<c00Go000004a<C01<C4`0C4a<0000000306IVIP030000001oOgl0Ogmo00L0
Ogmo00<0000006IVIP1VIVH00P1VIVH010000000C4a<04a<C000000303<c<`03o`000?oooooooooo
00;ooooo00<00000ooooooooool0?oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Gooooo1?l0000[ooooo`002Oooool01000003ooooooooooooooolg000005<06ATI00D0000003<c
<`0c<c<0<c<c0000000404a<C0050000001VIVH0IVIV06IVIP0000001`1oOgl00ol00000IVIV06IV
IP0206IVIP040000001<C4`0C4a<000000<0<c<c00?o000001TI6Oooool00oooool00`00003ooooo
ooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oooooo
0009ooooo`0400000?oooooooooooooooc/0000000?o0000000000000000=P0I6AT>000000T06ATI
00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1o
Ogl00`1oOgl2000000@0IVIV00@0000004a<C01<C4`000000`0c<c<00ol000006ATIooooo`03oooo
o`0300000?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0ooooo
o`Co0000<_ooool000Wooooo00@00000ooooooooooooooooB000000R01TI6AX000001`0I6AT01@00
0000<c<c03<c<`0c<c<0000000<0C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000000000000002
07moO`030000001VIVH0IVIV00@0IVIV00@0000004a<C01<C4`000000`0c<c<00ol000006ATIoooo
o`03ooooo`0300000?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0
000fooooo`002Oooool01000003ooooooooooooooon5000000H06ATI00D0000003<c<`0c<c<0<c<c
0000000304a<C0030000001VIVH0IVIV00D0IVIV0P00000606IVIP040000001<C4`0C4a<000000@0
<c<c00?o000001TI6Oooool00oooool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0=oooool4o`0003[ooooo0009ooooo`0400000?ooooooooooooooohD0
00001`0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00<0000006IVIP1VIVH0301VIVH01000
0000C4a<04a<C?l0000303<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0AOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000
003ooooooooooooooon6000000H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001V
IVH0IVIV00/0IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`03o`00000I6AT06ATI00Cooooo
00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo
0ol00012ooooo`002Oooool01000003ooooooooooooooon6000000H06ATI00D0000003<c<`0c<c<0
<c<c0000000404a<C003o`00001VIVH0IVIV00X0IVIV00D0000004a<C01<C4`0C4a<0000000303<c
<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0Aoooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01000003ooooooooooooooon70000
00H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVH0IVIV00T0IVIV00D00000
04a<C01<C4`0C4a<0000000403<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0B?oo
ool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0400000?oooooo
ooooooooohP000001@0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C0000000
2P1VIVH01@000000C4a<04a<C01<C4`0000000@0<c<c00?o000001TI6@0I6AT01?ooool00`00003o
ooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool4o`0004go
oooo0009ooooo`0400000?ooooooooooooooohL0000000?o000001TI6@0I6AT00`0I6AT00`000000
<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000002@1VIVH00`000000C4a<04a<C00204a<
C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT01?ooool00`00003oooooooooo`1;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0009ooooo`04
00000?ooooooooooooooohP000001@0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<
0080C4a<00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c
0080<c<c00?o000001TI6@0I6AT01?ooool00`00003oooooooooo`1<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0009ooooo`0400000?oooooooooooooo
ohT000001@0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<0000006IV
IP1VIVH0101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00Co000001TI
6@0I6AT06ATI1?ooool00`00003oooooooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0I
ooooo`Co0000F?ooool000Wooooo00@00000ooooooooooooooooR@00000501TI6@030000000c<c<0
<c<c0080<c<c00<0000004a<C01<C4`00`1<C4`00ol00000000000000003000000D0C4a<00<00000
03<c<`0c<c<00P0c<c<01?l000006ATI01TI6@0I6AT4ooooo`0300000?oooooooooo04oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wooooo00@00000
ooooooooooooooooR@00000501TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`03P1<
C4`00`000000<c<c03<c<`0203<c<`04o`00000I6AT06ATI01TI6@Cooooo00<00000ooooooooool0
D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Pooooo`002Ooo
ool01000003ooooooooooooooon:000000D06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<
04a<C00<04a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT00P0I6AT4ooooo`030000
0?oooooooooo057ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000
Hoooool000Wooooo00@00000ooooooooooooooooRP00000501TI6@030000000c<c<0<c<c0080<c<c
00<0000004a<C01<C4`0301<C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00806ATI
1?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000
Ioooool000Wooooo00@00000ooooooooooooooooRP00000501TI6@030000000c<c<0<c<c0080<c<c
00<0000004a<C01<C4`0301<C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00806ATI
1?ooool00`00003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`00
2Oooool01000003ooooooooooooooon:000000H06ATI00<0000003<c<`0c<c<00P0c<c<00`000000
C4a<04a<C00:04a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT00`0I6AT4ooooo`03
00000?oooooooooo05Gooooo00?o0000ooooool000001Oooool3o`0006oooooo0009ooooo`040000
0?ooooooooooooooohX000001P0I6AT00`000000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00T0
C4a<00<0000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0301TI6@Cooooo00<00000oooooooo
ool0E_ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooo
ooooRP00000601TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`0201<C4`00`000000
<c<c03<c<`0303<c<`03o`00000I6AT06ATI00<06ATI1?ooool00`00003oooooooooo`1Gooooo`;o
0000M_ooool000Wooooo00@00000ooooooooooooooooRP00000601TI6@030000000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00@0
6ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon;000000H0
6ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00504a<C003o`00000c<c<0<c<c00@0
<c<c00?o000001TI6@0I6AT0100I6AT01Ol0003oooooooooooooool000000=7ooooo0009ooooo`04
00000?oooooooooooooooh/000001P0I6AT00`000000<c<c03<c<`0403<c<`0500000?l000000000
0000001<C4`00P00000703<c<`03o`00000I6AT06ATI00@06ATI00Go0000oooooooooooooooo0000
003Aooooo`002Oooool01000003ooooooooooooooon;000000H06ATI00<0000003<c<`0c<c<0200c
<c<00`000000<c<c03<c<`0703<c<`03o`00000I6AT06ATI00@06ATI00Go0000oooooooooooooooo
0000003Aooooo`002Oooool01000003ooooooooooooooon<000000H06ATI00?o000003<c<`0c<c<0
400c<c<00ol000006ATI01TI6@0401TI6@03o`000?oooooooooo00;ooooo00<00000ooooooooool0
coooool000Wooooo00@00000ooooooooooooooooS000000601TI6@030000000c<c<0<c<c0100<c<c
00?o000001TI6@0I6AT0100I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?oooooooooooooooh`000001P0I6AT00`000000<c<c03<c<`0@03<c<`03o`00
000I6AT06ATI00@06ATI00?o0000ooooooooool00_ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003ooooooooooooooon<000000L06ATI00<0000003<c<`0c<c<03P0c<c<00ol000006ATI
01TI6@0501TI6@03o`000?oooooooooo00;ooooo00<00000ooooooooool0coooool000Wooooo00@0
0000ooooooooooooooooS000000701TI6@030000000c<c<0<c<c00h0<c<c00?o000001TI6@0I6AT0
1@0I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
oooooooooooooh`00000200I6AT00`000000<c<c03<c<`0<03<c<`03o`00000I6AT06ATI00H06ATI
00?o0000ooooooooool00_ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooon<000000P06ATI00<0000003<c<`0c<c<0300c<c<00ol000006ATI01TI6@0601TI6@03o`00
0?oooooooooo00;ooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
S@00000801TI6@03o`00000c<c<0<c<c00/0<c<c00?o000001TI6@0I6AT01@0I6AT00ol000000000
ooooo`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooohd00000
2@0I6AT00ol00000<c<c03<c<`0903<c<`03o`00000I6AT06ATI00H06ATI00?o000000000?ooool0
0oooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo0009oooookKo00004Ooooonfo`0000[ooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2?ooooo`0300000?oooooooooo00_ooooo0`00000<ooooo`03
00000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0
S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`;ookK1
00<00000oonf`Ooo]/402Ooo]/42000000?ookK100<00000oonf`Ooo]/402Ooo]/401000003ookK1
oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo
8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0S@3oool2oonf`@030000
0?oo]/7ookK100SookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@08oonf`@040000
0?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0
S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf
`@00003ookK100WookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@07oonf`@040000
0?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0
S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf
`@00003ookK100SookK100?o0000oonf`Ooo]/402?oo]/400ol0003ookK1oonf`@07oonf`@03o`00
0?oo]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf`@00
003ookK100OookK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo
]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`0300000?oo]/7o
okK100OookK100<00000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@07oonf`@0500000?oo]/7o
ooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`0300000?oo]/7ookK100KookK100<00000
oonf`Ooo]/403?oo]/400`00003ookK1oonf`@06oonf`@0500000?oo]/7oooooooooool000002_oo
ool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`2=0?ooo`0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/403?oo]/40
0ol0003ookK1oonf`@06oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000
ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=
0?ooo`0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/403Ooo]/400`00003ookK1oonf`@06
oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`0300000?oo]/7o
okK100GookK100<00000oonf`Ooo]/403_oo]/400`00003ookK1oonf`@05oonf`@0500000?oo]/7o
ooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03o`000?oo]/7ookK100CookK100?o0000
oonf`Ooo]/404?oo]/400`00003ookK1oonf`@04oonf`@0500000?oo]/7oooooooooool000002_oo
ool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`2=0?ooo`0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/404?oo]/40
0`00003ookK1oonf`@04oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000
ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2<
0?ooo`0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/404Ooo]/400`00003ookK1oonf`@04
oonf`@0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0S03oool00`00003ookK1oonf`@04
oonf`@0300000?oo]/7ookK100OookK10`000008oonf`@0300000?oo]/7ookK100CookK100@00000
oooooooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`2<0?ooo`0300000?oo]/7ookK100CookK100<00000
oonf`Ooo]/401Ooo]/42000000?ookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@04
oonf`@0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0S03oool00`00003ookK1oonf`@04
oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@05
oonf`@0300000?oo]/7ookK100?ookK100@00000oooooooooooo00002_ooool000Wooooo00?o0000
ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2;
0?ooo`030000003ooooookK100CookK100<00000oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@05
oonf`@03o`000?oo]/7ookK100CookK100<00000oonf`Ooo]/401?oo]/400`00003oooooo`00000:
ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo08/0oooo00<000000?oooooo]/401?oo]/400`00003ookK1oonf`@04oonf
`@0300000?oo]/7ookK100OookK100<00000oonf`Ooo]/400ooo]/400ol0003ookK1oonf`@04oonf
`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R`3oool00`000000oooooonf`@04oonf`@03
00000?oo]/7ookK100?ookK100<00000oonf`Ooo]/402?oo]/400`00003ookK1oonf`@03oonf`@03
00000?oo]/7ookK100CookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08X0oooo
00<000000?ooo`3oool01?oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100[ookK1
00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`2:0?ooo`030000003oool0oooo00CookK100<00000oonf`Ooo]/400_oo
]/400ol0003ookK1oonf`@0<oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo
]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0RP3oool00`000000oooo0?ooo`04
oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100?ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
08X0oooo00<000000?ooo`3oool00ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK1
00cookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`290?ooo`040000003oool0oooo0?ooo`?ookK100?o0000oonf
`Ooo]/400_oo]/400`00003ookK1oonf`@0=oonf`@0300000?oo]/7ookK100?ookK100<00000oonf
`Ooo]/400_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0
oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R@3oool010000000
oooo0?ooo`3oool3oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/401Ooo]/430000
00KookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`290?ooo`040000003oool0oooo0?ooo`?ookK100<00000oonf
`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@8000000ooo]/400`00003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`;ookK100<00000oonf`Ooo
]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo
]/400ooo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`280?ooo`030000003oool0oooo0080oooo0_oo]/401@00003o
okK1oonf`Ooo]/7o000000GookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@02oonf
`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/7ookK10_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo08L0oooo00<000000?ooo`3oool00`3oool2oonf`@0500000?oo]/7ookK1
oonf`@0000001?oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100;ookK100<00000
oonf`Ooo]/400_oo]/401000003ookK1oonf`Ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool0C`3ooolM000001T0oooo0P0000060?ooo`03oonf`@00003ookK100?ookK100D00000
oonf`Ooo]/7ookK10000000;oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK1
00000003oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`140?ooo`/000007@3o
ool;000000`0oooo0P0000080?ooo`03oonf`@00003ookK100;ookK100<00000oonf`Ooo]/400_oo
]/400`00003ookK1oonf`@09oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK1
00000003oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
oolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0j0?ooo`X00000<`3o
ool:00000003o`0000000000oooo00T0oooo00<00000oonf`Ooo]/400_oo]/401@00003ookK1oonf
`Ooo]/40000000gookK100<00000oonf`Ooo]/400_oo]/401Ol0003ookK1oonf`Ooo]/7o000000;o
okK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo03H0oooo1000001B0?ooo`030000
0?oo]/7ookK100?ookK100D00000oonf`Ooo]/7ookK100000006oonf`@<000001?oo]/400`00003o
okK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/42ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool0;`3oool7000001`0oooo5`00000R0?ooo`030000003ooooookK100?o
okK100D00000oonf`Ooo]/7ookK100000004oonf`@<000000ooo]/400`00003ookK1oonf`@02oonf
`@05o`000?oo]/7ookK1oonf`@0000001?oo]/401@00003ookK1oooooooooooo000000[ooooo0009
ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool0:`3oool01000003o000000000000000E0?ooo`h000005`3oool;000001H0oooo00?o
00000?ooo`3oool00ooo]/401@00003ookK1oonf`Ooo]/40000000CookK100<00000oonf`Ooo]/40
1Ooo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401@00003o
okK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool6oonf`@<000004_oo]/470000033o
okK11P00000>oonf`@8000001_oo]/401@00003ookK1oonf`Ooo]/7o000000?ookK100<00000oonf
`Ooo]/401ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100H00000oonf`Ooo]/7ookK10000
0?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooS_oo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool2oonf`@@000004_oo
]/43000000kookK18@00000>oonf`@L000000ooo]/44000000OookK100<00000oonf`Ooo]/400_oo
]/401000003ookK1oonf`@00000:oonf`@0500000?oo]/7ookK1oonf`@0000000ooo]/401P00003o
okK1oonf`Ooo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3oool08P3ooon>oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0R0?oo
o`8000004_oo]/44000000[ookK11`00000Qoonf`@L000003_oo]/43000000[ookK100<00000oonf
`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000_ookK100D00000oonf`Ooo]/7ookK10000
0003oonf`@0500000?oo]/7ookK100000?oo]/400_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?ooohkookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ool0oooo0200oooo00<00000o`000?oo]/403ooo]/4200000003o`000000003ookK100KookK11000
00000ol0000000000000000;oonf`@L0000000?o00000000000000001P0000000ol0000000000000
0007000000[ookK100<00000o`00000000001000000Boonf`@8000001?oo]/401@00003ookK1oonf
`Ooo]/40000000gookK100@00000oonf`Ooo]/4000000ooo]/401@00003ookK1oonf`@00003ookK1
00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooon>oonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0M0?ooo`<000000P3oool=oonf`@<0
00002?oo]/43000000OookK12`00000Joonf`@L000002_oo]/44000000cookK10P000005oonf`@03
00000?oo]/7ookK100;ookK100@00000oonf`Ooo]/7ookK11P000004oonf`@0400000?oo]/7ookK1
000000?ookK100D00000oonf`Ooo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo0280ooooN_oo]/440000oa3ookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo01X0oooo0`0000050?ooo`WookK110000007oonf`@@000001ooo]/43
000000OookK17P000007oonf`@L000001ooo]/43000000OookK10P000006oonf`@0300000?oo]/7o
okK100;ookK100D00000oonf`Ooo]/7ookK100000006oonf`@0300000?oo]/7ookK100;ookK100@0
0000oonf`Ooo]/4000000_oo]/401@00003ookK1oonf`Ooo]/40000000;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomioonf`@030000oooo]/7ookK100;ookK1
00<0003ooonf`Ooo]/403Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`KookK100<00000o`00000000001ooo]/401000003o0000
000000000006oonf`@D000000ooo]/47000000[ookK100<00000o`000?l000002P000007oonf`@H0
000000?o0000oonf`Ooo]/401Ooo]/44000000KookK11`000007oonf`@06o`000?oo]/7ookK1oonf
`Ol0000000000ooo]/400`00003ookK1oonf`@06oonf`@05o`000?oo]/7ookK1oonf`Ol000000_oo
]/401000003ookK1oonf`@000003oonf`@0400000?ooooooooooo`0000[ooooo0009ooooo`03o`00
0?ooool0oooo0280oooo:_oo]/4Mo`00oc;ookK100<0003ooonf`Ooo]/400_oo]/400`000?oookK1
oonf`@0=oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0G0?ooo`030000
0?l00000oooo00P0oooo1Ooo]/400`00003ookK1oonf`@05oonf`@<000002?oo]/400`00003o0000
oonf`@04oonf`@<000001ooo]/4:000000gookK12P000004oonf`@<000002?oo]/430000013ookK1
00<00000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/7o000000[ookK100@00000oonf`Ooo
]/4000000_oo]/401000003ookK1oonf`@000003oonf`@0400000?ooooooooooo`0000[ooooo0009
ooooo`03o`000?ooool0oooo0280oooo9Ooo]/45o`00oagookK11Ol00?l/oonf`@030000oooo]/7o
okK100CookK100<0003ooonf`Ooo]/403?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool05@3oool2000000/0oooo0ooo]/42000000OookK100<00000oonf`Ooo]/401Ooo]/44
000000?ookK110000003oonf`@L000001ooo]/4C000000OookK110000003oonf`@@000001ooo]/43
000000_ookK10P000004oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/402?oo]/40
1000003ookK1oonf`@000003oonf`@0300000?oo]/40000000?ookK100@00000oooooooooooo0000
2_ooool000Wooooo00?o0000ooooo`3oool08P3ooolRoonf`@?o003o9ooo]/43o`00obWookK100<0
003ooonf`Ooo]/401Ooo]/400`000?oookK1oonf`@0;oonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00?ookK10000000000001ooo
]/42000000GookK10`000004oonf`@<000001?oo]/43000000OookK11`00000Coonf`@L000001?oo
]/43000000CookK10`000007oonf`@<000001ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/402_oo]/401000003ookK1oonf`@000002oonf`@04o`00
0?oo]/7ookK1000000?ookK100<00000ooooool000002_ooool000Wooooo00?o0000ooooo`3oool0
8P3ooolPoonf`@;o003o;Ooo]/42o`00obKookK100<0003ooonf`Ooo]/401_oo]/400`000?oookK1
oonf`@0;oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0D0?ooo`03o`00
003oool0oooo00X0oooo0P000007oonf`@8000001Ooo]/42000000KookK100<00000oonf`Ooo]/40
0_oo]/400`00003o000000000003oonf`@@000000_l000000`00003ookK1oonf`@02oonf`A000000
00?o00000000000000001`000003oonf`@03o`0000000000000000CookK100?o0000000000000000
1?oo]/43000000OookK11@0000000ol000000000oonf`@04oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/400_oo]/45000000CookK100@00000oonf`Ooo]/4000000_oo]/401000003o
okK1oonf`@000003oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280
oooo7Ooo]/43o`00oc7ookK10_l00?lSoonf`@03o`00oooo]/7ookK100SookK100<0003ooonf`Ooo
]/402_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04`3oool00`000000
oooo0?ooo`0:0?ooo`030000003ooooookK100KookK100<00000oonf`Ooo]/401?oo]/400`00003o
okK1oonf`@04oonf`@0300000?l0003ookK100;ookK10P000004oonf`@8000001?oo]/47000000Oo
okK130000007oonf`@8000001?oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100Co
okK100<00000oonf`Ooo]/404?oo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf
`@0000001?oo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1000000;ookK100@00000
oonf`Ooo]/4000000ooo]/400`00003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R
0?oooa_ookK10_l00?lfoonf`@;o003o8Ooo]/400`000?oookK1oonf`@08oonf`@030000oooo]/7o
okK100[ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0180oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`06oonf`@0300000?oo]/7ookK100CookK100<00000
oonf`Ooo]/400ooo]/42000000CookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03
oonf`@0300000?oo]/7ookK100GookK11`00000<oonf`@8000001ooo]/42000000?ookK10P000005
oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/403_oo]/400`00003ookK1oonf`@02
oonf`@0500000?oo]/7ookK1oonf`@0000001_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo
]/40000000;ookK100@00000oonf`Ooo]/4000000ooo]/400`00003oooooo`00000:ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?oooaWookK10_l00?ljoonf`@03o`00oooo]/7ookK101gookK100<0
003ooonf`Ooo]/402Ooo]/400`000?oookK1oonf`@0:oonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01Ooo
]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo
]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401?oo
]/400ol000000000oonf`@0Doonf`@<000001_oo]/400ol0003ookK1oonf`@02oonf`@8000001?oo
]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100gookK100<00000oonf`Ooo]/400_oo
]/401000003ookK1oonf`Ol00008oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/401P00003o
okK1oonf`@00003ookK1000000?ookK100<00000ooooool000002_ooool000Wooooo00?o0000oooo
o`3oool08P3ooolHoonf`@03o`00oooo]/7ookK103_ookK100?o003ooonf`Ooo]/407?oo]/400`00
0?oookK1oonf`@0:oonf`@030000oooo]/7ookK100WookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo0100oooo00?o00000?ooo`3oool02`3oool010000000oooo0?ooo`3oool4
oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/400ol0003ookK1oonf`@03
oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00003o0000oonf`@04
oonf`@80000000?o0000oonf`Ooo]/405_oo]/42000000GookK100<00000oonf`Ooo]/401?oo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/402ooo]/40
0`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`Ol000002Ooo]/401ol0003ookK1oonf
`Ooo]/400000oonf`@0000000_oo]/401000003ookK1oonf`@000002oonf`@;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolGoonf`@03o`00oooo]/7ookK101_o
okK10ol0000Ooonf`@03o`00oooo]/7ookK101[ookK100<0003ooonf`Ooo]/402ooo]/400`000?oo
okK1oonf`@09oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0@0?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo1?oo]/400`00003ookK1oonf`@04oonf
`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400ol0003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/42000000SookK12ol0000:oonf
`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf
`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@02oonf
`@0500000?oo]/7ookK1oonf`@0000002_oo]/401P00003ookK1oonf`@00003ookK1000000;ookK1
00@00000oonf`Ooo]/4000000_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?ooool0oooo0280oooo5ooo]/400ol00?oookK1oonf`@0Joonf`@Go00007_oo]/400ol00?oookK1
oonf`@0Joonf`@030000oooo]/7ookK100_ookK100<0003ooonf`Ooo]/402Ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo0ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100?ookK1
00<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK1
00<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@06oonf`@03o`000?oo]/7ookK100WookK1
0_l00009oonf`@03o`000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1
oonf`@02oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/402Ooo]/400`00003ookK1
oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000002ooo]/401000003ookK1oonf`@000002oonf
`@0300000?oo]/40000000;ookK100<00000oonf`Ooo]/400_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?ooo`0R0?oooaOookK100?o003ooonf`Ooo]/406_oo]/45o`0001ko
okK100?o003ooonf`Ooo]/406_oo]/400`000?oookK1oonf`@0;oonf`@030000oooo]/7ookK100Wo
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo00l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`?ookK100<00000oonf`Ooo]/400ooo]/400`00003o
okK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@02oonf`@03o`000?oo]/7ookK100CookK100<00000oonf`Ooo]/401_oo]/42o`0000go
okK100?o0000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;o
okK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100Wo
okK100<00000oonf`Ooo]/400_oo]/401@00003ookK1oonf`Ooo]/40000000_ookK100@00000oonf
`Ooo]/4000000_oo]/400`00003ookK100000002oonf`@0300000?oo]/7ookK100;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolGoonf`@03o`00oooo]/7ookK1
01[ookK11Ol0000Moonf`@03o`00oooo]/7ookK101[ookK100<0003ooonf`Ooo]/403Ooo]/400`00
0?oookK1oonf`@08oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0?0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool3oonf`@0300000?oo]/7ookK1
00?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK1
00;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1
00SookK100?o0000oonf`Ooo]/401ooo]/43o`0000SookK100<00000oonf`Ooo]/401?oo]/400`00
003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00
003ookK1oonf`@09oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK10000000;
oonf`@0400000?oo]/7ookK1000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf
`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo5ooo]/40
0ol00?oookK1oonf`@0Koonf`@?o00007_oo]/400ol00?oookK1oonf`@0Joonf`@030000oooo]/7o
okK100gookK100<0003ooonf`Ooo]/402?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0ooo]/40
0`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/401?oo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/401?oo]/42
000000WookK12Ol0000:oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/40
0`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/402_oo]/40
0`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@0000001?oo]/43000000CookK100@0
0000oonf`Ooo]/4000000_oo]/400`00003ookK100000002oonf`@0300000?oo]/7ookK100;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolGoonf`@;o003o>ooo
]/42o`00oagookK100<0003ooonf`Ooo]/403Ooo]/400`000?oookK1oonf`@08oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool3oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo
]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo
]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK101OookK10P000006oonf`@03o`000?oo
]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100cookK100D00000oonf`Ooo]/7ookK100000002oonf`@0300000?oo]/7ookK100?ookK1
00@00000oonf`Ooo]/7o00001?oo]/401P00003ookK1oonf`@00003ookK1000000;ookK100<00000
oonf`@0000000_oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
0280oooo6Ooo]/400ol00?oookK1oonf`@0foonf`@;o003o7ooo]/400`000?oookK1oonf`@0=oonf
`@030000oooo]/7ookK100SookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`?ookK100<00000oonf
`Ooo]/401?oo]/400`00003ookK1oonf`@03oonf`@8000001?oo]/400ol0003ookK1oonf`@03oonf
`@0300000?oo]/7ookK100?ookK10P000006oonf`@0400000?l0000000000000017ookK110000006
oonf`@8000001?oo]/42000000?ookK10P0000000ol0003ookK1oonf`@02oonf`@8000003ooo]/40
1@00003ookK1oonf`Ooo]/40000000;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf
`@02oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/400`00003ookK100000002oonf`@030000
0?oo]/40000000;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`0R0?oooa[ookK10_l00?ldoonf`@;o003o8Ooo]/400`000?oookK1oonf`@0=oonf`@030000oooo
]/7ookK100SookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0100oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`CookK100?o000000000?oo]/401?oo
]/400ol000000000oonf`@04oonf`@8000000ooo]/400`00003ookK1oonf`@03oonf`@03o`000000
003ookK100CookK10`000007oonf`@<000002_oo]/44000000OookK10`000004oonf`@8000001?oo
]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100oookK100D00000oonf`Ooo]/7ookK1
00000002oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/401@00003ookK1
oonf`Ooo]/40000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK100000002oonf`@;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolLoonf`@;o003o
<?oo]/42o`00ob;ookK100<0003ooonf`Ooo]/403ooo]/400`000?oookK1oonf`@07oonf`@;ooooo
00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool0oooo1_oo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100Co
okK100D00000oonf`Ooo]/7ookK100000006oonf`@0300000?oo]/7ookK100GookK10`000007oonf
`@X000001ooo]/44000000?ookK110000003oonf`@<000001Ooo]/42000000SookK11@000006oonf
`@0400000?oo]/7ookK1000000;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03
oonf`@0700000?oo]/7ookK1oonf`@00003ookK100000002oonf`@0300000?oo]/40000000;ookK1
00D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooakookK1
0_l00?l/oonf`@;o003o9?oo]/400`000?oookK1oonf`@0?oonf`@030000oooo]/7ookK100OookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0140oooo00?o00000?ooo`3oool0
2`3oool2000000030?oooooo]/7ookK100GookK100<00000oonf`Ooo]/401?oo]/42000000GookK1
00@00000o`000000003ookK1100000000ol00000000000000007000000?ookK12@0000000ol00000
00000000000300000003o`0000000000000000H000000ooo]/4200000003o`000000003ookK100?o
okK10`000004oonf`@80000000?o000000000?oo]/401?oo]/400ol00000000000000002000000Go
okK100<00000o`000?oo]/400ooo]/401000003ookK1oonf`@000002oonf`@0300000?oo]/7ookK1
00;ookK100<00000oonf`Ooo]/400ooo]/401`00003ookK1oonf`Ooo]/400000oonf`@0000000_oo
]/400`00003ookK100000002oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o
0000ooooo`3oool08P3ooolPoonf`@Ko003o8?oo]/46o`00obKookK100<0003ooonf`Ooo]/403ooo
]/400`000?oookK1oonf`@07oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`0B0?ooo`030000003oool0oooo00`0oooo00<00000oonf`Ooo]/401Ooo]/400ol000000000oonf
`@06oonf`@8000001_oo]/400`00003ookK1oonf`@05oonf`@<000001?oo]/470000017ookK11P00
0004oonf`@@000001_oo]/400`00003ookK1oonf`@05oonf`@8000003?oo]/401@00003ookK1oonf
`Ooo]/40000000;ookK100@00000oonf`Ooo]/4000001?oo]/400`00003ookK1oonf`@03oonf`@07
00000?oo]/7ookK1oonf`@00003ookK100000002oonf`@0300000?oo]/40000000;ookK100D00000
oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooobKookK11Ol00?lF
oonf`@Go003o;?oo]/400`000?oookK1oonf`@0?oonf`@030000oooo]/7ookK100OookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01<0oooo00<000000?ooo`3oool0303oool2
000000OookK10P000007oonf`@<000001?oo]/43000000OookK110000007oonf`A4000001ooo]/43
000000CookK11P000004oonf`@@000003ooo]/401000003ookK1oonf`@000002oonf`@0400000?oo
]/7ookK1000000CookK100<00000oonf`Ooo]/400ooo]/401`00003ookK1oonf`Ooo]/400000oonf
`@0000000_oo]/400`00003ookK100000002oonf`@0500000?oo]/7oooooooooool000002_ooool0
00Wooooo00?o0000ooooo`3oool08P3oool[oonf`AKo003o<Ooo]/400`000?oookK1oonf`@0@oonf
`@030000oooo]/7ookK100KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo
01@0oooo00<000000?ooo`3oool02`3oool2oonf`@0300000?oo]/7ookK100KookK10`000007oonf
`@8000001Ooo]/44000000OookK12P00000:oonf`@/000001?oo]/43000000OookK10`000008oonf
`@H000001_oo]/401000003ookK1oonf`@000002oonf`@0400000?oo]/7ookK1000000?ookK100<0
0000oonf`Ooo]/400ooo]/401`00003ookK1oonf`Ooo]/400000oonf`@0000000_oo]/400`00003o
okK100000002oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3o
ool08P3ooomboonf`@030000oooo]/7ookK1013ookK100<0003ooonf`Ooo]/401_oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool05@3oool00ol0000000000000000:0?ooo`?o
okK100?o00000000000000002?oo]/43000000KookK100?o00000000000000000P000004oonf`@03
00000?l00000000000@000002_oo]/4:000000OookK11P0000000ol000000000oonf`@05oonf`@@0
00001ooo]/4200000003o`000000003ookK100GookK100?o000000000?oo]/400ooo]/401?l0003o
okK1oonf`@000002oonf`@0400000?oo]/7ookK1000000?ookK100<00000oonf`Ooo]/400ooo]/40
1`00003ookK1oonf`Ooo]/400000oonf`@0000000_oo]/400`00003ookK100000002oonf`@050000
0?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool08P3ooomboonf`@030000
oooo]/7ookK1013ookK100<0003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0603oool2000000P0oooo1_oo]/400`00003ookK1oonf`@08oonf`@@00000
1ooo]/44000000OookK16`000007oonf`@L000001ooo]/44000000cookK100D00000oonf`Ooo]/7o
okK100000002oonf`@0400000?oo]/7ookK1000000;ookK100D00000oonf`Ooo]/7ookK100000005
oonf`@0700000?oo]/7ookK1oonf`@00003ookK100000002oonf`@0300000?oo]/40000000;ookK1
00D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooog;ookK1
00?o003ooonf`Ooo]/404?oo]/400`000?oookK1oonf`@06oonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo1ooo]/43000000_ookK1
10000007oonf`@L000006ooo]/47000000OookK11`00000Aoonf`@0500000?oo]/7ookK1oonf`@00
00000_oo]/401P00003ookK1oonf`@00003ookK1000000?ookK100<00000oonf`Ooo]/401?oo]/40
1000003ookK1oonf`@000002oonf`@0500000?oo]/400000oonf`@0000000_oo]/401@00003ookK1
oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280ooooL_oo]/400`000?oookK1
oonf`@0@oonf`@030000oooo]/7ookK100KookK10_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0oooo01/0oooo00@00000o`000000000000000`3oool:oonf`@0400000?l0000000000000
00_ookK11000000:oonf`A/000002_oo]/4200000003o`000000003ookK100gookK11@000006oonf
`@0400000?oo]/7ookK1000000;ookK100H00000oonf`Ooo]/400000oonf`@000003oonf`@030000
0?oo]/7ookK100CookK100@00000oonf`Ooo]/4000000_oo]/401@00003ookK100000?oo]/400000
00;ookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oo
og;ookK100<0003ooonf`Ooo]/404Ooo]/400`000?oookK1oonf`@05oonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`0O0?ooo`80000000<0oooooonf`Ooo]/403?oo]/430000
00cookK12P00000Koonf`@X000002ooo]/47000000GookK10P000004oonf`@0400000?oo]/7ookK1
000000;ookK100H00000oonf`Ooo]/400000oonf`@000003oonf`@0300000?oo]/7ookK100CookK1
00@00000oonf`Ooo]/4000000_oo]/401@00003ookK100000?oo]/40000000;ookK100D00000oonf
`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooog;ookK100<0003ooonf
`Ooo]/404Ooo]/400`000?oookK1oonf`@05oonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`0Q0?ooo`0300000?oo]/7ookK100oookK12000000>oonf`A/000003_oo]/470000
00gookK100<00000oonf`Ooo]/400_oo]/401000003ookK1oonf`@000002oonf`@0600000?oo]/7o
okK100000?oo]/4000000ooo]/400`00003ookK1oonf`@04oonf`@0400000?oo]/7ookK1000000;o
okK100D00000oonf`@00003ookK100000002oonf`@0500000?oo]/7oooooooooool000002_ooool0
00Wooooo00?o0000ooooo`3oool08P3ooomboonf`@030000oooo]/7ookK1017ookK100<0003ooonf
`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool30000
01KookK11P00000[oonf`@H000005Ooo]/400`00003ookK1oonf`@02oonf`@0600000?oo]/7ookK1
00000?oo]/4000000_oo]/400`00003ookK100000002oonf`@0300000?oo]/7ookK100GookK100/0
0000oonf`Ooo]/7ookK100000?oo]/400000oonf`@00003ookK100000002oonf`@0500000?oo]/7o
ooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool08P3ooomboonf`@030000oooo]/7o
okK1017ookK100<0003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool08P3oool3oonf`@80000000?o00000000000000000P00000Eoonf`@03o`0000000000
000000P000005Ooo]/4800000003o`0000000000000001cookK100D00000oonf`Ooo]/7ookK10000
0002oonf`@0300000?oo]/40000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf
`@05oonf`@0;00000?oo]/7ookK1oonf`@00003ookK100000?oo]/400000oonf`@0000000_oo]/40
1@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo08d0oooo1ooo]/40
0`000?oookK1oonf`@0Aoonf`@030000oooo]/7ookK100GookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo02`0oooo1000000L0?oooaD000009`3oool01@000000oooo0?ooo`3o
ool0000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK100000002oonf`@0300000?oo
]/7ookK100GookK100/00000oonf`Ooo]/7ookK100000?oo]/400000oonf`@00003ookK100000002
oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3oool6
oonf`@030000oooo]/7ookK101;ookK100<0003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool0<03oool3000004<0oooo2`0000080?ooo`070000003oool0
oooo0?ooo`00003ookK100000002oonf`@0500000?oo]/400000oonf`@0000000_oo]/400`00003o
okK1oonf`@06oonf`@0800000?oo]/7ookK100000?oo]/400000oonf`@000002oonf`@0400000?oo
]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
ool6oonf`@030000oooo]/7ookK101;ookK100<0003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0<`3oool600000003o`0000000000oooo03<0oooo0P00
00000ol00000000000000002000000/0oooo0P0000060?ooo`070000003oool0oooo0?ooo`00003o
okK100000002oonf`@0500000?oo]/400000oonf`@0000000_oo]/400`00003ookK1oonf`@06oonf
`@0800000?oo]/7ookK100000?oo]/400000oonf`@000002oonf`@0400000?oo]/400000oonf`@;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool6oonf`@030000
oooo]/7ookK101;ookK100<0003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0>`3oool>000001P0oooo3P00000C0?ooo`030000003oool0oooo00@0oooo
00L000000?ooo`3oool0oooo00000?oo]/40000000;ookK100D00000oonf`@00003ookK100000002
oonf`@0300000?oo]/7ookK100KookK100P00000oonf`Ooo]/400000oonf`@00003ookK1000000;o
okK100@00000oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?ooo`2=0?ooo`KookK100<0003ooonf`Ooo]/404_oo]/400`000?oookK1oonf`@05oonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`190?oooaP000008P3oool00`000000
oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`00003ookK100000002oonf`@0500000?oo]/40
0000oonf`@0000000_oo]/400`00003ookK1oonf`@06oonf`@0800000?oo]/7ookK100000?oo]/40
0000oonf`@000002oonf`@0400000?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3oool0S@3oool6oonf`@030000oooo]/7ookK101;ookK100<0003ooonf
`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0Q03oool00`00
0000oooo0?ooo`030?ooo`060000003oool0oooo00000?oo]/4000000_oo]/401@00003ookK10000
0?oo]/40000000;ookK100<00000oonf`Ooo]/401ooo]/401`00003ookK100000?oo]/400000oonf
`@0000000_oo]/401000003ookK100000?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?ooool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@0Boonf`@030000oooo]/7ookK1
00GookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08D0oooo00<000000?oo
o`3oool00P3oool01P000000oooo0?ooo`00003ookK1000000;ookK100D00000oonf`@00003ookK1
00000002oonf`@0300000?oo]/7ookK100OookK100L00000oonf`@00003ookK100000?oo]/400000
00;ookK100@00000oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003ooooo0?ooo`2=0?ooo`KookK100<0003ooonf`Ooo]/404_oo]/400`000?oookK1oonf`@05oonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`250?ooo`030000003oool0oooo
0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@0500000?oo]/400000oonf`@000000
0_oo]/400`00003ookK1oonf`@07oonf`@0700000?oo]/400000oonf`@00003ookK100000002oonf
`@0400000?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3oool0S@3oool6oonf`@030000oooo]/7ookK101;ookK100<0003ooonf`Ooo]/401Ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0Q@3oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo00000?oo]/4000000_oo]/401@00003ookK100000?oo]/40000000;ookK1
00<00000oonf`Ooo]/401ooo]/400`00003ookK100000002oonf`@0800000?oo]/400000oonf`@00
003ookK100000?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
08d0oooo1_oo]/400`000?oookK1oonf`@0Boonf`@030000oooo]/7ookK100GookK10_ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0oooo08D0oooo00<000000?ooo`3oool00P3oool01P00
0000oooo0?ooo`00003ookK1000000;ookK100D00000oonf`@00003ookK100000002oonf`@030000
0?oo]/7ookK100OookK100<00000oonf`@0000000_oo]/402000003ookK100000?oo]/400000oonf
`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?oo
o`KookK100<0003ooonf`Ooo]/404ooo]/400`000?oookK1oonf`@04oonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`250?ooo`030000003oool0oooo0080oooo00H000000?oo
o`3oool00000oonf`@000002oonf`@0500000?oo]/400000oonf`@0000000_oo]/400`00003ookK1
oonf`@07oonf`@0300000?oo]/40000000;ookK100P00000oonf`@00003ookK100000?oo]/400000
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool6oonf
`@030000oooo]/7ookK101?ookK100<0003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo
00000?oo]/4000000_oo]/401@00003ookK100000?oo]/40000000;ookK100<00000oonf`Ooo]/40
1ooo]/400`00003ookK100000002oonf`@0800000?oo]/400000oonf`@00003ookK100000?oo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo1_oo]/400`00
0?oookK1oonf`@0Coonf`@030000oooo]/7ookK100CookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo08D0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00003o
okK1000000;ookK100L00000oonf`@00003ookK100000?oo]/40000000[ookK100<00000oonf`@00
00000_oo]/402000003ookK100000?oo]/400000oonf`@00003ookK10_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`KookK100<0003ooonf`Ooo]/404ooo]/40
0`000?oookK1oonf`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`25
0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@070000
0?oo]/400000oonf`@00003ookK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/400000oonf
`@00003ookK100000?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@0Coonf`@030000oooo]/7ookK100Co
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08D0oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`00003ookK1000000;ookK100L00000oonf`@00003ookK10000
0?oo]/40000000[ookK100d00000oonf`Ooo]/400000oonf`@00003ookK100000?oo]/400000oonf
`@00003ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3o
ool6oonf`@030000oooo]/7ookK101?ookK100<0003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`060000003o
ool0oooo00000?oo]/4000000_oo]/401`00003ookK100000?oo]/400000oonf`@0000002_oo]/40
3@00003ookK1oonf`@00003ookK100000?oo]/400000oonf`@00003ookK100000?oo]/400_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`KookK100<0003ooonf
`Ooo]/404ooo]/400`000?oookK1oonf`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`250?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000oonf`@00
0002oonf`@0700000?oo]/400000oonf`@00003ookK10000000:oonf`@0=00000?oo]/7ookK10000
0?oo]/400000oonf`@00003ookK100000?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@07oonf`@?o0000
2Ooo]/400`000?oookK1oonf`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`250?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000oonf`@000002oonf
`@0700000?oo]/400000oonf`@00003ookK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/40
0000oonf`@00003ookK100000?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?ooool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@06oonf`@Go00002?oo]/40
0`000?oookK1oonf`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`25
0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@070000
0?oo]/400000oonf`@00003ookK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/400000oonf
`@00003ookK100000?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?ooool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@06oonf`@Go00002?oo]/400`000?oo
okK1oonf`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`250?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@0700000?oo]/40
0000oonf`@00003ookK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/400000oonf`@00003o
okK100000?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@06oonf`@Go00002?oo]/400`000?oookK1oonf
`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`250?ooo`030000003o
ool0oooo0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@0700000?oo]/400000oonf
`@00003ookK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/400000oonf`@00003ookK10000
0?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo
08d0oooo1_oo]/400`000?oookK1oonf`@07oonf`@?o00002Ooo]/400`000?oookK1oonf`@04oonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`250?ooo`030000003oool0oooo
0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@0700000?oo]/400000oonf`@00003o
okK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/400000oonf`@00003ookK100000?oo]/40
0000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo
1_oo]/400`000?oookK1oonf`@0Coonf`@030000oooo]/7ookK100CookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo08D0oooo00<000000?ooo`3oool00P3oool01P000000oooo
0?ooo`00003ookK1000000;ookK100L00000oonf`@00003ookK100000?oo]/40000000[ookK100d0
0000oonf`Ooo]/400000oonf`@00003ookK100000?oo]/400000oonf`@00003ookK100;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool6oonf`@030000oooo]/7o
okK101?ookK100<0003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo00000?oo]/400000
0_oo]/401`00003ookK100000?oo]/400000oonf`@0000002_oo]/403@00003ookK1oonf`@00003o
okK100000?oo]/400000oonf`@00003ookK100000?oo]/400_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003ooooo0?ooo`2=0?ooo`KookK100<0003ooonf`Ooo]/404ooo]/400`000?oo
okK1oonf`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`250?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool00000oonf`@000002oonf`@0700000?oo]/40
0000oonf`@00003ookK10000000:oonf`@0=00000?oo]/7ookK100000?oo]/400000oonf`@00003o
okK100000?oo]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
ool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@0Coonf`@030000oooo]/7ookK100CookK10_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08D0oooo00<000000?ooo`3oool00P3o
ool01P000000oooo0?ooo`00003ookK1000000;ookK100L00000oonf`@00003ookK100000?oo]/40
000000[ookK100d00000oonf`Ooo]/400000oonf`@00003ookK100000?oo]/400000oonf`@00003o
okK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool6oonf
`@030000oooo]/7ookK101?ookK100<0003ooonf`Ooo]/401?oo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0Q03oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo
00000?oo]/4000000_oo]/401`00003ookK100000?oo]/400000oonf`@0000002_oo]/400`00003o
okK100000002oonf`@0800000?oo]/400000oonf`@00003ookK100000?oo]/42ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo1_oo]/400`000?oookK1oonf`@0C
oonf`@030000oooo]/7ookK100CookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
oooo08@0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`00003ookK1000000;ookK1
00L00000oonf`@00003ookK100000?oo]/40000000[ookK100<00000oonf`@0000000_oo]/402000
003ookK100000?oo]/400000oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`2=0?ooo`KookK100<0003ooonf`Ooo]/404ooo]/400`000?oookK1oonf
`@04oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`240?ooo`030000003o
ool0oooo00<0oooo00H000000?ooo`3oool00000oonf`@000002oonf`@0700000?oo]/400000oonf
`@00003ookK10000000:oonf`@0300000?oo]/40000000;ookK100P00000oonf`@00003ookK10000
0?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0
S@3oool6oonf`@030000oooo]/7ookK101?ookK100<0003ooonf`Ooo]/401?oo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool0@@3oool[000001L0oooo00<000000?ooo`3oool0
0`3oool01`000000oooo0?ooo`3oool00000oonf`@0000000_oo]/401`00003ookK100000?oo]/40
0000oonf`@0000002_oo]/400`00003ookK100000002oonf`@0800000?oo]/400000oonf`@00003o
okK100000?oo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0
oooo1_oo]/400`000?oookK1oonf`@0Coonf`@030000oooo]/7ookK100CookK10_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooool0oooo03X0oooo1`00000[0?ooo`X00000303oool00`000000
oooo0?ooo`040?ooo`09o`00003oool0oooo0?ooo`00003ookK100000?oo]/40000000;ookK100<0
0000oonf`@0000000_oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/40000000;ookK100P0
0000oonf`@00003ookK100000?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooo`3oool0S@3oool6oonf`@030000oooo]/7ookK101?ookK100<0003ooonf`Ooo
]/401?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0<P3oool500000003
o`0000000000000003`0oooo00?o0000000000000000200000000ol00000oooo0?ooo`050?ooo`09
0000003oool0oooo0?ooool0003ookK100000?oo]/40000000;ookK100<00000oonf`@0000000_oo
]/400`00003ookK1oonf`@07oonf`@0300000?oo]/40000000;ookK100P00000oonf`@00003ookK1
00000?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3o
ool0S@3oool6oonf`@030000oooo]/7ookK101?ookK100<0003ooonf`Ooo]/401?oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0;`3oool3000005L0oooo00T000000?ooo`3o
ool0oooo00000?oo]/400000oonf`@0000000_oo]/400`00003ookK100000002oonf`@0300000?oo
]/7ookK100OookK100<00000oonf`@0000000_oo]/402000003ookK100000?oo]/400000oonf`@00
003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooo`Ko
okK100<0003ooonf`Ooo]/404ooo]/400`000?oookK1oonf`@04oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`0[0?ooo`@000005@3ooolU000001l0oooo00D000000?ooo`3o
ool0oooo00000002oonf`@0500000?oo]/400000oonf`@0000000_oo]/401000003ookK1oonf`@00
0009oonf`@0500000?oo]/400000oonf`@0000000_oo]/401P00003ookK100000?oo]/400000oonf
`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3oool6oonf`@03
0000oooo]/7ookK101;ookK100<0003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooo`3oool09`3oool400000180oooo1`00000U0?ooo`L0000000?o000000000000
00005@3oool01@000000oooo0?ooo`3oool0000000;ookK100D00000oonf`@00003ookK100000002
oonf`@0400000?oo]/7ookK1000000WookK100D00000oonf`@00003ookK100000002oonf`@060000
0?oo]/400000oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?ooo`0R0?ooog7ookK100<0003ooonf`Ooo]/404_oo]/400`000?oookK1oonf`@05oonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0R0?ooo`;ookK10P0000000ol0003o
okK1oonf`@0Aoonf`@<000004_oo]/4C0000017ookK11000000@oonf`@0300000?oo]/7ookK100;o
okK100P00000oonf`Ooo]/400000oonf`@00003ookK1000000;ookK100@00000oonf`Ooo]/400000
2Ooo]/401@00003ookK100000?oo]/40000000;ookK100H00000oonf`@00003ookK100000?oo]/42
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280ooooLOoo]/400`00
0?oookK1oonf`@0Boonf`@030000oooo]/7ookK100GookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo0240oooo0`00000>oonf`@P000002_oo]/4;000001?ookK12P00000;oonf
`@L000001_oo]/43000000CookK100T00000oonf`Ooo]/7ookK100000?oo]/400000oonf`@000000
0_oo]/401000003ookK1oonf`@000009oonf`@0500000?oo]/400000oonf`@0000000_oo]/401P00
003ookK100000?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool08P3ooomaoonf`@030000oooo]/7ookK101;ookK100<0003ooonf`Ooo]/401Ooo]/42
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool07`3oool2000000030?oooooo]/7o
okK100cookK100?o000000000?oo]/402ooo]/46000000_ookK14`00000:oonf`@H000003?oo]/46
000000OookK100@00000oonf`Ooo]/4000000_oo]/400`00003ookK100000002oonf`@0400000?oo
]/7ookK1000000SookK100P00000oonf`Ooo]/400000oonf`@00003ookK1000000;ookK100@00000
oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`0R
0?ooog;ookK100<0003ooonf`Ooo]/404Ooo]/400`000?oookK1oonf`@05oonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`0M0?ooo`0300000?l00000oooo0080oooo2_oo]/44
000000[ookK100@00000o`000000000000001_oo]/4;000001?ookK100?o00000000000000001000
0009oonf`@D000004ooo]/401@00003ookK1oonf`Ooo]/40000000;ookK100<00000oonf`@000000
0_oo]/401000003ookK1oonf`@000008oonf`@0800000?oo]/7ookK100000?oo]/400000oonf`@00
0002oonf`@0400000?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooo`3oool08P3ooomboonf`@030000oooo]/7ookK1017ookK100<0003ooonf`Ooo]/401Ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool06P3oool3000000D0oooo2?oo
]/42000000[ookK110000007oonf`@<000002ooo]/4C000000OookK11`000007oonf`@<000003_oo
]/400`00003o0000oonf`@03oonf`@0600000?oo]/7ookK100000?oo]/4000000_oo]/401000003o
okK1oonf`@000008oonf`@0800000?oo]/7ookK100000?oo]/400000oonf`@000002oonf`@040000
0?oo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0
8P3ooomboonf`@030000oooo]/7ookK1017ookK100<0003ooonf`Ooo]/401Ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`KookK1
0P000008oonf`@@000001ooo]/44000000?ookK12`00000Coonf`@X000001?oo]/43000000OookK1
10000009oonf`@0300000?oo]/7ookK100?ookK100@00000oonf`Ooo]/4000000_oo]/400`00003o
okK100000002oonf`@0300000?oo]/7ookK100OookK100P00000oonf`Ooo]/400000oonf`@00003o
okK1000000;ookK100@00000oonf`@00003ookK10_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?oooc?ookK11_l00?lioonf`@030000oooo]/7ookK1017ookK100<0
003ooonf`Ooo]/401Ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool05`3o
ool00ol0000000000?ooo`080?ooo`?ookK10`000007oonf`@<000001ooo]/44000000?ookK100@0
0000o`000?l0000000001ooo]/400`00003o0000o`00000G000000OookK100@00000o`0000000000
00000ooo]/4300000003o`000?oo]/7ookK100GookK12@000006oonf`@0400000?oo]/7ookK1o`00
00;ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf`@07oonf`@0800000?oo]/7ookK1
00000?oo]/400000oonf`@000002oonf`@0400000?oo]/400000oonf`@;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolZoonf`@Wo003o1_oo]/49o`00oc3ookK1
00<0003ooonf`Ooo]/404Ooo]/400`000?oookK1oonf`@05oonf`@;ooooo00?o0000ooooooooool0
3oooool00ol0003ooooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo0_oo]/400`00003ookK1
oonf`@07oonf`@0300000?oo]/7ookK100GookK10P0000000ol0003ookK1oonf`@02oonf`@<00000
1?oo]/47000000OookK130000007oonf`@L000001?oo]/43000000CookK10`00000Coonf`@040000
0?oo]/7ookK1000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf`@07oonf`@08
00000?oo]/7ookK100000?oo]/400000oonf`@000002oonf`@0400000?oo]/400000oonf`@;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolUoonf`@Go003o6?oo
]/45o`00ob_ookK100<0003ooonf`Ooo]/404?oo]/400`000?oookK1oonf`@06oonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00?o
okK100000?oo]/401ooo]/42000000GookK10`000004oonf`@<000001?oo]/43000000OookK11`00
000<oonf`@/000000ooo]/44000000?ookK110000003oonf`@@000003_oo]/401@00003ookK1oonf
`Ooo]/40000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf`@07oonf`@080000
0?oo]/7ookK100000?oo]/400000oonf`@000002oonf`@0400000?oo]/400000oonf`@;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolOoonf`@Ko003o8_oo]/46
o`00obGookK100<0003ooonf`Ooo]/404?oo]/400`000?oookK1oonf`@06oonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00?o0000
oonf`Ooo]/401Ooo]/42000000KookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02
oonf`@<000001?oo]/46000000CookK14`000007oonf`@8000001Ooo]/42000000GookK10P000005
oonf`@8000002ooo]/401@00003ookK1oonf`Ooo]/40000000;ookK100@00000oonf`Ooo]/400000
0_oo]/400`00003ookK1oonf`@06oonf`@0;00000?oo]/7ookK1oonf`@00003ookK100000?oo]/40
0000oonf`@0000000_oo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?oo
ool0oooo0280oooo7Ooo]/42o`00obkookK10_l00?lSoonf`@030000oooo]/7ookK1013ookK100<0
003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04`3o
ool00ol00000oooo0?ooo`0;0?ooo`0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/401?oo
]/400ol000000000oonf`@03oonf`@0300000?l00000000000;ookK10`000003oonf`@@000000ooo
]/4500000003o`000000003ookK100;ookK13?l00004oonf`@03o`0000000000000000@000000_oo
]/45000000;ookK110000003oonf`@8000001Ooo]/45000000?ookK100<00000o`00000000001?oo
]/401000003ookK1oonf`@000002oonf`@0400000?oo]/7ookK1000000SookK100/00000oonf`Ooo
]/7ookK100000?oo]/400000oonf`@00003ookK100000002oonf`@0500000?oo]/7oooooooooool0
00002_ooool000Wooooo00?o0000ooooo`3oool08P3ooolLoonf`@03o`00oooo]/7ookK1033ookK1
0_l00?lQoonf`@030000oooo]/7ookK1013ookK100<0003ooonf`Ooo]/401_oo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000
003ooooookK100GookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@800000
1?oo]/400`00003ookK1oonf`@02oonf`@8000001?oo]/43000000CookK11_l0000<oonf`@Oo0000
1?oo]/42000000GookK10P000004oonf`@0300000?oo]/7ookK100;ookK10P000008oonf`@<00000
1ooo]/401000003ookK1oonf`@000002oonf`@0400000?oo]/7ookK1000000SookK100/00000oonf
`Ooo]/7ookK100000?oo]/400000oonf`@00003ookK100000002oonf`@0500000?oo]/7ooooooooo
ool000002_ooool000Wooooo00?o0000ooooo`3oool08P3ooolKoonf`@03o`00oooo]/7ookK103?o
okK10_l00?lPoonf`@030000oooo]/7ookK100oookK100<0003ooonf`Ooo]/401_oo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`03
o`00003oool0oooo00GookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@03
00000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@80
00001Ooo]/42o`0001WookK10_l00004oonf`@8000001Ooo]/400`00003ookK1oonf`@02oonf`@80
00001?oo]/400`00003ookK1oonf`@0>oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/401@00
003ookK1oonf`Ooo]/40000000OookK100@00000oonf`Ooo]/4000000_oo]/401@00003ookK10000
0?oo]/40000000;ookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo
0?ooo`0R0?oooaWookK10_l00?lhoonf`@03o`00oooo]/7ookK101gookK100<0003ooonf`Ooo]/40
3ooo]/400ol00?oookK1oonf`@06oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo1?oo]/400`00003o
okK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400`00003o
okK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/401?oo]/400ol0003o
okK1oonf`@06oonf`@go00002?oo]/42o`0000CookK100?o000000000?oo]/400ooo]/400ol0003o
okK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000o`000?oo]/403Ooo]/401@00003o
okK1oonf`Ooo]/40000000;ookK100D00000oonf`Ooo]/7ookK100000007oonf`@0400000?oo]/7o
okK1000000;ookK100D00000oonf`@00003ookK100000002oonf`@0500000?oo]/7oooooooooool0
00002_ooool000Wooooo00?o0000ooooo`3oool08P3ooolHoonf`@03o`00oooo]/7ookK103WookK1
00?o003ooonf`Ooo]/407?oo]/400`000?oookK1oonf`@0?oonf`@030000oooo]/7ookK100KookK1
0_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo0140oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`3oool4oonf`@03o`000?oo]/7ookK100CookK100<00000oonf`Ooo
]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo
]/400_oo]/400`00003ookK1oonf`@03oonf`@03o`000?oo]/7ookK100CookK10ol0000=oonf`@?o
00001ooo]/400ol0003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo
]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100gookK100D00000oonf`Ooo
]/7ookK100000002oonf`@0500000?oo]/7ookK1oonf`@0000001ooo]/401000003ookK1oonf`@00
0002oonf`@0500000?oo]/400000oonf`@0000000_oo]/401@00003ookK1oooooooooooo000000[o
oooo0009ooooo`03o`000?ooool0oooo0280oooo6?oo]/400ol00?oookK1oonf`@0Joonf`@?o0000
7?oo]/400ol00?oookK1oonf`@0Loonf`@030000oooo]/7ookK100oookK100<0003ooonf`Ooo]/40
1_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04@3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo0?ooo`CookK100<00000oonf`Ooo]/401?oo]/400`00003o
okK1oonf`@02oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100?o0000oonf`Ooo]/401?oo]/400ol0003o
okK1oonf`@0Aoonf`@03o`000?oo]/7ookK100CookK100?o0000oonf`Ooo]/400ooo]/400`00003o
okK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@0<oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/401@00003ookK1oonf`Ooo]/40
000000KookK100D00000oonf`Ooo]/7ookK100000002oonf`@0500000?oo]/400000oonf`@000000
0_oo]/401@00003ookK1oooooooooooo000000[ooooo0009ooooo`03o`000?ooool0oooo0280oooo
6?oo]/400ol00?oookK1oonf`@0Ioonf`@Go00006ooo]/400ol00?oookK1oonf`@0Loonf`@030000
oooo]/7ookK100oookK100<0003ooonf`Ooo]/401_oo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
0ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/40
0ooo]/401@00003ookK1oonf`Ooo]/40000000GookK100<00000oonf`Ooo]/400_oo]/400ol0003o
okK1oonf`@04oonf`@03o`000?oo]/7ookK101?ookK100?o0000oonf`Ooo]/401?oo]/400ol0003o
okK1oonf`@03oonf`@03o`000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003o
okK1oonf`@03oonf`@0300000?oo]/7ookK100[ookK100<00000oonf`Ooo]/400_oo]/401000003o
okK1oonf`@000004oonf`@0300000?oo]/7ookK100?ookK100L00000oonf`Ooo]/7ookK100000?oo
]/40000000;ookK100<00000oonf`@0000000_oo]/401@00003ookK1oooooooooooo000000[ooooo
0009ooooo`03o`000?ooool0oooo0280oooo6?oo]/400ol00?oookK1oonf`@0Ioonf`@Go00007?oo
]/400ol00?oookK1oonf`@0Koonf`@030000oooo]/7ookK100kookK100<0003ooonf`Ooo]/401ooo
]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo0ooo]/400`00003ookK1oonf`@04oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@02oonf`@03o`000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400ol0003ookK1oonf`@03oonf`@03o`000?oo
]/7ookK101GookK100?o0000oonf`Ooo]/401?oo]/400ol0003ookK1oonf`@03oonf`@03o`000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100WookK100<00000oonf`Ooo]/400_oo]/401000003ookK1oonf`@000004oonf`@030000
0?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK100000002oonf`@030000
0?oo]/40000000;ookK100D00000oonf`Oooooooooooo`00000:ooooo`002Oooool00ol0003ooooo
0?ooo`0R0?oooaSookK100?o003ooonf`Ooo]/406Ooo]/45o`0001cookK100?o003ooonf`Ooo]/40
6ooo]/400`000?oookK1oonf`@0>oonf`@030000oooo]/7ookK100OookK10_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0oooo0140oooo00?o00000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`?ookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@030000
0?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400ol0003ookK1oonf`@02oonf`@030000
0?oo]/7ookK100?ookK100?o0000oonf`Ooo]/401?oo]/42o`0001CookK100?o0000oonf`Ooo]/40
1Ooo]/400ol0003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/40
0_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100WookK100<00000oonf`Ooo]/40
0_oo]/401000003ookK1oonf`@000005oonf`@05o`00000000000000oonf`@0000001?oo]/400`00
003ookK100000002oonf`@0300000?oo]/40000000;ookK100D00000oonf`Oooooooooooo`00000:
ooooo`002Oooool00ol0003ooooo0?ooo`0R0?oooaSookK100?o003ooonf`Ooo]/406_oo]/43o`00
01cookK10_l00?lMoonf`@030000oooo]/7ookK100kookK100<0003ooonf`Ooo]/401ooo]/42oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04@3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo0?ooo`CookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK100000005oonf`@0300000?oo
]/7ookK100?ookK100?o0000oonf`Ooo]/401Ooo]/400ol0003ookK1oonf`@0?oonf`@;o00001ooo
]/400ol0003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo
]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100_ookK100D00000oonf`Ooo]/7ookK1
00000002oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1
00000002oonf`@0300000?oo]/40000000;ookK100D00000oonf`Oooooooooooo`00000:ooooo`00
2Oooool00ol0003ooooo0?ooo`0R0?oooaWookK100?o003ooonf`Ooo]/40=ooo]/400ol00?oookK1
oonf`@0Moonf`@030000oooo]/7ookK100kookK100<0003ooonf`Ooo]/401ooo]/42ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`040000
003oool0oooo0?ooo`CookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@02oonf`@03
00000?oo]/7ookK100?ookK100D00000oonf`Ooo]/7ookK100000005oonf`@0300000?oo]/7ookK1
00?ookK100?o0000oonf`Ooo]/401Ooo]/43o`0000cookK10_l00008oonf`@03o`000?oo]/7ookK1
00?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK1
00?ookK100<00000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@02oonf`@0400000?oo]/7ookK1
000000cookK100<00000oonf`@0000000_oo]/400`00003ookK100000002oonf`@0300000?oo]/7o
okK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolJoonf
`@;o003o=_oo]/400ol00?oookK1oonf`@0Noonf`@030000oooo]/7ookK100kookK100<0003ooonf
`Ooo]/401ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool04P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00GookK100<00000oonf`Ooo]/400ooo]/400ol0
003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100?o000000000?oo]/400_oo]/420000
00CookK100?o00000000000000000ooo]/43o`0000OookK13?l00008oonf`@;o00001Ooo]/400ol0
003ookK1oonf`@02oonf`@8000001?oo]/400`00003ookK1oonf`@03oonf`@03o`000?oo]/7ookK1
00gookK100D00000oonf`Ooo]/7ookK100000002oonf`@0300000?oo]/7ookK100[ookK100?o0000
oonf`@0000000_oo]/400`00003ookK100000002oonf`@0300000?oo]/7ookK100;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooolLoonf`@;o003o<_oo]/42o`00
ob;ookK100<0003ooonf`Ooo]/403?oo]/400`000?oookK1oonf`@08oonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?oo
oooo]/401Ooo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100?ookK100?o00000000
0?oo]/400ooo]/400`00003ookK1oonf`@02oonf`@<000001?oo]/43000000?ookK11?l0000Doonf
`@?o00001?oo]/43000000?ookK10P000005oonf`@0300000?oo]/7ookK100;ookK10P00000@oonf
`@0500000?oo]/7ookK1oonf`@0000000ooo]/400ol0003ookK1oonf`@08oonf`@0400000?oo]/7o
okK1000000;ookK100<00000oonf`@0000000_oo]/400`00003ookK1oonf`@02ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280oooo7_oo]/43o`00obgookK10_l00?lT
oonf`@030000oooo]/7ookK100cookK100<0003ooonf`Ooo]/402?oo]/42ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`0300000?oo]/7o
okK100GookK10P000004oonf`@0300000?oo]/7ookK100CookK10P000003oonf`@<000001?oo]/43
000000CookK10`000004oonf`@Oo00001_oo]/47o`0000CookK10`000004oonf`@8000001Ooo]/42
000000CookK100<00000oonf`Ooo]/401Ooo]/47000000GookK100D00000oonf`Ooo]/7ookK10000
0003oonf`@0300000?oo]/7ookK100OookK100H00000oonf`Ooo]/400000oonf`@000002oonf`@04
00000?oo]/7ookK1000000;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
oooo0?ooo`0R0?ooob7ookK10_l00?lYoonf`@;o003o9_oo]/400`000?oookK1oonf`@0<oonf`@03
0000oooo]/7ookK100SookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01@0
oooo0P00000<0?ooo`8000001ooo]/42000000?ookK110000004oonf`@<000000ooo]/401000003o
0000000000000003oonf`@0400000?l000000000000000?ookK10P0000000ol00000000000000002
000000CookK11_l00004oonf`@L000000ooo]/44000000?ookK110000003oonf`@80000000?o0000
oonf`Ooo]/400_oo]/44000000OookK10P000003oonf`@0500000?l0003ookK1oonf`Ol000001?oo
]/400`00003ookK1oonf`@04oonf`@8000000ooo]/400`00003ookK100000002oonf`@0400000?oo
]/7ookK1o`0000;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?oo
o`0R0?ooob?ookK10ol00?lSoonf`@?o003o:Ooo]/400`000?oookK1oonf`@0:oonf`@030000oooo
]/7ookK100WookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01H0oooo00<0
00000?ooo`3oool02@3oool2oonf`@0300000?oo]/7ookK100KookK10P000005oonf`@8000001Ooo
]/42000000GookK10`000004oonf`@<000001ooo]/4>000000OookK10`000004oonf`@<000001?oo
]/43000000CookK10`00000=oonf`@0500000?oo]/7ookK1oonf`@0000000_oo]/400`00003ookK1
oonf`@03oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1
00000002oonf`@0300000?oo]/40000000?ookK100<00000ooooool000002_ooool000Wooooo00?o
0000ooooo`3oool08P3ooolVoonf`@Go003o6ooo]/43o`00obgookK100<0003ooonf`Ooo]/402Ooo
]/400`000?oookK1oonf`@09oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?oo
o`0G0?ooo`030000003oool0oooo00P0oooo0ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo
]/7ookK100CookK10P000005oonf`@8000001_oo]/44000000?ookK12`000006oonf`@/000000ooo
]/44000000KookK100<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@0>oonf`@0300000?oo
]/7ookK100;ookK100@00000oonf`Ooo]/4000001Ooo]/44000000GookK100@00000oonf`Ooo]/40
00000_oo]/400`00003ookK100000003oonf`@0300000?oooooo000000[ooooo0009ooooo`03o`00
0?ooool0oooo0280oooo:ooo]/4Ko`00oc3ookK100<0003ooonf`Ooo]/402Ooo]/400`000?oookK1
oonf`@09oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0H0?ooo`030000
003oool0oooo00L0oooo1?oo]/42000000SookK10P000006oonf`@8000001Ooo]/44000000KookK1
1@000009oonf`@H000002Ooo]/400ol00000000000000002000000GookK100?o0000000000000000
0P000005oonf`@8000004_oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo
]/402ooo]/400`00003ookK100000002oonf`@0400000?oo]/7ookK1000000?ookK100<00000oooo
ool000002_ooool000Wooooo00?o0000ooooo`3oool08P3ooomgoonf`@030000oooo]/7ookK100Oo
okK100<0003ooonf`Ooo]/402_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3o
ool06@3oool00ol0000000000?ooo`060?ooo`KookK100?o00000000000000001ooo]/44000000Co
okK100@00000o`000000000000001Ooo]/400ol00000000000000003000000GookK100?o00000000
000000005@000005oonf`@H000001Ooo]/4200000003o`000000003ookK100GookK12`000004oonf
`@0500000?oo]/7ookK1oonf`@0000000ooo]/400`00003ookK1oonf`@09oonf`@0400000?oo]/7o
okK1000000;ookK100@00000oonf`Ooo]/4000000ooo]/400`00003oooooo`00000:ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?ooogOookK100<0003ooonf`Ooo]/401ooo]/400`000?oookK1oonf
`@0:oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`0K0?ooo`8000001@3o
ool9oonf`@8000002Ooo]/42000000KookK110000007oonf`@L000005?oo]/47000000OookK11000
0007oonf`@<000002ooo]/400`00003ookK1oonf`@02oonf`@05o`000?oo]/7ookK1oonf`Ol00000
0ooo]/400`00003ookK1oonf`@08oonf`@0400000?oo]/7ookK1000000;ookK100@00000oonf`Ooo
]/4000000ooo]/400`00003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`0R0?ooogSo
okK100<0003ooonf`Ooo]/401Ooo]/400`000?oookK1oonf`@0;oonf`@;ooooo00?o0000oooooooo
ool03oooool00ol0003ooooo0?ooo`0M0?ooo`8000000`3oool;oonf`@<000002?oo]/46000000Co
okK11`000007oonf`A@000001ooo]/47000000OookK11000000?oonf`@0500000?oo]/7ookK1oonf
`@0000000ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100KookK100Co0000oonf
`Ooo]/7o00000_oo]/401000003ookK1oonf`@000003oonf`@0400000?ooooooooooo`0000[ooooo
0009ooooo`03o`000?ooool0oooo0280ooooN?oo]/400`000?oookK1oonf`@05oonf`@030000oooo
]/7ookK100_ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo01l0oooo00<0
0000o`00000000003_oo]/401?l00000000000000000000:oonf`@0400000?l000000000000000Oo
okK12P00000>oonf`@X000001ooo]/4300000004o`00000000000000000001CookK100D00000oonf
`Ooo]/7ookK100000003oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400ooo]/42
000000?ookK100@00000oonf`Ooo]/4000000_oo]/401@00003ookK1oonf`Ooo]/40000000;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool08P3ooomhoonf`@030000oooo
]/7ookK100CookK100<0003ooonf`Ooo]/403?oo]/42ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`3oool08P3oool3000000oookK10`00000;oonf`@L000002_oo]/4>000000kookK10`00
000>oonf`@P000001Ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/40
0ooo]/401Ol00000000000000?oo]/40000000GookK100@00000oonf`Ooo]/4000000_oo]/401@00
003ookK1oonf`Ooo]/40000000;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
o`3oool08P3ooomioonf`@80003o0_oo]/420000o`oookK10_ooool00ol0003oooooooooo`0?oooo
o`03o`000?ooool0oooo0280oooo0ooo]/44000000kookK11000000>oonf`@X000004Ooo]/4;0000
00[ookK11`000008oonf`@0300000?oo]/7ookK100?ookK100D00000oonf`Ooo]/7ookK100000003
oonf`@0300000?oo]/7ookK100GookK100<00000oonf`Ooo]/401?oo]/401000003ookK1oonf`@00
0002oonf`@0500000?oo]/7ookK1oonf`@0000000_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003ooooo0?ooo`0R0?ooog_ookK10P000?lAoonf`@;ooooo00?o0000ooooooooool03ooo
ool00ol0003ooooo0?ooo`0R0?ooo`OookK100<00000oonf`Ooo]/403ooo]/46000001;ookK14@00
000?oonf`@H000004?oo]/400ol0003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf`@000000
0ooo]/400`00003ookK1oonf`@0;oonf`@0400000?oo]/7ookK1000000?ookK100D00000oonf`Ooo
]/400000oonf`@02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo0280
ooooS_oo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool08P3oool8oonf`@03
o`0000000000000000<000004Ooo]/400ol00000000000000005000002;ookK12000000Goonf`@03
00000?oo]/7ookK100;ookK100H00000oonf`Ooo]/7ookK100000?l00002oonf`@0300000?oo]/7o
okK100[ookK100@00000oonf`Ooo]/4000000ooo]/401@00003ookK1oonf`@00003ookK100;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o
0000ooooooooool03oooool00ol0003ooooo0?ooo`0`0?ooo`<000005P3ooolR00000200oooo00<0
00000?oooooo]/400_oo]/401Ol0003ookK1oonf`Ooo]/40000000?ookK100<00000oonf`Ooo]/40
2?oo]/401@00003ookK1oonf`Ooo]/40000000?ookK100D00000oonf`Ooo]/400000oonf`@02oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0<`3oool4000005D0oooo00D00000oonf`Ooo
]/7ookK100000004oonf`@0500000?oo]/7ookK1oonf`@0000002?oo]/401Ol0003ookK1oonf`Ooo
]/40000000?ookK100H00000oonf`Ooo]/7ookK100000?oo]/42ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`3oool0=`3oool7000003/0oooo2`0000090?ooo`0500000?oo]/7ookK1oonf`@00
00000ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK10P000004oonf`@05
00000?oo]/7ookK1oonf`@0000000ooo]/401@00003ookK1oooooooooooo000000[ooooo0009oooo
o`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0?P3oool;000002H0oooo2P00000;0?ooo`8000001`3oool01@00003ookK1oonf`Ooo]/40
000000?ookK100<00000oonf`Ooo]/400ooo]/401Ol00000000000000?oo]/40000000KookK100D0
0000oonf`Ooo]/7ookK100000003oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo
00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`190?ooobH000005`3oool00`000000oooo0?ooo`040?ooo`0500000?oo]/7ookK1oonf`@00
00001?oo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo
]/400_oo]/401P00003ookK1oonf`Ooo]/400000oonf`@;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`260?ooo`030000003oool0oooo00@0oooo00?ookK100000?oo]/400_oo]/401@00
003ookK1oonf`Ooo]/40000000kookK100D00000oonf`Ooo]/7ookK100000003oonf`@0300000?oo
]/7ookK100;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolS
oonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`270?ooo`030000003oool0
oooo00<0oooo00?ookK100000?oo]/400_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7o
okK100_ookK100D00000oonf`Ooo]/7ookK100000003oonf`@0300000?oo]/7ookK100;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000
ooooooooool03oooool00ol0003ooooo0?ooo`270?ooo`030000003oool0oooo00<0oooo00?ookK1
00000?oo]/400_oo]/400`00003ookK1oonf`@02oonf`@03o`000?oo]/7ookK100_ookK100D00000
oonf`Ooo]/7ookK100000003oonf`@0300000?oo]/7ookK100;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool0
0ol0003ooooo0?ooo`280?ooo`030000003oool0oooo0080oooo0_oo]/401@00003ookK1oonf`Ooo
]/40000000CookK100<00000oonf`Ooo]/402Ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK1
00@00000oonf`Ooo]/7ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08T0oooo
00@000000?ooo`3oool0oooo0_oo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100;o
okK100<00000oonf`Ooo]/401ooo]/400`00003ookK1oonf`@02oonf`@0500000?oo]/7ookK1oonf
`@0000000ooo]/42ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0
oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000ooooo`3oool0R@3oool01?l00000
oooo0?ooo`3oool2oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/400`00
003ookK1oonf`@07oonf`@0300000?oo]/7ookK100;ookK100D00000oonf`Ooo]/7ookK100000003
oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`290?ooo`040000003oool0oooo
0?ooo`;ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7o
okK100GookK100<00000oonf`Ooo]/400ooo]/401@00003ookK1oonf`Ooo]/40000000?ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08X0oooo00<000000?ooo`3oool00ooo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400ooo]/40
0`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/7ookK10_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08X0oooo00<000000?ooo`3oool00ooo]/40
0`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100CookK100?o000000000?oo]/400P000006
oonf`@0300000?oo]/7ookK100;ookK100@00000oonf`Ooo]/7ookK10_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?
ooooo`03o`000?ooool0oooo08X0oooo00<000000?ooo`3oool00ooo]/400`00003ookK1oonf`@02
oonf`@0300000?oo]/7ookK100KookK100<00000oonf`Ooo]/401_oo]/400`00003ookK1oonf`@02
oonf`@0400000?oo]/7ookK1oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2;
0?ooo`030000003ooooookK100?ookK100<00000oonf`Ooo]/400_oo]/400`00003ookK1oonf`@0=
oonf`@0300000?oo]/7ookK100;ookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`3oool0R`3oool00`000000oooooonf`@03oonf`@0300000?oo]/7ookK1
00;ookK100<00000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK1
00;ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=0?ooob?o
okK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08/0oooo00<000000?oooooo
]/400ooo]/400`00003ookK1oonf`@02oonf`@0300000?oo]/7ookK100cookK100<00000oonf`Ooo
]/400ooo]/400`00003ookK1oonf`@02oonf`@;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
0?ooo`2;0?ooo`030000003ooooookK100?ookK100<00000oonf`Ooo]/400ooo]/400`00003ookK1
oonf`@0;oonf`@0300000?oo]/7ookK100?ookK100<00000oonf`Ooo]/400_oo]/42ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooo`3oool0R`3oool00`000000oooooonf`@04oonf`@0300000?oo
]/7ookK100;ookK100<00000oonf`Ooo]/402_oo]/400`00003ookK1oonf`@03oonf`@0300000?oo
]/7ookK100?ookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo0?ooo`2=
0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08/0oooo00<00000
0?oooooo]/401?oo]/400`00003ookK1oonf`@03oonf`@0300000?oo]/7ookK100WookK100<00000
oonf`Ooo]/400ooo]/400`00003ookK1oonf`@03oonf`@;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`2;0?ooo`030000003ooooookK100CookK100<00000oonf`Ooo]/401?oo]/400`00
003ookK1oonf`@07oonf`@0300000?oo]/7ookK100CookK100<00000oonf`Ooo]/400ooo]/42oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooo`3oool0S03oool00`00003ookK1oonf`@04oonf`@03
00000?oo]/7ookK100CookK100<00000oonf`Ooo]/401Ooo]/400ol0003ookK1oonf`@04oonf`@03
00000?oo]/7ookK100CookK10_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
0?ooo`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08`0oooo
00<00000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@05oonf`@8000000ooo]/42000000OookK1
00<00000oonf`Ooo]/401?oo]/400`00003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?oo
o`2=0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08`0oooo00<0
0000oonf`Ooo]/401?oo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/40000000WookK100<0
0000oonf`Ooo]/401?oo]/400`00003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`2=
0?ooob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08`0oooo00<00000
oonf`Ooo]/401Ooo]/400`00003ookK1oonf`@07oonf`@0300000?oo]/7ookK100OookK100<00000
oonf`Ooo]/401Ooo]/400`00003oooooo`00000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?oo
ob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08d0oooo00<00000oonf
`Ooo]/401?oo]/400`00003ookK1oonf`@0Aoonf`@0300000?oo]/7ookK100CookK100@00000oooo
oooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`0300000?oo]/7ookK100CookK100<00000oonf
`Ooo]/404?oo]/400`00003ookK1oonf`@05oonf`@0400000?ooooooooooo`0000[ooooo0009oooo
o`03o`000?ooool0oooo08d0oooo8ooo]/42ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`3oool0S@3oool00`00003ookK1oonf`@04oonf`@0300000?oo]/7ookK1013ookK100<00000oonf
`Ooo]/401Ooo]/401000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo0?ooo`2=0?oo
ob?ookK10_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0oooo08d0oooo00<00000oonf
`Ooo]/401Ooo]/400`00003ookK1oonf`@0?oonf`@0300000?oo]/7ookK100GookK100@00000oooo
oooooooo00002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000oooo
ooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf`@00003ookK100GookK100<00000oonf
`Ooo]/403_oo]/400`00003ookK1oonf`@05oonf`@0500000?oo]/7oooooooooool000002_ooool0
00Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0
003ooooo0?ooo`2=0?ooo`03oonf`@00003ookK100KookK100<00000oonf`Ooo]/403Ooo]/400ol0
003ookK1oonf`@05oonf`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000oooo
o`3oool0S@3ooolSoonf`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?oo
o`03oonf`@00003ookK100KookK100<00000oonf`Ooo]/403?oo]/400`00003ookK1oonf`@06oonf
`@0500000?oo]/7oooooooooool000002_ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf
`@;ooooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf`@00003ookK1
00OookK100?o0000oonf`Ooo]/402ooo]/400`00003ookK1oonf`@05oonf`@0300000?oo]/7ookK1
00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooo`3oool0S@3ooolSoonf`@;o
oooo00?o0000ooooooooool03oooool00ol0003ooooo0?ooo`2=0?ooo`03oonf`@00003ookK100So
okK100?o0000oonf`Ooo]/402Ooo]/400`00003ookK1oonf`@06oonf`@0300000?oo]/7ookK100;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo]_l0
000AoooookKo00002_ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0.32198 0.000521284 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.25057 -0.0125 -3 -9 ]
[.25057 -0.0125 3 0 ]
[.47732 -0.0125 -6 -9 ]
[.47732 -0.0125 6 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.93084 -0.0125 -6 -9 ]
[.93084 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00921 -24 -4.5 ]
[-0.0125 .00921 0 4.5 ]
[-0.0125 .11347 -24 -4.5 ]
[-0.0125 .11347 0 4.5 ]
[-0.0125 .21772 -24 -4.5 ]
[-0.0125 .21772 0 4.5 ]
[-0.0125 .32198 -6 -4.5 ]
[-0.0125 .32198 0 4.5 ]
[-0.0125 .42624 -18 -4.5 ]
[-0.0125 .42624 0 4.5 ]
[-0.0125 .53049 -18 -4.5 ]
[-0.0125 .53049 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.25057 0 m
.25057 .61803 L
s
.47732 0 m
.47732 .61803 L
s
.70408 0 m
.70408 .61803 L
s
.93084 0 m
.93084 .61803 L
s
0 .11347 m
1 .11347 L
s
0 .21772 m
1 .21772 L
s
0 .32198 m
1 .32198 L
s
0 .42624 m
1 .42624 L
s
0 .53049 m
1 .53049 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.25057 0 m
.25057 .00625 L
s
[(5)] .25057 -0.0125 0 1 Mshowa
.47732 0 m
.47732 .00625 L
s
[(10)] .47732 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(15)] .70408 -0.0125 0 1 Mshowa
.93084 0 m
.93084 .00625 L
s
[(20)] .93084 -0.0125 0 1 Mshowa
.125 Mabswid
.06916 0 m
.06916 .00375 L
s
.11451 0 m
.11451 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.20522 0 m
.20522 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38662 0 m
.38662 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.52268 0 m
.52268 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.74943 0 m
.74943 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00921 m
.00625 .00921 L
s
[(-600)] -0.0125 .00921 1 0 Mshowa
0 .11347 m
.00625 .11347 L
s
[(-400)] -0.0125 .11347 1 0 Mshowa
0 .21772 m
.00625 .21772 L
s
[(-200)] -0.0125 .21772 1 0 Mshowa
0 .32198 m
.00625 .32198 L
s
[(0)] -0.0125 .32198 1 0 Mshowa
0 .42624 m
.00625 .42624 L
s
[(200)] -0.0125 .42624 1 0 Mshowa
0 .53049 m
.00625 .53049 L
s
[(400)] -0.0125 .53049 1 0 Mshowa
.125 Mabswid
0 .03527 m
.00375 .03527 L
s
0 .06134 m
.00375 .06134 L
s
0 .0874 m
.00375 .0874 L
s
0 .13953 m
.00375 .13953 L
s
0 .16559 m
.00375 .16559 L
s
0 .19166 m
.00375 .19166 L
s
0 .24379 m
.00375 .24379 L
s
0 .26985 m
.00375 .26985 L
s
0 .29592 m
.00375 .29592 L
s
0 .34804 m
.00375 .34804 L
s
0 .37411 m
.00375 .37411 L
s
0 .40017 m
.00375 .40017 L
s
0 .4523 m
.00375 .4523 L
s
0 .47836 m
.00375 .47836 L
s
0 .50443 m
.00375 .50443 L
s
0 .55656 m
.00375 .55656 L
s
0 .58262 m
.00375 .58262 L
s
0 .60869 m
.00375 .60869 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.25057 .61178 m
.25057 .61803 L
s
.47732 .61178 m
.47732 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.93084 .61178 m
.93084 .61803 L
s
.125 Mabswid
.06916 .61428 m
.06916 .61803 L
s
.11451 .61428 m
.11451 .61803 L
s
.15986 .61428 m
.15986 .61803 L
s
.20522 .61428 m
.20522 .61803 L
s
.29592 .61428 m
.29592 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.38662 .61428 m
.38662 .61803 L
s
.43197 .61428 m
.43197 .61803 L
s
.52268 .61428 m
.52268 .61803 L
s
.56803 .61428 m
.56803 .61803 L
s
.61338 .61428 m
.61338 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.74943 .61428 m
.74943 .61803 L
s
.79478 .61428 m
.79478 .61803 L
s
.84014 .61428 m
.84014 .61803 L
s
.88549 .61428 m
.88549 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00921 m
1 .00921 L
s
.99375 .11347 m
1 .11347 L
s
.99375 .21772 m
1 .21772 L
s
.99375 .32198 m
1 .32198 L
s
.99375 .42624 m
1 .42624 L
s
.99375 .53049 m
1 .53049 L
s
.125 Mabswid
.99625 .03527 m
1 .03527 L
s
.99625 .06134 m
1 .06134 L
s
.99625 .0874 m
1 .0874 L
s
.99625 .13953 m
1 .13953 L
s
.99625 .16559 m
1 .16559 L
s
.99625 .19166 m
1 .19166 L
s
.99625 .24379 m
1 .24379 L
s
.99625 .26985 m
1 .26985 L
s
.99625 .29592 m
1 .29592 L
s
.99625 .34804 m
1 .34804 L
s
.99625 .37411 m
1 .37411 L
s
.99625 .40017 m
1 .40017 L
s
.99625 .4523 m
1 .4523 L
s
.99625 .47836 m
1 .47836 L
s
.99625 .50443 m
1 .50443 L
s
.99625 .55656 m
1 .55656 L
s
.99625 .58262 m
1 .58262 L
s
.99625 .60869 m
1 .60869 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06916 .33126 L
.11451 .3373 L
.15986 .34216 L
.20522 .3472 L
.25057 .35315 L
.29592 .36176 L
.34127 .37659 L
.38662 .40147 L
.43197 .4314 L
.47732 .45387 L
.52268 .4677 L
.56803 .48333 L
.61338 .514 L
.65873 .5579 L
.70408 .57235 L
.74943 .58404 L
.79478 .59498 L
.84014 .60106 L
.88549 .60282 L
.93084 .60322 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.06916 .33126 Mdot
.11451 .3373 Mdot
.15986 .34216 Mdot
.20522 .3472 Mdot
.25057 .35315 Mdot
.29592 .36176 Mdot
.34127 .37659 Mdot
.38662 .40147 Mdot
.43197 .4314 Mdot
.47732 .45387 Mdot
.52268 .4677 Mdot
.56803 .48333 Mdot
.61338 .514 Mdot
.65873 .5579 Mdot
.70408 .57235 Mdot
.74943 .58404 Mdot
.79478 .59498 Mdot
.84014 .60106 Mdot
.88549 .60282 Mdot
.93084 .60322 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0003Sooooo0ol0000eooooo`?o0000
1?ooool2o`0003;ooooo0ol00003ooooo`?o0000<?ooool5o`0000?ooooo0_l0000@ooooo`007ooo
ool01?l0003oooooooooool0000fooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0003;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000?ooooo`007oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00oooooo000Oooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0=ooooo`007oooool01?l0003oooooooooool0000fooooo`Co0000=_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0003;ooooo00Co0000oooooooooooooooo1?l0000`ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000?ooooo`007oooool01?l0
003oooooooooool0000fooooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`04o`000?oooooo
ooooo`00037ooooo0_l00003ooooo`03o`000?oooooooooo037ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000oooooo000Pooooo`;o0000=oooool5o`0003Gooooo
00?o0000ooooooooool00oooool2o`0003?ooooo00Co0000oooooooooooooooo1Ol0000`ooooo`?o
00001?ooool2o`00013ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?l0003o00000?oo
00000Ol000010000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`4000000Oooool000Go000000?oooooo`000?ooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00`00003o0000ooooo`02ooooo`?oo`00>Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`7o00000@00
0001ooooo`001_ooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0400000?ooooooooooooooo`Goo`00>?ooool00`0007ooooooooooo`0hooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`40
00000Oooool000Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00@00000oooooooooooooooo1Ooo000hooooo`030000Oooooooo
oooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooo
oooo00oooooo0@000001ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool01000003oooooooooooooool5ool003Sooooo
00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo
00<0001oooooooooool03oooool10000007ooooo0008ooooo`;o00001?ooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo00;ooooo0ooo000iooooo`030000Oooooooooooo03Sooooo00<0
001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo03Sooooo00<0001o
ooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001o
ooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0=oooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001ooooo
ooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool01?ooool00`00003oooooooooo`0gooooo`030000Oooooooooooo03Sooooo00<0001ooooooooo
ool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00kooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0=oooool00`0007oooooo
ooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0gooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007oooooooooo
o`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0h
ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Koooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool0=oooool00`0007ooooooooooo`0hoooo
o`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool001_ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0gooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`05ooooo`030000
0?oooooooooo03Kooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000
Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?l0
003ooooo00Gooooo00<00000ooooooooool0=_ooool00`0007ooooooooooo`0hooooo`030000Oooo
oooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0>ooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Kooooo00<0001o
ooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001o
ooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool0=_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001ooooo
ooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0fooooo`030000Oooooooooooo03Sooooo00<0001ooooooooo
ool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`00
6oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Kooooo00<0001oooooooooool0
>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool0
3oooool10000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0=_oo
ool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=ooo
ool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0eooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00
003o0000ooooo`06ooooo`0300000?oooooooooo03Gooooo00<0001oooooooooool0>?ooool00`00
07ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03_ooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0eooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo03Gooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000
Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oo
oooooooo00Kooooo00<00000ooooooooool0=Oooool00`0007ooooooooooo`0hooooo`030000Oooo
oooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Ooo
ool000Sooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0eooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`002Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0=Oooool00`0007oooooooooo
o`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooooooo
o`0?ooooo`4000000Oooool000Go000000?oooooo`000?l000000ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`070000O`030000
000007l0001o0?D0001o0Ol000010000007ooooo0006ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
00Oooooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo
03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000Oo
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`0dooooo`030000Oooooooo
oooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooo
oooo00oooooo0@000001ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0=?oo
ool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=ooo
ool00`0007ooooooooooo`0?ooooo`4000000Oooool000Wooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0=?ooool0
0`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool0
0`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool01oooool00`00
003oooooooooo`0dooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`00
07ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo03Cooooo00<0001oooooooooool0>?ooool00`0007oo
ooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007o
oooo000Kooooo`0300000?l0003ooooo00Sooooo00<00000ooooooooool0<oooool00`0007oooooo
ooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooo
ooooo`0>ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo03?ooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooo
oooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooo
oooo00Sooooo00<00000ooooooooool0<oooool00`0007ooooooooooo`0hooooo`030000Oooooooo
oooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0cooooo`030000Oooooooooooo
03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo
00oooooo0@000001ooooo`006oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo03?o
oooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oo
oooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool0<oooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo
00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`0cooooo`030000Oooooooooooo03Sooooo00<0
001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`006oooool00`00003o0000ooooo`09ooooo`0300000?oooooooooo03;ooooo00<0001o
ooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001o
ooooooooool03_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`0booooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`00
07ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo03;ooooo00<0001oooooooooool0>?ooool00`0007oo
ooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007o
oooo000Kooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0<_ooool00`0007oooooo
ooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool02Oooool00`00003ooooooooo
o`0booooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007oooooooooo
o`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo03;ooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0h
ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Koooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool0<Oooool00`0007ooooooooooo`0hoooo
o`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool001_ooooo00<00000o`000?ooool02_ooool00`00003oooooooooo`0aooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool0<Oooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo
00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`0aooooo`030000Oooooooooooo03Sooooo00<0
001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo037ooooo00<0001o
ooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001o
ooooooooool03oooool10000007ooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool0<Oooool00`0007ooooooooooo`0hoooo
o`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02_ooool00`00003ooooooooo
o`0aooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007oooooooooo
o`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`001Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?l00000001o00/0001o00<000000000O`0007l0l@0007l1o`00004000000Oooool000Wooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo033ooooo00<0001ooooooooo
ool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001ooooooooo
ool03oooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0`ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`001_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0<?ooool00`0007oooooo
ooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo03Sooooo00<0
001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo033ooooo00<0001o
ooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001o
ooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool0<?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001ooooo
ooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool03?ooool00`00003oooooooooo`0_ooooo`030000Oooooooooooo03Sooooo00<0001ooooooooo
ool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00kooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0;oooool00`0007oooooo
ooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0_ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007oooooooooo
o`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo02oooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0h
ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Koooo
o`0300000?oooooooooo00cooooo00<00000ooooooooool0;oooool00`0007ooooooooooo`0hoooo
o`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool001_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0_ooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo02oooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000
Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?l0
003ooooo00gooooo00<00000ooooooooool0;_ooool00`0007ooooooooooo`0hooooo`030000Oooo
oooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0>ooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo02kooooo00<0001o
ooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001o
ooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00gooooo00<00000oooo
ooooool0;_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001ooooo
ooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool03Oooool00`00003oooooooooo`0^ooooo`030000Oooooooooooo03Sooooo00<0001ooooooooo
ool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo02kooooo00<0001oooooooooool0
>?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool0
3oooool10000007ooooo000Kooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0;_oo
ool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=ooo
ool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool03Oooool0
0`00003oooooooooo`0^ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00
003o0000ooooo`0>ooooo`0300000?oooooooooo02gooooo00<0001oooooooooool0>?ooool00`00
07ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03_ooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0]ooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0>ooooo`030000
0?oooooooooo02gooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000
Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oo
oooooooo00kooooo00<00000ooooooooool0;Oooool00`0007ooooooooooo`0hooooo`030000Oooo
oooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Ooo
ool001Cooooo0_l00005ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool0;Oooool0
0`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool0
0`0007ooooooooooo`0?ooooo`4000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool0
0`00003oooooooooo`0>ooooo`0300000?oooooooooo02gooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool1
0000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool03_ooool0
0`00003oooooooooo`0]ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`004oooool01?l0
003oooooooooool00004ooooo`0300000?l00000001o00h0001o0ooo003^0000O`7o00000@000001
ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00gooooo1Ooo000/
ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0g
ooooo`030000Oooooooooooo00oooooo0@000001ooooo`004oooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo00gooooo1Ooo0004000000?ooooo0ooo000Rooooo`030000Oooooooo
oooo03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooo
oooo00oooooo0@000001ooooo`005?ooool2o`0000Gooooo00<00000ooooooooool03Oooool5ool0
00Cooooo0P000005ool0000300000?oooooooooo00Gooooo0ooo000Fooooo`030000Oooooooooooo
03Sooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo
00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0>ooooo`?oo`001oooool5ool00003
ooooo`000000000000@000001Ooo0008ooooo`?oo`002_ooool00`0007ooooooooooo`0hooooo`03
0000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`40
00000Oooool001_ooooo00<00000ooooooooool06?ooool5ool000Oooooo1Ooo0004000000?ooooo
1Ooo0009ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool00`0007oooooo
ooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o0000oooo
o`0Iooooo`?oo`002?ooool5ool000Cooooo0`000005ool0000300000?oooooooooo00Gooooo0ooo
000iooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007oooooooooo
o`0>ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Uooooo`?oo`002?ooool5
ool00003ooooo`000000000000@000001Ooo000hooooo`030000Oooooooooooo03Sooooo00<0001o
ooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0<Oooool3ool000Sooooo1Ooo00000`00003oooooooooo`05ooooo`?oo`00;Oooool00`00
07ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000
007ooooo000Kooooo`0300000?oooooooooo03cooooo1Ooo00000oooool0000000000004000000Go
o`00;?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001ooooooooo
ool03oooool10000007ooooo000Kooooo`0300000?oooooooooo03gooooo0ooo0008ooooo`Goo`00
;?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool0
3oooool10000007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001oooooooooool01ooo
ool5ool000800000:_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0
001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001o
ooooooooool02?ooool3ool000?ooooo0`000002ooooo`?oo`008_ooool00`0007ooooooooooo`0h
ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Koooo
o`0300000?l0003ooooo03kooooo00<0001oooooooooool04Oooool00`00003oo`00ool00003ool0
027ooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo
00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001ooooooooo
ool04_ooool5ool0027ooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0nooooo`030000
Oooooooooooo01;ooooo1Ooo00000`00003oooooooooo`0Nooooo`030000Oooooooooooo03Sooooo
00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0?_ooool00`0007ooooooooooo`0Cooooo`?oo`000_ooool2000001kooooo00<0
001oooooooooool0>?ooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0nooooo`030000Oooooooooooo01[ooooo0P00000L
ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0Loooo
o`80000000Coooooool00?oo003oo`005_ooool00`0007ooooooooooo`0hooooo`030000Oooooooo
oooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo
03kooooo00<0001oooooooooool07_ooool5ool001Gooooo00<0001oooooooooool0>?ooool00`00
07ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o
0000ooooo`0nooooo`030000Oooooooooooo01kooooo1Ooo000Eooooo`030000Oooooooooooo03So
oooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0>ooooo`7o00000@000001ooooo`00
6oooool00`00003oooooooooo`0nooooo`030000Oooooooooooo01kooooo1Ooo000Eooooo`030000
Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`400000
0Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0Oooooo`?oo`0000?o
oooo0000000000004oooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0
001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001o
ooooooooool09Oooool00`00003oooooooooo`0@ooooo`030000Oooooooooooo03Sooooo00<0001o
ooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000Kooooo1Ol00003oooo
o`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0Voooo
o`8000004?ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Oooooo00<0001ooooo
ooooool03oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03kooooo00<0
001oooooooooool0:?ooool00`00003oooooooooo`0=ooooo`030000Oooooooooooo03Sooooo00<0
001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool0?_ooool00`0007ooooooooooo`0Yooooo`8000000ooo000:ooooo`030000
Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`400000
0Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00`00003o00000000O`1[0000O`Goo`00S`0007l1o`000040
00000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0nooooo`030000Oooooooo
oooo02[ooooo1Ooo0009ooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0=oooool0
0`0007ooooooooooo`0?ooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0nooooo`030000Oooooooooooo02[ooooo1Ooo00000`00003oooooooooo`06ooooo`030000
Oooooooooooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`400000
0Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0?_oo
ool00`0007ooooooooooo`0[ooooo`?oo`000_ooool2000000Kooooo00<0001oooooooooool0>?oo
ool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0nooooo`030000Oooooooooooo03;ooooo0P000004ooooo`030000Oooooooo
oooo03Sooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0dooooo`80000000Coooooool0
0?oo003oo`00>Oooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001
ooooo`006oooool00`00003o0000ooooo`0nooooo`030000Oooooooooooo03Kooooo1Ooo000hoooo
o`030000Oooooooooooo03Oooooo00<0001oooooooooool03_ooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0fooooo`Goo`00>?ooool00`0007oo
ooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0nooooo`030000Oooooooooooo03Kooooo1Ooo0004000000?ooooo0ooo000^ooooo`030000
Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oo
oooooooo03kooooo00<0001oooooooooool0=oooool3ool000Gooooo0P000005ool002gooooo00<0
001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000
ooooooooool0?_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo00Kooooo1Ooo000]
ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Koooo
o`0300000?oooooooooo03kooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`06oooo
o`Goo`000`00000Zooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000
007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001oooooooooool0>?ooool00`0007oo
ooooooooo`07ooooo`?oo`001?ooool3000000;ooooo0ooo000Rooooo`030000Oooooooooooo03Oo
oooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?l0003ooooo03kooooo
00<0001oooooooooool0>?ooool00`0007ooooooooooo`0Aooooo`0300000?oo003oo`0000?oo`00
8Oooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00kooooo0Ol000010000007ooooo
000Kooooo`0300000?oooooooooo03kooooo00<0001oooooooooool0>?ooool00`0007oooooooooo
o`0Booooo`Goo`008Oooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001o
ooooooooool04_ooool5ool0027ooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0hoooo
o`030000Oooooooooooo01?ooooo0ooo00000oooool000000000000Oooooo`030000Oooooooooooo
03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo03ko
oooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0Iooooo`0300000?oooooooooo01co
oooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo
00<00000ooooooooool0?_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo01[ooooo
0P00000Looooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo
000Kooooo`0300000?oooooooooo03kooooo00<0001oooooooooool0>?ooool00`0007oooooooooo
o`0Looooo`0300000?oooooooooo01Wooooo00<0001oooooooooool0=oooool00`0007oooooooooo
o`0?ooooo`4000000Oooool001_ooooo00<00000o`000?ooool0?_ooool00`0007ooooooooooo`0h
ooooo`030000Oooooooooooo01gooooo0P000003ool001Kooooo00<0001oooooooooool0=oooool0
0`0007ooooooooooo`0>ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0noooo
o`030000Oooooooooooo03Sooooo00<0001oooooooooool07_ooool5ool001Gooooo00<0001ooooo
ooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0?_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo01kooooo1Ooo000Eooooo`03
0000Oooooooooooo03Oooooo00<0001oooooooooool03oooool10000007ooooo000Kooooo`030000
0?oooooooooo03kooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0Nooooo`Goo`00
5Oooool00`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`002?oo
ool3o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0nooooo`030000Oooo
oooooooo03Sooooo00<0001oooooooooool07oooool3ool0000300000?oooooooooo01?ooooo00<0
001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000Wooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0
8oooool00`00003oooooooooo`0Booooo`030000Oooooooooooo03Oooooo00<0001oooooooooool0
3oooool10000007ooooo0006ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0hooooo`03
0000Oooooooooooo02Cooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0gooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`001_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`2Q
0000O`030000000007l0001o05/0001o0Ol000010000007ooooo0007ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo03kooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0Vooooo`0300000?oo
oooooooo00oooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`4000000Ooo
ool000Sooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0
9oooool00`00003oooooooooo`0>ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool0
3oooool10000007ooooo0009ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Ooo
ool00`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0:?oo
ool00`00003oooooooooo`0=ooooo`030000Oooooooooooo03Oooooo00<0001oooooooooool03ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`0Yooooo`0300000?oooooooooo00cooooo00<0001oooooooooool0=oooool0
0`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool00`00
07ooooooooooo`0hooooo`030000Oooooooooooo02[ooooo00@00000ool00?oo003oo`002_ooool0
0`0007ooooooooooo`0gooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool00`00
003o0000ooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0:_ooool5ool0
00Wooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0>ooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001ooooooooo
ool0:_ooool5ool000Wooooo00<0001oooooooooool0=oooool00`0007ooooooooooo`0?ooooo`40
00000Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007ooooooooooo`0hooooo`030000
Oooooooooooo02[ooooo1Ooo0003000000Kooooo00<0001oooooooooool0=oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007oooooooooo
o`0hooooo`030000Oooooooooooo02_ooooo0ooo0004ooooo`<0000000Coooooool00?oo003oo`00
>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_oo
ool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Gooooo1Ooo000hooooo`030000Oooo
oooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0nooooo`030000Oooooooo
oooo03Sooooo00<0001oooooooooool0=Oooool5ool0000300000?oooooooooo03Gooooo00<0001o
ooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo03kooooo00<0001ooooo
ooooool0>?ooool00`0007ooooooooooo`0eooooo`Goo`0000?ooooo0000000000000P000003oooo
o`?oo`00;Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0?_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Kooooo0ooo0006ooooo`80
00001Ooo000/ooooo`030000Oooooooooooo00kooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo03kooooo00<0001oooooooooool0>?ooool00`0007ooooooooooo`0hooooo`030000
Oooooooooooo00Kooooo1Ooo00000`00003oooooooooo`05ooooo`?oo`008Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007oooooooooo
o`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool01_ooool5ool00003ooooo`00
0000000000@000001Ooo000Pooooo`030000Oooooooooooo00oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0>?ooool0
0`0007ooooooooooo`07ooooo`?oo`002?ooool5ool0000300000?oooooooooo00Gooooo0ooo0009
ooooo`?oo`002Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0?_ooool00`0007ooooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001ooooo
ooooool04_ooool5ool00003ooooo`000000000000@000001Ooo0007ooooo`Goo`001oooool3ool0
00Wooooo0ooo0004ooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool00`0007oo
ooooooooo`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool04oooool3ool000So
oooo1Ooo0007000000Goo`0010000002ooooo`Goo`001oooool5ool000?ooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0nooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool0
>?ooool00`0007ooooooooooo`0Nooooo`Goo`001oooool5ool000Cooooo0P000005ool000L00000
1Ooo0003ooooo`4000000Oooool001_ooooo00<00000o`000?ooool0?_ooool00`0007oooooooooo
o`0hooooo`030000Oooooooooooo03Sooooo00<0001oooooooooool07oooool3ool000Wooooo0ooo
0007ooooo`Goo`001oooool5ool000;ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`?oo`002Oooool3
ool000Cooooo0@000001ooooo`006ooooooo000000D000000Oooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.83904, -723.791, \
0.0849295, 7.38883}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(full2\  = \ em\  // \ Last;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classification", "Section"],

Cell[CellGroupData[{

Cell["Scalar covariance models", "Subsection"],

Cell[CellGroupData[{

Cell["Which models", "Subsubsection"],

Cell[BoxData[{
    \(\(model1\  = \ scalar1;\)\), "\[IndentingNewLine]", 
    \(\(model2\  = \ scalar2;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate classification data", "Subsubsection"],

Cell[BoxData[{
    \(\(pts\  = \ 150;\)\), "\n", 
    \(\(reg1\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model1];\)\), "\n", 
    \(\(reg2\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model2];\)\)}], "Input"],

Cell[BoxData[{
    \(\(class\  = 
        Partition[\(If[#[\([1]\)]\  < \ #[\([2]\)], \ 1, 
                0] &\)\  /@ \ \(({Flatten[reg1], \ Flatten[reg2]}\  // \ 
                Transpose)\), pts + 1];\)\), "\n", 
    \(\(classPlot\  = 
        ListDensityPlot[class, \ 
          ColorFunction -> \((If[# == 1, RGBColor[0, 0, #], \ 
                  RGBColor[1, 0, #]] &)\), \ Mesh -> False, \ 
          MeshRange -> {{0, 1}, {0, 1}}, nF, nS];\)\)}], "Input"],

Cell[BoxData[{
    \(\(g1\  = \ 
        drawPolygonalRegion[poly, {{0, 1}, {0, 1}}, \ Red, \ nF, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2\  = \ 
        drawAntiPolygonalRegion[poly, {{0, 1}, {0, 1}}, \ Blue, \ nF, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(idealPlot\  = \ Show[g2, g1];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{idealPlot, \ classPlot}], yS, 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
1 0 0 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
0000017ooooo]Ol0000;ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon80?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohP0o`00
9@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR03o000U0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon80?l002D0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohP0o`009@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooR03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon70?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohL0o`00
9P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ`3o000V0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon70?l002H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohL0o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon70?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohL0o`00
9P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ`3o000V0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon70?l002H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohL0o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon60?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohH0o`00
9`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQP3o000W0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon60?l002L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohH0o`009`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQP3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon60?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohD0o`00
:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ@3o000X0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon50?l002P0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohD0o`00:0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ03o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon30?l002X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooodL0o`00
1P000?lf0?l002X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooood@0o`00
3@000?l`0?l002`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooood00o`00
5P000?lZ0?l002d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocd0o`00
7P000?lT0?l002h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocd0o`00
7P000?lT0?l002h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooocD0o`00
;P000?lJ0?l00300003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooc00o`00
?0000?l@0?l00340003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobd0o`00
AP000?l50?l003D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobX0o`00
P`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:@3o00240000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolX0?l008D0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobH0o`00Q`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo9P3o00270000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolV0?l008L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0o`00
R0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo903o00290000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolT0?l008T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80o`00R`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8P3o002;0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolR0?l008/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80o`00
R`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8P3o002;0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolR0?l008/0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80o`00R`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8P3o002;0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolR0?l008/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0o`00
R@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo903o00290000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolT0?l008T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob@0o`00R@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo9@3o00280000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolU0?l008P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0o`00
Q`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9`3o00260000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolW0?l008H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobP0o`005P000?l:0?l002/0003o0`3o000g0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolX0?l001H0003o2P3o000[0000o`<0o`00
=`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:@3o000A0000oa80o`00
8@000?l<0?l003@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobX0o`00
3P000?lH0?l001T0003o4P3o000b0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
ooooool]0?l000P0003o7`3o000B0000oaH0o`00<@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooF03o00080000oad0o`00<0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooOP3o000_0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooomo0?l002h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh00o`00
;@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooP03o000]0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon00?l002d0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh40o`00;0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooP`3o000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon30?l002X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh<0o`00
:P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ03o000Y0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon40?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh@0o`00:@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ03o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon40?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh@0o`00
:@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ03o000Y0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon40?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh<0o`00:P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooP`3o000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon30?l002X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh40o`00
;0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooP@3o000/0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon00?l002d0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh00o`00;@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooO`3o000^0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooomG0?l000P0003o7`3o000_0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooomG0?l000P0003o7`3o000_0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooomE0?l000`0003o703o000`0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooomB0?l001<0003o5`3o000a0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooola0?l000T0003o5P3o000G0000oa@0o`00<P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo;`3o000@0000o`h0o`0070000?l@0?l003@0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobh0o`0060000?l20?l002@0003o2`3o000f0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003oooooooooooooool]0?l004<0003o1@3o000h0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003oooooooooooooool/0?l00840003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob`0o`00P@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo:P3o00230000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolY0?l008@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobT0o`00
Q0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:03o00250000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolW0?l008H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobL0o`00QP000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo9P3o00270000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolV0?l008L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0o`00
Q`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9@3o00280000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolU0?l008P0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob@0o`00R@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo903o00290000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolT0?l008T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0o`00
R@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo903o00290000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolT0?l008T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob@0o`00R@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo903o00290000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolT0?l008T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0o`00
R0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9@3o00280000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolV0?l008L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobH0o`00Q`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo9`3o00260000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolW0?l008H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobP0o`00
Q@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:@3o00180000o`X0o`00
<P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:P3o00140000o`l0o`00
<0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo;03o000E0000o`T0o`00
8P000?lB0?l002l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobh0o`00
3P000?lB0?l001/0003o5P3o000^0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
ooooool^0?l000h0003o4P3o000K0000oaH0o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo<@3o00060000oaT0o`0060000?lH0?l002d0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooe40o`005@000?lK0?l002`0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooe@0o`0040000?lO0?l002X0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooeH0o`002`000?lS0?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooeP0o`001`000?lU0?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohD0o`00:0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ@3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon50?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohD0o`00
:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQP3o000W0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon60?l002L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohH0o`009`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQP3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon60?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohH0o`00
9`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ`3o000V0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon70?l002H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohL0o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon70?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohL0o`00
9P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQ`3o000V0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon70?l002H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohP0o`009@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooR03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon80?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohP0o`00
9@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR03o000U0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon80?l002D0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohP0o`009@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooR03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon80?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohT0o`00
90000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR@3o000T0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:
ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aoooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09oooo
o`002_oooone0000017ooooo]Ol0000;ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0676948, \
-0.0365494, 0.00566279, 0.00566279}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Full covariance models", "Subsection"],

Cell[CellGroupData[{

Cell["Which models", "Subsubsection"],

Cell[BoxData[{
    \(\(model1\  = \ full1;\)\), "\[IndentingNewLine]", 
    \(\(model2\  = \ full2;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate classification data", "Subsubsection"],

Cell[BoxData[{
    \(\(pts\  = \ 150;\)\), "\n", 
    \(\(reg1\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model1];\)\), "\n", 
    \(\(reg2\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model2];\)\)}], "Input"],

Cell[BoxData[{
    \(\(class\  = 
        Partition[\(If[#[\([1]\)]\  < \ #[\([2]\)], \ 1, 
                0] &\)\  /@ \ \(({Flatten[reg1], \ Flatten[reg2]}\  // \ 
                Transpose)\), pts + 1];\)\), "\n", 
    \(\(classPlot\  = 
        ListDensityPlot[class, \ 
          ColorFunction -> \((If[# == 1, RGBColor[0, 0, #], \ 
                  RGBColor[1, 0, #]] &)\), \ Mesh -> False, \ 
          MeshRange -> {{0, 1}, {0, 1}}, nF, nS];\)\)}], "Input"],

Cell[BoxData[{
    \(\(g1\  = \ 
        drawPolygonalRegion[poly, {{0, 1}, {0, 1}}, \ Red, \ nF, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2\  = \ 
        drawAntiPolygonalRegion[poly, {{0, 1}, {0, 1}}, \ Blue, nF, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(idealPlot\  = \ Show[g2, g1];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{idealPlot, \ classPlot}], yS, 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.0098 .0098 m
.0098 .9902 L
.9902 .9902 L
.9902 .0098 L
F
1 1 1 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
1 0 0 r
.0098 .0098 m
.79412 .0098 L
.79412 .20588 L
.20588 .20588 L
.20588 .40196 L
.79412 .40196 L
.79412 .59804 L
.20588 .59804 L
.20588 .79412 L
.79412 .79412 L
.79412 .9902 L
.0098 .9902 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
0000017ooooo]Ol0000;ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon90?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh/0o`00
8P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR`3o000R0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon<0?l00240003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh`0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooS03o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon=0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohd0o`00
80000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooSP3o000O0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon>0?l001l0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohh0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooSP3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon>0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohh0o`00
7`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooS`3o000N0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon>0?l001l0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohh0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooSP3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon>0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohh0o`00
7`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooSP3o000O0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon=0?l00200003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohd0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooS03o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon<0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh/0o`00
8P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR@3o000T0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon90?l002@0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohT0o`0090000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooR03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon60?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohD0o`00
:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooP@3o000/0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooomF0?l005L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooocD0o`00N0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo=@3o001h0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
ooooool/0?l00840003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobP0o`00
Q@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9`3o00260000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolU0?l008P0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob@0o`00R@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo903o00290000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolR0?l008/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80o`00
R`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8P3o002;0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolQ0?l008`0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob40o`00S0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8@3o002<0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolQ0?l008`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00o`00
S@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo803o002=0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolP0?l008d0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob00o`00S@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8@3o002<0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolQ0?l008`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40o`00
S0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@3o002<0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolR0?l008/0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80o`00R`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8P3o002;0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolR0?l008/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0o`00
R@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9@3o00280000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolU0?l008P0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobH0o`00Q`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo9`3o00260000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolX0?l008D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobP0o`00
Q@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo:P3o00230000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003oooooooooooooool^0?l007l0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh00o`00;@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooP`3o000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon40?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohD0o`00
:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQP3o000W0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon60?l002L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohH0o`009`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon70?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohL0o`00
9P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR03o000U0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon80?l002D0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohP0o`009@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooR03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon80?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohP0o`00
9@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR03o000U0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon80?l002D0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohL0o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon70?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohL0o`00
9P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooQP3o000W0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon60?l002L0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohD0o`00:0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ@3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon40?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh<0o`00
:P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooP`3o000Z0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon10?l002`0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooogl0o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooN@3o000d0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooom50?l006P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooc00o`00
O@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo;03o00210000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolY0?l008@0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobT0o`00Q0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo:03o00250000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolW0?l008H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0o`00
Q`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9@3o00280000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolT0?l008T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob@0o`00R@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8P3o002;0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolR0?l008/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80o`00
R`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@3o002<0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolQ0?l008`0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob40o`00S0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8@3o002<0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolQ0?l008`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40o`00
S0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8@3o002<0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolQ0?l008`0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob40o`00S0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo8@3o002<0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolQ0?l008`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40o`00
S0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo8P3o002;0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolR0?l008/0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80o`00R`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo903o00290000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolT0?l008T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0o`00
R0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`000280o`00S@00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo9`3o00260000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o00008P3o002=0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooolY0?l008@0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0000R0?l008d0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobh0o`00O`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`000280o`00S@000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo?@3o001`0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o00008P3o002=0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooolm0?l00700003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
000R0?l008d0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooed0o`00
D0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooP@3o000/0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon40?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohH0o`009`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooQ`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon80?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohP0o`00
9@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR@3o000T0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon;0?l00280003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh/0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooS03o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon<0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohd0o`00
80000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooS@3o000P0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon=0?l00200003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohd0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooS@3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon=0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohd0o`00
80000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooS@3o000P0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon=0?l00200003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohd0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooS@3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon=0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?oooooooooooooooh`0o`00
8@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooS03o000Q0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon;0?l00280003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooh/0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00Co
0000ooooooooooooooooR@3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
00000?l0003o0000S03o000S0000o`;ooooo00<00000ooooooooool03oooool01?l0003ooooooooo
oooooon90?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0
002<0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooohT0o`00
90000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000003o0000o`0008`0o`008`00
0?l2ooooo`0300000?oooooooooo00oooooo00Co0000ooooooooooooooooR03o000U0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00<000000?l0003o0000S03o000S0000o`;ooooo00<0
0000ooooooooool03oooool01?l0003ooooooooooooooon70?l002H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`000000o`000?l0002<0?l002<0003o0_ooool00`00003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooohL0o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`030000003o0000o`0008`0o`008`000?l2ooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`000000o`000?l0002<
0?l002<0003o0_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000
ooooooooool02Oooool000[ooooo00<00000ooooooooool0/Oooool00`00003oooooooooo`0?oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo]@00000AoooookGo
00002oooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001
\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0676948, \
-0.0365494, 0.00566279, 0.00566279}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation (slow)", "Section"],

Cell[CellGroupData[{

Cell["Red class", "Subsection"],

Cell[BoxData[
    \(\(\(PolygonalAllPlot[poly, #] &\)\  /@ \ em;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blue class", "Subsection"],

Cell[BoxData[
    \(\(\(AntiPolygonalAllPlot[poly, #] &\)\  /@ \ em;\)\)], "Input"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{675, 713},
WindowMargins->{{106, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 48, 0, 62, "Title"],
Cell[1805, 53, 275, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2105, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2172, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2250, 71, 36, 0, 43, "Subsubsection"],
Cell[2289, 73, 166, 4, 63, "Input"],
Cell[2458, 79, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2669, 87, 53, 0, 43, "Subsubsection"],
Cell[2725, 89, 207, 4, 63, "Input"],
Cell[2935, 95, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068, 102, 40, 0, 49, "Subsection"],
Cell[3111, 104, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3211, 110, 36, 0, 49, "Subsection"],
Cell[3250, 112, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3429, 120, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3490, 124, 55, 0, 49, "Subsection"],
Cell[3548, 126, 325, 6, 127, "Input"],
Cell[3876, 134, 291, 5, 127, "Input"],
Cell[4170, 141, 441, 9, 175, "Input"],
Cell[4614, 152, 433, 8, 175, "Input"],
Cell[5050, 162, 76, 1, 47, "Input"],
Cell[5129, 165, 267, 5, 95, "Input"],
Cell[5399, 172, 275, 5, 111, "Input"],
Cell[5677, 179, 393, 6, 159, "Input"],
Cell[6073, 187, 386, 7, 127, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6496, 199, 58, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[6579, 203, 46, 0, 43, "Subsubsection"],
Cell[6628, 205, 161, 2, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6826, 212, 46, 0, 43, "Subsubsection"],
Cell[6875, 214, 522, 8, 143, "Input"],
Cell[7400, 224, 725, 13, 207, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8162, 242, 67, 0, 43, "Subsubsection"],
Cell[8232, 244, 1108, 18, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9377, 267, 67, 0, 43, "Subsubsection"],
Cell[9447, 269, 1110, 18, 223, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10618, 294, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[10695, 298, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10764, 302, 70, 1, 47, "Input"],
Cell[10837, 305, 19321, 308, 296, 1010, 77, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30207, 619, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[30292, 623, 55, 0, 43, "Subsubsection"],
Cell[30350, 625, 159, 4, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30546, 634, 39, 0, 35, "Subsubsection"],
Cell[30588, 636, 116, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30741, 643, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[30805, 647, 251, 5, 79, "Input"],
Cell[31059, 654, 139932, 3317, 296, 38285, 2058, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[171064, 3979, 66, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[171155, 3983, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[171249, 3987, 68, 0, 43, "Subsubsection"],
Cell[171320, 3989, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[171454, 3997, 51, 0, 35, "Subsubsection"],
Cell[171508, 3999, 87, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[171644, 4006, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[171711, 4010, 83, 1, 47, "Input"],
Cell[171797, 4013, 70, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[171916, 4020, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[171976, 4024, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[172039, 4028, 73, 1, 47, "Input"],
Cell[172115, 4031, 365226, 8844, 408, 228734, 7156, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[537390, 12881, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[537451, 12885, 72, 1, 47, "Input"],
Cell[537526, 12888, 537790, 14768, 408, 297229, 11795, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1075365, 27662, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1075498, 27669, 66, 1, 47, "Input"],
Cell[1075567, 27672, 53250, 1228, 186, 8121, 666, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1128878, 28907, 35, 0, 49, "Subsection"],
Cell[1128916, 28909, 66, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1129031, 28916, 64, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1129120, 28920, 75, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1129220, 28924, 68, 0, 43, "Subsubsection"],
Cell[1129291, 28926, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1129425, 28934, 57, 0, 35, "Subsubsection"],
Cell[1129485, 28936, 83, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1129617, 28943, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1129684, 28947, 81, 1, 47, "Input"],
Cell[1129768, 28950, 70, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1129887, 28957, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1129947, 28961, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1130010, 28965, 73, 1, 47, "Input"],
Cell[1130086, 28968, 368708, 8803, 408, 226319, 7042, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1498843, 37777, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1498904, 37781, 76, 1, 47, "Input"],
Cell[1498983, 37784, 477268, 13711, 408, 293618, 11441, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1976300, 51501, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1976433, 51508, 66, 1, 47, "Input"],
Cell[1976502, 51511, 55808, 1186, 186, 6987, 579, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2032371, 52704, 35, 0, 49, "Subsection"],
Cell[2032409, 52706, 64, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2032522, 52713, 67, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[2032614, 52717, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2032708, 52721, 68, 0, 43, "Subsubsection"],
Cell[2032779, 52723, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2032913, 52731, 51, 0, 35, "Subsubsection"],
Cell[2032967, 52733, 87, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2033103, 52740, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2033170, 52744, 83, 1, 47, "Input"],
Cell[2033256, 52747, 69, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2033374, 52754, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2033434, 52758, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2033497, 52762, 77, 1, 47, "Input"],
Cell[2033577, 52765, 476341, 12588, 408, 271424, 10055, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2509967, 65359, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2510028, 65363, 76, 1, 47, "Input"],
Cell[2510107, 65366, 488317, 13639, 408, 287446, 11156, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2998473, 79011, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2998606, 79018, 66, 1, 47, "Input"],
Cell[2998675, 79021, 42630, 985, 186, 6451, 534, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3041366, 80013, 35, 0, 49, "Subsection"],
Cell[3041404, 80015, 66, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3041519, 80022, 65, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3041609, 80026, 75, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3041709, 80030, 68, 0, 43, "Subsubsection"],
Cell[3041780, 80032, 97, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3041914, 80040, 57, 0, 35, "Subsubsection"],
Cell[3041974, 80042, 83, 1, 47, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3042106, 80049, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3042173, 80053, 81, 1, 47, "Input"],
Cell[3042257, 80056, 69, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3042375, 80063, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3042435, 80067, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3042498, 80071, 77, 1, 47, "Input"],
Cell[3042578, 80074, 441484, 10946, 408, 249401, 8571, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3484111, 91026, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3484172, 91030, 80, 1, 47, "Input"],
Cell[3484255, 91033, 451921, 12403, 408, 274163, 10205, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3936225, 103442, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3936358, 103449, 66, 1, 47, "Input"],
Cell[3936427, 103452, 40172, 880, 186, 5576, 448, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3976660, 104339, 35, 0, 49, "Subsection"],
Cell[3976698, 104341, 64, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3976811, 104348, 33, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3976869, 104352, 46, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3976940, 104356, 37, 0, 43, "Subsubsection"],
Cell[3976980, 104358, 119, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3977136, 104365, 53, 0, 35, "Subsubsection"],
Cell[3977192, 104367, 271, 7, 79, "Input"],
Cell[3977466, 104376, 466, 9, 111, "Input"],
Cell[3977935, 104387, 329, 7, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3978301, 104399, 41, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[3978367, 104403, 104, 2, 47, "Input"],
Cell[3978474, 104407, 168880, 2483, 199, 141199, 2138, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4147415, 106897, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4147484, 106901, 37, 0, 43, "Subsubsection"],
Cell[4147524, 106903, 115, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4147676, 106910, 53, 0, 35, "Subsubsection"],
Cell[4147732, 106912, 271, 7, 79, "Input"],
Cell[4148006, 106921, 466, 9, 111, "Input"],
Cell[4148475, 106932, 327, 7, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4148839, 106944, 41, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[4148905, 106948, 104, 2, 47, "Input"],
Cell[4149012, 106952, 168289, 2476, 199, 141199, 2138, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4317374, 109436, 35, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4317434, 109440, 31, 0, 49, "Subsection"],
Cell[4317468, 109442, 79, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4317584, 109448, 32, 0, 49, "Subsection"],
Cell[4317619, 109450, 83, 1, 47, "Input"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

