(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    334601,       8048]*)
(*NotebookOutlinePosition[    335320,       8073]*)
(*  CellTagsIndexPosition[    335276,       8069]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Two-parameter mixture-model example", "Title"],

Cell[TextData[{
  "This notebook explores a two-parameter mixture-model example and assumes \
that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Random numbers from Gaussian mixture model", "Subsection"],

Cell[CellGroupData[{

Cell["Uniform random number in range [0, 1]", "Subsubsection"],

Cell[BoxData[
    \(\(RR\  := \ Random[Real, \ {0. , \ 1. }];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random number generation helper functions", "Subsubsection"],

Cell[BoxData[
    \(\(TransformProbabilityVector[
          prob_] := \[IndentingNewLine]Module[{s\  = \ 0, \ 
            len}, \[IndentingNewLine]len\  = \ 
            Length[prob] - 1; \[IndentingNewLine]Join[
            Table[s\  = \ s\  + \ prob[\([i]\)], \ {i, \ 1, \ 
                len}], \ {1}]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(PickOne[\ 
          priors_] := \[IndentingNewLine]Module[{r}, \[IndentingNewLine]r\  = \
\ RR; \((Position[\(\((r\  <= \ #)\) &\)\  /@ \ 
                    TransformProbabilityVector[priors], True]\  // \ 
                Flatten)\)\  // \ First\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random number generation from Gaussian mixture model (1D)", \
"Subsubsection"],

Cell[BoxData[
    \(\(\(RandomMixtureModelOne1D[{\[Mu]_, \ \[Sigma]_, \ priors_}] := 
        Module[{class}, \[IndentingNewLine]class = 
            PickOne[priors]; \[IndentingNewLine]{class, 
            Random[NormalDistribution[\[Mu][\([class]\)], \ \
\[Sigma][\([class]\)]]]}\[IndentingNewLine]];\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(RandomMixtureModel1D[{\[Mu]_, \ \[Sigma]_, \ priors_}, \ 
          n_] := \[IndentingNewLine]Table[
          RandomMixtureModelOne1D[{\[Mu], \[Sigma], 
              priors}], {n}];\)\(\ \)\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1D Gaussian mixture modeling", "Subsection"],

Cell[CellGroupData[{

Cell["1D Mixture model PDF", "Subsubsection"],

Cell[BoxData[
    \(\(mixturepdf1D[{\[Mu]_, \ \[Sigma]_, \ priors_}, 
          x_] := \[IndentingNewLine]Plus\  @@ 
          Table[PDF[NormalDistribution[\[Mu][\([i]\)], \[Sigma][\([i]\)]], 
                x]\ priors[\([i]\)], {i, 1, Length[\[Mu]]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1D log mixture model PDF", "Subsubsection"],

Cell[BoxData[
    \(\(mixturelogpdf1D[{\[Mu]_, \ \[Sigma]_, \ priors_}, 
          x_] := \[IndentingNewLine]Log[
          mixturepdf1D[{\[Mu], \[Sigma], priors}, x]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Find best estimate for \[Mu]1 and \[Mu]2\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(likelihoodFunction1D[data_, 
          params_] := \[IndentingNewLine]Plus\  @@ \ \((\(mixturelogpdf1D[
                  params\  // \ N, #[\([2]\)]] &\)\  /@ \ 
              data)\);\)\)], "Input"],

Cell[BoxData[
    \(\(estimateParams1D[
          data_, \ {\[Mu]_, \[Sigma]_, 
            priors_}] := \[IndentingNewLine]Module[{mlf, \[Mu]1, \[Mu]2, \ 
            params, \ 
            sol}, \[IndentingNewLine]params\  = \ {{\[Mu]1, \[Mu]2}, \
\[Sigma], priors}; \[IndentingNewLine]mlf\  = \ 
            likelihoodFunction1D[data, params]; \[IndentingNewLine]sol\  = \ 
            FindMinimum[\(-mlf\), {\[Mu]1, \ \[Mu][\([1]\)]}, {\[Mu]2, \[Mu][\
\([2]\)]}]; \[IndentingNewLine]{{{\[Mu]1, \[Mu]2}\  /. \ 
                sol[\([2]\)]\ , \[Sigma], 
              priors}, \(-sol[\([1]\)]\)}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Special plotting functions", "Subsection"],

Cell[CellGroupData[{

Cell["Plot 1D labeled data", "Subsubsection"],

Cell[BoxData[
    \(\(PlotDataLabeled1D[data_, \ c1_, \ c2_, \ 
          opts___] := \[IndentingNewLine]Module[{colors}, \
\[IndentingNewLine]colors\  = \ {c1, c2}; \[IndentingNewLine]Show[
            Graphics[\({colors[\([#[\([1]\)]]\)], PointSize[ .02], 
                    Point[{#[\([2]\)], 1}]} &\)\  /@ \ data], 
            Axes \[Rule] {True, False}, Frame \[Rule] False, 
            AspectRatio \[Rule] Automatic, \ PlotRange \[Rule] All, \ 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood as a function of \[Mu]1 and \[Mu]2\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(PlotLogLikelihoodLocal[
          data_, {{\[Mu]1_, \[Mu]2_}, \[Sigma]_, priors_}, 
          opts___] := \[IndentingNewLine]Module[{lf}, \[IndentingNewLine]lf\  \
= \ Plus\  @@ \ \((\(mixturelogpdf1D[{{\[Mu]1, \[Mu]2}, \[Sigma], 
                          priors}\  // \ N, #[\([2]\)]] &\)\  /@ \ 
                  data)\); \[IndentingNewLine]ContourPlot[
            lf, {\[Mu]1, \(-6\), 6}, {\[Mu]2, \(-6\), 6}, \ 
            PlotPoints \[Rule] 30, opts]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(PlotLogLikelihoodLocal2[
          data_, {{\[Mu]1_, \[Mu]2_}, \[Sigma]_, priors_}, 
          opts___] := \[IndentingNewLine]Module[{g1, g2, est1, est2, c1, 
            c2}, \[IndentingNewLine]g1\  = \ 
            PlotLogLikelihoodLocal[
              data, {{\[Mu]1, \[Mu]2}, \[Sigma], priors}, 
              nS]; \[IndentingNewLine]est1\  = \ 
            estimateParams1D[
              data, \ {{\(-6\), 6}, \[Sigma], 
                priors}]; \[IndentingNewLine]est2\  = \ 
            estimateParams1D[
              data, \ {{6, \(-6\)}, \[Sigma], priors}]; \[IndentingNewLine]If[
            Last[est1]\  < \ Last[est2], c1 = Blue; c2 = Red, c1 = Red; 
            c2 = Blue]; \[IndentingNewLine]g2 = 
            Show[Graphics[{{c1, PointSize[ .02], 
                    Point[\(First[est1]\)[\([1]\)]]}, \[IndentingNewLine]{c2, 
                    PointSize[ .02], Point[\(First[est2]\)[\([1]\)]]}}], 
              Frame \[Rule] True, AspectRatio \[Rule] Automatic, \ 
              nS]; \[IndentingNewLine]Show[g1, g2, yS, \ 
            PlotRange \[Rule] All, \ 
            opts]; \[IndentingNewLine]{\(First[est1]\)[\([1]\)], \(First[
                est2]\)[\([1]\)]}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(PlotLogLikelihoodLocal3[
          data_, {{\[Mu]1_, \[Mu]2_}, \[Sigma]_, priors_}, 
          opts___] := \[IndentingNewLine]Module[{lf}, \[IndentingNewLine]lf\  \
= \ Plus\  @@ \ \((\(mixturelogpdf1D[{{\[Mu]1, \[Mu]2}, \[Sigma], 
                          priors}\  // \ N, #[\([2]\)]] &\)\  /@ \ 
                  data)\); \[IndentingNewLine]Plot3D[
            lf, {\[Mu]1, \(-6\), 6}, {\[Mu]2, \(-6\), 6}, \ 
            PlotPoints \[Rule] 30, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot optimization algorithm trajectory", "Subsubsection"],

Cell[BoxData[
    \(\(PlotTrajectory[pts_, \ color_, \ 
          opts___] := \[IndentingNewLine]Module[{g1, 
            g2}, \[IndentingNewLine]g1\  = \ 
            Graphics[{PointSize[ .015], color, 
                Point\  /@ \ pts}]; \[IndentingNewLine]g2\  = \ 
            Graphics[{color, Line[pts]}]; \[IndentingNewLine]Show[g1, g2, 
            opts]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Mixture of two Gaussians (unknown ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_2\)]],
  ")"
}], "Section"],

Cell[CellGroupData[{

Cell["Mixture model definitions", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Sigma]\  = \ {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(P\[Omega]\  = \ {1/3, 2/3};\)\), "\[IndentingNewLine]", 
    \(\(\[Mu]\  = \ {\(-2\), 2};\)\), "\[IndentingNewLine]", 
    \(\[Mu]1 =. ; \[Mu]2 =. ;\), "\[IndentingNewLine]", 
    \(\(\[Mu]v\  = \ {\[Mu]1, \ \[Mu]2};\)\)}], "Input"],

Cell[BoxData[{
    \(\(params1\  = \ {\[Mu], \ \[Sigma], 
          P\[Omega]};\)\), "\[IndentingNewLine]", 
    \(\(params2\  = \ {\[Mu]v, \[Sigma], P\[Omega]};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize mixture model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pdf\  = \ 
        Plot[mixturepdf1D[params1, x], {x, \(-5\), 5}, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          PlotStyle \[Rule] {Thickness[ .01], Green}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 2.21275 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12535 -24 -4.5 ]
[-0.0125 .12535 0 4.5 ]
[-0.0125 .23599 -18 -4.5 ]
[-0.0125 .23599 0 4.5 ]
[-0.0125 .34663 -24 -4.5 ]
[-0.0125 .34663 0 4.5 ]
[-0.0125 .45726 -18 -4.5 ]
[-0.0125 .45726 0 4.5 ]
[-0.0125 .5679 -24 -4.5 ]
[-0.0125 .5679 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12535 m
.00625 .12535 L
s
[(0.05)] -0.0125 .12535 1 0 Mshowa
0 .23599 m
.00625 .23599 L
s
[(0.1)] -0.0125 .23599 1 0 Mshowa
0 .34663 m
.00625 .34663 L
s
[(0.15)] -0.0125 .34663 1 0 Mshowa
0 .45726 m
.00625 .45726 L
s
[(0.2)] -0.0125 .45726 1 0 Mshowa
0 .5679 m
.00625 .5679 L
s
[(0.25)] -0.0125 .5679 1 0 Mshowa
.125 Mabswid
0 .03684 m
.00375 .03684 L
s
0 .05897 m
.00375 .05897 L
s
0 .0811 m
.00375 .0811 L
s
0 .10323 m
.00375 .10323 L
s
0 .14748 m
.00375 .14748 L
s
0 .16961 m
.00375 .16961 L
s
0 .19173 m
.00375 .19173 L
s
0 .21386 m
.00375 .21386 L
s
0 .25812 m
.00375 .25812 L
s
0 .28024 m
.00375 .28024 L
s
0 .30237 m
.00375 .30237 L
s
0 .3245 m
.00375 .3245 L
s
0 .36875 m
.00375 .36875 L
s
0 .39088 m
.00375 .39088 L
s
0 .41301 m
.00375 .41301 L
s
0 .43514 m
.00375 .43514 L
s
0 .47939 m
.00375 .47939 L
s
0 .50152 m
.00375 .50152 L
s
0 .52365 m
.00375 .52365 L
s
0 .54577 m
.00375 .54577 L
s
0 .59003 m
.00375 .59003 L
s
0 .61216 m
.00375 .61216 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12535 m
1 .12535 L
s
.99375 .23599 m
1 .23599 L
s
.99375 .34663 m
1 .34663 L
s
.99375 .45726 m
1 .45726 L
s
.99375 .5679 m
1 .5679 L
s
.125 Mabswid
.99625 .03684 m
1 .03684 L
s
.99625 .05897 m
1 .05897 L
s
.99625 .0811 m
1 .0811 L
s
.99625 .10323 m
1 .10323 L
s
.99625 .14748 m
1 .14748 L
s
.99625 .16961 m
1 .16961 L
s
.99625 .19173 m
1 .19173 L
s
.99625 .21386 m
1 .21386 L
s
.99625 .25812 m
1 .25812 L
s
.99625 .28024 m
1 .28024 L
s
.99625 .30237 m
1 .30237 L
s
.99625 .3245 m
1 .3245 L
s
.99625 .36875 m
1 .36875 L
s
.99625 .39088 m
1 .39088 L
s
.99625 .41301 m
1 .41301 L
s
.99625 .43514 m
1 .43514 L
s
.99625 .47939 m
1 .47939 L
s
.99625 .50152 m
1 .50152 L
s
.99625 .52365 m
1 .52365 L
s
.99625 .54577 m
1 .54577 L
s
.99625 .59003 m
1 .59003 L
s
.99625 .61216 m
1 .61216 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.01 w
.02381 .01798 m
.03279 .01903 L
.04262 .02051 L
.05288 .02251 L
.06244 .02488 L
.0828 .03202 L
.09421 .03756 L
.10458 .04377 L
.12373 .0586 L
.14451 .0803 L
.18538 .14053 L
.22473 .21268 L
.24448 .24778 L
.26256 .27531 L
.27184 .28685 L
.28197 .29697 L
.28752 .3013 L
.29267 .30449 L
.2976 .30679 L
.30035 .30774 L
.30285 .3084 L
.30397 .30862 L
.30517 .30883 L
.30649 .30899 L
.30772 .3091 L
.30839 .30914 L
.30911 .30916 L
.31042 .30916 L
.31169 .30911 L
.31287 .30901 L
.31397 .30889 L
.315 .30873 L
.31735 .30825 L
.31963 .30762 L
.3221 .30675 L
.32739 .30425 L
.33296 .30071 L
.34292 .29218 L
.35246 .28162 L
.36266 .26813 L
.38102 .2397 L
.40094 .20614 L
.42252 .17151 L
.43263 .1574 L
.44332 .14469 L
.45246 .13604 L
.45726 .13241 L
.4625 .12924 L
.46521 .12795 L
.46772 .12695 L
Mistroke
.47011 .1262 L
.47134 .12589 L
.47267 .12561 L
.47397 .1254 L
.47518 .12526 L
.47633 .12516 L
.47754 .12512 L
.47863 .12512 L
.47964 .12517 L
.48076 .12526 L
.48195 .1254 L
.48335 .12564 L
.48465 .12593 L
.48757 .1268 L
.49015 .12785 L
.49289 .12923 L
.49762 .13231 L
.50284 .13672 L
.51296 .14837 L
.52223 .16263 L
.5431 .20699 L
.56206 .26058 L
.58278 .33001 L
.62339 .4752 L
.64216 .53282 L
.65204 .55765 L
.66249 .57865 L
.66779 .58701 L
.67362 .59427 L
.67618 .5968 L
.67892 .59906 L
.68149 .60075 L
.68387 .60194 L
.68513 .60242 L
.68646 .60282 L
.68711 .60297 L
.6878 .6031 L
.68857 .60321 L
.68928 .60328 L
.69059 .60332 L
.69124 .6033 L
.69196 .60324 L
.69323 .60306 L
.69442 .6028 L
.69567 .60243 L
.69685 .60198 L
.69907 .6009 L
.70145 .59939 L
.70404 .59734 L
.70892 .59234 L
Mistroke
.71349 .58633 L
.72389 .56812 L
.73402 .54482 L
.74492 .51451 L
.78617 .36997 L
.8259 .22887 L
.84594 .17 L
.86411 .1264 L
.8838 .08971 L
.89472 .07374 L
.90477 .06152 L
.92404 .04381 L
.93416 .037 L
.94486 .03133 L
.95268 .02801 L
.96107 .02511 L
.97619 .02125 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00??ooool3o`0002cooooo1Ol0000/ooooo`;o0000
;Oooool5o`0002kooooo0ol0000Oooooo`00?Oooool00ol0003oooooooooo`0/ooooo`04o`000?oo
ooooooooo`0002_ooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000_oooo
o`03o`000?oooooooooo01kooooo000dooooo`Go000000?oooooo`000?l000000ol0000Vooooo`Go
00000oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooo
ooooool0;?ooool5o`0001oooooo000jooooo`04o`000?ooooooooooo`00033ooooo00?o0000oooo
ooooool0:_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo02_ooooo00Co0000
oooooooooooo00008?ooool003_ooooo00?o0000ooooool00000;Oooool01Ol0003ooooooooooooo
oooo000002_ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000002go
oooo00?o0000ooooool000008?ooool003cooooo0_l0000]ooooo`05o`000?ooooooooooooooool0
0000:oooool01?l0003oooooooooool0000/ooooo`05o`000?ooooooooooooooool00000;_ooool2
o`00023ooooo000mooooo`03o`000?oooooooooo02cooooo0ol0000]ooooo`;o0000;_ooool3o`00
033ooooo00?o0000ooooooooool07_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool001_ooooo00<00000o`000?l00000ool00001o`00004000000Oooool001Co
oooo0_l00005ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool0;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Looooo`4000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`3oooooo`7ooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`03
00000?l0003ooooo0?oooooo0Ol000010000007ooooo000Cooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool00_ooool8o`3o0>gooooo1000o`05ooooo`4000000Oooool001?ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`02ooooo`go0?l0iOooool7003o00Go
oooo0@000001ooooo`005?ooool2o`0000Gooooo00<00000ooooooooool02Oooool9o`3o0>3ooooo
1P00o`08ooooo`4000000Oooool001_ooooo00<00000ooooooooool03_ooool6o`3o0=cooooo1@00
o`0;ooooo`4000000Oooool001_ooooo00<00000o`000?ooool04Oooool4o`3o0=[ooooo1000o`0<
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Cooooo`Go0?l0eOooool4003o
00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0Dooooo`Ko0?l0d_ooool4003o013o
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Gooooo`Co0?l0d?ooool3003o01;ooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Iooooo`?o0?l0c_ooool3003o01?ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0Jooooo`?o0?l0c?ooool3003o01Cooooo0@000001
ooooo`006oooool00`00003o0000ooooo`0Kooooo`?o0?l0b_ooool3003o01Cooooo0Ol000010000
007ooooo000Kooooo`0300000?oooooooooo01cooooo0_l0o`39ooooo`<00?l05_ooool10000007o
oooo000Kooooo`0300000?oooooooooo01cooooo0ol0o`37ooooo`<00?l05oooool10000007ooooo
000Kooooo`0300000?oooooooooo01gooooo0ol0o`35ooooo`<00?l06?ooool10000007ooooo000K
ooooo`0300000?oooooooooo01kooooo0ol0o`33ooooo`<00?l06Oooool10000007ooooo000Koooo
o`0300000?oooooooooo01oooooo0ol0o`32ooooo`800?l06_ooool10000007ooooo000Kooooo`03
00000?l0003ooooo023ooooo0ol0o`30ooooo`<00?l06Oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool08Oooool2o`3o0;oooooo0`00o`0Kooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08Oooool3o`3o0;gooooo0`00o`0Looooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool3o`3o0;cooooo0P00o`0Mooooo`4000000Oooool001_ooooo00<00000oooo
ooooool08oooool3o`3o0;[ooooo0`00o`0Mooooo`4000000Oooool001_ooooo00<00000oooooooo
ool09?ooool2o`3o0;[ooooo0P00o`0Nooooo`4000000Oooool001_ooooo00<00000o`000?ooool0
9?ooool3o`3o0;Sooooo0`00o`0Mooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`0Uooooo`?o0?l0]oooool2003o01oooooo0@000001ooooo`006oooool00`00003oooooooooo`0V
ooooo`?o0?l0]Oooool3003o01oooooo0@000001ooooo`000_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol00005ooooo`0300000?oooooooooo02Oooooo0_l0o`2eoooo
o`800?l08?ooool10000007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool09ooo
ool3o`3o0;?ooooo0`00o`0Pooooo`4000000Oooool00005ooooool0003oooooooooool000002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0
:?ooool3o`3o04cooooo1?l0o`1Rooooo`800?l08?ooool1o`00004000000Oooool00005ooooool0
003oooooooooool000002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;o
oooo00<00000ooooooooool0:Oooool2o`3o04Sooooo2ol0o`1Nooooo`<00?l08Oooool10000007o
oooo00001Ooooooo0000oooooooooooo000000Sooooo00Go0000oooooooooooo0000ooooo`04o`00
00Gooooo00<00000ooooooooool0:Oooool3o`3o04Kooooo1_l0o`000ooooooo0?l0o`3o0004o`3o
05gooooo0P00o`0Rooooo`4000000Oooool00005ooooool0003oooooooooool000002?ooool01_l0
003oooooooooool0003oooooo`0000Sooooo00<00000ooooooooool0:_ooool3o`3o04Cooooo0ol0
o`09ooooo`?o0?l0Foooool3003o02;ooooo0@000001ooooo`000_ooool2o`0000[ooooo0_l00002
ooooo`Go00001?ooool00`00003oooooooooo`0[ooooo`?o0?l0@_ooool3o`3o00_ooooo0ol0o`1J
ooooo`800?l08oooool10000007ooooo000Kooooo`0300000?oooooooooo02cooooo0_l0o`11oooo
o`?o0?l03Oooool3o`3o05Sooooo0`00o`0Sooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0;?ooool3o`3o043ooooo0_l0o`0?ooooo`?o0?l0Eoooool2003o02?ooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo02gooooo0_l0o`0oooooo`?o0?l04?ooool2o`3o05Kooooo
0`00o`0Tooooo`4000000Oooool001_ooooo00<00000ooooooooool0;Oooool3o`3o03gooooo0ol0
o`0Aooooo`?o0?l0EOooool2003o02Gooooo0@000001ooooo`006oooool00`00003oooooooooo`0^
ooooo`;o0?l0??ooool3o`3o01?ooooo0_l0o`1Eooooo`800?l09Oooool10000007ooooo000Koooo
o`0300000?oooooooooo02kooooo0ol0o`0jooooo`?o0?l05?ooool3o`3o05?ooooo0`00o`0Uoooo
o`4000000Oooool001_ooooo00<00000ooooooooool0;oooool2o`3o03Wooooo0ol0o`0Fooooo`;o
0?l0Doooool2003o02Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0_ooooo`?o0?l0
=oooool3o`3o01Oooooo0ol0o`1Aooooo`<00?l09Oooool1o`00004000000Oooool001_ooooo00<0
0000ooooooooool0<?ooool2o`3o03Oooooo0_l0o`0Iooooo`;o0?l0DOooool2003o02Oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0`ooooo`?o0?l0=Oooool3o`3o01Wooooo0ol0o`1?
ooooo`<00?l09oooool10000007ooooo000Kooooo`0300000?oooooooooo037ooooo0ol0o`0doooo
o`;o0?l06oooool2o`3o04oooooo0P00o`0Xooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0<_ooool2o`3o03?ooooo0ol0o`0Kooooo`?o0?l0C_ooool2003o02Sooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0booooo`?o0?l0<Oooool3o`3o01gooooo0_l0o`1=ooooo`<00?l0
:?ooool10000007ooooo000Kooooo`0300000?l0003ooooo03?ooooo0_l0o`0aooooo`;o0?l07_oo
ool3o`3o04cooooo0P00o`0Xooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0c
ooooo`?o0?l0;oooool3o`3o01oooooo0_l0o`1<ooooo`800?l0:Oooool10000007ooooo000Koooo
o`0300000?oooooooooo03Cooooo0_l0o`0_ooooo`;o0?l08?ooool3o`3o04[ooooo0`00o`0Yoooo
o`4000000Oooool001_ooooo00<00000ooooooooool0=?ooool3o`3o02gooooo0ol0o`0Qooooo`;o
0?l0B_ooool2003o02[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0eooooo`;o0?l0
;Oooool2o`3o02;ooooo0ol0o`19ooooo`800?l0:_ooool10000007ooooo000Kooooo`0300000?l0
003ooooo03Gooooo0ol0o`0[ooooo`?o0?l08oooool2o`3o04Sooooo0`00o`0Yooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`0fooooo`;o0?l0:oooool2o`3o02Cooooo0ol0o`17
ooooo`800?l0:oooool10000007ooooo000Kooooo`0300000?oooooooooo03Kooooo0ol0o`0Yoooo
o`?o0?l09Oooool2o`3o04Oooooo0P00o`0[ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0=oooool2o`3o02Sooooo0ol0o`0Vooooo`;o0?l0A_ooool3003o02_ooooo0@000001ooooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00<00000ooooooooool0
=oooool3o`3o02Oooooo0_l0o`0Wooooo`?o0?l0AOooool2003o02cooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0
>?ooool3o`3o02Gooooo0ol0o`0Xooooo`;o0?l0AOooool2003o02cooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000o`000?ooool0
>Oooool2o`3o02Gooooo0_l0o`0Yooooo`;o0?l0AOooool2003o02_ooooo0Ol000010000007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`0iooooo`?o0?l08oooool3o`3o02Wooooo0ol0o`13ooooo`<00?l0;?ooool10000007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`0jooooo`;o0?l08oooool2o`3o02_ooooo0_l0o`13ooooo`800?l0;Oooool10000007ooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`0300000?oooooooooo03[ooooo
0ol0o`0Qooooo`?o0?l0:oooool2o`3o04?ooooo0P00o`0]ooooo`4000000Oooool000Sooooo0_l0
000:ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0>oooool2o`3o023ooooo0ol0
o`0/ooooo`?o0?l0@_ooool2003o02gooooo0@000001ooooo`006oooool00`00003oooooooooo`0k
ooooo`?o0?l07oooool2o`3o02kooooo0_l0o`11ooooo`<00?l0;Oooool10000007ooooo000Koooo
o`0300000?l0003ooooo03cooooo0ol0o`0Mooooo`?o0?l0;_ooool2o`3o047ooooo0P00o`0]oooo
o`7o00000@000001ooooo`006oooool00`00003oooooooooo`0mooooo`?o0?l07?ooool2o`3o02oo
oooo0ol0o`10ooooo`800?l0;_ooool10000007ooooo000Kooooo`0300000?oooooooooo03kooooo
0_l0o`0Kooooo`?o0?l0<?ooool2o`3o03oooooo0`00o`0^ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0?_ooool3o`3o01Wooooo0ol0o`0aooooo`;o0?l0?oooool2003o02oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`0oooooo`?o0?l05oooool3o`3o03;ooooo0ol0o`0n
ooooo`800?l0;oooool10000007ooooo000Kooooo`0300000?oooooooooo043ooooo0_l0o`0Foooo
o`?o0?l0=?ooool2o`3o03kooooo0P00o`0_ooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0@?ooool3o`3o01Cooooo0ol0o`0eooooo`;o0?l0?Oooool3003o02kooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo047ooooo0ol0o`0Cooooo`;o0?l0=_ooool3o`3o03cooooo
0P00o`0`ooooo`4000000Oooool001_ooooo00<00000ooooooooool0@_ooool3o`3o017ooooo0ol0
o`0gooooo`;o0?l0??ooool2003o033ooooo0@000001ooooo`006oooool00`00003oooooooooo`13
ooooo`?o0?l03_ooool4o`3o03Sooooo0_l0o`0looooo`800?l0<?ooool10000007ooooo000Koooo
o`0300000?oooooooooo04Cooooo0ol0o`0<ooooo`Co0?l0>Oooool2o`3o03_ooooo0`00o`0`oooo
o`4000000Oooool001_ooooo00<00000o`000?ooool0AOooool4o`3o00Wooooo0ol0o`0kooooo`?o
0?l0>_ooool2003o033ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo04Kooooo
1?l0o`06ooooo`Co0?l0?Oooool2o`3o03[ooooo0P00o`0aooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0B?ooool;o`3o03kooooo0_l0o`0iooooo`<00?l0<Oooool10000007ooooo000K
ooooo`0300000?oooooooooo04Wooooo2?l0o`10ooooo`;o0?l0>Oooool2003o03;ooooo0@000001
ooooo`006oooool00`00003oooooooooo`2Aooooo`?o0?l0>?ooool2003o03;ooooo0@000001oooo
o`006oooool00`00003oooooooooo`2Booooo`;o0?l0>?ooool2003o03;ooooo0@000001ooooo`00
6oooool00`00003o0000ooooo`2Booooo`;o0?l0=oooool3003o037ooooo0Ol000010000007ooooo
000Kooooo`0300000?oooooooooo09;ooooo0ol0o`0fooooo`800?l0<oooool10000007ooooo000K
ooooo`0300000?oooooooooo09?ooooo0_l0o`0fooooo`800?l0<oooool10000007ooooo0002oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00<00000oooo
ooooool0Toooool2o`3o03Kooooo0P00o`0cooooo`4000000Oooool00005ooooool0003ooooooooo
ool000002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`2Cooooo`;o0?l0=Oooool3003o03?ooooo0@000001ooooo`0000Goooooo`00
0?ooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`2Cooooo`?o0?l0=?ooool2003o03Cooooo0@000001ooooo`0000Goooooo`00
0?ooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0`00003o0000ooooo`2Dooooo`;o0?l0=?ooool2003o03?ooooo0Ol000010000007ooooo00001Ooo
oooo0000oooooooooooo000000Wooooo00Co0000oooooooooooooooo1?l00005ooooo`0300000?oo
oooooooo09Cooooo0_l0o`0cooooo`<00?l0=?ooool10000007ooooo00001Ooooooo0000oooooooo
oooo000000Sooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool0U?oo
ool3o`3o03;ooooo0P00o`0eooooo`4000000Oooool000;ooooo0_l0000:ooooo`04o`000?oooooo
ooooooooo`Go00001?ooool00`00003oooooooooo`2Eooooo`;o0?l0<_ooool2003o03Gooooo0@00
0001ooooo`006oooool00`00003oooooooooo`2Eooooo`;o0?l0<_ooool2003o03Gooooo0@000001
ooooo`006oooool00`00003oooooooooo`2Eooooo`?o0?l0<?ooool3003o03Gooooo0@000001oooo
o`006oooool00`00003o0000ooooo`2Fooooo`;o0?l0<?ooool2003o03Gooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo09Kooooo0_l0o`0`ooooo`800?l0=_ooool10000007ooooo
000Kooooo`0300000?oooooooooo09Kooooo0_l0o`0`ooooo`800?l0=_ooool10000007ooooo000K
ooooo`0300000?oooooooooo09Kooooo0ol0o`0^ooooo`<00?l0=_ooool10000007ooooo000Koooo
o`0300000?oooooooooo09Oooooo0_l0o`0^ooooo`800?l0=oooool10000007ooooo000Kooooo`03
00000?l0003ooooo09Oooooo0_l0o`0^ooooo`800?l0=_ooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool0Uoooool3o`3o02cooooo0`00o`0gooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0V?ooool2o`3o02cooooo0P00o`0hooooo`4000000Oooool001_ooooo00<00000
ooooooooool0V?ooool2o`3o02cooooo0P00o`0hooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0V?ooool3o`3o02_ooooo0P00o`0hooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0VOooool2o`3o02[ooooo0`00o`0hooooo`4000000Oooool001_ooooo00<00000o`000?ooool0
VOooool2o`3o02[ooooo0P00o`0hooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`2Iooooo`;o0?l0:_ooool2003o03Wooooo0@000001ooooo`006oooool00`00003oooooooooo`2I
ooooo`?o0?l0:?ooool3003o03Wooooo0@000001ooooo`006oooool00`00003oooooooooo`2Joooo
o`;o0?l0:?ooool2003o03[ooooo0@000001ooooo`006oooool00`00003oooooooooo`2Jooooo`;o
0?l0:?ooool2003o03[ooooo0@000001ooooo`006oooool00`00003oooooooooo`2Jooooo`?o0?l0
9oooool2003o03[ooooo0@000001ooooo`006oooool00`00003o0000ooooo`2Kooooo`;o0?l09_oo
ool3003o03Wooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo09_ooooo0_l0o`0V
ooooo`800?l0>oooool10000007ooooo000Kooooo`0300000?oooooooooo09_ooooo0_l0o`0Voooo
o`800?l0>oooool10000007ooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`00
00Cooooo00<00000ooooooooool0Voooool3o`3o02Cooooo0`00o`0kooooo`4000000Oooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo09cooooo0_l0o`0Tooooo`800?l0??ooool10000007ooooo0007ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`2Looooo`;o0?l09?ooool2
003o03cooooo0@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00<00000o`000?ooool0W?ooool3o`3o02;ooooo0`00o`0kooooo`7o00000@000001
ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00`00003oooooooooo`2Mooooo`;o0?l08_ooool2003o03gooooo0@000001ooooo`001oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00`00003ooooo
ooooo`2Mooooo`;o0?l08_ooool2003o03gooooo0@000001ooooo`002?ooool2o`0000Wooooo0ol0
0005ooooo`0300000?oooooooooo09gooooo0ol0o`0Qooooo`800?l0?Oooool10000007ooooo000K
ooooo`0300000?oooooooooo09kooooo0_l0o`0Pooooo`<00?l0?Oooool10000007ooooo000Koooo
o`0300000?l0003ooooo09kooooo0_l0o`0Pooooo`800?l0?Oooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool0W_ooool2o`3o023ooooo0P00o`0nooooo`4000000Oooool001_ooooo
00<00000ooooooooool0W_ooool3o`3o01kooooo0`00o`0nooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0Woooool2o`3o01kooooo0P00o`0oooooo`4000000Oooool001_ooooo00<00000
ooooooooool0Woooool2o`3o01kooooo0P00o`0oooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0Woooool2o`3o01kooooo0P00o`0oooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0Woooool3o`3o01cooooo0`00o`0nooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`2Pooooo`;o0?l07?ooool2003o043ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`2Pooooo`;o0?l07?ooool2003o043ooooo0@000001ooooo`006oooool00`00003oooooooooo`2P
ooooo`?o0?l06_ooool3003o043ooooo0@000001ooooo`006oooool00`00003oooooooooo`2Qoooo
o`;o0?l06_ooool2003o047ooooo0@000001ooooo`006oooool00`00003oooooooooo`2Qooooo`;o
0?l06_ooool2003o047ooooo0@000001ooooo`006oooool00`00003o0000ooooo`2Qooooo`;o0?l0
6Oooool3003o043ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo0:7ooooo0ol0
o`0Hooooo`800?l0@_ooool10000007ooooo000Kooooo`0300000?oooooooooo0:;ooooo0_l0o`0G
ooooo`<00?l0@_ooool10000007ooooo000Kooooo`0300000?oooooooooo0:;ooooo0_l0o`0Goooo
o`800?l0@oooool10000007ooooo000Kooooo`0300000?oooooooooo0:;ooooo0ol0o`0Fooooo`80
0?l0@oooool10000007ooooo000Kooooo`0300000?oooooooooo0:?ooooo0_l0o`0Eooooo`<00?l0
@oooool10000007ooooo000Kooooo`0300000?l0003ooooo0:?ooooo0ol0o`0Dooooo`800?l0@ooo
ool1o`00004000000Oooool001_ooooo00<00000ooooooooool0Y?ooool2o`3o01?ooooo0`00o`14
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0Y?ooool2o`3o01?ooooo0P00o`15oooo
o`4000000Oooool000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`00
00Gooooo00<00000ooooooooool0Y?ooool3o`3o01;ooooo0P00o`15ooooo`4000000Oooool00005
ooooool0003oooooooooool000002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`2Uooooo`;o0?l04Oooool3003o04Gooooo0@00
0001ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00`00003o0000ooooo`2Uooooo`?o0?l04?ooool2003o04Gooooo0Ol0
00010000007ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo0:Kooooo0ol0o`0?ooooo`800?l0A_oo
ool10000007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Ko0000oooooooooooooooo
o`000?ooool4o`0000Gooooo00<00000ooooooooool0Yoooool2o`3o00kooooo0`00o`16ooooo`40
00000Oooool00005ooooool0003oooooooooool000001oooool01ol0003ooooooooooooooooo0000
ooooool000002?ooool00`00003oooooooooo`2Wooooo`?o0?l03?ooool3003o04Oooooo0@000001
ooooo`000_ooool2o`0000Wooooo0ol00002ooooo`Go00001?ooool00`00003oooooooooo`2Xoooo
o`;o0?l03?ooool2003o04Sooooo0@000001ooooo`006oooool00`00003oooooooooo`2Xooooo`?o
0?l02_ooool3003o04Sooooo0@000001ooooo`006oooool00`00003o0000ooooo`2Yooooo`?o0?l0
2Oooool2003o04Sooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo0:[ooooo0ol0
o`07ooooo`<00?l0BOooool10000007ooooo000Kooooo`0300000?oooooooooo0:_ooooo0ol0o`05
ooooo`03o`3o0000o`000?l004[ooooo0@000001ooooo`006oooool00`00003oooooooooo`2[oooo
o`[o0?l0Boooool10000007ooooo000Kooooo`0300000?oooooooooo0:gooooo1ol0o`1<ooooo`40
00000Oooool001_ooooo00<00000ooooooooool0[_ooool3o`3o04oooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`7o00000@000001ooooo`006ooooooo000000D000000Oooool0
0?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.35193, -0.0316511, \
0.0404426, 0.00174068}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate labeled data from mixture model", "Subsubsection"],

Cell[BoxData[{
    \(\(n\  = \ 100;\)\), "\n", 
    \(\(data\  = \ RandomMixtureModel1D[params1, n];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize generated data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotDataLabeled1D[data, Red, \ Blue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25092 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.470003 0.119487 0.00597436 0.119487 [
[.23103 -0.00653 -6 -9 ]
[.23103 -0.00653 6 0 ]
[.47 -0.00653 -3 -9 ]
[.47 -0.00653 3 0 ]
[.70898 -0.00653 -3 -9 ]
[.70898 -0.00653 3 0 ]
[.94795 -0.00653 -3 -9 ]
[.94795 -0.00653 3 0 ]
[ 0 0 0 0 ]
[ 1 .25092 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23103 .00597 m
.23103 .01222 L
s
[(-2)] .23103 -0.00653 0 1 Mshowa
.47 .00597 m
.47 .01222 L
s
[(0)] .47 -0.00653 0 1 Mshowa
.70898 .00597 m
.70898 .01222 L
s
[(2)] .70898 -0.00653 0 1 Mshowa
.94795 .00597 m
.94795 .01222 L
s
[(4)] .94795 -0.00653 0 1 Mshowa
.125 Mabswid
.0518 .00597 m
.0518 .00972 L
s
.11154 .00597 m
.11154 .00972 L
s
.17128 .00597 m
.17128 .00972 L
s
.29077 .00597 m
.29077 .00972 L
s
.35052 .00597 m
.35052 .00972 L
s
.41026 .00597 m
.41026 .00972 L
s
.52975 .00597 m
.52975 .00972 L
s
.58949 .00597 m
.58949 .00972 L
s
.64923 .00597 m
.64923 .00972 L
s
.76872 .00597 m
.76872 .00972 L
s
.82846 .00597 m
.82846 .00972 L
s
.88821 .00597 m
.88821 .00972 L
s
.25 Mabswid
0 .00597 m
1 .00597 L
s
1 0 0 r
.02 w
.26313 .12546 Mdot
0 0 1 r
.84512 .12546 Mdot
.63012 .12546 Mdot
.60876 .12546 Mdot
.75578 .12546 Mdot
1 0 0 r
.1715 .12546 Mdot
.41262 .12546 Mdot
0 0 1 r
.6475 .12546 Mdot
.63727 .12546 Mdot
.64287 .12546 Mdot
.7617 .12546 Mdot
1 0 0 r
.29877 .12546 Mdot
.31896 .12546 Mdot
.37318 .12546 Mdot
.14515 .12546 Mdot
0 0 1 r
.84578 .12546 Mdot
.63862 .12546 Mdot
1 0 0 r
.27692 .12546 Mdot
0 0 1 r
.57351 .12546 Mdot
.73941 .12546 Mdot
.58441 .12546 Mdot
1 0 0 r
.18933 .12546 Mdot
0 0 1 r
.5489 .12546 Mdot
.69336 .12546 Mdot
.52234 .12546 Mdot
1 0 0 r
.43705 .12546 Mdot
0 0 1 r
.63035 .12546 Mdot
1 0 0 r
.02381 .12546 Mdot
.20698 .12546 Mdot
.32594 .12546 Mdot
.27608 .12546 Mdot
.03568 .12546 Mdot
0 0 1 r
.39271 .12546 Mdot
.80563 .12546 Mdot
.74201 .12546 Mdot
.60523 .12546 Mdot
.87492 .12546 Mdot
1 0 0 r
.27883 .12546 Mdot
0 0 1 r
.56937 .12546 Mdot
.73592 .12546 Mdot
.74662 .12546 Mdot
1 0 0 r
.27487 .12546 Mdot
.33166 .12546 Mdot
.21258 .12546 Mdot
.13126 .12546 Mdot
0 0 1 r
.5858 .12546 Mdot
.97619 .12546 Mdot
.66526 .12546 Mdot
1 0 0 r
.15104 .12546 Mdot
.08941 .12546 Mdot
.16364 .12546 Mdot
0 0 1 r
.80431 .12546 Mdot
.75378 .12546 Mdot
.68845 .12546 Mdot
1 0 0 r
.35907 .12546 Mdot
.2206 .12546 Mdot
0 0 1 r
.59368 .12546 Mdot
1 0 0 r
.38404 .12546 Mdot
.20853 .12546 Mdot
.23045 .12546 Mdot
.10297 .12546 Mdot
0 0 1 r
.8963 .12546 Mdot
.82014 .12546 Mdot
.7307 .12546 Mdot
.62574 .12546 Mdot
.49952 .12546 Mdot
1 0 0 r
.03584 .12546 Mdot
.3839 .12546 Mdot
.27101 .12546 Mdot
0 0 1 r
.91121 .12546 Mdot
.85129 .12546 Mdot
.59516 .12546 Mdot
.69069 .12546 Mdot
.9232 .12546 Mdot
1 0 0 r
.21503 .12546 Mdot
0 0 1 r
.67059 .12546 Mdot
.71761 .12546 Mdot
1 0 0 r
.36473 .12546 Mdot
0 0 1 r
.67713 .12546 Mdot
1 0 0 r
.19689 .12546 Mdot
.17629 .12546 Mdot
0 0 1 r
.65163 .12546 Mdot
.76467 .12546 Mdot
.77811 .12546 Mdot
.74992 .12546 Mdot
.63149 .12546 Mdot
1 0 0 r
.27914 .12546 Mdot
0 0 1 r
.54209 .12546 Mdot
.68519 .12546 Mdot
.69117 .12546 Mdot
1 0 0 r
.35709 .12546 Mdot
0 0 1 r
.85939 .12546 Mdot
1 0 0 r
.16048 .12546 Mdot
.28884 .12546 Mdot
.38674 .12546 Mdot
0 0 1 r
.72521 .12546 Mdot
1 0 0 r
.16911 .12546 Mdot
0 0 1 r
.68384 .12546 Mdot
1 0 0 r
.20925 .12546 Mdot
0 0 1 r
.71175 .12546 Mdot
0 0 m
1 0 L
1 .25092 L
0 .25092 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 72.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000B2000`400?l00000o`00003ooooooolQ
ooooo`00C_ooool5o`0003Cooooo0_l0000fooooo`Go0000=_ooool3o`0002?ooooo001?ooooo`04
o`000?ooooooooooo`0003?ooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0
000gooooo`03o`000?oooooooooo02;ooooo0018ooooo`Go00000oooool00ol0003oooooooooo`0c
ooooo`04o`000?ooooooooooo`0003Oooooo00?o0000ooooooooool0=?ooool5o`0002?ooooo001A
ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo0000>?ooool00ol0003ooooooooo
o`0cooooo`04o`000?ooooooooooo`0002Cooooo001>ooooo`05o`000?ooooooooooooooool00000
<oooool01?l0003oooooooooool0000eooooo`05o`000?ooooooooooooooool00000=Oooool00ol0
003oooooo`00000Tooooo`00C_ooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooo
oooooooo0000=Oooool01Ol0003ooooooooooooooooo000003Kooooo0_l0000Tooooo`00Coooool3
o`0003Gooooo0_l0000gooooo`?o0000>?ooool00ol0003oooooooooo`0Rooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005_oooooco`0001Oooooo000Soooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`0300000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02;ooooo001>ooooo`0300000?oooooooooo03Oooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02;ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Kooooo`;oo`00
00?oooooool00?oo00002oooool2ool00003oooooooo003oo`0000Gooooo0_oo00000oooooooo`00
ool00008ool00003oooooooo003oo`0000[oo`001_ooool:ool000?ooooo1Ooo0005ooooo`Goo`00
00Goooooool00?oo003oo`00o`00o`03ooooo`;oo`001?ooool2ool000gooooo0_l00?l4ooooo`;o
003o0_ooool4o`00o`?ooooo0ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00?o
oooo2?l00?l00ooooooo003oo`00o`07o`00o`;ooooo3ol00?l00ooooooo003oo`00o`05ooooo`;o
003o0_ooool2o`00o`Cooooo1Ol00?l2ooooo`;o003o0oooool2o`00o`;ooooo1?l00?l;ooooo`;o
003o7Oooool001[ooooo1ooo0009ooooo`Ooo`000ooooolLool000Cooooo3?oo00000oooooooo`00
ool00005ool000?ooooo2ooo00000ol00?ooooooool00003ool000;ooooo1?oo000;ooooo`Co003o
0_ooool:o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool00?l09_l00?l3ooooo`So003o
0_ooool;o`00o`03ooooool00?oo003o00So003o2Oooool4o`00oacooooo000Jooooo`Ooo`002Ooo
ool7ool000?ooooo7?oo0004ooooo`coo`0000?oooooool00?oo00001Ooo0003ooooo`_oo`0000?o
003ooooooooo00000ooo0002ooooo`Coo`002oooool4o`00o`;ooooo2_l00?l00ooooooo003oo`00
o`0;o`00o`03ooooool00?oo003o02Ko003o0oooool8o`00o`;ooooo2ol00?l00ooooooo003oo`00
o`08o`00o`Wooooo1?l00?lLooooo`006oooool2ool00003oooooooo003oo`0000_ooooo0_oo0000
0oooooooo`00ool00005ooooo`;oo`0000?oooooool00?oo00002?oo00000oooooooo`00ool0000:
ool000Kooooo2_oo0003ooooo`Goo`001Oooool5ool00005oooooooo003oo`00ool00?l00?l00ooo
ool2ool000Cooooo0_oo000=ooooo`;o003o1?ooool2o`00o`;ooooo1?l00?l3ooooo`?o003o00?o
ooooo`00ool00?l00_l00?l00ooooooo003oo`00o`03ooooo`So003o00?oooooo`00ool00?l01ol0
0?l2ooooo`oo003o00?oooooo`00ool00?l01Oooool2o`00o`;ooooo0_l00?l4ooooo`Go003o0_oo
ool2o`00o`?ooooo0_l00?l2ooooo`Co003o2oooool2o`00oagooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {71.25, 0}} -> {-4.71589, -0.416177, \
0.0346128, 0.0346128}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log likelihood of data as a function of \[Mu]1 and \
\[Mu]2\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \({est1, est2} = PlotLogLikelihoodLocal2[data, params2]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.5 0.0793651 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -3 -9 ]
[.81746 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .18254 -12 -4.5 ]
[-0.0125 .18254 0 4.5 ]
[-0.0125 .34127 -12 -4.5 ]
[-0.0125 .34127 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .65873 -6 -4.5 ]
[-0.0125 .65873 0 4.5 ]
[-0.0125 .81746 -6 -4.5 ]
[-0.0125 .81746 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-6)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-4)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-2)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(4)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(6)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-6)] -0.0125 .02381 1 0 Mshowa
0 .18254 m
.00625 .18254 L
s
[(-4)] -0.0125 .18254 1 0 Mshowa
0 .34127 m
.00625 .34127 L
s
[(-2)] -0.0125 .34127 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .65873 m
.00625 .65873 L
s
[(2)] -0.0125 .65873 1 0 Mshowa
0 .81746 m
.00625 .81746 L
s
[(4)] -0.0125 .81746 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(6)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .06349 m
.00375 .06349 L
s
0 .10317 m
.00375 .10317 L
s
0 .14286 m
.00375 .14286 L
s
0 .22222 m
.00375 .22222 L
s
0 .2619 m
.00375 .2619 L
s
0 .30159 m
.00375 .30159 L
s
0 .38095 m
.00375 .38095 L
s
0 .42063 m
.00375 .42063 L
s
0 .46032 m
.00375 .46032 L
s
0 .53968 m
.00375 .53968 L
s
0 .57937 m
.00375 .57937 L
s
0 .61905 m
.00375 .61905 L
s
0 .69841 m
.00375 .69841 L
s
0 .7381 m
.00375 .7381 L
s
0 .77778 m
.00375 .77778 L
s
0 .85714 m
.00375 .85714 L
s
0 .89683 m
.00375 .89683 L
s
0 .93651 m
.00375 .93651 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.18254 .99375 m
.18254 1 L
s
.34127 .99375 m
.34127 1 L
s
.5 .99375 m
.5 1 L
s
.65873 .99375 m
.65873 1 L
s
.81746 .99375 m
.81746 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.06349 .99625 m
.06349 1 L
s
.10317 .99625 m
.10317 1 L
s
.14286 .99625 m
.14286 1 L
s
.22222 .99625 m
.22222 1 L
s
.2619 .99625 m
.2619 1 L
s
.30159 .99625 m
.30159 1 L
s
.38095 .99625 m
.38095 1 L
s
.42063 .99625 m
.42063 1 L
s
.46032 .99625 m
.46032 1 L
s
.53968 .99625 m
.53968 1 L
s
.57937 .99625 m
.57937 1 L
s
.61905 .99625 m
.61905 1 L
s
.69841 .99625 m
.69841 1 L
s
.7381 .99625 m
.7381 1 L
s
.77778 .99625 m
.77778 1 L
s
.85714 .99625 m
.85714 1 L
s
.89683 .99625 m
.89683 1 L
s
.93651 .99625 m
.93651 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .18254 m
1 .18254 L
s
.99375 .34127 m
1 .34127 L
s
.99375 .5 m
1 .5 L
s
.99375 .65873 m
1 .65873 L
s
.99375 .81746 m
1 .81746 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .06349 m
1 .06349 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .22222 m
1 .22222 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30159 m
1 .30159 L
s
.99625 .38095 m
1 .38095 L
s
.99625 .42063 m
1 .42063 L
s
.99625 .46032 m
1 .46032 L
s
.99625 .53968 m
1 .53968 L
s
.99625 .57937 m
1 .57937 L
s
.99625 .61905 m
1 .61905 L
s
.99625 .69841 m
1 .69841 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .77778 m
1 .77778 L
s
.99625 .85714 m
1 .85714 L
s
.99625 .89683 m
1 .89683 L
s
.99625 .93651 m
1 .93651 L
s
.25 Mabswid
1 0 m
1 1 L
s
.7 g
.02381 .97619 m
.97619 .97619 L
.97619 .02381 L
.02381 .02381 L
F
.8 g
.02381 .45049 m
.05665 .44802 L
.08949 .44531 L
.12233 .44239 L
.15517 .4393 L
.18801 .43621 L
.22085 .4334 L
.25369 .43116 L
.28654 .42976 L
.31938 .42935 L
.35222 .42986 L
.38506 .43039 L
.4179 .42698 L
.43649 .4179 L
.4447 .38506 L
.44621 .35222 L
.44745 .31938 L
.45001 .28654 L
.45074 .27936 L
.45418 .25369 L
.45992 .22085 L
.46719 .18801 L
.47606 .15517 L
.48358 .13157 L
.48651 .12233 L
.49853 .08949 L
.51642 .05762 L
.51707 .05665 L
.54926 .03236 L
.5821 .03843 L
.61494 .05418 L
.62014 .05665 L
.64778 .07411 L
.67223 .08949 L
.68062 .09537 L
.71346 .11849 L
.71875 .12233 L
.74631 .14283 L
.76237 .15517 L
.77915 .16942 L
.79782 .18801 L
.81199 .20501 L
.82357 .22085 L
.84433 .25369 L
.84483 .25453 L
.86375 .28654 L
.87767 .30857 L
.88513 .31938 L
.91051 .35054 L
.91207 .35222 L
.94335 .38079 L
.94898 .38506 L
.97619 .40155 L
.97619 .97619 L
.02381 .97619 L
F
0 g
.5 Mabswid
.02381 .45049 m
.05665 .44802 L
.08949 .44531 L
.12233 .44239 L
.15517 .4393 L
.18801 .43621 L
.22085 .4334 L
.25369 .43116 L
.28654 .42976 L
.31938 .42935 L
.35222 .42986 L
.38506 .43039 L
.4179 .42698 L
.43649 .4179 L
.4447 .38506 L
.44621 .35222 L
.44745 .31938 L
.45001 .28654 L
.45074 .27936 L
.45418 .25369 L
.45992 .22085 L
.46719 .18801 L
.47606 .15517 L
.48358 .13157 L
.48651 .12233 L
.49853 .08949 L
.51642 .05762 L
.51707 .05665 L
.54926 .03236 L
.5821 .03843 L
.61494 .05418 L
.62014 .05665 L
.64778 .07411 L
.67223 .08949 L
.68062 .09537 L
.71346 .11849 L
.71875 .12233 L
.74631 .14283 L
.76237 .15517 L
.77915 .16942 L
.79782 .18801 L
.81199 .20501 L
.82357 .22085 L
.84433 .25369 L
.84483 .25453 L
.86375 .28654 L
.87767 .30857 L
.88513 .31938 L
.91051 .35054 L
.91207 .35222 L
Mistroke
.94335 .38079 L
.94898 .38506 L
.97619 .40155 L
Mfstroke
.7 g
.02381 .64516 m
.02739 .64778 L
.05665 .67252 L
.06577 .68062 L
.08949 .70424 L
.09842 .71346 L
.12233 .73828 L
.13016 .74631 L
.15517 .77276 L
.16128 .77915 L
.18801 .80436 L
.19745 .81199 L
.22085 .82831 L
.24996 .84483 L
.25369 .84674 L
.28654 .86238 L
.31938 .87722 L
.32033 .87767 L
.35222 .89312 L
.38389 .91051 L
.38506 .91117 L
.4179 .93149 L
.4307 .94335 L
.45074 .95386 L
.48358 .97131 L
.51642 .96109 L
.52962 .94335 L
.54661 .91051 L
.54926 .8998 L
.55712 .87767 L
.56694 .84483 L
.57537 .81199 L
.5821 .78196 L
.5827 .77915 L
.58891 .74631 L
.59362 .71346 L
.59695 .68062 L
.60082 .64778 L
.61494 .62151 L
.63858 .61494 L
.64778 .6139 L
.68062 .61282 L
.71346 .61224 L
.74631 .61104 L
.77915 .60918 L
.81199 .60686 L
.84483 .60427 L
.87767 .60153 L
.91051 .5988 L
.94335 .59623 L
.97619 .59401 L
.97619 .97619 L
.02381 .97619 L
F
0 g
.02381 .64516 m
.02739 .64778 L
.05665 .67252 L
.06577 .68062 L
.08949 .70424 L
.09842 .71346 L
.12233 .73828 L
.13016 .74631 L
.15517 .77276 L
.16128 .77915 L
.18801 .80436 L
.19745 .81199 L
.22085 .82831 L
.24996 .84483 L
.25369 .84674 L
.28654 .86238 L
.31938 .87722 L
.32033 .87767 L
.35222 .89312 L
.38389 .91051 L
.38506 .91117 L
.4179 .93149 L
.4307 .94335 L
.45074 .95386 L
.48358 .97131 L
.51642 .96109 L
.52962 .94335 L
.54661 .91051 L
.54926 .8998 L
.55712 .87767 L
.56694 .84483 L
.57537 .81199 L
.5821 .78196 L
.5827 .77915 L
.58891 .74631 L
.59362 .71346 L
.59695 .68062 L
.60082 .64778 L
.61494 .62151 L
.63858 .61494 L
.64778 .6139 L
.68062 .61282 L
.71346 .61224 L
.74631 .61104 L
.77915 .60918 L
.81199 .60686 L
.84483 .60427 L
.87767 .60153 L
.91051 .5988 L
.94335 .59623 L
Mistroke
.97619 .59401 L
Mfstroke
.6 g
.02381 .37158 m
.05665 .37119 L
.08949 .3706 L
.12233 .36984 L
.15517 .36893 L
.18801 .3679 L
.22085 .36681 L
.25369 .36576 L
.28654 .36476 L
.31938 .36335 L
.35222 .35788 L
.36416 .35222 L
.37763 .31938 L
.38126 .28654 L
.38421 .25369 L
.38506 .2445 L
.38728 .22085 L
.39048 .18801 L
.3936 .15517 L
.3964 .12233 L
.39874 .08949 L
.40064 .05665 L
.40217 .02381 L
.02381 .02381 L
F
0 g
.02381 .37158 m
.05665 .37119 L
.08949 .3706 L
.12233 .36984 L
.15517 .36893 L
.18801 .3679 L
.22085 .36681 L
.25369 .36576 L
.28654 .36476 L
.31938 .36335 L
.35222 .35788 L
.36416 .35222 L
.37763 .31938 L
.38126 .28654 L
.38421 .25369 L
.38506 .2445 L
.38728 .22085 L
.39048 .18801 L
.3936 .15517 L
.3964 .12233 L
.39874 .08949 L
.40064 .05665 L
.40217 .02381 L
s
.5 g
.02381 .32064 m
.05665 .3205 L
.08949 .32027 L
.12233 .31991 L
.15517 .31941 L
.15717 .31938 L
.18801 .31875 L
.22085 .31792 L
.25369 .31679 L
.28654 .31476 L
.31938 .3019 L
.32603 .28654 L
.33164 .25369 L
.33462 .22085 L
.33701 .18801 L
.33899 .15517 L
.34055 .12233 L
.34173 .08949 L
.34258 .05665 L
.34316 .02381 L
.02381 .02381 L
F
0 g
.02381 .32064 m
.05665 .3205 L
.08949 .32027 L
.12233 .31991 L
.15517 .31941 L
.15717 .31938 L
.18801 .31875 L
.22085 .31792 L
.25369 .31679 L
.28654 .31476 L
.31938 .3019 L
.32603 .28654 L
.33164 .25369 L
.33462 .22085 L
.33701 .18801 L
.33899 .15517 L
.34055 .12233 L
.34173 .08949 L
.34258 .05665 L
.34316 .02381 L
s
.6 g
.02381 .7525 m
.05556 .77915 L
.05665 .78008 L
.08949 .80948 L
.09212 .81199 L
.12233 .84095 L
.12661 .84483 L
.15517 .86809 L
.16879 .87767 L
.18801 .89005 L
.22085 .90929 L
.22299 .91051 L
.25369 .92839 L
.27674 .94335 L
.28654 .95045 L
.31602 .97619 L
.02381 .97619 L
F
0 g
.02381 .7525 m
.05556 .77915 L
.05665 .78008 L
.08949 .80948 L
.09212 .81199 L
.12233 .84095 L
.12661 .84483 L
.15517 .86809 L
.16879 .87767 L
.18801 .89005 L
.22085 .90929 L
.22299 .91051 L
.25369 .92839 L
.27674 .94335 L
.28654 .95045 L
.31602 .97619 L
s
.4 g
.02381 .28004 m
.05665 .27997 L
.08949 .27982 L
.12233 .27957 L
.15517 .27917 L
.18801 .27855 L
.22085 .27755 L
.25369 .27574 L
.28563 .25369 L
.28654 .24798 L
.29113 .22085 L
.29391 .18801 L
.29572 .15517 L
.29696 .12233 L
.29778 .08949 L
.29831 .05665 L
.29861 .02381 L
.02381 .02381 L
F
0 g
.02381 .28004 m
.05665 .27997 L
.08949 .27982 L
.12233 .27957 L
.15517 .27917 L
.18801 .27855 L
.22085 .27755 L
.25369 .27574 L
.28563 .25369 L
.28654 .24798 L
.29113 .22085 L
.29391 .18801 L
.29572 .15517 L
.29696 .12233 L
.29778 .08949 L
.29831 .05665 L
.29861 .02381 L
s
.3 g
.02381 .24532 m
.05665 .24527 L
.08949 .24515 L
.12233 .24491 L
.15517 .24447 L
.18801 .24367 L
.22085 .24231 L
.25254 .22085 L
.25369 .2083 L
.25643 .18801 L
.25878 .15517 L
.26008 .12233 L
.26083 .08949 L
.26125 .05665 L
.26147 .02381 L
.02381 .02381 L
F
0 g
.02381 .24532 m
.05665 .24527 L
.08949 .24515 L
.12233 .24491 L
.15517 .24447 L
.18801 .24367 L
.22085 .24231 L
.25254 .22085 L
.25369 .2083 L
.25643 .18801 L
.25878 .15517 L
.26008 .12233 L
.26083 .08949 L
.26125 .05665 L
.26147 .02381 L
s
.2 g
.02381 .2145 m
.05665 .21444 L
.08949 .21432 L
.12233 .21403 L
.15517 .21344 L
.18801 .21266 L
.22082 .18801 L
.22085 .18707 L
.22569 .15517 L
.22746 .12233 L
.22833 .08949 L
.22875 .05665 L
.22895 .02381 L
.02381 .02381 L
F
0 g
.02381 .2145 m
.05665 .21444 L
.08949 .21432 L
.12233 .21403 L
.15517 .21344 L
.18801 .21266 L
.22082 .18801 L
.22085 .18707 L
.22569 .15517 L
.22746 .12233 L
.22833 .08949 L
.22875 .05665 L
.22895 .02381 L
s
.5 g
.02381 .82926 m
.04251 .84483 L
.05665 .85767 L
.0782 .87767 L
.08949 .88766 L
.11819 .91051 L
.12233 .91351 L
.15517 .93552 L
.16763 .94335 L
.18801 .95606 L
.21811 .97619 L
.02381 .97619 L
F
0 g
.02381 .82926 m
.04251 .84483 L
.05665 .85767 L
.0782 .87767 L
.08949 .88766 L
.11819 .91051 L
.12233 .91351 L
.15517 .93552 L
.16763 .94335 L
.18801 .95606 L
.21811 .97619 L
s
.1 g
.02381 .18649 m
.05665 .18643 L
.08949 .18625 L
.12233 .18583 L
.15517 .18504 L
.18801 .16988 L
.19455 .15517 L
.19772 .12233 L
.19893 .08949 L
.19945 .05665 L
.19967 .02381 L
.02381 .02381 L
F
0 g
.02381 .18649 m
.05665 .18643 L
.08949 .18625 L
.12233 .18583 L
.15517 .18504 L
.18801 .16988 L
.19455 .15517 L
.19772 .12233 L
.19893 .08949 L
.19945 .05665 L
.19967 .02381 L
s
.02381 .16063 m
.05665 .16054 L
.08949 .16027 L
.12233 .15939 L
.15 .15517 L
.15517 .15259 L
.17016 .12233 L
.1718 .08949 L
.17254 .05665 L
.17282 .02381 L
.02381 .02381 L
F
.02381 .16063 m
.05665 .16054 L
.08949 .16027 L
.12233 .15939 L
.15 .15517 L
.15517 .15259 L
.17016 .12233 L
.1718 .08949 L
.17254 .05665 L
.17282 .02381 L
s
.4 g
.02381 .89416 m
.04185 .91051 L
.05665 .92345 L
.08163 .94335 L
.08949 .9491 L
.12233 .97155 L
.12936 .97619 L
.02381 .97619 L
F
0 g
.02381 .89416 m
.04185 .91051 L
.05665 .92345 L
.08163 .94335 L
.08949 .9491 L
.12233 .97155 L
.12936 .97619 L
s
.3 g
.02381 .95222 m
.054 .97619 L
.02381 .97619 L
F
0 g
.02381 .95222 m
.054 .97619 L
s
.9 g
.28654 .54265 m
.31938 .53844 L
.35222 .53991 L
.38506 .54744 L
.39086 .54926 L
.4179 .56222 L
.44224 .5821 L
.45074 .59055 L
.46437 .61494 L
.47389 .64778 L
.47384 .68062 L
.46373 .71346 L
.45074 .73409 L
.43781 .74631 L
.4179 .75695 L
.38506 .76504 L
.35222 .76446 L
.31938 .75705 L
.29257 .74631 L
.28654 .74208 L
.25369 .71425 L
.25302 .71346 L
.22959 .68062 L
.22085 .6634 L
.21457 .64778 L
.209 .61494 L
.21918 .5821 L
.22085 .57889 L
.25369 .55284 L
.2626 .54926 L
F
0 g
.28654 .54265 m
.31938 .53844 L
.35222 .53991 L
.38506 .54744 L
.39086 .54926 L
.4179 .56222 L
.44224 .5821 L
.45074 .59055 L
.46437 .61494 L
.47389 .64778 L
.47384 .68062 L
.46373 .71346 L
.45074 .73409 L
.43781 .74631 L
.4179 .75695 L
.38506 .76504 L
.35222 .76446 L
.31938 .75705 L
.29257 .74631 L
.28654 .74208 L
.25369 .71425 L
.25302 .71346 L
.22959 .68062 L
.22085 .6634 L
.21457 .64778 L
.209 .61494 L
.21918 .5821 L
.22085 .57889 L
.25369 .55284 L
.2626 .54926 L
.28654 .54265 L
s
.9 g
.61494 .24567 m
.64778 .2405 L
.68062 .2479 L
.69276 .25369 L
.71346 .26756 L
.73188 .28654 L
.74631 .31047 L
.75048 .31938 L
.76277 .35222 L
.76977 .38506 L
.7707 .4179 L
.75929 .45074 L
.74631 .4654 L
.71346 .4804 L
.69371 .48358 L
.68062 .48406 L
.67184 .48358 L
.64778 .47921 L
.61494 .46365 L
.59849 .45074 L
.5821 .42922 L
.57578 .4179 L
.56342 .38506 L
.55899 .35222 L
.56148 .31938 L
.57256 .28654 L
.5821 .27105 L
.60041 .25369 L
F
0 g
.61494 .24567 m
.64778 .2405 L
.68062 .2479 L
.69276 .25369 L
.71346 .26756 L
.73188 .28654 L
.74631 .31047 L
.75048 .31938 L
.76277 .35222 L
.76977 .38506 L
.7707 .4179 L
.75929 .45074 L
.74631 .4654 L
.71346 .4804 L
.69371 .48358 L
.68062 .48406 L
.67184 .48358 L
.64778 .47921 L
.61494 .46365 L
.59849 .45074 L
.5821 .42922 L
.57578 .4179 L
.56342 .38506 L
.55899 .35222 L
.56148 .31938 L
.57256 .28654 L
.5821 .27105 L
.60041 .25369 L
.61494 .24567 L
s
.6 g
.97619 .67261 m
.94335 .673 L
.91051 .67357 L
.87767 .67432 L
.84483 .67525 L
.81199 .67633 L
.77915 .67757 L
.74631 .67909 L
.724 .68062 L
.71346 .68164 L
.68062 .69161 L
.66867 .71346 L
.66258 .74631 L
.6583 .77915 L
.65451 .81199 L
.65114 .84483 L
.6482 .87767 L
.64778 .88266 L
.64572 .91051 L
.64367 .94335 L
.64209 .97619 L
.97619 .97619 L
F
0 g
.97619 .67261 m
.94335 .673 L
.91051 .67357 L
.87767 .67432 L
.84483 .67525 L
.81199 .67633 L
.77915 .67757 L
.74631 .67909 L
.724 .68062 L
.71346 .68164 L
.68062 .69161 L
.66867 .71346 L
.66258 .74631 L
.6583 .77915 L
.65451 .81199 L
.65114 .84483 L
.6482 .87767 L
.64778 .88266 L
.64572 .91051 L
.64367 .94335 L
.64209 .97619 L
s
.5 g
.97619 .72352 m
.94335 .72369 L
.91051 .72398 L
.87767 .72442 L
.84483 .72507 L
.81199 .72604 L
.77915 .72755 L
.74631 .73085 L
.71997 .74631 L
.71346 .77788 L
.71325 .77915 L
.70902 .81199 L
.70622 .84483 L
.70423 .87767 L
.7028 .91051 L
.7018 .94335 L
.70114 .97619 L
.97619 .97619 L
F
0 g
.97619 .72352 m
.94335 .72369 L
.91051 .72398 L
.87767 .72442 L
.84483 .72507 L
.81199 .72604 L
.77915 .72755 L
.74631 .73085 L
.71997 .74631 L
.71346 .77788 L
.71325 .77915 L
.70902 .81199 L
.70622 .84483 L
.70423 .87767 L
.7028 .91051 L
.7018 .94335 L
.70114 .97619 L
s
.6 g
.97619 .29768 m
.96305 .28654 L
.94335 .26661 L
.93248 .25369 L
.91051 .22331 L
.90886 .22085 L
.88723 .18801 L
.87767 .17407 L
.86385 .15517 L
.84483 .13237 L
.8354 .12233 L
.81199 .09991 L
.80046 .08949 L
.77915 .06969 L
.76591 .05665 L
.74631 .037 L
.7334 .02381 L
.97619 .02381 L
F
0 g
.97619 .29768 m
.96305 .28654 L
.94335 .26661 L
.93248 .25369 L
.91051 .22331 L
.90886 .22085 L
.88723 .18801 L
.87767 .17407 L
.86385 .15517 L
.84483 .13237 L
.8354 .12233 L
.81199 .09991 L
.80046 .08949 L
.77915 .06969 L
.76591 .05665 L
.74631 .037 L
.7334 .02381 L
s
.4 g
.97619 .76409 m
.94335 .7642 L
.91051 .76442 L
.87767 .76483 L
.84483 .76556 L
.81199 .76697 L
.77915 .77147 L
.76335 .77915 L
.75366 .81199 L
.75012 .84483 L
.74802 .87767 L
.74676 .91051 L
.74631 .92753 L
.74601 .94335 L
.74558 .97619 L
.97619 .97619 L
F
0 g
.97619 .76409 m
.94335 .7642 L
.91051 .76442 L
.87767 .76483 L
.84483 .76556 L
.81199 .76697 L
.77915 .77147 L
.76335 .77915 L
.75366 .81199 L
.75012 .84483 L
.74802 .87767 L
.74676 .91051 L
.74631 .92753 L
.74601 .94335 L
.74558 .97619 L
s
.3 g
.97619 .79879 m
.94335 .7989 L
.91051 .79914 L
.87767 .79967 L
.84483 .80083 L
.81199 .80514 L
.79737 .81199 L
.78819 .84483 L
.78537 .87767 L
.78387 .91051 L
.78311 .94335 L
.78274 .97619 L
.97619 .97619 L
F
0 g
.97619 .79879 m
.94335 .7989 L
.91051 .79914 L
.87767 .79967 L
.84483 .80083 L
.81199 .80514 L
.79737 .81199 L
.78819 .84483 L
.78537 .87767 L
.78387 .91051 L
.78311 .94335 L
.78274 .97619 L
s
.2 g
.97619 .82963 m
.94335 .82976 L
.91051 .8301 L
.87767 .83093 L
.84483 .83358 L
.82258 .84483 L
.8188 .87767 L
.81669 .91051 L
.8157 .94335 L
.81527 .97619 L
.97619 .97619 L
F
0 g
.97619 .82963 m
.94335 .82976 L
.91051 .8301 L
.87767 .83093 L
.84483 .83358 L
.82258 .84483 L
.8188 .87767 L
.81669 .91051 L
.8157 .94335 L
.81527 .97619 L
s
.5 g
.97619 .21287 m
.95643 .18801 L
.94335 .16953 L
.93349 .15517 L
.91051 .12284 L
.91013 .12233 L
.88342 .08949 L
.87767 .08318 L
.85143 .05665 L
.84483 .05022 L
.81921 .02381 L
.97619 .02381 L
F
0 g
.97619 .21287 m
.95643 .18801 L
.94335 .16953 L
.93349 .15517 L
.91051 .12284 L
.91013 .12233 L
.88342 .08949 L
.87767 .08318 L
.85143 .05665 L
.84483 .05022 L
.81921 .02381 L
s
.1 g
.97619 .85766 m
.94335 .85786 L
.91051 .85837 L
.87767 .85914 L
.85382 .87767 L
.84679 .91051 L
.84521 .94335 L
.84483 .96442 L
.8446 .97619 L
.97619 .97619 L
F
0 g
.97619 .85766 m
.94335 .85786 L
.91051 .85837 L
.87767 .85914 L
.85382 .87767 L
.84679 .91051 L
.84521 .94335 L
.84483 .96442 L
.8446 .97619 L
s
.97619 .88355 m
.94335 .88386 L
.91051 .88397 L
.87767 .90725 L
.87647 .91051 L
.8726 .94335 L
.87158 .97619 L
.97619 .97619 L
F
.97619 .88355 m
.94335 .88386 L
.91051 .88397 L
.87767 .90725 L
.87647 .91051 L
.8726 .94335 L
.87158 .97619 L
s
.4 g
.97619 .1313 m
.96982 .12233 L
.94616 .08949 L
.94335 .08575 L
.91982 .05665 L
.91051 .04625 L
.88901 .02381 L
.97619 .02381 L
F
0 g
.97619 .1313 m
.96982 .12233 L
.94616 .08949 L
.94335 .08575 L
.91982 .05665 L
.91051 .04625 L
.88901 .02381 L
s
.3 g
.97619 .05768 m
.97542 .05665 L
.94892 .02381 L
.97619 .02381 L
F
0 g
.97619 .05768 m
.97542 .05665 L
.94892 .02381 L
s
1 0 0 r
.02 w
.34935 .65241 Mdot
0 0 1 r
.65974 .3593 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`005_ooool3o`0002Wooooo0ol0000Wooooo`Go0000
9Oooool2o`0002Oooooo1Ol0000Xooooo`?o00009oooool3o`0000Oooooo000Eooooo`05o`000?oo
ooooooooooooool00000:Oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0002Co
oooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooo
oooo02Gooooo00Go0000ooooooooooooooooo`000006ooooo`003oooool5o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool07_ooool5o`000003ooooool0003o000000?o00008Oooool5
o`0000?ooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000Xooooo`03o`000?oo
oooooooo02Kooooo1Ol0000Vooooo`05o`000?ooooooooooooooool000001_ooool001Gooooo1?l0
000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool08oooool01?l0003ooooo
ooooool0000Yooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo00009oooool4o`00
00Oooooo000Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool00000:?ooool01Ol0003o
oooooooooooooooo000002Cooooo00Co0000oooooooooooo00009_ooool01Ol0003ooooooooooooo
oooo000002Oooooo00?o0000ooooool000009oooool00ol0003oooooooooo`08ooooo`005_ooool0
0ol0003oooooooooo`0Yooooo`;o0000:?ooool01Ol0003ooooooooooooooooo000002Cooooo00Co
0000oooooooooooo00009_ooool01Ol0003ooooooooooooooooo000002Sooooo0_l0000Xooooo`03
o`000?oooooooooo00Oooooo000Gooooo`;o0000:_ooool00ol0003oooooooooo`0Wooooo`?o0000
9_ooool2o`0002Sooooo0ol0000Zooooo`03o`000?oooooooooo02Oooooo0_l00007ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`003oooooooo`00017o0000
0Oooool000oooooo00?o0000ooooooooool00oooool00`00003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Xooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool0ooooool=ooooo`7o00000Oooool000Oooooo0ol00005ooooo`03
o`000?oooooooooo0?oooooo3Oooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`001Ol000000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool=ooooo`7o0000
0Oooool000Kooooo1?l00005ooooo`?o0000;?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Wooooo0_l00001ooooo`001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo:@0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00D0<c<c00?o0000
04a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o0000
09VIV@2IVIT03@2IVIT00ol0003o/k>cok>c/`1Hok>c/`03o`00002IVIT0VIVI01@0VIVI00?o0000
07moO`1oOgl0401oOgl00ol00000IVIV06IVIP0=06IVIP03o`00001<C4`0C4a<00@0C4a<1_ooool1
o`00007ooooo0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooooolY0000
0003o`00000I6AT06ATI00@06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00604a<
C003o`00001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0=09VI
V@03o`000?nc/k?o/k>c02Co/k>c1000000aok>c/`03o`00002IVIT0VIVI01@0VIVI00?o000007mo
O`1oOgl0401oOgl00ol00000IVIV06IVIP0=06IVIP03o`00001<C4`0C4a<00<0C4a<1_ooool1o`00
007ooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`03ooooobT0000000?o000001TI6@0I
6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1V
IVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00d0VIVI00?o0000ok>c/onc
/k<08onc/k<00`000000c<c<0<c<c0020<c<c0D00000;Onc/k<00ol00000VIVI09VIV@0D09VIV@03
o`00001oOgl0Ogmo0100Ogmo00?o000006IVIP1VIVH03@1VIVH00ol00000C4a<04a<C00204a<C0Ko
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobT0000000?o000001TI6@0I6AT0
100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH0
1`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00d0VIVI00?o0000ok>c/onc/k<0
8_nc/k<00`000000c<c<0<c<c0080<c<c0<00000:onc/k<00ol00000VIVI09VIV@0D09VIV@03o`00
001oOgl0Ogmo0100Ogmo00?o000006IVIP1VIVH03@1VIVH01?l00000C4a<04a<C01<C4`6ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooolY00000003o`00000I6AT06ATI00@06ATI
00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV
00?o000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0=09VIV@03o`000?nc/k?o/k>c023o/k>c
0P00000>0<c<c0800000:_nc/k<00ol00000VIVI09VIV@0D09VIV@03o`00001oOgl0Ogmo0100Ogmo
00?o000006IVIP1VIVH03@1VIVH00ol00000C4a<04a<C006ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00ooooolY00000003o`00000I6AT06ATI00@06ATI00?o000003<c<`0c<c<01@0c
<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl02@1o
Ogl00ol00000VIVI09VIV@0=09VIV@03o`000?nc/k?o/k>c01oo/k>c00<000000<c<c03<c<`0403<
c<`3000002So/k>c00?o000009VIV@2IVIT0502IVIT00ol00000Ogmo07moO`0@07moO`03o`00001V
IVH0IVIV00`0IVIV00?o000004a<C01<C4`01_ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00?ooooo:@0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00D0<c<c00?o0000
04a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o0000
09VIV@2IVIT03@2IVIT00ol0003o/k>cok>c/`0Nok>c/`030000003<c<`0c<c<01@0c<c<0P00000W
ok>c/`03o`00002IVIT0VIVI01@0VIVI00?o000007moO`1oOgl0401oOgl00ol00000IVIV06IVIP0<
06IVIP03o`00001<C4cooooo00Gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooo
obT0000000?o000001TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<
00H0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI
00d0VIVI00?o0000ok>c/onc/k<07Onc/k<00`000000c<c<0<c<c00G0<c<c003o`000?nc/k?o/k>c
02Go/k>c00?o000009VIV@2IVIT0502IVIT00ol00000Ogmo07moO`0@07moO`03o`00001VIVH0IVIV
00`0IVIV00?o0000ooooooooool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?o
oooo:@0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<
C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2I
VIT03@2IVIT00ol0003o/k>cok>c/`0Lok>c/`030000003<c<`0c<c<01T0c<c<0P00000Vok>c/`03
o`00002IVIT0VIVI01@0VIVI00?o000007moO`1oOgl0401oOgl00ol00000IVIV06IVIP0<06IVIP03
o`000?oooooooooo00?ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobT00000
00?o000001TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<
00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00d0VIVI
00?o0000ok>c/onc/k<07?nc/k<00`000000c<c<0<c<c00K0<c<c00300000?nc/k?o/k>c02Co/k>c
00?o000009VIV@2IVIT0502IVIT00ol00000Ogmo07moO`0?07moO`03o`00001VIVH0IVIV00`0IVIV
1_ooool1o`00007ooooo000?ooooo`;o00001?oooolY00000003o`00000I6AT06ATI00@06ATI00?o
000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV00?o
000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0=09VIV@03o`000?nc/k?o/k>c01_o/k>c00<0
00000<c<c03<c<`07@3<c<`2000002Go/k>c00?o000009VIV@2IVIT0502IVIT00ol00000Ogmo07mo
O`0?07moO`03o`00001VIVH0IVIV00/0IVIV1Oooool2o`00007ooooo000?ooooo`03o`000?oooooo
oooo00?ooooo:@0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00D0<c<c00?o0000
04a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o0000
09VIV@2IVIT03@2IVIT00ol0003o/k>cok>c/`0Kok>c/`030000003<c<`0c<c<01l0c<c<0P00000T
ok>c/`03o`00002IVIT0VIVI01@0VIVI00?o000007moO`1oOgl03`1oOgl00ol00000IVIV06IVIP0:
06IVIPKooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobT0000000?o000001TI
6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IV
IP1VIVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00d0VIVI00?o0000ok>c
/onc/k<06_nc/k<00`000000c<c<0<c<c00R0<c<c00300000?nc/k?o/k>c02;o/k>c00?o000009VI
V@2IVIT0502IVIT00ol00000Ogmo07moO`0?07moO`03o`00001VIVH0IVIV00T0IVIV1_ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?ooooo:@0000000ol000006ATI01TI6@0401TI6@03
o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03
o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Jok>c/`03
0000003<c<`0c<c<02@0c<c<0P00000Sok>c/`03o`00002IVIT0VIVI01@0VIVI00?o000007moO`1o
Ogl03P1oOgl00ol00000IVIV06IVIP0906IVIPKooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`03ooooobT0000000?o000001TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00
001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00
002IVIT0VIVI00`0VIVI00?o0000ok>c/onc/k<06_nc/k<00`000000c<c<0<c<c00V0<c<c0030000
0?nc/k?o/k>c027o/k>c00?o000009VIV@2IVIT0502IVIT00ol00000Ogmo07moO`0>07moO`03o`00
001VIVH0IVIV00P0IVIV1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo:@00
00000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01P1<
C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT0302I
VIT00ol0003o/k>cok>c/`0Iok>c/`030000003<c<`0c<c<02P0c<c<0P00000Rok>c/`03o`00002I
VIT0VIVI01@0VIVI00?o000007moO`1oOgl03P1oOgl00ol00000IVIV06IVIP0706IVIPKooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`03ooooobT0000000?o000001TI6@0I6AT0100I6AT0
0ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH0
0ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00`0VIVI00?o0000ok>c/onc/k<06Onc/k<0
0`000000c<c<0<c<c00Z0<c<c00300000?nc/k?o/k>c023o/k>c00?o000009VIV@2IVIT0502IVIT0
0ol00000Ogmo07moO`0>07moO`03o`00001VIVH0IVIV00H0IVIV1_ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00?ooooo:@0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c
00D0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo
00T0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Hok>c/`030000003<c<`0c<c<
02`0c<c<0`00000Pok>c/`03o`00002IVIT0VIVI01@0VIVI00?o000007moO`1oOgl03P1oOgl00ol0
0000IVIV06IVIP0506IVIPKooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobT0
000000?o000001TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0
C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00`0
VIVI00?o0000ok>c/onc/k<06?nc/k<00`000000c<c<0<c<c00_0<c<c08000007onc/k<00ol00000
VIVI09VIV@0C09VIV@03o`00001oOgl0Ogmo00h0Ogmo00?o000006IVIP1VIVH01@1VIVH6ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooolY00000003o`00000I6AT06ATI00@06ATI
00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV
00?o000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0<09VIV@03o`000?nc/k?o/k>c01Oo/k>c
00<000000<c<c03<c<`0<P3<c<`00`00003o/k>cok>c/`0Mok>c/`03o`00002IVIT0VIVI01<0VIVI
00?o000007moO`1oOgl03P1oOgl00ol00000IVIV06IVIP0406IVIPKooooo0Ol00001ooooo`003ooo
ool2o`0000Cooooo:@0000000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00D0<c<c00?o
000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o
000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Gok>c/`030000003<c<`0c<c<03<0c<c<00<0
0000ok>c/onc/k<07Onc/k<2o`0001@0VIVI00?o000007moO`1oOgl03P1oOgl00ol00000IVIV06IV
IP0306IVIPGooooo0_l00001ooooo`003oooool00ol0003oooooooooo`03ooooobT0000000?o0000
01TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o0000
06IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00`0VIVI00?o0000
ok>c/onc/k<05onc/k<00`000000c<c<0<c<c00d0<c<c08000007onc/k<00ol00000VIVI09VIV@0B
09VIV@03o`00001oOgl0Ogmo00d0Ogmo00?o000006IVIP1VIVH00`1VIVH6ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00ooooolX00000003o`00000I6AT06ATI00D06ATI00?o000003<c
<`0c<c<01@0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV00?o000007mo
O`1oOgl0201oOgl00ol00000VIVI09VIV@0=09VIV@03o`000?nc/k?o/k>c01Ko/k>c00<000000<c<
c03<c<`0=`3<c<`00`00003o/k>cok>c/`0Mok>c/`03o`00002IVIT0VIVI0180VIVI00?o000007mo
O`1oOgl03@1oOgl00ol00000IVIV06IVIP0206IVIPKooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`03ooooobP0000000?o000001TI6@0I6AT01@0I6AT00ol00000<c<c03<c<`0503<c<`03
o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0807moO`03
o`00002IVIT0VIVI00d0VIVI00?o0000ok>c/onc/k<05_nc/k<00`000000c<c<0<c<c00h0<c<c003
00000?nc/k?o/k>c01go/k>c00?o000009VIV@2IVIT04@2IVIT00ol00000Ogmo07moO`0>07moO`04
o`00001VIVH0IVIV06IVIPKooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobP0
000000?o000001TI6@0I6AT01@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0
C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0807moO`03o`00002IVIT0VIVI00d0
VIVI00?o0000ok>c/onc/k<05_nc/k<00`000000c<c<0<c<c00i0<c<c00300000?nc/k?o/k>c01go
/k>c00?o000009VIV@2IVIT04@2IVIT00ol00000Ogmo07moO`0=07moO`04o`00001VIVH0IVIV06IV
IPKooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobP0000000?o000001TI6@0I
6AT01@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1V
IVH01`1VIVH00ol00000Ogmo07moO`0807moO`03o`00002IVIT0VIVI00d0VIVI00?o0000ok>c/onc
/k<05Onc/k<00`000000c<c<0<c<c00k0<c<c003o`000?nc/k?o/k>c01go/k>c00?o000009VIV@2I
VIT04@2IVIT00ol00000Ogmo07moO`0=07moO`03o`00001VIVH0IVIV00Kooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`03ooooobP0000000?o000001TI6@0I6AT01@0I6AT00ol00000<c<c
03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo
07moO`0807moO`03o`00002IVIT0VIVI00d0VIVI00?o0000ok>c/onc/k<05Onc/k<00`000000c<c<
0<c<c00l0<c<c08000007_nc/k<00ol00000VIVI09VIV@0A09VIV@03o`00001oOgl0Ogmo00d0Ogmo
00?o000006IVI_ooool01Oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo:000
00000ol000006ATI01TI6@0501TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01P1<
C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00P0Ogmo00?o000009VIV@2IVIT03@2I
VIT00ol0003o/k>cok>c/`0Eok>c/`030000003<c<`0c<c<03h0c<c<00<00000ok>c/onc/k<07?nc
/k<00ol00000VIVI09VIV@0@09VIV@03o`00001oOgl0Ogmo00h0Ogmo00?o0000ooooooooool01?oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo9`0000000ol000006ATI01TI6@06
01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP07
06IVIP03o`00001oOgl0Ogmo00P0Ogmo00?o000009VIV@2IVIT03@2IVIT00ol0003o/k>cok>c/`0D
ok>c/`030000003<c<`0c<c<0400c<c<0P00000Mok>c/`03o`00002IVIT0VIVI0100VIVI00?o0000
07moO`1oOgl03P1oOgl00ol0003oooooooooo`03ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00ooooolW00000003o`00000I6AT06ATI00H06ATI00?o000003<c<`0c<c<01@0c<c<00ol0
0000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl0201oOgl00ol0
0000VIVI09VIV@0=09VIV@03o`000?nc/k?o/k>c01Co/k>c00<000000<c<c03<c<`0@P3<c<`20000
01_o/k>c00?o000009VIV@2IVIT04@2IVIT00ol00000Ogmo07moO`0=07moO`Kooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`03ooooobH0000000?o000001TI6@0I6AT01`0I6AT00ol00000
<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000
Ogmo07moO`0807moO`03o`00002IVIT0VIVI00d0VIVI00?o0000ok>c/onc/k<05?nc/k<00`000000
c<c<0<c<c0140<c<c00300000?nc/k?o/k>c01Wo/k>c00?o000009VIV@2IVIT0402IVIT00ol00000
Ogmo07moO`0=07moO`Kooooo0Ol00001ooooo`003oooool2o`0000Cooooo9P0000000ol000006ATI
01TI6@0601TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV
06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>c
ok>c/`0Dok>c/`030000003<c<`0c<c<04H0c<c<00<00000ok>c/onc/k<06Onc/k<00ol00000VIVI
09VIV@0@09VIV@03o`00001oOgl0Ogmo00`0Ogmo1Oooool2o`00007ooooo000?ooooo`03o`000?oo
oooooooo00?ooooo9@0000000ol000006ATI01TI6@0701TI6@03o`00000c<c<0<c<c00D0<c<c00?o
000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o
000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Dok>c/`030000003<c<`0c<c<04L0c<c<00<0
0000ok>c/onc/k<06Onc/k<00ol00000VIVI09VIV@0@09VIV@03o`00001oOgl0Ogmo00/0Ogmo1_oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo9@0000000ol000006ATI01TI6@07
01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP07
06IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0D
ok>c/`030000003<c<`0c<c<04P0c<c<00<00000ok>c/onc/k<06?nc/k<00ol00000VIVI09VIV@0@
09VIV@03o`00001oOgl0Ogmo00/0Ogmo1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00?ooooo900000000ol000006ATI01TI6@0801TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<
C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VI
V@2IVIT0302IVIT00ol0003o/k>cok>c/`0Cok>c/`030000003<c<`0c<c<04X0c<c<00<00000ok>c
/onc/k<06?nc/k<00ol00000VIVI09VIV@0@09VIV@03o`00001oOgl0Ogmo00X0Ogmo1_ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?ooooo7`000005o`0000/06ATI00?o000003<c<`0c
<c<01@0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV00?o000007moO`1o
Ogl02@1oOgl00ol00000VIVI09VIV@0<09VIV@03o`000?nc/k?o/k>c01?o/k>c00<000000<c<c03<
c<`0B`3<c<`2000001Wo/k>c00?o000009VIV@2IVIT0402IVIT00ol00000Ogmo07moO`0907moO`Ko
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooaoo0000400I6AT00ol00000<c<c
03<c<`0503<c<`03o`00001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo
07moO`0907moO`03o`00002IVIT0VIVI00`0VIVI00?o0000ok>c/onc/k<04onc/k<00`000000c<c<
0<c<c01=0<c<c00300000?nc/k?o/k>c01Ko/k>c00?o000009VIV@2IVIT04@2IVIT00ol00000Ogmo
07moO`0807moO`Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooobh06ATI00?o
000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00L0IVIV00?o
000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0<09VIV@03o`000?nc/k?o/k>c01?o/k>c00<0
00000<c<c03<c<`0CP3<c<`00`00003o/k>cok>c/`0Fok>c/`03o`00002IVIT0VIVI0140VIVI00?o
000007moO`1oOgl01`1oOgl6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool^
01TI6@03o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP07
06IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0B
ok>c/`030000003<c<`0c<c<0500c<c<00<00000ok>c/onc/k<05_nc/k<00ol00000VIVI09VIV@0A
09VIV@03o`00001oOgl0Ogmo00H0Ogmo1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00?ooooo;00I6AT2o`0000T0<c<c00?o000004a<C01<C4`01P1<C4`00ol00000IVIV06IVIP0706IV
IP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Bok>c
/`030000003<c<`0c<c<0540c<c<00<00000ok>c/onc/k<05_nc/k<00ol00000VIVI09VIV@0@09VI
V@03o`00001oOgl0Ogmo00H0Ogmo1_ooool1o`00007ooooo0008ooooo`?o00001?ooool00ol0003o
ooooooooo`03ooooobX06ATI0_l0000:03<c<`03o`00001<C4`0C4a<00L0C4a<00?o000006IVIP1V
IVH01`1VIVH00ol00000Ogmo07moO`0807moO`03o`00002IVIT0VIVI00`0VIVI00?o0000ok>c/onc
/k<04onc/k<00`000000c<c<0<c<c01B0<c<c00300000?nc/k?o/k>c01Ko/k>c00?o000009VIV@2I
VIT0402IVIT00ol00000Ogmo07moO`0507moO`Kooooo0Ol00001ooooo`002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo9`0I6AT3o`0000`0<c<c00?o000004a<C01<C4`0
1`1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00P0Ogmo00?o000009VIV@2IVIT0
302IVIT00ol0003o/k>cok>c/`0Cok>c/`030000003<c<`0c<c<05<0c<c<00<00000ok>c/onc/k<0
5_nc/k<00ol00000VIVI09VIV@0@09VIV@03o`00001oOgl0Ogmo00@0Ogmo1_ooool1o`00007ooooo
0005o`000003ooooool0003o000000?o00001?ooool3o`0000?ooooo9@0I6AT2o`0000l0<c<c00?o
000004a<C01<C4`01`1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00P0Ogmo00?o
000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Bok>c/`030000003<c<`0c<c<05D0c<c<00<0
0000ok>c/onc/k<05_nc/k<00ol00000VIVI09VIV@0@09VIV@03o`00001oOgl0Ogmo00<0Ogmo1Ooo
ool2o`00007ooooo0006ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00ooo
oolUo`000100<c<c0_l0000904a<C003o`00001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl0201o
Ogl00ol00000VIVI09VIV@0<09VIV@03o`000?nc/k?o/k>c01;o/k>c00<000000<c<c03<c<`0EP3<
c<`00`00003o/k>cok>c/`0Fok>c/`03o`00002IVIT0VIVI0100VIVI00?o000007moO`1oOgl00P1o
Ogl6ooooo`7o00000Oooool000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`03
oooooc@0<c<c00?o000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0
Ogmo00P0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Bok>c/`030000003<c<`0
c<c<05H0c<c<00<00000ok>c/onc/k<05_nc/k<00ol00000VIVI09VIV@0@09VIV@03o`00001oOgl0
Ogmo0080Ogmo1_ooool1o`00007ooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`03oooo
oc<0<c<c00?o000004a<C01<C4`02P1<C4`00ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo
00P0Ogmo00?o000009VIV@2IVIT0302IVIT00ol0003o/k>cok>c/`0Bok>c/`030000003<c<`0c<c<
05L0c<c<00<00000ok>c/onc/k<05_nc/k<00ol00000VIVI09VIV@0@09VIV@04o`00001oOgl0Ogmo
07moO`Kooooo0Ol00001ooooo`002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo<@0c<c<2o`0000d0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0807mo
O`03o`00002IVIT0VIVI00`0VIVI00?o0000ok>c/onc/k<04Onc/k<00`000000c<c<0<c<c01I0<c<
c00300000?nc/k?o/k>c01Ko/k>c00?o000009VIV@2IVIT0402IVIT00ol00000Ogmo07moO`06oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00oooool`03<c<`03o`00001<C4`0C4a<00`0
C4a<00?o000006IVIP1VIVH0201VIVH00ol00000Ogmo07moO`0807moO`03o`00002IVIT0VIVI00`0
VIVI00?o0000ok>c/onc/k<04Onc/k<00`000000c<c<0<c<c01J0<c<c00300000?nc/k?o/k>c01Go
/k>c00?o000009VIV@2IVIT04@2IVIT00ol00000Ogmoooooo`05ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00oooool_03<c<`03o`00001<C4`0C4a<00d0C4a<00?o000006IVIP1VIVH0
1`1VIVH00ol00000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00/0VIVI00?o0000ok>c/onc/k<0
4_nc/k<00`000000c<c<0<c<c01K0<c<c00300000?nc/k?o/k>c01Go/k>c00?o000009VIV@2IVIT0
402IVIT00ol00000Ogmoooooo`05ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooo
ool^03<c<`03o`00001<C4`0C4a<00h0C4a<00?o000006IVIP1VIVH01`1VIVH00ol00000Ogmo07mo
O`0907moO`03o`00002IVIT0VIVI00/0VIVI00?o0000ok>c/onc/k<04_nc/k<00`000000c<c<0<c<
c01K0<c<c00300000?nc/k?o/k>c01Ko/k>c00?o000009VIV@2IVIT0402IVIT00ol0003ooooooooo
o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooolP03<c<`ko00004@1<C4`0
0ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT02`2IVIT0
0ol0003o/k>cok>c/`0Bok>c/`030000003<c<`0c<c<05`0c<c<00<00000ok>c/onc/k<05Onc/k<0
0ol00000VIVI09VIV@0A09VIV@03o`000?oooooooooo00?ooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`03ooooob3o00007P1<C4`00ol00000IVIV06IVIP0806IVIP03o`00001oOgl0Ogmo
00T0Ogmo00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0Aok>c/`030000003<c<`0c<c<
05h0c<c<00<00000ok>c/onc/k<05Onc/k<00ol00000VIVI09VIV@0@09VIV@Kooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`03ooooocd0C4a<0_l0000:06IVIP03o`00001oOgl0Ogmo00T0
Ogmo00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0Aok>c/`030000003<c<`0c<c<05l0
c<c<00<00000ok>c/onc/k<05Onc/k<00ol00000VIVI09VIV@0?09VIV@Kooooo0Ol00001ooooo`00
3oooool2o`0000Cooooo?01<C4`00ol00000IVIV06IVIP0:06IVIP03o`00001oOgl0Ogmo00T0Ogmo
00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0Aok>c/`030000003<c<`0c<c<05l0c<c<
00<00000ok>c/onc/k<05Onc/k<00ol00000VIVI09VIV@0?09VIV@Gooooo0_l00001ooooo`003ooo
ool00ol0003oooooooooo`03oooooc/0C4a<00?o000006IVIP1VIVH02`1VIVH00ol00000Ogmo07mo
O`0907moO`03o`00002IVIT0VIVI00/0VIVI00?o0000ok>c/onc/k<04Onc/k<00`000000c<c<0<c<
c01P0<c<c00300000?nc/k?o/k>c01Co/k>c00?o000009VIV@2IVIT03`2IVIT6ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00oooooli04a<C0;o00003P1VIVH00ol00000Ogmo07moO`09
07moO`03o`00002IVIT0VIVI00/0VIVI00?o0000ok>c/onc/k<04?nc/k<00`000000c<c<0<c<c01R
0<c<c00300000?nc/k?o/k>c01Co/k>c00?o000009VIV@2IVIT03P2IVIT6ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00ooooolh04a<C003o`00001VIVH0IVIV00h0IVIV00?o000007mo
O`1oOgl02@1oOgl00ol00000VIVI09VIV@0:09VIV@03o`000?nc/k?o/k>c017o/k>c00<000000<c<
c03<c<`0HP3<c<`00`00003o/k>cok>c/`0Eok>c/`03o`00002IVIT0VIVI00d0VIVI1_ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?ooooo=`1<C4`00ol00000IVIV06IVIP0>06IVIP03
o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0Aok>c/`03
0000003<c<`0c<c<06<0c<c<00<00000ok>c/onc/k<05Onc/k<00ol00000VIVI09VIV@0<09VIV@Ko
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooc80C4a<1Ol0000A06IVIP03o`00
001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0Aok>c/`030000
003<c<`0c<c<02d0c<c<1ol0000`0<c<c00300000?nc/k?o/k>c01Co/k>c00?o000009VIV@2IVIT0
302IVIT6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooolbo`0001H0IVIV00?o
000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0;09VIV@03o`000?nc/k?o/k>c017o/k>c00<0
00000<c<c03<c<`09`3<c<`6o`0000L0i^KV1Ol0000[0<c<c00300000?nc/k?o/k>c01Go/k>c00?o
000009VIV@2IVIT02`2IVIT6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooom8
06IVIP03o`00001oOgl0Ogmo00T0Ogmo00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0@
ok>c/`030000003<c<`0c<c<02H0c<c<0_l0000B0>KViPCo0000:03<c<`00`00003o/k>cok>c/`0E
ok>c/`03o`00002IVIT0VIVI00X0VIVI1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00?oooooAP1VIVH2o`0000`0Ogmo00?o000009VIV@2IVIT02`2IVIT00ol0003o/k>cok>c/`0@ok>c
/`030000003<c<`0c<c<02D0c<c<00?o00000>KViP3Vi^H05P3Vi^H2o`0002L0c<c<00?o0000ok>c
/onc/k<05Onc/k<00ol00000VIVI09VIV@0909VIV@Kooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`03ooooodD0IVIV00?o000007moO`1oOgl0301oOgl00ol00000VIVI09VIV@0;09VIV@03
o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`0903<c<`00ol00000i^KV0>KViP0I0>KViP03
o`00003<c<`0c<c<02@0c<c<00<00000ok>c/onc/k<05Onc/k<00ol00000VIVI09VIV@0909VIV@Ko
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooood@0IVIV00?o000007moO`1oOgl0
3@1oOgl00ol00000VIVI09VIV@0;09VIV@03o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`0
8`3<c<`00ol00000i^KV0>KViP0K0>KViP;o0000903<c<`00`00003o/k>cok>c/`0Fok>c/`03o`00
002IVIT0VIVI00P0VIVI1_ooool1o`00007ooooo000?ooooo`;o00001?oooom206IVIP;o00003`1o
Ogl00ol00000VIVI09VIV@0<09VIV@03o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`08P3<
c<`00ol00000i^KV0>KViP0N0>KViP03o`00003<c<`0c<c<0280c<c<00<00000ok>c/onc/k<05_nc
/k<00ol00000VIVI09VIV@0709VIV@Gooooo0_l00001ooooo`003oooool00ol0003oooooooooo`03
oooood40IVIV00?o000007moO`1oOgl03`1oOgl00ol00000VIVI09VIV@0<09VIV@03o`000?nc/k?o
/k>c00oo/k>c00<000000<c<c03<c<`08P3<c<`00ol00000i^KV0>KViP0P0>KViP03o`00003<c<`0
c<c<0280c<c<00<00000ok>c/onc/k<05_nc/k<00ol00000VIVI09VIV@0609VIV@Kooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`03oooood00IVIV00?o000007moO`1oOgl0401oOgl00ol0
0000VIVI09VIV@0;09VIV@03o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`08@3<c<`00ol0
0000i^KV0>KViP0R0>KViP03o`00003<c<`0c<c<0240c<c<00<00000ok>c/onc/k<05onc/k<00ol0
0000VIVI09VIV@0509VIV@Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooc/0
IVIV1Ol0000C07moO`03o`00002IVIT0VIVI00/0VIVI00?o0000ok>c/onc/k<04?nc/k<00`000000
c<c<0<c<c00Q0<c<c003o`00003Vi^H0i^KV02<0i^KV00?o00000<c<c03<c<`08@3<c<`00`00003o
/k>cok>c/`0Gok>c/`03o`00002IVIT0VIVI00@0VIVI1_ooool1o`00007ooooo000?ooooo`03o`00
0?oooooooooo00?ooooo>ol0000H07moO`03o`00002IVIT0VIVI00/0VIVI00?o0000ok>c/onc/k<0
4?nc/k<00`000000c<c<0<c<c00P0<c<c003o`00003Vi^H0i^KV02D0i^KV00?o00000<c<c03<c<`0
803<c<`00`00003o/k>cok>c/`0Hok>c/`03o`00002IVIT0VIVI00<0VIVI1_ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00?oooooDP1oOgl00ol00000VIVI09VIV@0<09VIV@03o`000?nc
/k?o/k>c013o/k>c00<000000<c<c03<c<`07`3<c<`00ol00000i^KV0>KViP0W0>KViP03o`00003<
c<`0c<c<0200c<c<00<00000ok>c/onc/k<06?nc/k<00ol00000VIVI09VIV@0209VIV@Kooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`03oooooe80Ogmo00?o000009VIV@2IVIT0302IVIT0
0ol0003o/k>cok>c/`0@ok>c/`030000003<c<`0c<c<01h0c<c<00?o00000>KViP3Vi^H0:@3Vi^H0
0ol00000c<c<0<c<c00P0<c<c00300000?nc/k?o/k>c01So/k>c0_l0000209VIV@Kooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`03oooooe80Ogmo00?o000009VIV@2IVIT0302IVIT00ol0
003o/k>cok>c/`0@ok>c/`030000003<c<`0c<c<01h0c<c<00?o00000>KViP3Vi^H0:@3Vi^H00ol0
0000c<c<0<c<c00P0<c<c00300000?nc/k?o/k>c01[o/k>c00?o000009VIVOooool01Oooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?oooooDP1oOgl00ol00000VIVI09VIV@0<09VIV@03
o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`07@3<c<`00ol00000i^KV0>KViP0[0>KViP03
o`00003<c<`0c<c<0200c<c<00<00000ok>c/onc/k<06_nc/k<00ol0003oooooooooo`04ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooomA07moO`03o`00002IVIT0VIVI00d0VIVI
00?o0000ok>c/onc/k<04?nc/k<00`000000c<c<0<c<c00M0<c<c003o`00003Vi^H0i^KV02/0i^KV
00?o00000<c<c03<c<`08@3<c<`00`00003o/k>cok>c/`0Jok>c/`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`003oooool2o`0000CoooooD01oOgl2o`0000l0VIVI00?o0000ok>c/onc/k<04?nc
/k<00`000000c<c<0<c<c00M0<c<c003o`00003Vi^H0i^KV02`0i^KV00?o00000<c<c03<c<`0803<
c<`00`00003o/k>cok>c/`0Jok>c/`Gooooo0_l00001ooooo`003oooool00ol0003oooooooooo`03
ooooodh0Ogmo0_l0000@09VIV@03o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`07@3<c<`0
0ol00000i^KV0>KViP0^0>KViP03o`00003<c<`0c<c<0200c<c<00<00000ok>c/onc/k<06Onc/k<6
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooom;07moO`?o00004P2IVIT00ol0
003o/k>cok>c/`0@ok>c/`030000003<c<`0c<c<01d0c<c<00?o00000>KViP3Vi^H0;P3Vi^H00ol0
0000c<c<0<c<c00Q0<c<c00300000?nc/k?o/k>c01So/k>c1_ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00?oooooB@1oOgl2o`0001D0VIVI00?o0000ok>c/onc/k<04?nc/k<00`000000
c<c<0<c<c00M0<c<c003o`00003Vi^H0i^KV02l0i^KV00?o00000<c<c03<c<`0803<c<`00`00003o
/k>cok>c/`0Hok>c/`Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooc/0Ogmo
3_l0000G09VIV@03o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`0703<c<`00ol00000i^KV
0>KViP0`0>KViP03o`00003<c<`0c<c<0240c<c<00<00000ok>c/onc/k<05onc/k<6ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00oooool507moOcKo00009@2IVIT00ol0003o/k>cok>c
/`0@ok>c/`030000003<c<`0c<c<01`0c<c<00?o00000>KViP3Vi^H0<@3Vi^H00ol00000c<c<0<c<
c00Q0<c<c00300000?nc/k?o/k>c01Ko/k>c1_ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00?ooooo1Ol0001K09VIV@03o`000?nc/k?o/k>c013o/k>c00<000000<c<c03<c<`0703<c<`0
0ol00000i^KV0>KViP0a0>KViP03o`00003<c<`0c<c<0240c<c<00<00000ok>c/onc/k<05_nc/k<6
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooomO09VIV@03o`000?nc/k?o/k>c
017o/k>c00<000000<c<c03<c<`0703<c<`00ol00000i^KV0>KViP0b0>KViP03o`00003<c<`0c<c<
0240c<c<00<00000ok>c/onc/k<05Onc/k<6ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00ooooomO09VIV@03o`000?nc/k?o/k>c017o/k>c00<000000<c<c03<c<`0703<c<`00ol00000
i^KV0>KViP0b0>KViP03o`00003<c<`0c<c<0280c<c<00<00000ok>c/onc/k<05?nc/k<6ooooo`7o
00000Oooool000Kooooo1Ol00004ooooo`03o`000?oooooooooo00?oooooG`2IVIT00ol0003o/k>c
ok>c/`0Aok>c/`030000003<c<`0c<c<01`0c<c<00?o00000>KViP3Vi^H0<P3Vi^H00ol00000c<c<
0<c<c00S0<c<c00300000?nc/k?o/k>c01?o/k>c1_ooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00ooooomN09VIV@03o`000?nc/k?o/k>c01;o/k>c
00<000000<c<c03<c<`0703<c<`00ol00000i^KV0>KViP0c0>KViP03o`00003<c<`0c<c<02<0c<c<
00<00000ok>c/onc/k<04_nc/k<6ooooo`7o00000Oooool000Go00000oooool00ol0003ooooooooo
o`04ooooo`?o00000ooooomN09VIV@03o`000?nc/k?o/k>c01;o/k>c00<000000<c<c03<c<`0703<
c<`00ol00000i^KV0>KViP0c0>KViP03o`00003<c<`0c<c<02<0c<c<00<00000ok>c/onc/k<04_nc
/k<5ooooo`;o00000Oooool000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooeh0VIVI00?o0000ok>c/onc/k<04_nc/k<00`000000c<c<0<c<c00L0<c<c003o`00003Vi^H0
i^KV03<0i^KV00?o00000<c<c03<c<`0903<c<`00`00003o/k>cok>c/`0Aok>c/`Kooooo0Ol00001
ooooo`001_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00ooooomM
09VIV@03o`000?nc/k?o/k>c01?o/k>c00<000000<c<c03<c<`0703<c<`00ol00000i^KV0>KViP0d
0>KViP03o`00003<c<`0c<c<02@0c<c<00<00000ok>c/onc/k<04?nc/k<6ooooo`7o00000Oooool0
00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?oooooG02IVIT2
o`0001Go/k>c00<000000<c<c03<c<`0703<c<`00ol00000i^KV0>KViP0G0>KViP?o003o6P3Vi^H0
0ol00000c<c<0<c<c00U0<c<c003o`000000003o/k>c00oo/k>c1_ooool1o`00007ooooo0007oooo
o`?o00001Oooool00ol0003oooooooooo`03oooooe/0VIVI00?o0000ok>c/onc/k<05Onc/k<00`00
0000c<c<0<c<c00L0<c<c003o`00003Vi^H0i^KV01H0i^KV1Ol00?lI0>KViP03o`00003<c<`0c<c<
02L0c<c<00<00000ok>c/onc/k<03Onc/k<6ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00ooooomF09VIV@Go00006?nc/k<00`000000c<c<0<c<c00L0<c<c003o`00003Vi^H0i^KV01H0
i^KV1Ol00?lI0>KViP03o`00003<c<`0c<c<02P0c<c<00<00000ok>c/onc/k<03?nc/k<6ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooom409VIVA;o00007Onc/k<00`000000c<c<
0<c<c00L0<c<c003o`00003Vi^H0i^KV01H0i^KV1Ol00?lJ0>KViP03o`00003<c<`0c<c<02P0c<c<
00<00000ok>c/onc/k<02onc/k<6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooo
oolY09VIVA_o0000;onc/k<00`000000c<c<0<c<c00L0<c<c003o`00003Vi^H0i^KV01L0i^KV0ol0
0?lK0>KViP03o`00003<c<`0c<c<02T0c<c<00<00000ok>c/onc/k<02_nc/k<6ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00ooooolYo`0004[o/k>c00<000000<c<c03<c<`07@3<c<`0
0ol00000i^KV0>KViP0d0>KViP03o`00003<c<`0c<c<02X0c<c<00<00000ok>c/onc/k<02Onc/k<6
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooomcok>c/`030000003<c<`0c<c<
01d0c<c<00?o00000>KViP3Vi^H0=03Vi^H00ol00000c<c<0<c<c00[0<c<c00300000?nc/k?o/k>c
00So/k>c1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?oooooLonc/k<00`000000
c<c<0<c<c00M0<c<c003o`00003Vi^H0i^KV03@0i^KV00?o00000<c<c03<c<`0;03<c<`00`00003o
/k>cok>c/`07ok>c/`Kooooo0Ol00001ooooo`003oooool2o`0000CoooooLonc/k<00`000000c<c<
0<c<c00M0<c<c003o`00003Vi^H0i^KV03D0i^KV00?o00000<c<c03<c<`0;03<c<`2000000Oo/k>c
1Oooool2o`00007ooooo000?ooooo`03o`000?oooooooooo00?oooooLonc/k<00`000000c<c<0<c<
c00M0<c<c003o`00003Vi^H0i^KV03D0i^KV00?o00000<c<c03<c<`0;P3<c<`2000000Go/k>c1_oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?oooooLonc/k<00`000000c<c<0<c<c00M
0<c<c003o`00003Vi^H0i^KV03D0i^KV00?o00000<c<c03<c<`0<03<c<`2000000?o/k>c1_ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00?oooooL_nc/k<00`000000c<c<0<c<c00O0<c<
c003o`00003Vi^H0i^KV03@0i^KV00?o00000<c<c03<c<`0<P3<c<`00`00003o/k>cok>c/`06oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00ooooombok>c/`030000003<c<`0c<c<01l0
c<c<00?o00000>KViP3Vi^H0=03Vi^H00ol00000c<c<0<c<c00c0<c<c08000001_ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00?oooooL_nc/k<00`000000c<c<0<c<c00O0<c<c003o`00
003Vi^H0i^KV03@0i^KV00?o00000<c<c03<c<`0=@3<c<`00`00003oooooooooo`03ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00ooooomaok>c/`030000003<c<`0c<c<0240c<c<00?o
00000>KViP3Vi^H0<`3Vi^H00ol00000c<c<0<c<c00e0<c<c0Kooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`03ooooog7o/k>c00<000000<c<c03<c<`08@3<c<`00ol00000i^KV0>KViP0c
0>KViP03o`00003<c<`0c<c<03D0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00?oooooLOnc/k<00`000000c<c<0<c<c00Q0<c<c003o`00003Vi^H0i^KV03<0i^KV00?o00000<c<
c03<c<`0=@3<c<`6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooom`ok>c/`03
0000003<c<`0c<c<02<0c<c<00?o00000>KViP3Vi^H0<P3Vi^H00ol00000c<c<0<c<c00e0<c<c0Ko
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooofoo/k>c0P00000U0<c<c003o`00
003Vi^H0i^KV0380i^KV00?o00000<c<c03<c<`0=@3<c<`6ooooo`7o00000Oooool000oooooo0_l0
0004ooooofco/k>c0`00000W0<c<c003o`00003Vi^H0i^KV0380i^KV00?o00000<c<c03<c<`0=@3<
c<`5ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00ooooomWok>c/`D00000:`3<c<`0
0ol00000i^KV0>KViP0`0>KViP03o`00003<c<`0c<c<03H0c<c<1_ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00?oooooA?nc/k<S00000340c<c<00?o00000>KViP3Vi^H0;`3Vi^H00ol0
0000c<c<0<c<c00f0<c<c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooc;o
/k>c4P00001D0<c<c003o`00003Vi^H0i^KV02l0i^KV00?o00000<c<c03<c<`0=P3<c<`6ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooolYok>c/`T00000I`3<c<`00ol00000i^KV
0>KViP0]0>KViP03o`00003<c<`0c<c<03L0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00?ooooo8?nc/k<900000740c<c<00?o00000>KViP3Vi^H0;03Vi^H00ol00000c<c<0<c<
c00g0<c<c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`ko/k>c4P00001j
0<c<c003o`00003Vi^H0i^KV02`0i^KV00?o00000<c<c03<c<`0=`3<c<`6ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00oooool5ok>c/`T00000S@3<c<`00ol00000i^KV0>KViP0Z0>KV
iP03o`00003<c<`0c<c<03P0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?o
oooo1@00002G0<c<c0;o0000:P3Vi^H00ol00000c<c<0<c<c00h0<c<c0Kooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`03oooooih0c<c<0_l0000X0>KViP03o`00003<c<`0c<c<03P0c<c<
1_ooool1o`00007ooooo000?ooooo`;o00001?oooonP0<c<c003o`00003Vi^H0i^KV02@0i^KV00?o
00000<c<c03<c<`0>@3<c<`5ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00ooooonQ
0<c<c0;o00008`3Vi^H00ol00000c<c<0<c<c00j0<c<c0Kooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`03oooooj<0c<c<0_l0000O0>KViP;o0000?@3<c<`6ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool00ooooonU0<c<c0;o00006`3Vi^H2o`0003l0c<c<1_ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00?oooooY`3<c<`00ol00000i^KV0>KViP0E0>KViP?o0000
@@3<c<`6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooonX0<c<c0;o00004`3V
i^H2o`0004@0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?oooooZP3<c<`4
o`0000/0i^KV1?l000160<c<c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooo
ojh0c<c<2ol0001:0<c<c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooool0
c<c<103<c<`6ooooo`7o00000Oooool000Sooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo
o`3<c<`40<c<c0Kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00?oooooo`3<c<`40<c<c0Kooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00004ooooo`?o00000ooooooo0<c<c0@0c<c<1Oooool2o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00ooooooo0<c<c0@0c<c<1_ooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooooooo0<c<c0@0c<c<
1_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0ooooooo0<c<c0@0c<c<1_ooool1o`00007ooooo0008ooooo`;o00001Oooool00ol0003ooooooooo
o`03ooooool0c<c<103<c<`6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooooo
0<c<c0@0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?oooooo`3<c<`40<c<
c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooool0c<c<103<c<`6ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooooo0<c<c0@0c<c<1_ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00?oooooo`3<c<`40<c<c0Kooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`03ooooool0c<c<103<c<`6ooooo`7o00000Oooool000oooooo0_l00004oooo
odd0c<c<4?l0002V0<c<c0Gooooo0_l00001ooooo`003oooool00ol0003oooooooooo`03ooooodH0
c<c<1ol0000@0>KViPCo0000XP3<c<`6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0ooooom30<c<c0?o00006`3Vi^H3o`0009l0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00?ooooo@03<c<`3o`000240i^KV0_l0002M0<c<c0Kooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`03oooooch0c<c<0_l0000V0>KViP?o0000VP3<c<`6ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00ooooolm0<c<c003o`00003Vi^H0i^KV02T0i^KV0_l0002H0<c<
c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooc`0c<c<00?o00000>KViP3V
i^H0;03Vi^H2o`0009H0c<c<1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo
>P3<c<`2o`000340i^KV00?o00000<c<c03<c<`0T`3<c<`6ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00oooooli0<c<c003o`00003Vi^H0i^KV0380i^KV0_l0002C0<c<c0Kooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`03ooooocP0c<c<00?o00000>KViP3Vi^H0=@3Vi^H0
0ol00000c<c<0<c<c02@0<c<c0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooo
ocL0c<c<00?o00000>KViP3Vi^H0=`3Vi^H00ol00000c<c<0<c<c02?0<c<c0Kooooo0Ol00001oooo
o`003oooool2o`0000Cooooo=@3<c<`2o`0003/0i^KV00?o00000<c<c03<c<`0SP3<c<`5ooooo`;o
00000Oooool000oooooo00?o0000ooooooooool00ooooole0<c<c003o`00003Vi^H0i^KV03X0i^KV
00?o00000<c<c03<c<`0SP3<c<`6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooo
oole0<c<c003o`00003Vi^H0i^KV03/0i^KV00?o00000<c<c03<c<`0S@3<c<`6ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00ooooold0<c<c003o`00003Vi^H0i^KV03d0i^KV00?o0000
0<c<c03<c<`0S03<c<`6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooold0<c<
c003o`00003Vi^H0i^KV03d0i^KV00?o00000<c<c03<c<`0O`3<c<`>000000Gooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`03oooooc@0c<c<00?o00000>KViP3Vi^H0?P3Vi^H00ol00000
c<c<0<c<c01e0<c<c0T000003@2c/k<6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0ooooold0<c<c003o`00003Vi^H0i^KV03l0i^KV00?o00000<c<c03<c<`0J`3<c<`9000001H0/k>c
1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo=03<c<`00ol00000i^KV0>KV
iP0o0>KViP03o`00003<c<`0c<c<05T0c<c<4P00000O0;>c/`Kooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`03oooooc<0c<c<00?o00000>KViP3Vi^H0@@3Vi^H00ol00000c<c<0<c<c017
0<c<c1400000<@2c/k<6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooolc0<c<
c003o`00003Vi^H0i^KV0480i^KV00?o00000<c<c03<c<`0:`3<c<`K00000480/k>c1_ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?ooooo<`3<c<`00ol00000i^KV0>KViP120>KViP03
o`00003<c<`0c<c<02P0c<c<0`00001M0;>c/`Kooooo0Ol00001ooooo`003oooool2o`0000Cooooo
<`3<c<`00ol00000i^KV0>KViP130>KViP03o`00003<c<`0c<c<02D0c<c<0P00001P0;>c/`Gooooo
0_l00001ooooo`003oooool00ol0003oooooooooo`03oooooc<0c<c<00?o00000>KViP3Vi^H0@`3V
i^H00ol00000c<c<0<c<c00U0<c<c0030000002c/k<0/k>c05l0/k>c1_ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00?ooooo<`3<c<`00ol00000i^KV0>KViP130>KViP03o`00003<c<`0
c<c<02@0c<c<00<000000;>c/`2c/k<0H02c/k<6ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00ooooold0<c<c003o`00003Vi^H0i^KV04<0i^KV00?o00000<c<c03<c<`08`3<c<`00`00
0000/k>c0;>c/`1P0;>c/`Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooc@0
c<c<00?o00000>KViP3Vi^H0@`3Vi^H00ol00000c<c<0<c<c00R0<c<c0030000002c/k<0/k>c0640
/k>c1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo=03<c<`00ol00000i^KV
0>KViP130>KViP03o`00003<c<`0c<c<0240c<c<00<000000;>c/`2c/k<0HP2c/k<6ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00ooooold0<c<c003o`00003Vi^H0i^KV04@0i^KV00?o
00000<c<c03<c<`0803<c<`00`000000/k>c0;>c/`1R0;>c/`Kooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`03ooooo`03o`000000000000000340c<c<00?o00000>KViP3Vi^H08@3Vi^H3
ool00200i^KV00?o00000<c<c03<c<`07`3<c<`00`000000/k>c0;>c/`1S0;>c/`Kooooo0Ol00001
ooooo`001_ooool5o`0000Cooooo00?o0000ooooooooool00oooool30;>c/`030000003<c<`0c<c<
02h0c<c<00?o00000>KViP3Vi^H0803Vi^H5ool001l0i^KV00?o00000<c<c03<c<`07`3<c<`00`00
0000/k>c0;>c/`1S0;>c/`Kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo102c/k<00`000000c<c<0<c<c00^0<c<c003o`00003Vi^H0i^KV
01l0i^KV1Ooo000O0>KViP03o`00003<c<`0c<c<01l0c<c<00<000000;>c/`2c/k<0H`2c/k<6oooo
o`7o00000Oooool000Sooooo00?o0000ooooooooool01?ooool3o`0000?ooooo1@2c/k<00`000000
c<c<0<c<c00]0<c<c003o`00003Vi^H0i^KV01l0i^KV1Ooo000O0>KViP03o`00003<c<`0c<c<01l0
c<c<00<000000;>c/`2c/k<0H`2c/k<5ooooo`;o00000Oooool000Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`H0/k>c00<000000<c<c03<c<`0;03<c<`00ol00000i^KV
0>KViP0P0>KViP?oo`00803Vi^H00ol00000c<c<0<c<c00O0<c<c0030000002c/k<0/k>c06<0/k>c
1_ooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`L0/k>c00<000000<c<c03<c<`0;03<c<`00ol00000i^KV0>KViP120>KViP03o`00
003<c<`0c<c<01h0c<c<00<000000;>c/`2c/k<0I02c/k<6ooooo`7o00000Oooool000Kooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo202c/k<00`000000c<c<
0<c<c00[0<c<c003o`00003Vi^H0i^KV0480i^KV00?o00000<c<c03<c<`07P3<c<`00`000000/k>c
0;>c/`1T0;>c/`Kooooo0Ol00001ooooo`001oooool3o`0000Gooooo00?o0000ooooooooool00ooo
ool90;>c/`800000;03<c<`00ol00000i^KV0>KViP110>KViP03o`00003<c<`0c<c<01h0c<c<00<0
00000;>c/`2c/k<0CP2c/k<Go`0000Gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03
ooooo`/0/k>c00<000000<c<c03<c<`0:@3<c<`00ol00000i^KV0>KViP110>KViP03o`00003<c<`0
c<c<01h0c<c<00<000000;>c/`2c/k<0:P2c/k<To`0001H0VIVI1_ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00?ooooo302c/k<00`000000c<c<0<c<c00Y0<c<c003o`00003Vi^H0i^KV
0400i^KV00?o00000<c<c03<c<`07P3<c<`00`000000/k>c0;>c/`0N0;>c/`co0000>P2IVIT6oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00oooool<0;>c/`030000003<c<`0c<c<02T0
c<c<00?o00000>KViP3Vi^H0@03Vi^H00ol00000c<c<0<c<c00N0<c<c0030000002c/k<0/k>c01/0
/k>c0ol0001609VIV@Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`d0/k>c
00<000000<c<c03<c<`0:@3<c<`00ol00000i^KV0>KViP0n0>KViP03o`00003<c<`0c<c<01l0c<c<
00<000000;>c/`2c/k<05P2c/k<5o`0004T0VIVI1_ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00?ooooo3P2c/k<00`000000c<c<0<c<c00Y0<c<c003o`00003Vi^H0i^KV03d0i^KV00?o
00000<c<c03<c<`07`3<c<`00`000000/k>c0;>c/`0D0;>c/`;o0000CP2IVIT6ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00oooool?0;>c/`030000003<c<`0c<c<02T0c<c<00?o0000
0>KViP3Vi^H0?03Vi^H00ol00000c<c<0<c<c00O0<c<c0030000002c/k<0/k>c01@0/k>c00?o0000
09VIV@2IVIT0C@2IVIT6ooooo`7o00000Oooool000oooooo0_l00004oooooa00/k>c00<000000<c<
c03<c<`0:@3<c<`00ol00000i^KV0>KViP0j0>KViP03o`00003<c<`0c<c<01l0c<c<00<000000;>c
/`2c/k<0502c/k<00ol00000VIVI09VIV@1>09VIV@Gooooo0_l00001ooooo`003oooool00ol0003o
ooooooooo`03oooooa40/k>c00<000000<c<c03<c<`0:03<c<`00ol00000i^KV0>KViP0j0>KViP03
o`00003<c<`0c<c<01l0c<c<00<000000;>c/`2c/k<04`2c/k<00ol00000VIVI09VIV@1?09VIV@Ko
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooa80/k>c0P00000Y0<c<c003o`00
003Vi^H0i^KV03T0i^KV00?o00000<c<c03<c<`07`3<c<`00`000000/k>c0;>c/`0C0;>c/`03o`00
002IVIT0VIVI04l0VIVI1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo502c
/k<00`000000c<c<0<c<c00W0<c<c003o`00003Vi^H0i^KV03L0i^KV00?o00000<c<c03<c<`0803<
c<`00`000000/k>c0;>c/`0B0;>c/`03o`00002IVIT0VIVI0500VIVI1_ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00?ooooo5@2c/k<00`000000c<c<0<c<c00W0<c<c0;o0000=`3Vi^H0
0ol00000c<c<0<c<c00P0<c<c0030000002c/k<0/k>c0140/k>c00?o000009VIV@2IVIT0D@2IVIT6
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooolE0;>c/`030000003<c<`0c<c<
02T0c<c<00?o00000>KViP3Vi^H0=03Vi^H00ol00000c<c<0<c<c00P0<c<c0030000002c/k<0/k>c
0140/k>c00?o000009VIV@2IVIT0D@2IVIT6ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00ooooolF0;>c/`030000003<c<`0c<c<02T0c<c<00?o00000>KViP3Vi^H0<P3Vi^H00ol00000
c<c<0<c<c00Q0<c<c0030000002c/k<0/k>c0140/k>c00?o000009VIV@2IVIT0D@2IVIT6ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooolG0;>c/`030000003<c<`0c<c<02T0c<c<
00?o00000>KViP3Vi^H0<03Vi^H00ol00000c<c<0<c<c00R0<c<c0030000002c/k<0/k>c0140/k>c
00?o000009VIV@2IVIT0:@2IVITYo`0000Gooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`03oooooaP0/k>c00<000000<c<c03<c<`0:@3<c<`00ol00000i^KV0>KViP0_0>KViP03o`00003<
c<`0c<c<0280c<c<00<000000;>c/`2c/k<04@2c/k<00ol00000VIVI09VIV@0G09VIVA;o0000:01o
Ogl6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooooolI0;>c/`030000003<c<`0
c<c<02T0c<c<00?o00000>KViP3Vi^H0;@3Vi^H00ol00000c<c<0<c<c00R0<c<c0030000002c/k<0
/k>c0140/k>c00?o000009VIV@2IVIT04`2IVIT5o`0003X0Ogmo1_ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00?ooooo6P2c/k<00`000000c<c<0<c<c00Y0<c<c003o`00003Vi^H0i^KV
02/0i^KV00?o00000<c<c03<c<`08`3<c<`00`000000/k>c0;>c/`0A0;>c/`03o`00002IVIT0VIVI
0140VIVI0_l0000o07moO`Kooooo0Ol00001ooooo`003oooool2o`0000Cooooo6`2c/k<00`000000
c<c<0<c<c00Y0<c<c003o`00003Vi^H0i^KV02T0i^KV00?o00000<c<c03<c<`0903<c<`00`000000
/k>c0;>c/`0A0;>c/`03o`00002IVIT0VIVI00l0VIVI0_l0001107moO`Gooooo0_l00001ooooo`00
3oooool00ol0003oooooooooo`03oooooa`0/k>c00<000000<c<c03<c<`0:@3<c<`00ol00000i^KV
0>KViP0W0>KViP03o`00003<c<`0c<c<02D0c<c<00<000000;>c/`2c/k<04@2c/k<00ol00000VIVI
09VIV@0=09VIV@;o0000@`1oOgl6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooo
oolM0;>c/`030000003<c<`0c<c<02T0c<c<0_l0000U0>KViP;o0000:03<c<`00`000000/k>c0;>c
/`0A0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007moO`1oOgl0@`1oOgl6ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00ooooolN0;>c/`030000003<c<`0c<c<02X0c<c<0ol0000P
0>KViP;o0000:P3<c<`00`000000/k>c0;>c/`0A0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o0000
07moO`1oOgl0@`1oOgl6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool2o`00
01d0/k>c00<000000<c<c03<c<`0;03<c<`3o`0001/0i^KV0_l0000/0<c<c0030000002c/k<0/k>c
0140/k>c00?o000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`1307moO`Kooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`03ooooo`80VIVI00?o00000;>c/`2c/k<06`2c/k<00`000000
c<c<0<c<c00^0<c<c0?o00005@3Vi^H3o`0002d0c<c<00<000000;>c/`2c/k<04P2c/k<00ol00000
VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo04<0Ogmo1_ooool1o`00007ooooo000?ooooo`03o`00
0?oooooooooo00?ooooo0`2IVIT00ol00000/k>c0;>c/`0K0;>c/`030000003<c<`0c<c<0300c<c<
1Ol0000;0>KViPGo0000<03<c<`00`000000/k>c0;>c/`0B0;>c/`03o`00002IVIT0VIVI00`0VIVI
00?o000007moO`1oOgl0@`1oOgl6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooo
ool409VIV@;o0000702c/k<00`000000c<c<0<c<c00d0<c<c0_o0000=@3<c<`00`000000/k>c0;>c
/`0A0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007moO`1oOgl0701oOglYo`0000Gooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`03ooooo`H0VIVI00?o00000;>c/`2c/k<06P2c/k<0
0`000000c<c<0<c<c01c0<c<c0030000002c/k<0/k>c0140/k>c00?o000009VIV@2IVIT0302IVIT0
0ol00000Ogmo07moO`0C07moO`Wo0000:01VIVH6ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00oooool709VIV@03o`00002c/k<0/k>c01X0/k>c00<000000<c<c03<c<`0LP3<c<`00`00
0000/k>c0;>c/`0A0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007moO`1oOgl03@1oOgl6o`00
0340IVIV1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo202IVIT00ol00000
/k>c0;>c/`0J0;>c/`030000003<c<`0c<c<0700c<c<00<000000;>c/`2c/k<04P2c/k<00ol00000
VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00/0Ogmo0_l0000g06IVIPKooooo0Ol00001ooooo`00
3oooool2o`0000Cooooo2@2IVIT2o`0001/0/k>c00<000000<c<c03<c<`0K`3<c<`00`000000/k>c
0;>c/`0B0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007moO`1oOgl02P1oOgl00ol00000IVIV
06IVIP0g06IVIPGooooo0_l00001ooooo`003oooool00ol0003oooooooooo`03ooooo`/0VIVI00?o
00000;>c/`2c/k<06@2c/k<00`000000c<c<0<c<c01^0<c<c003o`00002c/k<0/k>c0180/k>c00?o
000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`0:07moO`03o`00001VIVH0IVIV03L0IVIV1_oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo302IVIT00ol00000/k>c0;>c/`0I
0;>c/`030000003<c<`0c<c<06d0c<c<00<000000;>c/`2c/k<04P2c/k<00ol00000VIVI09VIV@0<
09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0>01VIVH6ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00oooool=09VIV@03o`00002c/k<0/k>c01T0/k>c00<000000<c<
c03<c<`0K03<c<`00`000000/k>c0;>c/`0B0;>c/`03o`00002IVIT0VIVI00/0VIVI00?o000007mo
O`1oOgl02P1oOgl00ol00000IVIV06IVIP0h06IVIPKooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`03ooooo`h0VIVI00?o00000;>c/`2c/k<06@2c/k<00`000000c<c<0<c<c01Z0<c<c003
0000002c/k<0/k>c01<0/k>c00?o000009VIV@2IVIT02`2IVIT00ol00000Ogmo07moO`0:07moO`03
o`00001VIVH0IVIV03P0IVIV1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo
3`2IVIT00ol00000/k>c0;>c/`0I0;>c/`030000003<c<`0c<c<06T0c<c<00<000000;>c/`2c/k<0
4P2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0
8`1VIVHGo`0000Gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooa00VIVI00?o
00000;>c/`2c/k<06@2c/k<00`000000c<c<0<c<c01X0<c<c0030000002c/k<0/k>c0180/k>c00?o
000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV0140IVIV4_l0
000F04a<C0Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03oooooa40VIVI00?o0000
0;>c/`2c/k<06@2c/k<2000006P0c<c<00<000000;>c/`2c/k<04P2c/k<00ol00000VIVI09VIV@0<
09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH02`1VIVH6o`0002P0C4a<1_ooool1
o`00007ooooo0008ooooo`?o00001?ooool00ol0003oooooooooo`03oooooa80VIVI00?o00000;>c
/`2c/k<06P2c/k<00`000000c<c<0<c<c01T0<c<c0030000002c/k<0/k>c01<0/k>c00?o000009VI
V@2IVIT02`2IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00X0IVIV0_l0000^04a<
C0Kooooo0Ol00001ooooo`002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo4`2IVIT00ol00000/k>c0;>c/`0J0;>c/`800000I03<c<`00`000000/k>c0;>c/`0C0;>c/`03
o`00002IVIT0VIVI00/0VIVI00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0906IVIP03
o`00001<C4`0C4a<02h0C4a<1_ooool1o`00007ooooo0006ooooo`Go00001?ooool3o`0000?ooooo
502IVIT00ol00000/k>c0;>c/`0K0;>c/`030000003<c<`0c<c<0640c<c<00<000000;>c/`2c/k<0
4`2c/k<00ol00000VIVI09VIV@0;09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0
2@1VIVH00ol00000C4a<04a<C00^04a<C0Gooooo0_l00001ooooo`001_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00?ooooo5@2IVIT00ol00000/k>c0;>c/`0K0;>c/`800000
H@3<c<`00`000000/k>c0;>c/`0C0;>c/`03o`00002IVIT0VIVI00/0VIVI00?o000007moO`1oOgl0
2@1oOgl00ol00000IVIV06IVIP0906IVIP03o`00001<C4`0C4a<02h0C4a<1_ooool1o`00007ooooo
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ooooolF09VIV@03o`00002c
/k<0/k>c01`0/k>c00<000000<c<c03<c<`0G@3<c<`00`000000/k>c0;>c/`0D0;>c/`03o`00002I
VIT0VIVI00/0VIVI00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0806IVIP03o`00001<
C4`0C4a<02l0C4a<1_ooool1o`00007ooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`03
oooooaL0VIVI00?o00000;>c/`2c/k<0702c/k<2000005d0c<c<00<000000;>c/`2c/k<0502c/k<0
0ol00000VIVI09VIV@0;09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0201VIVH0
0ol00000C4a<04a<C00_04a<C0Kooooo0Ol00001ooooo`002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo0_l0000F09VIV@03o`00002c/k<0/k>c01d0/k>c00<000000<c<
c03<c<`0FP3<c<`00`000000/k>c0;>c/`0C0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007mo
O`1oOgl02@1oOgl00ol00000IVIV06IVIP0806IVIP03o`00001<C4`0C4a<0100C4a<8?l00005oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00oooool207moO`03o`00002IVIT0VIVI01@0
VIVI00?o00000;>c/`2c/k<07@2c/k<2000005X0c<c<00<000000;>c/`2c/k<04`2c/k<00ol00000
VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0201VIVH00ol00000
C4a<04a<C00:04a<C0Ko00007`0c<c<6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0oooool307moO`03o`00002IVIT0VIVI01@0VIVI00?o00000;>c/`2c/k<07P2c/k<2000005P0c<c<
00<000000;>c/`2c/k<04`2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo
00?o000006IVIP1VIVH0201VIVH00ol00000C4a<04a<C00804a<C0;o00009@0c<c<6ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00oooool407moO`03o`00002IVIT0VIVI01@0VIVI00?o
00000;>c/`2c/k<07`2c/k<00`000000c<c<0<c<c01D0<c<c0030000002c/k<0/k>c01@0/k>c00?o
000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o
000004a<C01<C4`01`1<C4`2o`0002L0<c<c1_ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00?ooooo1@1oOgl2o`0001D0VIVI0_l0000P0;>c/`03o`0000000000000005<0c<c<00<00000
0;>c/`2c/k<0502c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o0000
06IVIP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c02L0<c<c1_ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo1`1oOgl00ol00000VIVI09VIV@0D09VI
V@03o`00002c/k<0/k>c0200/k>c0P00001A0<c<c0030000002c/k<0/k>c01@0/k>c00?o000009VI
V@2IVIT0302IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<
C01<C4`01P1<C4`00ol00000<c<c03<c<`0W03<c<`Kooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`03ooooo`P0Ogmo00?o000009VIV@2IVIT0502IVIT00ol00000/k>c0;>c/`0Q0;>c/`80
0000CP3<c<`00`000000/k>c0;>c/`0E0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007moO`1o
Ogl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<00?o000003<c<`0c
<c<09`0c<c<6ooooo`7o00000Oooool000oooooo0_l00004ooooo`T0Ogmo00?o000009VIV@2IVIT0
502IVIT2o`0002<0/k>c00<000000<c<c03<c<`0B`3<c<`00`000000/k>c0;>c/`0E0;>c/`03o`00
002IVIT0VIVI00`0VIVI00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00
001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<04@0c<c<Go`0000Cooooo0_l00001ooooo`003ooo
ool00ol0003oooooooooo`03ooooo`X0Ogmo00?o000009VIV@2IVIT05@2IVIT00ol00000/k>c0;>c
/`0Q0;>c/`800000B`3<c<`00`000000/k>c0;>c/`0E0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o
000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<00?o
000003<c<`0c<c<02`0c<c<6o`0001H06ATI1_ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00?ooooo2`1oOgl00ol00000VIVI09VIV@0E09VIV@03o`00002c/k<0/k>c0280/k>c0P000018
0<c<c0030000002c/k<0/k>c01D0/k>c00?o000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`09
07moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0;
03<c<`03o`00000I6AT06ATI01X06ATI1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00?ooooo301oOgl00ol00000VIVI09VIV@0E09VIV@;o0000902c/k<2000004H0c<c<00<000000;>c
/`2c/k<05@2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IV
IP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00X0<c<c00?o000001TI
6@0I6AT06`0I6AT6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool=07moO`03
o`00002IVIT0VIVI01H0VIVI00?o00000;>c/`2c/k<08`2c/k<3000004<0c<c<00<000000;>c/`2c
/k<05@2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1V
IVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00T0<c<c00?o000001TI6@0I
6AT0700I6AT6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool>07moO`03o`00
002IVIT0VIVI01H0VIVI00?o00000;>c/`2c/k<09@2c/k<200000400c<c<00<000000;>c/`2c/k<0
5P2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0
1`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00P0<c<c00?o000001TI6@0I6AT0
7@0I6AT6ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool?07moO`;o00005`2I
VIT2o`0002L0/k>c0P00000n0<c<c0030000002c/k<0/k>c01H0/k>c00?o000009VIV@2IVIT0302I
VIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<
C4`00ol00000<c<c03<c<`0703<c<`03o`00000I6AT06ATI01h06ATI1_ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00?ooooo4@1oOgl00ol00000VIVI09VIV@0F09VIV@;o00009`2c/k<2
000003`0c<c<00<000000;>c/`2c/k<05P2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0
Ogmo00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0
<c<c00L0<c<c00?o000001TI6@0I6AT02`0I6ATDo`0000Gooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`03oooooa80Ogmo0_l0000H09VIV@03o`00002c/k<0/k>c02H0/k>c0`00000h0<c<
c0030000002c/k<0/k>c01L0/k>c00?o000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`0907mo
O`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0703<c
<`03o`00000I6AT06ATI00X06ATI00?o00000000000000004@000006ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool00ooooolD07moO`03o`00002IVIT0VIVI01H0VIVI0_l0000Y0;>c/`80
0000=P3<c<`00`000000/k>c0;>c/`0G0;>c/`03o`00002IVIT0VIVI00`0VIVI00?o000007moO`1o
Ogl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<00?o000003<c<`0c
<c<01P0c<c<00ol000006ATI01TI6@0:01TI6@03o`00000000000000018000001_ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00?ooooo00?o000007moO`1oOgl04P1oOgl00ol00000VIVI
09VIV@0G09VIV@;o0000:@2c/k<2000003@0c<c<00<000000;>c/`2c/k<05`2c/k<00ol00000VIVI
09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<
04a<C00604a<C003o`00000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT0200I6AT2o`0001D00000
1_ooool1o`00007ooooo000?ooooo`;o00001?ooool00`1VIVKo000007moO`0C07moO`03o`00002I
VIT0VIVI01P0VIVI0_l0000Y0;>c/`030000003<c<`0c<c<0300c<c<00<000000;>c/`2c/k<0602c
/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH01`1V
IVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT01`0I
6AT00ol0000000000000000E000000Gooooo0_l00001ooooo`003oooool00ol0003oooooooooo`03
ooooo`80IVIV00?o000007moO`1oOgl04P1oOgl00ol00000VIVI09VIV@0I09VIV@03o`00002c/k<0
/k>c02L0/k>c0P00000`0<c<c0030000002c/k<0/k>c01L0/k>c00?o000009VIV@2IVIT03@2IVIT0
0ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`0
0ol00000<c<c03<c<`0603<c<`03o`00000I6AT06ATI00H06ATI00?o00000000000000005P000006
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool306IVIP03o`00001oOgl0Ogmo
0180Ogmo00?o000009VIV@2IVIT06@2IVIT2o`0002T0/k>c0P00000^0<c<c0030000002c/k<0/k>c
01L0/k>c00?o000009VIV@2IVIT03@2IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV
00L0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0603<c<`03o`00000I6AT06ATI
00D06ATI00?o00000000000000005`000006ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00oooool406IVIP03o`00001oOgl0Ogmo0180Ogmo00?o000009VIV@2IVIT06P2IVIT00ol00000
/k>c0;>c/`0X0;>c/`030000003<c<`0c<c<02X0c<c<00<000000;>c/`2c/k<0602c/k<00ol00000
VIVI09VIV@0=09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000
C4a<04a<C00604a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01@0I6AT00ol00000
00000000000H000000Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`D0IVIV
0_l0000C07moO`?o00006@2IVIT2o`0002X0/k>c0P00000Z0<c<c0030000002c/k<0/k>c01P0/k>c
00?o000009VIV@2IVIT03@2IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV
00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00D06ATI
00?o000000000000000060000006ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00ooo
ool706IVIP03o`00001oOgl0Ogmo01<0Ogmo00?o000009VIV@2IVIT0602IVIT2o`0002X0/k>c0P00
000X0<c<c0030000002c/k<0/k>c01P0/k>c00?o000009VIV@2IVIT03@2IVIT00ol00000Ogmo07mo
O`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c
<`0503<c<`03o`00000I6AT06ATI00D06ATI00?o000000000000000060000006ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00oooool806IVIP03o`00001oOgl0Ogmo01<0Ogmo0_l0000J
09VIV@?o0000:@2c/k<2000002D0c<c<00<000000;>c/`2c/k<06@2c/k<00ol00000VIVI09VIV@0=
09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<04a<C006
04a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01@0I6AT00ol0000000000000000H
000000Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`T0IVIV0_l0000E07mo
O`03o`00002IVIT0VIVI01X0VIVI0_l0000Y0;>c/`030000003<c<`0c<c<0280c<c<00<000000;>c
/`2c/k<06@2c/k<00ol00000VIVI09VIV@0=09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IV
IP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI
6@0I6AT01@0I6AT00ol0000000000000000H000000Kooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`03ooooo`/0IVIV00?o000007moO`1oOgl04`1oOgl2o`0001`0VIVI0_l0000X0;>c/`80
00008@3<c<`00`000000/k>c0;>c/`0J0;>c/`03o`00002IVIT0VIVI00d0VIVI00?o000007moO`1o
Ogl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<00?o000003<c<`0c
<c<01@0c<c<00ol000006ATI01TI6@0501TI6@03o`0000000000000001P000001_ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00?ooooo301VIVH00ol00000Ogmo07moO`0D07moO`03o`00
002IVIT0VIVI01/0VIVI00?o00000;>c/`2c/k<09`2c/k<00`000000c<c<0<c<c00N0<c<c0030000
002c/k<0/k>c01X0/k>c00?o000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`0:07moO`03o`00
001VIVH0IVIV00H0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0503<c<`03o`00
000I6AT06ATI00D06ATI00?o00000000000000006@000006ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00oooool=06IVIP03o`00001oOgl0Ogmo01@0Ogmo00?o000009VIV@2IVIT06`2I
VIT00ol00000/k>c0;>c/`0W0;>c/`030000003<c<`0c<c<01d0c<c<00<000000;>c/`2c/k<06P2c
/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo00X0Ogmo00?o000006IVIP1VIVH01P1V
IVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01@0I
6AT00ol0000000000000000I000000Kooooo0Ol00001ooooo`003oooool2o`0000Cooooo3P1VIVH0
0ol00000Ogmo07moO`0D07moO`03o`00002IVIT0VIVI01/0VIVI00?o00000;>c/`2c/k<09`2c/k<0
0`000000c<c<0<c<c00K0<c<c0030000002c/k<0/k>c01/0/k>c00?o000009VIV@2IVIT0302IVIT0
0ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`0
0ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00D06ATI00?o00000000000000006@000005
ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00oooool?06IVIP03o`00001oOgl0Ogmo
01@0Ogmo00?o000009VIV@2IVIT06`2IVIT00ol00000/k>c0;>c/`0W0;>c/`030000003<c<`0c<c<
01X0c<c<00<000000;>c/`2c/k<06`2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo
00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c
00D0<c<c00?o000001TI6@0I6AT01@0I6AT00ol0000000000000000I000000Kooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`03oooooa00IVIV0_l0000E07moO`;o0000702IVIT3o`0002L0
/k>c0P00000I0<c<c0030000002c/k<0/k>c01`0/k>c00?o000009VIV@2IVIT0302IVIT00ol00000
Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000
<c<c03<c<`0503<c<`03o`00000I6AT06ATI00D06ATI00?o00000000000000006@000006ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00ooooolB06IVIP;o00005@1oOgl2o`0001d0VIVI
0_l0000W0;>c/`<000005@3<c<`00`000000/k>c0;>c/`0M0;>c/`03o`00002IVIT0VIVI00`0VIVI
00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<
00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0501TI6@03o`0000000000000001T00000
1_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo0_l0000B06IVIP03o`00001o
Ogl0Ogmo01@0Ogmo0_l0000M09VIV@03o`00002c/k<0/k>c02L0/k>c0P00000B0<c<c0030000002c
/k<0/k>c01h0/k>c00?o000009VIV@2IVIT0302IVIT00ol00000Ogmo07moO`0907moO`03o`00001V
IVH0IVIV00L0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I
6AT06ATI00D06ATI00?o00000000000000006@000006ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00oooool204a<C003o`00001VIVH0IVIV0100IVIV0_l0000F07moO`;o0000702IVIT0
0ol00000/k>c0;>c/`0X0;>c/`8000003`3<c<`00`000000/k>c0;>c/`0O0;>c/`03o`00002IVIT0
VIVI00`0VIVI00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0
C4a<00H0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0501TI6@03o`0000000000
000001T000001_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo0`1<C4`2o`00
0180IVIV00?o000007moO`1oOgl05@1oOgl00ol00000VIVI09VIV@0J09VIV@03o`00002c/k<0/k>c
02T0/k>c0P00000;0<c<c08000008P2c/k<00ol00000VIVI09VIV@0<09VIV@03o`00001oOgl0Ogmo
00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c
00D0<c<c00?o000001TI6@0I6AT01@0I6AT00ol0000000000000000I000000Kooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`03ooooo`D0C4a<00?o000006IVIP1VIVH0401VIVH2o`0001H0
Ogmo0_l0000K09VIV@03o`00002c/k<0/k>c02X0/k>c00<000000<c<c03<c<`01@3<c<`3000002<0
/k>c00?o000009VIV@2IVIT03@2IVIT00ol00000Ogmo07moO`0907moO`03o`00001VIVH0IVIV00L0
IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00D0
6ATI00?o00000000000000006@000006ooooo`7o00000Oooool000Oooooo0ol00005ooooo`03o`00
0?oooooooooo00?ooooo1P1<C4`2o`000180IVIV00?o000007moO`1oOgl05@1oOgl2o`0001X0VIVI
00?o00000;>c/`2c/k<0:P2c/k<200000080c<c<0`00000V0;>c/`03o`00002IVIT0VIVI00d0VIVI
00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<
00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0501TI6@03o`0000000000000001T00000
1_ooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`P0C4a<00?o000006IVIP1VIVH0401VIVH2o`0001L0Ogmo00?o000009VIV@2IVIT0
602IVIT00ol00000/k>c0;>c/`0[0;>c/`800000:@2c/k<00ol00000VIVI09VIV@0=09VIV@03o`00
001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00
000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01@0I6AT00ol0000000000000000I000000Kooooo
0Ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00003ooooo`T0C4a<
00?o000006IVIP1VIVH04@1VIVH00ol00000Ogmo07moO`0E07moO`03o`00002IVIT0VIVI01P0VIVI
00?o00000;>c/`2c/k<0E@2c/k<00ol00000VIVI09VIV@0=09VIV@03o`00001oOgl0Ogmo00T0Ogmo
00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00D0<c<c
00?o000001TI6@0I6AT01@0I6AT00ol0000000000000000I000000Gooooo0_l00001ooooo`001_oo
ool4o`0000Gooooo00?o0000ooooooooool0ooooool=ooooo`7o00000Oooool000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo3Oooool1o`00007ooooo0008ooooo`;o
00001Oooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`003oooooooo`00017o00000Oooool0
0?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-7.01451, -6.94779, 0.0464125, \
0.0464125}}],

Cell[BoxData[
    \({{\(-1.8982076661870237`\), 
        1.9203781909450985`}, {2.0127572774801945`, \
\(-1.7728737651825182`\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihoodLocal3[data, params2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.07624 .22703 -12 -8.84372 ]
[.07624 .22703 0 .15628 ]
[.20215 .17748 -23.3893 -9 ]
[.20215 .17748 .61073 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.47379 .07065 -15.9783 -9 ]
[.47379 .07065 2.02174 0 ]
[.6206 .01296 -5.06547 -9 ]
[.6206 .01296 .93453 0 ]
[.72942 .0388 0 -6.21888 ]
[.72942 .0388 12 2.78112 ]
[.79593 .14064 0 -6.11966 ]
[.79593 .14064 24 2.88034 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.91188 .3182 0 -5.95203 ]
[.91188 .3182 18 3.04797 ]
[.96273 .39607 0 -5.88058 ]
[.96273 .39607 6 3.11942 ]
[.02416 .26481 -30 -2.74206 ]
[.02416 .26481 0 6.25794 ]
[.01284 .33576 -30 -2.80209 ]
[.01284 .33576 0 6.19791 ]
[.00099 .41006 -24 -2.86523 ]
[.00099 .41006 0 6.13477 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.08568 .23614 m
.0904 .2407 L
s
[(-5)] .07624 .22703 1 .96527 Mshowa
.21118 .187 m
.2157 .19176 L
s
[(-2.5)] .20215 .17748 .94911 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.48183 .08102 m
.48585 .0862 L
s
[(2.5)] .47379 .07065 .77536 1 Mshowa
.62804 .02377 m
.63176 .02917 L
s
[(5)] .6206 .01296 .68849 1 Mshowa
.125 Mabswid
.11029 .2265 m
.1131 .22926 L
s
.13514 .21677 m
.13793 .21955 L
s
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.26314 .16665 m
.2658 .16956 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.37025 .12471 m
.37279 .12772 L
s
.39772 .11395 m
.40023 .11699 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.53939 .05848 m
.54173 .06164 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.0613 .24568 m
.06416 .24839 L
s
.65822 .01195 m
.66042 .01522 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.71716 .04348 m
.71104 .04583 L
s
[(-5)] .72942 .0388 -1 .38197 Mshowa
.78358 .14509 m
.77741 .14731 L
s
[(-2.5)] .79593 .14064 -1 .35992 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.89939 .32223 m
.89315 .32425 L
s
[(2.5)] .91188 .3182 -1 .32267 Mshowa
.95018 .39992 m
.94391 .40184 L
s
[(5)] .96273 .39607 -1 .3068 Mshowa
.125 Mabswid
.73096 .06459 m
.72728 .06598 L
s
.7445 .0853 m
.74081 .08667 L
s
.75778 .10561 m
.75408 .10697 L
s
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.80845 .18312 m
.80473 .18442 L
s
.82054 .20161 m
.81682 .20291 L
s
.83241 .21978 m
.82869 .22106 L
s
.85553 .25514 m
.8518 .25639 L
s
.86679 .27235 m
.86305 .2736 L
s
.87784 .28927 m
.87411 .2905 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.92022 .35409 m
.91647 .35528 L
s
.93037 .36962 m
.92662 .3708 L
s
.94036 .3849 m
.9366 .38606 L
s
.70309 .02196 m
.69942 .02338 L
s
.95984 .4147 m
.95608 .41584 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03638 .26003 m
.0425 .25765 L
s
[(-1500)] .02416 .26481 1 -0.39065 Mshowa
.02512 .33113 m
.03126 .32881 L
s
[(-1000)] .01284 .33576 1 -0.37731 Mshowa
.01332 .40558 m
.01949 .40334 L
s
[(-500)] .00099 .41006 1 -0.36328 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03417 .274 m
.03784 .27257 L
s
.03194 .28808 m
.03561 .28667 L
s
.02969 .3023 m
.03336 .30089 L
s
.02741 .31665 m
.03109 .31525 L
s
.0228 .34574 m
.02649 .34436 L
s
.02046 .36049 m
.02415 .35912 L
s
.0181 .37538 m
.0218 .37402 L
s
.01572 .39041 m
.01942 .38906 L
s
.01089 .42089 m
.0146 .41956 L
s
.00844 .43635 m
.01215 .43503 L
s
.00597 .45196 m
.00968 .45065 L
s
.00347 .46772 m
.00719 .46641 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.428 0 0 r
.3918 .66668 .403 .66446 .42071 .66873 .40961 .67089 Metetra
.377 0 0 r
.40961 .67089 .42071 .66873 .43866 .67222 .42768 .67425 Metetra
.321 0 0 r
.42768 .67425 .43866 .67222 .45683 .67505 .44597 .67678 Metetra
.258 0 0 r
.44597 .67678 .45683 .67505 .47522 .67734 .46449 .67861 Metetra
.187 0 0 r
.46449 .67861 .47522 .67734 .49382 .67923 .48321 .67984 Metetra
.105 0 0 r
.48321 .67984 .49382 .67923 .51263 .68091 .50215 .68059 Metetra
0 .57 .716 r
.50215 .68059 .51263 .68091 .53164 .68242 .52128 .68102 Metetra
.101 .65 .822 r
.52128 .68102 .53164 .68242 .55086 .68376 .54061 .68115 Metetra
.216 .716 .911 r
.54061 .68115 .55086 .68376 .57028 .68472 .56013 .68096 Metetra
.326 .761 .968 r
.56013 .68096 .57028 .68472 .5899 .68512 .57984 .68025 Metetra
.421 .787 .995 r
.57984 .68025 .5899 .68512 .60971 .68474 .59973 .67886 Metetra
.5 .799 .999 r
.59973 .67886 .60971 .68474 .62968 .68342 .61979 .67655 Metetra
.564 .801 .988 r
.61979 .67655 .62968 .68342 .6498 .68086 .63999 .67314 Metetra
.617 .8 .969 r
.63999 .67314 .6498 .68086 .67004 .67672 .66032 .66836 Metetra
.662 .8 .949 r
.66032 .66836 .67004 .67672 .69035 .67077 .68072 .66192 Metetra
.701 .802 .928 r
.68072 .66192 .69035 .67077 .7107 .6629 .70118 .65362 Metetra
.733 .802 .906 r
.70118 .65362 .7107 .6629 .73106 .653 .72164 .64333 Metetra
.761 .802 .886 r
.72164 .64333 .73106 .653 .75138 .64097 .74206 .63096 Metetra
.785 .802 .866 r
.74206 .63096 .75138 .64097 .77161 .62671 .76242 .61641 Metetra
.807 .802 .847 r
.76242 .61641 .77161 .62671 .79172 .61015 .78265 .59962 Metetra
.825 .802 .829 r
.78265 .59962 .79172 .61015 .81165 .59127 .80271 .58054 Metetra
.842 .802 .812 r
.80271 .58054 .81165 .59127 .83137 .57007 .82257 .55917 Metetra
.857 .802 .796 r
.82257 .55917 .83137 .57007 .85083 .54656 .84217 .53552 Metetra
.87 .802 .781 r
.84217 .53552 .85083 .54656 .86998 .52082 .86149 .50968 Metetra
.882 .803 .767 r
.86149 .50968 .86998 .52082 .88881 .49291 .88048 .48178 Metetra
.892 .805 .756 r
.88048 .48178 .88881 .49291 .90727 .46299 .89915 .45217 Metetra
.853 .811 .809 r
.89915 .45217 .90727 .46299 .92668 .44208 .91859 .43023 Metetra
.664 .741 .907 r
.91859 .43023 .92668 .44208 .94794 .43568 .93996 .42375 Metetra
.664 .741 .907 r
.93996 .42375 .94794 .43568 .96935 .42924 .96149 .41722 Metetra
.376 0 0 r
.38042 .66792 .3918 .66668 .40961 .67089 .39834 .67191 Metetra
.318 0 0 r
.39834 .67191 .40961 .67089 .42768 .67425 .41651 .67519 Metetra
.252 0 0 r
.41651 .67519 .42768 .67425 .44597 .67678 .43492 .67758 Metetra
.18 0 0 r
.43492 .67758 .44597 .67678 .46449 .67861 .45356 .67913 Metetra
.101 0 0 r
.45356 .67913 .46449 .67861 .48321 .67984 .47241 .67991 Metetra
.015 0 0 r
.47241 .67991 .48321 .67984 .50215 .68059 .49147 .68002 Metetra
.079 .638 .778 r
.49147 .68002 .50215 .68059 .52128 .68102 .51073 .67959 Metetra
.179 .705 .861 r
.51073 .67959 .52128 .68102 .54061 .68115 .53017 .67871 Metetra
.28 .758 .93 r
.53017 .67871 .54061 .68115 .56013 .68096 .54981 .67742 Metetra
.375 .793 .976 r
.54981 .67742 .56013 .68096 .57984 .68025 .56962 .67566 Metetra
.458 .812 .997 r
.56962 .67566 .57984 .68025 .59973 .67886 .58961 .67325 Metetra
.528 .819 .999 r
.58961 .67325 .59973 .67886 .61979 .67655 .60976 .67 Metetra
.585 .818 .988 r
.60976 .67 .61979 .67655 .63999 .67314 .63005 .66571 Metetra
.632 .814 .97 r
.63005 .66571 .63999 .67314 .66032 .66836 .65047 .66018 Metetra
.673 .81 .949 r
.65047 .66018 .66032 .66836 .68072 .66192 .67097 .65315 Metetra
.708 .808 .927 r
.67097 .65315 .68072 .66192 .70118 .65362 .69152 .64438 Metetra
.738 .807 .906 r
.69152 .64438 .70118 .65362 .72164 .64333 .71209 .6337 Metetra
.765 .806 .886 r
.71209 .6337 .72164 .64333 .74206 .63096 .73263 .62098 Metetra
.788 .805 .866 r
.73263 .62098 .74206 .63096 .76242 .61641 .75311 .60613 Metetra
.809 .804 .847 r
.75311 .60613 .76242 .61641 .78265 .59962 .77346 .58909 Metetra
.827 .804 .829 r
.77346 .58909 .78265 .59962 .80271 .58054 .79367 .56981 Metetra
.843 .804 .813 r
.79367 .56981 .80271 .58054 .82257 .55917 .81366 .54828 Metetra
.858 .804 .797 r
.81366 .54828 .82257 .55917 .84217 .53552 .83342 .52454 Metetra
.871 .805 .783 r
.83342 .52454 .84217 .53552 .86149 .50968 .8529 .49872 Metetra
.882 .808 .772 r
.8529 .49872 .86149 .50968 .88048 .48178 .87211 .47119 Metetra
.888 .816 .77 r
.87211 .47119 .88048 .48178 .89915 .45217 .89115 .44328 Metetra
.868 .849 .822 r
.89115 .44328 .89915 .45217 .91859 .43023 .91075 .42119 Metetra
.716 .821 .93 r
.91075 .42119 .91859 .43023 .93996 .42375 .93189 .41166 Metetra
.664 .741 .907 r
.93189 .41166 .93996 .42375 .96149 .41722 .95353 .40504 Metetra
.307 0 0 r
.36886 .66839 .38042 .66792 .39834 .67191 .3869 .6719 Metetra
.244 0 0 r
.3869 .6719 .39834 .67191 .41651 .67519 .40518 .67495 Metetra
.169 0 0 r
.40518 .67495 .41651 .67519 .43492 .67758 .4237 .67724 Metetra
.089 0 0 r
.4237 .67724 .43492 .67758 .45356 .67913 .44245 .67864 Metetra
0 .574 .724 r
.44245 .67864 .45356 .67913 .47241 .67991 .46142 .67914 Metetra
.084 .641 .789 r
.46142 .67914 .47241 .67991 .49147 .68002 .4806 .67883 Metetra
.173 .703 .85 r
.4806 .67883 .49147 .68002 .51073 .67959 .49998 .6778 Metetra
.262 .756 .907 r
.49998 .6778 .51073 .67959 .53017 .67871 .51956 .67613 Metetra
.348 .796 .954 r
.51956 .67613 .53017 .67871 .54981 .67742 .53931 .67392 Metetra
.428 .821 .985 r
.53931 .67392 .54981 .67742 .56962 .67566 .55923 .67116 Metetra
.498 .833 .998 r
.55923 .67116 .56962 .67566 .58961 .67325 .57933 .66778 Metetra
.557 .835 .997 r
.57933 .66778 .58961 .67325 .60976 .67 .59958 .66362 Metetra
.607 .832 .986 r
.59958 .66362 .60976 .67 .63005 .66571 .61997 .65849 Metetra
.648 .826 .968 r
.61997 .65849 .63005 .66571 .65047 .66018 .64048 .65218 Metetra
.684 .82 .948 r
.64048 .65218 .65047 .66018 .67097 .65315 .66108 .64449 Metetra
.716 .814 .926 r
.66108 .64449 .67097 .65315 .69152 .64438 .68174 .63519 Metetra
.744 .811 .906 r
.68174 .63519 .69152 .64438 .71209 .6337 .70242 .62408 Metetra
.769 .809 .885 r
.70242 .62408 .71209 .6337 .73263 .62098 .72308 .61101 Metetra
.791 .808 .866 r
.72308 .61101 .73263 .62098 .75311 .60613 .74367 .59587 Metetra
.811 .807 .848 r
.74367 .59587 .75311 .60613 .77346 .58909 .76416 .57859 Metetra
.829 .807 .83 r
.76416 .57859 .77346 .58909 .79367 .56981 .7845 .55912 Metetra
.844 .807 .814 r
.7845 .55912 .79367 .56981 .81366 .54828 .80466 .53749 Metetra
.859 .808 .8 r
.80466 .53749 .81366 .54828 .83342 .52454 .82458 .51379 Metetra
.871 .811 .788 r
.82458 .51379 .83342 .52454 .8529 .49872 .84428 .48837 Metetra
.878 .82 .787 r
.84428 .48837 .8529 .49872 .87211 .47119 .86383 .46252 Metetra
.857 .853 .837 r
.86383 .46252 .87211 .47119 .89115 .44328 .88387 .44188 Metetra
.631 .956 .924 r
.88387 .44188 .89115 .44328 .91075 .42119 .90502 .43107 Metetra
.2 0 0 r
.90502 .43107 .91075 .42119 .93189 .41166 .92669 .42353 Metetra
.279 0 .008 r
.92669 .42353 .93189 .41166 .95353 .40504 .94859 .41661 Metetra
.219 0 0 r
.3571 .66842 .36886 .66839 .3869 .6719 .37528 .67106 Metetra
.153 0 0 r
.37528 .67106 .3869 .6719 .40518 .67495 .39368 .67363 Metetra
0 .513 .707 r
.39368 .67363 .40518 .67495 .4237 .67724 .4123 .67569 Metetra
.011 .581 .772 r
.4123 .67569 .4237 .67724 .44245 .67864 .43116 .67696 Metetra
.098 .646 .827 r
.43116 .67696 .44245 .67864 .46142 .67914 .45025 .6773 Metetra
.183 .704 .874 r
.45025 .6773 .46142 .67914 .4806 .67883 .46955 .67672 Metetra
.265 .754 .916 r
.46955 .67672 .4806 .67883 .49998 .6778 .48906 .67528 Metetra
.343 .795 .95 r
.48906 .67528 .49998 .6778 .51956 .67613 .50875 .67306 Metetra
.415 .824 .977 r
.50875 .67306 .51956 .67613 .53931 .67392 .52863 .67012 Metetra
.48 .841 .993 r
.52863 .67012 .53931 .67392 .55923 .67116 .54867 .66653 Metetra
.537 .847 .998 r
.54867 .66653 .55923 .67116 .57933 .66778 .56888 .66227 Metetra
.586 .846 .994 r
.56888 .66227 .57933 .66778 .59958 .66362 .58924 .65725 Metetra
.628 .841 .982 r
.58924 .65725 .59958 .66362 .61997 .65849 .60974 .65131 Metetra
.664 .834 .965 r
.60974 .65131 .61997 .65849 .64048 .65218 .63035 .64426 Metetra
.696 .827 .945 r
.63035 .64426 .64048 .65218 .66108 .64449 .65105 .6359 Metetra
.724 .82 .925 r
.65105 .6359 .66108 .64449 .68174 .63519 .67182 .62605 Metetra
.749 .816 .905 r
.67182 .62605 .68174 .63519 .70242 .62408 .69261 .61448 Metetra
.772 .813 .885 r
.69261 .61448 .70242 .62408 .72308 .61101 .71339 .60105 Metetra
.794 .811 .866 r
.71339 .60105 .72308 .61101 .74367 .59587 .73412 .58562 Metetra
.813 .81 .849 r
.73412 .58562 .74367 .59587 .76416 .57859 .75474 .56813 Metetra
.83 .811 .832 r
.75474 .56813 .76416 .57859 .7845 .55912 .77523 .54855 Metetra
.845 .812 .817 r
.77523 .54855 .7845 .55912 .80466 .53749 .79555 .52696 Metetra
.858 .815 .806 r
.79555 .52696 .80466 .53749 .82458 .51379 .81568 .50365 Metetra
.866 .824 .805 r
.81568 .50365 .82458 .51379 .84428 .48837 .83571 .47987 Metetra
.844 .856 .853 r
.83571 .47987 .84428 .48837 .86383 .46252 .85613 .46066 Metetra
.643 .954 .939 r
.85613 .46066 .86383 .46252 .88387 .44188 .87747 .45001 Metetra
.117 0 0 r
.87747 .45001 .88387 .44188 .90502 .43107 .89926 .44237 Metetra
.252 0 0 r
.89926 .44237 .90502 .43107 .92669 .42353 .92129 .43537 Metetra
.273 0 0 r
.92129 .43537 .92669 .42353 .94859 .41661 .9435 .42853 Metetra
.113 0 0 r
.34516 .66788 .3571 .66842 .37528 .67106 .36348 .66967 Metetra
0 .536 .727 r
.36348 .66967 .37528 .67106 .39368 .67363 .382 .67143 Metetra
.029 .591 .803 r
.382 .67143 .39368 .67363 .4123 .67569 .40074 .67301 Metetra
.112 .646 .862 r
.40074 .67301 .4123 .67569 .43116 .67696 .41971 .67403 Metetra
.195 .699 .907 r
.41971 .67403 .43116 .67696 .45025 .6773 .43891 .67423 Metetra
.274 .746 .94 r
.43891 .67423 .45025 .6773 .46955 .67672 .45832 .67348 Metetra
.348 .786 .964 r
.45832 .67348 .46955 .67672 .48906 .67528 .47795 .67177 Metetra
.415 .816 .982 r
.47795 .67177 .48906 .67528 .50875 .67306 .49776 .66917 Metetra
.475 .837 .993 r
.49776 .66917 .50875 .67306 .52863 .67012 .51776 .66572 Metetra
.528 .849 .998 r
.51776 .66572 .52863 .67012 .54867 .66653 .53793 .66149 Metetra
.574 .853 .996 r
.53793 .66149 .54867 .66653 .56888 .66227 .55826 .65649 Metetra
.614 .851 .988 r
.55826 .65649 .56888 .66227 .58924 .65725 .57873 .6507 Metetra
.648 .844 .975 r
.57873 .6507 .58924 .65725 .60974 .65131 .59934 .64401 Metetra
.679 .837 .959 r
.59934 .64401 .60974 .65131 .63035 .64426 .62006 .63626 Metetra
.706 .83 .941 r
.62006 .63626 .63035 .64426 .65105 .6359 .64088 .62728 Metetra
.731 .824 .922 r
.64088 .62728 .65105 .6359 .67182 .62605 .66176 .61688 Metetra
.754 .819 .903 r
.66176 .61688 .67182 .62605 .69261 .61448 .68267 .60487 Metetra
.776 .816 .884 r
.68267 .60487 .69261 .61448 .71339 .60105 .70357 .59108 Metetra
.796 .814 .866 r
.70357 .59108 .71339 .60105 .73412 .58562 .72443 .5754 Metetra
.814 .814 .85 r
.72443 .5754 .73412 .58562 .75474 .56813 .74521 .55776 Metetra
.83 .815 .835 r
.74521 .55776 .75474 .56813 .77523 .54855 .76586 .5382 Metetra
.844 .818 .824 r
.76586 .5382 .77523 .54855 .79555 .52696 .78637 .51697 Metetra
.852 .827 .823 r
.78637 .51697 .79555 .52696 .81568 .50365 .80681 .49523 Metetra
.829 .857 .868 r
.80681 .49523 .81568 .50365 .83571 .47987 .82758 .47744 Metetra
.655 .95 .952 r
.82758 .47744 .83571 .47987 .85613 .46066 .84908 .46698 Metetra
.01 0 0 r
.84908 .46698 .85613 .46066 .87747 .45001 .87099 .45926 Metetra
.175 0 0 r
.87099 .45926 .87747 .45001 .89926 .44237 .89313 .45217 Metetra
.204 0 0 r
.89313 .45217 .89926 .44237 .92129 .43537 .91546 .44527 Metetra
.212 0 0 r
.91546 .44527 .92129 .43537 .9435 .42853 .93797 .43842 Metetra
.006 .578 .762 r
.33304 .66646 .34516 .66788 .36348 .66967 .35149 .66759 Metetra
.069 .622 .822 r
.35149 .66759 .36348 .66967 .382 .67143 .37015 .66855 Metetra
.138 .662 .878 r
.37015 .66855 .382 .67143 .40074 .67301 .38902 .66938 Metetra
.21 .699 .925 r
.38902 .66938 .40074 .67301 .41971 .67403 .4081 .66992 Metetra
.282 .734 .958 r
.4081 .66992 .41971 .67403 .43891 .67423 .4274 .66986 Metetra
.352 .768 .979 r
.4274 .66986 .43891 .67423 .45832 .67348 .44693 .66895 Metetra
.416 .797 .991 r
.44693 .66895 .45832 .67348 .47795 .67177 .46666 .66707 Metetra
.473 .82 .998 r
.46666 .66707 .47795 .67177 .49776 .66917 .4866 .66421 Metetra
.524 .836 .999 r
.4866 .66421 .49776 .66917 .51776 .66572 .50672 .66041 Metetra
.567 .845 .997 r
.50672 .66041 .51776 .66572 .53793 .66149 .52701 .6557 Metetra
.605 .849 .99 r
.52701 .6557 .53793 .66149 .55826 .65649 .54746 .65014 Metetra
.638 .847 .98 r
.54746 .65014 .55826 .65649 .57873 .6507 .56805 .64371 Metetra
.666 .842 .967 r
.56805 .64371 .57873 .6507 .59934 .64401 .58877 .63637 Metetra
.692 .835 .952 r
.58877 .63637 .59934 .64401 .62006 .63626 .60961 .628 Metetra
.716 .829 .935 r
.60961 .628 .62006 .63626 .64088 .62728 .63055 .61845 Metetra
.738 .823 .918 r
.63055 .61845 .64088 .62728 .66176 .61688 .65154 .60755 Metetra
.759 .819 .9 r
.65154 .60755 .66176 .61688 .68267 .60487 .67258 .59514 Metetra
.778 .817 .883 r
.67258 .59514 .68267 .60487 .70357 .59108 .69361 .58105 Metetra
.797 .815 .867 r
.69361 .58105 .70357 .59108 .72443 .5754 .71461 .56518 Metetra
.814 .816 .852 r
.71461 .56518 .72443 .5754 .74521 .55776 .73554 .54752 Metetra
.828 .819 .841 r
.73554 .54752 .74521 .55776 .76586 .5382 .75638 .52828 Metetra
.836 .827 .84 r
.75638 .52828 .76586 .5382 .78637 .51697 .77718 .50851 Metetra
.812 .856 .882 r
.77718 .50851 .78637 .51697 .80681 .49523 .79825 .49211 Metetra
.665 .941 .963 r
.79825 .49211 .80681 .49523 .82758 .47744 .8199 .4819 Metetra
.8199 .4819 .82758 .47744 .84908 .46698 .84191 .47412 Metetra
.071 0 0 r
.84191 .47412 .84908 .46698 .87099 .45926 .86415 .46694 Metetra
.109 0 0 r
.86415 .46694 .87099 .45926 .89313 .45217 .88657 .45995 Metetra
.12 0 0 r
.88657 .45995 .89313 .45217 .91546 .44527 .90918 .45304 Metetra
.125 0 0 r
.90918 .45304 .91546 .44527 .93797 .43842 .93197 .44613 Metetra
.131 .664 .861 r
.32076 .66412 .33304 .66646 .35149 .66759 .33934 .66454 Metetra
.187 .693 .904 r
.33934 .66454 .35149 .66759 .37015 .66855 .35813 .66485 Metetra
.244 .719 .939 r
.35813 .66485 .37015 .66855 .38902 .66938 .37712 .66495 Metetra
.302 .74 .966 r
.37712 .66495 .38902 .66938 .4081 .66992 .39632 .66481 Metetra
.359 .758 .985 r
.39632 .66481 .4081 .66992 .4274 .66986 .41573 .66429 Metetra
.415 .776 .995 r
.41573 .66429 .4274 .66986 .44693 .66895 .43537 .66311 Metetra
.469 .795 .999 r
.43537 .66311 .44693 .66895 .46666 .66707 .45521 .66105 Metetra
.517 .811 .999 r
.45521 .66105 .46666 .66707 .4866 .66421 .47526 .658 Metetra
.559 .824 .995 r
.47526 .658 .4866 .66421 .50672 .66041 .4955 .65395 Metetra
.596 .832 .989 r
.4955 .65395 .50672 .66041 .52701 .6557 .51591 .64891 Metetra
.628 .835 .98 r
.51591 .64891 .52701 .6557 .54746 .65014 .53648 .64293 Metetra
.656 .835 .969 r
.53648 .64293 .54746 .65014 .56805 .64371 .55719 .63602 Metetra
.68 .832 .956 r
.55719 .63602 .56805 .64371 .58877 .63637 .57804 .62815 Metetra
.702 .828 .942 r
.57804 .62815 .58877 .63637 .60961 .628 .599 .61926 Metetra
.723 .823 .927 r
.599 .61926 .60961 .628 .63055 .61845 .62005 .60922 Metetra
.742 .819 .912 r
.62005 .60922 .63055 .61845 .65154 .60755 .64117 .5979 Metetra
.761 .816 .896 r
.64117 .5979 .65154 .60755 .67258 .59514 .66233 .58514 Metetra
.779 .815 .881 r
.66233 .58514 .67258 .59514 .69361 .58105 .68351 .57083 Metetra
.796 .815 .867 r
.68351 .57083 .69361 .58105 .71461 .56518 .70466 .5549 Metetra
.81 .817 .856 r
.70466 .5549 .71461 .56518 .73554 .54752 .72576 .53752 Metetra
.817 .825 .856 r
.72576 .53752 .73554 .54752 .75638 .52828 .74686 .51963 Metetra
.794 .851 .893 r
.74686 .51963 .75638 .52828 .77718 .50851 .76818 .50458 Metetra
.672 .928 .971 r
.76818 .50458 .77718 .50851 .79825 .49211 .78997 .49467 Metetra
.259 .756 .694 r
.78997 .49467 .79825 .49211 .8199 .4819 .81208 .48688 Metetra
.81208 .48688 .8199 .4819 .84191 .47412 .83439 .47961 Metetra
.83439 .47961 .84191 .47412 .86415 .46694 .85689 .47252 Metetra
.85689 .47252 .86415 .46694 .88657 .45995 .87958 .46552 Metetra
.004 0 0 r
.87958 .46552 .88657 .45995 .90918 .45304 .90245 .45855 Metetra
.007 0 0 r
.90245 .45855 .90918 .45304 .93197 .44613 .9255 .45157 Metetra
.255 .735 .932 r
.3083 .66101 .32076 .66412 .33934 .66454 .32703 .66048 Metetra
.296 .744 .96 r
.32703 .66048 .33934 .66454 .35813 .66485 .34595 .66011 Metetra
.34 .755 .978 r
.34595 .66011 .35813 .66485 .37712 .66495 .36506 .65959 Metetra
.384 .766 .99 r
.36506 .65959 .37712 .66495 .39632 .66481 .38438 .65878 Metetra
.426 .772 .997 r
.38438 .65878 .39632 .66481 .41573 .66429 .40391 .65764 Metetra
.468 .778 .998 r
.40391 .65764 .41573 .66429 .43537 .66311 .42365 .65602 Metetra
.509 .786 .995 r
.42365 .65602 .43537 .66311 .45521 .66105 .4436 .65368 Metetra
.549 .795 .99 r
.4436 .65368 .45521 .66105 .47526 .658 .46376 .65043 Metetra
.585 .804 .983 r
.46376 .65043 .47526 .658 .4955 .65395 .48411 .64618 Metetra
.617 .811 .975 r
.48411 .64618 .4955 .65395 .51591 .64891 .50463 .64091 Metetra
.644 .816 .965 r
.50463 .64091 .51591 .64891 .53648 .64293 .52532 .63463 Metetra
.669 .817 .955 r
.52532 .63463 .53648 .64293 .55719 .63602 .54615 .62735 Metetra
.69 .817 .943 r
.54615 .62735 .55719 .63602 .57804 .62815 .56712 .61908 Metetra
.709 .815 .931 r
.56712 .61908 .57804 .62815 .599 .61926 .5882 .60978 Metetra
.727 .812 .917 r
.5882 .60978 .599 .61926 .62005 .60922 .60938 .59935 Metetra
.744 .81 .904 r
.60938 .59935 .62005 .60922 .64117 .5979 .63063 .5877 Metetra
.761 .809 .891 r
.63063 .5877 .64117 .5979 .66233 .58514 .65192 .57471 Metetra
.777 .809 .878 r
.65192 .57471 .66233 .58514 .68351 .57083 .67324 .56031 Metetra
.791 .812 .869 r
.67324 .56031 .68351 .57083 .70466 .5549 .69456 .54463 Metetra
.797 .819 .869 r
.69456 .54463 .70466 .5549 .72576 .53752 .7159 .52851 Metetra
.774 .842 .903 r
.7159 .52851 .72576 .53752 .74686 .51963 .73743 .51477 Metetra
.677 .911 .975 r
.73743 .51477 .74686 .51963 .76818 .50458 .75934 .50522 Metetra
.391 .851 .835 r
.75934 .50522 .76818 .50458 .78997 .49467 .78152 .49747 Metetra
.78152 .49747 .78997 .49467 .81208 .48688 .8039 .49015 Metetra
.8039 .49015 .81208 .48688 .83439 .47961 .82646 .48297 Metetra
.82646 .48297 .83439 .47961 .85689 .47252 .84921 .47585 Metetra
.84921 .47585 .85689 .47252 .87958 .46552 .87214 .46877 Metetra
.87214 .46877 .87958 .46552 .90245 .45855 .89526 .4617 Metetra
.89526 .4617 .90245 .45855 .9255 .45157 .91857 .45464 Metetra
.366 .781 .979 r
.29569 .65689 .3083 .66101 .32703 .66048 .31457 .65551 Metetra
.392 .778 .99 r
.31457 .65551 .32703 .66048 .34595 .66011 .33362 .65428 Metetra
.42 .774 .996 r
.33362 .65428 .34595 .66011 .36506 .65959 .35285 .65309 Metetra
.451 .774 .998 r
.35285 .65309 .36506 .65959 .38438 .65878 .37229 .6517 Metetra
.482 .775 .996 r
.37229 .6517 .38438 .65878 .40391 .65764 .39194 .64995 Metetra
.513 .775 .991 r
.39194 .64995 .40391 .65764 .42365 .65602 .41179 .64778 Metetra
.543 .775 .984 r
.41179 .64778 .42365 .65602 .4436 .65368 .43184 .64503 Metetra
.573 .778 .976 r
.43184 .64503 .4436 .65368 .46376 .65043 .4521 .6415 Metetra
.603 .784 .967 r
.4521 .6415 .46376 .65043 .48411 .64618 .47256 .63704 Metetra
.63 .789 .958 r
.47256 .63704 .48411 .64618 .50463 .64091 .49319 .63156 Metetra
.654 .793 .949 r
.49319 .63156 .50463 .64091 .52532 .63463 .51399 .62505 Metetra
.676 .796 .939 r
.51399 .62505 .52532 .63463 .54615 .62735 .53494 .61751 Metetra
.695 .797 .928 r
.53494 .61751 .54615 .62735 .56712 .61908 .55603 .60894 Metetra
.712 .797 .917 r
.55603 .60894 .56712 .61908 .5882 .60978 .57723 .59933 Metetra
.728 .797 .906 r
.57723 .59933 .5882 .60978 .60938 .59935 .59853 .58863 Metetra
.744 .797 .895 r
.59853 .58863 .60938 .59935 .63063 .5877 .61991 .57677 Metetra
.758 .798 .885 r
.61991 .57677 .63063 .5877 .65192 .57471 .64134 .5637 Metetra
.771 .801 .877 r
.64134 .5637 .65192 .57471 .67324 .56031 .66282 .54956 Metetra
.776 .808 .879 r
.66282 .54956 .67324 .56031 .69456 .54463 .68434 .53509 Metetra
.755 .829 .909 r
.68434 .53509 .69456 .54463 .7159 .52851 .70605 .52259 Metetra
.678 .889 .975 r
.70605 .52259 .7159 .52851 .73743 .51477 .72805 .51347 Metetra
.494 .897 .929 r
.72805 .51347 .73743 .51477 .75934 .50522 .75029 .50585 Metetra
.366 .836 .829 r
.75029 .50585 .75934 .50522 .78152 .49747 .77273 .49854 Metetra
.327 .811 .795 r
.77273 .49854 .78152 .49747 .8039 .49015 .79534 .49129 Metetra
.314 .803 .785 r
.79534 .49129 .8039 .49015 .82646 .48297 .81814 .48406 Metetra
.309 .799 .782 r
.81814 .48406 .82646 .48297 .84921 .47585 .84111 .47684 Metetra
.307 .798 .783 r
.84111 .47684 .84921 .47585 .87214 .46877 .86427 .46963 Metetra
.307 .798 .785 r
.86427 .46963 .87214 .46877 .89526 .4617 .88762 .46244 Metetra
.307 .798 .787 r
.88762 .46244 .89526 .4617 .91857 .45464 .91116 .45525 Metetra
.456 .8 .998 r
.28294 .65154 .29569 .65689 .31457 .65551 .30196 .6494 Metetra
.471 .791 .999 r
.30196 .6494 .31457 .65551 .33362 .65428 .32114 .64739 Metetra
.487 .781 .997 r
.32114 .64739 .33362 .65428 .35285 .65309 .34051 .64543 Metetra
.505 .773 .992 r
.34051 .64543 .35285 .65309 .37229 .6517 .36006 .64341 Metetra
.526 .768 .986 r
.36006 .64341 .37229 .6517 .39194 .64995 .37982 .64111 Metetra
.548 .766 .978 r
.37982 .64111 .39194 .64995 .41179 .64778 .39978 .63839 Metetra
.57 .763 .969 r
.39978 .63839 .41179 .64778 .43184 .64503 .41994 .63516 Metetra
.593 .762 .96 r
.41994 .63516 .43184 .64503 .4521 .6415 .4403 .63125 Metetra
.616 .764 .95 r
.4403 .63125 .4521 .6415 .47256 .63704 .46085 .62652 Metetra
.639 .767 .941 r
.46085 .62652 .47256 .63704 .49319 .63156 .48159 .62082 Metetra
.66 .771 .931 r
.48159 .62082 .49319 .63156 .51399 .62505 .5025 .61411 Metetra
.68 .774 .922 r
.5025 .61411 .51399 .62505 .53494 .61751 .52357 .60636 Metetra
.697 .776 .913 r
.52357 .60636 .53494 .61751 .55603 .60894 .54477 .59758 Metetra
.712 .778 .904 r
.54477 .59758 .55603 .60894 .57723 .59933 .56609 .58776 Metetra
.727 .78 .895 r
.56609 .58776 .57723 .59933 .59853 .58863 .58751 .57691 Metetra
.74 .782 .887 r
.58751 .57691 .59853 .58863 .61991 .57677 .60902 .56502 Metetra
.751 .786 .881 r
.60902 .56502 .61991 .57677 .64134 .5637 .6306 .55226 Metetra
.754 .793 .885 r
.6306 .55226 .64134 .5637 .66282 .54956 .65226 .53931 Metetra
.735 .812 .913 r
.65226 .53931 .66282 .54956 .68434 .53509 .67409 .52799 Metetra
.675 .864 .971 r
.67409 .52799 .68434 .53509 .70605 .52259 .69616 .51937 Metetra
.561 .903 .977 r
.69616 .51937 .70605 .52259 .72805 .51347 .71846 .51198 Metetra
.479 .889 .932 r
.71846 .51198 .72805 .51347 .75029 .50585 .74094 .50478 Metetra
.454 .88 .913 r
.74094 .50478 .75029 .50585 .77273 .49854 .76359 .49753 Metetra
.448 .878 .908 r
.76359 .49753 .77273 .49854 .79534 .49129 .78641 .4902 Metetra
.447 .877 .908 r
.78641 .4902 .79534 .49129 .81814 .48406 .80942 .48283 Metetra
.448 .878 .909 r
.80942 .48283 .81814 .48406 .84111 .47684 .8326 .47545 Metetra
.45 .878 .912 r
.8326 .47545 .84111 .47684 .86427 .46963 .85597 .46806 Metetra
.451 .878 .916 r
.85597 .46806 .86427 .46963 .88762 .46244 .87953 .4607 Metetra
.452 .878 .919 r
.87953 .4607 .88762 .46244 .91116 .45525 .90329 .45335 Metetra
.527 .804 .997 r
.27007 .645 .28294 .65154 .30196 .6494 .28923 .64197 Metetra
.53 .787 .992 r
.28923 .64197 .30196 .6494 .32114 .64739 .30854 .63924 Metetra
.538 .776 .986 r
.30854 .63924 .32114 .64739 .34051 .64543 .32803 .63656 Metetra
.548 .765 .978 r
.32803 .63656 .34051 .64543 .36006 .64341 .34771 .63385 Metetra
.56 .757 .97 r
.34771 .63385 .36006 .64341 .37982 .64111 .36757 .63097 Metetra
.576 .751 .961 r
.36757 .63097 .37982 .64111 .39978 .63839 .38763 .62775 Metetra
.592 .748 .952 r
.38763 .62775 .39978 .63839 .41994 .63516 .4079 .62403 Metetra
.609 .746 .942 r
.4079 .62403 .41994 .63516 .4403 .63125 .42836 .61971 Metetra
.627 .746 .933 r
.42836 .61971 .4403 .63125 .46085 .62652 .44901 .61465 Metetra
.646 .747 .923 r
.44901 .61465 .46085 .62652 .48159 .62082 .46985 .6087 Metetra
.664 .75 .914 r
.46985 .6087 .48159 .62082 .5025 .61411 .49086 .60178 Metetra
.681 .753 .906 r
.49086 .60178 .5025 .61411 .52357 .60636 .51203 .59385 Metetra
.696 .756 .898 r
.51203 .59385 .52357 .60636 .54477 .59758 .53334 .58492 Metetra
.71 .759 .891 r
.53334 .58492 .54477 .59758 .56609 .58776 .55477 .57502 Metetra
.722 .762 .885 r
.55477 .57502 .56609 .58776 .58751 .57691 .57632 .56421 Metetra
.731 .767 .882 r
.57632 .56421 .58751 .57691 .60902 .56502 .59796 .55269 Metetra
.733 .775 .887 r
.59796 .55269 .60902 .56502 .6306 .55226 .61971 .5411 Metetra
.715 .792 .912 r
.61971 .5411 .6306 .55226 .65226 .53931 .64161 .53089 Metetra
.669 .835 .963 r
.64161 .53089 .65226 .53931 .67409 .52799 .66373 .52284 Metetra
.598 .882 .992 r
.66373 .52284 .67409 .52799 .69616 .51937 .68606 .51582 Metetra
.548 .894 .981 r
.68606 .51582 .69616 .51937 .71846 .51198 .70858 .50888 Metetra
.537 .897 .972 r
.70858 .50888 .71846 .51198 .74094 .50478 .73125 .50174 Metetra
.538 .899 .97 r
.73125 .50174 .74094 .50478 .76359 .49753 .7541 .49439 Metetra
.542 .901 .97 r
.7541 .49439 .76359 .49753 .78641 .4902 .77712 .48689 Metetra
.545 .901 .972 r
.77712 .48689 .78641 .4902 .80942 .48283 .80031 .47931 Metetra
.549 .901 .974 r
.80031 .47931 .80942 .48283 .8326 .47545 .82369 .47169 Metetra
.551 .9 .976 r
.82369 .47169 .8326 .47545 .85597 .46806 .84725 .46407 Metetra
.553 .898 .978 r
.84725 .46407 .85597 .46806 .87953 .4607 .87101 .45647 Metetra
.554 .896 .98 r
.87101 .45647 .87953 .4607 .90329 .45335 .89496 .44891 Metetra
.579 .794 .981 r
.25708 .63712 .27007 .645 .28923 .64197 .27639 .63322 Metetra
.575 .777 .974 r
.27639 .63322 .28923 .64197 .30854 .63924 .29584 .62968 Metetra
.575 .762 .967 r
.29584 .62968 .30854 .63924 .32803 .63656 .31545 .62633 Metetra
.58 .751 .959 r
.31545 .62633 .32803 .63656 .34771 .63385 .33523 .62297 Metetra
.587 .742 .95 r
.33523 .62297 .34771 .63385 .36757 .63097 .35521 .61949 Metetra
.596 .735 .941 r
.35521 .61949 .36757 .63097 .38763 .62775 .37537 .61574 Metetra
.608 .731 .932 r
.37537 .61574 .38763 .62775 .4079 .62403 .39573 .61156 Metetra
.621 .729 .924 r
.39573 .61156 .4079 .62403 .42836 .61971 .41628 .60683 Metetra
.635 .728 .915 r
.41628 .60683 .42836 .61971 .44901 .61465 .43703 .60142 Metetra
.65 .729 .906 r
.43703 .60142 .44901 .61465 .46985 .6087 .45796 .5952 Metetra
.665 .731 .898 r
.45796 .5952 .46985 .6087 .49086 .60178 .47907 .58807 Metetra
.68 .733 .891 r
.47907 .58807 .49086 .60178 .51203 .59385 .50034 .58 Metetra
.693 .737 .884 r
.50034 .58 .51203 .59385 .53334 .58492 .52175 .57101 Metetra
.704 .741 .88 r
.52175 .57101 .53334 .58492 .55477 .57502 .5433 .5612 Metetra
.712 .746 .878 r
.5433 .5612 .55477 .57502 .57632 .56421 .56496 .5508 Metetra
.712 .754 .885 r
.56496 .5508 .57632 .56421 .59796 .55269 .58675 .54043 Metetra
.696 .769 .908 r
.58675 .54043 .59796 .55269 .61971 .5411 .60869 .53124 Metetra
.659 .804 .953 r
.60869 .53124 .61971 .5411 .64161 .53089 .63083 .52385 Metetra
.612 .849 .988 r
.63083 .52385 .64161 .53089 .66373 .52284 .65317 .51735 Metetra
.582 .872 .994 r
.65317 .51735 .66373 .52284 .68606 .51582 .6757 .51084 Metetra
.58 .882 .992 r
.6757 .51084 .68606 .51582 .70858 .50888 .6984 .50398 Metetra
.587 .888 .99 r
.6984 .50398 .70858 .50888 .73125 .50174 .72126 .49673 Metetra
.596 .891 .99 r
.72126 .49673 .73125 .50174 .7541 .49439 .74428 .48918 Metetra
.603 .892 .989 r
.74428 .48918 .7541 .49439 .77712 .48689 .76748 .48142 Metetra
.608 .89 .989 r
.76748 .48142 .77712 .48689 .80031 .47931 .79085 .47355 Metetra
.612 .888 .99 r
.79085 .47355 .80031 .47931 .82369 .47169 .81439 .46563 Metetra
.614 .885 .99 r
.81439 .46563 .82369 .47169 .84725 .46407 .83813 .45769 Metetra
.615 .881 .99 r
.83813 .45769 .84725 .46407 .87101 .45647 .86206 .44978 Metetra
.615 .877 .99 r
.86206 .44978 .87101 .45647 .89496 .44891 .88619 .44194 Metetra
.613 .773 .957 r
.24401 .62758 .25708 .63712 .27639 .63322 .26346 .62296 Metetra
.607 .759 .951 r
.26346 .62296 .27639 .63322 .29584 .62968 .28304 .61866 Metetra
.603 .745 .944 r
.28304 .61866 .29584 .62968 .31545 .62633 .30277 .61459 Metetra
.603 .733 .936 r
.30277 .61459 .31545 .62633 .33523 .62297 .32266 .61061 Metetra
.606 .724 .928 r
.32266 .61061 .33523 .62297 .35521 .61949 .34274 .60655 Metetra
.612 .718 .921 r
.34274 .60655 .35521 .61949 .37537 .61574 .363 .60228 Metetra
.62 .713 .913 r
.363 .60228 .37537 .61574 .39573 .61156 .38345 .59765 Metetra
.63 .711 .905 r
.38345 .59765 .39573 .61156 .41628 .60683 .40409 .59253 Metetra
.641 .71 .897 r
.40409 .59253 .41628 .60683 .43703 .60142 .42493 .58679 Metetra
.653 .711 .89 r
.42493 .58679 .43703 .60142 .45796 .5952 .44595 .5803 Metetra
.665 .712 .883 r
.44595 .5803 .45796 .5952 .47907 .58807 .46715 .573 Metetra
.677 .715 .877 r
.46715 .573 .47907 .58807 .50034 .58 .48851 .56485 Metetra
.688 .719 .873 r
.48851 .56485 .50034 .58 .52175 .57101 .51002 .55595 Metetra
.694 .724 .873 r
.51002 .55595 .52175 .57101 .5433 .5612 .53167 .54656 Metetra
.693 .731 .879 r
.53167 .54656 .5433 .5612 .56496 .5508 .55345 .53726 Metetra
.678 .744 .901 r
.55345 .53726 .56496 .5508 .58675 .54043 .57539 .52902 Metetra
.647 .772 .94 r
.57539 .52902 .58675 .54043 .60869 .53124 .59752 .52235 Metetra
.612 .811 .977 r
.59752 .52235 .60869 .53124 .63083 .52385 .61985 .51653 Metetra
.592 .839 .991 r
.61985 .51653 .63083 .52385 .65317 .51735 .64238 .51066 Metetra
.595 .855 .993 r
.64238 .51066 .65317 .51735 .6757 .51084 .66508 .5043 Metetra
.608 .864 .991 r
.66508 .5043 .6757 .51084 .6984 .50398 .68794 .49735 Metetra
.621 .869 .989 r
.68794 .49735 .6984 .50398 .72126 .49673 .71097 .48987 Metetra
.633 .87 .986 r
.71097 .48987 .72126 .49673 .74428 .48918 .73416 .482 Metetra
.641 .868 .984 r
.73416 .482 .74428 .48918 .76748 .48142 .75751 .47388 Metetra
.645 .865 .982 r
.75751 .47388 .76748 .48142 .79085 .47355 .78103 .46563 Metetra
.648 .86 .98 r
.78103 .46563 .79085 .47355 .81439 .46563 .80474 .45732 Metetra
.649 .854 .978 r
.80474 .45732 .81439 .46563 .83813 .45769 .82863 .449 Metetra
.65 .849 .976 r
.82863 .449 .83813 .45769 .86206 .44978 .85271 .4407 Metetra
.649 .843 .975 r
.85271 .4407 .86206 .44978 .88619 .44194 .877 .43248 Metetra
.631 .743 .928 r
.23092 .61603 .24401 .62758 .26346 .62296 .25047 .6109 Metetra
.627 .734 .925 r
.25047 .6109 .26346 .62296 .28304 .61866 .27017 .60597 Metetra
.622 .724 .919 r
.27017 .60597 .28304 .61866 .30277 .61459 .29001 .60124 Metetra
.62 .714 .913 r
.29001 .60124 .30277 .61459 .32266 .61061 .31001 .59665 Metetra
.62 .705 .906 r
.31001 .59665 .32266 .61061 .34274 .60655 .33019 .59204 Metetra
.623 .699 .899 r
.33019 .59204 .34274 .60655 .363 .60228 .35054 .58728 Metetra
.628 .695 .893 r
.35054 .58728 .363 .60228 .38345 .59765 .37107 .58222 Metetra
.635 .693 .886 r
.37107 .58222 .38345 .59765 .40409 .59253 .3918 .57672 Metetra
.644 .692 .88 r
.3918 .57672 .40409 .59253 .42493 .58679 .41272 .57068 Metetra
.654 .693 .874 r
.41272 .57068 .42493 .58679 .44595 .5803 .43382 .56397 Metetra
.664 .695 .869 r
.43382 .56397 .44595 .5803 .46715 .573 .4551 .55655 Metetra
.673 .698 .865 r
.4551 .55655 .46715 .573 .48851 .56485 .47654 .54847 Metetra
.678 .702 .865 r
.47654 .54847 .48851 .56485 .51002 .55595 .49814 .53995 Metetra
.677 .708 .871 r
.49814 .53995 .51002 .55595 .53167 .54656 .51988 .53155 Metetra
.662 .718 .89 r
.51988 .53155 .53167 .54656 .55345 .53726 .54178 .52418 Metetra
.633 .74 .925 r
.54178 .52418 .55345 .53726 .57539 .52902 .56387 .51833 Metetra
.602 .773 .962 r
.56387 .51833 .57539 .52902 .59752 .52235 .58616 .51337 Metetra
.586 .803 .982 r
.58616 .51337 .59752 .52235 .61985 .51653 .60865 .50835 Metetra
.592 .824 .988 r
.60865 .50835 .61985 .51653 .64238 .51066 .63134 .50272 Metetra
.609 .837 .986 r
.63134 .50272 .64238 .51066 .66508 .5043 .6542 .49632 Metetra
.628 .844 .983 r
.6542 .49632 .66508 .5043 .68794 .49735 .67722 .48914 Metetra
.644 .847 .978 r
.67722 .48914 .68794 .49735 .71097 .48987 .7004 .48133 Metetra
.656 .846 .973 r
.7004 .48133 .71097 .48987 .73416 .482 .72374 .47303 Metetra
.664 .842 .968 r
.72374 .47303 .73416 .482 .75751 .47388 .74723 .46442 Metetra
.668 .836 .964 r
.74723 .46442 .75751 .47388 .78103 .46563 .77089 .45566 Metetra
.67 .829 .96 r
.77089 .45566 .78103 .46563 .80474 .45732 .79474 .44686 Metetra
.67 .821 .956 r
.79474 .44686 .80474 .45732 .82863 .449 .81876 .43807 Metetra
.669 .814 .953 r
.81876 .43807 .82863 .449 .85271 .4407 .84298 .42932 Metetra
.667 .807 .95 r
.84298 .42932 .85271 .4407 .877 .43248 .8674 .42063 Metetra
.639 .711 .899 r
.21783 .60223 .23092 .61603 .25047 .6109 .23748 .59674 Metetra
.637 .706 .897 r
.23748 .59674 .25047 .6109 .27017 .60597 .25727 .59135 Metetra
.633 .7 .893 r
.25727 .59135 .27017 .60597 .29001 .60124 .27721 .58609 Metetra
.631 .692 .889 r
.27721 .58609 .29001 .60124 .31001 .59665 .29731 .58094 Metetra
.629 .685 .884 r
.29731 .58094 .31001 .59665 .33019 .59204 .31757 .57582 Metetra
.63 .68 .879 r
.31757 .57582 .33019 .59204 .35054 .58728 .338 .5706 Metetra
.633 .676 .873 r
.338 .5706 .35054 .58728 .37107 .58222 .35862 .56514 Metetra
.639 .675 .868 r
.35862 .56514 .37107 .58222 .3918 .57672 .37942 .55931 Metetra
.645 .674 .863 r
.37942 .55931 .3918 .57672 .41272 .57068 .40041 .55301 Metetra
.653 .675 .859 r
.40041 .55301 .41272 .57068 .43382 .56397 .42159 .54615 Metetra
.66 .677 .856 r
.42159 .54615 .43382 .56397 .4551 .55655 .44294 .53874 Metetra
.664 .68 .855 r
.44294 .53874 .4551 .55655 .47654 .54847 .46445 .53095 Metetra
.662 .685 .86 r
.46445 .53095 .47654 .54847 .49814 .53995 .48612 .52331 Metetra
.647 .691 .877 r
.48612 .52331 .49814 .53995 .51988 .53155 .50794 .51671 Metetra
.617 .707 .909 r
.50794 .51671 .51988 .53155 .54178 .52418 .52995 .51175 Metetra
.585 .736 .947 r
.52995 .51175 .54178 .52418 .56387 .51833 .55216 .50783 Metetra
.57 .768 .972 r
.55216 .50783 .56387 .51833 .58616 .51337 .5746 .50386 Metetra
.577 .793 .981 r
.5746 .50386 .58616 .51337 .60865 .50835 .59724 .4992 Metetra
.598 .809 .981 r
.59724 .4992 .60865 .50835 .63134 .50272 .62008 .49361 Metetra
.622 .82 .977 r
.62008 .49361 .63134 .50272 .6542 .49632 .64308 .48703 Metetra
.643 .826 .971 r
.64308 .48703 .6542 .49632 .67722 .48914 .66625 .47953 Metetra
.661 .828 .964 r
.66625 .47953 .67722 .48914 .7004 .48133 .68958 .47128 Metetra
.673 .825 .957 r
.68958 .47128 .7004 .48133 .72374 .47303 .71305 .46245 Metetra
.681 .82 .95 r
.71305 .46245 .72374 .47303 .74723 .46442 .73667 .45325 Metetra
.684 .812 .943 r
.73667 .45325 .74723 .46442 .77089 .45566 .76046 .44384 Metetra
.684 .802 .938 r
.76046 .44384 .77089 .45566 .79474 .44686 .78442 .43439 Metetra
.682 .792 .932 r
.78442 .43439 .79474 .44686 .81876 .43807 .80856 .425 Metetra
.68 .783 .928 r
.80856 .425 .81876 .43807 .84298 .42932 .83289 .41571 Metetra
.677 .775 .924 r
.83289 .41571 .84298 .42932 .8674 .42063 .85742 .4065 Metetra
.642 .681 .871 r
.20479 .58604 .21783 .60223 .23748 .59674 .22451 .58027 Metetra
.64 .677 .87 r
.22451 .58027 .23748 .59674 .25727 .59135 .24438 .57454 Metetra
.638 .674 .868 r
.24438 .57454 .25727 .59135 .27721 .58609 .2644 .56889 Metetra
.636 .669 .865 r
.2644 .56889 .27721 .58609 .29731 .58094 .28458 .56329 Metetra
.634 .664 .862 r
.28458 .56329 .29731 .58094 .31757 .57582 .30492 .55773 Metetra
.634 .66 .858 r
.30492 .55773 .31757 .57582 .338 .5706 .32543 .5521 Metetra
.636 .657 .854 r
.32543 .5521 .338 .5706 .35862 .56514 .34611 .54629 Metetra
.639 .656 .85 r
.34611 .54629 .35862 .56514 .37942 .55931 .36698 .54018 Metetra
.644 .656 .847 r
.36698 .54018 .37942 .55931 .40041 .55301 .38803 .53369 Metetra
.649 .657 .844 r
.38803 .53369 .40041 .55301 .42159 .54615 .40926 .52677 Metetra
.653 .659 .844 r
.40926 .52677 .42159 .54615 .44294 .53874 .43067 .51956 Metetra
.65 .662 .848 r
.43067 .51956 .44294 .53874 .46445 .53095 .45223 .51252 Metetra
.634 .665 .862 r
.45223 .51252 .46445 .53095 .48612 .52331 .47395 .5066 Metetra
.599 .674 .893 r
.47395 .5066 .48612 .52331 .50794 .51671 .49584 .50263 Metetra
.563 .7 .933 r
.49584 .50263 .50794 .51671 .52995 .51175 .51793 .4999 Metetra
.546 .734 .963 r
.51793 .4999 .52995 .51175 .55216 .50783 .54027 .49715 Metetra
.554 .762 .975 r
.54027 .49715 .55216 .50783 .5746 .50386 .56283 .49366 Metetra
.577 .782 .976 r
.56283 .49366 .5746 .50386 .59724 .4992 .58561 .48911 Metetra
.605 .797 .973 r
.58561 .48911 .59724 .4992 .62008 .49361 .60859 .48341 Metetra
.632 .806 .966 r
.60859 .48341 .62008 .49361 .64308 .48703 .63174 .47657 Metetra
.655 .811 .958 r
.63174 .47657 .64308 .48703 .66625 .47953 .65505 .46868 Metetra
.673 .811 .949 r
.65505 .46868 .66625 .47953 .68958 .47128 .67851 .45991 Metetra
.685 .808 .94 r
.67851 .45991 .68958 .47128 .71305 .46245 .70211 .45047 Metetra
.693 .801 .932 r
.70211 .45047 .71305 .46245 .73667 .45325 .72585 .44057 Metetra
.696 .792 .924 r
.72585 .44057 .73667 .45325 .76046 .44384 .74975 .4304 Metetra
.696 .782 .917 r
.74975 .4304 .76046 .44384 .78442 .43439 .7738 .42014 Metetra
.693 .769 .91 r
.7738 .42014 .78442 .43439 .80856 .425 .79804 .40997 Metetra
.688 .757 .904 r
.79804 .40997 .80856 .425 .83289 .41571 .82247 .39999 Metetra
.684 .747 .899 r
.82247 .39999 .83289 .41571 .85742 .4065 .84709 .39018 Metetra
.641 .653 .846 r
.19182 .5674 .20479 .58604 .22451 .58027 .2116 .56137 Metetra
.64 .651 .845 r
.2116 .56137 .22451 .58027 .24438 .57454 .23154 .55538 Metetra
.638 .648 .844 r
.23154 .55538 .24438 .57454 .2644 .56889 .25162 .54941 Metetra
.637 .646 .842 r
.25162 .54941 .2644 .56889 .28458 .56329 .27186 .54348 Metetra
.636 .643 .84 r
.27186 .54348 .28458 .56329 .30492 .55773 .29226 .53757 Metetra
.635 .64 .838 r
.29226 .53757 .30492 .55773 .32543 .5521 .31283 .5316 Metetra
.636 .638 .835 r
.31283 .5316 .32543 .5521 .34611 .54629 .33357 .5255 Metetra
.638 .637 .833 r
.33357 .5255 .34611 .54629 .36698 .54018 .35449 .51918 Metetra
.641 .637 .831 r
.35449 .51918 .36698 .54018 .38803 .53369 .37559 .51258 Metetra
.643 .638 .83 r
.37559 .51258 .38803 .53369 .40926 .52677 .39687 .50578 Metetra
.64 .639 .833 r
.39687 .50578 .40926 .52677 .43067 .51956 .4183 .49918 Metetra
.622 .639 .846 r
.4183 .49918 .43067 .51956 .45223 .51252 .43988 .49386 Metetra
.58 .641 .876 r
.43988 .49386 .45223 .51252 .47395 .5066 .46161 .49095 Metetra
.535 .665 .92 r
.46161 .49095 .47395 .5066 .49584 .50263 .48354 .48959 Metetra
.515 .701 .954 r
.48354 .48959 .49584 .50263 .51793 .4999 .50573 .4882 Metetra
.524 .731 .969 r
.50573 .4882 .51793 .4999 .54027 .49715 .52818 .48599 Metetra
.55 .754 .972 r
.52818 .48599 .54027 .49715 .56283 .49366 .55087 .48265 Metetra
.581 .772 .97 r
.55087 .48265 .56283 .49366 .58561 .48911 .57378 .47806 Metetra
.613 .784 .963 r
.57378 .47806 .58561 .48911 .60859 .48341 .59689 .47218 Metetra
.641 .793 .955 r
.59689 .47218 .60859 .48341 .63174 .47657 .62018 .46503 Metetra
.664 .797 .946 r
.62018 .46503 .63174 .47657 .65505 .46868 .64362 .45672 Metetra
.683 .798 .936 r
.64362 .45672 .65505 .46868 .67851 .45991 .66721 .44739 Metetra
.696 .794 .926 r
.66721 .44739 .67851 .45991 .70211 .45047 .69094 .43727 Metetra
.703 .787 .916 r
.69094 .43727 .70211 .45047 .72585 .44057 .71479 .42659 Metetra
.707 .778 .907 r
.71479 .42659 .72585 .44057 .74975 .4304 .73879 .41557 Metetra
.706 .766 .899 r
.73879 .41557 .74975 .4304 .7738 .42014 .76293 .4044 Metetra
.703 .754 .891 r
.76293 .4044 .7738 .42014 .79804 .40997 .78724 .39327 Metetra
.697 .74 .884 r
.78724 .39327 .79804 .40997 .82247 .39999 .81173 .38235 Metetra
.69 .726 .878 r
.81173 .38235 .82247 .39999 .84709 .39018 .83643 .37175 Metetra
.639 .628 .823 r
.17896 .54624 .19182 .5674 .2116 .56137 .19879 .53998 Metetra
.638 .626 .822 r
.19879 .53998 .2116 .56137 .23154 .55538 .21877 .53375 Metetra
.637 .625 .821 r
.21877 .53375 .23154 .55538 .25162 .54941 .2389 .52754 Metetra
.635 .623 .821 r
.2389 .52754 .25162 .54941 .27186 .54348 .25919 .52135 Metetra
.634 .621 .819 r
.25919 .52135 .27186 .54348 .29226 .53757 .27964 .51516 Metetra
.634 .619 .818 r
.27964 .51516 .29226 .53757 .31283 .5316 .30025 .50893 Metetra
.634 .618 .817 r
.30025 .50893 .31283 .5316 .33357 .5255 .32103 .50262 Metetra
.635 .618 .816 r
.32103 .50262 .33357 .5255 .35449 .51918 .34198 .49617 Metetra
.636 .618 .815 r
.34198 .49617 .35449 .51918 .37559 .51258 .36311 .48961 Metetra
.632 .618 .818 r
.36311 .48961 .37559 .51258 .39687 .50578 .3844 .48332 Metetra
.611 .614 .829 r
.3844 .48332 .39687 .50578 .4183 .49918 .40582 .47852 Metetra
.56 .61 .859 r
.40582 .47852 .4183 .49918 .43988 .49386 .42734 .47674 Metetra
.504 .63 .908 r
.42734 .47674 .43988 .49386 .46161 .49095 .44906 .47688 Metetra
.478 .668 .947 r
.44906 .47688 .46161 .49095 .48354 .48959 .47105 .47697 Metetra
.489 .701 .963 r
.47105 .47697 .48354 .48959 .50573 .4882 .49333 .47614 Metetra
.519 .726 .968 r
.49333 .47614 .50573 .4882 .52818 .48599 .51589 .47408 Metetra
.554 .745 .966 r
.51589 .47408 .52818 .48599 .55087 .48265 .5387 .47071 Metetra
.588 .76 .961 r
.5387 .47071 .55087 .48265 .57378 .47806 .56173 .46598 Metetra
.62 .771 .953 r
.56173 .46598 .57378 .47806 .59689 .47218 .58497 .45989 Metetra
.648 .78 .944 r
.58497 .45989 .59689 .47218 .62018 .46503 .6084 .45243 Metetra
.671 .784 .934 r
.6084 .45243 .62018 .46503 .64362 .45672 .63198 .44371 Metetra
.69 .785 .923 r
.63198 .44371 .64362 .45672 .66721 .44739 .6557 .43383 Metetra
.704 .783 .913 r
.6557 .43383 .66721 .44739 .69094 .43727 .67954 .42302 Metetra
.713 .777 .903 r
.67954 .42302 .69094 .43727 .71479 .42659 .70351 .4115 Metetra
.716 .767 .893 r
.70351 .4115 .71479 .42659 .73879 .41557 .7276 .39954 Metetra
.716 .756 .884 r
.7276 .39954 .73879 .41557 .76293 .4044 .75183 .38738 Metetra
.712 .742 .875 r
.75183 .38738 .76293 .4044 .78724 .39327 .7762 .3752 Metetra
.707 .728 .867 r
.7762 .3752 .78724 .39327 .81173 .38235 .80074 .36317 Metetra
.698 .713 .86 r
.80074 .36317 .81173 .38235 .83643 .37175 .82547 .35148 Metetra
.635 .605 .802 r
.16625 .52251 .17896 .54624 .19879 .53998 .18611 .51606 Metetra
.635 .604 .802 r
.18611 .51606 .19879 .53998 .21877 .53375 .20612 .50962 Metetra
.634 .603 .802 r
.20612 .50962 .21877 .53375 .2389 .52754 .22628 .5032 Metetra
.633 .602 .801 r
.22628 .5032 .2389 .52754 .25919 .52135 .2466 .49679 Metetra
.632 .601 .8 r
.2466 .49679 .25919 .52135 .27964 .51516 .26707 .49038 Metetra
.631 .6 .8 r
.26707 .49038 .27964 .51516 .30025 .50893 .28771 .48397 Metetra
.631 .599 .799 r
.28771 .48397 .30025 .50893 .32103 .50262 .30851 .47752 Metetra
.63 .599 .8 r
.30851 .47752 .32103 .50262 .34198 .49617 .32949 .47107 Metetra
.625 .597 .802 r
.32949 .47107 .34198 .49617 .36311 .48961 .35061 .46496 Metetra
.602 .591 .812 r
.35061 .46496 .36311 .48961 .3844 .48332 .37183 .4606 Metetra
.539 .578 .842 r
.37183 .4606 .3844 .48332 .40582 .47852 .39311 .46002 Metetra
.467 .594 .896 r
.39311 .46002 .40582 .47852 .42734 .47674 .41456 .46181 Metetra
.433 .633 .939 r
.41456 .46181 .42734 .47674 .44906 .47688 .43631 .46347 Metetra
.448 .669 .957 r
.43631 .46347 .44906 .47688 .47105 .47697 .45837 .46407 Metetra
.484 .697 .962 r
.45837 .46407 .47105 .47697 .49333 .47614 .48075 .46334 Metetra
.523 .718 .961 r
.48075 .46334 .49333 .47614 .51589 .47408 .50341 .46123 Metetra
.561 .734 .957 r
.50341 .46123 .51589 .47408 .5387 .47071 .52633 .45772 Metetra
.595 .747 .95 r
.52633 .45772 .5387 .47071 .56173 .46598 .54948 .4528 Metetra
.625 .758 .942 r
.54948 .4528 .56173 .46598 .58497 .45989 .57285 .44648 Metetra
.653 .766 .932 r
.57285 .44648 .58497 .45989 .6084 .45243 .59641 .43875 Metetra
.676 .771 .922 r
.59641 .43875 .6084 .45243 .63198 .44371 .62012 .42965 Metetra
.696 .774 .912 r
.62012 .42965 .63198 .44371 .6557 .43383 .64397 .41927 Metetra
.711 .773 .901 r
.64397 .41927 .6557 .43383 .67954 .42302 .66794 .4078 Metetra
.72 .768 .89 r
.66794 .4078 .67954 .42302 .70351 .4115 .69202 .39546 Metetra
.725 .76 .88 r
.69202 .39546 .70351 .4115 .7276 .39954 .7162 .38252 Metetra
.725 .749 .871 r
.7162 .38252 .7276 .39954 .75183 .38738 .74051 .36928 Metetra
.722 .735 .862 r
.74051 .36928 .75183 .38738 .7762 .3752 .76494 .35596 Metetra
.716 .721 .853 r
.76494 .35596 .7762 .3752 .80074 .36317 .78952 .34275 Metetra
.708 .706 .846 r
.78952 .34275 .80074 .36317 .82547 .35148 .81427 .32982 Metetra
.631 .585 .784 r
.15372 .49616 .16625 .52251 .18611 .51606 .1736 .48955 Metetra
.63 .584 .784 r
.1736 .48955 .18611 .51606 .20612 .50962 .19362 .48293 Metetra
.63 .583 .784 r
.19362 .48293 .20612 .50962 .22628 .5032 .21379 .47633 Metetra
.629 .583 .783 r
.21379 .47633 .22628 .5032 .2466 .49679 .23412 .46974 Metetra
.628 .582 .783 r
.23412 .46974 .2466 .49679 .26707 .49038 .25461 .46317 Metetra
.627 .581 .783 r
.25461 .46317 .26707 .49038 .28771 .48397 .27525 .45663 Metetra
.625 .58 .784 r
.27525 .45663 .28771 .48397 .30851 .47752 .29606 .45017 Metetra
.62 .578 .786 r
.29606 .45017 .30851 .47752 .32949 .47107 .317 .44414 Metetra
.594 .569 .796 r
.317 .44414 .32949 .47107 .35061 .46496 .33801 .44015 Metetra
.518 .548 .826 r
.33801 .44015 .35061 .46496 .37183 .4606 .35899 .44083 Metetra
.424 .556 .884 r
.35899 .44083 .37183 .4606 .39311 .46002 .38011 .44437 Metetra
.38 .596 .931 r
.38011 .44437 .39311 .46002 .41456 .46181 .40156 .44771 Metetra
.399 .635 .95 r
.40156 .44771 .41456 .46181 .43631 .46347 .42336 .44982 Metetra
.443 .666 .957 r
.42336 .44982 .43631 .46347 .45837 .46407 .44551 .45048 Metetra
.49 .691 .957 r
.44551 .45048 .45837 .46407 .48075 .46334 .46797 .44964 Metetra
.532 .709 .953 r
.46797 .44964 .48075 .46334 .50341 .46123 .49074 .44734 Metetra
.569 .724 .946 r
.49074 .44734 .50341 .46123 .52633 .45772 .51376 .4436 Metetra
.601 .735 .938 r
.51376 .4436 .52633 .45772 .54948 .4528 .53704 .43846 Metetra
.63 .744 .93 r
.53704 .43846 .54948 .4528 .57285 .44648 .56053 .4319 Metetra
.656 .751 .92 r
.56053 .4319 .57285 .44648 .59641 .43875 .58421 .4239 Metetra
.679 .757 .91 r
.58421 .4239 .59641 .43875 .62012 .42965 .60805 .41448 Metetra
.699 .761 .9 r
.60805 .41448 .62012 .42965 .64397 .41927 .63203 .40369 Metetra
.715 .762 .89 r
.63203 .40369 .64397 .41927 .66794 .4078 .65613 .39164 Metetra
.726 .76 .88 r
.65613 .39164 .66794 .4078 .69202 .39546 .68032 .37855 Metetra
.733 .754 .869 r
.68032 .37855 .69202 .39546 .7162 .38252 .70461 .36466 Metetra
.734 .744 .86 r
.70461 .36466 .7162 .38252 .74051 .36928 .72899 .3503 Metetra
.732 .731 .85 r
.72899 .3503 .74051 .36928 .76494 .35596 .75348 .33576 Metetra
.726 .717 .842 r
.75348 .33576 .76494 .35596 .78952 .34275 .77809 .32128 Metetra
.718 .701 .834 r
.77809 .32128 .78952 .34275 .81427 .32982 .80286 .30705 Metetra
.627 .566 .767 r
.14141 .46721 .15372 .49616 .1736 .48955 .16128 .46045 Metetra
.626 .566 .767 r
.16128 .46045 .1736 .48955 .19362 .48293 .1813 .45368 Metetra
.625 .566 .767 r
.1813 .45368 .19362 .48293 .21379 .47633 .20147 .44692 Metetra
.624 .565 .767 r
.20147 .44692 .21379 .47633 .23412 .46974 .22179 .44018 Metetra
.623 .564 .767 r
.22179 .44018 .23412 .46974 .25461 .46317 .24227 .4335 Metetra
.621 .563 .768 r
.24227 .4335 .25461 .46317 .27525 .45663 .2629 .42696 Metetra
.615 .561 .77 r
.2629 .42696 .27525 .45663 .29606 .45017 .28366 .42092 Metetra
.587 .549 .78 r
.28366 .42092 .29606 .45017 .317 .44414 .30443 .41721 Metetra
.495 .517 .81 r
.30443 .41721 .317 .44414 .33801 .44015 .32507 .41921 Metetra
.375 .515 .87 r
.32507 .41921 .33801 .44015 .35899 .44083 .3458 .42461 Metetra
.314 .553 .919 r
.3458 .42461 .35899 .44083 .38011 .44437 .36688 .42973 Metetra
.34 .596 .941 r
.36688 .42973 .38011 .44437 .40156 .44771 .38837 .43347 Metetra
.395 .633 .95 r
.38837 .43347 .40156 .44771 .42336 .44982 .41024 .43559 Metetra
.451 .663 .953 r
.41024 .43559 .42336 .44982 .44551 .45048 .43246 .43609 Metetra
.5 .685 .95 r
.43246 .43609 .44551 .45048 .46797 .44964 .45502 .43502 Metetra
.542 .702 .944 r
.45502 .43502 .46797 .44964 .49074 .44734 .47788 .43243 Metetra
.578 .714 .936 r
.47788 .43243 .49074 .44734 .51376 .4436 .50101 .42839 Metetra
.608 .723 .927 r
.50101 .42839 .51376 .4436 .53704 .43846 .5244 .42293 Metetra
.634 .731 .917 r
.5244 .42293 .53704 .43846 .56053 .4319 .548 .41608 Metetra
.658 .737 .908 r
.548 .41608 .56053 .4319 .58421 .4239 .57181 .40783 Metetra
.68 .743 .899 r
.57181 .40783 .58421 .4239 .60805 .41448 .59578 .39813 Metetra
.7 .748 .889 r
.59578 .39813 .60805 .41448 .63203 .40369 .61989 .38699 Metetra
.716 .751 .879 r
.61989 .38699 .63203 .40369 .65613 .39164 .64411 .37448 Metetra
.729 .751 .869 r
.64411 .37448 .65613 .39164 .68032 .37855 .66843 .36075 Metetra
.738 .748 .86 r
.66843 .36075 .68032 .37855 .70461 .36466 .69282 .34603 Metetra
.742 .74 .85 r
.69282 .34603 .70461 .36466 .72899 .3503 .71728 .3306 Metetra
.742 .73 .841 r
.71728 .3306 .72899 .3503 .75348 .33576 .74183 .3148 Metetra
.736 .716 .832 r
.74183 .3148 .75348 .33576 .77809 .32128 .76648 .29897 Metetra
.728 .7 .823 r
.76648 .29897 .77809 .32128 .80286 .30705 .79125 .28333 Metetra
.622 .55 .752 r
.12934 .43568 .14141 .46721 .16128 .46045 .14919 .42879 Metetra
.622 .55 .753 r
.14919 .42879 .16128 .46045 .1813 .45368 .16919 .42188 Metetra
.621 .549 .753 r
.16919 .42188 .1813 .45368 .20147 .44692 .18934 .41498 Metetra
.62 .549 .753 r
.18934 .41498 .20147 .44692 .22179 .44018 .20964 .40814 Metetra
.617 .548 .754 r
.20964 .40814 .22179 .44018 .24227 .4335 .23008 .40147 Metetra
.611 .545 .756 r
.23008 .40147 .24227 .4335 .2629 .42696 .25064 .39535 Metetra
.58 .531 .764 r
.25064 .39535 .2629 .42696 .28366 .42092 .27117 .39187 Metetra
.471 .487 .793 r
.27117 .39187 .28366 .42092 .30443 .41721 .29141 .39523 Metetra
.318 .471 .855 r
.29141 .39523 .30443 .41721 .32507 .41921 .31169 .40257 Metetra
.234 .502 .902 r
.31169 .40257 .32507 .41921 .3458 .42461 .33235 .40957 Metetra
.265 .549 .927 r
.33235 .40957 .3458 .42461 .36688 .42973 .35346 .41505 Metetra
.334 .595 .942 r
.35346 .41505 .36688 .42973 .38837 .43347 .37499 .41877 Metetra
.401 .632 .948 r
.37499 .41877 .38837 .43347 .41024 .43559 .39693 .42073 Metetra
.461 .661 .948 r
.39693 .42073 .41024 .43559 .43246 .43609 .41924 .42097 Metetra
.51 .681 .943 r
.41924 .42097 .43246 .43609 .45502 .43502 .44189 .41958 Metetra
.552 .696 .936 r
.44189 .41958 .45502 .43502 .47788 .43243 .46484 .41663 Metetra
.586 .707 .926 r
.46484 .41663 .47788 .43243 .50101 .42839 .48808 .41218 Metetra
.615 .715 .916 r
.48808 .41218 .50101 .42839 .5244 .42293 .51157 .40631 Metetra
.639 .72 .906 r
.51157 .40631 .5244 .42293 .548 .41608 .53529 .39907 Metetra
.66 .724 .896 r
.53529 .39907 .548 .41608 .57181 .40783 .55921 .39049 Metetra
.68 .729 .887 r
.55921 .39049 .57181 .40783 .59578 .39813 .5833 .38051 Metetra
.699 .734 .878 r
.5833 .38051 .59578 .39813 .61989 .38699 .60754 .36908 Metetra
.716 .738 .869 r
.60754 .36908 .61989 .38699 .64411 .37448 .63189 .35621 Metetra
.73 .74 .86 r
.63189 .35621 .64411 .37448 .66843 .36075 .65633 .34198 Metetra
.741 .74 .85 r
.65633 .34198 .66843 .36075 .69282 .34603 .68084 .32657 Metetra
.748 .736 .841 r
.68084 .32657 .69282 .34603 .71728 .3306 .7054 .31022 Metetra
.75 .728 .832 r
.7054 .31022 .71728 .3306 .74183 .3148 .73002 .29326 Metetra
.747 .716 .823 r
.73002 .29326 .74183 .3148 .76648 .29897 .7547 .27603 Metetra
.74 .701 .815 r
.7547 .27603 .76648 .29897 .79125 .28333 .77949 .25892 Metetra
.617 .535 .739 r
.11754 .40164 .12934 .43568 .14919 .42879 .13736 .39461 Metetra
.617 .535 .739 r
.13736 .39461 .14919 .42879 .16919 .42188 .15732 .38758 Metetra
.616 .534 .739 r
.15732 .38758 .16919 .42188 .18934 .41498 .17743 .38058 Metetra
.614 .533 .74 r
.17743 .38058 .18934 .41498 .20964 .40814 .19769 .37375 Metetra
.607 .53 .742 r
.19769 .37375 .20964 .40814 .23008 .40147 .21804 .3675 Metetra
.575 .515 .75 r
.21804 .3675 .23008 .40147 .25064 .39535 .2383 .36419 Metetra
.447 .458 .777 r
.2383 .36419 .25064 .39535 .27117 .39187 .2581 .36894 Metetra
.252 .421 .836 r
.2581 .36894 .27117 .39187 .29141 .39523 .27786 .37828 Metetra
.136 .439 .875 r
.27786 .37828 .29141 .39523 .31169 .40257 .29803 .38727 Metetra
.172 .491 .903 r
.29803 .38727 .31169 .40257 .33235 .40957 .31869 .39463 Metetra
.255 .548 .928 r
.31869 .39463 .33235 .40957 .35346 .41505 .33983 .4001 Metetra
.338 .597 .942 r
.33983 .4001 .35346 .41505 .37499 .41877 .36143 .40365 Metetra
.411 .634 .946 r
.36143 .40365 .37499 .41877 .39693 .42073 .38344 .40534 Metetra
.471 .661 .944 r
.38344 .40534 .39693 .42073 .41924 .42097 .40583 .40524 Metetra
.521 .68 .938 r
.40583 .40524 .41924 .42097 .44189 .41958 .42857 .40345 Metetra
.562 .693 .929 r
.42857 .40345 .44189 .41958 .46484 .41663 .45163 .40006 Metetra
.595 .703 .918 r
.45163 .40006 .46484 .41663 .48808 .41218 .47497 .39513 Metetra
.623 .709 .907 r
.47497 .39513 .48808 .41218 .51157 .40631 .49857 .38875 Metetra
.646 .713 .897 r
.49857 .38875 .51157 .40631 .53529 .39907 .52239 .381 Metetra
.664 .715 .886 r
.52239 .381 .53529 .39907 .55921 .39049 .54642 .37195 Metetra
.681 .717 .876 r
.54642 .37195 .55921 .39049 .5833 .38051 .57063 .36161 Metetra
.698 .721 .867 r
.57063 .36161 .5833 .38051 .60754 .36908 .59499 .34989 Metetra
.714 .725 .859 r
.59499 .34989 .60754 .36908 .63189 .35621 .61947 .33672 Metetra
.729 .729 .85 r
.61947 .33672 .63189 .35621 .65633 .34198 .64403 .32211 Metetra
.742 .73 .841 r
.64403 .32211 .65633 .34198 .68084 .32657 .66866 .30618 Metetra
.751 .729 .833 r
.66866 .30618 .68084 .32657 .7054 .31022 .69333 .28909 Metetra
.756 .725 .824 r
.69333 .28909 .7054 .31022 .73002 .29326 .71803 .27112 Metetra
.756 .716 .816 r
.71803 .27112 .73002 .29326 .7547 .27603 .74278 .25264 Metetra
.751 .704 .807 r
.74278 .25264 .7547 .27603 .77949 .25892 .76757 .23401 Metetra
.613 .522 .727 r
.10604 .36517 .11754 .40164 .13736 .39461 .12581 .35801 Metetra
.612 .521 .727 r
.12581 .35801 .13736 .39461 .15732 .38758 .14572 .35087 Metetra
.611 .521 .728 r
.14572 .35087 .15732 .38758 .17743 .38058 .16577 .34387 Metetra
.604 .517 .729 r
.16577 .34387 .17743 .38058 .19769 .37375 .18591 .33747 Metetra
.57 .5 .737 r
.18591 .33747 .19769 .37375 .21804 .3675 .20589 .33427 Metetra
.422 .428 .761 r
.20589 .33427 .21804 .3675 .2383 .36419 .2252 .34043 Metetra
.176 .365 .812 r
.2252 .34043 .2383 .36419 .2581 .36894 .24438 .35181 Metetra
.02 .362 .834 r
.24438 .35181 .2581 .36894 .27786 .37828 .26399 .36284 Metetra
.058 .418 .865 r
.26399 .36284 .27786 .37828 .29803 .38727 .28414 .3722 Metetra
.153 .488 .902 r
.28414 .3722 .29803 .38727 .31869 .39463 .30482 .37959 Metetra
.254 .55 .929 r
.30482 .37959 .31869 .39463 .33983 .4001 .32601 .38492 Metetra
.345 .6 .942 r
.32601 .38492 .33983 .4001 .36143 .40365 .34767 .38822 Metetra
.421 .637 .946 r
.34767 .38822 .36143 .40365 .38344 .40534 .36976 .38956 Metetra
.482 .663 .942 r
.36976 .38956 .38344 .40534 .40583 .40524 .39224 .38904 Metetra
.532 .681 .934 r
.39224 .38904 .40583 .40524 .42857 .40345 .41507 .38678 Metetra
.572 .693 .923 r
.41507 .38678 .42857 .40345 .45163 .40006 .43823 .38286 Metetra
.604 .701 .912 r
.43823 .38286 .45163 .40006 .47497 .39513 .46168 .37739 Metetra
.631 .706 .9 r
.46168 .37739 .47497 .39513 .49857 .38875 .48538 .37044 Metetra
.653 .709 .889 r
.48538 .37044 .49857 .38875 .52239 .381 .50932 .36208 Metetra
.67 .71 .877 r
.50932 .36208 .52239 .381 .54642 .37195 .53346 .3524 Metetra
.685 .709 .867 r
.53346 .3524 .54642 .37195 .57063 .36161 .55778 .34152 Metetra
.698 .71 .857 r
.55778 .34152 .57063 .36161 .59499 .34989 .58225 .32941 Metetra
.712 .713 .849 r
.58225 .32941 .59499 .34989 .61947 .33672 .60685 .31594 Metetra
.727 .716 .841 r
.60685 .31594 .61947 .33672 .64403 .32211 .63154 .30104 Metetra
.74 .72 .833 r
.63154 .30104 .64403 .32211 .66866 .30618 .65629 .2847 Metetra
.751 .721 .824 r
.65629 .2847 .66866 .30618 .69333 .28909 .68108 .26706 Metetra
.758 .72 .816 r
.68108 .26706 .69333 .28909 .71803 .27112 .70588 .24832 Metetra
.762 .715 .808 r
.70588 .24832 .71803 .27112 .74278 .25264 .73069 .22876 Metetra
.76 .706 .8 r
.73069 .22876 .74278 .25264 .76757 .23401 .75553 .20878 Metetra
.609 .51 .716 r
.09487 .32634 .10604 .36517 .12581 .35801 .11457 .31907 Metetra
.607 .509 .717 r
.11457 .31907 .12581 .35801 .14572 .35087 .13441 .31191 Metetra
.601 .506 .718 r
.13441 .31191 .14572 .35087 .16577 .34387 .15433 .30533 Metetra
.565 .486 .725 r
.15433 .30533 .16577 .34387 .18591 .33747 .17402 .30219 Metetra
.395 .398 .745 r
.17402 .30219 .18591 .33747 .20589 .33427 .19279 .30978 Metetra
.09 .301 .781 r
.19279 .30978 .20589 .33427 .2252 .34043 .21132 .32321 Metetra
0 .271 .773 r
.21132 .32321 .2252 .34043 .24438 .35181 .23031 .33633 Metetra
0 .328 .806 r
.23031 .33633 .24438 .35181 .26399 .36284 .24988 .34777 Metetra
.03 .41 .859 r
.24988 .34777 .26399 .36284 .28414 .3722 .27003 .35719 Metetra
.146 .488 .902 r
.27003 .35719 .28414 .3722 .30482 .37959 .29074 .36448 Metetra
.256 .554 .93 r
.29074 .36448 .30482 .37959 .32601 .38492 .31198 .3696 Metetra
.352 .605 .944 r
.31198 .3696 .32601 .38492 .34767 .38822 .3337 .37259 Metetra
.43 .643 .946 r
.3337 .37259 .34767 .38822 .36976 .38956 .35587 .37352 Metetra
.494 .668 .941 r
.35587 .37352 .36976 .38956 .39224 .38904 .37844 .37251 Metetra
.543 .685 .931 r
.37844 .37251 .39224 .38904 .41507 .38678 .40138 .3697 Metetra
.583 .695 .919 r
.40138 .3697 .41507 .38678 .43823 .38286 .42465 .36519 Metetra
.614 .702 .907 r
.42465 .36519 .43823 .38286 .46168 .37739 .4482 .35908 Metetra
.639 .705 .894 r
.4482 .35908 .46168 .37739 .48538 .37044 .47202 .35149 Metetra
.66 .707 .882 r
.47202 .35149 .48538 .37044 .50932 .36208 .49607 .34248 Metetra
.677 .707 .87 r
.49607 .34248 .50932 .36208 .53346 .3524 .52032 .3321 Metetra
.691 .706 .859 r
.52032 .3321 .53346 .3524 .55778 .34152 .54475 .32048 Metetra
.702 .704 .849 r
.54475 .32048 .55778 .34152 .58225 .32941 .56933 .30776 Metetra
.712 .703 .84 r
.56933 .30776 .58225 .32941 .60685 .31594 .59404 .29386 Metetra
.724 .705 .832 r
.59404 .29386 .60685 .31594 .63154 .30104 .61885 .27865 Metetra
.737 .708 .824 r
.61885 .27865 .63154 .30104 .65629 .2847 .64372 .26202 Metetra
.749 .711 .816 r
.64372 .26202 .65629 .2847 .68108 .26706 .66863 .24397 Metetra
.758 .712 .809 r
.66863 .24397 .68108 .26706 .70588 .24832 .69354 .22465 Metetra
.765 .711 .801 r
.69354 .22465 .70588 .24832 .73069 .22876 .71845 .20428 Metetra
.767 .706 .794 r
.71845 .20428 .73069 .22876 .75553 .20878 .74334 .18316 Metetra
.629 .57 .769 r
.08234 .29733 .09487 .32634 .11457 .31907 .10205 .28985 Metetra
.629 .569 .769 r
.10205 .28985 .11457 .31907 .13441 .31191 .12191 .28231 Metetra
.628 .567 .767 r
.12191 .28231 .13441 .31191 .15433 .30533 .14193 .2747 Metetra
.476 .477 .779 r
.14193 .2747 .15433 .30533 .17402 .30219 .16092 .27708 Metetra
0 .23 .741 r
.16092 .27708 .17402 .30219 .19279 .30978 .17874 .29255 Metetra
0 .168 .691 r
.17874 .29255 .19279 .30978 .21132 .32321 .19705 .30774 Metetra
0 .224 .725 r
.19705 .30774 .21132 .32321 .23031 .33633 .21597 .32128 Metetra
0 .314 .792 r
.21597 .32128 .23031 .33633 .24988 .34777 .23552 .33281 Metetra
.016 .406 .856 r
.23552 .33281 .24988 .34777 .27003 .35719 .25569 .34218 Metetra
.143 .49 .903 r
.25569 .34218 .27003 .35719 .29074 .36448 .27643 .34933 Metetra
.258 .559 .933 r
.27643 .34933 .29074 .36448 .31198 .3696 .29772 .35422 Metetra
.358 .612 .946 r
.29772 .35422 .31198 .3696 .3337 .37259 .31952 .35687 Metetra
.44 .65 .948 r
.31952 .35687 .3337 .37259 .35587 .37352 .34177 .35736 Metetra
.505 .675 .941 r
.34177 .35736 .35587 .37352 .37844 .37251 .36445 .35581 Metetra
.555 .691 .93 r
.36445 .35581 .37844 .37251 .40138 .3697 .38749 .35238 Metetra
.594 .7 .917 r
.38749 .35238 .40138 .3697 .42465 .36519 .41087 .34721 Metetra
.625 .705 .903 r
.41087 .34721 .42465 .36519 .4482 .35908 .43454 .34039 Metetra
.649 .707 .89 r
.43454 .34039 .4482 .35908 .47202 .35149 .45848 .33204 Metetra
.668 .707 .877 r
.45848 .33204 .47202 .35149 .49607 .34248 .48264 .32229 Metetra
.684 .706 .864 r
.48264 .32229 .49607 .34248 .52032 .3321 .50701 .3112 Metetra
.698 .705 .853 r
.50701 .3112 .52032 .3321 .54475 .32048 .53155 .29878 Metetra
.708 .702 .842 r
.53155 .29878 .54475 .32048 .56933 .30776 .55624 .28521 Metetra
.715 .698 .832 r
.55624 .28521 .56933 .30776 .59404 .29386 .58105 .27064 Metetra
.724 .696 .823 r
.58105 .27064 .59404 .29386 .61885 .27865 .60597 .25498 Metetra
.734 .697 .816 r
.60597 .25498 .61885 .27865 .64372 .26202 .63096 .23804 Metetra
.745 .7 .809 r
.63096 .23804 .64372 .26202 .66863 .24397 .65599 .21969 Metetra
.756 .703 .802 r
.65599 .21969 .66863 .24397 .69354 .22465 .68102 .19995 Metetra
.765 .704 .795 r
.68102 .19995 .69354 .22465 .71845 .20428 .70603 .17899 Metetra
.77 .702 .788 r
.70603 .17899 .71845 .20428 .74334 .18316 .73101 .15704 Metetra
.664 .741 .907 r
.0675 .28347 .08234 .29733 .10205 .28985 .08729 .27588 Metetra
.664 .741 .907 r
.08729 .27588 .10205 .28985 .12191 .28231 .10724 .26823 Metetra
.664 .741 .907 r
.10724 .26823 .12191 .28231 .14193 .2747 .12734 .26051 Metetra
.471 .672 .952 r
.12734 .26051 .14193 .2747 .16092 .27708 .14673 .25989 Metetra
0 .06 .592 r
.14673 .25989 .16092 .27708 .17874 .29255 .16429 .27712 Metetra
0 .113 .624 r
.16429 .27712 .17874 .29255 .19705 .30774 .1825 .29273 Metetra
0 .206 .704 r
.1825 .29273 .19705 .30774 .21597 .32128 .20139 .30637 Metetra
0 .308 .785 r
.20139 .30637 .21597 .32128 .23552 .33281 .22093 .31788 Metetra
.009 .406 .854 r
.22093 .31788 .23552 .33281 .25569 .34218 .24111 .32715 Metetra
.141 .492 .904 r
.24111 .32715 .25569 .34218 .27643 .34933 .26189 .33413 Metetra
.26 .563 .935 r
.26189 .33413 .27643 .34933 .29772 .35422 .28323 .33879 Metetra
.363 .618 .949 r
.28323 .33879 .29772 .35422 .31952 .35687 .3051 .34113 Metetra
.448 .657 .95 r
.3051 .34113 .31952 .35687 .34177 .35736 .32745 .34119 Metetra
.516 .684 .943 r
.32745 .34119 .34177 .35736 .36445 .35581 .35023 .33908 Metetra
.567 .699 .93 r
.35023 .33908 .36445 .35581 .38749 .35238 .37339 .33496 Metetra
.606 .707 .916 r
.37339 .33496 .38749 .35238 .41087 .34721 .39689 .32904 Metetra
.636 .711 .901 r
.39689 .32904 .41087 .34721 .43454 .34039 .42069 .32146 Metetra
.66 .712 .886 r
.42069 .32146 .43454 .34039 .45848 .33204 .44475 .3123 Metetra
.678 .711 .872 r
.44475 .3123 .45848 .33204 .48264 .32229 .46904 .30167 Metetra
.692 .707 .859 r
.46904 .30167 .48264 .32229 .50701 .3112 .49353 .28976 Metetra
.704 .705 .848 r
.49353 .28976 .50701 .3112 .53155 .29878 .51818 .27657 Metetra
.715 .702 .837 r
.51818 .27657 .53155 .29878 .55624 .28521 .54298 .26212 Metetra
.723 .698 .826 r
.54298 .26212 .55624 .28521 .58105 .27064 .56791 .24659 Metetra
.727 .692 .817 r
.56791 .24659 .58105 .27064 .60597 .25498 .59293 .23018 Metetra
.733 .689 .808 r
.59293 .23018 .60597 .25498 .63096 .23804 .61802 .21276 Metetra
.742 .69 .801 r
.61802 .21276 .63096 .23804 .65599 .21969 .64316 .19411 Metetra
.753 .693 .794 r
.64316 .19411 .65599 .21969 .68102 .19995 .66831 .17409 Metetra
.763 .696 .788 r
.66831 .17409 .68102 .19995 .70603 .17899 .69344 .1527 Metetra
.77 .696 .781 r
.69344 .1527 .70603 .17899 .73101 .15704 .71851 .13013 Metetra
.664 .741 .907 r
.05244 .26941 .0675 .28347 .08729 .27588 .07232 .2617 Metetra
.664 .741 .907 r
.07232 .2617 .08729 .27588 .10724 .26823 .09235 .25394 Metetra
.664 .741 .907 r
.09235 .25394 .10724 .26823 .12734 .26051 .11255 .24611 Metetra
.503 .685 .949 r
.11255 .24611 .12734 .26051 .14673 .25989 .1321 .2445 Metetra
0 .005 .515 r
.1321 .2445 .14673 .25989 .16429 .27712 .14955 .26212 Metetra
0 .095 .6 r
.14955 .26212 .16429 .27712 .1825 .29273 .1677 .27783 Metetra
0 .199 .694 r
.1677 .27783 .1825 .29273 .20139 .30637 .18656 .29146 Metetra
0 .305 .782 r
.18656 .29146 .20139 .30637 .22093 .31788 .2061 .30289 Metetra
.006 .407 .854 r
.2061 .30289 .22093 .31788 .24111 .32715 .2263 .31204 Metetra
.141 .495 .906 r
.2263 .31204 .24111 .32715 .26189 .33413 .24711 .31885 Metetra
.263 .567 .937 r
.24711 .31885 .26189 .33413 .28323 .33879 .26851 .32329 Metetra
.368 .623 .951 r
.26851 .32329 .28323 .33879 .3051 .34113 .29045 .32536 Metetra
.455 .664 .952 r
.29045 .32536 .3051 .34113 .32745 .34119 .31288 .32505 Metetra
.525 .692 .944 r
.31288 .32505 .32745 .34119 .35023 .33908 .33577 .32242 Metetra
.579 .709 .931 r
.33577 .32242 .35023 .33908 .37339 .33496 .35906 .31762 Metetra
.619 .717 .916 r
.35906 .31762 .37339 .33496 .39689 .32904 .3827 .31088 Metetra
.649 .719 .9 r
.3827 .31088 .39689 .32904 .42069 .32146 .40663 .30242 Metetra
.671 .718 .884 r
.40663 .30242 .42069 .32146 .44475 .3123 .43083 .29241 Metetra
.689 .716 .87 r
.43083 .29241 .44475 .3123 .46904 .30167 .45525 .28087 Metetra
.703 .713 .856 r
.45525 .28087 .46904 .30167 .49353 .28976 .47987 .26795 Metetra
.712 .707 .843 r
.47987 .26795 .49353 .28976 .51818 .27657 .50465 .25386 Metetra
.722 .703 .832 r
.50465 .25386 .51818 .27657 .54298 .26212 .52957 .23859 Metetra
.73 .699 .821 r
.52957 .23859 .54298 .26212 .56791 .24659 .5546 .2221 Metetra
.735 .694 .811 r
.5546 .2221 .56791 .24659 .59293 .23018 .57972 .20463 Metetra
.737 .687 .802 r
.57972 .20463 .59293 .23018 .61802 .21276 .60492 .1864 Metetra
.742 .683 .794 r
.60492 .1864 .61802 .21276 .64316 .19411 .63016 .16726 Metetra
.749 .684 .788 r
.63016 .16726 .64316 .19411 .66831 .17409 .65542 .14693 Metetra
.759 .686 .781 r
.65542 .14693 .66831 .17409 .69344 .1527 .68066 .12527 Metetra
.768 .689 .775 r
.68066 .12527 .69344 .1527 .71851 .13013 .70584 .10227 Metetra
.664 .741 .907 r
.03716 .25514 .05244 .26941 .07232 .2617 .05712 .24732 Metetra
.664 .741 .907 r
.05712 .24732 .07232 .2617 .09235 .25394 .07724 .23944 Metetra
.664 .741 .907 r
.07724 .23944 .09235 .25394 .11255 .24611 .09753 .2315 Metetra
.513 .69 .948 r
.09753 .2315 .11255 .24611 .1321 .2445 .11718 .22947 Metetra
.509 .01 0 r
.11718 .22947 .1321 .2445 .14955 .26212 .13455 .24717 Metetra
0 .088 .59 r
.13455 .24717 .14955 .26212 .1677 .27783 .15266 .26287 Metetra
0 .196 .69 r
.15266 .26287 .1677 .27783 .18656 .29146 .1715 .27645 Metetra
0 .305 .78 r
.1715 .27645 .18656 .29146 .2061 .30289 .19103 .28779 Metetra
.004 .408 .854 r
.19103 .28779 .2061 .30289 .2263 .31204 .21124 .29682 Metetra
.142 .498 .907 r
.21124 .29682 .2263 .31204 .24711 .31885 .23209 .30346 Metetra
.266 .571 .938 r
.23209 .30346 .24711 .31885 .26851 .32329 .25354 .30769 Metetra
.371 .627 .952 r
.25354 .30769 .26851 .32329 .29045 .32536 .27555 .30949 Metetra
.46 .669 .953 r
.27555 .30949 .29045 .32536 .31288 .32505 .29808 .30887 Metetra
.531 .698 .946 r
.29808 .30887 .31288 .32505 .33577 .32242 .32107 .30583 Metetra
.588 .718 .933 r
.32107 .30583 .33577 .32242 .35906 .31762 .34449 .30045 Metetra
.632 .728 .917 r
.34449 .30045 .35906 .31762 .3827 .31088 .36827 .29291 Metetra
.663 .73 .9 r
.36827 .29291 .3827 .31088 .40663 .30242 .39236 .28349 Metetra
.684 .727 .883 r
.39236 .28349 .40663 .30242 .43083 .29241 .4167 .27246 Metetra
.7 .722 .867 r
.4167 .27246 .43083 .29241 .45525 .28087 .44127 .25999 Metetra
.714 .718 .853 r
.44127 .25999 .45525 .28087 .47987 .26795 .46603 .24608 Metetra
.724 .713 .84 r
.46603 .24608 .47987 .26795 .50465 .25386 .49094 .23085 Metetra
.73 .705 .828 r
.49094 .23085 .50465 .25386 .52957 .23859 .51599 .2146 Metetra
.736 .7 .817 r
.51599 .2146 .52957 .23859 .5546 .2221 .54114 .19725 Metetra
.743 .696 .807 r
.54114 .19725 .5546 .2221 .57972 .20463 .56637 .17876 Metetra
.746 .69 .798 r
.56637 .17876 .57972 .20463 .60492 .1864 .59166 .15937 Metetra
.746 .682 .789 r
.59166 .15937 .60492 .1864 .63016 .16726 .617 .13936 Metetra
.749 .677 .782 r
.617 .13936 .63016 .16726 .65542 .14693 .64236 .11852 Metetra
.756 .677 .775 r
.64236 .11852 .65542 .14693 .68066 .12527 .6677 .09657 Metetra
.764 .68 .769 r
.6677 .09657 .68066 .12527 .70584 .10227 .69299 .07331 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.08568 .23614 m
.0904 .2407 L
s
[(-5)] .07624 .22703 1 .96527 Mshowa
.21118 .187 m
.2157 .19176 L
s
[(-2.5)] .20215 .17748 .94911 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.48183 .08102 m
.48585 .0862 L
s
[(2.5)] .47379 .07065 .77536 1 Mshowa
.62804 .02377 m
.63176 .02917 L
s
[(5)] .6206 .01296 .68849 1 Mshowa
.125 Mabswid
.11029 .2265 m
.1131 .22926 L
s
.13514 .21677 m
.13793 .21955 L
s
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.26314 .16665 m
.2658 .16956 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.37025 .12471 m
.37279 .12772 L
s
.39772 .11395 m
.40023 .11699 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.53939 .05848 m
.54173 .06164 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.0613 .24568 m
.06416 .24839 L
s
.65822 .01195 m
.66042 .01522 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00^?ooool3o`0006Gooooo002g
ooooo`05o`000?ooooooooooooooool00000I?ooool00;_ooooo00?o0000ooooooooool0H_ooool0
0;_ooooo00?o0000ooooooooool0H_ooool00;Oooooo1?l0000Aooooo`;o0000D_ooool00;Oooooo
00?o0000ooooooooool03oooool3o`000003ooooool0003ooooo057ooooo002gooooo`Go00002ooo
ool2o`0000Cooooo0_l0001Aooooo`00a?ooool3o`0000Kooooo00?o0000ooooool00000D?ooool0
0<;ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000D?ooool00;oo
oooo0ol0000;ooooo`04o`000?ooooooooooo`0004oooooo002mooooo`;o00003_ooool01Ol0003o
oooooooooooooooo000000gooooo0ol0000nooooo`00^_ooool3o`000003ooooool0003ooooo00go
oooo00?o0000ooooooooool00_l0000<ooooo`05o`000?ooooooooooooooool00000?Oooool00;So
oooo0_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`Go00001Oooool00ol0003oooooooooo`0kooooo`00]Oooool3o`0001Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03_ooooo
002cooooo`;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo1?l0000nooooo`00Q_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3
o`0001[ooooo0ol00003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo0027ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Fooooo`?o00007_ooool00ol0003ooooooooo
o`02ooooo`?o00002?ooool5o`0003gooooo0028ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool2o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`18ooooo`00ROooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00oooooo0ol00004ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`17ooooo`00Q_ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000@oooo
o`;o00009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Kooooo0026ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0>ooooo`?o000000?oooooo`00
0?ooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Kooooo0027ooooo`?o
00002?ooool5o`0000[ooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0AOooool009kooooo0ol0000]ooooo`03o`000?oooooooooo00Oooooo0_l00016ooooo`00W?oo
ool2o`000003ooooool0003o000002gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`14ooooo`00VOooool3o`0003;ooooo0_l0000:ooooo`03o`000?oooooooooo04?ooooo002Goooo
o`;o0000=?ooool3o`0000_ooooo00?o0000ooooooooool0@_ooool009Cooooo0ol000000ooooooo
0000ooooo`0booooo`05o`000033[/Co00000<>^a?l000002_ooool00ol0003oooooooooo`12oooo
o`00T_ooool2o`0000Gooooo00?o0000ooooooooool0;oooool01_l00000`jk40<>^a?l00000`jk4
o`0000[ooooo0_l00013ooooo`00Soooool3o`0003Sooooo00Go00000<>^a033[/@0`jk4o`000002
0<>^a003o`000?oooooooooo00Wooooo00?o0000ooooooooool0@?ooool006kooooo0_l0000Moooo
o`;o00000_ooool00ol0003oooooooooo`0eooooo`03o`000033[/@0`jk400<0`jk400?o00000<>^
a?l000002oooool00ol0003oooooooooo`10ooooo`00KOooool01?l0003oooooooooool0000Ioooo
o`?o0000>_ooool2o`0000H0`jk400?o00000<>^a?l000003?ooool00ol0003oooooooooo`0ooooo
o`00KOooool01?l0003oooooooooool0000Gooooo`;o0000??ooool00ol00000`Jg6o`0000060<>^
a004o`000033[/Co0000o`0000cooooo00?o0000ooooooooool0?_ooool006gooooo00Co0000oooo
oooooooo00005?ooool3o`0000;ooooo00?o0000ooooooooool0=oooool2o`0000<0`Jg600?o0000
0<>^a033[/@00`33[/@2o`0000030<B`a_l0003ooooo00[ooooo0_l00010ooooo`00KOooool01?l0
003oooooooooool0000Booooo`;o0000?_ooool00ol00000`Jg60<6]aP030<6]aP03o`000033[/@0
`jk400<0`jk400Go00000<B`aP34/<H0a;36o`00000<ooooo`03o`000?oooooooooo03gooooo001]
ooooo`04o`000?ooooooooooo`0000oooooo0ol0000oooooo`03o`000031[LH0`Jg600D0`Jg600Co
00000<>^a033[/@0`jk40_l000030<B`aP03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
?Oooool006kooooo0_l0000>ooooo`;o00000_ooool00ol0003oooooooooo`0looooo`03o`000031
[LH0`Jg600H0`Jg600Ko00000<>^a033[/Co00000<B`a_l000040<B`aP03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0??ooool007_ooooo0ol00012ooooo`;o00002031[LH00ol00000`jk4
o`0000020<B`aP03o`000034/<H0a;360080a;3600?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0kooooo`00N?ooool4o`0004?ooooo00Co00000;n]b02o[LSo00002031[LH01Ol00000a;36
0<B`aP34/<Ko000000@0a;3600?o0000ooooooooool02oooool2o`0000_ooooo1Ol00003ooooo`03
o`000?oooooooooo00;ooooo0ol0000Qooooo`00M_ooool2o`0000?ooooo00?o0000ooooooooool0
@?ooool01Ol00000_jg80;n]b02o[LSo000000L0`Jg60_l000030<B`aP03o`000034/<H0a;3600<0
a;3600?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Pooooo`00Loooool3o`0004Oooooo00?o00000;n]
b02o[LP00`2o[LP00ol00000`Jg60<6]aP030<6]aP04o`000032[lL0`Zo7o`000080a;3600?o0000
0<B`aP34/<H00P34/<H2o`0000kooooo00?o0000ooooooooool00_ooool5o`0000?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Nooooo`00LOooool2o`0000800000Aoooool00ol0
0000_jg80;n]b0040;n]b003o`000031[LH0`Jg60080`Jg600Go00000<:_a`32[lL0`Zo7o`000002
0<B`aP05o`000034/<H0a;360<B`a_l000000P35//L00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`00K_ooool3
o`0000Cooooo00<00000ooooooooool0@_ooool2o`0000P0_jg800Co00000<6]aP31[LKo00001@32
[lL00ol00000a;36o`0000020<B`aP05o`000035//L0aK;70<Fbaol000003_ooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000001oooool4o`00027ooooo001/ooooo`;o0000
Boooool00ol00000_Zk9o`0000080;n]b003o`000031[LKo000000L0`Zo70_l000000`34/<Ko0000
0<Fba`040<Fba`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool08_ooool003gooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Looooo`?o000000?oooooo`000?ooool0B?ooool2o`0000<0_Zk9
00?o00000;n]b02o[LP01@2o[LP2o`0000P0`Zo70ol000060<Fba`03o`000?oooooooooo00_ooooo
0_l00009ooooo`?o00002?ooool5o`00023ooooo000nooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Iooooo`;o0000COooool00ol00000_Zk90;j^b@030;j^b@03
o`00002o[LP0_jg800@0_jg800?o00000;n_bOl000002032[lL2o`0000L0aK;700?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0fooooo`00=oooool5o`0000?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Dooooo`?o0000C_ooool00ol00000_Zk90;j^b@050;j^b@04o`00
002o[LP0_jg80;n]b0;o00000`2o[lT00ol00000`Zo70<:_a`040<:_a`04o`000033//Wo0000o`00
00L0aK;700?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`00@?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`03o`000?oooooooooo04[o
oooo0_l000080;j^b@04o`00002o[LP0_jg8o`0000D0_jo900?o00000<:_a`32[lL00`32[lL01Ol0
0000`k;90<>bb@33//Wo000000H0aK;70_l0000?ooooo`03o`000?oooooooooo03Gooooo000moooo
o`05o`000?ooooooooooooooool000001oooool4o`0001;ooooo0ol0001@ooooo`03o`00002n/<co
000000P0_Zk900?o00000;n]b?l000001`2o[lT01Ol00000`Zo70<:_a`32[lOo000000@0`k;900?o
00000<Fba`35//L00`35//L01?l00000aK?90<FcbOl0000?ooooo`03o`000?oooooooooo03Cooooo
000mooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Aooooo`?o0000
DOooool01Ol00000_[3<0;j`c02n/<co000000L0_Zk90_l000080;n_b@04o`000032[lL0`Zo7o`00
00D0`k;90_l000030<Fba`05o`000035/lT0aK?90<FcbOl000003_ooool00ol0003oooooo`00000e
ooooo`00?_ooool3o`0000Sooooo1Ol0000<ooooo`?o00000_ooool00ol0003oooooooooo`1>oooo
o`03o`00002n/<`0_[3<0080_[3<00?o00000;j^b@2n[/T0102n[/T00ol00000_Jk;o`0000080;n_
b@03o`000032[lOo000000H0`k;90_l000020<Fba`03o`000035/lT0aK?900<0aK?900?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0cooooo`00F?ooool2o`0005Gooooo00?o00000;j`c02n
/<`0102n/<`00ol00000_Zk90;j^b@020;j^b@05o`00002m[//0_Jk;0;f^bol000001`2o[lT2o`00
00L0`k;90_l000000`35//Oo00000<Fcb@060<Fcb@03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0<_ooool005Gooooo0ol000000ooooooo0000ooooo`1Booooo`;o0000202n/<`01?l00000
_Zk90;j^bOl000040;f^b`03o`00002o[lT0_jo900@0_jo900?o00000<2abol000001`33//T3o`00
00P0aK?900?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`00Doooool2o`0005Oo
oooo00?o00000;jbc_l00000202n/<`00ol00000_Zk9o`0000060;f^b`03o`00002o[lT0_jo90080
_jo900Go00000<2ab`30/L/0`;7;o`0000060<>bb@03o`000033]<_o000000P0aK?90_l0000?oooo
o`;o0000<_ooool0053ooooo0ol0001Gooooo`;o00000`2n//h00ol00000_[3<0;j`c0050;j`c0;o
0000202m[//01?l00000_jo90;n_bOl000040<2ab`03o`000033//T0`k;90080`k;90ol000020<>d
b`03o`000035/lT0aK?900@0aK?900?o00000<Bdbol000004?ooool00ol0003oooooooooo`0`oooo
o`00C_ooool2o`0000;ooooo00?o0000ooooooooool0E?ooool00ol00000_[;>0;jbcP030;jbcP03
o`00002n/<`0_[3<00@0_[3<00?o00000;b_cOl00000202m[//00ol00000_jo9o`0000060<2ab`04
o`000033//T0`k;9o`000080`kC;00Co00000<>db`33]<_o00001@35/lT01Ol00000a;C;0<Bdb`34
]<_o0000013ooooo00?o0000ooooooooool0;oooool004_ooooo0ol0001Jooooo`03o`00002n//h0
_[;>00D0_[;>00Co00000;j`c02n/<`0_[3<0_l000030;b_c@03o`00002m[//0_Jk;00D0_Jk;0_l0
00070<2ab`03o`000033//Wo000000<0`kC;00Go00000<>db`33]</0`kC;o`0000030<Fcb@03o`00
0034]</0a;C;0080a;C;00?o0000ooooooooool03_ooool00ol0003oooooooooo`0_ooooo`00:Ooo
ool3o`0001gooooo0ol0001Jooooo`;o0000202n//h01?l00000_[3<0;j`c?l000050;b_c@03o`00
002m[//0_Jk;00@0_Jk;00?o00000;f`cOl000002030/L/00ol00000`kC;0<>db`020<>db`05o`00
0033]</0`kC;0<>dbol000000P35/lT00ol00000a;C;0<Bdb`040<Bdb`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0;_ooool002Sooooo00Go0000ooooooooooooooooo`00000Iooooo`?o
0000Foooool2o`0000030;bcdOl00000_[;>00L0_[;>00?o00000;j`c?l000001`2l[ld01?l00000
_Jk;0;f^b`2m[//2o`0000<0_K3=00?o00000<2ab`30/L/01030/L/2o`0000@0`kC;00Oo00000<>d
b`33]</0`kC;o`000035/lWo000000L0a;C;00?o0000ooooooooool03_ooool2o`0002oooooo000R
ooooo`Go00001Oooool00ol0003oooooooooo`0Eooooo`;o0000GOooool00ol00000_;?A0;bcd@02
0;bcd@03o`00002n//h0_[;>00D0_[;>0_l000080;b_c@04o`00002m[//0_Jk;o`0000D0_K3=00?o
00000<2ab`30/L/00`30/L/01?l00000`K?=0<6ccOl000030<>db`04o`000033]</0`kC;0<>db`;o
00002034]</00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo000/ooooo`03o`00
0?oooooooooo01;ooooo0ol000000ooooooo0000ooooo`1Jooooo`;o00001P2l/m400ol00000_[;>
0;jbcP030;jbcP03o`00002l/Loo000000P0_:o=00?o00000;f^bol000001`2m/<d01Ol00000`;7;
0<2ab`30/L_o000000<0`K?=00Go00000<>db`33]</0`kC;o`0000020<>db`03o`000033]/go0000
00P0a;C;0_l0000Aooooo`03o`000?oooooooooo02cooooo000Xooooo`Co00004_ooool3o`0005ko
oooo0_l000080;bcd@04o`00002n//h0_[;>0;jbcP;o00000`2l/Ll00ol00000_:o=0;b_c@050;b_
c@;o0000202m/<d01?l00000`;7;0<2abol000050<6cc@06o`000033]</0`kC;o`000033]<_o0000
0`33]/d00ol00000a;C;0<Bdb`040<Bdb`03o`000032]<co000001;ooooo00?o0000ooooooooool0
:oooool002Sooooo00?o0000ooooooooool04Oooool2o`00063ooooo00?o00000;Zddol000002@2l
/m400ol00000_[;>o`0000060;bac`03o`00002l[ld0_:o=00<0_:o=00?o00000;^`c_l00000202m
/<d00ol00000`;7;o`0000070<6cc@04o`000033]</0`kC;o`0000@0`kK=00?o00000<Bdb`34]</0
0P34]</2o`0000<0`[C<00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`;o0000
8oooool002Sooooo1Ol0000<ooooo`?o00000_ooool00ol0003oooooooooo`1Looooo`05o`00002j
]=<0^[CC0;Zddol00000202l/m42o`0000L0_;7?00Co00000;b_c@2l[ld0_:o=0_l000030;^`cP03
o`00002m/<d0_K3=00D0_K3=0_l000080<6cc@04o`000033]<_o0000o`0000D0`kK=00Co00000<Bd
b`34]<_o00001@32]<`00ol0003oooooooooo`0?ooooo`;o00001_ooool01?l0003oooooooooool0
000Rooooo`00=oooool2o`0006?ooooo00?o00000;Zdd`2j]=<00P2j]=<00ol00000_;?A0;bcd@05
0;bcd@03o`00002j/];o000000P0_;7?00?o00000;b_cOl000001@2k/<h00ol00000_K3=0;f`c@03
0;f`c@;o000000<0_[??o`000031/ld01`31/ld2o`0000030<>fcOl00000`kK=00@0`kK=00?o0000
0<Bdbol000001`32]<`00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00008_ooool003Cooooo1_l0001Qooooo`03o`00002j]=<0^[CC00@0^[CC00?o0000
0;bcd@2l/m400P2l/m42o`0000<0^[;B00?o00000;bac`2l/Ll01@2l/Ll2o`0000L0^k3>00Go0000
0;f`c@2m/<d0_K3=o`0000040;jcc`03o`000031/ld0`K?=00@0`K?=00Go00000<:fcol00000`kK=
o`0000050<>fc@;o00002032]<`00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00008_ooool003;ooooo1Ol0000208>`lP;o0000G_ooool2o`0000P0^[CC
00Co00000;bcd@2l/m7o00001@2j/]800ol00000_;7?0;bac`040;bac`03o`00002j/M7o000000L0
^k3>00Co00000;f`cOl0003o00001@2n/ll00ol00000`K?=0<6cc@020<6cc@;o00000`32]/l2o`00
00@0`kK=00?o00000<>gc_l000002032]<`2o`0001;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Rooooo`00;oooool4o`0000030:Vmj?l00000Pk3b00@0Pk3b0_l0001Koooo
o`;o000000<0^KKGo`00002j]=<01`2j]=<00ol00000_;?Ao`0000070;ZbdP04o`00002l/Ll0_;7?
0;bac`;o00000`2j/M400ol00000^k3>0;^`cP040;^`cP;o0000202n/ll01?l00000`K?=0<6ccOl0
00050<:fc`;o00000`33]/d01Ol00000`kO>0<>gcP33]lko000000H0`[C<00?o00000<2dc_l00000
4_ooool00`00003o0000ooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo000]ooooo`?o0000
0P2Y_NP01?l00000ZKgX0:Vmj?l0000508>`lP;o0000FOooool00ol00000^KKG0;Vfe`020;Vfe`03
o`00002j]=<0^[CC00D0^[CC0_l000080;ZbdP04o`00002l/Ll0_;7?o`0000D0^[7A00?o00000;^`
cP2k/<h00`2k/<h00ol00000^k;@o`0000080;jcc`03o`000031/lgo000000L0`[K?00Co00000<>f
c@33]/go00001@33]lh00ol00000`[C<0<:dc0020<:dc005o`000030]<h0`;C>0<2dc_l000004?oo
ool00`00003oooooo`000004ooooo`;o00008oooool002[ooooo0ol000020:Vmj003o`00002Y_NP0
ZKgX00@0ZKgX00Co000008>`lP23/?80Pk3b1?l0001Fooooo`;o00001P2i]]L00ol00000^[CC0;Zd
d`030;Zdd`03o`00002h/mCo000000P0^[;B00?o00000;bacol000001`2j/M401Ol00000^k3>0;^`
cP2k/<ko000000<0^k;@00?o00000;jcc`2n/ll01@2n/ll2o`0000L0`[K?0_l000000`33]/go0000
0<>gcP050<>gcP05o`000032]<`0`[C<0<:dc?l000001030]<h00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02Kooooo000Xooooo`;o000000<0ZKgXo`00002Y_NP00`2Y_NP00ol00000ZKgX
0:Vmj0030:Vmj0Co00000`20[o82o`0005?ooooo0_l000080;Vfe`04o`00002j]=<0^[CC0;Zdd`;o
00000`2h/m@00ol00000^[;B0;ZbdP050;ZbdP;o0000202j/M401?l00000^k3>0;^`c_l000040;^b
d003o`00002n/ll0_[??00@0_[??00?o00000;nfd?l000001032]/l3o`0000030<:fcol0003o0000
00P0`kO>00?o00000<:dc?l000001P30]<h00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Gooooo000Uooooo`?o00000P2Y_NP00ol00000ZKgX0:Vmj0040:Vmj003o`00002Y_NSo000000;o
00000`2Y_NP00ol00000P:ob082_lP02082_lP;o0000D?ooool2o`0000030;Jgf_l00000^KKG00P0
^KKG00?o00000;Zddol000001P2h/m@00ol00000^[;B0;ZbdP030;ZbdP03o`00002i/]?o000000P0
^[7A00?o00000;^`c_l000001P2k/]000ol00000_[??0;jcc`020;jcc`04o`00002o]]00_kK@0;nf
d0Co00000`32]/l00ol00000`[S@o`0000080<>gcP;o00001`30]<h00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Gooooo000Tooooo`03o`00002Y_NP0ZKgX00@0ZKgX00?o00000:Vmj02Y
_NP00`2Y_NP3o`0000H0ZKgX00?o0000082_lP20[o800P20[o82o`0004gooooo0_l000040;JgfP03
o`00002i]]L0^KKG00H0^KKG0_l000070;Rce004o`00002j/]80^[;B0;ZbdP;o00000`2i/]<00ol0
0000^[7A0;Zad@050;Zad@;o0000202k/]001?l00000_[??0;jccol000020;nfd0?o00001032]/l2
o`0000<0`[S@00?o00000<>gcP33]lh01033]lh00ol00000`KO@o`0000070<2dcP03o`000?oooooo
oooo017ooooo0_l0000Vooooo`009?ooool2o`0000H0ZKgX00?o00000:Vmj?l000000_l000030:Vm
j003o`00002Y_NP0ZKgX00<0ZKgX2?l0001:ooooo`;o00001`2f]mX00ol00000^KKG0;Vfe`020;Vf
e`?o000000<0][CGo`00002h/m@01`2h/m@00ol00000^[;Bo`0000050;Vbd`03o`00002j/M40^[7A
00<0^[7A0_l000000`2i/];o00000;^bd0070;^bd003o`00002n/loo000000?o00000`2o]]001?l0
0000`[K?0<:fcol000050<:hd0;o00000`33]lh2o`0000<0`KO@00?o00000<2dcP30]<h01030]<h2
o`0001Cooooo00?o0000ooooooooool08oooool000Wooooo0ol00003ooooo`?o00001?ooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooo000000D0ZKgX0ol000060:Vmj003o`00002Y_NSo0000
00;o00000P2Y_NP01?l00000N:cc07R/l`1h[?<4o`0004Kooooo0_l000000`2c^=go00000;JgfP07
0;JgfP04o`00002i]]Oo0000o`0000D0][CG00?o00000;Rce02h/m@01@2h/m@2o`0000L0^K;C00Go
00000;Zad@2j/M40^[7Ao`0000040;VbdP03o`00002k/]00^k;@00D0^k;@0ol000060;nfd003o`00
0032]/oo000000L0`[S@00Co00000<>gcP33]lko00001@31]m000ol00000`;C>0<2dcP030<2dcP03
o`00002m/m3o000001Cooooo00?o0000ooooooooool08oooool000[ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooo`00002Y_NP00ol000030:Vmj003o`00002Y
_NP0ZKgX00<0ZKgX0_l000060:Vmj004o`00001h[?<0N:cc07R/l`Go0000@_ooool2o`0000@0/kSM
00?o00000;JgfP2f]mX01@2f]mX2o`0000P0][CG00Co00000;Rce02h/m@0^;?D0ol000000`2g/mKo
00000;Vbd`060;Vbd`04o`00002j/M7o0000o`0000D0^K;B00?o00000;^bd02k/]000P2k/]03o`00
00030;bed_l00000_kK@00H0_kK@0_l000080<:hd0?o00001`31]m000ol00000`;C>0<2dcP02o`00
00<0_K?@00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`000_ooool5o`0000?o
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0_l000060:Vmj003o`00002Y_NSo
000000;o00000P2Y_NP00ol00000ZKgX0:Vmj0040:Vmj004o`00001h[?<0N:cc07R/l`?o000000<0
03:`o`000?ooool0?_ooool2o`0000L0/kSM00?o00000;JgfP2f]mX00`2f]mX00ol00000/kKKo`00
00080;Jde`04o`00002h/mCo0000o`0000D0]k?F00?o00000;Vbd`2i/]<0102i/]<2o`0000P0^K;B
00?o00000;^bd?l000000_l000040;bedP03o`00002o]]00_kK@00<0_kK@00?o00000<2hd_l00000
2032^=03o`0000L0`KO@00?o00000<2dc_l000001@2m/m000ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo000:ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol00000ZKgX0:Vmj0030:Vmj0;o00001P2Y_NP00ol00000ZKgX0:Vmj0030:Vmj0So
000000<003:`o`000?l00000>_ooool3o`0000030:njh_l00000/kSM00H0/kSM00Co00000;JgfP2f
]mX0][OJ0_l000030;>ff`03o`00002f]=L0][CG00D0][CG0_l000070;NceP03o`00002i/]<0^K;C
00<0^K;C00?o00000;Nbe?l000001`2i/]85o`0000D0_;GB00?o00000;nfd02o]]000P2o]]001Ol0
0000`;SB0<2hdP30^=;o000000H0`[S@00Co00000<6id_l0003o00001`31]m02o`0000L0_K?@00?o
0000ooooooooool04Oooool2o`0002?ooooo000:ooooo`04o`000?ooooooooooooooo`Co00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol00000ZKgXo`000002o`000080ZKgX00?o00000:Vmj02Y_NP0102Y_NP00ol00000
ZKgXo`000002o`0000030:2Aa?l00000NG[70080NG[72?l0000fooooo`;o00001@2_^^800ol00000
/kSM0;>hg@050;>hg@03o`00002f]m[o000000H0/kKK00?o00000;Jde`2f]=L00`2f]=L00ol00000
];CIo`0000080;NceP03o`00002i/]<0^K;C00;o00000`2g/]@01?l00000^K;B0;VbdP2i/]83o`00
00030;Vbd_l0003o000000P0_;GB00Co00000;nfd02o]]3o00001@30^=800ol00000`[S@0<:hd002
0<:hd004o`000031^M80`KWB0<6idP;o00001@31]m000ol00000_kOBo`0000070;fcd003o`000?oo
oooooooo01?ooooo00?o0000ooooooooool08?ooool000Wooooo0_l00003ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Kooooo00?o00000:Vmj02Y_NP0102Y_NP00ol00000ZKgX0:Vmj0030:Vmj0;o0000
1@2PTL@01_l00000NG[707Uja`1iN/Oo0000000j_@Co000000<004k7o`000?ooool0<_ooool2o`00
00L0[k[R00?o00000;>hg@2c^=d01@2c^=d2o`0000L0/kKK00Co00000;Jde`2f]=L0][CG0_l00003
0;Bdf@03o`00002g/mH0]k?F00D0]k?F00?o00000;Vbdol000001P2g/]@3o`0000<0^K;B00?o0000
0;Vde?l00000202l]M800ol00000_kK@o`0000060<2hdP05o`000032^=00`[S@0<:hd?l000001031
^M800ol00000`KO@o`0000020<6gd0;o00000`2o]m800ol00000_K?@0;fcd0040;fcd0;o00005Ooo
ool00ol0003oooooooooo`0Oooooo`002_ooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
0004ooooo`;o00001?ooool2o`0000Wooooo00?o00000:Vmj02Y_NP0102Y_NP00ol00000ZKgXo`00
0002o`0000030:6Aa?l00000X97400@0X97400?o000007Uja`1iN/L00P1iN/L01ol0000003Zmo`00
0?l0000003:ao`000000C/L00_l0000_ooooo`;o000000<0ZK[Vo`00002_^^801`2_^^801?l00000
/kSM0;>hg@2c^=d3o`0000030;2gg_l00000/kKK00L0/kKK00?o00000;Jdeol000001P2d]=T00ol0
0000]k?F0;NceP040;NceP;o0000102g/]@4o`0000<0^K;B0_l000030;Vde003o`00002l]M80_;GB
00D0_;GB0_l000080<2hdP03o`000032^=3o000000H0`KWB00Co00000<6gd?l0003o00001@2o]m80
0ol00000_K?@0;fcd0030;fcd003o`00002j/m;o000001Gooooo00?o0000ooooooooool07oooool0
02?ooooo00?o0000ooooooooool02?ooool00ol00000ZKgX0:Vmj0030:Vmj0;o00001@2QTL@00ol0
0000X9740:2Aa0020:2Aa003o`00001iN/L0NG[70080NG[700?o0000000j_@00>[d00_l000000`00
<[7o0000o`000003o`0002_ooooo0_l000040:VjiP03o`00002_^^80[k[R00D0[k[R00Co00000;>h
gOl0003o00001@2`]mh00ol00000/kKK0;>ff`050;>ff`;o00001`2d]=T00ol00000]k?F0;NceP02
0;NceP;o000000<0]K?Go`00002g/]@00ol000040;Nbe003o`00002i/];o000000H0^KCD00?o0000
0;bedP2l]M800`2l]M800ol00000_KSEo`0000080<2hdP;o00001`31^M800ol00000`KO@o`000007
0;ngdP03o`00002m/m00_K?@00;o00000`2j/m800ol0003oooooooooo`0Booooo`;o00008?ooool0
02;ooooo00?o0000ooooooooool02_ooool00ol00000ZKgXo`000002o`0000030:6Aa?l00000XI74
00@0XI7400?o00000:2Aa02PTL@00`2PTL@00ol00000NG[707Uja`0207Uja`03o`000000>[d003Zm
00Ko000000<00FSJo`000?ooool09oooool2o`0000L0ZK[V00?o00000:njhP2_^^80102_^^82o`00
00P0/;ON00Co00000;>ff`2c]]/0/kKK0ol000000`2a]=_o00000;Bdf@070;Bdf@04o`00002g/mKo
0000o`000080]K?G0ol000070;Nbe0;o00001`2i]=@01?l00000_;GB0;bedP2l]M82o`0000<0_KSE
00?o00000<2hdP30^=800`30^=82o`0000030<2jeOl00000`KWB00H0`KWB0_l000000`2o]m;o0000
0;ngdP050;ngdP03o`00002m/m3o000000D0^[?B00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Mooooo`008_ooool00ol0003oooooooooo`0;ooooo`03o`00002QTL@0XI7400<0XI7400?o
00000:6Aa02QTL@00P2QTL@00ol00000X9740:2Aa0030:2Aa003o`00001iN/L0NG[70080NG[700?o
0000000j_@00>[d00_l000001P00=;Co0000o`000000C/So0000005XfPCo00008Oooool3o`000080
XK[Z00?o00000:VjiP2Y^^H01@2Y^^H00ol00000[k[R0:njhP03o`0000030:^gh_l00000/;ON00L0
/;ON00Co00000;>ffol0003o00001@2a]=/00ol00000];CI0;Bdf@050;Bdf@;o00000P2e/mL2o`00
0080]K?G00?o00000;Nbe02g/]@00`2g/]@2o`0000030;Jceol00000^KCD00L0^KCD00?o00000;be
d_l000001P2m^=D01Ol00000`;SB0<2hdP30^=;o000000@0`;[E00?o00000<6idP31^M800`31^M80
0ol00000_k[Do`0000020;ngdP03o`00002o]m80_kOB00<0_kOB0_l000070;ZcdP03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07Oooool002;ooooo0_l0000<ooooo`03o`00002QTL@0XI74
00<0XI7400?o00000:6Aa02QTL@00`2QTL@00ol00000X9740:2Aa0020:2Aa004o`00001iN/L0NG[7
07Uja`Co000000<003Zmo`000?l000000P00=;@00ol0000004k8o`000002o`00008097oX1?l0000H
ooooo`Go00001P2Q^^X00ol00000ZK[V0:VjiP040:VjiP?o00001@2[]n800ol00000/;ON0;2ggP05
0;2ggP;o0000202a]=/01?l00000];CI0;Bdf@2d]=T3o`0000040;:df_l0003o0000o`0000D0]K?G
00Go00000;Nbe02g/]@0]k;Do`0000040;Jce`03o`00002i]=@0^KCD00D0^KCD0_l000070;fhe@04
o`000030^=;o0000o`0000H0`;[E00?o00000<6idP31^M800_l000030;nje004o`00002o]m80_kOB
o`000080_kOB0_l000000`2l]mCo00000;ZcdP060;ZcdP03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Sooooo000Roooo
o`03o`000?oooooooooo00cooooo00?o00000:6Aa02QTL@00P2QTL@00ol00000XI740:6Aa0030:6A
a003o`00002PTL@0X9740080X9741?l00002091l^@03o`00001UIKko000000?o00000P00=;@5o`00
00<097oX00?o000004BBl?l000000_l0000?ooooo`Ko0000102F]nh00ol00000XK[Z0:6jjP050:6j
jP03o`00002Y^^H0ZK[V00?o000000<0Y[SVo`00002[]n801P2[]n800ol00000/;ON0;2ggP020;2g
gP;o000000<0[KKOo`00002a]=/01`2a]=/01Ol00000];CIo`000?l00000/[CJ00?o000000<0/[CJ
o`00002e/mL01@2e/mL01?l00000]k;Do`000?l000050;Jce`03o`00002i]=@0^KCD00<0^KCD0_l0
00000`2j]mOo00000;fhe@060;fhe@;o00002030^]D00ol00000`KWBo`0000060;nje005o`00002o
]m;o00000;ngd_l00000102l]m@00ol00000^[?B0;ZcdP040;ZcdP;o00005Oooool2o`0000Kooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo000Rooooo`03
o`000?oooooooooo00cooooo00?o00000:6Aa02QTL@00`2QTL@00ol00000XI740:6Aa0020:6Aa003
o`00002PTLCo000000;o000000<0VH6go`00002@O;T0102@O;T01?l00000IFFn06EU_P1UIKh4o`00
0005001>b?l0003o0000005Xf_l000000`0TOnP01?l00000A9;`04BBl014T_0?o`0000@0Qk;b00?o
000009JgkP2F]nh0102F]nh00ol00000XK[Z0:6jjP040:6jjP?o00001@2V^>H00ol00000ZkOR0:^g
hP050:^ghP04o`00002`]mko0000o`0000@0[KKO00?o00000;6df`2a]=/01@2a]=/5o`0000@0/[CJ
00?o00000;Fce`2e/mL0102e/mL2o`0000P0][?G00Go00000;Vde02i]=@0^KCDo`0000040;Zge`03
o`00002m^=D0_KSE00<0_KSE00?o00000;fjeol000002030^]D2o`0000L0_k[D00Co00000;ngd_l0
003o00001@2l]m@00ol00000^[?B0;ZcdP030;ZcdP03o`00002g/mGo000001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Rooooo`03
o`000?oooooooooo00gooooo00?o00000:6Aa02QTL@00P2QTL@00ol00000XI740:6Aa0020:6Aa0;o
0000102IPKL00ol00000T7bi091l^@03091l^@06o`00001UIKh0IFFn06EU__l000005dg70ol00002
001>b003o`000001J=[o000000Co00000`14T_000ol00000GZ3c05jPl`0305jPl`03o`00001eZo<0
MJ_c00<0MJ_c00?o000008NblP27/_801027/_800ol00000U[O^09JgkP0409JgkP03o`00002Q^^X0
XK[Z00?o000000<0W[OZo`00002V^>H01P2V^>H00ol00000ZkOR0:^ghP040:^ghP;o00001`2]]]l0
0ol00000/KCK0;6df`020;6df`Co0000202b]=X01?l00000]K?G0;Fce`2e/mL2o`0000030;>dfOl0
0000][?G00L0][?G00Co00000;Vde?l0003o00001P2j]mL00ol00000_KSE0;fhe@02o`0000<0_K[G
00?o00000<2je@30^]D00`30^]D2o`0000030;nleol00000_k[D00H0_k[D0_l000020;bge003o`00
002l]m@0_;OD00<0_;OD00?o00000;ZcdP2j/m800_l000030;Nce@03o`000?oooooooooo01Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`;o00003oooool00ol00000XI740:6Aa0020:6Aa003o`00002QTLCo000000;o000000<0
Vh:go`00002IPKL0102IPKL00ol00000T7bi091l^@03091l^@09o`00001UIKh0IFFn06EU__l00000
5dg7o`000000>KWo0000008004k80ol0000202Ani`Co000000<0A9;`o`00001NX?<0101NX?<00ol0
0000MJ_c07F[l`0307F[l`03o`000027/_80Qk;b00@0Qk;b00Co000009JgkP2F]nh0U[O^1Ol00005
09jgjP03o`00002V^>H0Y[SV00D0Y[SV00?o00000:^ghP2[]n800ol000000`2X]^;o00000:ffg`07
0:ffg`03o`00002a]=_o000000;o00000`2_]=d00ol00000/[CJ0;:dfP050;:dfP04o`00002e/mOo
0000o`0000@0/kCI00?o00000;Jce`2f/mL01@2f/mL2o`0000P0^[OG00?o00000;fheOl000001P2m
^]L01Ol00000`;[E0<2je@30^]Go000000@0_kcG00?o00000;nje02o^]@00`2o^]@00ol00000_K[G
o`0000020;bge003o`00002l]m@0_;OD00<0_;OD00?o00000;Zcd_l000001@2g/mD00ol0003ooooo
ooooo`0Eooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`Co
00002?ooool0027ooooo00?o0000ooooooooool03_ooool01?l00000XI740:6Aa02QTL@3o`0000@0
Vh:g00?o000009V1]`2IPKL00`2IPKL00ol00000T7bi091l^@03091l^@03o`00001UIKh0IFFn0080
IFFn00Co000001M=aol0000003Vi0ol000000`02Im[o0000o`00000302Ani`03o`000013TNoo0000
00;o00001@1NX?<00ol00000MJ_c07F[l`0307F[l`04o`000027/_80Qk;b08NblPKo00000`2D]Nh0
0ol00000W[OZ09jgjP0509jgjP03o`00002V^>H0Y[SV00<0Y[SV1?l000050:RfhP03o`00002]]]l0
[KKO00@0[KKO0ol000070:ndg@03o`00002b]=X0/[CJ00@0/[CJ0_l000070;>df@03o`00002f/mL0
][?G0080][?G0_l000000`2f]]Wo00000;Zge`070;Zge`;o00001`2m^]L01?l00000`;[Eo`000?l0
00050;nle`03o`00002o^]@0_k[D0080_k[D00Go00000;fje`2m^]L0_K[Go`0000020;bge003o`00
002l]m@0_;OD0080_;OD0_l000070;Nce@03o`000?oooooooooo01Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03oooool3o`000080Vh:g00?o000009^2]`2KP[L00`2KP[L00ol00000VH6g
09V1]`0209V1]`03o`00002@O;T0T7bi00<0T7bi00?o000006EU_P1UIKh00P1UIKh00ol000005dg7
01M=a`05o`0000800VOJ00Go000002Ani`0TO^L097kWo`00000304>Ak`oo00000`26/O400ol00000
U;G^09BekP0409BekP03o`00002N]nX0W[OZ00@0W[OZ00?o00000:JhiP2V^>H00ol000020::fiP03
o`00002X]^80Z;KR00D0Z;KR00Co00000:ffg`2]]]l0[KKO0ol000000`2[]>3o00000:ndg@060:nd
g@03o`00002b]=X0/[CJ0080/[CJ0_l000000`2`]=_o00000;>df@070;>df@04o`00002f/mOo0000
o`0000@0][KI00?o00000;Zge`2j]mL00`2j]mL2o`0000030;ZjfOl00000_K[G00H0_K[G0_l00008
0;nle`04o`00002o^]@0_k[Do`0000@0_K[G00Ko00000;bge02l]m@0_;ODo`00002l]m@2o`000003
0;Vgeol00000]k?E00H0]k?E00?o0000ooooooooool04oooool00ol0003oooooo`000003ooooo`?o
00002?ooool5o`0000Oooooo000Qooooo`;o00004?ooool00ol00000Vh:g09^2]`0209^2]`03o`00
002KP[L0Vh:g00<0Vh:g00?o000009V1]`2IPKL00`2IPKL00ol00000T7bi091l^@03091l^@03o`00
001UIKh0IFFn0080IFFn00?o000001M=a`0GCLL00ol000001000D<[o0000009WfP02ImX5o`0000<0
@i7_00?o000005jOl`1NWo<00`1NWo<00ol00000M:Wc07BYl`0207BYl`03o`000026/O40Q[7a00@0
Q[7a00?o000009BekP2D]Nh0102D]Nh00ol00000W[OZ09jgjP0309jgjP?o00001P2R]^H00ol00000
Z;KR0:RfhP050:RfhPCo0000102[]>000ol00000[kCM0:ndg@050:ndg@04o`00002b]=[o0000o`00
00@0/;CK00?o00000;>df@2c]=T01@2c]=T2o`0000L0][KI00Go00000;Zge`2j]mL0^[OGo`000004
0;Zjf@03o`00002m^]L0_K[G00<0_K[G00?o00000;fmfOl00000202o_=L00ol00000_k[Do`000006
0;fje`05o`00002l]m@0_;OD0;bge?l00000102i]mL00ol00000]k?E0;Nce@040;Nce@;o00005_oo
ool00ol0003oooooooooo`0Hooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool03oooool00ol00000Vh:g09^2]`0309^2]`03o`00002KP[L0
Vh:g0080Vh:g00?o000009V1]`2IPKL00`2IPKL00ol00000T7bi091l^@03091l^@04o`00001UIKh0
IFFn06EU_PCo000000D05dg7o`000000ALGo0000001@bP02o`000004009Wf_l0000097gW02Ami`Co
000000<0@i7_o`00001NWo<0101NWo<00ol00000M:Wc07BYl`0207BYl`03o`000026/O40Q[7a00@0
Q[7a00?o000009BekP2D]Nh00`2D]Nh00ol00000W[OZ09jgjP03o`00000309^dj_l00000X[KV00L0
X[KV00Co00000:RfhP2X]^80Z;KR1Ol000060:^dh003o`00002_]=d0[kCM00D0[kCM0_l000070;2d
f`04o`00002c]=T0/kCI0;>df@?o000000<0/[GKo`00002f]]T01P2f]]T01?l00000^[OGo`000?l0
00060;Zjf@03o`00002m^]L0_K[G00;o00000`2m_MT00ol00000_kcG0;nle`050;nle`;o00001`2m
^]L00ol00000_;ODo`000002o`0000@0^KOG00?o00000;Nce@2g/mD00`2g/mD00ol00000]KCHo`00
000Gooooo`03o`000?oooooooooo01Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool04?ooool00ol00000Vh:g09^2]`0209^2]`03o`00002KP[L0Vh:g00<0
Vh:g00?o000009V1]`2IPKL00P2IPKL00ol00000T7bi091l^@03091l^@Co00000P2AOk`00ol00000
K6g2o`000002o`0000030015aOl0003o000000Co00000`0TONL00ol00000@Y3_o`000002o`0000D0
GYoc00?o000007BYl`1dZO<00P1dZO<00ol00000Q[7a08Jal@0308Jal@04o`00002D]Nh0U;G^09Be
kPGo00001@2K]>X00ol00000X[KV0::fiP050::fiPKo00000P2V]><00ol00000ZkCP0:^dh0050:^d
h004o`00002_]=d0[kCM0:ndg@?o000000<0[KCNo`00002`]=/01P2`]=/01?l00000/kCIo`000?l0
00050;:ef`03o`00002f]]T0][KI00@0][KI0_l000080;Zjf@03o`00002m^]Oo000000H0_KgI00?o
00000;nle`2o_=L00`2o_=L00ol00000_KgIo`0000070;fje`;o00000`2i]mL00ol00000^KOG0;Vg
e`020;Vge`03o`00002g/mD0]k?E00;o00000`2e]=P00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Kooooo0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Aooooo`03o`00002KP[L0Vh:g0080Vh:g00?o000009^2]`2KP[L00`2KP[L00ol00000
VH6g09V1]`0309V1]`03o`00002@O;Wo000000;o000000<0VXBjo`00002AOk`0102AOk`01?l00000
K6g206a]`P1/KL85o`00000300AWfol0003o000000<097gW00Co000004:@k`12T>l0@Y3_5?l00004
096bkP03o`00002K]>X0VkCZ00@0VkCZ00?o00000::fiP2R]^H00P2R]^H5o`0000H0Y[CS00?o0000
0:^dh02[]>00102[]>001?l00000[kCMo`000?l000050:fdgP03o`00002`]=/0/;CK00@0/;CK0_l0
00070;:ef`03o`00002f]]T0][KI00<0][KI00?o00000;Jifol00000202j^]T2o`0000L0_KgI00Co
00000;nle`2o_=L0_kcG0_l000030;fmf@03o`00002m^]L0_K[G00<0_K[G00?o00000;^kfOl00000
102i]mL01ol00000^KOG0;Vge`2i]mOo00000;NceOl000001@2e]=P00ol0003oooooooooo`0Doooo
o`;o00006?ooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`0001;ooooo00?o
000009^2]`2KP[L00`2KP[L00ol00000Vh:g09^2]`0209^2]`03o`00002IPKL0VH6g0080VH6g0ol0
000409Z4^P03o`00002AOk`0TGnl00<0TGnl00Ko000006a]`P1/KL80K6g2o`00000]GLl2o`000004
001Cc_l0000016OK00AWf`Go00000`12T>l00ol00000G9kb05bNlP0205bNlP03o`00001bZ?<0LZSc
00<0LZSc00?o000008B_l@24[o400`24[o400ol00000TK;^096bkP04096bkP03o`00002K]>X0VkCZ
00@0VkCZ1_l000000`2O]>Oo00000:Jdh`070:Jdh`03o`00002[]>00ZkCP00<0ZkCP0_l000080:fd
gP04o`00002`]=/0/;CK0;2df`;o000000<0[kGMo`00002b]M/01`2b]M/00ol00000][KI0;Jff@02
o`0000<0][WK00?o00000;Zjf@2j^]T0102j^]T00ol00000^[gLo`0000080;fmf@03o`00002o_=Oo
000000H0_KgI00?o00000;fje`2m^]L00_l000030;^kf@03o`00002i]mL0^KOG0080^KOG00?o0000
0;Vge`2i]mL00_l000070;Fdf003o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool0
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Booooo`03o`00
002KP[L0Vh:g0080Vh:g00?o000009^2]`2KP[L00`2KP[L4o`00000309b5^_l00000VXBj00D0VXBj
00?o0000095o_02AOk`00P2AOk`00ol00000K6g206a]`P0206a]`P05o`00000]GLl0;Eg?o`000000
Dlh00_l000001004Im_o000002Ami`0TONL4o`00000304:@kol00000G9kb00<0G9kb00?o000007:X
l`1bZ?<00`1bZ?<00ol00000Q:oa08B_l@0308B_l@03o`00002A/^h0TK;^00@0TK;^00Co000009^d
jP2K]>X0VkCZ1Ol0000509ndi`03o`00002V]><0Y[CS00D0Y[CS00?o00000:^dh02[]>000ol00000
0`2X]>7o00000:fdgP070:fdgP04o`00002`]=_o0000o`0000@0[kGM00?o00000;:ef`2b]M/01@2b
]M/00ol00000][KIo`0000060;Jif`04o`00002j^]T0^[[I0;Zjf@;o00000`2j_M`00ol00000_KgI
0;fmf@050;fmf@;o00001`2m_MT00ol00000_K[Go`0000060;^kf@04o`00002i]mL0^KOG0;Vge`?o
000000<0]kSJo`00002e]=P01P2e]=P00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Co
oooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Booooo`03o`00002KP[L0
Vh:g0080Vh:g00?o000009^2]`2KP[L00P2KP[L2o`0000@0W8Fj00?o000009Z4^P2JQ;X0102JQ;X0
0ol00000TGnl095o_003095o_005o`00001/KL80K6g206a]`_l000000`0]GLl6o`0000<097gW00?o
000004:?k_l000000_l0000405bNlP03o`00001bZ?<0LZSc00<0LZSc00?o000008B_l@24[o400`24
[o401?l00000TK;^096bkP2A/^h6o`0000<0V;?Z00?o000009ndi`2O]>L01@2O]>L00ol00000Y[CS
0:Jdh`040:Jdh`?o00001@2X]>400ol00000[KCN0:fdgP050:fdgP;o00001`2_]Md00ol00000/[GK
0;:ef`040;:ef`;o0000202f^M/00ol00000^[[Io`0000060;Zmg004o`00002m_MT0_KgI0;fmf@?o
000000<0_;oLo`00002m_MT01P2m_MT2o`0000L0^k_I00Ko00000;Vgeol0003o00000;Nhf_l00003
0;NhfP03o`00002e]=P0]KCH00@0]KCH0_l0000Gooooo`03o`000?oooooooooo01Cooooo0008oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooo
ooooool04_ooool00ol00000Vh:g09^2]`0309^2]`Co000000<0W8Fjo`00002LQKX0102LQKX00ol0
0000VXBj09Z4^P0309Z4^P03o`00002AOk`0TGnl00<0TGnl00?o000006a]`P1/KL800P1/KL801Ol0
0000;Eg?02eMcol000001EcE00;o00000P07J=/3o`00000302Amiol00000@Xo^0080@Xo^5?l00000
102>/>ko0000o`000?l0000609RcjP03o`00002O]>L0WkCW00D0WkCW00?o00000:Jdh`2V]><00ol0
00000`2S]>Co00000:Rdh@060:Rdh@03o`00002]]=h0[KCN0080[KCN0_l000000`2[]N3o00000:ne
g@060:neg@03o`00002b]M/0/[GK0080/[GK0_l000000`2b^=go00000;Jif`070;Jif`;o00001`2j
_M`01?l00000_KgIo`000?l000050;bog003o`00002m_MT0_KgI0080_KgI0_l000000`2k_]co0000
0;^kf@060;^kf@;o0000102g^=X01Ol00000]kSJ0;NhfP2g^=[o000000<0]KCH0_l000000`2b]]co
0000ooooo`0Fooooo`;o00005Oooool001oooooo0_l0000Dooooo`03o`00002KP[L0Vh:g0080Vh:g
0_l0000509b5^P03o`00002LQKX0W8Fj0080W8Fj00?o000009Z4^P2JQ;X0102JQ;X00ol00000TGnl
095o_002095o_003o`00001/KL80K6g20080K6g200Go000002eMc`0]GLl0;Eg?o`00000200ELe@05
o`000007J=/01fSKo`00000UO>H00ol0000204:?kP03o`00001KW?80Ficb00<0Ficb00?o0000072V
lP1`Y_800P1`Y_800ol00000PJc`086/l004086/l0?o00000`2>/>h00ol00000V;?Z09RcjP0409Rc
jP03o`00002O]>L0WkCW00@0WkCW0ol000050:>di003o`00002X]>40Z;CQ00D0Z;CQ00Co00000:fd
g_l0003o0000102[]N000ol00000[kGM0:neg@050:neg@04o`00002b]M_o0000o`0000@0/[SM00?o
00000;Jif`2f^M/00`2f^M/2o`0000030;Nlg_l00000^[gL00H0^[gL0_l000080;bog004o`00002m
_MWo0000o`0000@0^kkL00?o00000;^kf@2k^mT00`2k^mT00ol00000^;cLo`0000050;NhfP05o`00
002g^=X0]kSJo`00002e]=P00_l000040;:fg003o`000?oooooooooo01Kooooo00?o0000oooooooo
ool04_ooool001oooooo00?o0000ooooooooool05?ooool4o`00000309b5^_l00000W8Fj00@0W8Fj
00?o000009b5^P2LQKX00P2LQKX00ol00000VXBj09Z4^P0409Z4^P03o`00002AOk`0TGnl00<0TGnl
00?o000006a]`P1/KL801ol0000200ELe@;o000000<01fSKo`00000UO>H00P0UO>H2o`00000304:?
k_l00000Ficb00@0Ficb00?o0000072VlP1`Y_800P1`Y_800ol00000PJc`086/l003o`000003086/
l?l00000S[3^00@0S[3^00?o000009RcjP2H/nX0102H/nX00ol00000WkCW09ndi`03o`00000309fc
j?l00000XkCT00H0XkCT00?o00000:Rdh@2X]>40102X]>42o`0000L0ZkGP00?o00000:neg@2_]Md0
0`2_]Md3o`0000L0/[SM00Go00000;Jif`2f^M/0][WKo`0000040;NlgP03o`00002j_M`0^[gL00<0
^[gL00?o00000;[0g_l00000202l_m`2o`0000L0^kkL00?o00000;^kf@2k^mT00_l000030;Rlg003
o`00002g^=X0]kSJ0080]kSJ00?o00000;NhfP2g^=X00_l000070;:fg003o`000?oooooooooo01Go
oooo00?o0000ooooooooool04_ooool001oooooo00?o0000ooooooooool05?ooool00ol00000W8Fj
09b5^P0309b5^P03o`00002LQKX0W8Fj0080W8Fj00?o000009b5^P2LQKX00`2LQKX00ol00000VXBj
09Z4^P0309Z4^P03o`00002AOk`0TGnl0080TGnl1?l0000209>3_`04o`00001bMLH0LWG6079eaPCo
000000@03V_Mo`000?l0003o00000`0UO>H4o`0000D0Ficb00Co0000072VlP1`Y_80L:Kb0ol00005
086/l003o`00002>/>h0S[3^00<0S[3^00Co000009RcjP2H/nX0V;?Z1Ol0000509fcj003o`00002S
]>@0XkCT00D0XkCT00?o00000:Rdh@2X]>400ol000000`2W]N?o00000:^eh0060:^eh003o`00002_
]Md0[kGM00?o00000P2^]n000ol00000/[SM0;:hg@050;:hg@04o`00002f^M_o0000o`0000H0]kcN
00?o00000;Zmg02j_M`00_l000030;[0gP03o`00002l_m`0_;oL00<0_;oL0_l000000`2k`Mko0000
0;^ng0060;^ng003o`00002k^mWo000000H0^;cL00Co00000;NhfP2g^=X0]kSJ0ol000000`2d^]go
00000;:fg0060;:fg003o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool001oooooo
00?o0000ooooooooool05?ooool00ol00000W8Fj09b5^P0309b5^P03o`00002LQKX0W8Fj00<0W8Fj
00?o000009b5^P2LQKX00P2LQKX00ol00000VXBj09Z4^P0409Z4^PCo000000<0VhNmo`00002CPkl0
102CPkl01_l00000LWG6079eaP1bMLKo0000041[eP;o00000`0>Jmd3o`00000402Eli_l00000@Hg^
046=kP[o000000<0L:Kbo`000021[?000P21[?0<o`0000<0UK7[00?o000009fcj02M/nP01@2M/nP0
0ol00000XkCT0:>di0030:>di0Co00001@2W]N<00ol00000ZkGP0:^eh0040:^eh0?o00001P2^]n00
0ol00000/[SM0;:hg@040;:hg@;o0000202g_=h00ol00000^[gLo`0000060;[0gP05o`00002l_m`0
_;oL0;bog?l00000102k`Mh00ol00000^kkL0;^ng0040;^ng0;o00001`2h_=`01?l00000]kSJo`00
0?l000020;Bjg@04o`00002d^]d0];[Mo`0000H0/[KL0_l0000Fooooo`?o00004_ooool001oooooo
0_l0000Fooooo`03o`00002LQKX0W8Fj0080W8Fj00?o000009b5^P2LQKX00`2LQKX00ol00000W8Fj
09b5^P0209b5^P03o`00002JQ;X0VXBj00<0VXBj0_l0000509^7_@03o`00002CPkl0Th>o0080Th>o
00?o0000079eaP1bMLH00P1bMLH01?l00000@6_F041[e_l0000300i[g@03o`00000WO>Ko000000;o
00000P11SNh00ol00000FY[ao`000003o`0000<0KZCb1Ol0000307j[l003o`00002;[nh0Rjo^00<0
Rjo^00?o000009Faj`2E/N/0102E/N/00ol00000WK?X09fcj00409fcj003o`00002S]>@0XkCT00?o
00000P2Q]>H00ol00000YkGS0:Neh`050:Neh`04o`00002[]N00ZkGP0:^eh0;o000000<0ZKORo`00
002^]n001`2^]n001?l00000/[SM0;:hg@2b^=d2o`000080/[_P00?o00000;NlgP2g_=h01@2g_=h2
o`0000L0^/3N00Co00000;bog?l0003o00001P2k`Mh01?l00000^kkL0;^ng02k_]`2o`0000030;Vo
g_l00000^;cL00H0^;cL0_l000040;Bjg@04o`00002d^]d0];[Mo`0000<0/[KL0ol000000`2`^N3o
0000ooooo`0Gooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo01Gooooo
00?o000009b5^P2LQKX00`2LQKX00ol00000W8Fj09b5^P0209b5^P03o`00002LQKX0W8Fj00<0W8Fj
00?o000009Z4^_l000000_l000000`2MR;go000009^7_@0409^7_@03o`00002CPkl0Th>o0080Th>o
00?o0000079eaP1bMLH00`1bMLH00ol00000@6_F041[eP03o`00000300i[gOl000009gcV00809gcV
1?l0000405ZJl@03o`00001^Y?80KZCb0080KZCb00?o000007j[l01nZo00101nZo000ol00000Rjo^
08^_kP0308^_kP03o`00002E/N/0UK7[00@0UK7[00Co000009fcj02M/nP0WK?X1Ol000060:6diP03
o`00002W]N<0YkGS00@0YkGS00Co00000:^eh?l0003o0000102Y]n800ol00000[[OP0:jgh0050:jg
h004o`00002b^=go0000o`0000D0/[_P00?o00000;NlgP2g_=h00P2g_=h2o`0000030;O0hOl00000
^/3N00H0^/3N0_l000080;_1gP04o`00002k_]co0000o`0000@0^KoN00?o00000;Rlg02h_=`00P2h
_=`2o`0000030;Jmgol00000];[M00@0];[M00Co00000;BjgOl00000/[KL0_l000050;2ih003o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01Oooool3o`0000Oooooo000Oooooo`03o`000?oo
oooooooo01Gooooo00?o000009b5^P2LQKX00`2LQKX00ol00000W8Fj09b5^P0309b5^P03o`00002L
QKX0W8Fj00Co00001@2MR;d00ol00000VhNm09^7_@0209^7_@03o`00002CPkl0Th>o00<0Th>o00?o
0000079eaP1bMLH00P1bMLH01_l00000@6_F041[eP10JmKo0000029`g`?o000000@09gcVo`000?l0
0000@Hc]0ol0000405ZJl@03o`00001^Y?80KZCb0080KZCb00?o000007j[l01nZo00101nZo000ol0
0000Rjo^08^_kP0308^_kP04o`00002E/N/0UK7[09Faj`Ko0000102J/nT00ol00000XKCV0:6diP05
0:6diP03o`00002W]N<0YkGS00<0YkGS0_l000070:VghP03o`00002^]n00[[OP00@0[[OP0_l00008
0;:kh004o`00002g_=ko0000o`0000@0]l3Q00?o00000;[0gP2j`=h00P2j`=h2o`0000030;W2hOl0
0000^l7N00L0^l7N0_l000070;VogP04o`00002h_=co0000o`0000@0][gO00?o00000;Bjg@2d^]d0
0`2d^]d3o`0000P0/;WP00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001_ooool001oooooo00?o0000ooooooooool05_ooool00ol00000W8Fj
09b5^P0209b5^P03o`00002LQKX0W8Fj0080W8Fj1?l0000209f8_@03o`00002MR;d0WHRm00@0WHRm
00?o000009^7_@2KQkd00`2KQkd00ol00000Th>o09>3_`0209>3_`03o`00001bMLH0LWG600<0LWG6
00Ko0000041[eP10JmH0@6_Fo`00000RL=l4o`00000302Mli_l00000@Hc]0080@Hc]1?l000000`1J
V_7o000006jTlP0306jTlP03o`00001nZo00OZ_`00<0OZ_`00Co000008^_kP2;[nh0Rjo^1_l00003
09:ak003o`00002J/nT0V[?Y00D0V[?Y00?o00000:6diP2Q]>H0102Q]>H00ol00000YkGS0:Neh`03
o`000080YKKU00?o00000:VghP2Y]n801@2Y]n800ol00000[[OP0:jgh003o`0000030:jjhol00000
/[_P00L0/[_P0_l000070;O0h@04o`00002j`=ko0000o`0000@0^L;Q00?o00000;_1gP2k`Mh00P2k
`Mh3o`0000030;W2hOl00000^KoN00H0^KoN0_l000070;Jmg`04o`00002d^]d0];[M0;Bjg@Co0000
202`^N000ol0003oooooooooo`0Eooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`007_oo
ool2o`0001Sooooo00?o000009b5^P2LQKX00`2LQKX4o`00000309f8_Ol00000WHRm00@0WHRm00?o
000009f8_@2MR;d00`2MR;d00ol00000VhNm09^7_@0309^7_@03o`00002CPkl0Th>o0080Th>o00Co
0000079eaP1bMLH0LWG62?l00002029`g`03o`00000/ONOo000000;o00000`11S>d00ol00000F9Wa
05RIl@0@o`0000@0R:k_00?o000009:ak02B/N`00`2B/N`00ol00000V[?Y09Zcj@0509Zcj@04o`00
002Q]>H0XKCV0:6diPGo00001P2U]^D00ol00000ZKOR0:VghP040:VghP?o00001@2^^^<00ol00000
/[_P0;:kh0020;:kh0?o000000<0/koSo`00002g`>401P2g`>42o`0000L0^L;Q00Co00000;_1g_l0
003o00001@2i`^400ol00000^KoN0;VogP020;VogP;o000000<0]l7Ro`00002f_Ml01P2f_Ml01?l0
0000];[Mo`000?l000020;:mhP03o`00002b_N;o000000L0/;WP0_l0000Hooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool001kooooo00?o0000ooooooooool05oooool00ol0
0000W8Fj09b5^P0209b5^P;o00001@2MR;d00ol00000WHRm09f8_@0209f8_@03o`00002MR;d0WHRm
00@0WHRm00?o000009^7_@2KQkd00P2KQkd00ol00000Th>o09>3_`0209>3_`Co00000P2DQl<3o`00
0080N7c;0ol000000`0RL=oo000002ami`0202ami`?o000000<0@Hc]o`00001HVO400P1HVO400ol0
0000Jj?b06^SlP0306^SlP03o`00001kZO40NjWa00<0NjWa00?o000008R^k`28[^l01028[^l00ol0
0000T[7/09:ak00309:ak003o`00002J/nT0V[?Y00@0V[?Y1?l0000309nej003o`00002U]^D0YKKU
00H0YKKU00?o00000:VghP2Y]n800ol000000`2X^NGo00000:jjh`060:jjh`04o`00002b^n3o0000
o`0000D0/koS00?o00000;O0h@2g`>400`2g`>400ol00000]l?So`0000070;W2h@;o0000202i`^40
1?l00000^KoNo`000?l000040;O1hP03o`00002f_Ml0][gO00@0][gO0_l000050;:mhP03o`00002b
_N;o000000<0/;WP0ol000000`2__nKo0000ooooo`0Hooooo`04o`000?ooooooooooooooo`Co0000
1oooool001kooooo00?o0000ooooooooool06?ooool4o`00000309f8_Ol00000WHRm00@0WHRm00?o
000009f8_@2MR;d00P2MR;d00ol00000WHRm09f8_@0409f8_@03o`00002KQkd0VhNm00<0VhNm1?l0
00000`2LRl7o000009B7``03o`000080U8O300Ko000007Qlb`1hO</0N7c;o`00001AN=X3o`0000<0
;7gW00?o0000046<kOl000000_l0000305RIl@03o`00001[Xo80Jj?b00<0Jj?b00?o000007^Yl@1k
ZO400`1kZO400ol00000R:k_08R^k`0408R^k`03o`00002B/N`0T[7/00<0T[7/00?o000009Zcj@2J
/nT00ol000000`2H/n_o000009nej00509nej003o`00002U]^D0YKKU00@0YKKU1?l000050:Rii@03
o`00002^^^<0[[[S00@0[[[S0_l000080;>oh`03o`00002g`>40]l3Q00;o00000`2g`n<00ol00000
^L;Q0;W2h@030;W2h@03o`00002ha>?o000000P0^L;Q0_l000070;O1hP04o`00002f_Ml0][gO0;Jm
g`;o000000<0/l7To`00002b_N801@2b_N82o`0000030;2ih?l0003o000000D0[koV00?o0000oooo
ooooool05_ooool01Ol0003ooooooooooooooooo000000[ooooo000Nooooo`;o00006Oooool00ol0
0000WHRm09f8_@0309f8_@03o`00002MR;d0WHRm0080WHRm00?o000009f8_@2MR;d00`2MR;d00ol0
0000WHRm09f8_@0309f8_@03o`00002KQkd0VhNm0080VhNm0_l0000309b;`@?o00001@2DQl<00ol0
0000N7c;07Qlb`0207Qlb`04o`00001AN=X0DGSJ055hfP?o000000<0;7gWo`000011S>d00P11S>d5
o`0000D0Jj?b00?o000007^Yl@1kZO400`1kZO401?l00000R:k_08R^k`28[^l;o`0000D0V;?[00?o
000009nej02O]NP0102O]NP00ol00000YKKU0:Ffi@03o`000080XkSW00?o00000:Rii@2X^ND01@2X
^ND01?l00000[[[S0:jjh`2^^^<2o`0000030:jni_l00000/koS00L0/koS00?o00000;O0hOl00000
1P2g`n<00ol00000^L;Q0;W2h@02o`0000<0^<CS00?o00000;W2h@2i`^400`2i`^42o`0000030;O4
i?l00000]l7R00H0]l7R00Co00000;Jmgol0003o0000102c`N@00ol00000/[gR0;:mhP040;:mhP;o
00001`2__nH00ol0003oooooooooo`0Eooooo`80000000?o0000ooooooooool01Ol00006ooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`03o`00002MR;d0WHRm00<0WHRm00?o000009f8_@2MR;d0
0`2MR;d00ol00000WHRm09f8_@0209f8_@03o`00002MR;d0WHRm00@0WHRm1?l000000`2MS<7o0000
o`000002o`000080W8_100?o000009B7``2DQl<00`2DQl<00ol00000N7c;07Qlb`0207Qlb`05o`00
001AN=X0DGSJ055hf_l000000P0kP>H3o`0000<0@Hc]00?o000005JHl@1FV?404?l0000308F^l003
o`00002?/Nd0Sk7]00<0Sk7]00?o000009Rcj`2H/n/01@2H/n/00ol00000WkGX09nej00309nej0?o
00001P2S^>L00ol00000Z;WU0:Rii@040:Rii@04o`00002^^^?o0000o`0000@0[[kV00?o00000;>o
h`2c_n<0102c_n<3o`0000L0]l?S00?o00000;W2hOl000001P2ha><01Ol00000^L;Q0;W2h@2i`^7o
000000@0]lCT00?o00000;O1hP2g`N80102g`N82o`0000L0/l7T00?o00000;:mhP2b_N801Ol00007
0:noiP;o00005oooool3o`0000cooooo0009ooooo`?o00001?ooool2o`0000Cooooo0_l00006oooo
o`03o`000?oooooooooo01Wooooo00?o000009f8_@2MR;d00P2MR;d00ol00000WHRm09f8_@0309f8
_@03o`00002MR;d0WHRm0080WHRm00Co000009f8_@2MR;d0WHRm1?l0000309f<`@?o00001@2LRl40
0ol00000U8O309B7``0309B7``03o`00001hO</0N7c;0080N7c;00Go0000055hfP1AN=X0DGSJo`00
000403^0iPGo0000101FV?401Ol00000JJ;b06VRlP1YX_;o000000D0N:Wa00?o000008F^l025[_00
1025[_000ol00000Sk7]08nak@0308nak@03o`00002H/n/0V;?[00@0V;?[00?o000009nej02O]NP0
0ol000000`2M]n[o00000:>hi`070:>hi`03o`00002X^ND0Z;WU00<0Z;WU0_l000070:jniP03o`00
002c_n<0/koS00?o00000P2b`^H00ol00000]l?S0;O3h`050;O3h`;o00001`2ha><01?l00000^L;Q
o`000?l000050;O4i004o`00002g`N80]l7R0;O1hP?o000000<0]<CVo`00002c`N@01P2c`N@3o`00
00@0/<7W0_l000040:noiP;o000000<0[LK/o`000?ooool04oooool3o`00000304L00_l0003o0000
00cooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06_ooool00ol00000WHRm09f8
_@0309f8_@03o`00002MR;d0WHRm0080WHRm00?o000009f8_@2MR;d00P2MR;d4o`0000<0WXc01?l0
000209f<`@03o`00002LRl40W8_100<0W8_100?o000009B7``2DQl<00`2DQl<00ol00000N7c;07Ql
b`0207Qlb`03o`00001AN=X0DGSJ0080DGSJ00Go000003^0iP0kP>H0>h3Vo`00000304><k@Go0000
00<0EYSao`00001YX_800P1YX_800ol00000N:Wa07RYl@0307RYl@03o`000025[_00QJk`00@0QJk`
00?o000008nak@2?/Nd00`2?/Nd01?l00000V;?[09Rcj`2H/n/5o`0000D0WKOZ00?o00000:>hi`2S
^>L01@2S^>L00ol00000Z;WU0:Rii@03o`0000030:Rlj?l00000[[kV00H0[[kV0ol000060;;2iP03
o`00002g`n<0]l?S0080]l?S0_l000000`2faNKo00000;S4h`060;S4h`;o00001`2ga>@01?l00000
]l7Ro`000?l000050;C4iP03o`00002c`N@0/l7T0080/l7T0_l000000`2aa>So00000;31i`050;31
i`;o000000<0[koVo`000?l00000102]a^`00ol0003oooooooooo`0?ooooo`;o00000`1700801?l0
0000ZKgXo`000?l0000;ooooo`000_ooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_oo
ool00ol00000WHRm09f8_@0309f8_@03o`00002MR;d0WHRm00<0WHRm1?l000000`2NS<3o000009j<
`00209j<`0Co0000102MS<400ol00000W8_109b;`@0309b;`@03o`00002DQl<0U8O300<0U8O300Co
000007Qlb`1hO</0N7c;1_l000000`1AN=[o000003^0iP0203^0iP03o`000013S>d0@hc]0080@hc]
00?o000005FHl@1EV?401ol0000507RYl@03o`000025[_00QJk`00<0QJk`00Co000008nak@2?/Nd0
Sk7]1_l0000409Jdk@03o`00002M]nX0WKOZ00@0WKOZ00?o00000:>hi`2S^>L0102S^>L3o`0000D0
Z;cX00?o00000:jniP2^_^H00P2^_^H2o`000080[L7X00?o00000;;2iP2b`^H01@2b`^H01?l00000
]l?So`000?l000040;K5iP03o`00002ha><0^<CS0080^<CS0_l000000`2fa^Oo00000;O4i0060;O4
i0;o0000202da>H01?l00000/l7To`000?l000040;74j003o`00002``NL0/<7W00<0/<7W0ol00007
0:g6k003o`000?oooooooooo00_ooooo0ol00000100c003o000004L00P170082o`0000040:Vmj?l0
003o0000o`0000[ooooo000<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`;o00007?ooool00ol00000WHRm09f8_@0209f8_@03
o`00002MR;d0WHRm0080WHRm0_l0000509j<`0?o00000`2NS<000ol00000WHc109f<`@0309f<`@03
o`00002LRl40W8_100<0W8_100?o000009B7``2DQl<00P2DQl<4o`000080UXc700Co000007j4c`1n
Q<l0OXC?1ol0000404><k@05o`00001EV?40EISa05FHlOl000000`1VXO8@o`0000@0SK;_00?o0000
09Jdk@2F]>d0102F]>d00ol00000WKOZ09fgjP0409fgjP03o`00002S^>L0XkSW00?o000000<0X[_Z
o`00002X_>P01P2X_>P01?l00000[[kVo`000?l000050:g1j003o`00002b`^H0//;V00@0//;V0_l0
00070;K5iP04o`00002ha>?o0000o`0000@0]/KW00?o00000;O4i02ga>@00P2ga>@2o`000080]<OX
00?o00000;C4iP2da>H0102da>H3o`0000L0/LCX00?o00000;31i`2``NL01?l000000`2^b>go0000
0:g6k0050:g6k0;o00002_ooool2o`0000<0<`001?l000000`15003o0000o`0000020:Vmj003o`00
0?oooooooooo00Sooooo0008ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool06oooool00ol00000WHRm09f8_@0309f8_@Co
000000@0Whc0o`00002NS<00WXc01?l0000509j<`003o`00002MS<40WHc100<0WHc100?o000009b;
`@2LRl400`2LRl400ol00000U8O3o`000002o`00000309f?aOl00000UXc700@0UXc700?o000007j4
c`1nQ<l00P1nQ<l01?l00000Gh?N05n3gP1OPmh5o`00000304><kOl00000EISa0080EISa00?o0000
06JQlP1VXO800P1VXO800ol00000MZWb07JYlP0307JYlP03o`000022[_40PZka00<0PZka00?o0000
08fbk`2=/^l0102=/^l00ol00000U[C]09Jdk@0409Jdk@04o`00002M]nX0WKOZ09fgjPGo00001@2R
^nX00ol00000Z;cX0:Rlj0040:Rlj0;o0000202]`NP00ol00000//;V0;;2iP03o`000080//KY00?o
00000;K5iP2faNH0102faNH2o`0000L0]/KW00Co00000;O4i?l0003o00001@2danP00ol00000]<CV
0;C4iP03o`000080//SZ00?o00000;74j02aa>P01@2aa>P3o`0000@0[/S]00?o00000:k8kOl00000
0P2]a^`3o`0000030:[>lol0003ooooo00Wooooo00?o000003<0000c00000ol0000304D00003o`00
002Y_NP0ZKgX00<0ZKgX00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool06oooool00ol00000WHRm09f8_@0209f8_@;o0000102OS<03o`0000@0WXc000?o000009j<`02N
S<000`2NS<000ol00000WHc109f<`@0209f<`@04o`00002LRl40W8_109b;`@Co00001@2MSlD00ol0
0000UXc709J<a`0209J<a`03o`00001nQ<l0OXC?00<0OXC?00?o000005n3gP1OPmh00P1OPmh00ol0
0000D8g[052=j`07o`0000@0IZ7b00?o000007JYlP1fZO800`1fZO800ol00000PZka08:^l@0308:^
l@03o`00002=/^l0SK;_00@0SK;_00Co000009Jdk@2F]>d0U[C]1_l0000309^ik@03o`00002R^nX0
X[_Z00D0X[_Z00?o00000:Rlj02X_>P00ol000000`2W`>_o00000:g1j0070:g1j0?o00001P2ba^T0
0ol00000]/GV0;K5iP03o`000080]<SY00?o00000;K6i`2fa^L0102fa^L2o`0000L0]<OX0ol00006
0;;8jP04o`00002aa>P0/LCX0;74j0?o000000<0[/[^o`00002^b>d01@2^b>d4o`0000D0Z/kc00?o
0000ooooooooool01_ooool4o`00000304000?l00000A@000080A@000_l000050:Vmj0;o00002?oo
ool000Sooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool07?ooool4
o`00000309n<`?l00000Whc000?o000000<0Whc0o`00002NS<00102NS<000ol00000WXc009j<`003
09j<`003o`00002MS<40WHc10080WHc11?l0000309j@a003o`00002MSlD0WHo500<0WHo500?o0000
09J<a`2FS<L00`2FS<L00ol00000OXC?07j4c`0307j4c`03o`00001OPmh0Gh?N0080Gh?N00Go0000
052=j`1@SN/0D8g[o`00000305NHl0Go000000<0IZ7bo`00001fZO80101fZO800ol00000PZka08:^
l@0308:^l@04o`00002=/^l0SK;_08fbk`Ko00000`2C]^l00ol00000VkW]09^ik@0409^ik@03o`00
002R^nX0X[_Z00@0X[_Z0ol000050:O0j`03o`00002]`NP0[L7X0080[L7X0ol000000`2]aNco0000
0;;6j@060;;6j@?o00001P2db>T00ol00000]/KW0;K6i`03o`000080/lWZ00?o00000;C7j02danP0
0P2danP2o`0000030;;:k?l00000//SZ00H0//SZ00Co00000;74j?l0003o00001@2^b^h00ol00000
[/S]0:k8k@04o`0000030:_@lol00000Z/kc00D0Z/kc0ol00005ooooo`;o00000`1000000ol00000
A@00o`000002o`00000403H00?l00000ZKgX0:Vmj0?o000000?oooooo`000?ooool01oooool001co
oooo0_l0000Nooooo`03o`00002OS<00Whc00080Whc00_l0000409n<`003o`00002NS<00WXc000<0
WXc000?o000009j<`02NS<000`2NS<000ol00000WHc1o`000002o`00000309n@a?l00000WY3400D0
WY3400?o000009f?a@2MSlD00P2MSlD00ol00000UXc709J<a`0409J<a`03o`00001nQ<l0OXC?0080
OXC?00?o000005n3gP1OPmh00`1OPmh01Ol00000D8g[052=j`1@SN_o000000@0EiS`00?o000006FR
l`1UX_<04Ol0000308Zcl@03o`00002C]^l0TkK_00@0TkK_00?o000009^ik@2K^Nd0102K^Nd00ol0
0000X[_Z0::kjP03o`0000030:6nk_l00000Yl3[00H0Yl3[00Co00000:g1j?l0003o00001@2]aN`0
0ol00000//KY0;;6j@020;;6j@;o000000<0/<S/o`00002db>T01P2db>T3o`0000H0/lWZ00Co0000
0;C7j?l0003o0000102bb^`00ol00000//SZ0;;8jP040;;8jP;o00001`2^b^h3o`0000@0Zm3c00?o
00000:_@lol000000P2Zc_<3o`0000<0Y]Oi00?o0000ooooool000000_l00000100M003o00000400
00100003o`0000<0=P001?l00004ooooo`03o`000?oooooooooo00Kooooo000Looooo`03o`000?oo
oooooooo01gooooo00?o000009n<`?l000000_l000000`2OS<3o000009n<`00409n<`003o`00002N
S<00WXc000<0WXc000?o000009j<`02NS<000P2NS<02o`0000D0Wi3400?o000009j@a02NT<@00`2N
T<@00ol00000WHo509f?a@0309f?a@03o`00002FS<L0UXc700<0UXc700Co000007j4c`1nQ<l0OXC?
3Ol0000405NHl005o`00001UX_<0IJ;c06FRlol000001@1cZO<00ol00000Ojoc07n_l`0307n_l`03
o`00002:/o40R[?a00@0R[?a00?o000009>fk`2C]^l0102C]^l01?l00000VkW]09^ik@2K^Nd5o`00
00D0XKk^00?o00000:O0j`2W`>/0102W`>/3o`0000L0[LG/00Co00000;;6jOl0003o0000102`b>`0
0ol00000]<SY0;C8j@020;C8j@;o000000<0//_]o`00002cbNX01P2cbNX2o`0000L0//[/00?o0000
0;;8jP2bb>X00ol000020:o=l003o`00002^b^h0[/[^0080[/[^0_l000020:_Bm003o`00002[d?<0
Zm3c00<0Zm3c1?l000060:KGn@;o00000`0M0005o`00000303H00?l0003o000000?o00001oooool0
0ol0003oooooooooo`06ooooo`007?ooool00ol0003oooooooooo`0Looooo`?o0000102OS<000ol0
0000Whc009n<`00309n<`003o`00002NS<00WXc000<0WXc000?o000009j<`?l000000_l000000`2O
T<Co000009n@a00409n@a003o`00002NT<@0WY3400@0WY3400?o000009f?a@2MSlD00P2MSlD00ol0
0000UXc709J<a`0309J<a`Co00000P2HTL/00ol00000Q8cC08B<d`0308B<d`04o`00001/S^80K8kR
06b>hPGo000000<0EiS`o`00001UX_<00P1UX_<00ol00000LjWc07>Yl`0307>Yl`03o`00001o[o<0
Ojoc00<0Ojoc00?o000008Zcl@2:/o40102:/o401?l00000TkK_09>fk`2C]^l6o`0000@0VKc`00?o
00000:6nkP2Q_^h0102Q_^h00ol00000Yl3[0:O0j`03o`0000<0YlC^00?o00000:g5k02]aN`0102]
aN`2o`0000L0/<S/00Co00000;C8jOl0003o0000102bbnd00ol00000/lWZ0;?9jP020;?9jP;o0000
0P2acNh00ol00000//[/0;;:k0040;;:k0?o00001P2_cO001?l00000[/[^o`000?l000050:_Bm003
o`00002[d?<0Zm3c00Co000000<0Y]Wio`00002VeoT00`2VeoT2o`000080WN3m1?l000000`0d003o
0000o`000002o`0000<07`0000?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`00
7?ooool00ol0003oooooooooo`0Iooooo`?o00000_ooool00ol00000Whc009n<`00309n<`003o`00
002OS<00Whc00080Whc000?o000009j<`02NS<000`2NS<02o`0000D0Wi3400?o000009n@a02OT<@0
0P2OT<@00ol00000WY3409j@a00409j@a003o`00002MSlD0WHo50080WHo500?o000009J<a`2FS<L0
0ol000000`2NTlWo000009RAb`0409RAb`03o`000024S=<0Q8cC00<0Q8cC00?o000006b>hP1/S^80
0P1/S^800ol00000HIS^066HkP07o`0000D0LjWc00?o000007n_l`1o[o<00`1o[o<01?l00000R[?a
08Zcl@2:/o46o`0000<0TKWb00?o000009Vll02I_?001@2I_?001?l00000XKk^0:6nkP2Q_^h5o`00
00L0YlC^00?o00000:g5k02]aN`00ol000020:_8k`03o`00002`b>`0/<S/00@0/<S/0_l000070;;;
k@04o`00002cbN[o0000o`0000D0/Lg^00?o00000;;:k02bb^`00ol000020:o?l@03o`00002_cO00
[lg`00@0[lg`0_l000070:_Bm0?o00000`2VfOT01Ol00000Y]Wi0:KInOl00000Y]Oi00;o0000102M
h?d5o`00000301h00?l000007`0000Co00002_ooool00ol0003oooooooooo`05ooooo`007?ooool2
o`0001Oooooo0ol00005ooooo`03o`00002OS<00Whc000<0Whc000?o000009n<`02OS<000`2OS<00
0ol00000WXc0o`000002o`00000309n@a?l00000Wi3400@0Wi3400?o000009n@a02OT<@00`2OT<@0
0ol00000WY3409j@a00309j@a004o`00002MSlD0WHo509f?a@Co00001@2NTlT00ol00000V97;09RA
b`0209RAb`03o`000024S=<0Q8cC00@0Q8cC00?o000006b>hP1/S^800P1/S^801Ol00000HIS^066H
kP1QV>ko000000<0IZ;c4?l0000308Rel`03o`00002A^O80TKWb00@0TKWb00?o000009Vll02I_?00
102I_?04o`0000@0Wl;a00?o00000:O4kP2Wa>h0102Wa>h4o`0000H0ZlS_00?o00000;38k02`b>`0
0ol000020:k<k`03o`00002bbnd0//_]00@0//_]0_l000070;7=kP?o00001P2_co400ol00000[lg`
0:o=l003o`000080ZmCe00?o00000:_Bm02[d_@00P2[d_@2o`0000030:KJn_l00000Y]Wi00@0Y]Wi
1Ol0000209gPo@?o00000P2=iOX8o`0000cooooo00?o0000ooooooooool01Oooool001cooooo00?o
0000ooooooooool04oooool3o`0000Wooooo00?o000009n<`02OS<000P2OS<001?l00000Whc009n<
`02OS<04o`0000D0Wi3400?o000009n@a02OT<@00P2OT<@00ol00000Wi3409n@a00309n@a003o`00
002NT<@0WY3400<0WY341?l0000209nDb003o`00002NTlT0WY?900@0WY?900?o000009RAb`2HTL/0
0`2HTL/00ol00000Q8cC08B<d`0308B<d`03o`00001/S^80K8kR00<0K8kR00Go0000066HkP1QV>h0
HIS^o`00000506JRl`03o`00001aZ_@0LJ[d0080LJ[d00?o000007f`m01m/?@00`1m/?@00ol00000
R;Gc08Rel`0308Rel`03o`00002A^O80TKWb00@0TKWb00?o000009Vll02I_?000ol000000`2H_o?o
000009o2l@0609o2l@03o`00002Wa>h0YlC^00?o00000P2Uao400ol00000ZlS_0:_8k`050:_8k`?o
00001P2^c>l00ol00000//_]0;;;k@03o`000080[lk`00?o00000;7=kP2acNh00P2acNh2o`000080
[]7c00?o00000:o?l@2_co40102_co43o`0000H0ZmCe00Co00000:_Bm?l0003o0000102Vf_X00ol0
0000Y]Wi0:KIn@04o`000080WN7m0ol0000208gUnP?o00000P1ch>/4o`0000kooooo00?o0000oooo
ooooool01Oooool001_ooooo00?o0000ooooooooool04Oooool3o`0000cooooo00?o000009n<`02O
S<000P2OS<04o`000080X93400?o000009n@a02OT<@0102OT<@00ol00000Wi3409n@a00309n@a003
o`00002OT<@0Wi340080Wi3400?o000009j@a02NT<@00ol000000`2PU<So000009nDb00409nDb003
o`00002NTlT0WY?900@0WY?900?o000009RAb`2HTL/00P2HTL/01?l00000Q8cC08B<d`24S=<>o`00
00D0IZ;c00?o0000076Zm01aZ_@00P1aZ_@00ol00000OK3d07f`m00307f`m003o`000028]O<0R;Gc
00<0R;Gc00Co0000096ilP2A^O80TKWb1Ol0000509Rol`03o`00002O`_40Wl;a00@0Wl;a0ol00006
0:G7l@03o`00002[b>l0ZlS_0080ZlS_0_l000020:W<lP03o`00002^c>l0[/c_00@0[/c_0ol00006
0:o>l004o`00002acNko0000o`0000D0[]7c00?o00000:o?l@2_co400ol000000`2[e_Ko00000:_D
m@050:_Dm@?o00001P2Vf_X4o`000080WN7m0ol0000208gUnP?o00000P1ch>/5o`00013ooooo00?o
0000ooooooooool01Oooool001_ooooo00?o0000ooooooooool03oooool2o`0000oooooo00?o0000
09n<`?l000000_l000000`2PT<Co00000:2@a0040:2@a003o`00002OT<@0Wi3400@0Wi3400?o0000
09n@a02OT<@00P2OT<@00ol00000Wi3409n@a00209n@a0?o00001@2PU<P00ol00000WiC809nDb002
09nDb003o`00002NTlT0WY?900@0WY?900?o000009RAb`2HTL/00P2HTL/4o`0000<0VYO?00?o0000
08VCe`29TmL00`29TmL01?l00000MiSU07NHi@1gV>DKo`0000@0Sk_d00?o000009Rol`2H_o<0102H
_o<00ol00000Wl;a09o2l@03o`0000<0W/Gc00?o00000:G7l@2Uao40102Uao401?l00000ZlS_o`00
0?l000050:W<lP03o`00002^c>l0[/c_00?o00000P2/co800ol00000[lk`0:o>l0040:o>l0;o0000
1`2^dO<3o`0000D0ZmKf00?o00000:_Dm@2[e?D00ol000030:GLnP03o`00002Vf_X0Y][j00?o0000
0`2Mh_d3o`00000308gUn_l0003o000000;o00000P1ch>X5o`0000030>C>`Ol0003ooooo013ooooo
00?o0000ooooooooool01Oooool001_ooooo0_l0000=ooooo`?o00004_ooool00ol00000X9340:2@
a0030:2@a003o`00002PT<@0X9340080X93400?o000009n@a02OT<@0102OT<@00ol00000Wi3409n@
a00209n@a003o`00002OT<Co000000;o000000<0X9C8o`00002PU<P01@2PU<P00ol00000WiC809nD
b00309nDb003o`00002NTlT0WY?900<0WY?900?o000009RAbol000000_l000000`2OV<go000009ZG
c`0509ZGc`03o`000029TmL0RI?G00<0RI?G00Go000007NHi@1gV>D0MiSUo`00000506jRl003o`00
001bZo@0LZ_d00<0LZ_d00?o000007^bmP1k/_H0101k/_H00ol00000QKOf08FgmP0208FgmP03o`00
002?^o@0Sk_d00@0Sk_d00Co000009Rol`2H_o<0V;oc1Ol0000709k5l`04o`00002Uao40YLOa0:G7
l@Co00001`2Yc?83o`0000H0[<ob00?o00000:o>l02_c_000ol000020:cCm003o`00002^dO<0[]7c
0080[]7c0_l000000`2YeoOo00000:_FmP050:_FmP?o00001P2Ug?X4o`000080WN;m0ol0000208gV
n@Co000000<0Ln3Zo`000?l000000_l000000`3Sd<Go00000>C>`@020>C>`@03o`000?oooooooooo
00oooooo00?o0000ooooooooool01Oooool001_ooooo00?o0000ooooooooool02Oooool3o`0001Go
oooo00?o00000:2@a02PT<@00`2PT<@00ol00000X9340:2@a0030:2@a003o`00002OT<@0Wi3400<0
Wi3400Co000009n@a02OT<@0Wi340ol000050:2Db003o`00002PU<P0X9C800@0X9C800?o000009nD
b02OU<P00P2OU<P00ol00000WY?909jCb@0309jCb@;o00001@2OV<d00ol00000VYO?09ZGc`0309ZG
c`03o`000029TmL0RI?G00@0RI?G00Go000007NHi@1gV>D0MiSUo`00000506jRl003o`00001bZo@0
LZ_d00<0LZ_d00?o000007^bmP1k/_H0101k/_H00ol00000QKOf08FgmP0208FgmP04o`00002?^o@0
Sk_d08nkm0Ko00001@2F`_H00ol00000W/Gc09k5l`0409k5l`Co0000102Tbo@00ol00000ZLcb0:W<
lP020:W<lP;o00000P2WcoD00ol00000[<ob0:c?lP040:c?lP?o00001P2/do@01?l00000[]7co`00
0?l000040:WGm`03o`00002[e_H0ZmKf00?o00000`2UgO/00ol00000YMcj0:GLnP03o`0000<0W>?m
0ol0000208gVn@?o00000P1ch>T4o`0000<0hm3500Go00000>C>`@3Tc/40i<k1o`00000Booooo`03
o`000?oooooooooo00Gooooo000Kooooo`03o`000?oooooooooo00Kooooo0ol0000Iooooo`03o`00
002PT<@0X9340080X93400?o00000:2@a02PT<@0102PT<@00ol00000Wi3409n@a00209n@a0Co0000
0P2QULP00ol00000X9C80:2Db0030:2Db003o`00002PU<P0X9C800@0X9C800?o000009nDb02OU<P0
0P2OU<P00ol00000WY?909jCb@03o`0000030:6Ic?l00000WiS=00@0WiS=00?o000009ZGc`2JUll0
102JUll00ol00000RI?G08VCe`0308VCe`03o`00001gV>D0MiSU0080MiSU00?o000006jRl01^X_00
0`1^X_000ol00000LZ_d07:[m00307:[m004o`00001k/_H0Nk;f07^bmP_o00001@2=__L00ol00000
U/;f09K2mP0409K2mP03o`00002NaO<0W/Gc00?o00000P2Lb?H00ol00000Y<_d0:C;m0040:C;m004
o`00002Yc?;o0000o`0000D0Yloe00?o00000:c?lP2/co800ol000020:WCmP03o`00002/do@0[=?d
00@0[=?d0_l000060:WGm`?o00001P2UgO/4o`000080W>?m0ol0000208cVn@?o00000P1ch>T3o`00
0080h=790_l000030>?@a@05o`00003Tc/40i<k10>C>`Ol000004oooool00ol0003oooooooooo`04
ooooo`006oooool00ol0003oooooooooo`03ooooo`?o00007?ooool00ol00000X9340:2@a0030:2@
a003o`00002PT<@0X93400<0X93400?o000009n@a?l000000_l000000`2QULSo00000:6Eb0040:6E
b003o`00002PU<P0X9C800<0X9C800?o00000:2Db02PU<P00`2PU<P01?l00000WiC809nDb02OU<P4
o`0000D0XIW<00?o000009nHc@2OV<d00`2OV<d00ol00000VYO?09ZGc`0309ZGc`04o`000029TmL0
RI?G08VCeaOo00000`1m/oH00ol00000Q;Wg08Bim`0408Bim`03o`00002=__L0SKkg00@0SKkg00Co
000009K2mP2F`_H0U/;f1Ol0000609c8mP04o`00002Tbo@0Y<_d0:C;m0Go00001P2WcoD3o`0000H0
ZM?f00?o00000:cCm02/do@00ol000020:OHn@03o`00002YeoL0ZMOg00?o00000`2Tg_/00ol00000
YMgk0:GMn`03o`000080Vn?m1?l0000208cVn@So000000<0f=_Jo`00003PdLT00P3PdLT3o`000003
0>?@aOl00000i<k10080i<k100?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`00
6_ooool01?l00000000000000?ooool3o`0001oooooo00?o00000:2@a02PT<@00`2PT<@00ol00000
X9340:2@a0030:2@a0;o00001@2QULP00ol00000XIG80:6Eb0020:6Eb003o`00002PU<P0X9C800@0
X9C800?o00000:2Db02PU<P00P2PU<P4o`000080XIW<00?o00000:6Ic02QVL`0102QVL`00ol00000
WiS=09nHc@0409nHc@03o`00002JUll0VYO?0080VYO?1?l0000309bMe003o`00002?W=/0SicK00<0
SicK00?o0000086Qj021XNP00`21XNP00ol00000NZ_b07Z[lP0307Z[lP03o`00001m/oH0OK?f00<0
OK?f00?o000008Bim`24^OL01024^OL01?l00000SKkg08fnm`2=__L6o`0000@0U<Gh00?o000009c8
mP2Lb?H0102Lb?H4o`0000D0XLkg00?o00000:O?m@2WcoD00ol000000`2TdoSo00000:WCmP050:WC
mPCo00001@2Wf?T3o`0000H0Y=kk0ol0000209_So@?o00000`2;i_P7o`0000030=CKg_l00000f=_J
0080f=_J00Co00000>3Ab@3PdLWo00000P3Qc/D2o`0000@0i<k100?o0000ooooooooool04_ooool0
0ol0003oooooooooo`04ooooo`004oooool2o`0000Gooooo1?l0000Sooooo`03o`00002PT<@0X934
0080X93400?o00000:2@a02PT<@00ol000000`2QULSo00000:6Eb0040:6Eb003o`00002QULP0XIG8
00<0XIG800?o00000:2Db02PU<P00`2PU<P00ol00000X9C8o`000002o`0000030:6Ic?l00000XIW<
00@0XIW<00?o00000:6Ic02QVL`0102QVL`00ol00000WiS=09nHc@0309nHc@03o`00002JUloo0000
00;o000000<0XIkAo`00002LWM@01@2LWM@00ol00000SicK08nLf`0308nLf`03o`000021XNP0PJ7X
00<0PJ7X00?o000007Z[lP1jZo800`1jZo800ol00000OK?f07fcmP0307fcmP04o`000024^OL0Q;Wg
08Bim`Ko0000102<`OP00ol00000U<Gh09C5n00409C5n003o`00002Lb?H0W<Sf00?o00000P2Jc?T0
0ol00000XLkg0:7>m`040:7>m`?o00001@2TdoP00ol00000ZM?f0:WCmP03o`0000<0Y=Sj00?o0000
0:OHn@2Wf?T00ol000030:;No003o`00002Tg_/0Y=kk00?o00000P2Ji?d4o`000080RnKh1ol00003
0=CKgP05o`00003Md/ko00000=SKf_l000000P3PdLT00ol00000hLk50>7>a@020>7>a@;o00000P3T
c/400ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo000Booooo`04o`000?oooooo
ooooo`0000Cooooo0_l0000Uooooo`03o`00002PT<@0X9340080X9340ol000050:6Eb003o`00002Q
ULP0XIG800<0XIG800?o00000:6Eb02QULP00P2QULP00ol00000X9C80:2Db0030:2Db0;o00001@2Q
VL`00ol00000XIW<0:6Ic0030:6Ic003o`00002QVL`0XIW<00<0XIW<00?o000009nHc@2OV<d00`2O
V<d2o`0000D0XIkA00?o000009bMe02LWM@0102LWM@00ol00000SicK08nLf`0308nLf`04o`000021
XNP0PJ7X086Qj17o00001026^oP00ol00000S<7h08c1n00408c1n004o`00002DaOP0U<Gh09C5n0Go
00001P2Jc?T00ol00000XLkg0:7>m`03o`00000309oAn_l00000Y=?h00D0Y=?h0ol000060:CHnP?o
00001P2Rg_`3o`000080V^Cm0ol0000308[Vn0So0000103Dfmh01Ol00000gM;>0=gBcP3Md/ko0000
00<0h=7900Co00000>7>a@3Qc/D0hLk50_l00000103QcLCo00000>C>`Ol0000Eooooo`03o`000?oo
oooooooo00Cooooo000Booooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool08_oo
ool00ol00000X934o`000002o`0000030:6Eb?l00000XIG800D0XIG800?o00000:6Eb02QULP00`2Q
ULP00ol00000XIG80:6Eb0020:6Eb003o`00002PU<P0X9C800?o000000<0XIW<o`00002QVL`0102Q
VL`00ol00000XIW<0:6Ic0030:6Ic003o`00002QVL`0XIW<00<0XIW<00?o000009nHc@2OV<d00ol0
00000`2RW]3o00000:6Nd@040:6Nd@03o`00002LWM@0W9gD00@0W9gD00Co000008nLf`2?W=/0SicK
1_l0000309BTh003o`000028Z^/0R:[[00<0R:[[00?o000008>cm023/o@00`23/o@00ol00000Q[_h
08Jkn00408Jkn004o`00002<`OP0S<7h08c1n0Ko00001@2Cb?T01?l00000V/ci09[<n@2Jc?T5o`00
00D0Wm7j00?o00000:CCn02TdoP00ol000030:3Hn`03o`00002Tf?X0Y=Sj00?o00000`2Ng_d00ol0
0000X]kl0:;No003o`000080V>Cm1?l0000208[Vn0[o0000103Dfmh00ol00000gM;>0=gBcP020=gB
cP;o000000<0h=79o`00003Qc/D00P3Qc/D01_l00000hLg40>7=a?l00000hLg4o`0001Kooooo00?o
0000ooooooooool01?ooool001;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0Rooooo`03o`00002QULP0XIG800<0XIG800?o00000:6Eb02QULP0102QULP00ol00000XIG80:6E
b0020:6Eb004o`00002QULP0XIG80:6Eb0Co00001@2QVL`00ol00000XIW<0:6Ic0030:6Ic003o`00
002QVL`0XIW<00<0XIW<00Co00000:6Ic02QVL`0XIW<1?l000050::Nd003o`00002QW]40XIkA00<0
XIkA00?o000009bMe02LWM@00`2LWM@4o`0000<0Wj?H00?o000009BTh02DY>00102DY>000ol00000
R:[[08RZj`0308RZj`03o`000023/o@0Pk?d00<0Pk?d00Co000008Jkn026^oP0Q[_h1_l0000408g3
n@03o`00002Cb?T0TlSi00@0TlSi1?l0000509W?n`04o`00002OdOX0Wm7j09oAnPCo00001P2Pf?/3
o`0000H0W]km1?l00000102Hi?go0000o`000?l0000308WVn0Oo000000<0[>gho`00003?fn400P3?
fn42o`0000<0e=_N00Go00000=gBcP3Md/h0gM;>o`0000020=k?b@05o`00003Qc/D0hLk50>7>aOl0
0000103QcL@2o`0001Kooooo00?o0000ooooooooool01?ooool001;ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`0Qooooo`03o`00002QULP0XIG800<0XIG800?o00000:6Eb02Q
ULP0102QULP00ol00000XIG80:6Eb0020:6Eb0Co00000P2RV/d00ol00000XIW<0:6Ic0040:6Ic003
o`00002QVL`0XIW<00<0XIW<00?o00000:6Ic02QVL`00`2QVL`4o`000080XYk@00?o00000::Nd02R
W]00102RW]000ol00000XIkA0:6Nd@030:6Nd@03o`00002LWM@0W9gD00?o000000<0Xj?Eo`00002O
XmP01@2OXmP00ol00000U:CP09BTh00409BTh004o`000028Z^/0R:[[08RZj`_o0000102;^oH00ol0
0000SL?i08g3n@0408g3n@03o`00002Cb?T0TlSi00?o00000P2Cbo/00ol00000VLok09W?n`0409W?
n`Co0000102Ke_`00ol00000X=Sk0:3Hn`03o`0000<0Vmgm00?o000009kNo@2Ng_d00ol0000309KS
o@?o00000P29i_P8o`0000030:c]n?l0003o000000<0cm_Q00Ko00000=[CdP3Jdm;o00000=CKg_l0
00030=gBcP05o`00003NclT0g/o90=k?bOl000000`3Qc/D00ol00000hLg40>7=a0020>7=a003o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00oooool001;ooooo00Co0000oooooooooooo0000
2Oooool2o`0002;ooooo00?o00000:6Eb02QULP00`2QULP00ol00000XIG80:6Eb0030:6Eb003o`00
002QULSo000000;o000000<0XY[=o`00002RV/d0102RV/d00ol00000XIW<0:6Ic0040:6Ic003o`00
002QVL`0XIW<0080XIW<00?o00000:6Ic02QVL`00ol000000`2RW]7o00000::Nd0040::Nd003o`00
002RW]00XYk@00@0XYk@00?o00000:6Nd@2QW]400P2QW]43o`0000D0Xj?E00?o000009nSf02OXmP0
102OXmP00ol00000U:CP09BTh00309BTh0Co00000P2I[>@00ol00000T;?^092ckP04092ckP03o`00
002;^oH0Rk_f00@0Rk_f00Co000008g3n@2=`oT0SL?i1Ol0000609?;n`03o`00002Ico/0VLok00?o
00000P2Gd_`01?l00000VmKl09_Fo02Ke_`6o`0000<0Vmgm1_l0000209KSo@?o00000P29iOP:o`00
00030:c]n?l00000cm_Q00<0cm_Q00?o00000=[CdP3Jdm800P3Jdm801Ol00000gM;>0=gBcP3Md/ko
000000<0g/o900Go00000=k>b?l00000hLk5o`0000040>7=a003o`000?oooooo000001Oooooo00?o
0000ooooooooool00oooool001?ooooo0_l0000<ooooo`03o`000?oooooooooo01oooooo00?o0000
0:6Eb02QULP0102QULP00ol00000XIG80:6Eb0020:6Eb0;o00001@2RV/d00ol00000XY[=0::Jc@03
0::Jc@03o`00002QVL`0XIW<00<0XIW<00?o00000:6Ic02QVL`00P2QVL`3o`0000D0XYkA00?o0000
0::Nd02RW]000P2RW]000ol00000XYk@0::Nd0040::Nd003o`00002QW]7o000000;o000000<0Y:?D
o`00002SXmD01@2SXmD00ol00000Wj?H09nSf00409nSf003o`00002DY>00U:CP00?o000000<0XZ[L
o`00002I[>@0102I[>@00ol00000T;?^092ckP04092ckP04o`00002;^oH0Rk_f08^kmPKo00001@2A
a?P01?l00000Tl_k09?;n`2Cbo/5o`0000D0Um;l1?l0000509SJoPCo00001@2DhOd3o`000080RNGh
2?l000000`2]jOWo00000<_Ii0020<_Ii0;o00000`3?fn400ol00000f]?B0=[CdP020=[CdP05o`00
003Kd<ko00000=gBc_l000000`3NclT01Ol00000g/k80=k>b03Nc/So000000@0hLg400Go0000oooo
ooooooooooooo`00000Fooooo`03o`000?oooooooooo00?ooooo000Rooooo`03o`000?oooooooooo
01oooooo00?o00000:6Eb02QULP00`2QULP00ol00000XIG8o`000002o`0000030::JcOl00000XY[=
00@0XY[=00?o00000::Jc@2RV/d00`2RV/d00ol00000XIW<0:6Ic0030:6Ic003o`00002QVLco0000
00;o000000<0XYkAo`00002RW]401@2RW]400ol00000XYk@0::Nd0030::Nd003o`00002RW]00XYk@
00<0XYk@0_l000050:BSe003o`00002SXmD0Xj?E00@0Xj?E00?o000009nSf02OXmP00`2OXmP3o`00
00D0XZ[L00?o000009V/i02I[>@00`2I[>@01?l00000T;?^092ckP2@/nh6o`0000D0UKcb00Co0000
0974n02Aa?P0TLCh1_l0000509K=n`03o`00002Gd_co000000;o00000`2Ge_d00ol00000V=[n09SJ
oP03o`0000<0U=on00?o000009CQo@2DhOd00ol0000208cTn`So00000`2]jOT01Ol00000bmWT0<_I
i03;fNCo00000080e]?G00?o00000<oKhOl00000103Jdm801Ol00000fm3>0=_@cP3Kd<ko000000<0
g/o900?o00000=k>b03Nc/P00P3Nc/P2o`0000<0hLg400?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000Sooooo`03o`000?oooooooooo01kooooo
00Co00000:6Eb02QULP0XIG81?l000050::Jc@03o`00002RV/d0XY[=00<0XY[=00?o00000::Jc@2R
V/d00`2RV/d01?l00000XIW<0:6Ic02QVL`3o`0000D0XYkA00?o00000::Nd@2RW]40102RW]400ol0
0000XYk@0::Nd0020::Nd003o`00002RW]00XYk@00?o000000<0Y:?Do`00002TXm@01@2TXm@00ol0
0000Xj?E0:>Se@030:>Se@03o`00002OXmP0Wj?H00?o000000<0YZWIo`00002RZ]`01P2RZ]`00ol0
0000VJcT09V/i00209V/i0Co0000102M]>P00ol00000UKcb09FllP0409FllPCo00001@2JaOH01?l0
0000U/gk09K=n`2FcO/4o`0000H0UmKm0ol0000609COoP?o00000P2<i?/6o`0000030:gSnOl00000
a]OW0080a]OW00?o00000:gYnOl000000`3;fN@00ol00000e]?G0=KCe`020=KCe`03o`00003Jdm80
f]?B0080f]?B00?o00000=_@cP3Kd<h00P3Kd<h01Ol00000g/o90=k?b@3NclWo000000<0g/k800Ko
00000=k=a`3NcLOo00000>7=a?l00005ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool002Cooooo0_l0000Oooooo`?o00000`2RV/d00ol00000XY[=0::Jc@030::Jc@03o`00
002RV/d0XY[=00<0XY[=00?o00000::Jc@2RV/d00`2RV/d4o`000080XYkA00?o00000::Nd@2RW]40
102RW]400ol00000XYkA0::Nd@030::Nd@04o`00002RW]00XYk@0::Nd0Co00001@2TXm@00ol00000
Y:?D0:BSe0030:BSe003o`00002SXmD0Xj?E00<0Xj?E0ol000050:JYf@03o`00002RZ]`0XZ[L00@0
XZ[L00?o000009V/i?l000000_l000020:F`h003o`00002M]>P0WKCX00@0WKCX00?o000009FllP2E
_?800ol000020::mk003o`00002JaOH0V/Gf00@0V/Gf1?l0000409c?nP03o`00002Ge_d0UmKm00?o
00000`2LfO`00ol00000U=on09COoP03o`000080VN7m1_l000030:gSn@03o`000036enL0a]OW0080
a]OW0_l000030<_Ii003o`00003FdmL0e]?G00<0e]?G00Go00000=[CdP3Jdm80f]?Bo`0000040=_@
cP05o`00003Kc/co00000=k?bOl000000`3Nc/P00ol00000g/g70=k=a`020=k=a`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`009_ooool00ol0
003oooooooooo`0Looooo`03o`00002RV/d0XY[=00@0XY[=00?o00000::Jc@2RV/d00`2RV/d00ol0
0000XY[=0::Jc@020::Jc@03o`00002RV/d0XY[=00?o000000<0XYoBo`00002RW]40102RW]400ol0
0000XYkA0::Nd@030::Nd@03o`00002RW]40XYkA00<0XYkA1?l000020:>Se@03o`00002TXm@0Y:?D
00D0Y:?D00?o00000:BSe02TXm@00`2TXm@00ol00000Xj?Eo`000002o`0000030:NXf?l00000YZWI
00H0YZWI00?o00000::Zg02RZ]`00`2RZ]`2o`0000H0YK3P00?o000009fdj02M]>P00`2M]>P3o`00
00H0X[g/00?o000009[5mP2JaOH00ol000020:G5l003o`00002LcoX0W<oj00<0W<oj0ol0000609cI
o0Co000000@0VN7mo`000?l0003o00000P2/gOP01ol00000`MCX0<7Dj031e>So00000:gSnOl00000
1036enL01_l00000dM?K0=7Cfol00000bmWTo`0000D0e]?G00Go00000=SAd_l00000f]?Bo`000004
0=_@cP05o`00003Kc/`0flk<0=_>c?l000000`3Nc/P00ol00000g/g70=k=a`030=k=a`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`009oooool0
0ol0003oooooooooo`0Looooo`03o`00002RV/d0XY[=00<0XY[=00?o00000::Jc@2RV/d00`2RV/d0
1?l00000XY[=0::Jc@2RV/d4o`0000D0XYoB00?o00000::Nd@2RW]400`2RW]400ol00000XYkA0::N
d@030::Nd@03o`00002RW]7o000000;o000000<0XZ?Eo`00002SXmD0102SXmD00ol00000Y:?D0:BS
e0040:BSe004o`00002TXm@0Y:?D0:BSe0Co00001@2WZ=P00ol00000YZWI0:JYf@040:JYf@03o`00
002RZ]`0XZ[L00?o000000<0ZJoLo`00002U/>001P2U/>000ol00000WKCXo`000002o`000080ZKOS
00?o00000::mk02R_N`0102R_N`3o`0000H0YLG`00?o000009c?n_l000000_l000030:S=l`03o`00
002LfO`0W=Wl00?o00000`2[eOH2o`0000<0[=gh0_l000040<7Dj0;o00000`36enL2o`0000@0dM?K
00?o00000=KCe`3FdmL00`3FdmL01?l00000f=7B0=SAdP3HdM82o`0000<0fm3>00?o00000=_>c03K
c/`00P3Kc/`01Ol00000g/k80=k>b03Nc/So000000@0g/g700?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000Xooooo`03o`000?oooooooooo01_o
oooo00?o00000::Jc@2RV/d0102RV/d00ol00000XY[=0::Jc@020::Jc@Co00000P2SWm800ol00000
XYoB0::OdP040::OdP03o`00002RW]40XYkA00<0XYkA00Co00000::Nd@2RW]40XYkA1?l000050::S
e@03o`00002SXmD0Xj?E00<0Xj?E00?o00000:BSe02TXm@00`2TXm@4o`0000<0YZSH00?o00000:NX
f02WZ=P0102WZ=P00ol00000YZWI0:JYf@030:JYf@?o00001@2Y[m`00ol00000YK3P0:F`h0040:F`
h0;o00001P2Y]n<00ol00000X[g/0::mk003o`000080[KkV00?o00000:G5l02UaO00102UaO02o`00
00H0Z<gc0ol000040:_EmP;o00000P2lcnT00ol00000[=gho`0000050<7Dj006o`00003<dMh0c=7N
o`000036enOo00001@3Adm/00ol00000dm7Go`0000030=KCe`05o`00003HdM80f=7B0=SAd_l00000
0P3Hcm400ol00000fm3>o`0000040=_>c005o`00003KcLco00000=k>b?l00000103NcLL00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool002Wooooo
00?o0000ooooooooool06oooool00ol00000XY[=0::Jc@030::Jc@03o`00002RV/go000000;o0000
00<0Xj3Bo`00002SWm80102SWm800ol00000XYoB0::OdP040::OdP03o`00002RW]40XYkA0080XYkA
1?l000030::SeP03o`00002RXmD0XZ?E00<0XZ?E00?o00000:>Se@2SXmD0102SXmD00ol00000Y:?D
o`000002o`0000030:BWf?l00000YZSH00D0YZSH00?o00000:NXf02WZ=P00`2WZ=P00ol00000YZWI
0:JYf@03o`0000030:V^f_l00000ZJoL00H0ZJoL00?o00000:F`h02U/>000ol000000`2]]Mko0000
0:Vgh`050:Vgh`?o00001P2]_^H00ol00000YLG`0:G5l003o`000080//CX00?o00000:S=l`2XcO<0
0ol000030;O:j@04o`00002[eOKo0000o`0000@0_<oY0ol000030<7Dj0;o0000103<dMh00ol00000
dM?K0=7Cf`030=7Cf`07o`00003CdML0dm7G0=?Aeol00000e]?Go`0000030=SAdP03o`00003Hcm40
f<oA0080f<oA00?o00000=_>c03Kc/`00P3Kc/`01Ol00000flg<0=_=c03KcLco000000@0g/g700?o
0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000Z
ooooo`;o00007?ooool00ol00000XY[=0::Jc@020::Jc@;o00001@2SX=800ol00000XioB0:>OdP03
0:>OdP03o`00002RWm80XYoB00<0XYoB00?o00000::NdOl000000_l000000`2RY=Oo00000::SeP05
0::SeP03o`00002RXmD0XZ?E00<0XZ?E00?o00000:>Se@2SXmD00`2SXmD2o`0000D0Y:OH00?o0000
0:JXf02VZ=P0102VZ=P00ol00000YjSH0:NXf0020:NXf0?o00001@2Y[]X00ol00000ZJoL0:V_g004
0:V_g0?o00001@2]]Mh01?l00000ZKOS0:Vgh`2Y]n<2o`0000030;6khOl00000[KkV00H0[KkV0ol0
00050;;4j0?o00001P2gb^T2o`0000D0_<oY00Oo00000<K>h@36c^40a/kQo`000031e>So000000D0
c=7N00?o00000<oAfol000000`3Adm/00ol00000dm7G0=?Ae`020=?Ae`;o00000`3HdM800ol00000
f<oA0=S?d@020=S?d@;o00000`3Kc/`00ol00000flg<0=_=c0020=_=c0;o00000`3NcLL00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool002cooooo
00?o0000ooooooooool06Oooool00ol00000XY[=o`000002o`0000030:>Pd_l00000Xj3B00@0Xj3B
00?o00000:>OdP2SWm80102SWm801?l00000XYoB0::OdP2RWm83o`0000D0XZCG00?o00000::SeP2R
XmH0102RXmH00ol00000XZ?E0::Se@020::Se@03o`00002SXmD0Xj?E00?o000000<0XjOIo`00002T
YmP01@2TYmP00ol00000YZSH0:JXf0030:JXf003o`00002WZ=So000000;o00000P2X[M/00ol00000
ZJkJ0:V^fP040:V^fP03o`00002Y[m`0ZJoL00?o000000<0[K?Mo`00002]]Mh01P2]]Mh00ol00000
ZKOSo`0000040;6kh@03o`00002]_^H0[KkV0080[KkV0_l000020;K1hP04o`00002ba>P0//CX0;;4
j0;o00000P2ka^<00ol00000]l[Y0;O:j@020;O:j@;o00000P31bn801Ol00000_<oY0;c?j@2lcnWo
000000@0a/kQ0_l000050<cAgP07o`00003?dM/0cm7K0<oAfol00000dM?Ko`0000040=?Ae`06o`00
003Dd=D0e=3Eo`00003HdM;o0000103Hcm401_l00000f<k@0=S>d?l00000flk<o`0000@0flg<00Ko
00000=_=b`3KcL_o00000=k=aol0000?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool002gooooo00?o0000ooooooooool06Oooool00ol00000Xj3B0:>PdP030:>PdP03o`00
002SX=80Xj3B00<0Xj3B00?o00000:>OdP2SWm800`2SWm84o`000080XjGG00?o00000::Te`2RY=L0
102RY=L00ol00000XZ?F0::SeP030::SeP04o`00002RXmD0XZ?E0::Se@Co00001@2SYmT00ol00000
Y:OH0:BWf0030:BWf004o`00002VZ=P0YZSH0:JXf0Co00001P2X[M/00ol00000ZJkJ0:V^fP030:V^
fP?o00001@2]/md00ol00000[KGN0:fegP040:fegP;o00001P2a^n401?l00000[KkVo`000?l00005
0;K1hP03o`00002ba>So000000D0^lKS00Co00000;O:jOl0003o00001@31bn800ol00000_<oYo`00
00040<K>h@04o`00003:cmh0b/oNo`0000<0c=7N00?o00000<oAf`3?dM/00P3?dM/2o`0000@0dm7G
00?o00000=C@e@3Dd=D00P3Dd=D00ol00000f<oA0=S?d@020=S?d@03o`00003Hc]00f<k@0080f<k@
00?o00000=_=c03KcL`00P3KcL`00ol00000flg;0=_=b`020=_=b`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00;_ooool00ol0003ooooooooo
o`0Hooooo`03o`00002SX=80Xj3B00<0Xj3B00?o00000:>PdP2SX=800`2SX=800ol00000XioB0:>O
dP03o`0000030:>Uf?l00000XjGG00@0XjGG00?o00000::Te`2RY=L00`2RY=L00ol00000XZ?F0::S
eP030::SePCo00000P2RZ=X00ol00000XjOI0:>Wf@050:>Wf@03o`00002TYmP0Y:OH0080Y:OH1?l0
00030:N/f`03o`00002X[M/0Z:gK00D0Z:gK00?o00000:V^f_l000000_l000000`2//]go00000:fc
g@060:fcg@03o`00002]]Mh0[KGN00?o000000<0/KWOo`00002a^n401@2a^n42o`0000L0]/7R0_l0
00060;_6h`;o00001`31bn82o`0000<0a/kQ0_l000040<[?gP03o`00003<dMko000000@0cm7K00?o
00000=3@f_l000000`3CdML00ol00000e=3E0=C@e@020=C@e@;o00000`3Hcm400ol00000f<k@0=S>
d0030=S>d005o`00003KcL`0flg<0=_=c?l000001@3KcL/00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool002oooooo0_l0000Iooooo`03o`00002S
X=80Xj3B00<0Xj3B00?o00000:>PdP2SX=800P2SX=83o`0000D0XjGH00?o00000:>Ue`2SYML00`2S
YML00ol00000XZCG0::Te`030::Te`03o`00002RXmKo000000;o000000<0XZSKo`00002RZ=X0102R
Z=X00ol00000XjOI0:>Wf@040:>Wf@03o`00002TYmSo000000;o000000<0YJcLo`00002W[=/01@2W
[=/00ol00000Z:gK0:R]f`040:R]f`;o00001@2//]d00ol00000[K?M0:fcg@040:fcg@?o00001@2a
^Ml01?l00000/K_Q0;6kh@2a^n42o`000080][kP00?o00000;K1hP2f`N800P2f`N82o`0000030;_4
hOl00000^lKS00@0^lKS00Co00000<39h@30bN7o00001031bn82o`000080aLgP00?o00000<K>hOl0
00001P3:cmh2o`0000@0cm7K00Oo00000=3@fP3@d=X0d=3Jo`00003CdMOo000000@0e=3E00Ko0000
0=C?e03DcmCo00000=S?dOl000050=S>d005o`00003GcM3o00000=_=c?l000001@3KcL/00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0037ooooo
00?o0000ooooooooool05oooool00ol00000Xj3B0:>PdP020:>PdP03o`00002SX=;o000000;o0000
00<0XjKHo`00002SYMP01@2SYMP00ol00000XjGG0:>Ue`030:>Ue`04o`00002RY=L0XZCG0::Te`Co
00001@2RZ=/00ol00000XZSJ0::XfP030::XfP03o`00002SYmT0XjOI00<0XjOI0_l000050:F/g003
o`00002W[=/0YjcK00@0YjcK00?o00000:R]f`2X[M/00ol000000`2Y/Mko00000:bbg@050:bbg@03
o`00002]/md0[K?M00?o000000<0/;SOo`00002a^Ml01P2a^Ml00ol00000/K_Qo`0000050;Jnh004
o`00002f`N;o0000o`0000@0^lCQ00Go00000;_6h`2ka^<0^lKSo`0000040<39h@04o`000031bn;o
0000o`0000@0aLgP0_l000060<[?gP03o`00003;d=go000000<0cm7K00?o00000=3@fP3@d=X00P3@
d=X3o`0000<0e=3E00?o00000=C?e03Dcm@00P3Dcm@00ol00000f<k@0=S>d0030=S>d005o`00003G
cM00elg@0=O=d?l000001@3KcL/00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00Oooool003;ooooo00?o0000ooooooooool05_ooool01?l00000Xj3B0:>P
dP2SX=83o`0000D0XjKH00?o00000:>Uf02SYMP0102SYMP00ol00000XjGG0:>Ue`020:>Ue`Co0000
0`2RZM`00ol00000XZSK0::Xf`040::Xf`03o`00002RZ=X0XZSJ00<0XZSJ00?o00000:>WfOl00000
0_l000000`2S[=ko00000:F/g0050:F/g003o`00002W[=/0YjcK00<0YjcK0ol000050:VagP03o`00
002//]d0[;;M00<0[;;M0ol000050;2hg`03o`00002a^Ml0/KWO00@0/KWO0_l000060;Jnh0;o0000
1`2ka>400ol00000^lKSo`0000050<39h@;o00001@35cN001?l00000a/oP0<K?h?l000030<[?gP;o
00000`3;d=d00ol00000cm7Ko`0000040=3@fP07o`00003@d=T0d=3I0=3@fOl00000e=3Eo`000004
0=C?e003o`00003Dc]Co000000<0f<k@00?o00000=O=d03GcM000P3GcM02o`0000<0flg;00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000coooo
o`03o`000?oooooooooo01Kooooo0ol000020:BWf003o`00002SY]P0XjKH00@0XjKH00?o00000:>U
f02SYMP00`2SYMP00ol00000XjGGo`000002o`0000030::[gOl00000XZWL00D0XZWL00?o00000::X
f`2RZ=/00`2RZ=/01?l00000XZSJ0::XfP2RZ=X4o`0000D0XjcN00?o00000:F/g02U[=`0102U[=`0
0ol00000YjcKo`000002o`0000030:Nagol00000ZK7N00H0ZK7N00?o00000:bbg@2//]d00_l00000
0`2]]n3o00000;2hg`060;2hg`03o`00002a^Ml0/KWO00?o00000P2d_N401?l00000][kP0;Jnh02f
_^02o`0000030;S3h_l00000^lCQ00H0^lCQ0_l000050<39h@04o`000032c>80`/cRo`0000<0aLgP
00?o00000<K?h036cn000P36cn000ol00000b/oNo`0000050<_@g@?o00000`3@d=X00ol00000d=3I
0=3@f@020=3@f@;o0000103Dcm@01ol00000e<kD0=C>e03Dc]Co00000=S>d?l00000103GcM001_l0
0000elg?0=O=col00000flg;o`0001Wooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`01ooooo`00=?ooool2o`0001Kooooo00?o00000:BWf02TYmP00`2TYmP00ol00000XjKH0:>Vf004
0:>Vf004o`00002SYMP0XjGH0:>Uf0?o00001@2RZmd00ol00000XZWL0::Yg0040::Yg004o`00002R
Z=/0XZSK0::Xf`Go00000`2R[Ml00ol00000XjcN0:>/gP040:>/gP03o`00002U[=`0YJcL00<0YJcL
0_l000050:Nag`03o`00002Y/Mh0ZK7N00@0ZK7N00?o00000:bbgOl00000102]]n000ol00000/;SO
0;2hg`040;2hg`?o00001P2d_N400ol00000][kPo`0000040;S3hP03o`00002ka>40^lCQ0080^lCQ
0_l000020;g8h`05o`000030bN40`<WQ0<39hOl000001032c>800ol00000aLgPo`0000050<K?h0;o
00001@3;d=d01ol00000c=3M0<c@g@3<d=go00000=3@f_l00000103@d=T00ol00000d<oIo`000003
0=C?e003o`00003Dc]@0e<kD00<0e<kD00?o00000=O=d03GcM000P3GcM001?l00000elg?0=O=c`3G
cLl2o`0001_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00=_ooool0
0ol0003oooooooooo`0Dooooo`03o`00002TYmP0Y:OH00<0Y:OH00?o00000:>Vf02SY]P00`2SY]P4
o`000080XjcN00?o00000::[g@2RZmd0102RZmd00ol00000XZWL0::Yg0030::Yg0Co00000P2Q[^40
0ol00000XZgO0::]g`040::]g`03o`00002S[=h0XjcN00<0XjcN00?o00000:F/g02U[=`00ol00000
0`2T/N7o00000:Nag`050:Nag`03o`00002Y/Mh0ZK7N00<0ZK7N0_l000060:fgh003o`00002`^=l0
/;SO00?o000000<0/KcRo`00002d_N401P2d_N42o`0000H0^<?R00Co00000;_4hOl0003o00001@2m
b><00ol00000`<WQo`0000050<;<hP;o00001@36cn001?l00000am3Q0<O@hOl000030<_@g@03o`00
003<d=d0c=3M0080c=3M0_l000040=3@f@07o`00003@cmT0d<oI0=3?fOl00000e<oDo`0000050=C>
e0;o00000`3GcM001Ol00000elg?0=O=c`3GcLoo000001gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00=oooool00ol0003oooooooooo`0Dooooo`03o`00002TYmP0Y:OH
00<0Y:OH00?o00000:>Vf?l000000_l000000`2S[Mko00000:>/gP040:>/gP03o`00002RZmd0XZ_M
00@0XZ_M00?o00000::Yg?l000000_l000000`2Q[n;o00000:6^h@040:6^h@03o`00002R[Ml0XZgO
00@0XZgO00Co00000:>/gP2S[=h0XjcN1?l000050:Bah@03o`00002W/Ml0Yk7O00<0Yk7O00?o0000
0:VagP2Y/Mh00ol000000`2Z]^;o00000:fgh0050:fgh0?o00001@2a_>800ol00000];gQ0;Bmh@02
0;Bmh@;o00000P2e`^@00ol00000^<?R0;S3hP030;S3hP;o00001`2mb><2o`0000@0`/cR0_l00002
0<;?i005o`000036cn00a/oP0<K?h?l000001037d>400ol00000bm3Mo`0000040<c@g@03o`00003;
d=go000000<0d=3I00?o00000=3?f@3@cmT00`3@cmT00ol00000e<kD0=C>e0030=C>e006o`00003C
cM@0dlgDo`00003GcM3o00000`3GcLl00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00Oooool003Sooooo00?o0000ooooooooool04oooool01?l00000Y:OH
0:BWf02TYmP4o`0000D0XjgN00?o00000:>/gP2S[=h00`2S[=h01?l00000XZ_M0::[g@2RZmd4o`00
00D0XJoR00?o00000:6^h@2Q[^400`2Q[^401?l00000XZgO0::]g`2R[Ml6o`000080X[7R00?o0000
0:Bah@2T/N401@2T/N401?l00000Yk7O0:Nag`2W/Ml4o`0000D0Z[KR00Co00000:fgh02]]n00[KOP
0_l000000`2^^nCo00000;6lhP060;6lhP04o`00002d_N7o0000o`0000D0]L;T00?o00000;S3h_l0
00000_l000020;[7i@03o`00002mb><0_LSS0080_LSS0_l000020;k<i@04o`000032c>;o0000o`00
00D0`/oT00?o00000<K?h?l000001@37d>42o`0000<0c=3M0_l000030<_@g@03o`00003@d=Wo0000
00D0d<oI00?o00000<o>fOl000000`3Dc]@00ol00000dlgD0=?=e0020=?=e005o`00003GcLl0elg?
0=O=col000008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo000ioooo
o`;o00005?ooool3o`0000<0Y:kN00?o00000:>]gP2S[Mh0102S[Mh01?l00000XjcN0:>/gP2S[=h5
o`0000<0XK7S00?o00000:6_hP2Q[n80102Q[n800ol00000XJkQ0:6^h@020:6^h@Co00000`2P/N@0
0ol00000X[7R0::ahP030::ahP03o`00002T/N40Y;7Q00@0Y;7Q1?l00003ojNfh`03o`00002Z]^80
Z[KR00@0Z[KR00?o00000:fgh?l00000102^^n@00ol00000/KcR0;6lhP040;6lhP;o00001`2e`^@2
o`0000H0^/OU00Co00000;g8hol0003o0000102nc>D2o`0000L0`/oT0_l000040<O@h@;o00000P37
dN800ol00000c=3Mo`0000050<_@g@;o00001@3@cmT01ol00000clkI0<o>f@3?c]Wo00000=C>e?l0
0000103CcM@01Ol00000dlgDo`00003GcLoo000002?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`01ooooo`00>oooool00ol0003oooooooooo`0Booooo`03o`00002T[]h0Y:kN00<0
Y:kN00?o00000:>]gP2S[Mh00`2S[Mh4o`0000<0X[?T00?o00000:6ah`2Q/N<00`2Q/N<00ol00000
XJoR0:6_hP030:6_hP03o`00002Q[^7o000000;o00000P2O/^H00ol00000X;7T0:2ai0030:2ai003
o`00002R/N80X[7R00<0X[7R00?o00000:Bah@2T/N400ol000000`2T]NGo0000ojNfh`05ojNfh`04
o`00002Z]^80Z[KR0:ZfhPCo00001P2^^n@00ol00000/KcR0;6lhP03o`000080//7U00?o00000;G2
i02e`^@00P2e`^@2o`0000030;K7iol00000^/OU00D0^/OU0ol000030;k<i@;o00000P2ncnL00ol0
0000`/oT0<;?i0020<;?i0;o00000P32d>D01?l00000am3Qo`000?l000040<OAhP;o00001@3;d=d0
1?l00000bloM0<_?gOl000030=3?f@03o`00003?c]T0clkI0080clkI0_l000040=?=e005o`00003C
cM@0dlgD0=?=e?l000009?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00??oo
ool00ol0003oooooooooo`0Booooo`03o`00002T[]h0Y:kN00<0Y:kN00?o00000:>]g_l000000_l0
00000`2S]>Go00000::ci0050::ci003o`00002Q/N<0XK7S00<0XK7S00Co00000:6_hP2Q[n80XJoR
0ol0000609nbiP03o`00002P/N@0X;7T00<0X;7T00Co00000::ahP2R/N80X[7R1?l000050:Bei@03
o`000?nW]^?oYkKS00?oYkKS1?l000040:Zki@03o`00002^^n@0[[_T00<0[[_T0ol000060;;1i@04
o`00002e`^Co0000o`0000@0]/OW00?o00000;[7i@2janD00ol000030;[<i`03o`00002nc>Go0000
00D0_/oW00Co00000<;?i?l0003o00001032d>D2o`0000D0am7R00Co00000<K@hP36d>;o00000`3;
d=d00ol00000bloM0<_?g@020<_?g@03o`00003@cmWo000000@0clkI00?o00000<o=f?l000000`3C
cM@01Ol00000dlgD0=?=e03CcMCo000002Kooooo00?o0000ooooooooool01oooool1o`00007ooooo
0Oooool003gooooo00?o0000ooooooooool04_ooool01?l00000Y:kN0:B^gP2T[]h3o`0000D0XkCU
00?o00000::ci02R/n@0102R/n@01?l00000XK7S0:6ah`2Q/N<5o`0000<0W[CW00?o000009nbiP2O
/^H0102O/^H01?l00000X;7T0:2ai02P/N@5o`0000@0XKKW00?o00000:Bei@2T]ND00`2T]ND00ol0
003oYkKSo`000002o`0000030:Jjiol00000Z[_U00H0Z[_U00?o00000:jki?l000000_l000020:k0
i`03o`00002b`ND0//7U00@0//7U0_l000060;K7i`?o00001P2jc>L2o`0000H0_/oW0_l000050<;@
i@04o`000032dNH0`]7Vo`0000<0am7R00?o00000<K@hP36d>800P36d>800ol00000bm3Mo`000005
0<_?g@;o00000`3?c]T2o`0000<0clgH00?o00000=?=e?l000000`3CcM@00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000nooooo`;o00004oooool3o`00
00<0XkKV00?o00000:>di@2S]>D00`2S]>D01?l00000X[?T0::ci02R/n@6o`0000<0W[KY00?o0000
09jdi`2N]>L00`2N]>L01?l00000Wk;V09nbiP2O/^H6o`000080W[KY00?o00000:6fi`2Q]^L01@2Q
]^L01?l00000Y;GU0:Bei@2T]ND3o`0000D0Y[[W00?o00000:Zki@2Z^nD0102Z^nD2o`0000H0[/3W
00?o00000;;1i@2b`ND00ol000020;;6j@04o`00002fanL0]/OW0;K7i`;o00000P2fc>X00ol00000
^/cW0;[<i`020;[<i`;o00000P2jcnX01?l00000_/oW0;k?i`2ncnL2o`000080_M7Y00Go00000<;@
i@32d>D0`]3Uo`0000040<;AiP03o`000037dN;o000000D0a]3R0_l000050<_?g@06o`00003:c]d0
b/kMo`00003?c]Wo00001@3?cMP2o`0000<0dlgD00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`06ooooo`7o00000Oooool1ooooo`00@?ooool00ol0003oooooooooo`0@ooooo`03o`00002S
]^H0XkKV00@0XkKV00Co00000:>di@2S]>D0XkCU1Ol0000409nij`03o`00002N]^T0W[KY00<0W[KY
00Co000009jdi`2N]>L0W[CW1Ol0000309bgj`03o`00002N]^T0W[KY00<0W[KY00?o00000:6fi`2Q
]^L0102Q]^L4o`0000<0X[[Z00?o00000:Jji`2V^^L00`2V^^L00ol00000Z[_U0:Zki@03o`000080
ZKoY00?o00000:k0i`2^`>L00`2^`>L3o`0000H0//KY00?o00000;K7iol000001@2fc>X01?l00000
^/cWo`000?l000050;[?jP03o`00002ncnOo000000D0_M7Y00?o00000<;@iOl000001@32dNH2o`00
00@0a]3R0_l000000`35d>;o00000<_?g@020<_?g@;o00000`3:c]d2o`0000D0clgH00Ko00000<k=
f03>cMSo00000=?=e?l0000[ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0011
ooooo`03o`000?oooooooooo013ooooo00?o00000:>fiP2S]^H00`2S]^H4o`0000<0X;_/00?o0000
09nij`2O^N/0102O^N/01?l00000W[KY09jfj@2N]^T5o`0000<0VkW]00?o000009bgj`2L]n/00`2L
]n/00ol00000W[KY09jfj@0309jfj@03o`00002Q]^L0XKKW00?o000000<0W[[/o`00002R^^X01@2R
^^X01?l00000Y[[W0:Jji`2V^^L4o`0000H0ZKoY00?o00000:k0iol000000_l000020:k6k003o`00
002ba^T0//KY00@0//KY0_l000060;K<jP;o00001`2jcnX2o`0000H0_M7Y0_l000040<;AiP;o0000
0P31dNL01?l00000a]3Ro`000?l000040<G@hP03o`00003;cmgo000000@0b/kM00Co00000<W>g@39
c]go00000`3?cMP00ol00000c/gH0<k=f0020<k=f003o`000?oooooooooo02_ooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo0Oooool004;ooooo00?o0000ooooooooool04?ooool00ol00000
XkKVo`000002o`000080XKk]00?o00000:2kk02P^n`00`2P^n`00ol00000WkW[09nij`0309nij`Co
00000P2J^nl00ol00000VkW]09^ik@0409^ik@03o`00002L]n/0W;O[00<0W;O[00Co000009jfj@2N
]^T0W[KY1?l0000509jjk003o`00002R^^X0X[[Z00<0X[[Z1?l000040:Fok003o`00002Y_nT0ZKoY
00<0ZKoY0_l000060:k6k003o`00002ba^T0//KY00?o00000P2ac>d01?l00000]/cZ0;K<jP2fc>X2
o`000080]M3^00?o00000;[?jP2jcnX00P2jcnX2o`000080^M;]00?o00000;gAj@2mdNT00ol00002
0;cBj`04o`000032dNKo0000o`0000@0`M7W0_l000060<G@hP?o00000`3:c]d00ol00000bLkM0<W>
g@020<W>g@03o`00003?cMSo000000@0c/gH00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`00@oooool00ol0003oooooooooo`0@ooooo`;o00001@2Q_^d0
0ol00000X;_/0:2kk0030:2kk003o`00002O^N_o000000;o000000<0V[kao`00002J^nl0102J^nl0
0ol00000VkW]09^ik@0409^ik@04o`00002L]n/0W;O[09bgj`Go00000`2K^nh00ol00000W[[/09jj
k00409jjk003o`00002R^^[o000000;o000000<0X;k^o`00002U_n`01P2U_n`00ol00000ZKoYo`00
0002o`000080Z<G^00?o00000:k6k02^a^`00`2^a^`3o`0000H0/Lc]00?o00000;K<j_l000001@2e
d>h01?l00000^/oZo`000?l000040;WBk@?o00001@2ld^/3o`0000<0`M7W0_l000020;o@i`04o`00
0035d>80aM3R0<G@hP;o00000`34cn800ol00000b/kMo`0000050<W>g@;o0000103>cMP00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00A?ooool2o`0001;ooooo
00?o00000:6nk@2Q_^d00`2Q_^d01?l00000X;_/0:2kk02P^n`4o`0000@0V[ka00?o000009Zkk`2J
^nl00`2J^nl01?l00000VkW]09^ik@2K^Nd6o`0000<0V;c`00?o000009^kkP2K^nh00`2K^nh01?l0
0000W[[/09jjk02N^^`4o`0000D0X;k^00?o00000:Fok02U_n`0102U_n`2o`0000H0Z<G^00?o0000
0:k6k?l000000_l000020:g;l003o`00002ac>d0/Lc]00@0/Lc]0ol000050;G@kP?o00000`2id^d2
o`000080]mC_00Co00000;cBj`2ld^/0_=;[0_l000030;_Bk003o`000031dNOo000000D0_m3W00?o
00000<G@h_l000001@34cn82o`0000D0bLkM00?o00000<S=gOl000000`3>cMP00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00A_ooool00ol0003oooooooooo`0@
ooooo`04o`00002Q_^d0XKk]0:6nk@Go0000102K`_<00ol00000V[ka09Znl@0209Znl@04o`00002J
^nl0V[__09Zkk`Go0000102F_O<00ol00000V;c`09Rll00309Rll004o`00002K^nh0Vk_^09^kkPGo
0000102K__400ol00000X;k^0:2nkP030:2nkP03o`00002U_n`0YKo/00?o00000P2Sa?000ol00000
Z<G^0:S5kP030:S5kP;o00001P2]bo000ol00000/Lc]0;7<k@03o`0000<0/=7a00?o00000;G@k_l0
00000_l000030;?Cl@03o`00002id^go000000D0]mC_00?o00000;cBjol000001@2kd^`2o`0000H0
_m3W0ol000030<C?hP;o000000<0`lkRo`000039c]d00P39c]d2o`0000<0b<gM00?o00000<k=f?l0
0000=?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004Oooooo00?o0000ooooooooool0
4?ooool3o`0000@0W<Gd00Co000009_2l`2K`_<0Vl;c2_l0000409C0m@;o0000102F_O<01?l00000
V;c`09Rll02H_?05o`0000<0Ukoc00?o000009^nl@2K__40102K__401?l00000X;k^0:2nkP2P_^h4
o`0000H0XlC`00?o00000:S5k_l000000_l000020:O;lP03o`00002]bo00[L_`00<0[L_`0ol00006
0;3Al@;o00001P2cdo43o`0000D0]mC_0ol000030;_Bk0;o00000P2idN`01?l00000_m3W0;o@i`2o
d>L2o`0000<0_/oW00?o00000<C?h_l000001033c^800ol00000bLkMo`0000050<S=g@;o0000=_oo
ool01Ol0003ooooooooooooooooo0000007ooooo0018ooooo`03o`000?oooooooooo017ooooo00Co
000009c5m02LaO@0W<Gd1Ol0000309?6n@03o`00002C`oL0Tl?g00<0Tl?g0_l0000309C0m@[o0000
0`2C`?H00ol00000Ukoc09Nol`0309Nol`04o`00002K__40Vkka09^nl@Ko0000102M`o<01?l00000
XlC`0:?4l02Sa?05o`0000D0Yl_b00?o00000:g;l?l000000_l000030:_Am003o`00002`dO40/=7a
00?o00000P2^e?@00ol00000/m?a0;?Cl@03o`0000<0/MGc00?o00000;ODkol000000_l000030;CD
l003o`00002kd^co000000D0^M7/00?o00000;o@iol000001@2ncnL2o`0000D0`lkR0ol000030<S=
g@;o0000>?ooool01Ol0003ooooooooooooooooo0000007ooooo0019ooooo`;o00004_ooool3o`00
00<0U<_k00?o000009?6n@2Ca_T00`2Ca_T01?l00000Tl?g09?3m`2C`oL6o`0000<0S<?j00?o0000
08o1n02?`OP00`2?`OP00ol00000Tl3f09?0mP0209?0mP04o`00002G_o<0Ukoc09Nol`Go00001@2G
`oD01?l00000WL?c09g3l`2M`o<5o`0000D0XLWe00Co00000:O;lP2Wbo80Yl_b1?l000050:_Am0?o
00001@2^e?@3o`0000H0/MGc0_l000060;CDl0;o00001P2idN`2o`0000@0_/oW0_l000000`2lc^Oo
00000<?>hP020<?>hP;o00000`32cN800ol00000b<gMo`00000kooooo`04o`000?ooooooooooo`00
007ooooo001;ooooo`03o`000?oooooooooo017ooooo00?o000009C;n`2Dbo/00P2Dbo/01?l00000
TlKi09?6n@2Ca_T5o`0000D0RLKl00?o000008c3nP2<`oX00P2<`oX01?l00000Sl7h08o1n02?`OP:
o`0000@0TL?h0_l0000309O3m@Go00000`2Jb?L00ol00000XLWe0:79m@040:79m@Co0000102Td?L0
0ol00000Zm7do`000002o`0000<0YmGh00?o00000:kDm?l000000_l000030:[Gm`03o`00002aeO<0
/MGc00?o00000P2]e_D00ol00000]=C`0;CDl003o`000080/]?a00?o00000;WAk02idN`00ol00002
0;O@k@04o`00002ncnOo0000o`0000@0_<kW00?o00000<?>h_l000001@32cN82o`0003gooooo00?o
0000ooooool000000Oooool004cooooo00?o0000ooooooooool04Oooool8o`0000@0QlWm0_l00003
08W6o0[o00000`26a?`00ol00000S<Cj08c4nP0308c4nP04o`00002A`oP0TL?h0973n0Ko00000`2B
aoT00ol00000V/Sg09[8m`0309[8m`03o`00002QbOD0XLWe00?o00000P2McoT01?l00000Y=3g0:C@
m`2Td?L5o`0000D0YmGh0ol000050:[Gm`?o00001@2]e_D3o`0000D0/]?a0ol000050;O@k@;o0000
1P2lc^L2o`0000@0`/gR0_l0000oooooo`03o`000?oooooooooo007o0000001=ooooo`03o`000?oo
oooooooo01;ooooo0_l0000308K=o`;o00000`27bOd5o`0000@0O<Oo00?o00000875o@21aOd00P21
aOd00ol00000Q/Cl08K4o00208K4o004o`00002<a?X0S<Cj08c4nPGo0000102;a_/00ol00000T/Oi
09;7n@0309;7n@04o`00002Jb?L0V/Sg09[8m`Co00001@2McoT4o`0000D0X=Gj00?o00000:OEn?l0
00000_l000030:?HnP03o`00002ZeoOo000000;o00000`2Uf?T00ol00000[MKeo`000002o`0000<0
ZMGg00?o00000;;ClOl000000_l000030:oAlP03o`00002gd>go000000;o00000P2ec^d01?l00000
_<kW0;c>i`2lc^L2o`000080^lgW00Co00000<;=h_l0003o0000@_ooool1o`00007ooooo0Ol00000
04kooooo0_l0000Dooooo`So0000101hb_l01?l00000O<Oo07c7o`1laol?o`0000@0PlKm00?o0000
08_6n`2;a_/00`2;a_/01?l00000T/Oi09;7n@2BaoT5o`0000@0ULgk00?o000009g?nOl000000_l0
000309SDo@04o`00002PeOX0X=Gj0:3EnPGo00000`2Sf?X5o`0000D0YMSi0ol000050:WEm`?o0000
1@2_dO82o`0000H0]Lk]00?o00000;c>iol00000102kcNL2o`0004Gooooo0_l00000053ooooo00?o
0000ooooooooool05?ooool=o`0000@0JlKn00?o000007?6o`1ca_l00P1ca_l00ol00000NlKn07_6
oP0207_6oP04o`000023a_d0PlKm08?6o@_o0000102<bod01?l00000ULgk09G=n`2EcO/5o`0000<0
V=Cm1Ol0000409[Io@Co00001@2MfO`00ol00000YMSio`000002o`0000<0X=Ok00?o00000:WEmol0
00000_l000030:GCm`03o`00002_dO;o000000;o000000<0[<obo`00002ec^d01@2ec^d2o`0000<0
^lgW0_l00016ooooo`?o0000001Aooooo`03o`000?oooooooooo01Gooooo00Co000005g7nP1MaoX0
GLOj6Ol0000407O7o`;o00001022bOh01?l00000S<_m08c;o@2<bod5o`0000<0Sm;n1Ol00004097H
o`03o`00002JfOgo000000;o00000`2Bf_h01?l00000WMWl09gIo02MfO`5o`0000<0X=Ok1?l00006
0:GCm`;o00001@2/co800ol00000]Lk]0;G>k@03o`000080/lg]00?o00000;_=iol00000A?ooool4
o`0000?ooooo001Booooo`03o`000?oooooooooo01Gooooo3Ol0000405O1nP03o`00001Ra?d0H/Cm
0080H/Cm00Co000006g5o`1]aOl0KLGo4?l0000308C?o`Go00001026e_l01?l00000TMSo097Ho`2A
f?l5o`0000<0T][n1Ol0000309KHoPGo0000102Ke?`00ol00000YM?g0:GCm`03o`000080XM3h00Co
00000:c?lP2/co80[<ob1?l000050;?=k@;o0000@Oooool4o`0000Oooooo001Cooooo`;o00007?oo
oolCo`0000@0Fl;l00?o000006[6oP1Za_h00`1Za_h01?l00000N<_o07S;o`1hbol5o`0000@0NM7o
00Co000008KFo`26e_l0Q]Ko1Ol0000308OIo`Go00000`29f?l5o`0000@0S]Go00Co000009_Do02K
e?`0VmCl1?l000050:7@n0Co0000102Yc?800ol00000/lg]o`000002o`00043ooooo0ol0000;oooo
o`00EOooool00ol0003oooooooooo`0Poooooa[o00000P1Zc?d;o`0000<0NMKn1Ol0000307[GoPGo
0000101oeOl01?l00000S]Go08kEo`2>eOl5o`0000@0UM7l00?o00000:7@n?l000000_l0000209g<
n003o`00002Yc?80ZLcb00<0ZLcb0_l0000oooooo`Co00003_ooool005Kooooo00?o0000oooooooo
ool09ooooolDo`0000<0FLWf4ol0000206gBo0_o00001027dOl01?l00000UM7l09GAo02EdO`3o`00
00H0WLch00?o00000:W<l_l000000_l0000mooooo`Co00004_ooool005Oooooo00?o0000oooooooo
ool0:Oooool01?l0003ooooooooooooooolUo`0000@0Gl_i00Co000007G?o`1ecol0MLoo2ol00003
093=o004o`00002Mc?P0WLch09g<n0Co0000??ooool4o`0001Kooooo001Hooooo`;o0000:Oooool0
0ol0003oooooooooo`0FoooooaSo0000101[bOh01?l00000Olco07o<o`1oc?l:o`0003cooooo1?l0
000Jooooo`00F_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Sooooo3_l00012
ooooo`Co00007_ooool005_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1eoooo
o`?o00008_ooool005cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1aooooo`Co
00009Oooool005gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1]ooooo`Co0000
:Oooool005kooooo0_l0000Sooooo`03o`000?oooooooooo06Wooooo1?l0000]ooooo`00H?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0000aooooo`00HOooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0000eooooo`00H_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo05kooooo0ol0000iooooo`00Hoooool2o`0001kooooo
00?o0000ooooooooool0F_ooool4o`0003cooooo001Uooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0E_ooool4o`00043ooooo001Vooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0D_ooool4o`0004Cooooo001Wooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0C_ooool4o`0004Sooooo001Xooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co
0000C?ooool006[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`?o0000
D?ooool006_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`Co0000Dooo
ool006cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000Eoooool0
06gooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l0001Kooooo`00Koooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0001Oooooo`00L?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03Cooooo0ol0001Sooooo`00LOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo033ooooo1?l0001Vooooo`00L_ooool2o`0000kooooo00?o0000
ooooooooool0;Oooool4o`0006[ooooo001dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0:Oooool4o`0006kooooo001eooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool09Oooool4o`0007;ooooo001fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8Oooool4o`0007Kooooo001gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_oo
ool3o`0007[ooooo001hooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000OOooool0
07[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000POooool007_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000QOooool007cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000ROooool007gooooo0_l0
0003ooooo`03o`000?oooooooooo00[ooooo1?l0002=ooooo`00Ooooool01?l0003oooooooooool0
0009ooooo`?o0000TOooool0083ooooo00?o0000ooooool000001Oooool4o`0009Cooooo0021oooo
o`;o000000?oooooo`000?l000000_l0002Hooooo`00P_ooool2o`0009cooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.097544, 0.0153105, \
0.00365902, 0.00365902}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(likelihoodFunction1D[data, \ 
      Join[{est1}, \ Drop[params2, 1]]]\)], "Input"],

Cell[BoxData[
    \(\(-200.8526766263539`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(likelihoodFunction1D[data, \ 
      Join[{est2}, \ Drop[params2, 1]]]\)], "Input"],

Cell[BoxData[
    \(\(-208.65013979047146`\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize resulting pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1\  = \ 
        Plot[mixturepdf1D[{est1, \[Sigma], P\[Omega]}, x], {x, \(-5\), 5}, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          PlotStyle \[Rule] {Thickness[ .01], Red}, \ 
          Evaluate[nS]];\)\), "\n", 
    \(\(g2\  = \ \ Plot[
          mixturepdf1D[{est2, \[Sigma], P\[Omega]}, x], {x, \(-5\), 5}, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          PlotStyle \[Rule] {Thickness[ .01], Blue}, \ 
          Evaluate[nS]];\)\), "\n", 
    \(\(Show[pdf, g1, g2, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 2.21226 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12533 -24 -4.5 ]
[-0.0125 .12533 0 4.5 ]
[-0.0125 .23594 -18 -4.5 ]
[-0.0125 .23594 0 4.5 ]
[-0.0125 .34655 -24 -4.5 ]
[-0.0125 .34655 0 4.5 ]
[-0.0125 .45717 -18 -4.5 ]
[-0.0125 .45717 0 4.5 ]
[-0.0125 .56778 -24 -4.5 ]
[-0.0125 .56778 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12533 m
.00625 .12533 L
s
[(0.05)] -0.0125 .12533 1 0 Mshowa
0 .23594 m
.00625 .23594 L
s
[(0.1)] -0.0125 .23594 1 0 Mshowa
0 .34655 m
.00625 .34655 L
s
[(0.15)] -0.0125 .34655 1 0 Mshowa
0 .45717 m
.00625 .45717 L
s
[(0.2)] -0.0125 .45717 1 0 Mshowa
0 .56778 m
.00625 .56778 L
s
[(0.25)] -0.0125 .56778 1 0 Mshowa
.125 Mabswid
0 .03684 m
.00375 .03684 L
s
0 .05896 m
.00375 .05896 L
s
0 .08108 m
.00375 .08108 L
s
0 .10321 m
.00375 .10321 L
s
0 .14745 m
.00375 .14745 L
s
0 .16957 m
.00375 .16957 L
s
0 .1917 m
.00375 .1917 L
s
0 .21382 m
.00375 .21382 L
s
0 .25806 m
.00375 .25806 L
s
0 .28019 m
.00375 .28019 L
s
0 .30231 m
.00375 .30231 L
s
0 .32443 m
.00375 .32443 L
s
0 .36868 m
.00375 .36868 L
s
0 .3908 m
.00375 .3908 L
s
0 .41292 m
.00375 .41292 L
s
0 .43504 m
.00375 .43504 L
s
0 .47929 m
.00375 .47929 L
s
0 .50141 m
.00375 .50141 L
s
0 .52354 m
.00375 .52354 L
s
0 .54566 m
.00375 .54566 L
s
0 .5899 m
.00375 .5899 L
s
0 .61203 m
.00375 .61203 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12533 m
1 .12533 L
s
.99375 .23594 m
1 .23594 L
s
.99375 .34655 m
1 .34655 L
s
.99375 .45717 m
1 .45717 L
s
.99375 .56778 m
1 .56778 L
s
.125 Mabswid
.99625 .03684 m
1 .03684 L
s
.99625 .05896 m
1 .05896 L
s
.99625 .08108 m
1 .08108 L
s
.99625 .10321 m
1 .10321 L
s
.99625 .14745 m
1 .14745 L
s
.99625 .16957 m
1 .16957 L
s
.99625 .1917 m
1 .1917 L
s
.99625 .21382 m
1 .21382 L
s
.99625 .25806 m
1 .25806 L
s
.99625 .28019 m
1 .28019 L
s
.99625 .30231 m
1 .30231 L
s
.99625 .32443 m
1 .32443 L
s
.99625 .36868 m
1 .36868 L
s
.99625 .3908 m
1 .3908 L
s
.99625 .41292 m
1 .41292 L
s
.99625 .43504 m
1 .43504 L
s
.99625 .47929 m
1 .47929 L
s
.99625 .50141 m
1 .50141 L
s
.99625 .52354 m
1 .52354 L
s
.99625 .54566 m
1 .54566 L
s
.99625 .5899 m
1 .5899 L
s
.99625 .61203 m
1 .61203 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.01 w
.02381 .01798 m
.03279 .01903 L
.04262 .02051 L
.05288 .02251 L
.06244 .02488 L
.0828 .03201 L
.09421 .03756 L
.10458 .04376 L
.12373 .05859 L
.14451 .08029 L
.18538 .1405 L
.22473 .21264 L
.24448 .24773 L
.26256 .27525 L
.27184 .28679 L
.28197 .29691 L
.28752 .30123 L
.29267 .30443 L
.2976 .30673 L
.30035 .30768 L
.30285 .30833 L
.30397 .30856 L
.30517 .30876 L
.30649 .30893 L
.30772 .30903 L
.30839 .30907 L
.30911 .30909 L
.31042 .3091 L
.31169 .30904 L
.31287 .30895 L
.31397 .30882 L
.315 .30867 L
.31735 .30819 L
.31963 .30755 L
.3221 .30668 L
.32739 .30418 L
.33296 .30064 L
.34292 .29212 L
.35246 .28156 L
.36266 .26808 L
.38102 .23965 L
.40094 .2061 L
.42252 .17148 L
.43263 .15737 L
.44332 .14466 L
.45246 .13601 L
.45726 .13239 L
.4625 .12922 L
.46521 .12792 L
.46772 .12693 L
Mistroke
.47011 .12618 L
.47134 .12587 L
.47267 .12559 L
.47397 .12538 L
.47518 .12523 L
.47633 .12514 L
.47754 .1251 L
.47863 .1251 L
.47964 .12514 L
.48076 .12523 L
.48195 .12538 L
.48335 .12562 L
.48465 .1259 L
.48757 .12678 L
.49015 .12782 L
.49289 .1292 L
.49762 .13228 L
.50284 .1367 L
.51296 .14834 L
.52223 .16259 L
.5431 .20695 L
.56206 .26053 L
.58278 .32994 L
.62339 .4751 L
.64216 .53271 L
.65204 .55753 L
.66249 .57853 L
.66779 .58689 L
.67362 .59415 L
.67618 .59668 L
.67892 .59894 L
.68149 .60062 L
.68387 .60181 L
.68513 .60229 L
.68646 .60269 L
.68711 .60284 L
.6878 .60297 L
.68857 .60308 L
.68928 .60315 L
.69059 .60319 L
.69124 .60317 L
.69196 .60311 L
.69323 .60293 L
.69442 .60267 L
.69567 .6023 L
.69685 .60185 L
.69907 .60077 L
.70145 .59926 L
.70404 .59721 L
.70892 .59221 L
Mistroke
.71349 .5862 L
.72389 .568 L
.73402 .5447 L
.74492 .5144 L
.78617 .36989 L
.8259 .22882 L
.84594 .16996 L
.86411 .12637 L
.8838 .08969 L
.89472 .07372 L
.90477 .06151 L
.92404 .0438 L
.93416 .037 L
.94486 .03133 L
.95268 .02801 L
.96107 .02511 L
.97619 .02125 L
Mfstroke
1 0 0 r
.02381 .01711 m
.03279 .01791 L
.04262 .01905 L
.05288 .02061 L
.06244 .02248 L
.0731 .02515 L
.0828 .02822 L
.09413 .03273 L
.10458 .03793 L
.12373 .0505 L
.14451 .0694 L
.16324 .09165 L
.18386 .12187 L
.22415 .19347 L
.26292 .26178 L
.27302 .27631 L
.28405 .28961 L
.2891 .29467 L
.29447 .29928 L
.29918 .30264 L
.30414 .30546 L
.3067 .30661 L
.3095 .30765 L
.31205 .30837 L
.31443 .30886 L
.31512 .30897 L
.31587 .30907 L
.31653 .30915 L
.31724 .30921 L
.31787 .30925 L
.31857 .30929 L
.3198 .30931 L
.32054 .3093 L
.32123 .30927 L
.32198 .30923 L
.32277 .30916 L
.3241 .309 L
.32556 .30877 L
.3282 .30817 L
.33061 .30744 L
.336 .30514 L
.34101 .30224 L
.34573 .29884 L
.35545 .28996 L
.36574 .27812 L
.38419 .25212 L
.42208 .19274 L
.44153 .1674 L
.44713 .16157 L
.45244 .1568 L
Mistroke
.45768 .15288 L
.46242 .15007 L
.4648 .14892 L
.46737 .1479 L
.4698 .14715 L
.47203 .14664 L
.47326 .14643 L
.47441 .14629 L
.47566 .14619 L
.47637 .14616 L
.47701 .14615 L
.47831 .14617 L
.47904 .14621 L
.47971 .14627 L
.48095 .14642 L
.48227 .14664 L
.48444 .14715 L
.48678 .14791 L
.49102 .14984 L
.49605 .15308 L
.50066 .15696 L
.51049 .16818 L
.51963 .18222 L
.54034 .22652 L
.56084 .28532 L
.57944 .34791 L
.61947 .48813 L
.63783 .54187 L
.64825 .56618 L
.65334 .57607 L
.65799 .58385 L
.66259 .59032 L
.6676 .59592 L
.67035 .59834 L
.67289 .60015 L
.67532 .60151 L
.67667 .60209 L
.67791 .60253 L
.67911 .60286 L
.68039 .60311 L
.68167 .60325 L
.68239 .60329 L
.68306 .60329 L
.68429 .60322 L
.68541 .60307 L
.68669 .6028 L
.68791 .60244 L
.68925 .60194 L
.69067 .60128 L
.69321 .59978 L
Mistroke
.69595 .59771 L
.69896 .59488 L
.70417 .58868 L
.70911 .58129 L
.71839 .56366 L
.73927 .50855 L
.77748 .37402 L
.81815 .22935 L
.83696 .17371 L
.8573 .12473 L
.87872 .08576 L
.88835 .07214 L
.8989 .05965 L
.91885 .04205 L
.92975 .03517 L
.93992 .03013 L
.94967 .02635 L
.9589 .02354 L
.96718 .02155 L
.97619 .01985 L
Mfstroke
0 0 1 r
.02381 .01794 m
.03279 .01906 L
.04262 .02069 L
.05288 .02295 L
.06244 .02571 L
.0731 .02969 L
.0828 .03435 L
.094 .04121 L
.10458 .04944 L
.12455 .07066 L
.14299 .09829 L
.16172 .1356 L
.18234 .1883 L
.22263 .32212 L
.2614 .46469 L
.28111 .52726 L
.29153 .55434 L
.29724 .56701 L
.30263 .57735 L
.30782 .58577 L
.31343 .5931 L
.31591 .59572 L
.31853 .59808 L
.32098 .5999 L
.32322 .60122 L
.32549 .60223 L
.32675 .60265 L
.32793 .60295 L
.32903 .60315 L
.33004 .60327 L
.33115 .60332 L
.33233 .60328 L
.33351 .60316 L
.33479 .60293 L
.33599 .60261 L
.33709 .60224 L
.33965 .60108 L
.34234 .5994 L
.34734 .59508 L
.35188 .58983 L
.36208 .57362 L
.37153 .55357 L
.38045 .53075 L
.41891 .40442 L
.4384 .3354 L
.45983 .2661 L
.48019 .21265 L
.4893 .19369 L
.49923 .17687 L
.50463 .16945 L
Mistroke
.50964 .16367 L
.51483 .15879 L
.51952 .15534 L
.52174 .15402 L
.52415 .15282 L
.52622 .15197 L
.5285 .15124 L
.52967 .15094 L
.53092 .15069 L
.53162 .15057 L
.53225 .15048 L
.53348 .15035 L
.53461 .15028 L
.53583 .15026 L
.53699 .15029 L
.53806 .15036 L
.53924 .1505 L
.54048 .15069 L
.54271 .15117 L
.5451 .15189 L
.54771 .1529 L
.5524 .15528 L
.55676 .15812 L
.56673 .16672 L
.57738 .17867 L
.61893 .24056 L
.63977 .27136 L
.64891 .28293 L
.65896 .29361 L
.66363 .29773 L
.66864 .30151 L
.67297 .30421 L
.67768 .30652 L
.68044 .30756 L
.683 .30832 L
.68544 .30885 L
.68667 .30905 L
.68733 .30914 L
.68803 .30921 L
.68926 .30931 L
.69038 .30935 L
.69158 .30936 L
.6929 .30931 L
.69405 .30923 L
.69527 .30909 L
.69643 .30892 L
.69748 .30872 L
.69978 .30817 L
.70232 .30737 L
.70744 .30515 L
Mistroke
.71219 .30236 L
.71664 .29914 L
.72666 .28983 L
.73743 .27693 L
.77867 .20859 L
.8184 .13612 L
.85661 .0804 L
.8763 .05966 L
.89728 .04334 L
.90758 .03725 L
.91871 .03189 L
.92833 .02814 L
.93888 .02485 L
.94764 .02266 L
.95703 .02078 L
.96694 .01923 L
.97619 .01811 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00??ooool3o`0002cooooo1Ol0000/ooooo`;o0000
;Oooool5o`0002kooooo0ol0000Oooooo`00?Oooool00ol0003oooooooooo`0/ooooo`04o`000?oo
ooooooooo`0002_ooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000_oooo
o`03o`000?oooooooooo01kooooo000dooooo`Go000000?oooooo`000?l000000ol0000Vooooo`Go
00000oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooo
ooooool0;?ooool5o`0001oooooo000jooooo`04o`000?ooooooooooo`00033ooooo00?o0000oooo
ooooool0:_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo02_ooooo00Co0000
oooooooooooo00008?ooool003_ooooo00?o0000ooooool00000;Oooool01Ol0003ooooooooooooo
oooo000002_ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000002go
oooo00?o0000ooooool000008?ooool003cooooo0_l0000]ooooo`05o`000?ooooooooooooooool0
0000:oooool01?l0003oooooooooool0000/ooooo`05o`000?ooooooooooooooool00000;_ooool2
o`00023ooooo000mooooo`03o`000?oooooooooo02cooooo0ol0000]ooooo`;o0000;_ooool3o`00
033ooooo00?o0000ooooooooool07_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool001_ooooo00<00000o`000?l00000ool00001o`00004000000Oooool001Co
oooo0_l00005ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool0;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Looooo`4000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`3oooooo`7ooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`03
00000?l0003ooooo00;ooooo0`3o003jooooo`7o00000@000001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo00;ooooo20000?l30?l00>Kooooo20000?l5ooooo`40
00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`02ooooo`/0
003o1@3o003Mooooo``0003o1Oooool10000007ooooo000Dooooo`;o00001Oooool00`00003ooooo
ooooo`09ooooo`L0003o1@3o003Gooooo`P0003o1@3o0007ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool03?ooool60000o`D0o`00d_ooool70000o`D0o`002oooool10000007ooooo000K
ooooo`0300000?l0003ooooo00oooooo1@000?l40?l00=3ooooo1@000?l50?l00003003o0?oooooo
oooo00[ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo017ooooo10000?l00ol0
o`00o`000?l000020?l00<cooooo10000?l00oooool0o`000?l000030?l00003003o0?oooooooooo
00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Cooooo`@0003o1@3o0038ooooo`D0
003o103o0003003o013ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Dooooo`@0003o
00?o0?l00?l0003o00000P3o0036ooooo`@0003o00?ooooo0?l0003o00000P3o0002003o01;ooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Fooooo`<0003o0_l0o`030?l00<?ooooo1000
0?l2ooooo`<0o`000`00o`0Cooooo`4000000Oooool001_ooooo00<00000ooooooooool05oooool3
0000o`;o0?l00`3o0031ooooo`@0003o0_ooool30?l000<00?l05?ooool10000007ooooo000Koooo
o`0300000?l0003ooooo01Sooooo0`000?l2o`3o00<0o`00_oooool30000o`?ooooo0`3o0003003o
01Cooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo01Wooooo0`000?l2o`3o00<0
o`00__ooool20000o`Cooooo0P3o0003003o01Kooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Jooooo`<0003o0_l0o`030?l00;cooooo0`000?l3ooooo`<0o`000P00o`0Gooooo`400000
0Oooool001_ooooo00<00000ooooooooool06oooool30000o`;o0?l00`3o002jooooo`<0003o0ooo
ool30?l000800?l06?ooool10000007ooooo000Kooooo`0300000?oooooooooo01cooooo0P000?l3
o`3o0080o`00^Oooool30000o`?ooooo0`3o0002003o01Wooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Looooo`<0003o0_l0o`030?l00;Oooooo0`000?l4ooooo`80o`000P00o`0Joooo
o`4000000Oooool001_ooooo00<00000o`000?ooool07Oooool30000o`;o0?l00`3o002eooooo`<0
003o1?ooool30?l000800?l06Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0
7_ooool30000o`;o0?l00`3o002dooooo`80003o1?ooool30?l000800?l06oooool10000007ooooo
000Kooooo`0300000?oooooooooo01oooooo0P000?l3o`3o00<0o`00/_ooool30000o`Cooooo0P3o
0002003o01cooooo0@000001ooooo`006oooool00`00003oooooooooo`0Oooooo`<0003o0ol0o`03
0?l00;3ooooo0`000?l4ooooo`<0o`0000<00?l0ooooooooool06oooool10000007ooooo000Koooo
o`0300000?oooooooooo023ooooo0`000?l3o`3o0080o`00[oooool30000o`Cooooo0`3o0002003o
01gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Qooooo`80003o00?oooooo`3o0?l0
o`000`3o002^ooooo`80003o1Oooool20?l000800?l07_ooool10000007ooooo000Kooooo`030000
0?l0003ooooo027ooooo0`000?l3o`3o00<0o`00[?ooool30000o`Cooooo0`3o0002003o01gooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02;ooooo0P000?l01?oooooo0?l0o`3o
0?l0o`020?l00:_ooooo0`000?l5ooooo`80o`000P00o`0Oooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool30000o`03ooooool0o`3o0?l000<0o`00Z_ooool20000o`Gooooo0`3o
0002003o01oooooo0@000001ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol00005ooooo`0300000?oooooooooo02?ooooo0P000?l2ooooo`;o0?l00P3o002Y
ooooo`<0003o1?ooool30?l000800?l08?ooool10000007ooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo
00<00000ooooooooool08oooool30000o`03ooooool0o`3o0?l000<0o`00Yoooool30000o`Gooooo
0P3o0003003o023ooooo0@000001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00`00003o0000ooooo`0Tooooo`80
003o0_ooool2o`3o00<0o`00B_ooool4o`3o05Oooooo0`000?l5ooooo`<0o`000P00o`0Pooooo`7o
00000@000001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0Tooooo`<0003o0_ooool2o`3o
0080o`00A_ooool;o`3o05Cooooo0P000?l6ooooo`80o`000`00o`0Qooooo`4000000Oooool00005
ooooool0003oooooooooool000002?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool0
0`00003oooooooooo`0Uooooo`80003o0_ooool2o`3o00<0o`00A?ooool6o`3o0003ooooool0o`3o
0?l000Co0?l0D_ooool30000o`Gooooo0`3o0002003o02;ooooo0@000001ooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00`00003ooooo
ooooo`0Uooooo`<0003o0_ooool2o`3o00<0o`00@_ooool3o`3o00Wooooo0ol0o`1@ooooo`<0003o
1_ooool20?l000<00?l08_ooool10000007ooooo0002ooooo`;o00002_ooool2o`0000;ooooo1Ol0
0004ooooo`0300000?oooooooooo02Kooooo0P000?l3ooooo`;o0?l00P3o0011ooooo`?o0?l02ooo
ool3o`3o04oooooo0P000?l7ooooo`80o`000P00o`0Sooooo`4000000Oooool001_ooooo00<00000
ooooooooool09_ooool30000o`?ooooo00Co0?l00?l0003o0000o`00?oooool3o`3o00gooooo0ol0
o`1=ooooo`<0003o1_ooool30?l000800?l08oooool10000007ooooo000Kooooo`0300000?l0003o
oooo02Oooooo0P000?l3ooooo`;o0?l00P3o000oooooo`;o0?l01?ooool70?l000Cooooo0ol0o`1<
ooooo`80003o1oooool20?l000800?l08oooool1o`00004000000Oooool001_ooooo00<00000oooo
ooooool09oooool20000o`Cooooo00Co0?l00?l0003o0000o`00?Oooool3o`3o00?ooooo2P3o0003
ooooo`;o0?l000?ooooo0000o`000?l01@000?m3ooooo`<0003o1_ooool30?l000800?l09?ooool1
0000007ooooo000Kooooo`0300000?oooooooooo02Oooooo0`000?l3ooooo`;o0?l00`3o000koooo
o`?o0?l00_ooool40?l000Gooooo103o0002ooooo`03o`3o00000?l0003o00T0003o@Oooool20000
o`Oooooo0P3o0002003o02Gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Xooooo`80
003o1?ooool2o`3o0080o`00>_ooool3o`3o00;ooooo103o0008ooooo`<0o`0000?ooooo0000o`00
0?l00`000?l4ooooo`D0003o?_ooool30000o`Oooooo0P3o0002003o02Gooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0Xooooo`80003o1?ooool2o`3o00<0o`00>?ooool3o`3o0003oooo
o`3o0000o`000080o`002oooool20?l000<0003o0_l0o`07ooooo`@0003o?Oooool20000o`Oooooo
0`3o0002003o02Gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Xooooo`<0003o1?oo
ool2o`3o0080o`00=oooool3o`3o0003ooooo`3o0000o`000080o`003?ooool20?l00080003o00?o
ooooo`3o0?l0o`002Oooool30000oc_ooooo0`000?l7ooooo`80o`000P00o`0Vooooo`4000000Ooo
ool001_ooooo00<00000o`000?ooool0:Oooool20000o`Cooooo0_l0o`030?l003Gooooo0ol0o`02
ooooo`80o`003oooool30000o`04ooooool0o`3o0?l0o`3o00Wooooo0`000?ljooooo`80003o2?oo
ool20?l000800?l09Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0:Oooool2
0000o`Gooooo0_l0o`030?l003Cooooo0_l0o`02ooooo`<0o`003_ooool30000o`80o`0000?ooooo
o`3o0?l0o`002_ooool30000ocSooooo0`000?l7ooooo`<0o`0000<00?l0ooooooooool09Oooool1
0000007ooooo000Kooooo`0300000?oooooooooo02Wooooo0`000?l4ooooo`?o0?l00P3o000coooo
o`?o0?l000Cooooo0?l0003o0000o`003_ooool30000o`04ooooo`3o0000o`000?l000?o0?l02_oo
ool30000ocKooooo0`000?l8ooooo`80o`000P00o`0Wooooo`4000000Oooool001_ooooo00<00000
ooooooooool0:_ooool20000o`Gooooo0_l0o`030?l003;ooooo0_l0o`001?ooool0o`000?l0003o
000?ooooo`80003o0oooool30?l000;o0?l02oooool20000ocKooooo0P000?l8ooooo`<0o`0000<0
0?l0ooooooooool09_ooool10000007ooooo000Kooooo`0300000?oooooooooo02[ooooo0P000?l6
ooooo`;o0?l00P3o000aooooo`?o0?l000?ooooo0?l0003o00003oooool30000o`Cooooo0P3o0003
o`3o00[ooooo0`000?ldooooo`<0003o2?ooool20?l000800?l0:?ooool10000007ooooo000Koooo
o`0300000?oooooooooo02[ooooo0`000?l5ooooo`;o0?l00`3o000_ooooo`?o0?l000Cooooo0?l0
003o0000o`003oooool20000o`Gooooo0`3o0002o`3o00_ooooo0`000?lcooooo`80003o2Oooool2
0?l000800?l0:?ooool10000007ooooo000Kooooo`0300000?l0003ooooo02_ooooo0P000?l6oooo
o`;o0?l00`3o000^ooooo`;o0?l000Cooooo0?l0003o0000o`003oooool30000o`Kooooo0P3o0003
o`3o00_ooooo0P000?lbooooo`<0003o2?ooool30?l00003003o0?oooooooooo02Kooooo0Ol00001
0000007ooooo000Kooooo`0300000?oooooooooo02_ooooo0P000?l6ooooo`?o0?l00P3o000]oooo
o`?o0?l000?ooooo0?l0003o00004?ooool20000o`Oooooo0P3o00000ooooooo0?l0o`3o000;oooo
o`<0003o<Oooool20000o`Wooooo0P3o0002003o02Wooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0[ooooo`<0003o1_ooool2o`3o00<0o`00;?ooool2o`3o0004ooooo`3o0000o`000?l0
00oooooo0`000?l7ooooo`<0o`000ol0o`0;ooooo`80003o<?ooool30000o`Wooooo0P3o0002003o
02Wooooo0@000001ooooo`006oooool00`00003oooooooooo`0/ooooo`80003o1_ooool3o`3o0080
o`00:oooool3o`3o00<0o`003oooool30000o`Wooooo0P3o00000ooooooo0?l0o`3o000;ooooo`<0
003o;oooool20000o`Wooooo0`3o00000`00o`3oooooooooo`0Xooooo`4000000Oooool001_ooooo
00<00000ooooooooool0;?ooool20000o`Oooooo0_l0o`030?l002[ooooo0_l0o`000oooool0o`00
0?l0000@ooooo`80003o2_ooool30?l000?o0?l02oooool30000obgooooo0`000?l9ooooo`80o`00
0P00o`0Zooooo`4000000Oooool001_ooooo00<00000o`000?ooool0;?ooool30000o`Kooooo0ol0
o`030?l002Sooooo0ol0o`030?l000oooooo0`000?l;ooooo`80o`0000?oooooo`3o0?l0o`003?oo
ool20000obgooooo0P000?l:ooooo`80o`000P00o`0Yooooo`7o00000@000001ooooo`006oooool0
0`00003oooooooooo`0]ooooo`80003o1oooool2o`3o0003ooooo`3o0000o`0002Sooooo0_l0o`03
0?l0013ooooo0P000?l<ooooo`<0o`000ol0o`0;ooooo`<0003o:oooool30000o`Wooooo0`3o0000
0`00o`3oooooooooo`0Yooooo`4000000Oooool001_ooooo00<00000ooooooooool0;Oooool20000
o`Oooooo0ol0o`030?l002Kooooo0ol0o`020?l0013ooooo0`000?l=ooooo`80o`0000?oooooo`3o
0?l0o`003?ooool30000obWooooo0`000?l:ooooo`80o`000P00o`0[ooooo`4000000Oooool001_o
oooo00<00000ooooooooool0;Oooool30000o`Oooooo0_l0o`000oooool0o`000?l0000Uooooo`?o
0?l00`3o000@ooooo`80003o3_ooool20?l00003ooooool0o`3o0?l000gooooo0P000?lYooooo`80
003o2oooool20?l000800?l0:oooool10000007ooooo0008ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00`00003oooooooooo`0^ooooo`80003o1oooool3o`3o00<0o`00
9?ooool2o`3o00<0o`004Oooool20000o`kooooo0`3o0003o`3o00cooooo0`000?lWooooo`<0003o
2_ooool30?l00003003o0?oooooooooo02[ooooo0@000001ooooo`001oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0;_ooool20000o`Sooooo
0ol0o`020?l002?ooooo0ol0o`020?l0017ooooo0`000?l?ooooo`80o`0000?oooooo`3o0?l0o`00
3Oooool20000obOooooo0P000?l;ooooo`80o`000P00o`0/ooooo`4000000Oooool000Oooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`0300000?l0003ooooo02kooooo
0`000?l8ooooo`;o0?l00`3o000Rooooo`;o0?l00`3o000Aooooo`80003o4?ooool30?l000;o0?l0
3Oooool30000obGooooo0`000?l;ooooo`80o`000P00o`0[ooooo`7o00000@000001ooooo`001ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0
;oooool20000o`Sooooo0ol0o`020?l0027ooooo0_l0o`030?l001;ooooo0P000?lAooooo`80o`00
0ol0o`0=ooooo`<0003o8oooool30000o`_ooooo0`3o0002003o02cooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0
;oooool20000o`Wooooo0_l0o`030?l0023ooooo0_l0o`020?l001;ooooo0`000?lAooooo`80o`00
00?oooooo`3o0?l0o`003_ooool20000ob?ooooo0P000?l<ooooo`80o`000P00o`0]ooooo`400000
0Oooool000Oooooo00Co0000oooooooooooo00002?ooool2o`0000Kooooo00<00000ooooooooool0
;oooool30000o`Sooooo0ol0o`030?l001kooooo0_l0o`030?l001;ooooo0P000?lBooooo`<0o`00
0_l0o`0>ooooo`<0003o8Oooool30000o`cooooo0P3o0002003o02gooooo0@000001ooooo`002?oo
ool2o`0000[ooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0`ooooo`80003o2Ooo
ool2o`3o0003ooooo`3o0000o`0001gooooo0_l0o`030?l001?ooooo0P000?lCooooo`80o`000ol0
o`0>ooooo`<0003o8?ooool20000o`gooooo0P3o0002003o02gooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0`ooooo`80003o2Oooool3o`3o00<0o`007?ooool2o`3o0080o`004oooool3
0000oa?ooooo0P3o00000ooooooo0?l0o`3o000?ooooo`<0003o7_ooool30000o`cooooo0`3o0002
003o02gooooo0@000001ooooo`006oooool00`00003o0000ooooo`0`ooooo`<0003o2Oooool3o`3o
0080o`006oooool2o`3o00<0o`004oooool20000oaCooooo0`3o0002o`3o013ooooo0P000?lMoooo
o`<0003o3Oooool20?l000800?l0;Oooool1o`00004000000Oooool001_ooooo00<00000oooooooo
ool0<Oooool20000o`[ooooo0_l0o`030?l001[ooooo0_l0o`020?l001Cooooo0P000?lEooooo`80
o`000ol0o`0?ooooo`<0003o7?ooool20000o`kooooo0P3o0002003o02kooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0aooooo`80003o2oooool2o`3o0080o`006Oooool2o`3o00<0o`00
4oooool30000oaGooooo0P3o00000ooooooo0?l0o`3o000@ooooo`<0003o6_ooool30000o`gooooo
0`3o0002003o02kooooo0@000001ooooo`006oooool00`00003oooooooooo`0aooooo`80003o2ooo
ool2o`3o00<0o`005oooool2o`3o00<0o`005?ooool20000oaKooooo0`3o0002o`3o017ooooo0`00
0?lIooooo`80003o3_ooool20?l000800?l0;oooool10000007ooooo000Kooooo`0300000?oooooo
oooo037ooooo0`000?l;ooooo`;o0?l00`3o000Eooooo`?o0?l00P3o000Eooooo`80003o5oooool2
0?l000?o0?l04Oooool20000oaSooooo0`000?l>ooooo`80o`000P00o`0_ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0<_ooool20000o`cooooo0_l0o`030?l001?ooooo0ol0o`030?l0
01Cooooo0`000?lGooooo`80o`0000?oooooo`3o0?l0o`004Oooool30000oaKooooo0`000?l?oooo
o`80o`000P00o`0_ooooo`4000000Oooool001_ooooo00<00000o`000?ooool0<_ooool20000o`co
oooo0ol0o`020?l001;ooooo0ol0o`030?l001Gooooo0P000?lHooooo`<0o`000_l0o`0Booooo`<0
003o5?ooool30000o`oooooo0`3o0002003o02kooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo03;ooooo0`000?l<ooooo`;o0?l00`3o000Aooooo`;o0?l00`3o000Fooooo`80003o
6Oooool20?l000?o0?l04_ooool30000oa;ooooo0`000?l@ooooo`80o`000P00o`0`ooooo`400000
0Oooool001_ooooo00<00000ooooooooool0<oooool20000o`gooooo0_l0o`040?l000kooooo0_l0
o`030?l001Kooooo0`000?lIooooo`80o`0000?oooooo`3o0?l0o`004oooool30000oa3ooooo0`00
0?lAooooo`80o`000P00o`0`ooooo`4000000Oooool001_ooooo00<00000ooooooooool0<oooool2
0000o`kooooo0_l0o`040?l000_ooooo1?l0o`020?l001Oooooo0P000?lJooooo`80o`0000?ooooo
o`3o0?l0o`005?ooool30000o`oooooo0P000?lBooooo`80o`000P00o`0`ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0<oooool30000o`kooooo0ol0o`020?l000[ooooo1?l0o`030?l0
01Oooooo0P000?lJooooo`<0o`000_l0o`0Eooooo`<0003o3Oooool30000oa7ooooo0`3o0002003o
033ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0dooooo`80003o3oooool2o`3o00D0
o`001_ooool2o`3o00D0o`006?ooool20000oa_ooooo0P3o0003o`3o01Gooooo0`000?l9ooooo`D0
003o4_ooool20?l000800?l0<?ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0
=?ooool20000oa3ooooo0_l0o`050?l000?ooooo0ol0o`050?l001Sooooo0`000?lKooooo`80o`00
00?oooooo`3o0?l0o`005_ooool40000o`Kooooo1@000?lCooooo`80o`000P00o`0aooooo`400000
0Oooool001_ooooo00<00000ooooooooool0=?ooool30000oa7ooooo0ol0o`0:0?l001_ooooo0P00
0?lLooooo`<0o`000_l0o`0Gooooo`/0003o5_ooool20?l000800?l0<Oooool10000007ooooo000K
ooooo`0300000?oooooooooo03Gooooo0P000?lBooooo`;o0?l02@3o000Looooo`80003o7Oooool2
0?l000;o0?l06Oooool80000oaKooooo0`3o00000`00o`3oooooooooo`0`ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0=Oooool20000ocWooooo0P000?lMooooo`80o`000ol0o`0foooo
o`80o`000P00o`0booooo`4000000Oooool001_ooooo00<00000ooooooooool0=Oooool30000ocOo
oooo0`000?lMooooo`<0o`000_l0o`0fooooo`80o`000P00o`0booooo`4000000Oooool001_ooooo
00<00000o`000?ooool0=_ooool20000ocOooooo0P000?lOooooo`80o`000_l0o`0fooooo`80o`00
0P00o`0aooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0fooooo`80003o=ooo
ool20000oaoooooo0P3o0003o`3o03Cooooo0`3o00000`00o`3oooooooooo`0aooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool0=_ooool20000ocKooooo0`000?lOooooo`<0o`000_l0o`0d
ooooo`80o`000P00o`0cooooo`4000000Oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00003ooooo`?o00001Oooool00`00003oooooooooo`0fooooo`<0003o=Oooool20000
ob7ooooo0P3o0002o`3o03Cooooo0P3o0002003o03?ooooo0@000001ooooo`0000Goooooo`000?oo
ooooooooo`000009ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`0300000?oooooooooo03Oooooo0P000?leooooo`80003o8Oooool20?l000;o0?l0<oooool3
0?l000800?l0<oooool10000007ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo03Oooooo0P000?le
ooooo`80003o8Oooool30?l000;o0?l0<_ooool20?l000800?l0=?ooool10000007ooooo00001Ooo
oooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`0300000?l0003ooooo03Oooooo0P000?ldooooo`<0003o8_ooool20?l000;o0?l0<_ooool2
0?l000800?l0<oooool1o`00004000000Oooool00005ooooool0003oooooooooool000002Oooool0
1?l0003oooooooooooooool4o`0000Gooooo00<00000ooooooooool0=oooool30000oc?ooooo0P00
0?lSooooo`80o`000_l0o`0booooo`80o`000P00o`0dooooo`4000000Oooool00005ooooool0003o
ooooooooool000002?ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00`00003ooooooooo
o`0hooooo`80003o<oooool20000ob?ooooo0P3o0003o`3o033ooooo0`3o00000`00o`3ooooooooo
o`0cooooo`4000000Oooool000;ooooo0_l0000:ooooo`04o`000?ooooooooooooooo`Go00001?oo
ool00`00003oooooooooo`0hooooo`80003o<_ooool30000ob?ooooo0`3o0002o`3o033ooooo0P3o
0002003o03Gooooo0@000001ooooo`006oooool00`00003oooooooooo`0hooooo`<0003o<Oooool2
0000obGooooo0P3o0002o`3o033ooooo0P3o0002003o03Gooooo0@000001ooooo`006oooool00`00
003oooooooooo`0iooooo`80003o<Oooool20000obGooooo0P3o0003o`3o02oooooo0P3o0002003o
03Gooooo0@000001ooooo`006oooool00`00003o0000ooooo`0iooooo`80003o<Oooool20000obGo
oooo0`3o0002o`3o02kooooo0`3o00000`00o`3oooooooooo`0cooooo`7o00000@000001ooooo`00
6oooool00`00003oooooooooo`0iooooo`80003o<?ooool30000obKooooo0P3o0002o`3o02kooooo
0P3o0002003o03Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0iooooo`<0003o;ooo
ool20000obOooooo0P3o0002o`3o02kooooo0P3o0002003o03Kooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0jooooo`80003o;oooool20000obOooooo0`3o0002o`3o02gooooo0P3o0002
003o03Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0jooooo`80003o;oooool20000
obSooooo0P3o0002o`3o02cooooo0`3o00000`00o`3oooooooooo`0eooooo`4000000Oooool001_o
oooo00<00000o`000?ooool0>_ooool20000obkooooo0`000?lXooooo`80o`000_l0o`0/ooooo`80
o`000P00o`0fooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0jooooo`<0003o
;Oooool20000obWooooo0P3o0003o`3o02_ooooo0P3o0002003o03Oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0kooooo`80003o;Oooool20000obWooooo0`3o0002o`3o02[ooooo0`3o
00000`00o`3oooooooooo`0fooooo`4000000Oooool001_ooooo00<00000ooooooooool0>oooool2
0000obcooooo0`000?lZooooo`80o`000_l0o`0Zooooo`80o`000P00o`0hooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0>oooool30000ob_ooooo0P000?l[ooooo`80o`000ol0o`0Yoooo
o`80o`000P00o`0hooooo`4000000Oooool001_ooooo00<00000ooooooooool0??ooool20000ob_o
oooo0P000?l[ooooo`<0o`000_l0o`0Yooooo`80o`0000<00?l0ooooooooool0=oooool10000007o
oooo000Kooooo`0300000?l0003ooooo03cooooo0P000?l[ooooo`80003o;?ooool20?l000;o0?l0
:?ooool30?l00003003o0?oooooooooo03Kooooo0Ol000010000007ooooo000Kooooo`0300000?oo
oooooooo03cooooo0P000?lZooooo`<0003o;?ooool20?l000;o0?l0:?ooool20?l000800?l0>Ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo03cooooo0`000?lYooooo`80003o;Oooool3
0?l000;o0?l09oooool20?l000800?l0>Oooool10000007ooooo000Kooooo`0300000?oooooooooo
03gooooo0P000?lYooooo`80003o;_ooool20?l000;o0?l09_ooool30?l00003003o0?oooooooooo
03Sooooo0@000001ooooo`006oooool00`00003oooooooooo`0mooooo`80003o:?ooool30000obko
oooo0P3o0002o`3o02Kooooo0P3o0002003o03[ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0mooooo`80003o:?ooool20000oboooooo0P3o0003o`3o02Gooooo0P3o0002003o03[ooooo
0@000001ooooo`006oooool00`00003o0000ooooo`0mooooo`<0003o9oooool20000oboooooo0`3o
0002o`3o02Gooooo0P3o00000`00o`3oooooooooo`0hooooo`7o00000@000001ooooo`006oooool0
0`00003oooooooooo`0nooooo`80003o9_ooool30000oc3ooooo0P3o0002o`3o02Cooooo0`3o0000
0`00o`3oooooooooo`0iooooo`4000000Oooool001_ooooo00<00000ooooooooool0?_ooool20000
obKooooo0P000?laooooo`80o`000_l0o`0Tooooo`80o`000P00o`0kooooo`4000000Oooool000So
oooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00`00003oooooooooo`0noooo
o`<0003o9Oooool20000oc7ooooo0`3o0002o`3o02?ooooo0P3o00000`00o`3oooooooooo`0joooo
o`4000000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo03oooooo0P000?lUooooo`80003o<_ooool20?l000;o0?l08_ooool3
0?l00003003o0?oooooooooo03[ooooo0@000001ooooo`001oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0?oooool20000obCooooo0`000?lb
ooooo`80o`000_l0o`0Rooooo`80o`000P00o`0looooo`4000000Oooool000Oooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`03ooooo`0300000?l0003ooooo03oooooo0P000?lT
ooooo`80003o<oooool20?l000?o0?l08Oooool20?l000800?l0>oooool1o`00004000000Oooool0
00Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<0
0000ooooooooool0?oooool30000ob?ooooo0P000?lcooooo`<0o`000_l0o`0Qooooo`80o`0000<0
0?l0ooooooooool0>oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo043ooooo0P000?lRooooo`<0003o
=?ooool20?l000;o0?l08?ooool30?l00003003o0?oooooooooo03_ooooo0@000001ooooo`002?oo
ool2o`0000Wooooo0ol00005ooooo`0300000?oooooooooo043ooooo0P000?lRooooo`80003o=Ooo
ool20?l000?o0?l07oooool20?l000800?l0?Oooool10000007ooooo000Kooooo`0300000?oooooo
oooo043ooooo0P000?lRooooo`80003o=Oooool30?l000;o0?l07oooool20?l00003003o0?oooooo
oooo03cooooo0@000001ooooo`006oooool00`00003o0000ooooo`10ooooo`<0003o8?ooool30000
ocKooooo0P3o0002o`3o01kooooo0`3o00000`00o`3oooooooooo`0kooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`11ooooo`80003o8?ooool20000ocOooooo0P3o0002o`3o01ko
oooo0P3o0002003o03kooooo0@000001ooooo`006oooool00`00003oooooooooo`11ooooo`80003o
8?ooool20000ocOooooo0`3o0002o`3o01gooooo0P3o0002003o03kooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`11ooooo`<0003o7_ooool30000ocSooooo0P3o0002o`3o01gooooo0P3o
00000`00o`3oooooooooo`0mooooo`4000000Oooool001_ooooo00<00000ooooooooool0@_ooool2
0000oakooooo0P000?liooooo`80o`000_l0o`0Looooo`<0o`0000<00?l0ooooooooool0?Oooool1
0000007ooooo000Kooooo`0300000?oooooooooo04;ooooo0P000?lNooooo`80003o>Oooool20?l0
00;o0?l07?ooool20?l000800?l0?oooool10000007ooooo000Kooooo`0300000?l0003ooooo04;o
oooo0`000?lMooooo`80003o>Oooool30?l000;o0?l06oooool20?l00003003o0?oooooooooo03go
oooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo04?ooooo0P000?lLooooo`<0003o
>_ooool20?l000;o0?l06_ooool30?l00003003o0?oooooooooo03kooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`13ooooo`80003o7?ooool20000oc_ooooo0P3o0002o`3o01[ooooo0P3o
0002003o043ooooo0@000001ooooo`006oooool00`00003oooooooooo`13ooooo`<0003o6oooool2
0000oc_ooooo0`3o0002o`3o01Wooooo0P3o00000`00o`3oooooooooo`0oooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0A?ooool20000oa[ooooo0`000?llooooo`80o`000_l0o`0Hoooo
o`<0o`0000<00?l0ooooooooool0?oooool10000007ooooo000Kooooo`0300000?oooooooooo04Co
oooo0P000?lJooooo`80003o?Oooool20?l000;o0?l06?ooool20?l000800?l0@Oooool10000007o
oooo000Kooooo`0300000?l0003ooooo04Cooooo0`000?lIooooo`80003o?Oooool20?l000;o0?l0
5oooool30?l00003003o0?oooooooooo03oooooo0Ol000010000007ooooo000Kooooo`0300000?oo
oooooooo04Gooooo0P000?lHooooo`<0003o?Oooool30?l000;o0?l05_ooool20?l000800?l0@_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo04Gooooo0P000?lHooooo`80003o?oooool2
0?l000;o0?l05_ooool20?l000800?l0@_ooool10000007ooooo000Kooooo`0300000?oooooooooo
04Gooooo0P000?lHooooo`80003o?oooool20?l000;o0?l05Oooool30?l00003003o0?oooooooooo
047ooooo0@000001ooooo`006oooool00`00003oooooooooo`15ooooo`<0003o5_ooool30000ocoo
oooo0`3o0002o`3o01Cooooo0P3o0002003o04?ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`16ooooo`80003o5_ooool20000od7ooooo0P3o0002o`3o01?ooooo0`3o0002003o04?ooooo
0@000001ooooo`006oooool00`00003o0000ooooo`16ooooo`80003o5Oooool30000od7ooooo0P3o
0003o`3o01;ooooo0P3o0002003o04?ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooo
oooo04Kooooo0`000?lDooooo`80003o@_ooool30?l000;o0?l04Oooool30?l000800?l0A?ooool1
0000007ooooo000Kooooo`0300000?oooooooooo04Oooooo0P000?lCooooo`<0003o@oooool20?l0
00;o0?l04Oooool20?l000800?l0AOooool10000007ooooo0002ooooo`;o00001?ooool01?l0003o
ooooooooooooool5o`0000;ooooo0ol00005ooooo`0300000?oooooooooo04Oooooo0P000?lCoooo
o`80003oA?ooool30?l000;o0?l04?ooool20?l000800?l0AOooool10000007ooooo00001Ooooooo
0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00<00000ooooooooool0Aoooool30000oa7ooooo0`000?m5ooooo`80o`000_l0
o`0?ooooo`<0o`000P00o`15ooooo`4000000Oooool00005ooooool0003oooooooooool000002Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0B?oo
ool30000oa3ooooo0P000?m6ooooo`<0o`000_l0o`0>ooooo`80o`000P00o`15ooooo`7o00000@00
0001ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`19ooooo`80003o4?ooool20000odOooooo0P3o
0003o`3o00cooooo0`3o0002003o04Kooooo0@000001ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`0300000?oooooooooo04Wo
oooo0`000?l>ooooo`<0003oAoooool30?l000;o0?l03?ooool20?l000<00?l0A_ooool10000007o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Oo0000ooooooooooooooooo`000?oooooo
000000Sooooo00<00000ooooooooool0B_ooool20000o`kooooo0P000?m9ooooo`80o`000ol0o`0;
ooooo`80o`000P00o`17ooooo`4000000Oooool000;ooooo0_l00009ooooo`?o00000_ooool5o`00
00Cooooo00<00000ooooooooool0B_ooool30000o`cooooo0`000?m9ooooo`<0o`000_l0o`0:oooo
o`<0o`0000<00?l0ooooooooool0A_ooool10000007ooooo000Kooooo`0300000?oooooooooo04_o
oooo0`000?l:ooooo`<0003oBoooool30?l000;o0?l02Oooool20?l000800?l0B?ooool10000007o
oooo000Kooooo`0300000?l0003ooooo04cooooo0P000?l9ooooo`<0003oCOooool30?l000;o0?l0
1_ooool40?l00003003o0?oooooooooo04Kooooo0Ol000010000007ooooo000Kooooo`0300000?oo
oooooooo04cooooo0`000?l7ooooo`<0003oCoooool20?l000?o0?l01?ooool40?l000800?l0BOoo
ool10000007ooooo000Kooooo`0300000?oooooooooo04gooooo0`000?l6ooooo`80003oD?ooool4
0?l000;o0?l00_ooool30?l00003o`3o0000o`000?l004[ooooo0@000001ooooo`006oooool00`00
003oooooooooo`1>ooooo`X0003oDOooool90?l000?o0?l0Boooool10000007ooooo000Kooooo`03
00000?oooooooooo04oooooo20000?mCooooo`P0o`000_l0o`1<ooooo`4000000Oooool001_ooooo
00<00000ooooooooool0DOooool30000oeSooooo0`3o0002o`3o04oooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`7o00000@000001ooooo`006ooooooo000000D000000Oooool0
0?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.35193, -0.0316581, \
0.0404426, 0.00174106}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{662, 627},
WindowMargins->{{52, Automatic}, {Automatic, 1}},
ShowSelection->True,
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 52, 0, 62, "Title"],
Cell[1809, 53, 256, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2090, 63, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2151, 67, 64, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2240, 71, 62, 0, 43, "Subsubsection"],
Cell[2305, 73, 76, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2418, 79, 66, 0, 43, "Subsubsection"],
Cell[2487, 81, 342, 6, 111, "Input"],
Cell[2832, 89, 307, 5, 127, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3176, 99, 84, 1, 43, "Subsubsection"],
Cell[3263, 102, 325, 5, 111, "Input"],
Cell[3591, 109, 230, 4, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3870, 119, 50, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3945, 123, 45, 0, 43, "Subsubsection"],
Cell[3993, 125, 268, 4, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4298, 134, 49, 0, 43, "Subsubsection"],
Cell[4350, 136, 183, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4570, 144, 73, 2, 43, "Subsubsection"],
Cell[4646, 148, 222, 4, 63, "Input"],
Cell[4871, 154, 634, 11, 143, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5554, 171, 48, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5627, 175, 45, 0, 43, "Subsubsection"],
Cell[5675, 177, 508, 8, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6220, 190, 89, 3, 43, "Subsubsection"],
Cell[6312, 195, 517, 8, 143, "Input"],
Cell[6832, 205, 1247, 22, 239, "Input"],
Cell[8082, 229, 513, 8, 143, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8632, 242, 63, 0, 43, "Subsubsection"],
Cell[8698, 244, 378, 7, 111, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9137, 258, 196, 8, 39, "Section"],

Cell[CellGroupData[{
Cell[9358, 270, 50, 0, 43, "Subsubsection"],
Cell[9411, 272, 315, 5, 111, "Input"],
Cell[9729, 279, 177, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9943, 287, 48, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[10016, 291, 215, 4, 63, "Input"],
Cell[10234, 297, 25456, 750, 186, 6545, 512, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35739, 1053, 65, 0, 43, "Subsubsection"],
Cell[35807, 1055, 116, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35960, 1062, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[36034, 1066, 74, 1, 47, "Input"],
Cell[36111, 1069, 7997, 304, 81, 3761, 247, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44157, 1379, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[44279, 1386, 86, 1, 47, "Input"],
Cell[44368, 1389, 85476, 2238, 296, 19532, 1419, "GraphicsData", \
"PostScript", "Graphics"],
Cell[129847, 3629, 143, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130027, 3637, 76, 1, 47, "Input"],
Cell[130106, 3640, 165433, 3258, 242, 72585, 2107, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[295576, 6903, 102, 2, 47, "Input"],
Cell[295681, 6907, 57, 1, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[295775, 6913, 102, 2, 47, "Input"],
Cell[295880, 6917, 58, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[295987, 6924, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[296061, 6928, 554, 11, 127, "Input"],
Cell[296618, 6941, 37943, 1102, 186, 10365, 757, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

