(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    755204,      16664]*)
(*NotebookOutlinePosition[    755903,      16688]*)
(*  CellTagsIndexPosition[    755859,      16684]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Varying the number of component densities", "Title"],

Cell[TextData[{
  "This notebook illustrates Gaussian mixture modeling for some 2d synthetic \
data, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Specialized data generation and visualization functions", "Subsection"],

Cell[BoxData[
    \(\(AnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {x1\  - \ r2, \ 
              x1 + \ r2}; \[IndentingNewLine]range2\  = \ {x2\  - \ r2, \ 
              x2\  + \ r2}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  < \ 
                  r2\  && \ tst\  > \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AntiAnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {0, \ 
              1}; \[IndentingNewLine]range2\  = \ {0, 
              1}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  > \ 
                  r2\  || \ tst\  < \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Region definitions", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(c1\  = \ { .5,  .5};\) (*\ 
      center\ of\ annular\ region\ *) \[IndentingNewLine]
    \(rr1\  = \  .12;\) (*\ inner\ radius\ *) \[IndentingNewLine]
    \(rr2\  = \  .35;\)\)\( (*\ outer\ radius\ *) \)\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(DrawAnnularRegion2[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          color2_:  White, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {color2, Disk[center, r1]}}], \ 
            AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{class1Color, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, class2Color, \ class1Color, nS]\ , 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize annular region in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Draw annular region in 2d", "Subsubsection"],

Cell[BoxData[
    \(\(DrawAnnularRegion[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {GrayLevel[1. ], 
                  Disk[center, r1]}}], \ AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for annular region", "Subsubsection"],

Cell[BoxData[
    \(\(AnnularAllPlot[center_, \ r1_, \ 
          r2_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ DrawAnnularRegion[center, 
              rr1, rr2, \ pr, LightPink, \ nF, 
              nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["All-in-one EM function (annular region)", "Subsection"],

Cell[BoxData[
    \(\(EMAll1[data_, k_, \ 
          scalar_:  False] := \[IndentingNewLine]Module[{init, em, \ 
            flag}, \[IndentingNewLine]flag = True; \[IndentingNewLine]While[
            flag, \[IndentingNewLine]init\  = \ \[IndentingNewLine]If[
                scalar \[Equal] 
                  False, \[IndentingNewLine]EMInitializationFull[data, 
                  k], \[IndentingNewLine]EMInitializationScalar[data, 
                  k]]; \[IndentingNewLine]em\  = \ 
              EM[data, init, 0.001]; \[IndentingNewLine]If[
              Position[em, \ Indeterminate] \[Equal] {}, 
              flag = False]]; \[IndentingNewLine]{AnnularAllPlot[c1, rr1, 
              rr2, Last[em]], \ 
            em\  // \ Last}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Local plot of log-likelihood", "Subsection"],

Cell[BoxData[
    \(\(PlotLogLikelihood2[em_, \ xd_, \ 
          opt___] := \[IndentingNewLine]Module[{logp, \ traj, \ g1, 
            g2}, \[IndentingNewLine]logp\  = \ \(LogLikelihoodMixtureDataSet[
                  xd, #] &\)\  /@ \ em; \[IndentingNewLine]traj\  = 
            Transpose[{Table[i, \ {i, 2, Length[logp] + 1}], 
                logp}]; \[IndentingNewLine]g1\  = \ 
            ListPlot[traj, \ \ Axes -> False, \ Frame \[Rule] True, 
              PlotRange \[Rule] All, PlotJoined \[Rule] True, 
              DisplayFunction\  -> \ Identity]; 
          g2\  = \ Show[
              Graphics[\({Red, PointSize[ .02], \ 
                      Point[#]} &\)\  /@ \ \ traj], \ 
              DisplayFunction\  -> \ Identity, \ Frame \[Rule] True, 
              PlotRange \[Rule] All, opt]; \[IndentingNewLine]Show[\ g1, \ 
            g2, \ yS, \ AspectRatio\  -> 1/GoldenRatio, \ 
            GridLines -> Automatic, \ opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Special data generation functions (interlocking-polygonal \
regions)\
\>", "Subsection"],

Cell[BoxData[
    \(\(withinRectangle[p_, \ r_] := \n\t
        Module[{rx1, \ ry1, \ rx2, \ ry2, \ x, 
            y}, \n\t\t{rx1, \ ry1, \ rx2, \ ry2}\  = \ r; \n\t\t{x, y}\  = \ 
            p; \n\t\tIf[
            rx1\  < \ x\  < \ rx2\  && \ 
              ry1\  < \ y\  < \ ry2, \n\t\t\tTrue, \ False]];\)\)], "Input"],

Cell[BoxData[
    \(withinRegion2[p_] := \n\t
      If[\n\t\t\t\ withinRectangle[p, \ {0.2, \ 0.6, \ 0.8, \ 0.8}]\  || \ 
          withinRectangle[p, \ {0.2, \ 0.2, \ 0.8, \ 0.4}]\  || \ 
          withinRectangle[p, \ {0.8, \ 0.0, \ 1.0, \ 1.0}], \n\t\tTrue, \ 
        False]\)], "Input"],

Cell[BoxData[
    \(\(region1Data[n_] := \n\t
        Module[{count, \ xd, p}, \n\t\tcount\  = \ 1; \n\t\txd\  = \ 
            Table[0, \ {n}]; \n\t\tWhile[
            count\  <= \ 
              n, \n\t\t\tp\  = \ {Random[Real, \ {0. , 1. }], \ 
                Random[Real, \ {0. , 1. }]}; \n\t\t\tIf[
              withinRegion2[p] == 
                False, \n\t\t\t\txd[\([\(count++\)]\)]\  = \ p]]; \n\t
          xd];\)\)], "Input"],

Cell[BoxData[
    \(\(region2Data[
          n_] := \n\t\tModule[{count, \ xd, p}, \n\t\tcount\  = \ 
            1; \n\t\txd\  = \ Table[0, \ {n}]; \n\t\tWhile[
            count\  <= \ 
              n, \n\t\t\tp\  = \ {Random[Real, \ {0. , 1. }], \ 
                Random[Real, \ {0. , 1. }]}; \n\t\t\tIf[
              withinRegion2[p] == True, \n\t\t\t\txd[\([\(count++\)]\)]\  = \ 
                p]]; \n\txd];\)\)], "Input"],

Cell[BoxData[
    \(\(RR\  := \ Random[Real, \ {0. , \ 1. }];\)\)], "Input"],

Cell[BoxData[
    \(\(TransformProbabilityVector[prob_] := \n\t
        Module[{s\  = \ 0, \ len}, \n\t\tlen\  = \ 
            Length[prob] - 1; \n\t\tJoin[
            Table[s\  = \ s\  + \ prob[\([i]\)], \ {i, \ 1, \ 
                len}], \ {1}]];\)\)], "Input"],

Cell[BoxData[
    \(\(PickOne[\ priors_] := \n\t
        Module[{r}, \n\t\tr\  = \ 
            RR; \n\t\((Position[\(\((r\  <= \ #)\) &\)\  /@ \ 
                    TransformProbabilityVector[priors], \ True]\  // \ 
                Flatten)\)\  // \ First];\)\)], "Input"],

Cell[BoxData[
    \(\(GenerateFromMixturePDF[{mu_, \ sigma_, \ priors_}] := \n\t
        Module[{k, \ d, \ class}, \n\t\tk\  = \ Length[priors]; \n\t\td\  = \ 
            Length[mu[\([1]\)]]; \n\t\ \ class\  = \ 
            PickOne[priors]; \n\t\ \ Random[
            MultinormalDistribution[mu[\([class]\)], \ 
              sigma[\([class]\)]\ IdentityMatrix[d]]]\ \n\t\t];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot2\  := 
        Show[Graphics[{{class1Color, 
                Rectangle[{0, 0}, {1, 1}]}, \ {class2Color, \ 
                Rectangle[{0.8, 0}, {1, 1}], \ 
                Rectangle[{0.2, 0.6}, {0.8, 0.8}], \ 
                Rectangle[{0.2, 0.2}, \ {0.8, 0.4}]}}], \ 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize interlocking regions in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Saved data definition", "Subsubsection"],

Cell[BoxData[
    \(\(poly\  = {Partition[\ {0, 0, 8, 0, 8, 2, 2, 2, 2, 4, 8, 4, 8, 6, 2, 
                6, 2, 8, 8, 8, 8, 10, 0, 10}, 2]/10. };\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Draw polygonal region", "Subsubsection"],

Cell[BoxData[
    \(\(drawPolygonalRegion[polyL_, \ pr_, \ color_:  LightPink, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[Graphics[{color, Polygon\  /@ \ polyL}], 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, \ 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
            opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(drawAntiPolygonalRegion[polyL_, \ pr_, \ color_:  LightPink, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[
            Graphics[{{color, 
                  Rectangle[{pr[\([1, 1]\)], 
                      pr[\([2, 1]\)]}, {pr[\([1, 2]\)], 
                      pr[\([2, 2]\)]}]}, {RGBColor[1, 1, 1], 
                  Polygon\  /@ \ polyL}}], 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, \ 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
            opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for polygonal region", "Subsubsection"],

Cell[BoxData[
    \(\(PolygonalAllPlot[
          polyL_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ drawPolygonalRegion[
              polyL, \ pr, LightPink, \ nF, nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for polygonal region", "Subsubsection"],

Cell[BoxData[
    \(\(AntiPolygonalAllPlot[
          polyL_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ drawAntiPolygonalRegion[
              polyL, \ pr, LightPink, \ nF, nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["All-in-one EM function (interlocking polygonal regions)", "Subsection"],

Cell[BoxData[
    \(\(EMAll2[data_, k_, \ 
          scalar_:  False] := \[IndentingNewLine]Module[{init, em, \ 
            flag}, \[IndentingNewLine]flag = True; \[IndentingNewLine]While[
            flag, \[IndentingNewLine]init\  = \ \[IndentingNewLine]If[
                scalar \[Equal] 
                  False, \[IndentingNewLine]EMInitializationFull[data, 
                  k], \[IndentingNewLine]EMInitializationScalar[data, 
                  k]]; \[IndentingNewLine]em\  = \ 
              EM[data, init, 0.001]; \[IndentingNewLine]If[
              Position[em, \ Indeterminate] \[Equal] {}, 
              flag = False]]; \[IndentingNewLine]{PolygonalAllPlot[poly, 
              em // Last], \ 
            em\  // \ Last}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(EMAll3[data_, k_, \ 
          scalar_:  False] := \[IndentingNewLine]Module[{init, em, \ 
            flag}, \[IndentingNewLine]flag = True; \[IndentingNewLine]While[
            flag, \[IndentingNewLine]init\  = \ \[IndentingNewLine]If[
                scalar \[Equal] 
                  False, \[IndentingNewLine]EMInitializationFull[data, 
                  k], \[IndentingNewLine]EMInitializationScalar[data, 
                  k]]; \[IndentingNewLine]em\  = \ 
              EM[data, init, 0.001]; \[IndentingNewLine]If[
              Position[em, \ Indeterminate] \[Equal] {}, 
              flag = False]]; \[IndentingNewLine]{AntiPolygonalAllPlot[poly, 
              em // Last], \ 
            em\  // \ Last}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Idealized plot (annular region)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?o
ooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0
oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooon60?ooO`P0OoooQ03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooNP3ooglP07ooogP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooogD0oomo:@1ooomd0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom`0?ooOc<0OoooK`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
KP3ooglg07ooofd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofX0oomo@01o
oomX0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomW0?ooOdD0OoooIP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooI@3oogm907ooof@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooof<0oomoC@1ooomR0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomQ0?ooOe40OoooH03oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooG`3oogmF07oooed0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooe`0oomoF`1ooomK0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomJ0?oo
Oel0OoooF@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF03oogmS07oooeL0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooeL0oomoI@1ooomF0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomF0?ooOfL0OoooE@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooE03oogm[07oooe<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooe80oomoK`1ooomA0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomA0?ooOg40OoooD03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
D03oogmc07ooodl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodh0oomoM`1o
oom=0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom=0?ooOgP0OoooC@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooC@3oogmi07oood`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood/0oomoO@1ooom:0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom:0?ooOgl0OoooB@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooodP0oomoP`1ooom70?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom70?oo
OhD0OoooAP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodD0oomoR@1ooom40?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom40?ooOh/0Oooo@`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooood80oomoS`1ooom10?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom10?ooOi00Oooo@@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
@@3oognA07oood00oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocl0oomoU@1o
ooln0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooln0?ooOiH0Oooo?P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo?P3oognG07ooocd0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocd0oomoV@1oooll0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooooll0?ooOi/0Oooo>`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo>`3oognL07oooc/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc/0oomoW@1ooolj0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolj0?oo
Oih0Oooo>P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>P3oognO07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocT0oomoX@1ooolh0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolh0?ooOj<0Oooo=`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oognT07ooocL0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomoY@1ooolf0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=P3oognW07ooocD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocD0oomoZ01o
oole0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=03oognZ07oooc@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooc@0oomoZ`1ooolc0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolc0?ooOj`0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<`3oogn/07oooc<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc<0oomo[@1ooolb0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolb0?oo
Ojh0Oooo<P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<P3oogn_07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc40oomo/01ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooola0?ooOk40Oooo<03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<03oognb07oooc00oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc00oomo/`1oool_0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool_0?ooOeD0Oooo2`3oogmD07ooobl0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm?07oooaX0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOdd0Oooo7@3oogm<07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobh0oomoC01ooolQ0?ooOdT0Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;P3oogm:07ooob@0oomoB01oool^0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool^0?ooOdL0Oooo:03oogm807ooobd0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobd0oomoA`1ooolZ0?ooOdL0Oooo;@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo;@3oogm607ooob`0oomoA`1oool/0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00oooool/0?ooOdL0Oooo;@3oogm607ooob`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooob`0oomoAP1oool_0?ooOdD0Oooo;03oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo;03oogm507oooc40oomoA01oool/0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00oooool/0?ooOd@0Oooo<P3oogm407ooob`0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooob`0oomo@`1ooold0?ooOd@0Oooo:`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm407ooocD0oomo@`1oool[0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo=`3oogm207ooob/0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?ooOd40Oooo
:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocT0oomo@P1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd80Oooo>`3oogm1
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?oo
Od40Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0
oomo@@1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo
?P3oogm007ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01o
ooln0?ooOd00Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm0
07oooch0oomo@01ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?oo
Od00Oooo?`3ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0
oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo:P3ooglo07oood40oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolZ0?ooOch0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobX0oomo?`1ooom10?ooOch0Oooo:P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo?`3ooglo07ooobX0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01oooln0?ooOd00Oooo:P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm007oooch0oomo@01ooolZ0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd40Oooo?@3oogm007ooobX0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?ooOd40Oooo
:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0oomo@@1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd40Oooo>P3oogm2
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?oo
Od40Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocP0
oomo@P1oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo
=P3oogm307ooob/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomoA01o
oole0?ooOd<0Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo;03oogm4
07oooc<0oomoA01oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool/0?oo
OdD0Oooo<@3oogm407ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob`0
oomoA@1oool`0?ooOdD0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
;03oogm607ooobh0oomoAP1oool/0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
ool/0?ooOdL0Oooo;03oogm707ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobd0oomoB01ooolY0?ooOdP0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo;@3oogm907ooobL0oomoB01oool]0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool^0?ooOd/0Oooo8`3oogm907ooobd0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobh0oomoC@1ooolO0?ooOdX0Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm>07oooa/0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOe40Oooo5`3oogm>07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;`3oogmF07ooo`T0oomoE@1oool_0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool_0?ooOk@0Oooo;`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<03oognc07ooobl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc00oomo/P1oool`0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooola0?oo
Ok40Oooo<03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<@3oogn`07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc80oomo[`1ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolb0?ooOjh0Oooo<P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<`3oogn]07oooc80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc<0oomo[01ooolc0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooold0?ooOj/0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=03oognZ07oooc@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc@0oomoZP1o
oold0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=@3oognX07ooocD0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocH0oomoY`1ooole0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oognU07ooocH0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocP0oomoX`1ooolg0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooli0?oo
Oj40Oooo>03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>@3oognP07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocX0oomoW`1oooli0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolj0?ooOih0Oooo>P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo>`3oognM07ooocX0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc`0oomoV`1ooolk0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolm0?ooOiT0Oooo?03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
?@3oognH07ooocd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooch0oomoU`1o
oolm0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom00?ooOi<0Oooo?`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo@03oognB07oood00oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood40oomoT@1ooom00?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom20?ooOhl0Oooo@@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooood@0oomoR`1ooom30?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom50?oo
OhT0OoooA03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodL0oomoQ@1ooom60?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom80?ooOh<0OoooA`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooodX0oomoO`1ooom90?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom<0?ooOg/0OoooB`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
C03oogmj07oood`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodd0oomoN@1o
oom<0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom?0?ooOgD0OoooCP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooD03oogmc07ooodl0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooe40oomoL@1ooom@0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomC0?ooOfd0OoooDP3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooE@3oogmY07oooe@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooeH0oomoI`1ooomE0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomG0?oo
OfD0OoooEP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF@3oogmQ07oooeP0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooe/0oomoG@1ooomJ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomM0?ooOeT0OoooG03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooH03oogmD07oooeh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooof80oomoC`1ooomQ0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomT0?ooOd/0OoooH`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
IP3oogm707ooofD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofP0oomo@`1o
oomW0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom[0?ooOch0OoooJ@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooK`3oogle07ooofh0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooog40oomo<@1ooom`0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomf0?ooObL0OoooM@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooN`3ooglN07ooogT0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooohL0oomo1P1ooon50?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?oo
Oa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the number of Gaussians (annular region)", "Section"],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points for training and test data", "Subsubsection"],

Cell[BoxData[{
    \(\(n1 = 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2 = 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = 
        AnnularRegion[c1, \ rr1, \ rr2, \ n1];\)\), "\[IndentingNewLine]", 
    \(\(data2\  = AnnularRegion[c1, \ rr1, \ rr2, \ n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize training data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.55459 .75199 Mdot
.41903 .67524 Mdot
.32433 .32917 Mdot
.1953 .57768 Mdot
.50481 .31519 Mdot
.44971 .1844 Mdot
.48728 .72111 Mdot
.41444 .60137 Mdot
.80108 .50252 Mdot
.47403 .23453 Mdot
.53891 .67042 Mdot
.30656 .7485 Mdot
.26812 .32768 Mdot
.51034 .17498 Mdot
.66156 .30014 Mdot
.33113 .42217 Mdot
.58674 .79871 Mdot
.30252 .43565 Mdot
.6288 .45306 Mdot
.67163 .35798 Mdot
.24675 .62578 Mdot
.23161 .44933 Mdot
.41067 .2818 Mdot
.59225 .82479 Mdot
.56323 .7174 Mdot
.27232 .2807 Mdot
.34769 .46562 Mdot
.44383 .76586 Mdot
.2578 .68298 Mdot
.76504 .47011 Mdot
.18306 .39052 Mdot
.51124 .34518 Mdot
.46178 .80245 Mdot
.76213 .36353 Mdot
.50102 .64718 Mdot
.7652 .32323 Mdot
.57437 .70075 Mdot
.78486 .60061 Mdot
.47344 .17463 Mdot
.44724 .62725 Mdot
.50858 .78532 Mdot
.58959 .57865 Mdot
.24377 .58288 Mdot
.32171 .41651 Mdot
.70301 .40813 Mdot
.76129 .65066 Mdot
.2739 .54113 Mdot
.74147 .52017 Mdot
.66979 .75702 Mdot
.38975 .57799 Mdot
.68433 .24595 Mdot
.55473 .22473 Mdot
.43257 .24657 Mdot
.69485 .65973 Mdot
.68524 .53081 Mdot
.56821 .83281 Mdot
.1921 .4889 Mdot
.64548 .75405 Mdot
.44746 .68685 Mdot
.1841 .39078 Mdot
.59575 .18398 Mdot
.342 .70312 Mdot
.61693 .71344 Mdot
.62695 .52914 Mdot
.71851 .63765 Mdot
.66128 .65096 Mdot
.35833 .32733 Mdot
.53182 .17667 Mdot
.33109 .77969 Mdot
.37217 .36313 Mdot
.50861 .67042 Mdot
.67865 .76079 Mdot
.52933 .80691 Mdot
.30295 .65377 Mdot
.31385 .5772 Mdot
.78482 .37093 Mdot
.44489 .64545 Mdot
.60937 .7278 Mdot
.41638 .74006 Mdot
.28905 .29434 Mdot
.41887 .7961 Mdot
.82924 .48371 Mdot
.67225 .74965 Mdot
.41303 .18193 Mdot
.73056 .53558 Mdot
.80184 .49396 Mdot
.44253 .73327 Mdot
.5966 .73634 Mdot
.54411 .71114 Mdot
.33459 .78338 Mdot
.55801 .38429 Mdot
.7289 .47778 Mdot
.56412 .75663 Mdot
.60542 .41953 Mdot
.5558 .20893 Mdot
.59243 .62941 Mdot
.3354 .33546 Mdot
.66123 .79595 Mdot
.62053 .7943 Mdot
.73477 .47338 Mdot
.27682 .25763 Mdot
.73643 .53118 Mdot
.51454 .68124 Mdot
.33749 .47911 Mdot
.76943 .31563 Mdot
.27946 .25392 Mdot
.26506 .36281 Mdot
.50207 .30275 Mdot
.42411 .34855 Mdot
.61043 .67251 Mdot
.30415 .24779 Mdot
.71714 .29819 Mdot
.63275 .40969 Mdot
.53651 .66221 Mdot
.71063 .35786 Mdot
.23538 .38656 Mdot
.67614 .67941 Mdot
.45386 .82989 Mdot
.68657 .31424 Mdot
.2616 .3968 Mdot
.47199 .83025 Mdot
.43292 .35385 Mdot
.6045 .62926 Mdot
.3544 .81042 Mdot
.6633 .58703 Mdot
.39847 .67778 Mdot
.25804 .53365 Mdot
.47353 .17995 Mdot
.28861 .51759 Mdot
.69883 .32061 Mdot
.39704 .40672 Mdot
.5013 .35333 Mdot
.57688 .66283 Mdot
.2597 .51868 Mdot
.58973 .75522 Mdot
.31509 .67078 Mdot
.16833 .49219 Mdot
.76844 .61953 Mdot
.22647 .45579 Mdot
.5683 .25932 Mdot
.56248 .36357 Mdot
.81589 .45149 Mdot
.30724 .75614 Mdot
.25019 .61901 Mdot
.25528 .54369 Mdot
.59073 .18755 Mdot
.21237 .3725 Mdot
.25108 .41319 Mdot
.66409 .32544 Mdot
.67086 .76612 Mdot
.49606 .32596 Mdot
.39765 .62541 Mdot
.35003 .67835 Mdot
.71067 .34105 Mdot
.64602 .4836 Mdot
.26627 .63873 Mdot
.73175 .53916 Mdot
.22453 .37059 Mdot
.34434 .45941 Mdot
.5716 .20149 Mdot
.40357 .59351 Mdot
.33082 .41921 Mdot
.46329 .23503 Mdot
.73176 .74707 Mdot
.6604 .59456 Mdot
.62235 .26521 Mdot
.60715 .72594 Mdot
.70413 .68481 Mdot
.28939 .64019 Mdot
.80171 .37784 Mdot
.49529 .29968 Mdot
.67802 .54825 Mdot
.45161 .74557 Mdot
.74937 .49285 Mdot
.20211 .65118 Mdot
.42478 .59624 Mdot
.40867 .76636 Mdot
.79728 .63314 Mdot
.44609 .16537 Mdot
.62396 .78521 Mdot
.71773 .44922 Mdot
.67248 .64118 Mdot
.6513 .47943 Mdot
.75977 .63019 Mdot
.79653 .54771 Mdot
.72282 .56465 Mdot
.66072 .45468 Mdot
.58465 .37902 Mdot
.33261 .47425 Mdot
.41597 .68719 Mdot
.53386 .34337 Mdot
.45348 .69014 Mdot
.58046 .63881 Mdot
.79297 .34028 Mdot
.22702 .61877 Mdot
.33848 .63415 Mdot
.22193 .50334 Mdot
.59698 .41199 Mdot
.66363 .51241 Mdot
.47335 .34191 Mdot
.28663 .3259 Mdot
.17673 .49491 Mdot
.2269 .31149 Mdot
.36848 .65039 Mdot
.61464 .39526 Mdot
.57214 .66151 Mdot
.66438 .55695 Mdot
.55227 .32346 Mdot
.48224 .16883 Mdot
.35336 .77807 Mdot
.63084 .65682 Mdot
.77305 .6218 Mdot
.37764 .4552 Mdot
.69452 .23001 Mdot
.73854 .44324 Mdot
.28641 .48783 Mdot
.41304 .81027 Mdot
.77619 .5529 Mdot
.70863 .52354 Mdot
.36344 .24023 Mdot
.56349 .35641 Mdot
.59703 .25654 Mdot
.31736 .56313 Mdot
.6161 .5387 Mdot
.74746 .596 Mdot
.48872 .81569 Mdot
.76837 .61614 Mdot
.32819 .51646 Mdot
.34282 .52115 Mdot
.65272 .79438 Mdot
.27801 .36202 Mdot
.23918 .28956 Mdot
.48094 .83603 Mdot
.40694 .30048 Mdot
.55571 .37675 Mdot
.38438 .70342 Mdot
.66541 .25182 Mdot
.80184 .37035 Mdot
.63995 .2938 Mdot
.30598 .41911 Mdot
.5188 .77492 Mdot
.33632 .45367 Mdot
.43648 .64222 Mdot
.69852 .46078 Mdot
.18641 .49861 Mdot
.29967 .24089 Mdot
.75842 .38061 Mdot
.35592 .63069 Mdot
.6506 .59115 Mdot
.19717 .56196 Mdot
.47114 .29434 Mdot
.60382 .76288 Mdot
.61576 .67671 Mdot
.55767 .36893 Mdot
.3539 .75108 Mdot
.60109 .35867 Mdot
.63793 .4142 Mdot
.79362 .61067 Mdot
.59762 .69537 Mdot
.70672 .63962 Mdot
.39062 .2038 Mdot
.67609 .67801 Mdot
.51268 .22165 Mdot
.23186 .4762 Mdot
.71789 .65059 Mdot
.28138 .70867 Mdot
.64518 .39235 Mdot
.7816 .59587 Mdot
.70693 .51137 Mdot
.84035 .53864 Mdot
.71488 .71406 Mdot
.63988 .39473 Mdot
.60978 .66641 Mdot
.48952 .71118 Mdot
.71333 .29371 Mdot
.36306 .68845 Mdot
.77487 .54098 Mdot
.49926 .33395 Mdot
.50204 .63844 Mdot
.51215 .278 Mdot
.7154 .72641 Mdot
.3569 .35408 Mdot
.76134 .63013 Mdot
.48671 .21723 Mdot
.55515 .78481 Mdot
.21275 .60773 Mdot
.32795 .52733 Mdot
.55384 .81243 Mdot
.65894 .40619 Mdot
.53634 .64785 Mdot
.78667 .52292 Mdot
.28548 .30653 Mdot
.58663 .32571 Mdot
.36728 .51954 Mdot
.25678 .26534 Mdot
.65527 .57787 Mdot
.59938 .81328 Mdot
.37385 .21864 Mdot
.55805 .65558 Mdot
.5092 .35301 Mdot
.61451 .28952 Mdot
.38059 .20334 Mdot
.17017 .52693 Mdot
.77109 .69847 Mdot
.35804 .7922 Mdot
.38302 .26623 Mdot
.60179 .82205 Mdot
.55625 .8212 Mdot
.45112 .39201 Mdot
.20391 .62505 Mdot
.67974 .25935 Mdot
.66647 .57857 Mdot
.65187 .29554 Mdot
.65316 .2085 Mdot
.72391 .4402 Mdot
.45198 .25944 Mdot
.49775 .33084 Mdot
.69333 .28052 Mdot
.48859 .28324 Mdot
.29393 .30247 Mdot
.24688 .52056 Mdot
.35772 .63188 Mdot
.42355 .78512 Mdot
.61353 .73348 Mdot
.66822 .20986 Mdot
.31841 .63091 Mdot
.32733 .72216 Mdot
.68189 .59578 Mdot
.33115 .36164 Mdot
.64442 .70455 Mdot
.24113 .68422 Mdot
.44356 .22954 Mdot
.66072 .74224 Mdot
.7377 .57948 Mdot
.22634 .52648 Mdot
.72877 .37785 Mdot
.74214 .64746 Mdot
.41741 .71374 Mdot
.24312 .50896 Mdot
.41584 .34713 Mdot
.34127 .76877 Mdot
.23457 .5381 Mdot
.29408 .76001 Mdot
.26609 .36416 Mdot
.74793 .31633 Mdot
.63314 .80849 Mdot
.74595 .4916 Mdot
.66086 .69091 Mdot
.58315 .30967 Mdot
.42432 .64909 Mdot
.57492 .29805 Mdot
.46569 .77703 Mdot
.18168 .44164 Mdot
.41671 .62141 Mdot
.27689 .28217 Mdot
.62671 .65606 Mdot
.37408 .63371 Mdot
.65568 .2246 Mdot
.3827 .65548 Mdot
.38823 .41865 Mdot
.65091 .5143 Mdot
.37236 .30859 Mdot
.34209 .58041 Mdot
.34754 .71009 Mdot
.22751 .58478 Mdot
.29866 .30294 Mdot
.33281 .33779 Mdot
.79325 .52545 Mdot
.65266 .46469 Mdot
.43716 .31297 Mdot
.80025 .43075 Mdot
.24648 .44602 Mdot
.1886 .47175 Mdot
.73308 .32567 Mdot
.32241 .75329 Mdot
.55713 .83102 Mdot
.19171 .40602 Mdot
.50756 .17738 Mdot
.58588 .37995 Mdot
.60385 .34548 Mdot
.18561 .39207 Mdot
.47918 .31867 Mdot
.42174 .77278 Mdot
.80021 .47838 Mdot
.18396 .39053 Mdot
.2577 .29176 Mdot
.49699 .78941 Mdot
.35906 .29393 Mdot
.78046 .36428 Mdot
.16807 .44372 Mdot
.75351 .30883 Mdot
.41338 .36255 Mdot
.39557 .57808 Mdot
.18658 .48848 Mdot
.38493 .55016 Mdot
.20634 .60257 Mdot
.34662 .71591 Mdot
.51873 .33139 Mdot
.33541 .42905 Mdot
.80482 .65557 Mdot
.42504 .27709 Mdot
.63558 .66575 Mdot
.6161 .33646 Mdot
.63882 .48138 Mdot
.38803 .62944 Mdot
.58935 .72195 Mdot
.22748 .54742 Mdot
.70599 .48447 Mdot
.26579 .73498 Mdot
.43781 .36424 Mdot
.47335 .22609 Mdot
.64794 .25623 Mdot
.65319 .2701 Mdot
.41977 .73918 Mdot
.38063 .57028 Mdot
.34915 .34863 Mdot
.51777 .24267 Mdot
.24022 .45678 Mdot
.61001 .38755 Mdot
.65381 .42873 Mdot
.79609 .51333 Mdot
.57859 .67483 Mdot
.53318 .61729 Mdot
.35483 .26142 Mdot
.34089 .42552 Mdot
.60023 .29718 Mdot
.78895 .55295 Mdot
.57563 .77968 Mdot
.36722 .72125 Mdot
.70156 .73688 Mdot
.3322 .59795 Mdot
.60089 .76813 Mdot
.2671 .3438 Mdot
.62867 .58919 Mdot
.58165 .73706 Mdot
.47251 .31499 Mdot
.80671 .63812 Mdot
.26201 .74438 Mdot
.50426 .81938 Mdot
.39402 .63245 Mdot
.65551 .73852 Mdot
.24128 .70357 Mdot
.64949 .78114 Mdot
.61191 .54544 Mdot
.68592 .29989 Mdot
.58077 .39865 Mdot
.23338 .4224 Mdot
.68249 .6331 Mdot
.54689 .67798 Mdot
.46247 .81755 Mdot
.3775 .79971 Mdot
.6937 .42897 Mdot
.53472 .65668 Mdot
.79709 .41489 Mdot
.51805 .36444 Mdot
.20387 .63292 Mdot
.19494 .35939 Mdot
.50012 .79808 Mdot
.16796 .46481 Mdot
.63359 .50824 Mdot
.34395 .55157 Mdot
.25574 .6947 Mdot
.64518 .28347 Mdot
.30179 .43668 Mdot
.28399 .76217 Mdot
.23698 .28611 Mdot
.38628 .24167 Mdot
.58 .33117 Mdot
.37518 .61999 Mdot
.54234 .35063 Mdot
.58473 .26861 Mdot
.35526 .6422 Mdot
.42609 .59656 Mdot
.7597 .53618 Mdot
.34597 .46731 Mdot
.60912 .29301 Mdot
.31197 .67452 Mdot
.71152 .30018 Mdot
.24139 .30258 Mdot
.31516 .62772 Mdot
.74361 .3222 Mdot
.45362 .33465 Mdot
.77712 .4277 Mdot
.29851 .50327 Mdot
.71035 .48532 Mdot
.57127 .78365 Mdot
.48674 .63793 Mdot
.68367 .55742 Mdot
.7946 .52626 Mdot
.60236 .68657 Mdot
.40836 .80555 Mdot
.3056 .50878 Mdot
.60717 .20626 Mdot
.43582 .22186 Mdot
.60834 .70739 Mdot
.79222 .42706 Mdot
.7678 .30683 Mdot
.36281 .79761 Mdot
.81634 .62371 Mdot
.60359 .2679 Mdot
.56484 .6613 Mdot
.24733 .28345 Mdot
.4833 .23405 Mdot
.16881 .53176 Mdot
.7181 .3698 Mdot
.70006 .3071 Mdot
.82023 .43927 Mdot
.41225 .62111 Mdot
.64161 .43693 Mdot
.32178 .49453 Mdot
.3507 .68331 Mdot
.68162 .41734 Mdot
.33875 .30841 Mdot
.41896 .73975 Mdot
.193 .54529 Mdot
.32249 .70055 Mdot
.62388 .76732 Mdot
.33018 .5803 Mdot
.83456 .42875 Mdot
.71554 .38191 Mdot
.6076 .43493 Mdot
.28782 .62789 Mdot
.82685 .51075 Mdot
.60694 .36427 Mdot
.52475 .23796 Mdot
.43362 .62711 Mdot
.4422 .35522 Mdot
.56979 .81645 Mdot
.44672 .28064 Mdot
.27321 .48801 Mdot
.68225 .68885 Mdot
.69854 .33497 Mdot
.37846 .49585 Mdot
.33065 .25387 Mdot
.42638 .1851 Mdot
.33593 .76737 Mdot
.77598 .54021 Mdot
.73235 .6436 Mdot
.65963 .20907 Mdot
.67424 .34895 Mdot
.35156 .61978 Mdot
.45265 .69624 Mdot
.17778 .52277 Mdot
.50781 .8275 Mdot
.16204 .47084 Mdot
.52626 .76984 Mdot
.41271 .72155 Mdot
.47617 .81509 Mdot
.28147 .35218 Mdot
.28582 .67637 Mdot
.26055 .67254 Mdot
.62114 .69201 Mdot
.50916 .33487 Mdot
.61596 .37803 Mdot
.25055 .60771 Mdot
.56742 .681 Mdot
.28778 .569 Mdot
.24812 .70905 Mdot
.54931 .19639 Mdot
.80979 .51374 Mdot
.42035 .36316 Mdot
.7061 .68433 Mdot
.64235 .51429 Mdot
.3538 .50632 Mdot
.26012 .74175 Mdot
.48276 .68885 Mdot
.53584 .21761 Mdot
.35184 .27672 Mdot
.44458 .3517 Mdot
.64566 .23719 Mdot
.47793 .6811 Mdot
.38217 .71716 Mdot
.58296 .35973 Mdot
.55658 .22347 Mdot
.31478 .59183 Mdot
.23069 .37776 Mdot
.62208 .53108 Mdot
.72198 .2579 Mdot
.33436 .33624 Mdot
.69956 .49828 Mdot
.69415 .30355 Mdot
.24145 .50151 Mdot
.55461 .72034 Mdot
.7297 .73128 Mdot
.60194 .3984 Mdot
.52562 .37769 Mdot
.67461 .231 Mdot
.61119 .55212 Mdot
.56342 .28719 Mdot
.78777 .54107 Mdot
.43599 .2787 Mdot
.52803 .75368 Mdot
.54943 .39055 Mdot
.76923 .51213 Mdot
.40048 .29131 Mdot
.30144 .62816 Mdot
.56901 .21717 Mdot
.53339 .23289 Mdot
.83991 .51999 Mdot
.30963 .41313 Mdot
.60334 .17944 Mdot
.54265 .25418 Mdot
.60612 .34079 Mdot
.57317 .74571 Mdot
.77128 .47974 Mdot
.56758 .81573 Mdot
.33938 .78791 Mdot
.18662 .53165 Mdot
.25893 .68628 Mdot
.66344 .32514 Mdot
.41725 .62608 Mdot
.35877 .61251 Mdot
.68722 .72351 Mdot
.43062 .28963 Mdot
.2765 .75091 Mdot
.2481 .34485 Mdot
.21835 .65634 Mdot
.44676 .61203 Mdot
.63507 .30413 Mdot
.61287 .36648 Mdot
.62601 .51661 Mdot
.33911 .23371 Mdot
.24787 .73199 Mdot
.39445 .77152 Mdot
.62344 .51857 Mdot
.42282 .79253 Mdot
.31022 .27845 Mdot
.65309 .58291 Mdot
.37984 .61721 Mdot
.22029 .68561 Mdot
.35032 .54155 Mdot
.55264 .30084 Mdot
.79901 .61317 Mdot
.77234 .6254 Mdot
.53305 .66378 Mdot
.61898 .50381 Mdot
.40912 .57481 Mdot
.67895 .41605 Mdot
.4546 .75938 Mdot
.72308 .64601 Mdot
.5254 .29084 Mdot
.74956 .63016 Mdot
.46692 .7445 Mdot
.65792 .73133 Mdot
.21467 .32655 Mdot
.58725 .82863 Mdot
.18539 .36895 Mdot
.58 .76841 Mdot
.34958 .79603 Mdot
.46963 .30689 Mdot
.6 .71819 Mdot
.27961 .32466 Mdot
.69358 .24489 Mdot
.65583 .4233 Mdot
.19253 .3567 Mdot
.59802 .25361 Mdot
.44842 .3712 Mdot
.5695 .7278 Mdot
.71156 .44593 Mdot
.37678 .7749 Mdot
.75029 .62488 Mdot
.82929 .56184 Mdot
.62754 .45709 Mdot
.29257 .47381 Mdot
.2569 .27397 Mdot
.37369 .78018 Mdot
.65162 .7459 Mdot
.64733 .20924 Mdot
.7832 .45684 Mdot
.42741 .27747 Mdot
.36775 .45812 Mdot
.54732 .22467 Mdot
.47258 .73796 Mdot
.18642 .48764 Mdot
.79546 .39909 Mdot
.21646 .36045 Mdot
.58663 .20208 Mdot
.29545 .3556 Mdot
.61148 .33488 Mdot
.59126 .28779 Mdot
.44482 .37045 Mdot
.69128 .27236 Mdot
.37556 .37754 Mdot
.18866 .37521 Mdot
.42324 .82159 Mdot
.36999 .34569 Mdot
.36365 .618 Mdot
.6265 .30047 Mdot
.22506 .41927 Mdot
.47693 .28834 Mdot
.5702 .59515 Mdot
.50884 .73229 Mdot
.4101 .63843 Mdot
.26391 .32512 Mdot
.62321 .19884 Mdot
.48054 .18151 Mdot
.55502 .62271 Mdot
.46552 .21591 Mdot
.23495 .49123 Mdot
.73846 .4639 Mdot
.38649 .57474 Mdot
.64554 .73568 Mdot
.42912 .82115 Mdot
.32186 .71104 Mdot
.71724 .35531 Mdot
.69948 .65199 Mdot
.63916 .70721 Mdot
.80415 .34495 Mdot
.34673 .38882 Mdot
.57452 .61335 Mdot
.30754 .55199 Mdot
.66507 .55255 Mdot
.25521 .53201 Mdot
.66922 .55399 Mdot
.79512 .35555 Mdot
.31282 .49148 Mdot
.46265 .33867 Mdot
.65855 .55067 Mdot
.64072 .62926 Mdot
.56021 .17552 Mdot
.62119 .8124 Mdot
.73413 .46466 Mdot
.62619 .61764 Mdot
.66009 .51498 Mdot
.62794 .80337 Mdot
.44133 .78879 Mdot
.61134 .37188 Mdot
.31474 .24734 Mdot
.82829 .59738 Mdot
.42657 .31916 Mdot
.32506 .23927 Mdot
.32351 .27495 Mdot
.37312 .61256 Mdot
.72532 .3293 Mdot
.36637 .62159 Mdot
.33184 .69145 Mdot
.28315 .65092 Mdot
.81154 .56044 Mdot
.57848 .72218 Mdot
.41029 .63978 Mdot
.54077 .66849 Mdot
.24364 .52169 Mdot
.32452 .21279 Mdot
.36146 .34925 Mdot
.80129 .43434 Mdot
.18649 .50094 Mdot
.675 .62656 Mdot
.46599 .18138 Mdot
.73064 .30233 Mdot
.32164 .66797 Mdot
.45635 .78669 Mdot
.18584 .63475 Mdot
.66633 .72579 Mdot
.53336 .26615 Mdot
.80287 .65967 Mdot
.64585 .80696 Mdot
.3255 .45814 Mdot
.7782 .47414 Mdot
.55774 .20553 Mdot
.74923 .68254 Mdot
.2164 .53946 Mdot
.74988 .54873 Mdot
.39321 .65681 Mdot
.37338 .43944 Mdot
.40202 .17434 Mdot
.56087 .70393 Mdot
.65413 .31206 Mdot
.61394 .61141 Mdot
.43761 .71576 Mdot
.33732 .61427 Mdot
.71008 .397 Mdot
.46492 .37952 Mdot
.76066 .59562 Mdot
.69398 .63108 Mdot
.43709 .81853 Mdot
.68683 .36287 Mdot
.6261 .66333 Mdot
.22976 .5946 Mdot
.34536 .79071 Mdot
.35049 .3715 Mdot
.43297 .61901 Mdot
.17239 .49172 Mdot
.58213 .83106 Mdot
.73844 .62506 Mdot
.60697 .74855 Mdot
.28543 .35484 Mdot
.57947 .67863 Mdot
.25641 .53521 Mdot
.56437 .22855 Mdot
.52111 .17574 Mdot
.66907 .44663 Mdot
.56878 .32275 Mdot
.80494 .41733 Mdot
.23043 .36605 Mdot
.67638 .21935 Mdot
.56131 .19242 Mdot
.3476 .47095 Mdot
.62637 .39926 Mdot
.78379 .48147 Mdot
.37187 .31559 Mdot
.79691 .53645 Mdot
.41006 .74139 Mdot
.72334 .32726 Mdot
.57682 .6789 Mdot
.3861 .63984 Mdot
.55375 .29985 Mdot
.41213 .76964 Mdot
.6131 .66151 Mdot
.45483 .81701 Mdot
.62086 .26703 Mdot
.41122 .76877 Mdot
.39571 .28229 Mdot
.35311 .30143 Mdot
.78411 .37493 Mdot
.22887 .32094 Mdot
.67391 .66129 Mdot
.68587 .21362 Mdot
.36422 .6966 Mdot
.43151 .28799 Mdot
.81575 .38314 Mdot
.6195 .23857 Mdot
.67852 .70678 Mdot
.27869 .70231 Mdot
.34924 .46258 Mdot
.44792 .19788 Mdot
.36415 .49895 Mdot
.33054 .69626 Mdot
.18418 .41921 Mdot
.29474 .69056 Mdot
.40783 .3375 Mdot
.78719 .66731 Mdot
.37431 .76712 Mdot
.17278 .51232 Mdot
.61227 .78286 Mdot
.43859 .24346 Mdot
.8318 .44763 Mdot
.30071 .39604 Mdot
.58084 .267 Mdot
.35666 .57186 Mdot
.62833 .62501 Mdot
.31698 .68288 Mdot
.61241 .26954 Mdot
.54785 .74316 Mdot
.59643 .4027 Mdot
.26612 .65656 Mdot
.60776 .79821 Mdot
.80854 .41739 Mdot
.60874 .68866 Mdot
.3902 .42678 Mdot
.75733 .39892 Mdot
.62092 .3141 Mdot
.36635 .4989 Mdot
.25709 .68548 Mdot
.41673 .79947 Mdot
.29169 .42496 Mdot
.38982 .26826 Mdot
.37129 .21647 Mdot
.53758 .25558 Mdot
.36018 .47558 Mdot
.32809 .59981 Mdot
.33568 .56418 Mdot
.76209 .60785 Mdot
.77931 .48938 Mdot
.41008 .75309 Mdot
.3147 .43685 Mdot
.80145 .41232 Mdot
.33361 .64716 Mdot
.42073 .31361 Mdot
.24951 .55693 Mdot
.63775 .6074 Mdot
.24234 .31007 Mdot
.34653 .50309 Mdot
.67539 .40012 Mdot
.69822 .41908 Mdot
.45321 .6742 Mdot
.72479 .2475 Mdot
.36057 .27413 Mdot
.24391 .48323 Mdot
.33892 .47468 Mdot
.36825 .48368 Mdot
.25344 .32147 Mdot
.42119 .76448 Mdot
.54724 .77668 Mdot
.29168 .49526 Mdot
.41002 .40463 Mdot
.32298 .76453 Mdot
.79787 .43771 Mdot
.45482 .34594 Mdot
.77615 .45712 Mdot
.1905 .42459 Mdot
.78625 .54278 Mdot
.65144 .20438 Mdot
.39237 .38856 Mdot
.39828 .64289 Mdot
.27744 .44065 Mdot
.46218 .27914 Mdot
.59301 .39324 Mdot
.58342 .39954 Mdot
.35159 .59348 Mdot
.27629 .71512 Mdot
.28759 .26026 Mdot
.63491 .55653 Mdot
.65442 .4478 Mdot
.32958 .43426 Mdot
.3538 .64617 Mdot
.6601 .61381 Mdot
.61352 .40349 Mdot
.46537 .17719 Mdot
.34595 .3052 Mdot
.40142 .3039 Mdot
.3471 .71701 Mdot
.60965 .5905 Mdot
.43693 .31311 Mdot
.2827 .41902 Mdot
.24 .51008 Mdot
.46574 .64835 Mdot
.46962 .26345 Mdot
.65442 .47968 Mdot
.77152 .33661 Mdot
.48946 .64864 Mdot
.64568 .76073 Mdot
.40633 .29543 Mdot
.3368 .26924 Mdot
.33643 .48436 Mdot
.52514 .16153 Mdot
.46319 .62358 Mdot
.21781 .39886 Mdot
.5368 .66184 Mdot
.48689 .30152 Mdot
.64102 .71777 Mdot
.70431 .68579 Mdot
.81366 .54792 Mdot
.70507 .50996 Mdot
.39873 .72951 Mdot
.38444 .30125 Mdot
.65773 .21134 Mdot
.60811 .78063 Mdot
.45802 .74836 Mdot
.3124 .49404 Mdot
.48749 .3573 Mdot
.45048 .82722 Mdot
.19897 .65719 Mdot
.65767 .51281 Mdot
.53208 .81869 Mdot
.79769 .49317 Mdot
.51537 .63885 Mdot
.35983 .30167 Mdot
.75249 .31759 Mdot
.81008 .57345 Mdot
.30927 .21751 Mdot
.51094 .18986 Mdot
.58974 .62999 Mdot
.63518 .29368 Mdot
.29551 .54887 Mdot
.26052 .27378 Mdot
.28646 .31822 Mdot
.35116 .79933 Mdot
.31952 .5879 Mdot
.49355 .7363 Mdot
.16712 .52726 Mdot
.42052 .74041 Mdot
.62848 .60359 Mdot
.54027 .38414 Mdot
.48983 .21159 Mdot
.43662 .26722 Mdot
.36023 .7365 Mdot
.24232 .31103 Mdot
.59191 .41787 Mdot
.18732 .62134 Mdot
.6093 .5577 Mdot
.60993 .72407 Mdot
.60554 .75497 Mdot
.22213 .52769 Mdot
.49163 .22262 Mdot
.62864 .41733 Mdot
.28826 .32926 Mdot
.54318 .26316 Mdot
.21709 .40245 Mdot
.34197 .2876 Mdot
.57957 .37577 Mdot
.51431 .69122 Mdot
.7288 .43075 Mdot
.34248 .32445 Mdot
.59827 .82536 Mdot
.2061 .34842 Mdot
.46966 .81579 Mdot
.6189 .65722 Mdot
.64169 .47881 Mdot
.22655 .69382 Mdot
.79587 .47279 Mdot
.72721 .52623 Mdot
.35447 .49057 Mdot
.49286 .20393 Mdot
.65957 .75394 Mdot
.44363 .69865 Mdot
.57183 .69569 Mdot
.17547 .60143 Mdot
.31124 .55966 Mdot
.35851 .24373 Mdot
.2217 .38138 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0T_ooool3ool008Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool3ool0
01?ooooo1Ooo0025ooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1Ooo0007ooooo`?o
o`002?ooool5ool008Gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool5ool000Kooooo
1Ooo0007ooooo`Goo`00QOooool1o`00007ooooo00000ol0003oooooooooo`1_ooooo`?oo`002?oo
ool5ool000Cooooo1ooo0004ooooo`Ooo`001oooool3ool007cooooo0Ol00001ooooo`0000?o0000
ooooooooool0K_ooool5ool000Sooooo0ooo0003ooooo`Woo`000oooool:ool000Cooooo1Ooo0008
ooooo`?oo`00L?ooool1o`00007ooooo00000ol0003oooooooooo`1^ooooo`Ooo`002oooool9ool0
00?ooooo3?oo0003ooooo`Goo`001oooool5ool006oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0K_ooool;ool000?ooooo0ooo00000oooooooo`00ool00007ool000?ooooo3?oo0003ooooo`Go
o`001_ooool6ool006oooooo0Ol00001ooooo`0000?o0000ooooooooool0Koooool;ool00003oooo
oooo003oo`0000coo`000oooool<ool000Cooooo0ooo0006ooooo`Ooo`00Koooool1o`00007ooooo
00000ol0003oooooooooo`1aooooo`Woo`0000?oooooool00?oo00003?oo0004ooooo`Goo`000_oo
ool3ool000Gooooo0ooo0005ooooo`Ooo`00L?ooool1o`00007ooooo00000ol0003oooooooooo`1b
ooooo`Soo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00005ool000Gooooo1Ooo0007
ooooo`Ooo`001?ooool6ool0077ooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool3ool0
00?ooooo0ooo000>ooooo`Goo`001_ooool8ool000Cooooo1Ooo0005ooooo`?oo`00J_ooool1o`00
007ooooo00000ol0003oooooooooo`1Xooooo`Koo`003Oooool5ool000Wooooo0ooo0002ooooo`?o
o`001oooool:ool000;ooooo1?oo0005ooooo`Goo`00JOooool1o`00007ooooo00000ol0003ooooo
ooooo`1Wooooo`Soo`003?ooool5ool000Sooooo1Ooo000;oooooa3oo`0000Goooooool00?oo003o
o`00ooooo`05ool000Cooooo0ooo001Rooooo`7o00000Oooool00003o`000?oooooooooo06Oooooo
2?oo000<ooooo`Goo`002?ooool5ool000cooooo6Ooo0003ooooo`Woo`00GOooool1o`00007ooooo
00000ol0003oooooooooo`1Hooooo`?oo`003?ooool8ool000gooooo0ooo0009ooooo`Goo`003Ooo
oolCool00004oooooooo003oo`00ool000?ooooo2ooo00001?ooooooo`00ool00?oo001Hooooo`7o
00000Oooool00003o`000?oooooooooo05Cooooo2?oo000:ooooo`Soo`004oooool3ool000?ooooo
1Ooo0009ooooo`?oo`000_ooool8ool000;ooooo0ooo00000oooooooo`00ool00003ool000Oooooo
4?oo001Gooooo`7o00000Oooool00003o`000?oooooooooo05?ooooo2Ooo0009ooooo`Goo`005_oo
ool5ool00003oooooooo003oo`0000Coo`000_ooool3ool000?ooooo1Ooo00000oooooooo`00ool0
0006ool000Oooooo0ooo0008oooooa3oo`00Eoooool1o`00007ooooo00000ol0003oooooooooo`1C
ooooo`Woo`002Oooool6ool000gooooo0ooo0005ooooo`Goo`0000?oooooool00?oo00001?oo0000
0oooooooo`00ool00003ool000;ooooo3_oo000Cooooo`ooo`00Eoooool1o`00007ooooo00000ol0
003oooooooooo`1Cooooo`Soo`002_ooool6ool000cooooo1Ooo0004ooooo`coo`0000?oooooool0
0?oo00000ooo0002ooooo`koo`005?ooool5ool00003oooooooo003oo`0000Goo`00F?ooool1o`00
007ooooo00000ol0003oooooooooo`1Dooooo`?oo`003oooool5ool000cooooo1ooo0003ooooo`_o
o`0000?oooooool00?oo00000ooo0003ooooo`coo`005Oooool5ool00003oooooooo003oo`0000?o
o`0000Coooooool00?oo003oo`00E_ooool1o`00007ooooo00000ol0003oooooooooo`1Mooooo`?o
o`001oooool3ool000gooooo2?oo00000oooooooo`00ool0000:ool000;ooooo0ooo0003ooooo`go
o`005Oooool5ool00003oooooooo003oo`0000Soo`00EOooool1o`00007ooooo00000ol0003ooooo
ooooo`1Looooo`Goo`005ooooolCool000Oooooo3ooo000<ooooo`?oo`001?ooool6ool000;ooooo
2_oo001Eooooo`7o00000Oooool00003o`000?oooooooooo057ooooo0ooo0005ooooo`Soo`000ooo
ool3ool000?ooooo0ooo000=oooooa3oo`001oooool7ool000Gooooo0ooo000<ooooo`Goo`000_oo
ool5ool000Cooooo2_oo001Eooooo`7o00000Oooool00003o`000?oooooooooo053ooooo1Ooo0003
ooooo`Woo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00003ool000_ooooo1Ooo0000
0oooooooo`00ool00009ool000Kooooo2?oo000Dooooo`Goo`000_ooool5ool000Gooooo2?oo001F
ooooo`7o00000Oooool00003o`000?oooooooooo053ooooo4?oo00000oooooooo`00ool00005ool0
0003oooooooo003oo`0000?oo`002Oooool6ool000?ooooo2Ooo0006ooooo`Soo`005Oooool5ool0
00;ooooo1Ooo0007ooooo`Ooo`001Oooool3ool004gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool=ool000Cooooo1ooo00000oooooooo`00ool00003ool000Sooooo1ooo000Booooo`Ko
o`006?ooool3ool000Cooooo0ooo0003ooooo`?oo`000_ooool7ool000Cooooo1Ooo001<ooooo`7o
00000Oooool00003o`000?oooooooooo04_ooooo0ooo0003ooooo`coo`001?ooool6ool000?ooooo
0ooo0009ooooo`Ooo`004_ooool5ool00003oooooooo003oo`0000?oo`003Oooool3ool000_ooooo
0ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Goo`001?ooool5ool004cooooo
0Ol00001ooooo`0000?o0000ooooooooool0B_ooool5ool000?ooooo3?oo0004ooooo`?oo`004Ooo
ool6ool00004oooooooo003oo`00ool0013ooooo0ooo00000oooooooo`00ool00005ool000?ooooo
0ooo0005ooooo`Goo`002OoooolAool000Gooooo1Ooo001<ooooo`7o00000Oooool00003o`000?oo
oooooooo04[ooooo1ooo0002ooooo`_oo`000oooool3ool001?ooooo0ooo0002ooooo`Goo`0000Co
ooooool00?oo003oo`003oooool7ool000;ooooo1Ooo0004ooooo`Goo`002Oooool>ool000Oooooo
1Ooo001=ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0ooo0002ooooo`Soo`001ooo
ool5ool000;ooooo1Ooo0004ooooo`?oo`004?ooool:ool000kooooo1ooo0002ooooo`Soo`0000?o
ooooool00?oo00000ooo0003ooooo`?oo`000oooool5ool00003oooooooo003oo`0000Koo`001ooo
ool5ool004gooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool5ool00003oooooooo003o
o`0000Koo`002?ooool5ool00003oooooooo003oo`0000?oo`000oooool6ool000_ooooo3Ooo000=
ooooo`Soo`000_ooool9ool00003oooooooo003oo`0000Woo`000oooool5ool000?ooooo1Ooo0007
ooooo`Goo`00COooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`Goo`000_ooool7ool0
00Wooooo2_oo0003ooooo`Ooo`002Oooool8ool00003oooooooo003oo`0000?oo`003Oooool8ool0
00?ooooo5?oo0004ooooo`Goo`000oooool3ool00004oooooooo003oo`00ool000Gooooo0ooo001>
ooooo`7o00000Oooool00003o`000?oooooooooo04Cooooo1_oo0004ooooo`?oo`001oooool>ool0
00;ooooo1ooo0006ooooo`Soo`001Oooool3ool000kooooo1ooo0007oooooa7oo`001?ooool5ool0
00Kooooo1Ooo001Eooooo`7o00000Oooool00003o`000?oooooooooo04Cooooo2?oo0008oooooa?o
o`000_ooool6ool000Gooooo2_oo0002ooooo`?oo`002oooool3ool000?ooooo0ooo000;ooooo`oo
o`001Oooool5ool000Kooooo1Ooo001Eooooo`7o00000Oooool00003o`000?oooooooooo04;ooooo
3?oo0005oooooaCoo`001?ooool5ool00003oooooooo003oo`00017oo`000oooool3ool000?ooooo
1Ooo000Aooooo`?oo`000_ooool8ool000Cooooo1_oo0007ooooo`Goo`00EOooool1o`00007ooooo
00000ol0003oooooooooo`0ooooooa3oo`001?ooool9ool00003oooooooo003oo`0000Soo`001Ooo
oolHool000;ooooo1Ooo0002ooooo`Goo`002oooool3ool000Gooooo0ooo000;ooooo`Goo`002Ooo
ool5ool005Gooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool8ool000;ooooo1ooo0004
ooooo`Soo`0000?oooooool00?oo00002?oo0006oooooaooo`000_ooool8ool000Oooooo1Ooo0003
ooooo`Goo`000oooool3ool000Cooooo1Ooo0009ooooo`Goo`00EOooool1o`00007ooooo00000ol0
003oooooooooo`0nooooo`[oo`0000?oooooool00?oo00001_oo0003ooooo`?oo`001Oooool5ool0
0004oooooooo003oo`00ool000Oooooo2Ooo00000oooooooo`00ool00006ool000;ooooo2ooo0003
ooooo`Soo`001_ooool5ool000?ooooo1Ooo00000oooooooo`00ool00004ool00003oooooooo003o
o`0000Goo`002_ooool3ool000?ooooo0ooo001@ooooo`7o00000Oooool00003o`000?oooooooooo
03kooooo2ooo0002ooooo`Ooo`002_ooool:ool000Oooooo1ooo0002ooooo`Goo`001_ooool9ool0
00Oooooo1Ooo0006ooooo`Ooo`0000?oooooool00?oo00004ooo000>ooooo`Goo`00Coooool1o`00
007ooooo00000ol0003oooooooooo`0oooooo`[oo`001?ooool5ool000_ooooo0ooo00000ooooooo
o`00ool00003ool000Cooooo2_oo0002ooooo`Goo`001_ooool;ool000Gooooo1Ooo0004ooooo`[o
o`0000?oooooool00?oo00005Ooo0004ooooo`?oo`001?ooool6ool004kooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool9ool000Cooooo1ooo000;ooooo`Ooo`000oooool;ool000?ooooo
0ooo0007ooooo`goo`001?ooool3ool000Cooooo1Ooo00000oooooooo`00ool00003ool000;ooooo
5ooo0002ooooo`Koo`0000?oooooool00?oo00002?oo001;ooooo`7o00000Oooool00003o`000?oo
oooooooo043ooooo2?oo0005ooooo`Soo`001ooooolHool000kooooo0ooo00000oooooooo`00ool0
0007ool000[ooooo1Ooo00000oooooooo`00ool00003ool000;ooooo1ooo00000oooooooo`00ool0
000=ool000;ooooo4_oo0002ooooo`?oo`0000Coooooool00?oo003oo`00@Oooool1o`00007ooooo
00000ol0003oooooooooo`0looooo`?oo`0000?oooooool00?oo00000ooo0007ooooo`Woo`001_oo
oolIool000gooooo3_oo000:ooooo`Goo`000_ooool6ool00004oooooooo003oo`00ool000Cooooo
1ooo00000oooooooo`00ool00005ool000;ooooo4_oo00000oooooooo`00ool00007ool0043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0>oooool:ool000Oooooo2Ooo0006oooooaSoo`0000Co
ooooool00?oo003oo`000_ooool3ool000Gooooo1Ooo00000oooooooo`00ool00006ool000_ooooo
0ooo0005ooooo`Goo`001_ooool8ool00003oooooooo003oo`0000Coo`001?ooool:ool000;ooooo
1Ooo00000oooooooo`00ool00007ool0043ooooo0Ol00001ooooo`0000?o0000ooooooooool0>ooo
ool:ool000Oooooo2?oo0007ooooo`Ooo`000oooool5ool000Cooooo0ooo0002ooooo`[oo`001?oo
ool7ool000?ooooo1Ooo000Booooo`Goo`001Oooool8ool000;ooooo1Ooo0004ooooo`Woo`001Ooo
ool3ool000;ooooo2_oo000oooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo3?oo0005
ooooo`Goo`002oooool3ool000Kooooo1Ooo0009ooooo`[oo`001Oooool7ool000;ooooo1Ooo000>
ooooo`?oo`0000?oooooool00?oo00000ooo0005ooooo`Goo`001Oooool5ool000Cooooo2?oo000:
ooooo`_oo`00?oooool1o`00007ooooo00000ol0003oooooooooo`0looooo`koo`0000?oooooool0
0?oo00001?oo000=ooooo`?oo`001?ooool5ool000Wooooo2_oo0005ooooo`Ooo`0000?oooooool0
0?oo00001?oo000:ooooo`Soo`0000?oooooool00?oo00000_oo0005ooooo`Goo`001_ooool6ool0
00;ooooo2Ooo0006ooooo`koo`00?oooool1o`00007ooooo00000ol0003oooooooooo`0iooooo`So
o`000_ooool?ool000Kooooo0ooo0002ooooo`Soo`0000Coooooool00?oo003oo`002oooool8ool0
00Oooooo3?oo000:ooooo`Woo`0000?oooooool00?oo00000ooo0005ooooo`?oo`002Oooool5ool0
00;ooooo2?oo0003oooooa3oo`00@?ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Wo
o`000_ooool?ool000Gooooo1Ooo00000oooooooo`00ool00007ool0013ooooo0ooo000<ooooo`?o
o`0000?oooooool00?oo00000ooo0002ooooo`?oo`001_ooool?ool0017ooooo1Ooo0005ooooo`Go
o`000_oooolAool0043ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool8ool000Cooooo
3_oo0005ooooo`ooo`005oooool3ool000Wooooo2ooo0005ooooo`ooo`000oooool4ool000[ooooo
1Ooo0006ooooo`?oo`000oooool:ool000;ooooo1_oo000oooooo`7o00000Oooool00003o`000?oo
oooooooo03Sooooo1Ooo000:ooooo`_oo`001Oooool?ool000[ooooo0ooo0009ooooo`Ooo`001_oo
ool;ool000Kooooo0ooo0004ooooo`Koo`000oooool6ool000[ooooo0ooo0006ooooo`Goo`000_oo
ool7ool000Kooooo1_oo000nooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo0ooo000<
ooooo`?oo`000oooool3ool000Oooooo1ooo0003ooooo`?oo`002_ooool5ool000Sooooo2_oo0003
ooooo`koo`002_ooool5ool000?ooooo1ooo000Cooooo`Ooo`0000Coooooool00?oo003oo`002_oo
ool5ool000;ooooo0ooo000iooooo`7o00000Oooool00003o`000?oooooooooo04;ooooo0ooo0003
ooooo`?oo`003oooool5ool000Kooooo0ooo0007ooooo`Ooo`001_ooool;ool000;ooooo3ooo000:
ooooo`?oo`000oooool8ool001?ooooo2?oo000=ooooo`Goo`0000?oooooool00?oo00001Ooo000f
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0ooo0008ooooo`Goo`0000?oooooool0
0?oo00000ooo000>ooooo`Soo`0000?oooooool00?oo00001?oo0006ooooo`Woo`001Oooool:ool0
00?ooooo2?oo00000oooooooo`00ool00005ool000gooooo2?oo000>ooooo`?oo`001?ooool7ool0
00kooooo0ooo0002ooooo`Soo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`Go
o`001oooool5ool00003oooooooo003oo`0000Koo`003?ooool>ool000Oooooo2_oo00000ooooooo
o`00ool0000:ool000Cooooo1ooo00000oooooooo`00ool00006ool000cooooo1_oo000?ooooo`Go
o`001Oooool5ool001?ooooo2?oo000eooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo
1ooo0007ooooo`Goo`0000?oooooool00?oo00002_oo000;ooooo`_oo`002Oooool@ool00005oooo
oooo003oo`00ool00?ooool02ooo0002ooooo`Ooo`000_ooool3ool000Oooooo1Ooo000@ooooo`Go
o`001_ooool5ool001?ooooo1ooo000eooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo
2_oo0006ooooo`?oo`000oooool<ool000[ooooo2_oo000;ooooo`koo`001Oooool;ool000Gooooo
1Ooo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool000?ooooo0ooo000Aooooo`Go
o`001_ooool6ool0017ooooo1ooo000fooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo
2ooo000:ooooo`goo`001_ooool3ool000;ooooo2_oo0009ooooo`goo`001oooool=ool000Cooooo
0ooo0002ooooo`[oo`0000?oooooool00?oo00000ooo000?ooooo`Soo`000oooool7ool000Wooooo
0ooo0002ooooo`Soo`00>?ooool1o`00007ooooo00000ol0003oooooooooo`0booooo`Goo`0000?o
ooooool00?oo00001_oo0006ooooo`koo`001Oooool5ool000Cooooo2?oo0007ooooo`goo`002?oo
ool>ool000Sooooo2_oo00000oooooooo`00ool00005ool000gooooo2Ooo0002ooooo`Ooo`002?oo
ool>ool003Sooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool7ool00003oooooooo003o
o`0000Ooo`001Oooool=ool000Kooooo1Ooo0002ooooo`?oo`000_ooool5ool000Oooooo3_oo0008
ooooo`?oo`001Oooool5ool000Oooooo2ooo00000oooooooo`00ool00006ool000cooooo2Ooo0002
ooooo`Koo`002Oooool?ool003Oooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool7ool0
00;ooooo2Ooo0005ooooo`Woo`002_ooool5ool00003oooooooo003oo`0000?oo`0000?oooooool0
0?oo00000ooo0007ooooo`ooo`003oooool5ool000Kooooo1ooo00001?ooooooo`00ool00?oo0003
ooooo`Ooo`003Oooool8ool000?ooooo1_oo0008oooooa3oo`00=_ooool1o`00007ooooo00000ol0
003oooooooooo`0_ooooo`Goo`000oooool:ool000Kooooo1ooo000<ooooo`?oo`000_ooool5ool0
00;ooooo1?oo0008ooooo`Goo`000_ooool7ool0013ooooo1Ooo0005ooooo`Koo`000_ooool3ool0
00Cooooo1_oo000Aooooo`?oo`001Oooool7ool000Oooooo0ooo0002ooooo`[oo`00=_ooool1o`00
007ooooo00000ol0003oooooooooo`0_ooooo`Koo`000_ooool:ool001kooooo1Ooo0002ooooo`Go
o`003oooool6ool00004oooooooo003oo`00ool000gooooo1Ooo0004ooooo`Goo`000_ooool5ool0
00Cooooo1_oo000Hooooo`Soo`001Oooool3ool000?ooooo2_oo000fooooo`7o00000Oooool00003
o`000?oooooooooo033ooooo1Ooo0002ooooo`[oo`007oooool3ool000?ooooo1Ooo000@ooooo`Co
o`0000?oooooool00?oo00000ooo000<ooooo`Soo`0000?oooooool00?oo00000ooo0002ooooo`Ko
o`000oooool6ool001Oooooo2Ooo0004ooooo`Goo`000_ooool=ool003?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<?ooool5ool000?ooooo2_oo000Mooooo`?oo`001?ooool5ool00004oooo
oooo003oo`00ool0017ooooo1Ooo000<ooooo`koo`000_ooool6ool000?ooooo1_oo000Gooooo`Wo
o`001?ooool5ool000?ooooo0ooo00000oooooooo`00ool00007ool003;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<?ooool4ool000Kooooo2Ooo000Kooooo`Goo`001?ooool3ool00003oooo
oooo003oo`0000?oo`003Oooool8ool000gooooo3Ooo0003ooooo`Goo`000_ooool6ool000Gooooo
0ooo000@ooooo`Soo`001Oooool5ool000Sooooo2?oo000booooo`7o00000Oooool00003o`000?oo
oooooooo02oooooo1_oo0006ooooo`Soo`006oooool5ool000Sooooo1Ooo000<ooooo`Soo`004Ooo
ool:ool000Cooooo1Ooo00000oooooooo`00ool00004ool000Cooooo1Ooo000@ooooo`?oo`002_oo
ool3ool000cooooo1Ooo000booooo`7o00000Oooool00003o`000?oooooooooo02oooooo1_oo0005
ooooo`?oo`0000?oooooool00?oo00000ooo0003ooooo`?oo`002Oooool3ool000Wooooo1Ooo0008
ooooo`Goo`003?ooool5ool001Gooooo2?oo0004oooooaKoo`003oooool3ool000[ooooo0ooo0008
ooooo`?oo`000oooool3ool003?ooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool6ool0
00Cooooo1Ooo00001?ooooooo`00ool00?oo0003ooooo`Goo`001oooool5ool000Wooooo0ooo000:
ooooo`?oo`003Oooool5ool001Oooooo1Ooo0004oooooaOoo`001Oooool3ool000Kooooo1Ooo0008
ooooo`Goo`001_ooool5ool003Sooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool5ool0
00Cooooo1Ooo0007ooooo`Goo`001oooool5ool001_ooooo0ooo0009ooooo`?oo`006Oooool3ool0
00Gooooo5_oo00001Oooooooo`00ool00?oo003ooooo00Goo`001Oooool5ool000Sooooo1Ooo0006
ooooo`Goo`00>?ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`Goo`000oooool5ool0
00Oooooo1Ooo0007ooooo`Goo`005oooool8ool002cooooo5Ooo00000oooooooo`00ool00008ool0
00Cooooo1_oo0008ooooo`Goo`001_ooool5ool003Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0<Oooool5ool000?ooooo1Ooo0005ooooo`Koo`002Oooool5ool001Gooooo2Ooo000]oooooa?o
o`000_ooool:ool000?ooooo1_oo000:ooooo`?oo`002?ooool5ool003Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0<Oooool5ool000Cooooo0ooo0005ooooo`Goo`003?ooool8ool0017ooooo
2Ooo000^ooooo`coo`0000?oooooool00?oo00000ooo0002ooooo`Goo`0000?oooooool00?oo0000
0_oo0003ooooo`Goo`005oooool5ool003Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?oo
ool5ool000Oooooo0ooo0003ooooo`Goo`001Oooool3ool000Cooooo2_oo000>ooooo`Woo`00<Ooo
ool9ool000;ooooo1_oo0002ooooo`?oo`000_ooool5ool000;ooooo1Ooo000Fooooo`Ooo`00=Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`Goo`001oooool6ool00003oooooooo003o
o`0000?oo`001?ooool5ool000;ooooo3?oo000<ooooo`Koo`00=?ooool9ool000;ooooo1ooo0000
1?ooooooo`00ool00?oo0003ooooo`_oo`005oooool8ool003Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0;oooool6ool000Kooooo1ooo00001?ooooooo`00ool00?oo0005oooooaGoo`002_oo
ool5ool003Gooooo2Ooo0002ooooo`coo`000_ooool;ool001Kooooo2Ooo000dooooo`7o00000Ooo
ool00003o`000?oooooooooo02oooooo1ooo0005ooooo`Ooo`002Oooool<ool00003oooooooo003o
o`0000Ooo`002Oooool5ool003Gooooo2Ooo0002ooooo`Koo`0000?oooooool00?oo00000ooo0003
ooooo`[oo`001?ooool3ool000_ooooo3Ooo0004ooooo`?oo`00;Oooool1o`00007ooooo00000ol0
003oooooooooo`0`ooooo`Koo`001_ooool6ool000[ooooo2_oo0003ooooo`Soo`002Oooool5ool0
03Kooooo0ooo00001?ooooooo`00ool00?oo0004ooooo`?oo`000oooool5ool000Cooooo2?oo0004
ooooo`Goo`002Oooool=ool000Cooooo1Ooo000/ooooo`7o00000Oooool00003o`000?oooooooooo
037ooooo1Ooo0008ooooo`?oo`003Oooool7ool00003oooooooo003oo`0000Woo`002Oooool5ool0
03_ooooo0ooo0006ooooo`Soo`001_ooool5ool000Gooooo1Ooo0009ooooo`coo`001Oooool5ool0
02cooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool3ool001Kooooo0ooo00000ooooooo
o`00ool0000?ool000Kooooo0ooo0002ooooo`?oo`00>oooool5ool000Cooooo2Ooo0006ooooo`Go
o`001Oooool5ool000Wooooo3?oo0002ooooo`Soo`00;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`Koo`006?ooool5ool000;ooooo3Ooo0007ooooo`Goo`00?oooool5ool000Cooooo
2?oo0008ooooo`?oo`001Oooool8ool000Sooooo0ooo0002ooooo`Koo`0000?oooooool00?oo0000
1_oo000]ooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo2?oo000?ooooo`?oo`001Ooo
ool5ool000;ooooo3?oo0008ooooo`Goo`00?oooool5ool000Cooooo2?oo00001?ooooooo`00ool0
0?oo0009ooooo`coo`003?ooool5ool000;ooooo1ooo000^ooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo2?oo000;ooooo`Soo`001?ooool5ool000?ooooo0ooo00001?ooooooo`00ool0
0?oo000<ooooo`Goo`00@?ooool3ool000Kooooo3?oo0007ooooo`goo`003Oooool3ool000;ooooo
2Ooo000]ooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo2?oo000:ooooo`Woo`001Ooo
ool3ool000kooooo0ooo0007ooooo`Goo`00AOooool3ool000?ooooo2Ooo0007ooooo`goo`004Ooo
ool:ool002gooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool6ool000[ooooo2_oo000C
ooooo`Ooo`001Oooool7ool004?ooooo1Ooo0002ooooo`Woo`001oooool7ool000;ooooo0ooo0008
ooooo`Goo`001Oooool:ool002gooooo0Ol00001ooooo`0000?o0000ooooooooool0>oooool:ool0
01?ooooo2Ooo0003ooooo`Soo`00@_ooool6ool000?ooooo1ooo0006ooooo`Woo`003?ooool7ool0
00Cooooo1Ooo00001?ooooooo`00ool00?oo000^ooooo`7o00000Oooool00003o`000?oooooooooo
02_ooooo0ooo000=ooooo`Woo`005?ooool:ool000;ooooo2?oo0012ooooo`Koo`000_ooool7ool0
00Kooooo1Ooo00001?ooooooo`00ool00?oo0002ooooo`Coo`001oooool7ool000Gooooo0ooo000c
ooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo1Ooo000<ooooo`Woo`005?ooool;ool0
0003oooooooo003oo`0000Goo`00@oooool5ool000;ooooo1ooo0007ooooo`Goo`001Oooool6ool0
00Kooooo1ooo000kooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo1Ooo0002ooooo`?o
o`002?ooool3ool00004oooooooo003oo`00ool001Kooooo0ooo00000oooooooo`00ool00004ool0
00;ooooo0ooo0017ooooo`?oo`000oooool5ool000Wooooo1Ooo0005ooooo`Koo`001?ooool8ool0
03cooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool6ool00003oooooooo003oo`0000?o
o`002Oooool3ool000kooooo0ooo0009ooooo`_oo`00Coooool5ool000[ooooo0ooo0006ooooo`Ko
o`000oooool7ool000?ooooo0ooo000hooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo
1Ooo0002ooooo`Goo`002?ooool5ool000cooooo1Ooo0007ooooo`goo`00C?ooool7ool001;ooooo
1_oo0004ooooo`Soo`0000?oooooool00?oo00000ooo000gooooo`7o00000Oooool00003o`000?oo
oooooooo02Wooooo1Ooo0002ooooo`Goo`002?ooool5ool000cooooo1Ooo0007ooooo`goo`00Booo
ool9ool0013ooooo1ooo0004ooooo`ooo`00=_ooool1o`00007ooooo00000ol0003oooooooooo`0Z
ooooo`?oo`001?ooool3ool000Wooooo1ooo000:ooooo`Goo`001oooool>ool004Wooooo2_oo000;
ooooo`Coo`0000?oooooool00?oo00001Ooo0005ooooo`koo`001?ooool3ool002oooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool4ool000Wooooo1ooo0005ooooo`Soo`002Oooool5ool0
00?ooooo1_oo0018ooooo`[oo`002_ooool<ool000Kooooo3_oo0003ooooo`Goo`00;_ooool1o`00
007ooooo00000ol0003oooooooooo`0/ooooo`[oo`002Oooool6ool000Cooooo2?oo0004ooooo`?o
o`000oooool5ool00003oooooooo003oo`0000Koo`00B?ooool9ool000_ooooo1_oo00001?oooooo
o`00ool00?oo0002ooooo`Coo`000_ooool=ool000Cooooo1Ooo000^ooooo`7o00000Oooool00003
o`000?oooooooooo02_ooooo2ooo0008ooooo`Ooo`001?ooool9ool000;ooooo5ooo0017ooooo`Oo
o`003?ooool6ool000Gooooo1_oo0002ooooo`coo`001?ooool5ool002kooooo0Ol00001ooooo`00
00?o0000ooooooooool0:oooool;ool000Sooooo1_oo0005ooooo`[oo`0000?oooooool00?oo0000
2Ooo00000oooooooo`00ool0000:ool004Wooooo0ooo000<ooooo`Koo`001_ooool6ool000Cooooo
2ooo0004ooooo`?oo`00;oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`[oo`001_oo
ool9ool000Kooooo4_oo0003ooooo`goo`00@Oooool3ool001?ooooo1Ooo0008ooooo`Koo`001Ooo
ool3ool00003oooooooo003oo`0000Coo`00=_ooool1o`00007ooooo00000ol0003oooooooooo`0/
ooooo`Woo`001Oooool;ool000Wooooo3_oo0002ooooo`koo`00@?ooool5ool001;ooooo1Ooo0009
ooooo`Coo`002oooool5ool003Kooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool7ool0
00Gooooo1Ooo00000oooooooo`00ool00003ool000[ooooo3?oo0003ooooo`goo`00@Oooool8ool0
00oooooo1Ooo000Hooooo`Goo`000oooool3ool0033ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;Oooool8ool000Gooooo2ooo000;ooooo`Ooo`001oooool9ool004Gooooo4Ooo0007ooooo`Go
o`003oooool3ool000Gooooo3?oo000_ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
2?oo0007ooooo`?oo`0000?oooooool00?oo00001?oo0009ooooo`Woo`000_ooool3ool000?ooooo
1_oo0018oooooa7oo`001_ooool6ool000gooooo1Ooo0003ooooo`goo`00;oooool1o`00007ooooo
00000ol0003oooooooooo`0/ooooo`Goo`003_ooool6ool00004oooooooo003oo`00ool000Cooooo
2_oo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Coo`0000Coooooool00?oo003o
o`00A_ooool@ool000Kooooo1_oo0006ooooo`?oo`001?ooool5ool000?ooooo4?oo000/ooooo`7o
00000Oooool00003o`000?oooooooooo02cooooo1Ooo000?ooooo`[oo`000oooool5ool00004oooo
oooo003oo`00ool000;ooooo2_oo0002ooooo`Goo`00A?oooolAool000Oooooo1Ooo0005ooooo`Go
o`000oooool5ool00003oooooooo003oo`00017oo`00:oooool1o`00007ooooo00000ol0003ooooo
ooooo`0[ooooo`Ooo`002Oooool4ool00003oooooooo003oo`0000Soo`000oooool5ool000Kooooo
2_oo0002ooooo`Goo`00A?ooool6ool00003oooooooo003oo`0000Ooo`002Oooool5ool00003oooo
oooo003oo`0000Koo`001?ooool3ool00003oooooooo003oo`0000Goo`0000Coooooool00?oo003o
o`001?ooool5ool002_ooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool:ool000Kooooo
4?oo0004ooooo`?oo`001oooool:ool000;ooooo1Ooo0014ooooo`Goo`001oooool3ool000Cooooo
0ooo0003ooooo`koo`002?ooool7ool000Sooooo1Ooo000[ooooo`7o00000Oooool00003o`000?oo
oooooooo02[ooooo2ooo0005ooooo`ooo`003oooool5ool00004oooooooo003oo`00ool000Cooooo
0ooo0015ooooo`Koo`003?ooool5ool000;ooooo3Ooo0009ooooo`Ooo`002Oooool3ool002cooooo
0Ol00001ooooo`0000?o0000ooooooooool0:_ooool;ool000Gooooo3ooo000?ooooo`Goo`00Cooo
ool7ool000cooooo1Ooo0003ooooo`?oo`0000?oooooool00?oo00001Ooo0003ooooo`?oo`001Ooo
ool6ool000Wooooo0ooo000/ooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo2_oo0004
oooooa3oo`0000Coooooool00?oo003oo`003?ooool3ool000Cooooo0ooo0018ooooo`Soo`003?oo
ool5ool000Sooooo1_oo0002ooooo`Goo`0000?oooooool00?oo00002?oo0007ooooo`Goo`00:ooo
ool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`?oo`000_ooool5ool000;ooooo1Ooo0000
0oooooooo`00ool00003ool00003oooooooo003oo`0000Soo`004Oooool5ool004Oooooo1ooo000>
ooooo`?oo`002Oooool5ool000?ooooo4?oo0007ooooo`Goo`00:oooool1o`00007ooooo00000ol0
003oooooooooo`0booooo`Goo`0000?oooooool00?oo00002Ooo00000oooooooo`00ool00008ool0
00;ooooo0ooo000<ooooo`Goo`00A_ooool6ool000kooooo0ooo000;ooooo`Goo`0000?oooooool0
0?oo00004?oo00001?ooooooo`00ool00?oo0003ooooo`Goo`00:oooool1o`00007ooooo00000ol0
003oooooooooo`0booooo`Goo`0000?oooooool00?oo00002?oo0002ooooo`[oo`0000?oooooool0
0?oo00001_oo0007ooooo`Koo`001_ooool3ool003gooooo1Ooo0009ooooo`[oo`002_ooool<ool0
0003oooooooo003oo`0000koo`000oooool3ool002cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0<_ooool5ool000;ooooo2?oo0003ooooo`Goo`0000Coooooool00?oo003oo`000_ooool9ool0
00Gooooo1_oo0006ooooo`Goo`00??ooool5ool000Sooooo2ooo000;ooooo`?oo`0000?oooooool0
0?oo00000ooo0003oooooa3oo`00<_ooool1o`00007ooooo00000ol0003oooooooooo`0cooooo`?o
o`001_ooool5ool000;ooooo1Ooo0007ooooo`Woo`001Oooool5ool000Oooooo1Ooo000looooo`Go
o`000_ooool3ool000?ooooo2ooo000?ooooo`Goo`000oooool@ool003;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0=?ooool3ool000Kooooo0ooo0002ooooo`Goo`002Oooool9ool000Cooooo
1Ooo0007ooooo`Goo`00>oooool6ool00003oooooooo003oo`0000?oo`000_ooool<ool000oooooo
0ooo0004ooooo`[oo`0000?oooooool00?oo00000_oo00001?ooooooo`00ool00?oo000_ooooo`7o
00000Oooool00003o`000?oooooooooo03?ooooo1Ooo000:ooooo`Goo`003Oooool6ool000;ooooo
1Ooo0009ooooo`?oo`00??ooool5ool000;ooooo1Ooo0003ooooo`_oo`002?ooool3ool000cooooo
0ooo00001?ooooooo`00ool00?oo0002ooooo`[oo`00;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0cooooo`Goo`002_ooool5ool000Oooooo0ooo0003ooooo`Koo`0000?oooooool00?oo0000
0ooo0008ooooo`?oo`00?_ooool5ool000;ooooo1Ooo0004ooooo`[oo`001oooool5ool001Cooooo
2_oo000^ooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo1Ooo000;ooooo`?oo`001ooo
ool5ool000?ooooo1Ooo00000oooooooo`00ool00003ool000;ooooo0ooo0002ooooo`Goo`00?_oo
ool3ool000Cooooo0ooo0006ooooo`?oo`000_ooool3ool000Sooooo1Ooo000Dooooo`[oo`00;_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`?oo`005_ooool5ool000?ooooo1?oo0002
ooooo`Goo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00004ool000Cooooo0ooo001F
ooooo`Goo`005?ooool5ool00004oooooooo003oo`00ool002oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<oooool3ool001Oooooo1Ooo0002ooooo`Goo`0000?oooooool00?oo00001?oo0000
0oooooooo`00ool00003ool00003oooooooo003oo`0000coo`00;oooool3ool0013ooooo1_oo000>
ooooo`?oo`0000Coooooool00?oo003oo`004Oooool5ool003?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0<_ooool5ool000[ooooo0ooo000:ooooo`?oo`000ooooolBool000;ooooo3Ooo000^
ooooo`Goo`003_ooool8ool0013ooooo1Ooo000@ooooo`Goo`00<oooool1o`00007ooooo00000ol0
003oooooooooo`0booooo`Goo`001_ooool8ool000oooooo3Ooo00001?ooooooo`00ool00?oo0004
ooooo`coo`00;_ooool5ool000kooooo2?oo000@ooooo`Goo`004Oooool3ool003Cooooo0Ol00001
ooooo`0000?o0000ooooooooool0<_ooool5ool000Gooooo2Ooo000@ooooo`coo`002Oooool:ool0
02oooooo1Ooo0002ooooo`?oo`000oooool3ool000?ooooo2?oo000@ooooo`Goo`00B?ooool1o`00
007ooooo00000ol0003oooooooooo`0cooooo`?oo`001_ooool9ool0017ooooo3Ooo0008ooooo`Oo
o`00<_ooool3ool000;ooooo1Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Oo
o`004Oooool3ool004Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool8ool0017ooooo
2Ooo00000oooooooo`00ool00003ool000[ooooo1Ooo0002ooooo`?oo`009oooool3ool000Oooooo
1Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Ooo`0000Coooooool00?oo003o
o`004?ooool6ool000?ooooo0ooo000;ooooo`?oo`00;oooool1o`00007ooooo00000ol0003ooooo
ooooo`0^ooooo`?oo`002oooool5ool001Cooooo3ooo000:ooooo`_oo`009Oooool5ool000Kooooo
1Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo0000
0ooo000>ooooo`Soo`0000?oooooool00?oo00000ooo0009ooooo`Goo`00;_ooool1o`00007ooooo
00000ol0003oooooooooo`0]ooooo`Goo`001?ooool3ool000?ooooo1Ooo000Dooooo`ooo`002_oo
ool;ool002Gooooo1Ooo0007ooooo`?oo`000oooool3ool000?ooooo1ooo00000oooooooo`00ool0
0003ool000kooooo2?oo00000oooooooo`00ool00004ool000Sooooo1Ooo000^ooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo1Ooo0003ooooo`Koo`000_ooool3ool000?ooooo0ooo000@
ooooo`Woo`0000Coooooool00?oo003oo`003?ooool:ool002Gooooo1Ooo000<ooooo`Koo`001?oo
ool3ool000;ooooo1Ooo000>ooooo`Soo`0000?oooooool00?oo00001?oo0008ooooo`Goo`00;_oo
ool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Goo`000oooool7ool000Kooooo1Ooo000A
ooooo`Koo`004oooool7ool000?ooooo0ooo000Qooooo`?oo`002Oooool3ool00003oooooooo003o
o`0000Goo`002Oooool3ool0013ooooo2?oo00000oooooooo`00ool00005ool000Oooooo0ooo000_
ooooo`7o00000Oooool00003o`000?oooooooooo02kooooo0ooo0004ooooo`Ooo`001_ooool5ool0
01;ooooo1_oo0003ooooo`?oo`0000Coooooool00?oo003oo`002Oooool3ool000Gooooo1Ooo000Q
ooooo`?oo`001oooool<ool000?ooooo0ooo000Iooooo`Goo`000_ooool7ool003Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0=_ooool9ool000?ooooo1Ooo000Dooooo`Goo`0000?oooooool0
0?oo00002?oo000<ooooo`Soo`005Oooool3ool000Sooooo1Ooo0006ooooo`coo`000_ooool5ool0
01Sooooo1_oo0003ooooo`Koo`00=oooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`?o
o`001?ooool8ool000;ooooo1Ooo000Doooooa7oo`001_ooool=ool001Cooooo1Ooo0002ooooo`?o
o`000_ooool5ool000Kooooo2ooo0003ooooo`Goo`006Oooool6ool000;ooooo1_oo000gooooo`7o
00000Oooool00003o`000?oooooooooo033ooooo1Ooo00001?ooooooo`00ool00?oo0002ooooo`Go
o`000_ooool5ool001Cooooo4Ooo00001Oooooooo`00ool00?oo003ooooo00goo`000_ooool3ool0
013ooooo1Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`001oooool8ool0
00Gooooo1Ooo000Booooo`Koo`000_ooool6ool000;ooooo1Ooo00001?ooooooo`00ool00?oo000c
ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo2_oo00000oooooooo`00ool00003ool0
0003oooooooo003oo`0000Coo`001oooool3ool00005oooooooo003oo`00ool00?ooool00ooo0003
oooooaooo`0000?oooooool00?oo00001_oo000?ooooo`Goo`0000?oooooool00?oo00000ooo0002
ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo2?oo0003ooooo`?oo`0000Co
ooooool00?oo003oo`003_ooool8ool00003oooooooo003oo`0000Coo`000oooool3ool00003oooo
oooo003oo`0000?oo`00<_ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`[oo`000_oo
ool3ool000;ooooo1Ooo0007ooooo`goo`001OoooolUool0013ooooo0ooo0002ooooo`Goo`001_oo
ool9ool00003oooooooo003oo`0000Ooo`001Oooool9ool000Wooooo3ooo0003ooooo`?oo`0000?o
ooooool00?oo00000ooo000booooo`7o00000Oooool00003o`000?oooooooooo037ooooo0ooo0000
0oooooooo`00ool00003ool000Oooooo1Ooo0007ooooo`koo`0000Goooooool00?oo003oo`00oooo
o`0Aool00003oooooooo003oo`00013oo`005_ooool3ool000Kooooo2_oo00000oooooooo`00ool0
0007ool000Gooooo2_oo0008ooooo`ooo`000_ooool:ool003;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool:ool000Sooooo0ooo0003ooooo`?oo`000_oooolSool00003oooooooo003o
o`0000?oo`0000?oooooool00?oo00002_oo0004ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool0013ooooo2ooo0002ooooo`Soo`001Oooool@ool000?ooooo3Ooo0003ooooo`Woo`00<ooo
ool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`[oo`003Oooool5ool000;ooooo0ooo0000
1Oooooooo`00ool00?oo003ooooo01ooo`000oooool3ool00004oooooooo003oo`00ool000Oooooo
3Ooo000>ooooo`Ooo`0000Coooooool00?oo003oo`001oooool3ool000Kooooo5?oo00000ooooooo
o`00ool00007ool000Gooooo2?oo000dooooo`7o00000Oooool00003o`000?oooooooooo033ooooo
1Ooo00001?ooooooo`00ool00?oo000>ooooo`Goo`0000?oooooool00?oo00000ooo0005ooooo`?o
o`0000?oooooool00?oo00002?oo00000oooooooo`00ool0000=ool000;ooooo1ooo0008ooooo`go
o`003_ooool6ool001Cooooo5_oo00000oooooooo`00ool00005ool000Oooooo1ooo000dooooo`7o
00000Oooool00003o`000?oooooooooo037ooooo0ooo000Cooooo`Goo`0000?oooooool00?oo0000
0ooo0009ooooo`Coo`0000?oooooool00?oo00007Ooo0002ooooo`?oo`000_ooool=ool000;ooooo
0ooo0009ooooo`Goo`005Oooool5ool000Gooooo3_oo000?ooooo`Goo`00=?ooool1o`00007ooooo
00000ol0003oooooooooo`0eooooo`?oo`004?ooool3ool000;ooooo2?oo0005ooooo`Goo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool0000Cool00003oooooooo003oo`0000?oo`000_oo
ool;ool000;ooooo1Ooo0009ooooo`?oo`005?ooool7ool000Cooooo4?oo0002ooooo`?oo`002_oo
ool3ool003Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool5ool00004oooooooo003o
o`00ool000_ooooo0ooo00000oooooooo`00ool00008ool000Cooooo1Ooo00000oooooooo`00ool0
000?ool000?ooooo2ooo00000oooooooo`00ool00003ool000;ooooo2?oo0005ooooo`Goo`000_oo
ool3ool000oooooo1_oo0005ooooo`Ooo`001?oooolAool00003oooooooo003oo`0000?oo`002?oo
ool3ool003Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<oooool;ool000Wooooo3ooo0004
ooooo`Goo`000_ooool?ool000Cooooo1Ooo0002ooooo`?oo`000_ooool5ool000;ooooo2?oo0005
ooooo`Goo`0000?oooooool00?oo00000ooo000=ooooo`Soo`001?ooool5ool000Kooooo2ooo0000
0oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`001oooool5ool003Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0<oooool;ool000Wooooo3ooo0005ooooo`?oo`001oooool;ool0
00Gooooo0ooo0009ooooo`?oo`001?ooool6ool000Kooooo1Ooo00000oooooooo`00ool00008ool0
00Oooooo2Ooo0004ooooo`Soo`000_ooool6ool00004oooooooo003oo`00ool000Cooooo0ooo0002
ooooo`Goo`001oooool5ool003Gooooo0Ol00001ooooo`0000?o0000ooooooooool0<oooool5ool0
0003oooooooo003oo`0000?oo`002Oooool5ool00004oooooooo003oo`00ool000;ooooo0ooo0003
ooooo`?oo`003Oooool8ool002?ooooo1_oo00000oooooooo`00ool00009ool000Gooooo2ooo0004
ooooo`Soo`0000?oooooool00?oo00000ooo000?ooooo`?oo`001?ooool3ool00003oooooooo003o
o`0000?oo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`?oo`000oooool3ool0
00_ooooo0ooo000;ooooo`Koo`003Oooool6ool001kooooo0ooo0003ooooo`Koo`000_ooool:ool0
00Cooooo3Ooo0006ooooo`Goo`0000?oooooool00?oo00000ooo000Eooooo`[oo`00=Oooool1o`00
007ooooo00000ol0003oooooooooo`16ooooo`?oo`003?ooool7ool0027ooooo0ooo000<ooooo`Go
o`000_ooool7ool000;ooooo2Ooo0004ooooo`goo`001_ooool5ool000;ooooo0ooo000Fooooo`Go
o`0000Coooooool00?oo003oo`00=_ooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`Go
o`000oooool3ool000Cooooo2?oo0004ooooo`?oo`002oooool3ool000;ooooo0ooo0006ooooo`Go
o`002oooool5ool000?ooooo1ooo0002ooooo`Soo`001?ooool=ool000Oooooo0ooo000Looooo`Go
o`00>_ooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`Goo`000_ooool5ool000?ooooo
1ooo0004ooooo`Goo`002Oooool:ool000Gooooo1Ooo0003ooooo`?oo`001Oooool6ool000?ooooo
1ooo0002ooooo`Ooo`001?ooool7ool000;ooooo0ooo0007ooooo`Goo`007?ooool3ool003_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0@?ooool3ool000;ooooo1Ooo0002ooooo`Goo`000ooo
ool5ool000Kooooo1Ooo0009ooooo`[oo`001Oooool5ool000;ooooo1Ooo0005ooooo`Koo`000ooo
ool6ool00003oooooooo003oo`0000Koo`001?ooool7ool000cooooo1Ooo0004ooooo`Coo`002Ooo
ool3ool004Kooooo0Ol00001ooooo`0000?o0000ooooooooool0>_ooool3ool000;ooooo2_oo0003
ooooo`Goo`001?ooool5ool000Gooooo1ooo0007ooooo`[oo`001Oooool4ool000?ooooo1_oo0005
ooooo`Goo`001?ooool5ool00003oooooooo003oo`0000Koo`000oooool8ool000cooooo1_oo0002
ooooo`Koo`001oooool5ool004Gooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool5ool0
0003oooooooo003oo`0000Woo`000oooool6ool000;ooooo2?oo0002ooooo`Soo`001oooool3ool0
0003oooooooo003oo`0000?oo`001?ooool5ool000?ooooo1ooo0004ooooo`Goo`001Oooool3ool0
00;ooooo2?oo0002ooooo`Woo`002Oooool:ool00003oooooooo003oo`0000Coo`001oooool5ool0
04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0>OoooolAool000Gooooo1Ooo00000ooooooo
o`00ool00007ool00003oooooooo003oo`0000Koo`002oooool5ool000Cooooo1_oo0003ooooo`Ko
o`001?ooool5ool000_ooooo1_oo0003ooooo`[oo`001oooool;ool00003oooooooo003oo`0000Co
o`001oooool5ool004Gooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool:ool00003oooo
oooo003oo`0000Coo`001Oooool5ool000;ooooo2?oo0002ooooo`Ooo`002oooool5ool000Cooooo
1_oo0004ooooo`Goo`001?ooool5ool000_ooooo1Ooo0003ooooo`_oo`001oooool5ool00003oooo
oooo003oo`0000?oo`0000?oooooool00?oo00000ooo0009ooooo`?oo`000oooool3ool0043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0>_ooool6ool000Cooooo1Ooo0002ooooo`?oo`0000?o
ooooool00?oo00000ooo0004ooooo`Koo`001Oooool5ool000_ooooo0ooo0004ooooo`Ooo`001Ooo
ool3ool000Gooooo1Ooo000;ooooo`Goo`000oooool;ool000Oooooo1Ooo0002ooooo`?oo`000ooo
ool3ool000oooooo1Ooo000oooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo1Ooo0000
0oooooooo`00ool00006ool00003oooooooo003oo`0000?oo`0000Coooooool00?oo003oo`001?oo
ool9ool000?ooooo1Ooo0002ooooo`?oo`003Oooool7ool000kooooo0ooo000:ooooo`Soo`000_oo
ool5ool000;ooooo0ooo0004ooooo`?oo`000_ooool3ool001_ooooo1Ooo000oooooo`7o00000Ooo
ool00003o`000?oooooooooo03cooooo0ooo00000oooooooo`00ool00006ool000;ooooo1Ooo0008
ooooo`[oo`000_ooool5ool00003oooooooo003oo`0000?oo`003?ooool7ool001[ooooo2Ooo0003
ooooo`Koo`001_ooool5ool000Kooooo0ooo000Fooooo`Goo`00?oooool1o`00007ooooo00000ol0
003oooooooooo`10ooooo`Koo`001?ooool6ool000Oooooo2ooo0002ooooo`?oo`000_ooool5ool0
00gooooo1Ooo0008ooooo`?oo`003?ooool3ool00003oooooooo003oo`0000Ooo`001Oooool5ool0
00Cooooo1_oo0005ooooo`Goo`005_ooool3ool0043ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0@?ooool6ool000Gooooo1Ooo0007ooooo`coo`001_ooool5ool000Gooooo0ooo0003ooooo`?o
o`002oooool5ool000[ooooo3Ooo0006ooooo`Koo`000oooool6ool000Gooooo1Ooo0006ooooo`?o
o`00D?ooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`Goo`001?ooool6ool000Oooooo
1Ooo00000oooooooo`00ool00004ool000Kooooo1?oo0005ooooo`Goo`0000?oooooool00?oo0000
0ooo000:ooooo`Goo`002_ooool:ool000Oooooo2Ooo0002ooooo`Goo`001_ooool5ool000Gooooo
1Ooo001?ooooo`7o00000Oooool00003o`000?oooooooooo04;ooooo0ooo0005ooooo`Goo`002?oo
ool5ool000;ooooo1Ooo0002ooooo`Soo`001Oooool5ool00003oooooooo003oo`0000?oo`002_oo
ool5ool000[ooooo6_oo0002ooooo`Goo`001oooool5ool000Cooooo1Ooo001?ooooo`7o00000Ooo
ool00003o`000?oooooooooo04[ooooo1Ooo0009ooooo`Goo`0000?oooooool00?oo00000ooo0000
0oooooooo`00ool00007ool000Cooooo1_oo00000oooooooo`00ool00003ool000Wooooo1Ooo000<
oooooaWoo`000_ooool5ool000?ooooo0ooo0002ooooo`Goo`000oooool5ool004oooooo0Ol00001
ooooo`0000?o0000ooooooooool0Boooool3ool000[ooooo1Ooo00000oooooooo`00ool00003ool0
0003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001_oo0003ooooo`?oo`002_ooool5ool0
00kooooo5_oo0003ooooo`Goo`000_ooool5ool00003oooooooo003oo`0000?oo`000oooool5ool0
04oooooo0Ol00001ooooo`0000?o0000ooooooooool0@_ooool3ool001?ooooo1Ooo0002ooooo`?o
o`000_ooool8ool00003oooooooo003oo`0000Ooo`001?ooool3ool000Wooooo1Ooo0002ooooo`?o
o`002_oooolDool000Gooooo0ooo0002ooooo`Koo`0000?oooooool00?oo00000ooo0003ooooo`Go
o`0000Coooooool00?oo003oo`00Boooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`Go
o`000_ooool3ool000kooooo0ooo0007ooooo`Goo`001Oooool8ool000Cooooo1Ooo0009ooooo`[o
o`003OoooolAool000Gooooo2_oo0002ooooo`?oo`0000?oooooool00?oo00002ooo001:ooooo`7o
00000Oooool00003o`000?oooooooooo047ooooo1Ooo00000oooooooo`00ool00003ool001Kooooo
1Ooo0006ooooo`Goo`0000?oooooool00?oo00000_oo0002ooooo`Goo`001Oooool3ool000;ooooo
2Ooo000=oooooa7oo`001?ooool:ool000Kooooo2?oo00000oooooooo`00ool00003ool004[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0@Oooool;ool001Kooooo1Ooo0007ooooo`[oo`0000?o
ooooool00?oo00000ooo0003ooooo`Koo`0000?oooooool00?oo00001ooo0007ooooo`?oo`001?oo
ool@ool000Cooooo2Ooo0007ooooo`Goo`001?ooool5ool004[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0@_ooool:ool001Kooooo1Ooo0009ooooo`Soo`000_ooool=ool00003oooooooo003o
o`0000Koo`001oooool5ool000Cooooo2_oo00001?ooooooo`00ool00?oo0005ooooo`[oo`001_oo
ool5ool000Gooooo0ooo001;ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo2Ooo0005
ooooo`?oo`002oooool5ool000[ooooo2?oo0004ooooo`_oo`000_ooool3ool000_ooooo1Ooo0003
ooooo`Koo`0000?oooooool00?oo00001?oo0008ooooo`_oo`001Oooool3ool000Gooooo1Ooo001:
ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo2_oo0003ooooo`Goo`0000Coooooool0
0?oo003oo`001Oooool5ool000_ooooo1ooo0005ooooo`[oo`003Oooool3ool00003oooooooo003o
o`0000Coo`000_ooool8ool00003oooooooo003oo`0000?oo`001oooool<ool000cooooo1Ooo001:
ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0ooo00000oooooooo`00ool00003ool0
00?ooooo2_oo0004ooooo`Goo`002oooool5ool000Oooooo2?oo000>ooooo`Goo`0000?oooooool0
0?oo00004ooo0006ooooo`goo`003?ooool5ool004[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0B_oooolBool000Cooooo1Ooo000;ooooo`Goo`002?ooool6ool000oooooo1Ooo0002oooooaCo
o`001_ooool>ool000cooooo0ooo001;ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo
4Ooo0005ooooo`?oo`003?ooool7ool000Kooooo1Ooo000@ooooo`Goo`000_ooool8ool000;ooooo
2_oo0006ooooo`ooo`00FOooool1o`00007ooooo00000ol0003oooooooooo`1<oooooaCoo`001ooo
ool3ool000Oooooo1ooo0003ooooo`Ooo`004Oooool3ool000Cooooo1ooo00000oooooooo`00ool0
0008ool000;ooooo0ooo0002ooooo`ooo`00FOooool1o`00007ooooo00000ol0003oooooooooo`1<
ooooo`[oo`0000?oooooool00?oo00002?oo0005ooooo`Goo`0000Goooooool00?oo003oo`00oooo
o`08ool000;ooooo2?oo000@ooooo`?oo`002?ooool3ool00003oooooooo003oo`0000?oo`0000?o
ooooool00?oo00000ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`000ooo
ool7ool005Wooooo0Ol00001ooooo`0000?o0000ooooooooool0COooool6ool000Cooooo2_oo0005
oooooa;oo`000_ooool7ool000oooooo1_oo000;ooooo`Goo`0000?oooooool00?oo00000ooo0000
0oooooooo`00ool00003ool000;ooooo0ooo0004ooooo`Koo`00F_ooool1o`00007ooooo00000ol0
003oooooooooo`1Hooooo`coo`000_oooolBool000;ooooo1Ooo0002ooooo`?oo`002oooool7ool0
00;ooooo0ooo0006ooooo`Goo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00003ool0
00Wooooo1Ooo001Kooooo`7o00000Oooool00003o`000?oooooooooo05[ooooo2ooo00000ooooooo
o`00ool0000@ool000?ooooo0ooo0002ooooo`Goo`002_ooool7ool00003oooooooo003oo`0000?o
o`001?ooool5ool000?ooooo2Ooo0005ooooo`?oo`000oooool3ool005cooooo0Ol00001ooooo`00
00?o0000ooooooooool0FOooool5ool000;ooooo2ooo00001?ooooooo`00ool00?oo0002ooooo`Oo
o`002?ooool5ool000Sooooo2?oo0002ooooo`Ooo`0000?oooooool00?oo00000ooo0005ooooo`So
o`001?ooool5ool0067ooooo0Ol00001ooooo`0000?o0000ooooooooool0FOoooolAool000[ooooo
1Ooo00001Oooooooo`00ool00?oo003ooooo00Ooo`001Oooool9ool000Cooooo3Ooo0005ooooo`Wo
o`000oooool5ool0067ooooo0Ol00001ooooo`0000?o0000ooooooooool0FOoooolAool000[ooooo
4?oo0005ooooo`Soo`001oooool<ool000Gooooo2Ooo0003ooooo`Goo`00HOooool1o`00007ooooo
00000ol0003oooooooooo`1Jooooo`ooo`002_ooool?ool000Oooooo2?oo0009ooooo`Woo`001ooo
ool8ool000Cooooo1_oo001Oooooo`7o00000Oooool00003o`000?oooooooooo05_ooooo2ooo0002
ooooo`?oo`001oooool@ool000Oooooo1ooo000;ooooo`?oo`0000Coooooool00?oo003oo`000_oo
ool3ool000?ooooo1ooo0004ooooo`Soo`00G_ooool1o`00007ooooo00000ol0003oooooooooo`1M
ooooo`ooo`001_ooool7ool00005oooooooo003oo`00ool00?ooool01Ooo0007ooooo`Goo`005?oo
ool5ool00003oooooooo003oo`0000Ooo`000oooool8ool005kooooo0Ol00001ooooo`0000?o0000
ooooooooool0G_ooool>ool000Cooooo2?oo0007ooooo`Goo`001_ooool5ool000Cooooo0ooo000=
ooooo`Goo`0000?oooooool00?oo00002?oo0002ooooo`Soo`00G_ooool1o`00007ooooo00000ol0
003oooooooooo`1Oooooo`goo`000oooool8ool000Sooooo1Ooo0006ooooo`Goo`000oooool5ool0
00cooooo1Ooo00000oooooooo`00ool0000Aool005oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0H?ooool6ool000;ooooo0ooo0004ooooo`Ooo`002Oooool5ool000Oooooo0ooo0004ooooo`Go
o`000oooool3ool000Oooooo5Ooo001Rooooo`7o00000Oooool00003o`000?oooooooooo063ooooo
1Ooo000:ooooo`Ooo`002?ooool<ool000Sooooo1Ooo0002ooooo`Woo`001?ooool5ool00003oooo
oooo003oo`0000_oo`00H_ooool1o`00007ooooo00000ol0003oooooooooo`1Pooooo`Goo`002ooo
ool<ool00003oooooooo003oo`0000coo`0000Coooooool00?oo003oo`001?ooool4ool000;ooooo
2_oo0003ooooo`Goo`0000?oooooool00?oo00002_oo001Sooooo`7o00000Oooool00003o`000?oo
oooooooo067ooooo0ooo000>oooooakoo`000oooool5ool00003oooooooo003oo`0000Soo`000_oo
ool6ool00003oooooooo003oo`0000Koo`00Ioooool1o`00007ooooo00000ol0003oooooooooo`1d
oooooacoo`000oooool5ool000;ooooo2Ooo00000oooooooo`00ool00006ool00004oooooooo003o
o`00ool006_ooooo0Ol00001ooooo`0000?o0000ooooooooool0M?oooolFool00003oooooooo003o
o`0000Coo`000_ooool5ool000;ooooo4_oo001_ooooo`7o00000Oooool00003o`000?oooooooooo
07Cooooo3Ooo00000oooooooo`00ool00003ool000Gooooo1Ooo0003ooooo`?oo`000ooooolBool0
06oooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool3ool000?ooooo1_oo00000ooooooo
o`00ool00004ool000Cooooo1Ooo0009oooooa7oo`00L?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1looooo`Goo`0000?oooooool00?oo00001Ooo0004ooooo`?oo`002_ooool@ool0077ooooo
0Ol00001ooooo`0000?o0000ooooooooool0OOooool3ool000?ooooo1_oo000Booooo`coo`00M?oo
ool1o`00007ooooo00000ol0003oooooooooo`24ooooo`Goo`005Oooool3ool007[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0QOooool3ool009?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generate sample EM results with varying number of component \
densities\
\>", "Subsection"],

Cell[BoxData[
    \(\(results = Table[EMAll1[data1, k], {k, 2, 15}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of training data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 -0.764651 0.00143398 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09574 -18 -4.5 ]
[-0.0125 .09574 0 4.5 ]
[-0.0125 .23913 -18 -4.5 ]
[-0.0125 .23913 0 4.5 ]
[-0.0125 .38253 -18 -4.5 ]
[-0.0125 .38253 0 4.5 ]
[-0.0125 .52593 -18 -4.5 ]
[-0.0125 .52593 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .09574 m
1 .09574 L
s
0 .23913 m
1 .23913 L
s
0 .38253 m
1 .38253 L
s
0 .52593 m
1 .52593 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09574 m
.00625 .09574 L
s
[(600)] -0.0125 .09574 1 0 Mshowa
0 .23913 m
.00625 .23913 L
s
[(700)] -0.0125 .23913 1 0 Mshowa
0 .38253 m
.00625 .38253 L
s
[(800)] -0.0125 .38253 1 0 Mshowa
0 .52593 m
.00625 .52593 L
s
[(900)] -0.0125 .52593 1 0 Mshowa
.125 Mabswid
0 .12442 m
.00375 .12442 L
s
0 .1531 m
.00375 .1531 L
s
0 .18178 m
.00375 .18178 L
s
0 .21046 m
.00375 .21046 L
s
0 .26781 m
.00375 .26781 L
s
0 .29649 m
.00375 .29649 L
s
0 .32517 m
.00375 .32517 L
s
0 .35385 m
.00375 .35385 L
s
0 .41121 m
.00375 .41121 L
s
0 .43989 m
.00375 .43989 L
s
0 .46857 m
.00375 .46857 L
s
0 .49725 m
.00375 .49725 L
s
0 .06706 m
.00375 .06706 L
s
0 .03838 m
.00375 .03838 L
s
0 .0097 m
.00375 .0097 L
s
0 .55461 m
.00375 .55461 L
s
0 .58329 m
.00375 .58329 L
s
0 .61197 m
.00375 .61197 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09574 m
1 .09574 L
s
.99375 .23913 m
1 .23913 L
s
.99375 .38253 m
1 .38253 L
s
.99375 .52593 m
1 .52593 L
s
.125 Mabswid
.99625 .12442 m
1 .12442 L
s
.99625 .1531 m
1 .1531 L
s
.99625 .18178 m
1 .18178 L
s
.99625 .21046 m
1 .21046 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .29649 m
1 .29649 L
s
.99625 .32517 m
1 .32517 L
s
.99625 .35385 m
1 .35385 L
s
.99625 .41121 m
1 .41121 L
s
.99625 .43989 m
1 .43989 L
s
.99625 .46857 m
1 .46857 L
s
.99625 .49725 m
1 .49725 L
s
.99625 .06706 m
1 .06706 L
s
.99625 .03838 m
1 .03838 L
s
.99625 .0097 m
1 .0097 L
s
.99625 .55461 m
1 .55461 L
s
.99625 .58329 m
1 .58329 L
s
.99625 .61197 m
1 .61197 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .4116 L
.17033 .4159 L
.24359 .49527 L
.31685 .51534 L
.39011 .50243 L
.46337 .56561 L
.53663 .5043 L
.60989 .53779 L
.68315 .56779 L
.75641 .54071 L
.82967 .58282 L
.90293 .56196 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .4116 Mdot
.17033 .4159 Mdot
.24359 .49527 Mdot
.31685 .51534 Mdot
.39011 .50243 Mdot
.46337 .56561 Mdot
.53663 .5043 Mdot
.60989 .53779 Mdot
.68315 .56779 Mdot
.75641 .54071 Mdot
.82967 .58282 Mdot
.90293 .56196 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0002Cooooo0ol0000Sooooo`?o00009?ooool3o`00027ooooo0ol00004oooo
o`;o00007_ooool3o`0000;ooooo1Ol0000Mooooo`?o00001?ooool3o`0001Kooooo000Iooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooo
ooooo`0Rooooo`Go00008_ooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooooooo
ooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`006oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0002?ooooo1?l0
000Tooooo`?o00008_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000002?o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`006?ooool01Ol0003ooooooooooooooooo000002Cooooo0_l0
000Tooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000
1?ooool01?l0003oooooooooool0000Mooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01gooooo0_l00005ooooo`;o00005oooool001Wooooo0ol0000Vooooo`03o`000?oooooooooo02?o
oooo0_l0000Tooooo`?o00008_ooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003o
ooooooooo`02ooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eooooo`03
00000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`02ooooo`<0o`009Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool10000007ooooo000E
ooooo`0400000?l0003oooooooooo`D0o`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00@00000
oooooooooooooooo1@3o000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00@00000oooooooooooooooo1@3o
000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool00_ooool30?l002Gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003o0000ooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000E
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool08oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool08oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00Ko
oooo00<00000ooooooooool08Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo0_l00004oooo
o`;o00001Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`001?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003o00000000O`070000O`030000000007l0001o0?/0001o0Ol000010000
007ooooo00000ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`0000?oooooo`000?ooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Pooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool000;ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`0Oooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`0Oooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`0Oooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`0Oooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool02?ooool00`00003ooooooooo
o`0Oooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo01kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo
01kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01ko
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01kooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01kooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003o0000ooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool07Oooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool07Oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0
003ooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool02oooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
3?ooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03Oooool00`00
003oooooooooo`0Jooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool03Oooool00`00003o
ooooooooo`0Jooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0=ooooo`0300000?oo
oooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0=ooooo`0300000?oooooo
oooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo
01Wooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`000_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Go
oooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`0300000?l00000001o00h0001o00<000000000O`0007l0m000
07l1o`00004000000Oooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0Hooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Hooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool000Go00000oooool2o`0000Cooooo0_l00005ooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo
013ooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000oooooooo
ool04?ooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
4?ooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04?oo
ool00`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04?ooool0
0`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00
003oooooooooo`0Fooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003o
ooooooooo`0Fooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003ooooo
ooooo`0Fooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool04Oooool00`00003ooooooooo
o`0Fooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Aooooo`0300000?oooooo
oooo01Kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo
01Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Go
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003o0000ooooo`0Cooooo`0300000?oooooooooo01Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000
007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007o
oooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0
003ooooo01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool05?ooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool05?ooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool05Oooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
5Oooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo
0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01;ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo
01;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Eooooo`0300000?oo
oooooooo01;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`0000Coooooo`000?l0003o00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l05P0007l00`000000
001o0000O`3/0000O`7o00000@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0F
ooooo`0300000?oooooooooo017ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0Fooooo`0300000?oooooooooo017ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Coooooo`000?l0003o0000
1?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool0
4Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool04Ooo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool04?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo01Gooooo0`3o000Booooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Go
oooo00<00000o`000?ooool05?ooool50?l000@000003?ooool30?l002Gooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003ooooo
ooooo`0Dooooo`D0o`001?ooool9000000;ooooo1@3o000Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Cooooo1@3o
000=ooooo`8000001@3o000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo01Gooooo0`3o000@ooooo`D0o`009?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Yooooo`<0o`009Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Ooooool0000002Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo
00<00000ooooooooool0:_ooool0100007ooooooooooo`00000Sooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo
00D0001ooooooooooooooooo0000000Rooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo02[ooooo00<0001oooooooooool0
0_ooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooooooo
o`03ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`04
ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`05oooo
o`0300000?oooooooooo01cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`06ooooo`03
00000?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`07ooooo`030000
0?oooooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`08ooooo`0300000?oo
oooooooo01Wooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`09ooooo`0300000?oooooo
oooo01Sooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01Gooooo00<00000o`000?ooool0:_ooool00`0007ooooooooooo`0:ooooo`0300000?oooooooooo
01Oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001oooo
o`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00_ooooo00<00000oooooooo
ool05_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00cooooo00<00000ooooooooool0
5Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00gooooo00<00000ooooooooool05?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Zooooo`030000Oooooooooooo00kooooo00<00000ooooooooool04oooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Zooooo`030000Oooooooooooo00oooooo0`3o000Booooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool03_ooool50?l0017ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool0:_ooool00`0007oooooo
ooooo`0>ooooo`D0o`0000<00000ooooooooool03_ooool00`0007ooooooooooo`0?ooooo`<0o`00
4_ooool00`0007ooooooooooo`0?ooooo`<0o`004_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool0:_ooool00`0007ooooooooooo`0>ooooo`D0o`0000?ooooo0000000000000P00
000<ooooo`030000Oooooooooooo00kooooo1@3o000Aooooo`030000Oooooooooooo00kooooo1@3o
000Aooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0?
ooooo`<0o`001_ooool4000000Sooooo00<0001oooooooooool03Oooool00`000000o`000?l00003
0?l0017ooooo00<0001oooooooooool03_ooool50?l0017ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Zooooo`030000Oooooooooooo01cooooo0`000004ooooo`<0o`001oooool70000
0003ooooo`3o0000o`0000<0o`004Oooool00`0007ooooooooooo`0>ooooo`D0o`0000<00000oooo
ooooool03_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001ooooooooo
ool07oooool3000000D0o`001P000009ooooo`<0o`0000?ooooo00000?ooool03oooool00`0007oo
ooooooooo`0=ooooo`0300000?ooool0o`000080o`000_ooool3000000gooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
00?oooooo`000?l000001Oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo02[ooooo
00<0001oooooooooool08_ooool50?l001Cooooo00<00000ooooooooool03Oooool00`0007oooooo
ooooo`0<ooooo`0300000?oooooooooo00Sooooo0P00000;ooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02;ooooo1@3o000Eooooo`80
00003Oooool00`0007ooooooooooo`0;ooooo`0300000?oooooooooo00_ooooo0P000009ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Soooo
o`<0o`006?ooool00`00003oooooooooo`0:ooooo`030000Oooooooooooo00Wooooo0P00000@oooo
o`8000001oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo00000ooooooo0000o`000002o`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o06`0001o00<00000
0000O`0007l0500007l00`000000001o0000O`0B0000O`800000J`0007l1o`00004000000Oooool0
0005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Wooooo00<00000ooooooooool02?ooool00`0007ooooooooooo`07ooooo`030000
0?oooooooooo01Gooooo0`0000001?ooool0o`000?l0003o000Uooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo00001Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Jooooo`8000002?ooool0
0`0007ooooooooooo`06ooooo`0300000?oooooooooo01Wooooo1@3o000Sooooo`<0o`009Oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo0_l00004
ooooo`;o00001Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool07?ooool00`00003oooooooooo`05ooooo`030000Oooooooooooo00Gooooo00<00000
ooooooooool06_ooool50?l002;ooooo1@3o000Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool07Oooool00`00003oooooooooo`04ooooo`030000Oooooooooooo00Cooooo00<00000oooo
ooooool06oooool50?l0008000008?ooool50?l002Cooooo00<0001oooooooooool05_ooool10000
007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Nooooo`0300000?oooooooooo00?ooooo00<0001oooooooooool00_ooool2000001oo
oooo0`3o0003ooooo`8000007?ooool2000000D0o`0000<00000ooooooooool08Oooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01oooooo0P000003ooooo`050000Ooooooooooooooooo`00
00008_ooool00`0007ooooooooooo`04ooooo`8000005oooool3000000?ooooo0`3o0002ooooo`03
00000?oooooooooo023ooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?l0003ooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Qooooo`040000
0?oooooooooo0000O`;ooooo00<00000ooooooooool08Oooool00`0007ooooooooooo`06ooooo`<0
00004Oooool3000000Oooooo00<0001oooooooooool00_ooool2000001kooooo0`3o000Gooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool08_ooool01@000000o`000?l0003o0000000002Cooooo00<0001ooooooooo
ool02Oooool2000000cooooo0`00000:ooooo`030000Oooooooooooo00Cooooo0P00000Kooooo`D0
o`005oooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Rooooo`D0o`009?ooool00`0007ooooooooooo`0;ooooo`800000
0_ooool30?l000;ooooo0`00000=ooooo`030000Oooooooooooo00Kooooo0P00000Iooooo`D0o`00
5oooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Rooooo`D0o`009?ooool00`0007ooooooooooo`0=ooooo`030000003o
0000o`0000<0o`0000<00000ooooooooool03_ooool00`0007ooooooooooo`08ooooo`0300000?oo
oooooooo01Cooooo0P0000050?l0008000005Oooool10000007ooooo000Eooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Rooooo`D0o`009?ooool0
0`0007ooooooooooo`0>ooooo`D0o`004Oooool00`0007ooooooooooo`09ooooo`8000004Oooool3
000000?ooooo0`3o0003ooooo`0300000?oooooooooo01;ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool08oooool30?l0
02Gooooo00<0001oooooooooool03_ooool50?l0017ooooo00<0001oooooooooool02oooool20000
00_ooooo10000008ooooo`030000Oooooooooooo00;ooooo0P00000Booooo`4000000Oooool001Go
oooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0?ooooo`<0o`004_ooool00`0007oo
ooooooooo`0=ooooo`0300000?ooool0o`000080o`000oooool3000000cooooo00<0001ooooooooo
ool01?ooool20000013ooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool03_ooool50?l0008000003oooool00`0007oooooo
ooooo`06ooooo`8000003_ooool10000007ooooo000Eooooo`0300000?l0003ooooo02[ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`D0o`004Oooool00`0007oooooooooo
o`08ooooo`0300000?oooooooooo00[ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`D0o`004Oooool0
0`0007ooooooooooo`09ooooo`8000002oooool10000007ooooo000Eooooo`0300000?oooooooooo
02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0?ooooo`<0o`004_ooool00`00
07ooooooooooo`0;ooooo`8000002Oooool10000007ooooo000Eooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo00go
oooo00<00000ooooo`3o00000P3o0004ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
3_ooool50?l000?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`D0o`000ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo00kooooo1@3o0003ooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool03oooool30?l000Cooooo0@000001ooooo`005Oooool00`00003o
0000ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`7o00000@000001ooooo`005Ooooooo000000/000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.579071, 500.231, \
0.0514022, 2.62607}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of test data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 -0.763962 0.00149641 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13388 -18 -4.5 ]
[-0.0125 .13388 0 4.5 ]
[-0.0125 .28352 -18 -4.5 ]
[-0.0125 .28352 0 4.5 ]
[-0.0125 .43316 -18 -4.5 ]
[-0.0125 .43316 0 4.5 ]
[-0.0125 .5828 -18 -4.5 ]
[-0.0125 .5828 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .13388 m
1 .13388 L
s
0 .28352 m
1 .28352 L
s
0 .43316 m
1 .43316 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13388 m
.00625 .13388 L
s
[(600)] -0.0125 .13388 1 0 Mshowa
0 .28352 m
.00625 .28352 L
s
[(700)] -0.0125 .28352 1 0 Mshowa
0 .43316 m
.00625 .43316 L
s
[(800)] -0.0125 .43316 1 0 Mshowa
0 .5828 m
.00625 .5828 L
s
[(900)] -0.0125 .5828 1 0 Mshowa
.125 Mabswid
0 .16381 m
.00375 .16381 L
s
0 .19374 m
.00375 .19374 L
s
0 .22367 m
.00375 .22367 L
s
0 .25359 m
.00375 .25359 L
s
0 .31345 m
.00375 .31345 L
s
0 .34338 m
.00375 .34338 L
s
0 .37331 m
.00375 .37331 L
s
0 .40324 m
.00375 .40324 L
s
0 .46309 m
.00375 .46309 L
s
0 .49302 m
.00375 .49302 L
s
0 .52295 m
.00375 .52295 L
s
0 .55288 m
.00375 .55288 L
s
0 .10395 m
.00375 .10395 L
s
0 .07403 m
.00375 .07403 L
s
0 .0441 m
.00375 .0441 L
s
0 .01417 m
.00375 .01417 L
s
0 .61273 m
.00375 .61273 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .13388 m
1 .13388 L
s
.99375 .28352 m
1 .28352 L
s
.99375 .43316 m
1 .43316 L
s
.99375 .5828 m
1 .5828 L
s
.125 Mabswid
.99625 .16381 m
1 .16381 L
s
.99625 .19374 m
1 .19374 L
s
.99625 .22367 m
1 .22367 L
s
.99625 .25359 m
1 .25359 L
s
.99625 .31345 m
1 .31345 L
s
.99625 .34338 m
1 .34338 L
s
.99625 .37331 m
1 .37331 L
s
.99625 .40324 m
1 .40324 L
s
.99625 .46309 m
1 .46309 L
s
.99625 .49302 m
1 .49302 L
s
.99625 .52295 m
1 .52295 L
s
.99625 .55288 m
1 .55288 L
s
.99625 .10395 m
1 .10395 L
s
.99625 .07403 m
1 .07403 L
s
.99625 .0441 m
1 .0441 L
s
.99625 .01417 m
1 .01417 L
s
.99625 .61273 m
1 .61273 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .42658 L
.17033 .47044 L
.24359 .56929 L
.31685 .5725 L
.39011 .57134 L
.46337 .58542 L
.53663 .57723 L
.60989 .56938 L
.68315 .56214 L
.75641 .59115 L
.82967 .59668 L
.90293 .60249 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .42658 Mdot
.17033 .47044 Mdot
.24359 .56929 Mdot
.31685 .5725 Mdot
.39011 .57134 Mdot
.46337 .58542 Mdot
.53663 .57723 Mdot
.60989 .56938 Mdot
.68315 .56214 Mdot
.75641 .59115 Mdot
.82967 .59668 Mdot
.90293 .60249 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0002Cooooo0ol0000Sooooo`?o00009?ooool3o`00027ooooo0ol00004oooo
o`;o00007_ooool3o`0000;ooooo1Ol0000Mooooo`?o00001?ooool3o`0001Kooooo000Iooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooo
ooooo`0Rooooo`Go00008_ooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooooooo
ooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`006oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0002?ooooo1?l0
000Tooooo`?o00008_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000002?o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`006?ooool01Ol0003ooooooooooooooooo000002Cooooo0_l0
000Tooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000
1?ooool01?l0003oooooooooool0000Mooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01gooooo0_l00005ooooo`;o00005oooool001Wooooo0ol0000Vooooo`03o`000?oooooooooo02?o
oooo0_l0000Tooooo`?o00008_ooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003o
ooooooooo`02ooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eooooo`03
00000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`02ooooo`?oo`009Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool10000007ooooo000E
ooooo`0400000?ooooooooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0400000?l0003o
ooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00@00000oooooooooooooooo1Ooo
000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool00_ooool3ool002Gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003o0000ooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool08Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00Kooooo00<0
0000ooooooooool08Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`0Pooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0Pooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0P
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Poooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000o`000?ooool01oooool00`00003oooooooooo`0Pooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01oooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01oooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01oooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo
00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo00001Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00001Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo00Wooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0004o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o
00T0001o00<000000000O`0007l0n@0007l1o`00004000000Oooool00003o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00000ooooooo0000ooooo`04oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`000_ooool2o`0000Cooooo0_l00004
ooooo`;o00001Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01kooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003o0000ooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eoooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool07Oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00cooooo
00<00000ooooooooool06oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool00`00
003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool00`00003o
ooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03Oooool00`00003ooooo
ooooo`0Jooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03Oooool00`00003ooooooooo
o`0Jooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0J
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000o`000?ooool03Oooool00`00003oooooooooo`0Joooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eoooo
o`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo01[o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo
000Eooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0002ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0@ooooo`0300000?oo
oooooooo01Oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0@ooooo`030000
0?oooooooooo01Oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o0100
001o00<000000000O`0007l0lP0007l1o`00004000000Oooool000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00
003oooooooooo`0@ooooo`0300000?oooooooooo01Oooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`0@ooooo`0300000?oooooooooo01Oooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo01Oooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001Ol0
0003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool04Oooool00`00003ooooooooo
o`0Fooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0F
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Foooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Fooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000o`000?ooool04Oooool00`00003oooooooooo`0Fooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o0000
0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Gooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Cooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003o0000ooooo`0Cooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo01?ooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Co
oooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Cooooo
00<00000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo01Cooooo00<0
0000ooooooooool04oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool05Oooool0
0`00003oooooooooo`0Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool05Oooool00`00
003oooooooooo`0Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool05Oooool00`00003o
ooooooooo`0Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool05Oooool00`00003ooooo
ooooo`0Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`0Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0B
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0Aoooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000o`000?ooool05_ooool00`00003oooooooooo`0Aooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo017ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo017ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo017ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo013ooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0Eooooo`?oo`004_ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00001?oooooo0000
o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool05?ooool5ool0017o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Dooooo`Goo`0000<00000
ooooooooool03_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000001o01@0001o
1Ooo00000`0007l000000000003Y0000O`7o00000@000001ooooo`0000Coooooo`000?l0003o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool05Oooool3ool000Cooooo0P00000<ooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00005o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool07_ooool00`00003oooooooooo`09ooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00005o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool07oooool2000000Wooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Coooooo`000?l0003o
00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo027ooooo00<00000oooooooo
ool01_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02;ooooo0P000006ooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000ooooooooool09?ooool00`00003oooooooooo`03ooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool09Oooool2000000?ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003o0000ooooo`0Wooooo`8000000ooo000Uooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0:?ooool5ool002Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo
00<00000ooooooooool0:?ooool5ool002Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:?ooool5ool002Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool0:Oooool3ool002Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooo0000000Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo02[ooooo00@0001oooooooooool000008oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`04
0000Oooooooooooo000002?ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000o`000?ooool0:_ooool01@0007ooooooooooooooool00000
02;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001oooo
o`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00;ooooo00<00000oooooooo
ool07oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00?ooooo00<00000ooooooooool0
7_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00Cooooo00<00000ooooooooool07Ooo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Zooooo`030000Oooooooooooo00Cooooo00<00000ooooooooool07Oooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Zooooo`030000Oooooooooooo00Gooooo00<00000ooooooooool07?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0Zooooo`030000Oooooooooooo00Kooooo00<00000ooooooooool06oooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0Zooooo`030000Oooooooooooo00Oooooo00<00000ooooooooool06_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000oooo
o`0Zooooo`030000Oooooooooooo00Oooooo00<00000ooooooooool06_ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool02?ooool00`00003oooooooooo`0Iooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
02[ooooo00<0001oooooooooool02Oooool00`00003oooooooooo`0Hooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool02_ooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo
00<0001oooooooooool02_ooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0
001oooooooooool02oooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001o
ooooooooool03?ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001ooooo
ooooool03Oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo02[ooooo00<0001ooooooooo
ool03_ooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooo
ooooo`0>ooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo00oooooo0ooo000Booooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0
001oooooooooool03oooool3ool001;ooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Sooooo`?oo`003?ooool3000000Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooo
oooo00kooooo1Ooo000@ooooo`?oo`004?ooool3ool001;ooooo00<0001oooooooooool08_ooool5
ool000;ooooo2@000003ooooo`Goo`000P00000?ooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001ooooo
ooooool03_ooool5ool000T000001_ooool5ool000kooooo1Ooo000Aooooo`030000Oooooooooooo
01oooooo0`000005ool0008000003?ooool5ool000;ooooo0P00000=ooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo00000ooooooo0000o`000005ooooo`;o
00001?ooool2o`0000Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0>ooooo`Go
o`002Oooool6000000Goo`003P000005ool0000300000?oooooooooo00kooooo00<0001ooooooooo
ool03oooool3ool000?ooooo2P000003ooooo`Goo`003oooool3ool000Gooooo0`00000:ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0003ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0?ooooo`?oo`004?ooool5ool0
00kooooo1Ooo00000oooool0000000000003000000_ooooo00<0001oooooooooool03Oooool00`00
003oo`00ool00003ool0008000003_ooool3ool001_ooooo0P000008ooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo0004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool08oooool3ool0013ooooo0ooo0007ooooo`D000001Oooool3
ool000Oooooo1`0000000oooooooo`00ool00003ool0017ooooo00<0001oooooooooool07?ooool3
000000Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
0003ooooool0003o000000;o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000o`000?ooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01kooooo10000005ool000H000002?ooool5ool0017ooooo00<0001oooooooooool07ooo
ool2000000;ooooo0ooo000Uooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo0000
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Rooooo`Goo`003oooool3ool001;ooooo00<0001oooooooooool08Oooool00`00003o
o`00ool00003ool002Cooooo00<0001oooooooooool05_ooool10000007ooooo00001Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0R
ooooo`Goo`009?ooool00`0007ooooooooooo`0Rooooo`Goo`000`00000<ooooo`?oo`004_ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo0_l00004
ooooo`;o00001Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool08oooool3ool002Gooooo00<0001oooooooooool08_ooool5ool000?ooooo2@000002
ooooo`Goo`003oooool3ool0017ooooo0ooo0004ooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Sooooo`?oo`003Oooool2000000Goo`0020000006oooo
o`Goo`003oooool5ool000?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool03_ooool5ool000Sooooo1P000005ool000l0
00001Ooo0003ooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo00oooooo0ooo000?ooooo`Goo`003oooool5ool000?ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool08_ooool3ool0017ooooo0ooo0004ooooo`4000000Oooool001Gooooo00<00000
o`000?ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool1o`00004000000Oooool001Goooooo`00000;0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.579071, 478.901, \
0.0514022, 2.51651}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the number of Gaussians (anti-annular region)", "Section"],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points for training and test data", "Subsubsection"],

Cell[BoxData[{
    \(\(n1 = 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2 = 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = 
        AntiAnnularRegion[c1, \ rr1, \ rr2, \ 
          n1];\)\), "\[IndentingNewLine]", 
    \(\(data2\  = AntiAnnularRegion[c1, \ rr1, \ rr2, \ n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize training data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.52508 .99009 Mdot
.59523 .09037 Mdot
.86654 .53326 Mdot
.23525 .82753 Mdot
.73459 .79089 Mdot
.11452 .92663 Mdot
.20604 .13992 Mdot
.73341 .07549 Mdot
.03758 .42945 Mdot
.12336 .50067 Mdot
.77882 .97452 Mdot
.29831 .03932 Mdot
.55337 .15679 Mdot
.35767 .1085 Mdot
.70545 .15466 Mdot
.6113 .09781 Mdot
.86023 .11961 Mdot
.49774 .58733 Mdot
.09122 .13528 Mdot
.52804 .96869 Mdot
.08918 .75814 Mdot
.95796 .55126 Mdot
.83892 .97609 Mdot
.96889 .86629 Mdot
.84891 .86611 Mdot
.88748 .74081 Mdot
.01376 .97929 Mdot
.28987 .01399 Mdot
.90614 .3909 Mdot
.73854 .21734 Mdot
.07702 .40501 Mdot
.09833 .52892 Mdot
.53317 .86837 Mdot
.20104 .77831 Mdot
.87388 .56008 Mdot
.822 .02579 Mdot
.86993 .57098 Mdot
.54193 .02161 Mdot
.17343 .80239 Mdot
.04301 .84077 Mdot
.50004 .9626 Mdot
.27901 .89886 Mdot
.44721 .88287 Mdot
.73662 .83154 Mdot
.89547 .87107 Mdot
.573 .03895 Mdot
.15771 .43429 Mdot
.71072 .04408 Mdot
.12451 .58371 Mdot
.96146 .43864 Mdot
.9885 .20878 Mdot
.52406 .54596 Mdot
.53097 .89419 Mdot
.38831 .04314 Mdot
.7918 .69917 Mdot
.88317 .05854 Mdot
.54161 .14257 Mdot
.85293 .79448 Mdot
.91509 .95892 Mdot
.33176 .89049 Mdot
.90568 .58001 Mdot
.89801 .55474 Mdot
.12368 .87103 Mdot
.49077 .95024 Mdot
.5978 .90151 Mdot
.76897 .24787 Mdot
.90624 .44359 Mdot
.40852 .55894 Mdot
.58429 .54329 Mdot
.12221 .96106 Mdot
.6688 .95348 Mdot
.55492 .09225 Mdot
.12583 .54478 Mdot
.46557 .46374 Mdot
.78262 .02691 Mdot
.54952 .02996 Mdot
.95543 .47687 Mdot
.0669 .08098 Mdot
.22724 .08012 Mdot
.0414 .26558 Mdot
.43482 .06301 Mdot
.06073 .59504 Mdot
.77943 .11754 Mdot
.23021 .25497 Mdot
.72234 .04637 Mdot
.98173 .10432 Mdot
.17143 .35117 Mdot
.95014 .82894 Mdot
.47787 .59333 Mdot
.95122 .82478 Mdot
.88664 .58539 Mdot
.25192 .75577 Mdot
.77544 .13714 Mdot
.30044 .8225 Mdot
.87721 .48801 Mdot
.81277 .23898 Mdot
.21114 .78508 Mdot
.85174 .4044 Mdot
.31469 .2095 Mdot
.13073 .81499 Mdot
.15039 .65087 Mdot
.86901 .06902 Mdot
.85452 .25935 Mdot
.64368 .92228 Mdot
.52275 .1171 Mdot
.64394 .05788 Mdot
.83276 .09037 Mdot
.03531 .65011 Mdot
.10103 .34302 Mdot
.6977 .09425 Mdot
.23671 .09347 Mdot
.20228 .74796 Mdot
.03586 .70859 Mdot
.03732 .75033 Mdot
.19476 .66977 Mdot
.35661 .0202 Mdot
.10353 .33655 Mdot
.6491 .91615 Mdot
.85702 .25289 Mdot
.89802 .3523 Mdot
.06767 .26945 Mdot
.87196 .63391 Mdot
.04015 .50931 Mdot
.49965 .9636 Mdot
.83559 .82974 Mdot
.15284 .9532 Mdot
.49393 .04686 Mdot
.87503 .25991 Mdot
.04711 .85907 Mdot
.13929 .51657 Mdot
.25752 .87285 Mdot
.50352 .84747 Mdot
.74807 .89945 Mdot
.65813 .02753 Mdot
.60503 .93644 Mdot
.90646 .51474 Mdot
.1209 .89939 Mdot
.04123 .26463 Mdot
.08359 .05013 Mdot
.9345 .52376 Mdot
.89602 .27182 Mdot
.9289 .73185 Mdot
.81811 .87229 Mdot
.22258 .87641 Mdot
.14879 .83609 Mdot
.3568 .97905 Mdot
.20449 .32214 Mdot
.05846 .31229 Mdot
.56921 .92957 Mdot
.31428 .90566 Mdot
.24533 .15377 Mdot
.48636 .04317 Mdot
.03256 .26755 Mdot
.87397 .42165 Mdot
.67929 .10932 Mdot
.8821 .70021 Mdot
.83345 .39773 Mdot
.60217 .48891 Mdot
.52897 .48227 Mdot
.05242 .4489 Mdot
.34388 .0872 Mdot
.35275 .0428 Mdot
.01967 .60595 Mdot
.12776 .89593 Mdot
.59964 .13774 Mdot
.98767 .63903 Mdot
.74574 .03554 Mdot
.35031 .92809 Mdot
.06563 .01452 Mdot
.23235 .04196 Mdot
.45619 .86697 Mdot
.93804 .52415 Mdot
.81808 .92406 Mdot
.48918 .91178 Mdot
.1388 .37775 Mdot
.69447 .15624 Mdot
.63864 .15152 Mdot
.55614 .4077 Mdot
.19226 .27475 Mdot
.6083 .87375 Mdot
.72374 .0468 Mdot
.89586 .11293 Mdot
.91701 .46354 Mdot
.78801 .09559 Mdot
.01913 .64593 Mdot
.04143 .1076 Mdot
.83937 .82305 Mdot
.83508 .36448 Mdot
.12543 .78605 Mdot
.42889 .96955 Mdot
.50207 .51581 Mdot
.83542 .29698 Mdot
.17495 .05746 Mdot
.14332 .94006 Mdot
.29415 .12682 Mdot
.17852 .33097 Mdot
.96797 .20203 Mdot
.94896 .63824 Mdot
.12335 .35107 Mdot
.76165 .25621 Mdot
.93859 .30341 Mdot
.07652 .47212 Mdot
.81517 .92626 Mdot
.35201 .89575 Mdot
.44055 .56246 Mdot
.95504 .87623 Mdot
.2797 .90644 Mdot
.13648 .16751 Mdot
.9859 .04239 Mdot
.88338 .46695 Mdot
.6437 .13683 Mdot
.45264 .89469 Mdot
.26026 .85971 Mdot
.48779 .02827 Mdot
.97075 .94347 Mdot
.16773 .23093 Mdot
.14261 .08113 Mdot
.84642 .98968 Mdot
.14691 .04855 Mdot
.95324 .53253 Mdot
.49341 .90191 Mdot
.24295 .052 Mdot
.03242 .60957 Mdot
.2624 .09873 Mdot
.72821 .23074 Mdot
.57029 .99001 Mdot
.71407 .01013 Mdot
.83023 .7267 Mdot
.25042 .82996 Mdot
.2278 .23019 Mdot
.48978 .98964 Mdot
.73132 .83728 Mdot
.90969 .98982 Mdot
.27058 .16992 Mdot
.20543 .9895 Mdot
.92733 .5217 Mdot
.4446 .53151 Mdot
.1069 .78519 Mdot
.20399 .69175 Mdot
.50002 .1105 Mdot
.96638 .47137 Mdot
.4864 .47192 Mdot
.56691 .47229 Mdot
.22631 .96643 Mdot
.91688 .93168 Mdot
.12922 .19104 Mdot
.61939 .09035 Mdot
.74651 .76857 Mdot
.46386 .57542 Mdot
.04944 .90757 Mdot
.6932 .82435 Mdot
.87619 .41944 Mdot
.67252 .17974 Mdot
.91107 .18143 Mdot
.91621 .40137 Mdot
.45702 .59621 Mdot
.6561 .10472 Mdot
.9531 .27057 Mdot
.63119 .89961 Mdot
.8619 .81618 Mdot
.62762 .90863 Mdot
.94375 .78638 Mdot
.96172 .81371 Mdot
.53617 .11735 Mdot
.01843 .55294 Mdot
.01459 .83835 Mdot
.14288 .03198 Mdot
.15128 .1636 Mdot
.58784 .834 Mdot
.40087 .07558 Mdot
.95041 .91556 Mdot
.97889 .11166 Mdot
.90135 .17185 Mdot
.97026 .54891 Mdot
.89656 .3237 Mdot
.60263 .89558 Mdot
.95204 .83356 Mdot
.86352 .89798 Mdot
.90331 .97262 Mdot
.12345 .4982 Mdot
.91462 .87076 Mdot
.93455 .33165 Mdot
.30594 .02225 Mdot
.87076 .67468 Mdot
.57081 .86756 Mdot
.01704 .76689 Mdot
.01965 .10957 Mdot
.10393 .78447 Mdot
.88639 .60157 Mdot
.17951 .90391 Mdot
.88363 .16559 Mdot
.8453 .54206 Mdot
.02267 .48111 Mdot
.01543 .70441 Mdot
.90169 .91013 Mdot
.37825 .95355 Mdot
.73199 .01603 Mdot
.50663 .42417 Mdot
.4515 .88328 Mdot
.17701 .22839 Mdot
.59471 .08286 Mdot
.89277 .65366 Mdot
.68321 .16293 Mdot
.94142 .1567 Mdot
.82997 .01199 Mdot
.53317 .56704 Mdot
.09148 .67396 Mdot
.90466 .45537 Mdot
.0217 .7919 Mdot
.93353 .45071 Mdot
.48757 .11139 Mdot
.98231 .30381 Mdot
.6478 .10921 Mdot
.54752 .57128 Mdot
.12443 .53236 Mdot
.71614 .11692 Mdot
.04276 .8486 Mdot
.4949 .43023 Mdot
.12829 .40304 Mdot
.85855 .8166 Mdot
.1164 .60134 Mdot
.91522 .3757 Mdot
.92311 .08169 Mdot
.96142 .40034 Mdot
.38539 .50061 Mdot
.84679 .85818 Mdot
.81384 .01938 Mdot
.17436 .95345 Mdot
.306 .14666 Mdot
.58876 .01501 Mdot
.95993 .50546 Mdot
.98871 .11492 Mdot
.07247 .19846 Mdot
.15172 .24694 Mdot
.23866 .8319 Mdot
.92286 .69505 Mdot
.04396 .61581 Mdot
.55169 .92409 Mdot
.07423 .12015 Mdot
.11344 .24463 Mdot
.07571 .01503 Mdot
.05078 .05598 Mdot
.91419 .75829 Mdot
.59592 .53074 Mdot
.9632 .89992 Mdot
.92904 .29392 Mdot
.91474 .77055 Mdot
.86462 .18357 Mdot
.79871 .17834 Mdot
.87471 .41024 Mdot
.14217 .24835 Mdot
.2886 .8697 Mdot
.72347 .82924 Mdot
.31559 .95997 Mdot
.25704 .1346 Mdot
.50232 .50209 Mdot
.8093 .9135 Mdot
.59928 .09043 Mdot
.5305 .05361 Mdot
.86601 .25139 Mdot
.22472 .08383 Mdot
.61877 .12659 Mdot
.83817 .39817 Mdot
.34565 .88628 Mdot
.77469 .94401 Mdot
.05284 .62484 Mdot
.82293 .63923 Mdot
.44375 .54421 Mdot
.08732 .5214 Mdot
.93936 .18584 Mdot
.23935 .13303 Mdot
.8839 .23695 Mdot
.86859 .45968 Mdot
.82555 .82503 Mdot
.41893 .03519 Mdot
.12651 .42996 Mdot
.81386 .97819 Mdot
.04899 .89876 Mdot
.86469 .80216 Mdot
.79984 .77553 Mdot
.90614 .54839 Mdot
.34301 .92898 Mdot
.66428 .87398 Mdot
.50765 .11375 Mdot
.25515 .84859 Mdot
.12585 .81332 Mdot
.13845 .42844 Mdot
.30219 .82533 Mdot
.09926 .51988 Mdot
.4277 .03297 Mdot
.86328 .68592 Mdot
.45424 .45378 Mdot
.24938 .75884 Mdot
.3256 .03515 Mdot
.93739 .92372 Mdot
.51949 .90055 Mdot
.93673 .76112 Mdot
.57286 .57496 Mdot
.44011 .58993 Mdot
.86348 .27259 Mdot
.08449 .01776 Mdot
.8253 .24911 Mdot
.10325 .78366 Mdot
.87811 .31559 Mdot
.85731 .288 Mdot
.91078 .51708 Mdot
.06503 .1294 Mdot
.34772 .93231 Mdot
.54043 .52171 Mdot
.06519 .85073 Mdot
.95214 .07687 Mdot
.81741 .95701 Mdot
.10463 .77907 Mdot
.45879 .56158 Mdot
.18405 .2718 Mdot
.40357 .44199 Mdot
.82653 .32968 Mdot
.77865 .90252 Mdot
.30651 .78981 Mdot
.53289 .11801 Mdot
.70568 .15119 Mdot
.24974 .93387 Mdot
.07549 .67188 Mdot
.84332 .14763 Mdot
.07447 .23531 Mdot
.86745 .69186 Mdot
.81664 .8349 Mdot
.57074 .89224 Mdot
.23598 .1793 Mdot
.57807 .58531 Mdot
.97643 .23563 Mdot
.33118 .0153 Mdot
.91075 .55395 Mdot
.47806 .85787 Mdot
.3032 .07077 Mdot
.01703 .43855 Mdot
.03079 .21272 Mdot
.39395 .47016 Mdot
.11024 .64896 Mdot
.90608 .60248 Mdot
.41904 .44701 Mdot
.5025 .96031 Mdot
.6051 .92711 Mdot
.90575 .18245 Mdot
.61235 .12148 Mdot
.36447 .88051 Mdot
.88722 .63601 Mdot
.24305 .03844 Mdot
.58719 .56337 Mdot
.0945 .59326 Mdot
.83742 .32565 Mdot
.48275 .43533 Mdot
.14906 .74793 Mdot
.8962 .71929 Mdot
.5695 .92409 Mdot
.0918 .14747 Mdot
.86308 .49295 Mdot
.31566 .91021 Mdot
.03546 .17711 Mdot
.0991 .93815 Mdot
.40366 .97424 Mdot
.9228 .45069 Mdot
.41565 .12709 Mdot
.8685 .18597 Mdot
.51711 .45703 Mdot
.9644 .71526 Mdot
.78188 .25623 Mdot
.0827 .47626 Mdot
.55027 .55346 Mdot
.12427 .72483 Mdot
.97782 .29732 Mdot
.18384 .64244 Mdot
.45955 .93553 Mdot
.06241 .81153 Mdot
.96991 .34507 Mdot
.2491 .94968 Mdot
.32247 .9763 Mdot
.20801 .26127 Mdot
.7014 .11851 Mdot
.60085 .97386 Mdot
.52737 .46626 Mdot
.96789 .43112 Mdot
.07762 .52093 Mdot
.91529 .60979 Mdot
.93557 .27452 Mdot
.16066 .86254 Mdot
.46183 .46632 Mdot
.4247 .03695 Mdot
.81405 .05329 Mdot
.23306 .88155 Mdot
.83635 .61236 Mdot
.16524 .37042 Mdot
.91126 .01238 Mdot
.96588 .72806 Mdot
.1526 .20974 Mdot
.91827 .4223 Mdot
.39217 .84232 Mdot
.11403 .37882 Mdot
.16891 .95097 Mdot
.26788 .75665 Mdot
.01347 .59036 Mdot
.24818 .06157 Mdot
.37114 .03582 Mdot
.02816 .57657 Mdot
.10008 .16407 Mdot
.1086 .33345 Mdot
.97624 .77545 Mdot
.92989 .37267 Mdot
.71817 .0286 Mdot
.92622 .77251 Mdot
.01982 .2387 Mdot
.06389 .34505 Mdot
.98186 .65233 Mdot
.89158 .49807 Mdot
.90553 .71282 Mdot
.52464 .46315 Mdot
.19717 .69402 Mdot
.89097 .95028 Mdot
.7962 .21021 Mdot
.83688 .61504 Mdot
.90315 .05981 Mdot
.98781 .33719 Mdot
.29458 .16639 Mdot
.98443 .20406 Mdot
.19804 .98405 Mdot
.94869 .89082 Mdot
.47075 .39578 Mdot
.85572 .81551 Mdot
.47313 .06839 Mdot
.86498 .19298 Mdot
.07941 .66752 Mdot
.12091 .76689 Mdot
.1065 .78152 Mdot
.57065 .50632 Mdot
.16262 .33696 Mdot
.9899 .83759 Mdot
.48994 .90193 Mdot
.13472 .65441 Mdot
.8115 .68076 Mdot
.06511 .97709 Mdot
.9344 .22 Mdot
.50803 .87856 Mdot
.92757 .38204 Mdot
.45563 .92962 Mdot
.92787 .53465 Mdot
.95589 .0375 Mdot
.80295 .87043 Mdot
.15419 .34693 Mdot
.74764 .88354 Mdot
.80349 .88367 Mdot
.80344 .67334 Mdot
.30521 .78497 Mdot
.95084 .94517 Mdot
.50501 .02535 Mdot
.43016 .86829 Mdot
.53932 .97805 Mdot
.61741 .98805 Mdot
.85997 .11432 Mdot
.06633 .43118 Mdot
.02235 .5259 Mdot
.06171 .57093 Mdot
.54689 .55538 Mdot
.95331 .35537 Mdot
.01738 .56752 Mdot
.61264 .91679 Mdot
.04081 .17914 Mdot
.02826 .64344 Mdot
.65829 .18542 Mdot
.95675 .08232 Mdot
.27481 .94215 Mdot
.41966 .51714 Mdot
.41209 .93982 Mdot
.95618 .24887 Mdot
.78964 .03284 Mdot
.49005 .98607 Mdot
.75863 .84389 Mdot
.08044 .18385 Mdot
.74017 .21025 Mdot
.41235 .98862 Mdot
.77362 .13773 Mdot
.14735 .05627 Mdot
.94187 .66116 Mdot
.85987 .21082 Mdot
.16203 .63813 Mdot
.30899 .0409 Mdot
.88683 .04247 Mdot
.8602 .45607 Mdot
.74929 .9764 Mdot
.91364 .53632 Mdot
.06357 .33531 Mdot
.40235 .53618 Mdot
.67414 .13016 Mdot
.01855 .74193 Mdot
.37495 .09906 Mdot
.36513 .16774 Mdot
.47831 .06639 Mdot
.71922 .08019 Mdot
.97907 .85659 Mdot
.74201 .20857 Mdot
.04175 .15591 Mdot
.07768 .08821 Mdot
.033 .40417 Mdot
.69292 .97934 Mdot
.22441 .92275 Mdot
.49539 .85236 Mdot
.18388 .66817 Mdot
.73978 .97608 Mdot
.938 .12934 Mdot
.70783 .82998 Mdot
.87012 .05093 Mdot
.187 .06179 Mdot
.03638 .19917 Mdot
.95279 .12923 Mdot
.85382 .6548 Mdot
.67975 .97683 Mdot
.76758 .92917 Mdot
.93017 .01055 Mdot
.81978 .80964 Mdot
.23214 .17077 Mdot
.93985 .76851 Mdot
.51112 .53599 Mdot
.6475 .87138 Mdot
.95794 .88475 Mdot
.03758 .884 Mdot
.79564 .72304 Mdot
.78604 .8031 Mdot
.26775 .98788 Mdot
.03319 .09638 Mdot
.10912 .58052 Mdot
.87085 .15946 Mdot
.14138 .68597 Mdot
.1136 .79216 Mdot
.30816 .07892 Mdot
.05021 .08124 Mdot
.19427 .03902 Mdot
.0627 .34325 Mdot
.3509 .87015 Mdot
.9393 .54128 Mdot
.98739 .3483 Mdot
.24655 .08041 Mdot
.13228 .75198 Mdot
.05296 .65364 Mdot
.07938 .41853 Mdot
.13028 .86745 Mdot
.91124 .08071 Mdot
.47953 .40509 Mdot
.91405 .7226 Mdot
.86919 .01416 Mdot
.96788 .3696 Mdot
.43977 .46138 Mdot
.92472 .70615 Mdot
.37019 .05265 Mdot
.24226 .92267 Mdot
.24972 .1754 Mdot
.32121 .85176 Mdot
.76039 .76051 Mdot
.39736 .13897 Mdot
.8814 .75615 Mdot
.73257 .11738 Mdot
.87939 .09122 Mdot
.519 .04837 Mdot
.5656 .46895 Mdot
.27908 .86317 Mdot
.50889 .11247 Mdot
.84702 .47821 Mdot
.14657 .01085 Mdot
.29853 .79392 Mdot
.40419 .88366 Mdot
.59634 .49205 Mdot
.88054 .67394 Mdot
.04055 .03291 Mdot
.11217 .6983 Mdot
.91973 .92771 Mdot
.78297 .92667 Mdot
.38858 .05281 Mdot
.7768 .83556 Mdot
.88646 .17143 Mdot
.96534 .12193 Mdot
.18263 .65256 Mdot
.05541 .18442 Mdot
.26264 .24795 Mdot
.86425 .20495 Mdot
.71539 .88773 Mdot
.09162 .64419 Mdot
.81913 .7261 Mdot
.33012 .12614 Mdot
.35498 .01402 Mdot
.30938 .8198 Mdot
.05655 .58165 Mdot
.18096 .67902 Mdot
.10067 .73252 Mdot
.62683 .06519 Mdot
.0927 .68015 Mdot
.71178 .95746 Mdot
.116 .78237 Mdot
.04843 .54535 Mdot
.06926 .21052 Mdot
.85766 .85653 Mdot
.87697 .81421 Mdot
.4117 .08484 Mdot
.7861 .09149 Mdot
.77507 .02945 Mdot
.03515 .46551 Mdot
.60977 .84374 Mdot
.97059 .37223 Mdot
.50357 .07118 Mdot
.93197 .81708 Mdot
.44411 .85085 Mdot
.08411 .95075 Mdot
.55734 .04645 Mdot
.6626 .87571 Mdot
.76144 .94515 Mdot
.87772 .85606 Mdot
.13613 .6359 Mdot
.21495 .16393 Mdot
.18844 .71388 Mdot
.52648 .49099 Mdot
.85005 .72228 Mdot
.12377 .24263 Mdot
.45341 .10856 Mdot
.97784 .59693 Mdot
.24826 .93483 Mdot
.36489 .0322 Mdot
.96527 .60758 Mdot
.18625 .30851 Mdot
.7762 .24088 Mdot
.69529 .8894 Mdot
.61076 .12477 Mdot
.16715 .02601 Mdot
.59369 .06945 Mdot
.90909 .08138 Mdot
.23861 .04705 Mdot
.93401 .464 Mdot
.06216 .72874 Mdot
.16762 .23292 Mdot
.49721 .11706 Mdot
.89829 .48303 Mdot
.79211 .21786 Mdot
.13999 .35186 Mdot
.61708 .49185 Mdot
.22109 .28028 Mdot
.27728 .80648 Mdot
.11947 .58336 Mdot
.82891 .6088 Mdot
.21137 .11014 Mdot
.04661 .40074 Mdot
.90423 .73227 Mdot
.81622 .83945 Mdot
.56275 .11974 Mdot
.81086 .89301 Mdot
.18561 .71029 Mdot
.96444 .60996 Mdot
.07002 .86788 Mdot
.58405 .96076 Mdot
.76339 .07756 Mdot
.42814 .08387 Mdot
.28845 .881 Mdot
.0332 .15523 Mdot
.21787 .86634 Mdot
.24021 .81746 Mdot
.9219 .38868 Mdot
.64635 .84689 Mdot
.21809 .02095 Mdot
.87316 .77913 Mdot
.78015 .92728 Mdot
.59452 .88832 Mdot
.53763 .5733 Mdot
.95209 .57547 Mdot
.26935 .81948 Mdot
.9287 .43004 Mdot
.06128 .94334 Mdot
.12958 .56446 Mdot
.06175 .74609 Mdot
.90168 .55331 Mdot
.17878 .95716 Mdot
.13133 .61623 Mdot
.57446 .07864 Mdot
.5839 .05273 Mdot
.61256 .49336 Mdot
.67406 .07312 Mdot
.96597 .46054 Mdot
.1531 .69604 Mdot
.91402 .70464 Mdot
.24161 .15253 Mdot
.12008 .5265 Mdot
.18039 .66884 Mdot
.52637 .48357 Mdot
.21182 .26992 Mdot
.87415 .12196 Mdot
.92915 .9898 Mdot
.89838 .65162 Mdot
.78585 .30357 Mdot
.97455 .93717 Mdot
.55405 .16084 Mdot
.23931 .2093 Mdot
.06872 .53065 Mdot
.90759 .15078 Mdot
.70558 .87106 Mdot
.76663 .87145 Mdot
.97097 .57768 Mdot
.42673 .42665 Mdot
.4949 .43514 Mdot
.97315 .79231 Mdot
.43598 .89468 Mdot
.07536 .65133 Mdot
.92527 .5493 Mdot
.58355 .88922 Mdot
.86537 .09985 Mdot
.18585 .88489 Mdot
.2029 .10239 Mdot
.93449 .75043 Mdot
.13734 .44125 Mdot
.01902 .21093 Mdot
.69108 .88504 Mdot
.19381 .76194 Mdot
.10131 .17017 Mdot
.58123 .45041 Mdot
.22614 .08013 Mdot
.40518 .55571 Mdot
.83607 .41541 Mdot
.89177 .65518 Mdot
.08455 .03169 Mdot
.88255 .45405 Mdot
.12318 .58916 Mdot
.10977 .39883 Mdot
.53215 .14856 Mdot
.87382 .32851 Mdot
.13678 .58304 Mdot
.04756 .90329 Mdot
.9149 .12972 Mdot
.14598 .25792 Mdot
.84015 .10784 Mdot
.25362 .79406 Mdot
.06215 .24466 Mdot
.42939 .15776 Mdot
.94258 .83602 Mdot
.88743 .01901 Mdot
.07857 .51731 Mdot
.04081 .60422 Mdot
.83575 .30625 Mdot
.88503 .3561 Mdot
.9858 .20822 Mdot
.45283 .46129 Mdot
.03325 .31333 Mdot
.13601 .30413 Mdot
.56771 .94444 Mdot
.36575 .86816 Mdot
.52019 .57172 Mdot
.64187 .98412 Mdot
.01046 .44169 Mdot
.08156 .90221 Mdot
.4118 .13411 Mdot
.05812 .59868 Mdot
.91231 .30436 Mdot
.20761 .69849 Mdot
.55636 .42639 Mdot
.04597 .84487 Mdot
.02904 .36434 Mdot
.51157 .48137 Mdot
.02838 .91285 Mdot
.43981 .56935 Mdot
.39149 .96087 Mdot
.83145 .14561 Mdot
.90322 .24973 Mdot
.96273 .08885 Mdot
.86705 .39505 Mdot
.9435 .7147 Mdot
.36528 .90388 Mdot
.92492 .79205 Mdot
.91567 .34433 Mdot
.32794 .01331 Mdot
.48669 .85789 Mdot
.0744 .69754 Mdot
.84324 .43039 Mdot
.8707 .35134 Mdot
.28452 .07237 Mdot
.9174 .62684 Mdot
.90944 .15868 Mdot
.98268 .82498 Mdot
.98397 .80455 Mdot
.66454 .82148 Mdot
.45979 .44069 Mdot
.18766 .95378 Mdot
.9493 .22296 Mdot
.5269 .55502 Mdot
.04967 .07409 Mdot
.0559 .25974 Mdot
.86007 .88895 Mdot
.68221 .92537 Mdot
.20091 .08571 Mdot
.94748 .79037 Mdot
.89349 .22011 Mdot
.98837 .57721 Mdot
.9485 .51293 Mdot
.83218 .92525 Mdot
.90241 .26299 Mdot
.96231 .0461 Mdot
.2899 .11093 Mdot
.13481 .36804 Mdot
.9227 .69916 Mdot
.03901 .48885 Mdot
.17935 .98085 Mdot
.65281 .82376 Mdot
.81083 .88871 Mdot
.83871 .85241 Mdot
.97312 .77079 Mdot
.84811 .41255 Mdot
.62611 .06192 Mdot
.68039 .83488 Mdot
.5969 .56327 Mdot
.51084 .84422 Mdot
.93429 .72971 Mdot
.13327 .8312 Mdot
.98096 .16157 Mdot
.28475 .96898 Mdot
.01765 .38097 Mdot
.71634 .22751 Mdot
.15973 .95862 Mdot
.10003 .17539 Mdot
.46954 .13354 Mdot
.49332 .60232 Mdot
.9489 .27952 Mdot
.54923 .86281 Mdot
.6591 .89341 Mdot
.42576 .04142 Mdot
.15081 .06263 Mdot
.51056 .40206 Mdot
.05083 .27832 Mdot
.83132 .06722 Mdot
.09213 .989 Mdot
.2919 .19461 Mdot
.42323 .10539 Mdot
.85634 .163 Mdot
.71533 .11017 Mdot
.0944 .97364 Mdot
.57403 .58139 Mdot
.9562 .60551 Mdot
.13468 .5481 Mdot
.83298 .36329 Mdot
.03726 .21849 Mdot
.96684 .2101 Mdot
.28237 .85476 Mdot
.26132 .10973 Mdot
.19777 .87131 Mdot
.95105 .82488 Mdot
.98505 .22917 Mdot
.09074 .97705 Mdot
.86016 .67127 Mdot
.03699 .31778 Mdot
.6028 .46409 Mdot
.06035 .11748 Mdot
.78923 .01755 Mdot
.14227 .71842 Mdot
.82837 .18287 Mdot
.51853 .4285 Mdot
.83352 .9439 Mdot
.4376 .44165 Mdot
.96355 .28243 Mdot
.79754 .75906 Mdot
.93637 .95485 Mdot
.20454 .30477 Mdot
.88582 .84718 Mdot
.86449 .69543 Mdot
.1064 .83943 Mdot
.73202 .96721 Mdot
.7759 .11667 Mdot
.45154 .44004 Mdot
.96856 .34781 Mdot
.50537 .47538 Mdot
.77382 .05284 Mdot
.89953 .3476 Mdot
.17731 .37059 Mdot
.25473 .1126 Mdot
.94421 .81227 Mdot
.17812 .7054 Mdot
.37829 .94028 Mdot
.86312 .47471 Mdot
.26318 .8465 Mdot
.50679 .96695 Mdot
.74022 .08715 Mdot
.49529 .96475 Mdot
.21696 .0885 Mdot
.02701 .7113 Mdot
.17067 .31313 Mdot
.10409 .41999 Mdot
.755 .80402 Mdot
.91555 .26124 Mdot
.37953 .02973 Mdot
.17237 .93142 Mdot
.95313 .04247 Mdot
.15517 .22992 Mdot
.53888 .86323 Mdot
.45 .41319 Mdot
.94756 .33391 Mdot
.04181 .08248 Mdot
.15291 .63822 Mdot
.98793 .4181 Mdot
.45345 .58492 Mdot
.89228 .93026 Mdot
.01326 .18154 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`0Uooooo`?oo`00X?ooool3ool001ko
oooo0ooo000Eooooo`?oo`000_ooool3ool001;ooooo0@000001ooooo`0000<00000ooooooooool0
3_ooool6ool0013ooooo1Ooo000Uooooo`?oo`002?ooool4ool000Cooooo0ooo0010ooooo`?oo`00
8?ooool5ool001cooooo1Ooo0008ooooo`?oo`002?ooool:ool0017ooooo0@000001ooooo`0000<0
0000ooooooooool03Oooool:ool000gooooo1Ooo000Tooooo`Goo`001_ooool6ool000;ooooo1Ooo
000nooooo`Goo`007oooool5ool00004oooooooo003oo`00ool000kooooo0ooo0004ooooo`Soo`00
1oooool5ool00004oooooooo003oo`00ool000?ooooo2_oo000Aooooo`4000000Oooool000030000
0?oooooooooo00gooooo2ooo000<ooooo`Goo`004Oooool3ool0013ooooo1Ooo00001?ooooooo`00
ool00?oo0002ooooo`Koo`000_ooool5ool003;ooooo0ooo0009ooooo`Goo`007oooool:ool000co
oooo1Ooo0002ooooo`Woo`001oooool:ool000;ooooo2_oo000Aooooo`4000000Oooool000030000
0?oooooooooo00gooooo2ooo000=ooooo`?oo`000oooool3ool000_ooooo1Ooo000?ooooo`[oo`00
00?oooooool00?oo00001?oo0002ooooo`Koo`009_ooool3ool000Oooooo1Ooo0008ooooo`Goo`00
8?ooool3ool00003oooooooo003oo`0000?oo`003?ooool5ool000;ooooo2?oo0008ooooo`[oo`00
0oooool3ool000;ooooo0ooo000Booooo`4000000Oooool0000300000?oooooooooo00kooooo2_oo
000Booooo`Goo`002_ooool5ool0013ooooo0ooo00000oooooooo`00ool00003ool000;ooooo1?oo
0004ooooo`Goo`000_ooool3ool001cooooo0ooo00000oooooooo`00ool00003ool000Kooooo1Ooo
0009ooooo`?oo`004Oooool3ool000kooooo2?oo0009ooooo`Soo`000_ooool7ool000[ooooo0ooo
00000oooooooo`00ool00003ool001gooooo0@000001ooooo`0000<00000ooooooooool01oooool3
ool000[ooooo0ooo000=ooooo`?oo`000oooool5ool000[ooooo1Ooo000Dooooo`Goo`002_ooool;
ool000[ooooo0ooo000=ooooo`[oo`001_ooool6ool001_ooooo1Ooo000<ooooo`Soo`002Oooool8
ool000Cooooo1_oo000?ooooo`?oo`007_ooool10000007ooooo00000`00003oooooooooo`06oooo
o`Goo`002?ooool5ool000_ooooo1Ooo0002ooooo`Goo`002oooool3ool001Kooooo0ooo0003oooo
o`?oo`001_ooool:ool000Oooooo1ooo000<ooooo`[oo`001oooool6ool001[ooooo1Ooo000<oooo
o`Goo`001?ooool3ool000Gooooo2Ooo0004ooooo`Goo`00<?ooool10000007ooooo00000`00003o
ooooooooo`06ooooo`Goo`002?ooool5ool000_ooooo1Ooo0003ooooo`?oo`001Oooool3ool000_o
oooo0ooo000=ooooo`?oo`001?ooool5ool000Kooooo2Ooo0006ooooo`Soo`003?ooool5ool00004
oooooooo003oo`00ool000Wooooo1Ooo0003ooooo`?oo`005?ooool5ool000cooooo1Ooo0003oooo
o`Goo`001?ooool9ool000Gooooo0ooo000Sooooo`?oo`002oooool10000007ooooo00000`00003o
ooooooooo`06ooooo`Goo`002?ooool5ool000_ooooo1Ooo000:ooooo`Goo`001oooool7ool000_o
oooo1ooo00000oooooooo`00ool00003ool000?ooooo3_oo0004ooooo`Soo`003Oooool3ool000ko
oooo1Ooo0002ooooo`Goo`005?ooool3ool000kooooo0ooo0004ooooo`Goo`001Oooool8ool001So
oooo0ooo000?ooooo`Goo`001Oooool3ool000;ooooo0@000001ooooo`0000<00000ooooooooool0
1oooool3ool000[ooooo0ooo000=ooooo`?oo`002oooool5ool000Kooooo2?oo000;ooooo`goo`00
0_ooool@ool000?ooooo1ooo000=ooooo`Koo`003Oooool5ool00003oooooooo003oo`0000?oo`00
8oooool7ool000;ooooo1Ooo0009ooooo`?oo`006?ooool5ool000kooooo1_oo0003ooooo`Goo`00
0Oooool10000007ooooo00000`00003oooooooooo`0Cooooo`?oo`003oooool3ool000[ooooo1Ooo
0006ooooo`Soo`002oooool8ool00004oooooooo003oo`00ool000?ooooo1Ooo0002ooooo`?oo`00
00?oooooool00?oo00000ooo0004ooooo`Koo`003Oooool7ool000?ooooo0ooo0007ooooo`[oo`00
8_ooool9ool000;ooooo0ooo000Uooooo`Goo`003_ooool7ool000;ooooo1Ooo0001ooooo`400000
0Oooool0000300000?oooooooooo01;ooooo1Ooo000=ooooo`Goo`002_ooool3ool000Oooooo1ooo
000=ooooo`Ooo`001oooool5ool00004oooooooo003oo`00ool000;ooooo1Ooo0005ooooo`Goo`00
3Oooool7ool000;ooooo1ooo0004ooooo`Goo`0000?oooooool00?oo00001?oo000Pooooo`Woo`00
2_ooool3ool000Wooooo0ooo000=ooooo`?oo`0000?oooooool00?oo00000ooo000>ooooo`Ooo`00
0_ooool5ool0007ooooo0@000001ooooo`0000<00000ooooooooool02_ooool3ool000Gooooo1Ooo
000=ooooo`Goo`001?ooool3ool000kooooo1ooo000?ooooo`?oo`002Oooool3ool00003oooooooo
003oo`0000?oo`0000?oooooool00?oo00000ooo0006ooooo`?oo`003oooool6ool000;ooooo2?oo
0003ooooo`Goo`000oooool5ool001oooooo2Ooo0009ooooo`Goo`001oooool5ool000_ooooo1Ooo
00001?ooooooo`00ool00?oo000@ooooo`Koo`000oooool3ool000;ooooo0@000001ooooo`0000<0
0000ooooooooool02Oooool5ool000Cooooo1Ooo000=ooooo`Koo`000_ooool5ool000oooooo1Ooo
000Oooooo`Goo`0000?oooooool00?oo00000ooo000Jooooo`?oo`000oooool8ool000Cooooo0ooo
0004ooooo`Goo`003Oooool3ool0013ooooo1ooo000:ooooo`Goo`001oooool5ool000_ooooo2?oo
0002ooooo`?oo`003_ooool3ool000Wooooo0@000001ooooo`0000<00000ooooooooool02Oooool5
ool000Gooooo0ooo000?ooooo`Goo`000_ooool8ool000cooooo1Ooo000Oooooo`Goo`0000?ooooo
ool00?oo00000ooo0009ooooo`?oo`005Oooool7ool000_ooooo1Ooo0008ooooo`?oo`0000?ooooo
ool00?oo00000ooo000Pooooo`Goo`001oooool5ool000_ooooo3_oo000Iooooo`4000000Oooool0
000300000?oooooooooo00Wooooo1Ooo000Gooooo`Koo`0000?oooooool00?oo00001ooo000<oooo
o`Goo`007oooool3ool000?ooooo0ooo0009ooooo`Goo`002?ooool3ool000cooooo0ooo000=oooo
o`?oo`002?ooool:ool0027ooooo0ooo0009ooooo`?oo`000_ooool3ool000Sooooo3Ooo000Ioooo
o`4000000Oooool0000300000?oooooooooo00[ooooo0ooo000Iooooo`Goo`000_ooool8ool000co
oooo1Ooo000<ooooo`?oo`008_ooool5ool000Oooooo1Ooo0004ooooo`?oo`005oooool3ool000Go
oooo2_oo000aooooo`Goo`001oooool=ool001Wooooo0@000001ooooo`0000<00000ooooooooool0
2_ooool3ool001Wooooo1Ooo0005ooooo`Goo`003?ooool5ool000Oooooo0ooo00000oooooooo`00
ool00003ool0027ooooo1Ooo0006ooooo`Koo`000oooool5ool001Gooooo1Ooo0004ooooo`Goo`00
00Coooooool00?oo003oo`001_ooool3ool002Wooooo1Ooo0006ooooo`Soo`000_ooool3ool001[o
oooo0@000001ooooo`0000<00000ooooooooool02Oooool5ool001Wooooo0ooo0007ooooo`?oo`00
3_ooool3ool000Oooooo2_oo000Hooooo`?oo`001oooool3ool000Oooooo1_oo0003ooooo`Goo`00
4?ooool3ool000;ooooo1Ooo0004ooooo`Goo`002Oooool5ool000gooooo0ooo0005ooooo`?oo`00
4?ooool5ool000Kooooo1Ooo000Cooooo`?oo`003?ooool10000007ooooo00000`00003ooooooooo
o`09ooooo`Soo`004oooool3ool001Gooooo0ooo0003ooooo`?oo`001oooool;ool001Kooooo1Ooo
000@ooooo`Goo`001?ooool5ool000oooooo1Ooo00000oooooooo`00ool00003ool000Gooooo0ooo
000:ooooo`Goo`002Oooool8ool000?ooooo1Ooo000@ooooo`?oo`001oooool5ool000Oooooo1ooo
0004ooooo`Goo`002oooool10000007ooooo00000`00003oooooooooo`07ooooo`_oo`004Oooool5
ool001?ooooo1Ooo00000oooooooo`00ool00003ool000Kooooo1Ooo00000oooooooo`00ool00004
ool001Gooooo1ooo0002ooooo`?oo`002_ooool3ool000Kooooo0ooo000@ooooo`Goo`000_ooool3
ool001?ooooo1Ooo0008ooooo`Woo`000oooool5ool001_ooooo0ooo0007ooooo`Woo`000oooool6
ool000[ooooo0@000001ooooo`0000<00000ooooooooool01_ooool?ool000kooooo1Ooo000=oooo
o`?oo`000_ooool6ool00003oooooooo003oo`0000?oo`001oooool3ool000?ooooo1Ooo0006oooo
o`?oo`003?ooool=ool002Gooooo1Ooo00000oooooooo`00ool00003ool001?ooooo0ooo0009oooo
o`[oo`000_ooool5ool002Gooooo2Ooo0003ooooo`Ooo`002Oooool10000007ooooo00000`00003o
ooooooooo`06oooooa3oo`003Oooool5ool000cooooo3?oo00000oooooooo`00ool00003ool000go
oooo1Ooo0005ooooo`Goo`003?ooool<ool0023ooooo0ooo0003ooooo`?oo`000_ooool5ool000?o
oooo0ooo000Iooooo`_oo`000_ooool3ool000Cooooo0ooo000:ooooo`?oo`002_ooool3ool000Go
oooo2Ooo0004ooooo`Ooo`002?ooool10000007ooooo00000`00003oooooooooo`06ooooo`Ooo`00
00?oooooool00?oo00001_oo000>ooooo`?oo`003OoooolAool000oooooo0ooo0006ooooo`Goo`00
3_ooool:ool001oooooo1Ooo0007ooooo`Koo`0000?oooooool00?oo00000ooo000Booooo`?oo`00
1?ooool3ool000;ooooo1Ooo0008ooooo`Goo`002?ooool5ool000Sooooo1Ooo0005ooooo`Ooo`00
1_ooool6ool000Sooooo0@000001ooooo`0000<00000ooooooooool01Oooool5ool000Oooooo1Ooo
000Nooooo`ooo`001?ooool3ool001?ooooo1Ooo0005ooooo`?oo`001oooool3ool000;ooooo0ooo
000Pooooo`Goo`001oooool<ool0017ooooo1Ooo0008ooooo`Goo`002?ooool5ool000Sooooo1Ooo
0008ooooo`Goo`004oooool5ool000Sooooo0@000001ooooo`0000<00000ooooooooool01?ooool5
ool000Wooooo0ooo000Pooooo`?oo`000_ooool3ool00003oooooooo003oo`0000?oo`000oooool5
ool001?ooooo0ooo0005ooooo`Goo`00;_ooool5ool000Oooooo3?oo000Aooooo`Goo`002Oooool3
ool000Wooooo1Ooo0008ooooo`Goo`001Oooool8ool001Cooooo0ooo0009ooooo`4000000Oooool0
000300000?oooooooooo00Cooooo1Ooo000[ooooo`Goo`001Oooool5ool000?ooooo1Ooo000Koooo
o`Goo`002_ooool3ool002;ooooo0ooo0009ooooo`[oo`001oooool3ool000Sooooo1Ooo000Eoooo
o`Goo`002Oooool3ool000Gooooo2?oo000Kooooo`?oo`000oooool10000007ooooo00001000003o
ooooooooooooool9ool002[ooooo1Ooo0006ooooo`?oo`001?ooool5ool001Oooooo0ooo00000ooo
ooooo`00ool00003ool000Wooooo1Ooo0004ooooo`?oo`00:_ooool5ool000Kooooo1_oo0003oooo
o`?oo`000_ooool3ool001Oooooo0ooo000<ooooo`?oo`000oooool5ool001gooooo1Ooo0002oooo
o`4000000Oooool0000300000?oooooooooo00_oo`00:Oooool7ool000Wooooo1_oo0004ooooo`?o
o`004?ooool5ool00004oooooooo003oo`00ool000[ooooo1Ooo0003ooooo`Goo`001_ooool3ool0
0003oooooooo003oo`0000?oo`006oooool3ool000Kooooo1ooo0002ooooo`Goo`001_ooool3ool0
023ooooo1Ooo0002ooooo`Goo`001Oooool3ool001Gooooo1Ooo0002ooooo`4000000Oooool00003
00000?oooooooooo00Goo`0000?oooooool00?oo00000ooo000Zooooo`Ooo`001oooool7ool000?o
oooo1Ooo000?ooooo`Goo`003_ooool5ool000?ooooo1Ooo0005ooooo`_oo`008oooool7ool000;o
oooo1Ooo0005ooooo`Goo`003_ooool3ool000kooooo1Ooo0002ooooo`Coo`001Oooool5ool001?o
oooo1ooo0001ooooo`4000000Oooool0000300000?oooooooooo00Goo`0000?oooooool00?oo0000
0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`008oooool5ool000Oooooo1ooo0003ooooo`Go
o`003oooool5ool000oooooo0ooo0004ooooo`Goo`001OoooolBool000Gooooo0ooo000Dooooo`Ko
o`000oooool5ool000;ooooo3?oo0009ooooo`Goo`003Oooool5ool00003oooooooo003oo`0000?o
o`001Oooool5ool001?ooooo2?oo00010000007ooooo00001000003oooooooooooooool3ool000?o
oooo0ooo0002ooooo`Woo`008_ooool5ool000Oooooo1_oo0004ooooo`Goo`004?ooool3ool001So
oooo0ooo0006oooooa?oo`000oooool5ool000[ooooo0ooo0007ooooo`?oo`001_ooool3ool000;o
oooo3_oo0008ooooo`Koo`003Oooool3ool000;ooooo2?oo0002ooooo`Goo`004?ooool;ool00040
00000Oooool0000300000?oooooooooo00cooooo2Ooo000Sooooo`?oo`002Oooool3ool000Oooooo
1Ooo0007ooooo`?oo`005_ooool3ool0017ooooo4_oo0003ooooo`Goo`002Oooool6ool001?ooooo
3_oo0008ooooo`Koo`004_ooool9ool000;ooooo0ooo000@ooooo`coo`000@000001ooooo`0000<0
0000ooooooooool03?ooool9ool003[ooooo1Ooo0005ooooo`Goo`005?ooool5ool001;ooooo4?oo
0003ooooo`Goo`002?ooool8ool000cooooo0ooo0003ooooo`Goo`0000?oooooool00?oo00001_oo
0009ooooo`Goo`004_ooool9ool000Sooooo0ooo0003ooooo`?oo`000_ooool7ool000?ooooo0ooo
0001ooooo`4000000Oooool0000300000?oooooooooo00gooooo1ooo000/ooooo`?oo`003?ooool5
ool000Gooooo1Ooo000Cooooo`Koo`002oooool3ool000Gooooo0ooo0004ooooo`Ooo`001Oooool3
ool000Wooooo2?oo000;ooooo`Goo`000oooool3ool000Kooooo0ooo000;ooooo`?oo`005?ooool8
ool000Oooooo1Ooo00000oooooooo`00ool0000;ool000Oooooo0@000001ooooo`0000<00000oooo
ooooool03Oooool5ool000?ooooo0ooo000Wooooo`Goo`0000Coooooool00?oo003oo`001oooool5
ool000Gooooo1Ooo000Booooo`Ooo`002_ooool5ool0027ooooo2_oo0003ooooo`?oo`001Oooool5
ool001Sooooo1?oo000Iooooo`?oo`002?ooool5ool00003oooooooo003oo`0000[oo`002?ooool1
0000007ooooo00000`00003oooooooooo`0=ooooo`Goo`000_ooool5ool001gooooo0ooo0006oooo
o`[oo`001oooool3ool000Oooooo0ooo000@ooooo`Woo`002oooool5ool0023ooooo2_oo0003oooo
o`Goo`001?ooool5ool001Oooooo1_oo000Sooooo`Goo`0000?oooooool00?oo00002?oo000:oooo
o`4000000Oooool0000300000?oooooooooo00kooooo0ooo0003ooooo`Goo`007?ooool5ool000Go
oooo2_oo000Sooooo`Woo`003?ooool5ool0017ooooo0ooo000<ooooo`Goo`002?ooool5ool000Go
oooo0ooo000Hooooo`Koo`009?ooool3ool000?ooooo0ooo0002ooooo`?oo`002oooool10000007o
oooo00000`00003oooooooooo`0Dooooo`Goo`007?ooool5ool000Kooooo0ooo00000oooooooo`00
ool00003ool000[ooooo0ooo000Fooooo`Soo`003_ooool3ool0017ooooo1Ooo000;ooooo`Goo`00
2?ooool5ool0023ooooo1_oo000<ooooo`Koo`00:oooool10000007ooooo00000`00003ooooooooo
o`0Eooooo`Goo`006oooool5ool000_ooooo0ooo000:ooooo`Goo`005Oooool5ool002?ooooo1ooo
000<ooooo`?oo`002?ooool5ool000oooooo0ooo000@ooooo`Coo`003?ooool8ool000oooooo0ooo
000Hooooo`4000000Oooool0000300000?oooooooooo00Gooooo0ooo000=ooooo`Goo`007?ooool3
ool000Sooooo1?oo000=ooooo`Goo`005_ooool3ool002?ooooo2?oo000Fooooo`Goo`003oooool5
ool001oooooo2?oo000>ooooo`Goo`005oooool10000007ooooo00000`00003oooooooooo`04oooo
o`Koo`002oooool5ool002Kooooo1_oo000<ooooo`Goo`007oooool3ool001[ooooo2_oo000Doooo
o`Goo`003?ooool8ool001oooooo2?oo000>ooooo`Goo`001Oooool3ool000oooooo0@000001oooo
o`0000<00000ooooooooool01?ooool7ool000_ooooo0ooo000Wooooo`Koo`003Oooool3ool001oo
oooo1Ooo000Iooooo`Goo`0000?oooooool00?oo00000ooo000Cooooo`Goo`002oooool9ool0023o
oooo1_oo0005ooooo`?oo`001oooool5ool000Cooooo1Ooo0008ooooo`?oo`000oooool10000007o
oooo00000`00003oooooooooo`04ooooo`Ooo`003Oooool3ool000cooooo0ooo000?ooooo`?oo`00
1?ooool6ool002oooooo1Ooo000Jooooo`?oo`000_ooool5ool001Cooooo0ooo000:ooooo`_oo`00
9oooool;ool000?ooooo1Ooo0004ooooo`Goo`001oooool5ool000;ooooo0@000001ooooo`0000<0
0000ooooooooool01Oooool6ool000cooooo1Ooo0006ooooo`?oo`0000?oooooool00?oo00000ooo
000=ooooo`Goo`001?ooool4ool000_ooooo0ooo000Aooooo`?oo`003_ooool5ool001oooooo1Ooo
000Pooooo`_oo`009oooool=ool000;ooooo1Ooo0004ooooo`Goo`001oooool5ool000;ooooo0@00
0001ooooo`0000<00000ooooooooool01oooool3ool000gooooo1Ooo0005ooooo`[oo`003Oooool5
ool00004oooooooo003oo`00ool000Sooooo0ooo0003ooooo`Goo`003oooool5ool000kooooo0ooo
000Pooooo`Goo`008?ooool7ool002_ooooo3Ooo00000oooooooo`00ool00003ool000Kooooo0ooo
0008ooooo`Goo`000_ooool10000007ooooo00000`00003oooooooooo`0Gooooo`Goo`001Oooool:
ool000gooooo2_oo00001?ooooooo`00ool00?oo0002ooooo`Goo`000_ooool5ool000oooooo1Ooo
000booooo`?oo`008Oooool5ool002gooooo4_oo000Cooooo`?oo`000oooool10000007ooooo0000
0`00003oooooooooo`05ooooo`Goo`003Oooool5ool000Gooooo1Ooo00001?ooooooo`00ool00?oo
000?ooooo`?oo`0000?oooooool00?oo00002?oo00000oooooooo`00ool00003ool000;ooooo1Ooo
000?ooooo`Goo`00E?ooool6ool001kooooo0ooo000>ooooo`?oo`001Oooool9ool001Wooooo0@00
0001ooooo`0000<00000oooooooo00000_oo0002ooooo`Ooo`003?ooool5ool000Kooooo0ooo000H
ooooo`[oo`0000?oooooool00?oo00000ooo0003ooooo`?oo`004Oooool3ool005Cooooo1Ooo000O
ooooo`Goo`001Oooool3ool000gooooo2ooo000Gooooo`4000000Oooool0000300000?oo003oo`00
00?oo`0000?oooooool00?oo00002?oo0004ooooo`?oo`000_ooool5ool002;ooooo2Ooo0002oooo
o`?oo`00K?ooool8ool001oooooo1Ooo0004ooooo`Goo`001_ooool4ool000?ooooo0ooo00000ooo
ooooo`00ool00005ool000Cooooo0ooo000?ooooo`4000000Oooool0000300000?oo003oo`0000?o
o`0000?oooooool00?oo00002Ooo0002ooooo`Goo`000_ooool3ool002?ooooo2?oo001aooooo`Wo
o`007oooool5ool000Cooooo1Ooo0005ooooo`Koo`001_ooool7ool000?ooooo1Ooo000>ooooo`40
00000Oooool0000300000?oo003oo`0000?oo`000_ooool:ool000;ooooo1Ooo000:ooooo`?oo`00
7?ooool3ool007Gooooo2?oo000Qooooo`?oo`001Oooool5ool000Gooooo1_oo0006ooooo`Ooo`00
0oooool5ool000kooooo0@000001ooooo`0000<00000oooooooo00000_oo0008ooooo`Goo`000_oo
ool5ool000Wooooo1Ooo000[ooooo`?oo`00IOooool5ool002gooooo0ooo0006ooooo`Koo`001ooo
ool5ool000Cooooo1Ooo000>ooooo`4000000Oooool0000300000?oooooooooo00Kooooo0ooo0002
ooooo`?oo`000_ooool5ool000[ooooo1Ooo000Zooooo`Goo`00IOooool3ool003Oooooo1Ooo000B
ooooo`?oo`003oooool10000007ooooo00000`00003oooooooooo`05ooooo`Goo`001Oooool5ool0
00_ooooo1Ooo000Zooooo`Goo`00Woooool5ool001[ooooo0ooo0002ooooo`?oo`000_ooool10000
007ooooo00000`00003oooooooooo`05ooooo`Goo`001Oooool5ool000cooooo0ooo000[ooooo`Go
o`00X?ooool3ool001[ooooo2_oo0001ooooo`4000000Oooool0000400000?ooooooooooooooo`?o
o`0000?oooooool00?oo00000ooo0005ooooo`Goo`004oooool3ool001Kooooo0ooo000<ooooo`?o
o`001?ooool3ool007Oooooo0ooo000=ooooo`?oo`003oooool5ool001Wooooo2_oo0001ooooo`40
00000Oooool0000300000?oooooooooo00Woo`001Oooool5ool001?ooooo1Ooo000Dooooo`Goo`00
4Oooool5ool007Gooooo1Ooo000;ooooo`Goo`003Oooool6ool001Wooooo2ooo00010000007ooooo
00000`00003oooooooooo`08ool000Kooooo1Ooo000Cooooo`Goo`005?ooool5ool0017ooooo1Ooo
001eooooo`Goo`002_ooool6ool000gooooo1_oo000Iooooo`_oo`000@000001ooooo`0000<00000
ooooooooool02Ooo0005ooooo`Goo`004oooool5ool001Cooooo1Ooo000Aooooo`Goo`00M?ooool6
ool000Wooooo1ooo000=ooooo`Goo`001_ooool3ool000Sooooo0ooo0006ooooo`_oo`000@000001
ooooo`0000@00000oooooooooooooooo2Ooo0005ooooo`?oo`005Oooool3ool001Kooooo0ooo000C
ooooo`?oo`00MOooool5ool000[ooooo1_oo000?ooooo`?oo`001_ooool5ool000Kooooo1Ooo0000
1?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool4ool0007ooooo0@000001ooooo`0000<00000
ooooooooool01?ooool6ool002Cooooo0ooo002Hooooo`?oo`000_ooool5ool000[ooooo1Ooo000I
ooooo`Goo`001_ooool:ool000_ooooo0@000001ooooo`0000<00000ooooooooool01Oooool5ool0
01kooooo2_oo000;ooooo`?oo`00R?ooool:ool000cooooo0ooo000Jooooo`Goo`001_ooool:ool0
00Kooooo0ooo0002ooooo`4000000Oooool0000300000?oooooooooo00Kooooo0ooo0008ooooo`?o
o`004oooool;ool000[ooooo1Ooo0027ooooo`Soo`00;?ooool3ool000Sooooo0ooo00000ooooooo
o`00ool00003ool000Gooooo1Ooo0001ooooo`4000000Oooool0000400000?ooooooooooooooo`?o
o`003?ooool5ool001;ooooo2ooo000:ooooo`Goo`00Qoooool8ool001Cooooo0ooo000Booooo`?o
o`004?ooool3ool000Cooooo1ooo0001ooooo`4000000Oooool0000300000?oooooooooo00Goo`00
2oooool5ool001;ooooo2_oo000;ooooo`Goo`00R?ooool7ool000[ooooo0ooo0006ooooo`Goo`00
4?ooool5ool001Gooooo2?oo0001ooooo`4000000Oooool0000300000?oooooooooo00Goo`002?oo
ool8ool000Oooooo1_oo0006ooooo`Ooo`003_ooool3ool008cooooo0ooo000:ooooo`Goo`001Ooo
ool5ool0013ooooo1Ooo000Eooooo`Ooo`000_ooool10000007ooooo00000`00003oooooooooo`05
ool000Oooooo2?oo0007ooooo`Soo`0000?oooooool00?oo00001?oo00001?ooooooo`00ool00?oo
000Iooooo`?oo`00S_ooool6ool000Gooooo2?oo000=ooooo`Goo`004?ooool3ool000;ooooo1Ooo
0004ooooo`4000000Oooool0000400000?ooooooooooooooo`?oo`002?ooool5ool000[ooooo4?oo
000Kooooo`Goo`00S?ooool7ool000Kooooo2?oo0005ooooo`Koo`000_ooool3ool000;ooooo0ooo
000;ooooo`Goo`000_ooool3ool000Gooooo0@000001ooooo`0000<00000ooooooooool03?ooool5
ool000[ooooo4?oo000Booooo`?oo`001_ooool5ool008_ooooo2Ooo0008ooooo`Goo`001?ooool8
ool000Gooooo1Ooo000:ooooo`Goo`002_ooool10000007ooooo00000`00003oooooooooo`0;oooo
o`Goo`003?ooool6ool00003oooooooo003oo`0000Koo`004Oooool5ool000Gooooo1Ooo002:oooo
o`_oo`001oooool5ool000Cooooo2Ooo0004ooooo`Goo`002_ooool5ool000[ooooo0@000001oooo
o`0000<00000ooooooooool02_ooool5ool001Gooooo1_oo000=ooooo`?oo`000_ooool5ool000Ko
oooo0ooo002;ooooo`_oo`002?ooool3ool000Cooooo2ooo0003ooooo`Soo`002?ooool3ool000_o
oooo0@000001ooooo`0000<00000ooooooooool01oooool8ool001Gooooo1Ooo000=ooooo`Goo`00
00?oooooool00?oo00000ooo002Dooooo`Goo`0000?oooooool00?oo00000ooo000?ooooo`_oo`00
0oooool9ool001Gooooo0@000001ooooo`0000<00000ooooooooool01Oooool=ool001;ooooo1Ooo
000=ooooo`Goo`000_ooool3ool009Kooooo0ooo0003ooooo`?oo`004?ooool5ool00003oooooooo
003oo`0000?oo`000oooool9ool001Gooooo0@000001ooooo`0000<00000ooooooooool01?ooool?
ool001;ooooo0ooo0008ooooo`?oo`000oooool6ool00;Cooooo2Ooo0003ooooo`[oo`001oooool3
ool000_ooooo0@000001ooooo`0000<00000ooooooooool01?ooool7ool000?ooooo1Ooo000Loooo
o`Koo`000_ooool5ool00;Kooooo1Ooo0004ooooo`Koo`0000Coooooool00?oo003oo`000oooool3
ool00003oooooooo003oo`0000?oo`002_ooool10000007ooooo00000`00003oooooooooo`04oooo
o`Woo`0000?oooooool00?oo00000ooo000Looooo`Ooo`0000?oooooool00?oo00001Ooo002doooo
o`Goo`001?ooool5ool000Oooooo2_oo000:ooooo`4000000Oooool0000300000?oooooooooo00Go
oooo0ooo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool001gooooo1ooo0002oooo
o`Ooo`00/oooool5ool000Cooooo1Ooo0007ooooo`coo`002?ooool10000007ooooo00000`00003o
ooooooooo`09ooooo`Goo`008_ooool6ool000Cooooo1Ooo002dooooo`?oo`001_ooool3ool000So
oooo3Ooo0007ooooo`4000000Oooool0000300000?oooooooooo00Wooooo1Ooo000Tooooo`?oo`00
1Oooool5ool00;;ooooo0ooo000Dooooo`coo`001oooool10000007ooooo00000`00003ooooooooo
o`0:ooooo`?oo`00;_ooool3ool00;;ooooo1Ooo000Aooooo`?oo`000_ooool3ool00003oooooooo
003oo`0000?oo`001oooool10000007ooooo00000`00003oooooooooo`3[ooooo`?oo`000_ooool5
ool0013ooooo1Ooo0006ooooo`?oo`0000Coooooool00?oo003oo`001?ooool10000007ooooo0000
0`00003oooooooooo`3Zooooo`Goo`0000?oooooool00?oo00000ooo000@ooooo`Goo`002Oooool5
ool000?ooooo0@000001ooooo`0000<00000ooooooooool08_ooool3ool0017ooooo0ooo002Toooo
o`?oo`002_ooool5ool000;ooooo0ooo000=ooooo`?oo`0000?oooooool00?oo00001?oo0008oooo
o`Goo`000oooool10000007ooooo00000`00003oooooooooo`0Qooooo`Goo`002oooool3ool00003
oooooooo003oo`0000?oo`00X_ooool5ool000Wooooo1Ooo000Aooooo`Goo`0000?oooooool00?oo
00001?oo0007ooooo`Koo`000_ooool10000007ooooo00000`00003oooooooooo`0<ooooo`?oo`00
4_ooool5ool000[ooooo2_oo002Rooooo`Goo`002Oooool5ool0017ooooo1Ooo0002ooooo`Goo`00
2?ooool5ool000;ooooo0@000001ooooo`0000<00000ooooooooool01Oooool3ool000?ooooo1Ooo
000Aooooo`Goo`001_ooool3ool00003oooooooo003oo`0000Soo`00X_ooool5ool000Wooooo1Ooo
0008ooooo`?oo`001_ooool5ool000;ooooo1Ooo0008ooooo`Goo`000_ooool10000007ooooo0000
0`00003oooooooooo`04ooooo`Goo`000_ooool5ool001;ooooo0ooo0006ooooo`[oo`0000Cooooo
ool00?oo003oo`00Y?ooool3ool000[ooooo1Ooo0007ooooo`Goo`001_ooool3ool000Cooooo0ooo
000:ooooo`?oo`000oooool10000007ooooo00000`00003oooooooooo`04ooooo`Koo`0000?ooooo
ool00?oo00000ooo000Kooooo`Goo`0000Coooooool00?oo003oo`000_ooool3ool00;;ooooo0ooo
0008ooooo`Goo`008?ooool10000007ooooo00000`00003oooooooooo`04ooooo`Koo`000_ooool3
ool001cooooo1Ooo0005ooooo`Goo`00/Oooool3ool000Sooooo1Ooo00001?ooooooo`00ool00?oo
000Looooo`4000000Oooool0000300000?oooooooooo00Gooooo1Ooo000Rooooo`?oo`001_ooool5
ool00:kooooo1ooo0007ooooo`Coo`0000?oooooool00?oo00000ooo000Kooooo`4000000Oooool0
000300000?oooooooooo00Kooooo0ooo000Vooooo`?oo`000oooool5ool00:gooooo2?oo0006oooo
o`Goo`0000?oooooool00?oo00000ooo0007ooooo`?oo`004Oooool10000007ooooo00000`00003o
ooooooooo`0>ooooo`?oo`002?ooool4ool0017ooooo1Ooo0003ooooo`?oo`00[_ooool8ool000Ko
oooo1Ooo00000oooooooo`00ool00003ool000Kooooo2?oo000=ooooo`4000000Oooool000030000
0?oooooooooo00gooooo1Ooo0006ooooo`Koo`003?ooool3ool00003oooooooo003oo`0000?oo`00
]?ooool7ool000Oooooo1Ooo0002ooooo`?oo`001oooool9ool000Sooooo0ooo0001ooooo`400000
0Oooool0000300000?oooooooooo00gooooo1Ooo0006ooooo`Koo`002oooool:ool00;Gooooo0ooo
000;ooooo`?oo`003Oooool9ool000Oooooo1Ooo00010000007ooooo00000`00003oooooooooo`0<
ooooo`Koo`001Oooool7ool000[ooooo1_oo00001?ooooooo`00ool00?oo003@ooooo`?oo`000_oo
ool8ool000;ooooo0ooo0002ooooo`Goo`000@000001ooooo`0000<00000ooooooooool03?ooool6
ool000Gooooo1_oo000:ooooo`Ooo`00coooool3ool00003oooooooo003oo`0000?oo`001Oooool3
ool000;ooooo1Ooo00000oooooooo`00ool00003ool0004000000Oooool0000300000?oooooooooo
00cooooo1_oo0005ooooo`Goo`000oooool3ool00005oooooooo003oo`00ool00?ooool02?oo0036
ooooo`?oo`001?ooool:ool000[ooooo2_oo0001ooooo`4000000Oooool0000300000?oooooooooo
00gooooo1Ooo0006ooooo`?oo`000ooooolBool00<Cooooo4_oo0007ooooo`goo`000Oooool10000
007ooooo00000`00003oooooooooo`0>ooooo`?oo`003Oooool9ool00003oooooooo003oo`0000Ko
o`00a?ooool=ool00004oooooooo003oo`00ool000Oooooo3_oo0001ooooo`4000000Oooool00003
00000?oooooooooo00Cooooo0ooo000Gooooo`Woo`001?ooool5ool00;[ooooo1?oo0006ooooo`go
o`002oooool8ool000;ooooo0ooo0002ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
1Ooo000Gooooo`Ooo`001_ooool3ool00;[ooooo1_oo0006ooooo`_oo`003?ooool5ool000[ooooo
0@000001ooooo`0000<00000ooooooooool00oooool5ool001Wooooo1Ooo0005ooooo`Koo`00^?oo
ool6ool000[ooooo0ooo000Aooooo`?oo`0000Coooooool00?oo003oo`001oooool10000007ooooo
00000`00003oooooooooo`03ooooo`Goo`006Oooool5ool000Cooooo2?oo002gooooo`Koo`005ooo
ool3ool000Oooooo1Ooo0006ooooo`4000000Oooool0000300000?oooooooooo00Cooooo0ooo000J
ooooo`Goo`001?ooool8ool00;Sooooo1?oo000Dooooo`Soo`001_ooool6ool000Gooooo0@000001
ooooo`0000<00000ooooooooool00ooo000Iooooo`?oo`000oooool5ool000?ooooo2?oo003?oooo
o`Woo`001_ooool6ool000Gooooo0@000001ooooo`0000<00000oooooooo00001?oo000Gooooo`Go
o`000_ooool5ool000Cooooo1_oo003@ooooo`Woo`001oooool5ool000Gooooo0@000001ooooo`00
00<00000oooooooo00001?oo000Gooooo`Goo`000_ooool5ool00=[ooooo2?oo0009ooooo`?oo`00
1_ooool10000007ooooo00000`00003oooooool00004ool001Oooooo1Ooo0003ooooo`?oo`00fOoo
ool:ool001;ooooo0@000001ooooo`0000<00000ooooooooool00ooo000Iooooo`?oo`00Hoooool3
ool006oooooo0ooo0007ooooo`[oo`004oooool10000007ooooo00000`00003oooooooooo`0Koooo
o`?oo`00Hoooool5ool006Cooooo1Ooo0004ooooo`Goo`001_ooool:ool001?ooooo0@000001oooo
o`0000<00000ooooooooool02Oooool3ool000kooooo1Ooo001Rooooo`Goo`002?ooool3ool005So
oooo1ooo0003ooooo`Goo`001_ooool9ool000Sooooo0ooo0009ooooo`4000000Oooool000030000
0?oooooooooo00Gooooo2?oo0004ooooo`?oo`001_ooool5ool00004oooooooo003oo`00ool005ko
oooo1ooo0005ooooo`Goo`00Eoooool?ool000Oooooo1ooo0008ooooo`Goo`002?ooool10000007o
oooo00000`00003oooooooooo`04ooooo`Woo`000oooool5ool000Gooooo2_oo001Nooooo`Ooo`00
1?ooool5ool000Wooooo0ooo001;ooooo`koo`002_ooool5ool000Sooooo1Ooo0008ooooo`400000
0Oooool0000300000?oooooooooo00Cooooo2Ooo0003ooooo`Goo`001_ooool3ool00003oooooooo
003oo`0000?oo`00F?ooool3ool000Gooooo1Ooo0004ooooo`Goo`002?ooool5ool004_ooooo2_oo
0002ooooo`?oo`002?ooool5ool000Sooooo1Ooo0008ooooo`4000000Oooool0000300000?oooooo
oooo00Cooooo2?oo0004ooooo`Goo`002_ooool5ool005Oooooo1Ooo0004ooooo`Goo`001Oooool3
ool000Wooooo1Ooo001<ooooo`Woo`0000?oooooool00?oo00000ooo0008ooooo`?oo`002_ooool3
ool000Wooooo0@000001ooooo`0000<00000ooooooooool01Oooool3ool000Wooooo1?oo0004oooo
o`?oo`001?ooool3ool005Sooooo1Ooo0005ooooo`?oo`004_ooool5ool004_ooooo2Ooo0002oooo
o`Goo`007Oooool3ool0007ooooo0@000001ooooo`0000<00000ooooooooool04Oooool5ool000;o
oooo1Ooo001Nooooo`Goo`006oooool3ool004cooooo2Ooo0002ooooo`Koo`002?ooool3ool0013o
oooo1Ooo00010000007ooooo00000`00003oooooooooo`0Aooooo`Goo`000_ooool5ool005Wooooo
0ooo0003ooooo`?oo`003_ooool3ool000_ooooo0ooo001<ooooo`Soo`000oooool6ool000Oooooo
1Ooo000?ooooo`Goo`000@000001ooooo`0000<00000ooooooooool01_ooool3ool000Sooooo1Ooo
0002ooooo`Goo`000oooool6ool004oooooo1Ooo000?ooooo`[oo`001oooool5ool004cooooo1Ooo
0005ooooo`Koo`001oooool7ool000gooooo1Ooo00010000007ooooo00000`00003oooooooooo`05
ooooo`Goo`001?ooool3ool00004oooooooo003oo`00ool000Cooooo0ooo0003ooooo`Soo`000_oo
ool3ool004Wooooo1Ooo000>ooooo`coo`001_ooool5ool004gooooo1Ooo0004ooooo`Goo`002?oo
ool8ool000Oooooo0ooo0003ooooo`?oo`000Oooool10000007ooooo00000`00003oooooooooo`05
ooooo`Goo`000oooool5ool000gooooo2?oo00000oooooooo`00ool00003ool004Sooooo1Ooo000<
ooooo`koo`001_ooool5ool004gooooo1Ooo0005ooooo`?oo`002_ooool7ool000Kooooo1Ooo0006
ooooo`4000000Oooool0000300000?oooooooooo00?oo`000_ooool5ool000?ooooo1Ooo000=oooo
o`Soo`0000?oooooool00?oo00000ooo0019ooooo`?oo`001?ooool5ool000?ooooo3ooo0007oooo
o`?oo`00C_ooool5ool001Cooooo1Ooo0005ooooo`Koo`001_ooool10000007ooooo00000`00003o
o`00ool00004ool000;ooooo0ooo0004ooooo`Goo`003_ooool7ool00003oooooooo003oo`0000?o
o`00@_ooool3ool000Oooooo2_oo0002ooooo`Soo`000oooool3ool005[ooooo0ooo000?ooooo`?o
o`001?ooool3ool000Gooooo1ooo0006ooooo`4000000Oooool000Ooo`002_ooool3ool0017ooooo
1Ooo0002ooooo`?oo`00@_ooool8ool000;ooooo2ooo0002ooooo`Soo`00LOooool5ool000_ooooo
1_oo0007ooooo`4000000Oooool000Ooo`001_ooool3ool001Gooooo1Ooo0017ooooo`Woo`0000?o
ooooool00?oo00002Ooo0003ooooo`Koo`005_ooool3ool005Wooooo1Ooo00000oooooooo`00ool0
0004ool000Cooooo1Ooo0008ooooo`4000000Oooool000Koo`001_ooool5ool001Gooooo0ooo0018
ooooo`Woo`0000?oooooool00?oo00002?oo000Oooooo`Goo`00D_ooool3ool000?ooooo3Ooo0004
ooooo`?oo`002Oooool10000007ooooo00001000003oo`00ool00?oo0008ooooo`Goo`00HOooool8
ool000;ooooo0ooo00000oooooooo`00ool00003ool000kooooo0ooo000>ooooo`Goo`00C?ooool3
ool000;ooooo1Ooo0003ooooo`?oo`0000?oooooool00?oo00001_oo000@ooooo`4000000Oooool0
000300000?oooooooooo00Wooooo1Ooo001Uooooo`?oo`000oooool3ool00003oooooooo003oo`00
00?oo`003Oooool5ool000gooooo1Ooo001;ooooo`_oo`000_ooool=ool000Gooooo0ooo0008oooo
o`4000000Oooool0000300000?oooooooooo00Gooooo0ooo0002ooooo`?oo`00Joooool<ool000_o
oooo1_oo000=ooooo`?oo`000oooool3ool004Kooooo2ooo0002ooooo`coo`001Oooool5ool000Oo
oooo0@000001ooooo`0000<00000ooooooooool01?ooool5ool006oooooo3Ooo000:ooooo`Ooo`00
2?ooool3ool000Kooooo1Ooo0015ooooo`_oo`000_ooool=ool000Cooooo1Ooo0007ooooo`400000
0Oooool0000300000?oooooooooo00Cooooo1Ooo0008ooooo`?oo`00F?ooool3ool000Wooooo3Ooo
0002ooooo`?oo`001_ooool7ool000Kooooo1Ooo0005ooooo`Goo`00A_ooool;ool000;ooooo3?oo
0004ooooo`Goo`001oooool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`001oooool5
ool005Kooooo1Ooo0009ooooo`?oo`0000?oooooool00?oo00001_oo00000oooooooo`00ool00003
ool00004oooooooo003oo`00ool000;ooooo1_oo0006ooooo`Goo`001Oooool5ool004Oooooo1?oo
00000oooooooo`00ool00003ool000Cooooo2_oo0004ooooo`Goo`001oooool10000007ooooo0000
0`00003oooooooooo`05ooooo`?oo`002?ooool6ool005Gooooo1Ooo000?ooooo`Goo`000_ooool:
ool000;ooooo1Ooo0006ooooo`Goo`001_ooool3ool004?ooooo0ooo00000oooooooo`00ool00003
ool00003oooooooo003oo`0000?oo`001Oooool3ool000;ooooo0ooo0003ooooo`Ooo`001oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`?oo`002oooool7ool005Cooooo1Ooo000@oooo
o`?oo`000oooool;ool000;ooooo0ooo0007ooooo`Goo`00Boooool:ool000;ooooo0ooo00001?oo
ooooo`00ool00?oo000<ooooo`Soo`001oooool10000007ooooo00001000003oooooooooooooool5
ool000_ooooo1_oo001Eooooo`?oo`006?ooool3ool00003oooooooo003oo`0000[oo`001oooool3
ool004cooooo2_oo0005ooooo`Goo`002oooool7ool000Sooooo0@000001ooooo`0000@00000oooo
oooooooooooo1Ooo00001?ooooooo`00ool00?oo0008ooooo`Goo`00MOooool;ool0017ooooo0ooo
0012ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo1Ooo000;ooooo`Goo`00
2_ooool10000007ooooo00001000003oooooooooooooool:ool000Sooooo0ooo001gooooo`[oo`00
3oooool9ool003oooooo0ooo0002ooooo`Soo`0000?oooooool00?oo00000ooo000<ooooo`?oo`00
2oooool10000007ooooo00000`00003oooooooooo`02ooooo`?oo`0000?oooooool00?oo00000ooo
0023ooooo`Soo`003oooool;ool004;ooooo2Ooo0002ooooo`?oo`006oooool10000007ooooo0000
0`00003oooooooooo`06ooooo`Goo`005?ooool3ool004Sooooo0ooo000Tooooo`Goo`003oooool;
ool004;ooooo3?oo000Mooooo`4000000Oooool0000300000?oooooooooo00Oooooo0ooo000Doooo
o`Goo`00A_ooool5ool001gooooo0ooo0003ooooo`Goo`003oooool;ool004;ooooo3Ooo000Loooo
o`4000000Oooool0000300000?oooooooooo01kooooo1Ooo0016ooooo`Goo`007?ooool5ool000?o
oooo0ooo000:ooooo`?oo`001?ooool3ool000;ooooo1?oo0014ooooo`?oo`001?ooool5ool0013o
oooo0ooo0009ooooo`4000000Oooool0000300000?oooooooooo00Oooooo0ooo000Dooooo`Goo`00
A_ooool5ool001cooooo1Ooo000?ooooo`Goo`00Eoooool5ool000oooooo1Ooo0008ooooo`400000
0Oooool0000300000?oooooooooo00Kooooo1Ooo000Cooooo`Goo`00Aoooool3ool001gooooo1Ooo
000?ooooo`Goo`00F?ooool3ool000gooooo2?oo0008ooooo`4000000Oooool0000300000?oooooo
oooo00Kooooo1Ooo0007ooooo`?oo`002_ooool3ool00004oooooooo003oo`00ool004kooooo0ooo
000Dooooo`?oo`004?ooool5ool005cooooo1?oo0007ooooo`Woo`002?ooool10000007ooooo0000
0`00003oooooooooo`06ooooo`Goo`001_ooool6ool00004oooooooo003oo`00ool000Oooooo1Ooo
001<ooooo`Goo`004_ooool5ool0013ooooo0ooo001Looooo`Koo`001_ooool8ool000Wooooo0@00
0001ooooo`0000<00000ooooooooool01oooool3ool000Oooooo2ooo0006ooooo`Goo`00C?ooool5
ool001;ooooo1Ooo0007ooooo`?oo`00IOooool6ool00003oooooooo003oo`0000Soo`003?ooool1
0000007ooooo00000`00003oooooooooo`02ooooo`?oo`003?ooool;ool000;ooooo0ooo00000ooo
ooooo`00ool00003ool004cooooo1Ooo000Booooo`Goo`001_ooool5ool006Cooooo4?oo000=oooo
o`4000000Oooool0000400000?ooooooooooooooo`Goo`002Oooool=ool00003oooooooo003oo`00
00?oo`0000Coooooool00?oo003oo`00C_ooool3ool000Cooooo0ooo000=ooooo`?oo`001oooool5
ool000cooooo0ooo001Fooooo`Coo`0000?oooooool00?oo00001_oo000?ooooo`4000000Oooool0
000400000?ooooooooooooooo`Goo`002?ooool>ool00003oooooooo003oo`0000?oo`00F?ooool5
ool001Kooooo1Ooo000;ooooo`Goo`00B_ooool3ool000gooooo2?oo00001?ooooooo`00ool00?oo
000;ooooo`4000000Oooool0000400000?ooooooooooooooo`Goo`002?ooool5ool000Cooooo1Ooo
00000oooooooo`00ool00004ool004cooooo0ooo0008ooooo`Goo`003oooool3ool000Gooooo0ooo
000<ooooo`Goo`00BOooool5ool000Wooooo2_oo00000oooooooo`00ool00003ool000[ooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool3ool000Wooooo1Ooo0004ooooo`Goo`000_ooool5
ool004_ooooo1Ooo0007ooooo`Goo`003_ooool5ool001?ooooo1Ooo0014ooooo`?oo`000_ooool5
ool000Sooooo4Ooo000:ooooo`4000000Oooool0000300000?oooooooooo00Wooooo0ooo0003oooo
o`?oo`001_ooool3ool000?ooooo1Ooo001;ooooo`Goo`002?ooool3ool000oooooo2?oo000>oooo
o`Koo`00A?ooool5ool00003oooooooo003oo`0000?oo`002?oooolAool000[ooooo0@000001oooo
o`0000<00000ooooooooool02?ooool5ool0017ooooo1ooo0019ooooo`Goo`001oooool5ool000ko
oooo2Ooo000<ooooo`Goo`00A_ooool5ool000;ooooo0ooo0008oooooa7oo`000_ooool3ool000Ko
oooo0@000001ooooo`0000@00000oooooooooooooooo0ooo0004ooooo`Goo`004Oooool8ool004Wo
oooo0ooo0008ooooo`Goo`003oooool8ool000cooooo1Ooo0016ooooo`Goo`003?ooool?ool00003
oooooooo003oo`0000Koo`001Oooool10000007ooooo00000`00003oooooooooo`05ool000?ooooo
1Ooo000Aooooo`Soo`00B_ooool3ool000Oooooo1Ooo000Booooo`Goo`000_ooool4ool000Kooooo
1Ooo0017ooooo`?oo`003?ooool6ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo0000
1ooo0005ooooo`4000000Oooool0000300000?oooooooooo00Goo`001?ooool3ool001?ooooo1ooo
0019ooooo`Goo`001oooool3ool001?ooooo1Ooo00000oooooooo`00ool00004ool000Kooooo0ooo
001Fooooo`goo`001?ooool9ool000Gooooo0@000001ooooo`0000<00000ooooooooool01Ooo000M
ooooo`?oo`00B_ooool5ool000Kooooo0ooo0002ooooo`?oo`003oooool5ool00003oooooooo003o
o`0000Coo`001oooool5ool004gooooo0ooo0003ooooo`Soo`0000Coooooool00?oo003oo`001Ooo
ool8ool000Kooooo0@000001ooooo`0000@00000oooooooooooooooo0ooo000Looooo`?oo`00C?oo
ool5ool000Gooooo2_oo000>ooooo`Goo`0000?oooooool00?oo00001?oo0006ooooo`Ooo`00Booo
ool5ool000;ooooo2?oo000:ooooo`?oo`002_ooool10000007ooooo00000`00003oooooooooo`03
ool001cooooo1Ooo001;ooooo`Goo`001Oooool:ool000oooooo1Ooo00000oooooooo`00ool00002
ool000Oooooo1ooo001;ooooo`Goo`000oooool6ool001Sooooo0@000001ooooo`0000<00000oooo
oooo00001?oo0009ooooo`?oo`003oooool5ool004cooooo0ooo0005ooooo`_oo`003Oooool;ool0
00Sooooo1ooo001;ooooo`Goo`008Oooool10000007ooooo00000`00003oooooool00006ool000Ko
oooo1Ooo000>ooooo`Goo`00E?ooool5ool000;ooooo1?oo000<ooooo`goo`001?ooool3ool00003
oooooooo003oo`0000?oo`00Boooool5ool001?ooooo0ooo0008ooooo`?oo`000Oooool10000007o
oooo00000`00003oooooool00007ool000Gooooo1Ooo000:ooooo`?oo`000_ooool3ool005Gooooo
1Ooo0002ooooo`Goo`002oooool=ool000?ooooo1Ooo001@ooooo`Goo`001_ooool3ool000Wooooo
1Ooo0002ooooo`?oo`0000?oooooool00?oo00000ooo00010000007ooooo00000`00003ooooooooo
o`07ool000Gooooo1Ooo0009ooooo`Soo`0000Coooooool00?oo003oo`00Doooool3ool000?ooooo
1Ooo000;ooooo`goo`000oooool5ool0053ooooo1Ooo0005ooooo`Goo`002?ooool5ool00003oooo
oooo003oo`0000Soo`000@000001ooooo`0000<00000ooooooooool00_ooool5ool000Cooooo1Ooo
000:ooooo`goo`00E_ooool7ool000Kooooo0ooo0003ooooo`?oo`000_ooool6ool000Cooooo1Ooo
001Aooooo`?oo`000_ooool3ool00003oooooooo003oo`0000?oo`002?ooool5ool00003oooooooo
003oo`0000Soo`000@000001ooooo`0000<00000oooooooo00000_oo00001?ooooooo`00ool00?oo
0005ooooo`Goo`002_ooool=ool005?ooooo2Ooo0006ooooo`Goo`004Oooool6ool005Cooooo2_oo
0009ooooo`?oo`000_ooool5ool00006oooooooo003oo`00ool00?ooool000000Oooool000030000
0?oo003oo`0000?oo`002?ooool5ool000Kooooo0ooo0002ooooo`coo`00D_ooool8ool000?ooooo
0ooo0002ooooo`Goo`004Oooool6ool005Cooooo1Ooo00001?ooooooo`00ool00?oo000@ooooo`?o
o`001_ooool10000007ooooo00000`00003oo`00ool00003ool000Wooooo1?oo0005ooooo`Goo`00
1?ooool8ool005?ooooo2?oo0002ooooo`Goo`0000?oooooool00?oo00000ooo000Booooo`Goo`00
E?ooool5ool001Kooooo0ooo0004ooooo`4000000Oooool0000300000?oo003oo`0000?oo`002Ooo
ool5ool000Cooooo1Ooo0003ooooo`Koo`00E_ooool9ool00003oooooooo003oo`0000?oo`000_oo
ool3ool001Cooooo0ooo001Eooooo`Coo`005_ooool5ool000?ooooo0@000001ooooo`0000<00000
oooooooo00000_oo0005ooooo`?oo`0000?oooooool00?oo00001?oo0004ooooo`Goo`000_ooool6
ool005Sooooo2?oo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool006cooooo1Ooo
0002ooooo`?oo`004Oooool5ool000?ooooo0@000001ooooo`0000@00000oooooooooooooooo0ooo
0002ooooo`_oo`001Oooool3ool000?ooooo1Ooo001Looooo`Goo`000_ooool3ool00003oooooooo
003oo`0000?oo`00Joooool5ool00003oooooooo003oo`0000?oo`002oooool:ool000?ooooo0@00
0001ooooo`0000<00000ooooooooool04?oo000<ooooo`Goo`00GOooool3ool000Oooooo1Ooo001L
ooooo`?oo`003?ooool5ool00003oooooooo003oo`0000Goo`002?ooool:ool000Cooooo0@000001
ooooo`0000<00000ooooooooool02ooo00001?ooooooo`00ool00?oo000>ooooo`?oo`00J?ooool5
ool005_ooooo1_oo000;ooooo`?oo`000_ooool8ool000Oooooo1ooo0007ooooo`4000000Oooool0
000300000?oooooooooo00_oo`005_ooool3ool006Gooooo0ooo001Looooo`Ooo`004?ooool7ool0
00Oooooo1ooo0007ooooo`4000000Oooool0000400000?ooooooooooooooo`_oo`005?ooool5ool0
0<?ooooo1ooo000Booooo`Goo`002?ooool6ool000Oooooo0@000001ooooo`0000<00000oooooooo
ool01Oooool8ool001?ooooo1Ooo0034ooooo`Koo`004oooool3ool000_ooooo0ooo0008ooooo`40
00000Oooool0000300000?oooooooooo00Oooooo1ooo000Booooo`Goo`00a_ooool3ool001Cooooo
0ooo000Fooooo`4000000Oooool0000300000?oooooooooo00Sooooo1_oo000Cooooo`?oo`00gOoo
ool5ool001Gooooo0@000001ooooo`0000<00000ooooooooool02Oooool5ool001Cooooo0ooo003@
ooooo`?oo`000_ooool3ool000Cooooo1Ooo000Eooooo`4000000Oooool0000300000?oooooooooo
00[ooooo0ooo000Dooooo`Goo`0000?oooooool00?oo00001?oo002jooooo`?oo`002_ooool:ool0
00?ooooo1Ooo0005ooooo`?oo`002Oooool3ool0007ooooo0@000001ooooo`0000<00000oooooooo
ool00oooool3ool001_ooooo3Ooo0002ooooo`?oo`00/oooool5ool000Wooooo2_oo0004ooooo`?o
o`001Oooool5ool000Oooooo1Ooo00010000007ooooo00001000003oooooooooooooool6ool000oo
oooo0ooo0008ooooo`goo`0000?oooooool00?oo00000ooo002booooo`Goo`002Oooool:ool000co
oooo1Ooo0007ooooo`Goo`000@000001ooooo`0000<00000ooooooooool02?oo000=ooooo`Goo`00
00Coooooool00?oo003oo`001?ooool3ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo
00000ooo002booooo`Goo`002_ooool3ool000;ooooo0ooo000=ooooo`Goo`001oooool5ool00040
00000Oooool0000300000?oooooooooo00Woo`000_ooool3ool000?ooooo0ooo00000oooooooo`00
ool00008ool000Oooooo1ooo0002ooooo`Goo`00/oooool3ool0017ooooo1Ooo000;ooooo`?oo`00
1oooool5ool0007ooooo0@000001ooooo`0000<00000ooooooooool02Ooo00000oooooooo`00ool0
0003ool00003oooooooo003oo`0000goo`000oooool8ool000Gooooo1Ooo002looooo`?oo`001ooo
ool7ool001?ooooo1Ooo0002ooooo`4000000Oooool0000400000?ooooooooooooooo`Soo`0000?o
ooooool00?oo00000ooo00000oooooooo`00ool00003ool00005oooooooo003oo`00ool00?ooool0
1Ooo0002ooooo`Woo`001Oooool5ool00;_ooooo1Ooo0006ooooo`Ooo`004oooool5ool000;ooooo
0@000001ooooo`0000<00000ooooooooool01Oooool3ool000;ooooo1Ooo00000oooooooo`00ool0
0003ool000Kooooo0ooo0003ooooo`Woo`001Oooool5ool00;_ooooo1Ooo0006ooooo`Ooo`002?oo
ool3ool000Sooooo1Ooo0002ooooo`4000000Oooool0000300000?oooooooooo00_ooooo0ooo0003
ooooo`Coo`003?ooool8ool000Oooooo0ooo002looooo`Goo`001_ooool6ool000Sooooo1Ooo0008
ooooo`?oo`000oooool10000007ooooo00000`00003oooooooooo`0Aooooo`Goo`003?ooool3ool0
00[ooooo1ooo002jooooo`Goo`001_ooool3ool000[ooooo1Ooo000>ooooo`4000000Oooool00003
00000?oooooooooo017ooooo2?oo000Eooooo`Woo`00Zoooool3ool000cooooo2_oo000=ooooo`Go
o`003_ooool10000007ooooo00000`00003oooooooooo`0@ooooo`[oo`005?ooool9ool00:[ooooo
1Ooo000;ooooo`_oo`003Oooool3ool000oooooo0@000001ooooo`0000<00000ooooooooool04?oo
ool:ool001Cooooo2Ooo002Zooooo`Koo`002_ooool;ool001oooooo0@000001ooooo`0000<00000
ooooooooool04?ooool:ool001Cooooo2?oo002[ooooo`Ooo`002_ooool:ool001oooooo0@000001
ooooo`0000<00000ooooooooool04Oooool3ool00003oooooooo003oo`0000?oo`002_ooool3ool0
00Oooooo1Ooo002_ooooo`Koo`002oooool8ool0023ooooo0@000001ooooo`0000<00000oooooooo
ool05Oooool5ool000Wooooo1Ooo0006ooooo`Goo`000oooool3ool00:[ooooo1Ooo000:ooooo`Go
o`009?ooool10000007ooooo00000`00003oooooooooo`0Fooooo`?oo`002_ooool5ool000Oooooo
0ooo0002ooooo`Koo`00Z_ooool3ool000_ooooo1_oo000<ooooo`?oo`005?ooool10000007ooooo
00000`00003oooooooooo`0Aooooo`?oo`001oooool3ool000Gooooo1ooo0009ooooo`Ooo`00Y?oo
ool3ool0017ooooo1_oo000;ooooo`Goo`004oooool10000007ooooo00000`00003oooooooooo`0@
ooooo`Goo`001Oooool5ool000Gooooo1ooo0008ooooo`Soo`00X_ooool5ool0013ooooo2Ooo0008
ooooo`Goo`004oooool10000007ooooo00000`00003oooooooooo`03ool000gooooo1Ooo0005oooo
o`Goo`001oooool5ool000?ooooo0ooo0002ooooo`Soo`00X_ooool5ool0013ooooo2_oo0005oooo
o`Ooo`004oooool10000007ooooo00000`00003oooooool00004ool000;ooooo0ooo0007ooooo`Go
o`001Oooool5ool000Oooooo1Ooo0002ooooo`Goo`000_ooool7ool00:;ooooo1Ooo000Aooooo`?o
o`0000?oooooool00?oo00000ooo0004ooooo`Soo`004oooool10000007ooooo00000`00003ooooo
ool0000:ool000Oooooo0ooo0007ooooo`?oo`002Oooool3ool000?ooooo1ooo0003ooooo`?oo`00
Y?ooool3ool001Kooooo1Ooo0003ooooo`Woo`004oooool10000007ooooo00000`00003oooooool0
000:ool002?ooooo2?oo0033ooooo`?oo`000oooool:ool000;ooooo0ooo0003ooooo`?oo`002?oo
ool10000007ooooo00000`00003oooooooooo`0:ool001[ooooo0ooo0007ooooo`Ooo`00aoooool;
ool000;ooooo1Ooo00000oooooooo`00ool00003ool000Oooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool7ool001[ooooo1Ooo0008ooooo`Goo`00Z_ooool3ool000gooooo0ooo0009oooo
o`Woo`001Oooool5ool00003oooooooo003oo`0000?oo`001oooool10000007ooooo00000`00003o
ooooooooo`03ooooo`?oo`006Oooool3ool00003oooooooo003oo`0000?oo`002?ooool5ool00:Wo
oooo1Ooo0003ooooo`Koo`000_ooool5ool000Sooooo2_oo0004ooooo`Goo`0000?oooooool00?oo
00000ooo0007ooooo`4000000Oooool0000300000?oooooooooo00gooooo0ooo000>ooooo`[oo`00
2Oooool3ool00:[ooooo1Ooo0002ooooo`Soo`0000?oooooool00?oo00000ooo0008ooooo`[oo`00
0_ooool6ool000?ooooo0ooo0008ooooo`4000000Oooool0000300000?oooooooooo00cooooo1Ooo
0007ooooo`?oo`000oooool5ool00004oooooooo003oo`00ool00;Oooooo1Ooo0002ooooo`Soo`00
00?oooooool00?oo00000ooo0009ooooo`Woo`0000?oooooool00?oo00000ooo0004ooooo`Goo`00
1oooool10000007ooooo00000`00003oooooooooo`0<ooooo`Goo`001_ooool5ool000;ooooo1Ooo
002looooo`?oo`000oooool8ool000;ooooo0ooo000<ooooo`Koo`0000?oooooool00?oo00001?oo
0004ooooo`Goo`001oooool10000007ooooo00000`00003oooooooooo`0<ooooo`Goo`001_ooool5
ool000?ooooo0ooo0034ooooo`Koo`003_ooool3ool00003oooooooo003oo`0000?oo`000_ooool6
ool000Cooooo1Ooo0007ooooo`4000000Oooool0000400000?ooooooooooooooo`?oo`002Oooool3
ool000Oooooo1Ooo003Mooooo`[oo`000_ooool5ool000Kooooo0ooo0008ooooo`4000000Oooool0
000300000?oooooooooo00Goo`002?ooool3ool000Sooooo0ooo000;ooooo`?oo`003?ooool3ool0
0<7ooooo1Ooo00001?ooooooo`00ool00?oo0004ooooo`?oo`004_ooool10000007ooooo00000`00
003oooooooooo`05ool00004oooooooo003oo`00ool000?ooooo1Ooo000Dooooo`Goo`002_ooool5
ool00<3ooooo1Ooo0009ooooo`?oo`004Oooool10000007ooooo00000`00003oooooooooo`0:ool0
00;ooooo1Ooo000@ooooo`?oo`0000?oooooool00?oo00000ooo000:ooooo`Goo`00`Oooool3ool0
00Wooooo1Ooo000@ooooo`4000000Oooool0000400000?ooooooooooooooo`?oo`0000?oooooool0
0?oo00000ooo0002ooooo`Goo`001?ooool3ool000Sooooo2_oo000:ooooo`Goo`002oooool3ool0
0004oooooooo003oo`00ool00:gooooo0ooo0006ooooo`?oo`000_ooool5ool0013ooooo0@000001
ooooo`0000<00000ooooooooool01Oooool5ool000?ooooo0ooo0004ooooo`Goo`001oooool5ool0
0004oooooooo003oo`00ool000[ooooo1Ooo000;ooooo`Woo`00ROooool3ool000Sooooo0ooo000D
ooooo`Goo`001?ooool5ool00003oooooooo003oo`0000?oo`004?ooool10000007ooooo00000`00
003oooooooooo`06ooooo`?oo`002oooool5ool000Oooooo1Ooo000=ooooo`Goo`002oooool:ool0
08Sooooo1Ooo0006ooooo`Goo`004oooool5ool000Cooooo1Ooo0002ooooo`Goo`003oooool10000
007ooooo00000`00003oooooooooo`03ool0017ooooo1Ooo0005ooooo`Koo`003_ooool5ool000_o
oooo2_oo0025ooooo`Soo`001_ooool5ool001?ooooo1Ooo0004ooooo`Goo`000_ooool5ool000oo
oooo0@000001ooooo`0000<00000oooooooo00001?oo000Aooooo`?oo`001Oooool5ool0013ooooo
1Ooo000;ooooo`Goo`0000Coooooool00?oo003oo`00QOooool9ool000Kooooo1Ooo000Dooooo`?o
o`001_ooool<ool000Gooooo0ooo0006ooooo`4000000Oooool0000300000?ooooooo`0000Coo`00
6Oooool5ool0017ooooo0ooo000=ooooo`?oo`00R_ooool8ool000Sooooo1?oo000Mooooo`coo`00
1?ooool5ool000Gooooo0@000001ooooo`0000<00000oooooooo00001?oo000Eooooo`?oo`0000?o
ooooool00?oo00000ooo000Cooooo`?oo`00V?ooool5ool000_ooooo1Ooo000Aooooo`?oo`002?oo
ool<ool000Cooooo1_oo0004ooooo`4000000Oooool0000300000?oooooooooo00?oo`005Oooool9
ool001?ooooo1Ooo002Hooooo`?oo`003?ooool5ool0013ooooo1Ooo0007ooooo`_oo`001Oooool6
ool000Cooooo0@000001ooooo`0000<00000ooooooooool06?ooool:ool001;ooooo1ooo000Hoooo
o`?oo`00R_ooool5ool0013ooooo1Ooo0008ooooo`Koo`000_ooool3ool000Gooooo1Ooo0004oooo
o`4000000Oooool0000300000?oooooooooo01Sooooo2ooo000Aooooo`Soo`005_ooool5ool008[o
oooo0ooo000Aooooo`Goo`003oooool5ool000Gooooo0ooo0005ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo0ooo000Cooooo`_oo`004_ooool7ool001Kooooo1Ooo001gooooo`?oo`00
9Oooool3ool000cooooo0ooo00000oooooooo`00ool00003ool000Cooooo0ooo0006ooooo`400000
0Oooool0000400000?ooooooooooooooo`Goo`004_ooool;ool001Cooooo1Ooo0008ooooo`?oo`00
2_ooool6ool007Kooooo1Ooo000Nooooo`?oo`004Oooool;ool000;ooooo1Ooo0005ooooo`400000
0Oooool0000400000?ooooooooooooooo`Goo`004oooool9ool001Kooooo0ooo0008ooooo`Goo`00
2?ooool7ool007Kooooo1Ooo000Mooooo`Goo`004?ooool5ool00003oooooooo003oo`0000?oo`00
0_ooool5ool000Gooooo0@000001ooooo`0000@00000oooooooooooooooo1Ooo000Eooooo`Goo`00
3Oooool3ool001?ooooo1Ooo0008ooooo`Koo`00Moooool5ool000;ooooo0ooo0006ooooo`?oo`00
3oooool7ool000kooooo1Ooo00000oooooooo`00ool00003ool000;ooooo1Ooo0005ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo0ooo000Gooooo`?oo`003Oooool5ool001;ooooo1Ooo
0003ooooo`?oo`000_ooool5ool007Wooooo0ooo0002ooooo`Goo`001?ooool5ool000kooooo2?oo
000>ooooo`?oo`000oooool3ool000Cooooo1_oo0003ooooo`4000000Oooool0000300000?oooooo
oooo02cooooo1Ooo000Cooooo`?oo`000oooool5ool000;ooooo0ooo001oooooo`Goo`001?ooool5
ool000Gooooo0ooo0007ooooo`Ooo`007Oooool5ool000;ooooo0@000001ooooo`0000<00000oooo
ooooool03Oooool3ool000oooooo0ooo000:ooooo`Goo`006Oooool5ool008Cooooo1Ooo0004oooo
o`Goo`001?ooool5ool000Sooooo2?oo000@ooooo`?oo`000_ooool3ool000;ooooo1Ooo0002oooo
o`4000000Oooool0000300000?oooooooooo00cooooo1Ooo000=ooooo`Koo`002Oooool3ool0013o
oooo0ooo0007ooooo`Goo`00QOooool3ool000Kooooo0ooo0005ooooo`Goo`001oooool:ool000co
oooo3?oo00000oooooooo`00ool00003ool000;ooooo0@000001ooooo`0000<00000ooooooooool0
3?ooool5ool000gooooo1ooo000Jooooo`Goo`001Oooool5ool000Kooooo0ooo001Sooooo`?oo`00
:?ooool5ool000Kooooo2ooo000;ooooo`goo`000_ooool3ool000?ooooo0@000001ooooo`0000<0
0000ooooooooool03?ooool5ool000gooooo1ooo000Jooooo`Goo`001?ooool5ool000Cooooo1ooo
001Oooooo`Ooo`001?ooool3ool0027ooooo0ooo0003ooooo`?oo`0000?oooooool00?oo00002Ooo
000;ooooo`goo`000_ooool3ool000?ooooo0@000001ooooo`0000<00000ooooooooool03Oooool3
ool000oooooo1_oo000Jooooo`Goo`001?ooool5ool000?ooooo2?oo001Nooooo`Soo`000oooool5
ool002;ooooo3_oo00001?ooooooo`00ool00?oo000<ooooo`coo`000_ooool5ool000;ooooo0@00
0001ooooo`0000<00000ooooooooool08Oooool4ool001Wooooo2?oo0002ooooo`Goo`000oooool8
ool005kooooo2?oo0003ooooo`Soo`000_ooool3ool00004oooooooo003oo`00ool001Gooooo2Ooo
00000oooooooo`00ool00002ool001;ooooo0ooo00000oooooooo`00ool00003ool000Cooooo1Ooo
0002ooooo`4000000Oooool0000300000?oooooooooo027ooooo1Ooo000Hooooo`Woo`000_ooool3
ool000Cooooo1ooo001=ooooo`?oo`003oooool7ool00003oooooooo003oo`0001?oo`004_ooool;
ool001_ooooo1Ooo0004ooooo`Goo`000_ooool10000007ooooo00000`00003oooooool00002ool0
01oooooo2?oo000Eooooo`Woo`002_ooool5ool004gooooo1Ooo000?ooooo`?oo`000ooooolFool0
00Oooooo0ooo0007ooooo`_oo`006oooool6ool000Gooooo1Ooo0001ooooo`4000000Oooool00003
00000?oo003oo`0000?oo`001Oooool3ool000oooooo0ooo0004ooooo`Woo`005Oooool8ool000_o
oooo0ooo000Gooooo`?oo`00=?ooool5ool001Gooooo1Ooo0003ooooo`koo`001_ooool5ool000Ko
oooo2ooo000Jooooo`Ooo`001_ooool5ool0004000000Oooool0000300000?oo003oo`0000?oo`00
1?ooool5ool000gooooo1Ooo0004ooooo`Soo`005_ooool6ool002Gooooo1Ooo000Nooooo`?oo`00
4_ooool5ool000;ooooo0ooo000@ooooo`Goo`001?ooool3ool000;ooooo1ooo0003ooooo`?oo`00
00?oooooool00?oo00000ooo0006ooooo`Goo`000_ooool3ool001_ooooo1ooo0006ooooo`Goo`00
0@000001ooooo`0000<00000ool00?oo00000ooo0004ooooo`Goo`003Oooool5ool000Oooooo1Ooo
000Jooooo`Koo`008Oooool5ool001cooooo1_oo000Booooo`?oo`000_ooool5ool000Oooooo0ooo
0006ooooo`?oo`002oooool5ool000?ooooo2_oo0006ooooo`Goo`004?ooool3ool000gooooo1_oo
0007ooooo`Goo`000@000001ooooo`0000<00000oooooooo00000_oo0005ooooo`Goo`000_ooool3
ool000Sooooo1Ooo0008ooooo`?oo`006_ooool8ool000cooooo0ooo000Aooooo`Goo`002oooool3
ool000_ooooo2Ooo000Gooooo`Goo`001_ooool5ool001Cooooo0ooo0004ooooo`Goo`0000Cooooo
ool00?oo003oo`001oooool5ool000?ooooo0ooo0009ooooo`Goo`003Oooool3ool000[ooooo0ooo
0001ooooo`4000000Oooool0000300000?oooooooooo00Oooooo1Ooo00000oooooooo`00ool00003
ool000Sooooo0ooo000Vooooo`Soo`0000Coooooool00?oo003oo`001oooool5ool0017ooooo0ooo
000;ooooo`Goo`002Oooool:ool001Oooooo1Ooo0006ooooo`Goo`006oooool5ool000cooooo0ooo
0003ooooo`Goo`001oooool6ool001kooooo0@000001ooooo`0000<00000ooooooooool01oooool5
ool00003oooooooo003oo`0000?oo`00<Oooool=ool000Kooooo1Ooo000Oooooo`Goo`001Oooool=
ool001Wooooo0ooo0007ooooo`Goo`007?ooool3ool001?ooooo2Ooo0002ooooo`Ooo`005oooool3
ool000Cooooo0@000001ooooo`0000<00000ooooooooool02?ooool:ool001Oooooo0ooo000Hoooo
o`Koo`0000?oooooool00?oo00000ooo0006ooooo`Goo`007oooool5ool000Cooooo3?oo0007oooo
o`Koo`006Oooool3ool003?ooooo2_oo00000oooooooo`00ool00004ool001Oooooo1Ooo0003oooo
o`4000000Oooool0000300000?oooooooooo00Sooooo1Ooo00001?ooooooo`00ool00?oo000Goooo
o`Goo`003Oooool3ool000Sooooo2ooo0007ooooo`?oo`008Oooool3ool000Gooooo2Ooo0009oooo
o`Soo`00Coooool9ool00003oooooooo003oo`0000?oo`005_ooool7ool000?ooooo0@000001oooo
o`0000<00000ooooooooool02?ooool5ool000;ooooo0ooo000?ooooo`?oo`001?ooool5ool000co
oooo1Ooo0007ooooo`coo`003oooool3ool00004oooooooo003oo`00ool0013ooooo0ooo0004oooo
o`?oo`000_ooool8ool000Wooooo2Ooo0002ooooo`?oo`00Boooool8ool000;ooooo0ooo000Foooo
o`Soo`000oooool10000007ooooo00000`00003oooooooooo`09ooooo`?oo`000_ooool5ool000co
oooo1_oo0003ooooo`Goo`001oooool3ool000;ooooo1Ooo0007ooooo`Coo`0000?oooooool00?oo
00001_oo000=ooooo`Woo`003_ooool5ool000;ooooo1Ooo0002ooooo`Koo`002Oooool:ool00003
oooooooo003oo`0000?oo`001oooool3ool000Sooooo0ooo000>ooooo`?oo`003_ooool3ool000So
oooo0ooo00001?ooooooo`00ool00?oo0005ooooo`Koo`002?ooool3ool000?ooooo0ooo000;oooo
o`Ooo`001?ooool10000007ooooo00000`00003oooooooooo`0>ooooo`Goo`002oooool7ool000Co
oooo0ooo0007ooooo`Goo`0000?oooooool00?oo00000ooo0006ooooo`Goo`000_ooool7ool000go
oooo2Ooo000>ooooo`Goo`000_ooool5ool0017ooooo2Ooo0002ooooo`Goo`001_ooool5ool000Ko
oooo2Ooo0008ooooo`Goo`003?ooool5ool000Kooooo2Ooo0004ooooo`Goo`002?ooool5ool00003
oooooooo003oo`0000?oo`001oooool8ool000Kooooo0@000001ooooo`0000<00000ooooooooool0
3_ooool5ool000_ooooo1ooo000>ooooo`Goo`000_ooool5ool000Gooooo1Ooo0004ooooo`Goo`00
3Oooool9ool000kooooo1Ooo0002ooooo`Goo`002oooool3ool000?ooooo1Ooo0006ooooo`Goo`00
1_ooool5ool000Kooooo2_oo0007ooooo`Goo`003?ooool5ool000Kooooo2Ooo0005ooooo`?oo`00
2Oooool5ool00003oooooooo003oo`0000?oo`001_ooool8ool000Oooooo0@000001ooooo`0000<0
0000ooooooooool01_ooool3ool000Kooooo0ooo000<ooooo`Koo`003oooool5ool000;ooooo1ooo
0003ooooo`Goo`001Oooool3ool000oooooo2?oo0007ooooo`?oo`001Oooool3ool000;ooooo1Ooo
000;ooooo`Goo`000oooool3ool000Sooooo0ooo0007ooooo`Goo`001_ooool:ool000Oooooo1Ooo
0008ooooo`?oo`0000?oooooool00?oo00000ooo0006ooooo`Woo`004Oooool5ool00003oooooooo
003oo`0000?oo`001_ooool5ool000[ooooo0@000001ooooo`0000<00000ooooooooool01Oooool5
ool001Gooooo0ooo000?ooooo`Koo`000oooool8ool000?ooooo0ooo0005ooooo`Goo`003?ooool3
ool000;ooooo1Ooo0006ooooo`Goo`002?ooool6ool000_ooooo1Ooo000Iooooo`?oo`002?ooool9
ool000?ooooo0ooo0002ooooo`Goo`001_ooool5ool00004oooooooo003oo`00ool000Oooooo2?oo
000Cooooo`?oo`000oooool3ool000Oooooo1Ooo000:ooooo`4000000Oooool0000300000?oooooo
oooo00Gooooo1Ooo000Vooooo`Goo`001_ooool7ool000_ooooo1Ooo0008ooooo`Soo`0000?ooooo
ool00?oo00000ooo0006ooooo`Goo`002?ooool6ool000_ooooo1Ooo000Booooo`Koo`004?ooool4
ool000?ooooo1_oo00000oooooooo`00ool00003ool000Gooooo1Ooo000;ooooo`Koo`002oooool3
ool001Kooooo1ooo0009ooooo`4000000Oooool0000300000?oooooooooo00Gooooo1Ooo000Voooo
o`Goo`002?ooool5ool000_ooooo1Ooo0007ooooo`Woo`000_ooool3ool000Oooooo1Ooo0005oooo
o`Woo`003?ooool3ool000Cooooo0ooo0008ooooo`_oo`003_ooool3ool000Gooooo3?oo0005oooo
o`Goo`002oooool7ool000Wooooo1Ooo000Dooooo`Soo`002Oooool10000007ooooo00000`00003o
ooooooooo`06ooooo`?oo`005oooool3ool000gooooo1Ooo0009ooooo`?oo`003Oooool3ool000So
oooo2_oo000<ooooo`?oo`001Oooool:ool001;ooooo1Ooo0006ooooo`goo`003?ooool5ool000Co
oooo3?oo0006ooooo`?oo`003Oooool6ool000Wooooo1Ooo000Dooooo`Soo`002Oooool10000007o
oooo00000`00003oooooooooo`09ooooo`?oo`004_ooool6ool000gooooo0ooo000Gooooo`?oo`00
2oooool;ool001?ooooo2_oo000?ooooo`Soo`001_ooool>ool000Cooooo0ooo0004ooooo`Goo`00
1Oooool6ool00004oooooooo003oo`00ool000Oooooo0ooo000>ooooo`Goo`002Oooool6ool001?o
oooo2Ooo0008ooooo`4000000Oooool0000300000?oooooooooo00Sooooo1Ooo0006ooooo`?oo`00
1oooool7ool000_ooooo0ooo000Hooooo`Goo`002oooool3ool000;ooooo2?oo000@ooooo`[oo`00
1oooool4ool000?ooooo2Ooo0006ooooo`koo`000oooool5ool000?ooooo1Ooo0007ooooo`?oo`00
2oooool5ool000Gooooo0ooo0005ooooo`Goo`002_ooool5ool001Cooooo0ooo00000oooooooo`00
ool00003ool000Oooooo0@000001ooooo`0000<00000ooooooooool02?ooool5ool000Gooooo1Ooo
0006ooooo`Ooo`002_ooool5ool001Oooooo1Ooo0006ooooo`?oo`001oooool9ool0013ooooo0ooo
0002ooooo`?oo`001oooool6ool000;ooooo2?oo0008ooooo`?oo`001?ooool6ool000?ooooo1Ooo
0004ooooo`?oo`005_ooool5ool000Cooooo1Ooo0005ooooo`?oo`002oooool5ool001Sooooo1Ooo
0007ooooo`4000000Oooool0000300000?oooooooooo00Sooooo1Ooo0005ooooo`Goo`001_ooool6
ool000_ooooo1Ooo000Gooooo`Koo`001?ooool5ool000Oooooo2?oo000Oooooo`Koo`000_ooool5
ool001;ooooo1Ooo0003ooooo`Koo`007Oooool5ool000Cooooo1Ooo000Dooooo`?oo`002?ooool3
ool000kooooo1Ooo0007ooooo`4000000Oooool0000300000?oooooooooo00?ooooo0ooo0002oooo
o`Goo`001Oooool5ool000Oooooo0ooo000=ooooo`Goo`006?ooool5ool000Cooooo1_oo0009oooo
o`Goo`007oooool6ool000?ooooo0ooo000Dooooo`?oo`001?ooool5ool001oooooo0ooo0005oooo
o`Goo`001?ooool3ool001Oooooo1Ooo000:ooooo`?oo`0000Coooooool00?oo003oo`002?ooool1
0000007ooooo00000`00003oooooooooo`02ooooo`Goo`0000?oooooool00?oo00000ooo0006oooo
o`?oo`006Oooool3ool001Wooooo1Ooo0004ooooo`Koo`002_ooool3ool0023ooooo1Ooo000Ooooo
o`Soo`000_ooool3ool002?ooooo0ooo0004ooooo`Goo`005_ooool5ool000Wooooo1Ooo000;oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1Ooo0002ooooo`?oo`00@?ooool3ool000Ko
oooo1Ooo000]ooooo`Goo`007_ooool8ool000;ooooo1Ooo000Yooooo`Goo`005_ooool5ool000Wo
oooo1Ooo000;ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1Ooo000eooooo`?oo`00
0_ooool3ool001;ooooo0ooo000_ooooo`?oo`003oooool3ool000;ooooo0ooo0008ooooo`Goo`00
1?ooool6ool000Kooooo0ooo000Pooooo`Ooo`0000Coooooool00?oo003oo`004Oooool3ool000Oo
oooo2?oo000;ooooo`4000000Oooool0000300000?oooooooooo00?ooooo0ooo000Fooooo`?oo`00
7?ooool:ool001Wooooo1Ooo000fooooo`[oo`001_ooool6ool000Cooooo1_oo0005ooooo`Goo`00
5?ooool3ool00003oooooooo003oo`0000;oo`001?ooool;ool001Gooooo0ooo00000oooooooo`00
ool00006ool000cooooo0@000001ooooo`0000<00000ooooooooool06oooool5ool000gooooo0ooo
000;ooooo`[oo`006?ooool7ool001[ooooo0ooo000Hooooo`[oo`001Oooool6ool000Gooooo1Ooo
0006ooooo`Goo`004oooool:ool000Cooooo2_oo000=ooooo`?oo`001?ooool:ool000oooooo0@00
0001ooooo`0000<00000ooooooooool06oooool5ool000cooooo1Ooo000:ooooo`_oo`005oooool7
ool001Wooooo1Ooo000Gooooo`[oo`001Oooool5ool000Oooooo0ooo0007ooooo`Goo`004oooool:
ool000Cooooo2_oo000<ooooo`Goo`000_ooool;ool000oooooo0@000001ooooo`0000<00000oooo
ooooool06?ooool8ool000Cooooo0ooo0005ooooo`Goo`002oooool3ool000;ooooo1_oo000Foooo
o`Ooo`003Oooool3ool000Wooooo1_oo000Gooooo`?oo`0000?oooooool00?oo00000ooo0005oooo
o`Goo`004_ooool3ool001Cooooo2_oo0004ooooo`Goo`0000Coooooool00?oo003oo`003Oooool5
ool000;ooooo1_oo00001?ooooooo`00ool00?oo0008ooooo`?oo`001Oooool10000007ooooo0000
0`00003oooooooooo`0=ooooo`?oo`001oooool8ool000Cooooo1Ooo0004ooooo`Goo`004Oooool5
ool000?ooooo0ooo000Aooooo`Goo`001Oooool3ool000Gooooo1Ooo0008ooooo`Koo`007?ooool3
ool000Kooooo1Ooo000Zooooo`?oo`0000?oooooool00?oo00000_oo0006ooooo`?oo`004_ooool5
ool000;ooooo1Ooo000<ooooo`Goo`001?ooool10000007ooooo00000`00003oooooooooo`0<oooo
o`Goo`001_ooool5ool000Oooooo1Ooo0005ooooo`?oo`004_ooool5ool000;ooooo1Ooo000Aoooo
o`?oo`001Oooool5ool000Cooooo1Ooo0009ooooo`Goo`006oooool3ool000Oooooo1Ooo000Yoooo
o`Koo`003_ooool3ool000kooooo0ooo0004ooooo`?oo`001oooool3ool000;ooooo1_oo0004oooo
o`4000000Oooool0000300000?oooooooooo00cooooo1Ooo0006ooooo`Goo`001oooool5ool001_o
oooo0ooo0003ooooo`Goo`006Oooool5ool000Cooooo1Ooo000:ooooo`?oo`001_ooool3ool001;o
oooo1Ooo0007ooooo`?oo`00:Oooool8ool000cooooo1Ooo000=ooooo`?oo`003Oooool5ool00003
oooooooo003oo`0000Coo`001?ooool10000007ooooo00000`00003oooooooooo`0<ooooo`Goo`00
0_ooool3ool000;ooooo0ooo0009ooooo`Koo`000_ooool4ool00004oooooooo003oo`00ool000ko
oooo1Ooo0002ooooo`Goo`006Oooool5ool000Gooooo0ooo000Cooooo`Goo`004Oooool5ool001Wo
oooo0ooo000Gooooo`Soo`003?ooool5ool000cooooo1Ooo000<ooooo`Goo`0000?oooooool00?oo
00000ooo0005ooooo`4000000Oooool0000300000?oooooooooo00gooooo0ooo0002ooooo`Goo`00
3oooool?ool000gooooo1Ooo0003ooooo`?oo`006_ooool5ool001_ooooo1Ooo000Aooooo`Goo`00
6?ooool5ool000Sooooo0ooo000;ooooo`Soo`002Oooool8ool000cooooo1Ooo0009ooooo`Soo`00
0_ooool3ool000Kooooo0@000001ooooo`0000<00000ooooooooool04_ooool5ool000oooooo3ooo
000=ooooo`Goo`003oooool3ool000kooooo2?oo000Hooooo`Ooo`004?ooool3ool000;ooooo0ooo
000Dooooo`Goo`001oooool5ool000_ooooo1_oo0009ooooo`Soo`003Oooool5ool000?ooooo0ooo
0002ooooo`Soo`003?ooool10000007ooooo00000`00003oooooooooo`0Booooo`Goo`001oooool3
ool000Gooooo3ooo000>ooooo`?oo`003oooool5ool000gooooo2Ooo000Hooooo`Ooo`004oooool5
ool001?ooooo1Ooo0007ooooo`Goo`006_ooool5ool0017ooooo0ooo0003ooooo`Goo`0000?ooooo
ool00?oo00000ooo000?ooooo`4000000Oooool0000300000?oooooooooo01?ooooo0ooo0007oooo
o`Goo`001Oooool=ool000Sooooo0ooo000Fooooo`Goo`003_ooool8ool001Wooooo1ooo000Boooo
o`Goo`005?ooool3ool000Sooooo1Ooo0002ooooo`?oo`005Oooool5ool001Oooooo1Ooo00000ooo
ooooo`00ool00003ool000oooooo0@000001ooooo`0000<00000ooooooooool07Oooool5ool000Ko
oooo1Ooo0002ooooo`?oo`002Oooool5ool000gooooo0ooo0005ooooo`Goo`004Oooool5ool000Ko
oooo0ooo000?ooooo`Woo`000_ooool3ool000cooooo1Ooo000Pooooo`?oo`000_ooool5ool001Go
oooo0ooo000Hooooo`Goo`000_ooool3ool0013ooooo0@000001ooooo`0000<00000ooooooooool0
5_ooool3ool000Cooooo1Ooo0007ooooo`?oo`003oooool5ool000cooooo1Ooo0005ooooo`?oo`00
4oooool6ool000?ooooo1Ooo000>ooooo`Woo`0000?oooooool00?oo00000ooo000<ooooo`?oo`00
0_ooool3ool0027ooooo1Ooo000:ooooo`?oo`008?ooool3ool00004oooooooo003oo`00ool001Ko
oooo0@000001ooooo`0000<00000ooooooooool03_ooool3ool000Cooooo1Ooo0004ooooo`?oo`00
6_ooool5ool000cooooo1Ooo0007ooooo`?oo`004oooool5ool000;ooooo1Ooo000>ooooo`Woo`00
00?oooooool00?oo00001Ooo000>ooooo`Goo`004_ooool3ool000_ooooo2Ooo0005ooooo`Goo`00
1_ooool3ool000Cooooo0ooo000>ooooo`Goo`006Oooool10000007ooooo00000`00003oooooool0
0002ool000_ooooo1Ooo0002ooooo`Koo`005Oooool3ool000[ooooo0ooo000=ooooo`Goo`001_oo
ool5ool000Kooooo0ooo0009ooooo`Goo`000_ooool5ool000oooooo0ooo00001?ooooooo`00ool0
0?oo0002ooooo`Soo`003Oooool5ool0017ooooo2?oo0008ooooo`Woo`001?ooool5ool000Gooooo
1Ooo0002ooooo`Goo`003Oooool5ool001Wooooo0@000001ooooo`0000<00000ool00?oo00000ooo
000:ooooo`Goo`000_ooool6ool001Cooooo1Ooo00001?ooooooo`00ool00?oo000Fooooo`?oo`00
1oooool5ool000Gooooo1Ooo0008ooooo`Goo`000oooool3ool001[ooooo1ooo000=ooooo`Goo`00
1oooool3ool000Oooooo2Ooo0008ooooo`Soo`001?ooool5ool000Gooooo1Ooo0002ooooo`Goo`00
3Oooool5ool001Wooooo0@000001ooooo`0000<00000ool00?oo00000ooo000:ooooo`Goo`000_oo
ool5ool001Gooooo2_oo000@ooooo`?oo`003?ooool5ool000Gooooo1Ooo0009ooooo`Koo`004ooo
ool3ool000[ooooo1Ooo000>ooooo`?oo`0000Coooooool00?oo003oo`000oooool5ool000Kooooo
2Ooo0008ooooo`Soo`001Oooool3ool000Kooooo1Ooo0002ooooo`Goo`003_ooool3ool001[ooooo
0@000001ooooo`0000<00000ool00?oo00000ooo000;ooooo`?oo`001?ooool4ool001Gooooo2ooo
000>ooooo`Goo`003?ooool3ool000Kooooo1Ooo000;ooooo`Goo`004Oooool5ool000Kooooo0ooo
00001?ooooooo`00ool00?oo0006ooooo`?oo`002Oooool5ool000;ooooo1Ooo0007ooooo`Soo`00
2Oooool6ool0013ooooo0ooo0004ooooo`Goo`003oooool3ool000?ooooo0ooo000Booooo`400000
0Oooool0000300000?ooooooo`0000;oo`004oooool5ool001Gooooo0ooo00000oooooooo`00ool0
0005ool000gooooo1Ooo000Fooooo`?oo`003?ooool5ool0017ooooo1Ooo0005ooooo`Goo`002?oo
ool5ool000Sooooo1Ooo0002ooooo`Goo`002oooool3ool002Sooooo1Ooo000=ooooo`Goo`0000?o
ooooool00?oo00000ooo000Aooooo`4000000Oooool0000300000?oooooooooo01Gooooo1Ooo000J
ooooo`Koo`003Oooool5ool002Gooooo1Ooo000Aooooo`Goo`001Oooool5ool000Sooooo1Ooo0008
ooooo`Goo`000oooool3ool003Oooooo1Ooo000=ooooo`Goo`0000?oooooool00?oo00000ooo000A
ooooo`4000000Oooool0000300000?oooooooooo01Gooooo1Ooo000Kooooo`Goo`003_ooool3ool0
02Oooooo0ooo000Booooo`Goo`001Oooool5ool000Sooooo1Ooo0009ooooo`?oo`00?_ooool5ool0
00gooooo1Ooo00000oooooooo`00ool00003ool0017ooooo0@000001ooooo`006@000003ool001d0
00000ooo001?000000?oo`001`000003ool000X000000ooo001<000000?oo`003`000003ool000<0
00000ooo000C0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generate sample EM results with varying number of component \
densities\
\>", "Subsection"],

Cell[BoxData[
    \(\(results = Table[EMAll1[data1, k], {k, 2, 15}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of training data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 0.378093 0.000856317 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03557 -24 -4.5 ]
[-0.0125 .03557 0 4.5 ]
[-0.0125 .1212 -24 -4.5 ]
[-0.0125 .1212 0 4.5 ]
[-0.0125 .20683 -24 -4.5 ]
[-0.0125 .20683 0 4.5 ]
[-0.0125 .29246 -24 -4.5 ]
[-0.0125 .29246 0 4.5 ]
[-0.0125 .37809 -6 -4.5 ]
[-0.0125 .37809 0 4.5 ]
[-0.0125 .46372 -18 -4.5 ]
[-0.0125 .46372 0 4.5 ]
[-0.0125 .54936 -18 -4.5 ]
[-0.0125 .54936 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .03557 m
1 .03557 L
s
0 .1212 m
1 .1212 L
s
0 .20683 m
1 .20683 L
s
0 .29246 m
1 .29246 L
s
0 .37809 m
1 .37809 L
s
0 .46372 m
1 .46372 L
s
0 .54936 m
1 .54936 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03557 m
.00625 .03557 L
s
[(-400)] -0.0125 .03557 1 0 Mshowa
0 .1212 m
.00625 .1212 L
s
[(-300)] -0.0125 .1212 1 0 Mshowa
0 .20683 m
.00625 .20683 L
s
[(-200)] -0.0125 .20683 1 0 Mshowa
0 .29246 m
.00625 .29246 L
s
[(-100)] -0.0125 .29246 1 0 Mshowa
0 .37809 m
.00625 .37809 L
s
[(0)] -0.0125 .37809 1 0 Mshowa
0 .46372 m
.00625 .46372 L
s
[(100)] -0.0125 .46372 1 0 Mshowa
0 .54936 m
.00625 .54936 L
s
[(200)] -0.0125 .54936 1 0 Mshowa
.125 Mabswid
0 .05269 m
.00375 .05269 L
s
0 .06982 m
.00375 .06982 L
s
0 .08695 m
.00375 .08695 L
s
0 .10407 m
.00375 .10407 L
s
0 .13832 m
.00375 .13832 L
s
0 .15545 m
.00375 .15545 L
s
0 .17258 m
.00375 .17258 L
s
0 .1897 m
.00375 .1897 L
s
0 .22396 m
.00375 .22396 L
s
0 .24108 m
.00375 .24108 L
s
0 .25821 m
.00375 .25821 L
s
0 .27534 m
.00375 .27534 L
s
0 .30959 m
.00375 .30959 L
s
0 .32671 m
.00375 .32671 L
s
0 .34384 m
.00375 .34384 L
s
0 .36097 m
.00375 .36097 L
s
0 .39522 m
.00375 .39522 L
s
0 .41235 m
.00375 .41235 L
s
0 .42947 m
.00375 .42947 L
s
0 .4466 m
.00375 .4466 L
s
0 .48085 m
.00375 .48085 L
s
0 .49798 m
.00375 .49798 L
s
0 .5151 m
.00375 .5151 L
s
0 .53223 m
.00375 .53223 L
s
0 .01844 m
.00375 .01844 L
s
0 .00131 m
.00375 .00131 L
s
0 .56648 m
.00375 .56648 L
s
0 .58361 m
.00375 .58361 L
s
0 .60074 m
.00375 .60074 L
s
0 .61786 m
.00375 .61786 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03557 m
1 .03557 L
s
.99375 .1212 m
1 .1212 L
s
.99375 .20683 m
1 .20683 L
s
.99375 .29246 m
1 .29246 L
s
.99375 .37809 m
1 .37809 L
s
.99375 .46372 m
1 .46372 L
s
.99375 .54936 m
1 .54936 L
s
.125 Mabswid
.99625 .05269 m
1 .05269 L
s
.99625 .06982 m
1 .06982 L
s
.99625 .08695 m
1 .08695 L
s
.99625 .10407 m
1 .10407 L
s
.99625 .13832 m
1 .13832 L
s
.99625 .15545 m
1 .15545 L
s
.99625 .17258 m
1 .17258 L
s
.99625 .1897 m
1 .1897 L
s
.99625 .22396 m
1 .22396 L
s
.99625 .24108 m
1 .24108 L
s
.99625 .25821 m
1 .25821 L
s
.99625 .27534 m
1 .27534 L
s
.99625 .30959 m
1 .30959 L
s
.99625 .32671 m
1 .32671 L
s
.99625 .34384 m
1 .34384 L
s
.99625 .36097 m
1 .36097 L
s
.99625 .39522 m
1 .39522 L
s
.99625 .41235 m
1 .41235 L
s
.99625 .42947 m
1 .42947 L
s
.99625 .4466 m
1 .4466 L
s
.99625 .48085 m
1 .48085 L
s
.99625 .49798 m
1 .49798 L
s
.99625 .5151 m
1 .5151 L
s
.99625 .53223 m
1 .53223 L
s
.99625 .01844 m
1 .01844 L
s
.99625 .00131 m
1 .00131 L
s
.99625 .56648 m
1 .56648 L
s
.99625 .58361 m
1 .58361 L
s
.99625 .60074 m
1 .60074 L
s
.99625 .61786 m
1 .61786 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .17522 L
.17033 .32746 L
.24359 .46856 L
.31685 .52231 L
.39011 .54027 L
.46337 .54755 L
.53663 .55128 L
.60989 .56859 L
.68315 .58232 L
.75641 .59612 L
.82967 .5892 L
.90293 .58465 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .17522 Mdot
.17033 .32746 Mdot
.24359 .46856 Mdot
.31685 .52231 Mdot
.39011 .54027 Mdot
.46337 .54755 Mdot
.53663 .55128 Mdot
.60989 .56859 Mdot
.68315 .58232 Mdot
.75641 .59612 Mdot
.82967 .5892 Mdot
.90293 .58465 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`007_ooool5o`0002?ooooo0ol0000Rooooo`?o0000
8oooool3o`00023ooooo0ol00004ooooo`;o00007Oooool3o`0000;ooooo1Ol0000Looooo`?o0000
1?ooool3o`0001Kooooo000Oooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo0000027ooooo00Go0000ooooooooooooooooo`00000Poooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Eooooo`008?ooool00ol0003oooooooooo`0Qooooo`Go00008Oooool01Ol0003ooooooooooooo
oooo0000027ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01go
oooo00Co0000oooooooooooooooo1Ol0000Fooooo`008Oooool00ol0003oooooooooo`0Pooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Sooooo`?o00008Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0L
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Eooooo`007_ooool0
1Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooool000008_ooool00ol0003ooooooooo
o`0Sooooo`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Gooooo`007_ooool01Ol0003o
oooooooooooooooo000002?ooooo0_l0000Sooooo`03o`000?oooooooooo02;ooooo00Go0000oooo
ooooooooooooo`00000Oooooo`;o00001?ooool01?l0003oooooooooool0000Looooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000001cooooo0_l00005ooooo`;o00005oooool001oooooo0ol0
000Uooooo`03o`000?oooooooooo02;ooooo0_l0000Sooooo`?o00008Oooool00ol0003ooooooooo
o`03ooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`?o00007_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo000Kooooo`0300000?l0003o00000?oo00000Ol000010000007ooooo000K
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`006oooool00`00003oooooooooo`02oooo
o`<0o`009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool05_ooool10000007ooooo000Kooooo`0400000?ooooooooooooooo`D0o`008oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo000Kooooo`0400000?ooooooooooooooo`D0o`008oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`04
00000?l0003oooooooooo`D0o`008oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000oooooooo
ool00_ooool30?l002Cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`002?ooool3o`0000?ooooo0_l00004ooooo`;o0000
1Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08Oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007o
oooo0005o`000003ooooool0003o000000?o00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000o`00000007l01@0007l00`000000001o0000O`3g0000
O`7o00000@000001ooooo`001_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo023ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`001oooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo023ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool08?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo0009ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
1Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01oooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`07ooooo`0300000?oooooooooo01oooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000K
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Koooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`03
00000?oooooooooo00Wooooo00<00000ooooooooool07Oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`030000
0?l0003ooooo00Wooooo00<00000ooooooooool07Oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000
ooooooooool02_ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool02oooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo01[ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo01[ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0=
ooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0=oooo
o`0300000?oooooooooo01Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0=ooooo`03
00000?oooooooooo01Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00kooooo
00<00000ooooooooool06?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool05_ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool06?ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Gooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`40
00000Oooool000Go00001Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00`00003o00000000O`0?0000O`030000000007l0001o
0>d0001o0Ol000010000007ooooo0008ooooo`;o00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0F
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool04?ooool00`00003ooooooooo
o`0Fooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Fooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Aooooo`03
00000?oooooooooo01Gooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Gooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`0Booooo`0300000?oooooooooo01Cooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000K
ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Koooo
o`0300000?oooooooooo01?ooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`030000
0?l0003ooooo01?ooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<0
0000ooooooooool05?ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000
ooooooooool05?ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooo
ooooool05Oooool30?l0017ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Dooooo`D0
o`004?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?l0003ooooo01Cooooo1@3o000@ooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Eooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`0Dooooo`D0o`004?ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?oooooooooo01Gooooo0`3o000Aooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooo
ooooool05oooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool06?ooool00`00003oooooooooo`0>ooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0Hooooo`0300000?oooooooooo00kooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001_ooool5o`0000?ooooo0_l0
0004ooooo`;o00001Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00gooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00go
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01[ooooo00<00000oooo
ooooool03?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool05_ooool10000007ooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l06P0007l0
0`000000001o0000O`3R0000O`7o00000@000001ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo01_ooooo00<00000ooooooooool02oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo0006ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool06oooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Oo
oooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool06oooool00`00003o
ooooooooo`0;ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool07?ooool00`00003ooooo
ooooo`0:ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Looooo`0300000?oo
oooooooo00[ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Mooooo`0300000?oooooo
oooo00Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo
00Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00So
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`006oooool00`00003o0000ooooo`0Nooooo`0300000?oooooooooo00Sooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo01oooooo00<00000ooooooooool01ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo01oooooo00<00000ooooooooool01oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo023ooooo00<00000ooooooooool01_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo000Kooooo`0300000?l0003ooooo023ooooo00<00000ooooooooool01_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`000040
00000Oooool001_ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`05ooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001_ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`05ooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool08_ooool00`00003oooooooooo`04ooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01_ooooo00<00000o`000?ooool08_ooool00`00003oooooooooo`04ooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo00?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
1oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Sooooo`030000
0?oooooooooo00?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Tooooo`03
00000?oooooooooo00;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
02Cooooo00<00000ooooooooool00_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05_ooool10000007ooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000
001o02@0001o00<000000000O`0007l0f00007l1o`00004000000Oooool000Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool09Oooool01@00003oooooooooooooool0001o02Gooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Oooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Uooooo`05
00000?ooooooooooooooo`0007l09Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Go
oooo00<00000ooooooooool09_ooool01000003oooooooooo`0007lUooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?l0003ooooo02Ko
oooo00@00000ooooooooool0001o9Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Oooooo00<00000ooooo`00
07l09Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0Wooooo`0300000?ooool0001o02Gooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0:?oo
ool30?l002Cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool09oooool50?l002?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool09oooool50?l0
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`0Wooooo`D0o`008oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Xooooo`<0o`00
9?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Yooooo`030000O`00003ooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool0
0`0007oooooo0000000Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1
o`00004000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`0007oooooo0000000Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`03
00000?oooooooooo02Wooooo00@0001oooooooooool000008_ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`04
0000Oooooooooooo000002;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001_ooooo00<00000ooooooooool0:Oooool01@0007ooooooooooooooool00000
027ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_o
oooo00<00000o`000?ooool0:Oooool01@0007ooooooooooooooool00000027ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`0Yooooo`030000Oooooooooooo00;ooooo00<00000ooooooooool07_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005?ooool2o`0000Gooooo
00<00000ooooooooool0:Oooool00`0007ooooooooooo`02ooooo`0300000?oooooooooo01kooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo00?ooooo
00<00000ooooooooool07Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?l00000001o02l0001o
00<000000000O`0007l0c@0007l1o`00004000000Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo00Cooooo00<00000ooooooooool0
7?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`004ooo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0
1?ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5_ooool10000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
:Oooool00`0007ooooooooooo`05ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Cooooo0_l00005ooooo`0300000?oo
oooooooo02Wooooo00<0001oooooooooool01Oooool00`00003oooooooooo`0Kooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?l0003o
oooo02Wooooo00<0001oooooooooool01_ooool00`00003oooooooooo`0Jooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000oooo
ooooool0:Oooool00`0007ooooooooooo`07ooooo`0300000?oooooooooo01Wooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0:Oooool00`0007ooooooooooo`07ooooo`0300000?oooooooooo01Wooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0
:Oooool00`0007ooooooooooo`08ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Ooo
ool00`0007ooooooooooo`08ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Y
ooooo`030000Oooooooooooo00Wooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yoooo
o`030000Oooooooooooo00Wooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`03
0000Oooooooooooo00[ooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Yooooo`030000
Oooooooooooo00[ooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0
001oooooooooool02oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001o
ooooooooool02oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001ooooo
ooooool03?ooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001ooooooooo
ool03?ooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?l0003ooooo02Wooooo00<0001oooooooooool0
3Oooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`0007oooooooooo
o`0=ooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Fooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000
ooooooooool0:Oooool00`0007ooooooooooo`0>ooooo`0300000?oooooooooo01;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0:Oooool00`0007ooooooooooo`0>ooooo`0300000?oooooooooo01;ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000o`00000007l0>`0007l30?l00<40001o0Ol000010000007ooooo0008ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo02Wooooo00<0001oooooooooool03_ooool50?l0013ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool0:Oooool00`0007ooooooooooo`0>ooooo`D0o`004?ooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`001oooool2o`0000Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Wooooo00<0001o
ooooooooool03_ooool50?l0013ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo02Wooooo00<0001oooooooooool03oooool30?l00003ooooo`00003ooooo
00kooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_o
oooo00<00000o`000?ooool0:Oooool00`0007ooooooooooo`0Dooooo`8000003Oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo02Wooooo00<0001oooooooooool05_ooool00`00003oooooooooo`0:ooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oo
oooooooo02Wooooo00<0001oooooooooool05oooool00`00003oooooooooo`09ooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooo
oooo02Wooooo00<0001oooooooooool06?ooool2000000Wooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool00`00
07ooooooooooo`0Jooooo`0300000?oooooooooo00Kooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`03
0000Oooooooooooo01_ooooo0P000006ooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0
7Oooool00`00003oooooooooo`03ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool07_oo
ool00`00003oooooooooo`02ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool07oooool2
000000;ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01_ooooo00<00000o`000?ooool0:Oooool00`0007ooooooooooo`0Qooooo`040000003o0000o`00
0?l002Cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000oooo
ooooool0:Oooool00`0007ooooooooooo`0Qooooo`D0o`008oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`0Qooooo`D0
o`008oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0
:Oooool00`0007ooooooooooo`0Qooooo`D0o`001@00000Nooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`006oooool00`00003o0000ooooo`0Yooooo`030000Oooooooooooo02;ooooo0`3o
0006ooooo`D000001Oooool30?l0017ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Ooo
ool001_ooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo00[ooooo100000050?l0013ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo0006oooo
o`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo02Wooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0>ooooo`D0o`000`00000<ooooo`<0o`009?ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0>ooooo`D0o`000oooool9000000;ooooo1@3o000?ooooo`<0o`004Ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0?ooooo`<0o`003Oooool2000000D0o`0020000006ooooo`D0o`00
4?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5_ooool10000007ooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l0L`0007l50?l000P0
001o1P0000050?l007@0001o0Ol000010000007ooooo0006ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool0:Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo0`3o000?
ooooo`D0o`001000000<ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0Yooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0?ooooo`<0o`001Oooool4000000Sooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001oooool3o`0000Cooooo0_l0
0004ooooo`;o00001Oooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Kooooo`<000001?ooool30?l002Cooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000
o`000?ooool0:Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool07_ooool3000000D0o`008oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo027ooooo1@3o00000`00
003oooooooooo`0Pooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo027ooooo1@3o00000oooool0000000000005000000Oo
oooo0`3o000Aooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007o
oooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02;ooooo0`3o0009ooooo`H000001@3o000@ooooo`030000
Oooooooooooo02;ooooo0`3o000Gooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0>ooooo`D0o`004?ooool00`0007ooooooooooo`0?ooooo`<0o`003ooo
ool50?l001Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool03_ooool50?l000D000002oooool00`0007ooooooooooo`0>ooooo`D0o`001oooool7
000000D0o`005_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool03oooool30?l000Kooooo1@000005ooooo`<0o`003?ooool3000000D0o`001`000007oooo
o`D0o`001000000Booooo`4000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Mooooo`@000001@3o0002ooooo`T000000oooool50?l000oooooo0`3o0005ooooo`@0
00003_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8Oooool50?l0008000003Oooool30?l0017ooooo00<0001oooooooooool02?ooool3000000Cooooo
0`3o0004ooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Qooooo`D0o`008oooool00`0007ooooooooooo`0;ooooo`<000001@3o0002ooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02;ooooo0`3o000T
ooooo`030000Oooooooooooo00kooooo1@3o0003ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0:Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool03_ooool50?l000?ooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool30?l000Cooooo0@000001ooooo`00
6ooooooo000000<000000Ol000010000007ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.242501, -506.137, \
0.0525754, 4.49796}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of test data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 0.427601 0.000923715 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05812 -24 -4.5 ]
[-0.0125 .05812 0 4.5 ]
[-0.0125 .15049 -24 -4.5 ]
[-0.0125 .15049 0 4.5 ]
[-0.0125 .24286 -24 -4.5 ]
[-0.0125 .24286 0 4.5 ]
[-0.0125 .33523 -24 -4.5 ]
[-0.0125 .33523 0 4.5 ]
[-0.0125 .4276 -6 -4.5 ]
[-0.0125 .4276 0 4.5 ]
[-0.0125 .51997 -18 -4.5 ]
[-0.0125 .51997 0 4.5 ]
[-0.0125 .61234 -18 -4.5 ]
[-0.0125 .61234 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .05812 m
1 .05812 L
s
0 .15049 m
1 .15049 L
s
0 .24286 m
1 .24286 L
s
0 .33523 m
1 .33523 L
s
0 .4276 m
1 .4276 L
s
0 .51997 m
1 .51997 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05812 m
.00625 .05812 L
s
[(-400)] -0.0125 .05812 1 0 Mshowa
0 .15049 m
.00625 .15049 L
s
[(-300)] -0.0125 .15049 1 0 Mshowa
0 .24286 m
.00625 .24286 L
s
[(-200)] -0.0125 .24286 1 0 Mshowa
0 .33523 m
.00625 .33523 L
s
[(-100)] -0.0125 .33523 1 0 Mshowa
0 .4276 m
.00625 .4276 L
s
[(0)] -0.0125 .4276 1 0 Mshowa
0 .51997 m
.00625 .51997 L
s
[(100)] -0.0125 .51997 1 0 Mshowa
0 .61234 m
.00625 .61234 L
s
[(200)] -0.0125 .61234 1 0 Mshowa
.125 Mabswid
0 .07659 m
.00375 .07659 L
s
0 .09506 m
.00375 .09506 L
s
0 .11354 m
.00375 .11354 L
s
0 .13201 m
.00375 .13201 L
s
0 .16896 m
.00375 .16896 L
s
0 .18744 m
.00375 .18744 L
s
0 .20591 m
.00375 .20591 L
s
0 .22438 m
.00375 .22438 L
s
0 .26133 m
.00375 .26133 L
s
0 .27981 m
.00375 .27981 L
s
0 .29828 m
.00375 .29828 L
s
0 .31676 m
.00375 .31676 L
s
0 .3537 m
.00375 .3537 L
s
0 .37218 m
.00375 .37218 L
s
0 .39065 m
.00375 .39065 L
s
0 .40913 m
.00375 .40913 L
s
0 .44608 m
.00375 .44608 L
s
0 .46455 m
.00375 .46455 L
s
0 .48302 m
.00375 .48302 L
s
0 .5015 m
.00375 .5015 L
s
0 .53845 m
.00375 .53845 L
s
0 .55692 m
.00375 .55692 L
s
0 .5754 m
.00375 .5754 L
s
0 .59387 m
.00375 .59387 L
s
0 .03964 m
.00375 .03964 L
s
0 .02117 m
.00375 .02117 L
s
0 .00269 m
.00375 .00269 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05812 m
1 .05812 L
s
.99375 .15049 m
1 .15049 L
s
.99375 .24286 m
1 .24286 L
s
.99375 .33523 m
1 .33523 L
s
.99375 .4276 m
1 .4276 L
s
.99375 .51997 m
1 .51997 L
s
.99375 .61234 m
1 .61234 L
s
.125 Mabswid
.99625 .07659 m
1 .07659 L
s
.99625 .09506 m
1 .09506 L
s
.99625 .11354 m
1 .11354 L
s
.99625 .13201 m
1 .13201 L
s
.99625 .16896 m
1 .16896 L
s
.99625 .18744 m
1 .18744 L
s
.99625 .20591 m
1 .20591 L
s
.99625 .22438 m
1 .22438 L
s
.99625 .26133 m
1 .26133 L
s
.99625 .27981 m
1 .27981 L
s
.99625 .29828 m
1 .29828 L
s
.99625 .31676 m
1 .31676 L
s
.99625 .3537 m
1 .3537 L
s
.99625 .37218 m
1 .37218 L
s
.99625 .39065 m
1 .39065 L
s
.99625 .40913 m
1 .40913 L
s
.99625 .44608 m
1 .44608 L
s
.99625 .46455 m
1 .46455 L
s
.99625 .48302 m
1 .48302 L
s
.99625 .5015 m
1 .5015 L
s
.99625 .53845 m
1 .53845 L
s
.99625 .55692 m
1 .55692 L
s
.99625 .5754 m
1 .5754 L
s
.99625 .59387 m
1 .59387 L
s
.99625 .03964 m
1 .03964 L
s
.99625 .02117 m
1 .02117 L
s
.99625 .00269 m
1 .00269 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .21071 L
.17033 .34141 L
.24359 .48623 L
.31685 .53426 L
.39011 .56379 L
.46337 .56987 L
.53663 .56244 L
.60989 .58565 L
.68315 .59655 L
.75641 .5967 L
.82967 .59866 L
.90293 .60332 L
.97619 .60311 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .21071 Mdot
.17033 .34141 Mdot
.24359 .48623 Mdot
.31685 .53426 Mdot
.39011 .56379 Mdot
.46337 .56987 Mdot
.53663 .56244 Mdot
.60989 .58565 Mdot
.68315 .59655 Mdot
.75641 .5967 Mdot
.82967 .59866 Mdot
.90293 .60332 Mdot
.97619 .60311 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007_ooool5o`0002?ooooo0ol0000Rooooo`?o00008oooool3o`00023ooooo0ol00004oooo
o`;o00007Oooool3o`0000;ooooo1Ol0000Looooo`?o00001?ooool3o`0001Kooooo000Oooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo
0000027ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`008?ooool00ol0003ooooo
ooooo`0Qooooo`Go00008Oooool01Ol0003ooooooooooooooooo0000027ooooo00Go0000oooooooo
ooooooooo`00000Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`008Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0002;ooooo1?l0
000Sooooo`?o00008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`007_ooool01Ol0003ooooooooooooooooo000002;o
oooo00?o0000ooooool000008_ooool00ol0003oooooooooo`0Sooooo`05o`000?oooooooooooooo
ool000008?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`007_ooool01Ol0003ooooooooooooooooo000002?ooooo0_l0
000Sooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`00000Oooooo`;o0000
1?ooool01?l0003oooooooooool0000Looooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01cooooo0_l00005ooooo`;o00005oooool001oooooo0ol0000Uooooo`03o`000?oooooooooo02;o
oooo0_l0000Sooooo`?o00008Oooool00ol0003oooooooooo`03ooooo`;o00007_ooool00ol0003o
ooooooooo`02ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Kooooo`03
00000?l0003o00000?oo00000Ol000010000007ooooo000Kooooo`0300000?l0003ooooo00?ooooo
00<00000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00;ooooo0ooo000Tooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00@00000oooooooooooooooo1Ooo000Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00@00000
oooooooooooooooo1Ooo000Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00@00000oooooooooooooooo1Ooo
000Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool00_ooool3ool002Cooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol00001
0000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool08_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo000Kooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool08_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007o
oooo000Kooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08Oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo
000Kooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08Oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?l0003ooooo00Gooooo00<00000ooooooooool08Oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool0
01_ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000So
oooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0Pooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo01oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`001Ol000000ooooooo0000o`000003o`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo0006ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?l00000001o00L0001o00<000000000O`0007l0m@0007l1o`00004000000Oooool000Oooooo00?o
0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Sooooo
0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`002Oooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`0Nooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool02Oooool00`00003ooooo
ooooo`0Mooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo01gooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo01cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo
01cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01co
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`006oooool00`00003o0000ooooo`0;ooooo`0300000?oooooooooo01_ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool06ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool06oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo000Kooooo`0300000?oooooooooo00cooooo00<00000ooooooooool06_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007o
oooo000Kooooo`0300000?l0003ooooo00gooooo00<00000ooooooooool06Oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Iooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Iooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01_ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Hooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_o
oooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Hooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo
00<00000o`000?ooool03_ooool00`00003oooooooooo`0Hooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006ooo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Oooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001oooool3
o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01Oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool05oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool05_ooool10000007ooooo0005o`0000Gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`000000
07l0400007l00`000000001o0000O`3/0000O`7o00000@000001ooooo`002?ooool2o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
013ooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05_ooool10000007ooooo000:ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooo
oooo017ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo0006ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool04Oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Oooooo0ol0
0004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool04Oooool00`00003ooooooooo
o`0Eooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool04_ooool00`00003oooooooooo`0D
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0E
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo
01Cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01Co
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`006oooool00`00003o0000ooooo`0Dooooo`0300000?oooooooooo01;ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol00001
0000007ooooo000Kooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04_ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000
007ooooo000Kooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04_ooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007o
oooo000Kooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool04Oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo
000Kooooo`0300000?oooooooooo01Gooooo0ooo000Aooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000
o`000?ooool05?ooool5ool0013ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo
01Cooooo1Ooo000@ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool05?ooool5ool0013o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Eooooo`?oo`004Oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo
000Kooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool03oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?l0003ooooo01Sooooo00<00000ooooooooool03_ooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool0
01_ooooo00<00000ooooooooool06Oooool00`00003oooooooooo`0=ooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Ko
oooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool06Oooool00`00003o
ooooooooo`0=ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool06_ooool0
0`00003oooooooooo`0<ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool000Go00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000
O`0J0000O`030000000007l0001o0>80001o0Ol000010000007ooooo0009ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00<00000ooooooooool06oooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Kooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00_ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool02_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooo
oooo01cooooo00<00000ooooooooool02_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?l0003ooooo
01gooooo00<00000ooooooooool02Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000oooooooo
ool07_ooool00`00003oooooooooo`08ooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0
7_ooool00`00003oooooooooo`08ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool07ooo
ool00`00003oooooooooo`07ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool07oooool0
0`00003oooooooooo`07ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool08?ooool00`00
003oooooooooo`06ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Pooooo`03
00000?oooooooooo00Kooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Qooooo`030000
0?oooooooooo00Gooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Qooooo`0300000?oo
oooooooo00Gooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`0300000?oooooo
oooo00Cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Sooooo`0300000?oooooooooo
00?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<00000oooooooo
ool00oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool0
0_ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool00_oo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02Gooooo00D00000oooooooooooooooo0000
O`0Uooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000K
ooooo`0300000?l0003ooooo02Gooooo00D00000oooooooooooooooo0000O`0Uooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000
ooooooooool09_ooool01000003oooooooooo`0007lUooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool05_ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005
ooooo`0300000?oooooooooo02Kooooo00@00000ooooooooool0001o9Oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`002?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`0Wooooo`0300000?ooool0001o02Gooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`0X0000O`?o
o`00e00007l1o`00004000000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool09oooool5ool0
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000ooooooooool09oooool5ool002?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool000Oooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Wooooo`Goo`008ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`002?ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0:?ooool3
ool002Cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01_ooooo00<00000o`000?ooool0:Oooool00`0007l00000ooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000oooooooo
ool0:Oooool00`0007oooooo0000000Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooo`000000
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Yooooo`040000Oooooooooooo000002;ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0:Ooo
ool0100007ooooooooooo`00000Rooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?l0003ooooo02Wooooo00D0001ooooooooooooooooo
0000000Qooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05Oooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool0:Oooool01@0007ooooooooooooooool00000027ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0:Oooool00`0007ooooooooooo`02ooooo`0300000?oooooooooo01kooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000
ooooooooool0:Oooool00`0007ooooooooooo`02ooooo`0300000?oooooooooo01kooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0:Oooool00`0007ooooooooooo`03ooooo`0300000?oooooooooo01gooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooo
ooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0:Oooool00`0007ooooooooooo`03ooooo`0300000?oooooooooo01gooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0Yooooo`030000Oooooooooooo00Cooooo00<00000ooooooooool07?ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Yooooo`030000Oooooooooooo00Cooooo00<00000ooooooooool07?ooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Y
ooooo`030000Oooooooooooo00Gooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yoooo
o`030000Oooooooooooo00Gooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Yooooo`03
0000Oooooooooooo00Kooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Wooooo
00<0001oooooooooool01_ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool05_ooool10000007ooooo000Dooooo`;o00001Oooool00`00003ooooooooo
o`0Yooooo`030000Oooooooooooo00Oooooo00<00000ooooooooool06Oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool01oooool00`00003ooooooooo
o`0Iooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0=00007l00`000000001o0000
O`380000O`7o00000@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo02Wooooo00<0001oooooooooool02?ooool00`00003oooooooooo`0Hooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`09ooooo`0300000?oo
oooooooo01Oooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Yooooo`030000Oooo
oooooooo00Wooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005?ooool2o`0000Gooooo00<00000ooooooooool0:Oooool0
0`0007ooooooooooo`0:ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool00`00
07ooooooooooo`0:ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Eooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`03
0000Oooooooooooo00_ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000
Oooooooooooo00_ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000Oooo
oooooooo00cooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000Oooooooo
oooo00cooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Yooooo`030000Oooooooooooo
00gooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
01Gooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001ooooooooo
ool03Oooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0
3_ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
8oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool0
5_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool03_oo
ool00`00003oooooooooo`0Booooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool03oooool3
ool0017ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01_ooooo00<00000o`000?ooool0:Oooool00`0007ooooooooooo`0>ooooo`Goo`004?ooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Kooooo`03
00000?oooooooooo02Wooooo00<0001oooooooooool03_ooool5ool0013ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001ooooooooo
ool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0
:Oooool00`0007ooooooooooo`0>ooooo`Goo`004?ooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000Oooo
oooooooo00oooooo0ooo00000oooool000000000000>ooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0
001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001o
ooooooooool05Oooool2000000cooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool00`0007ooooooooooo`0Goooo
o`0300000?oooooooooo00Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Soooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Eoooo
o`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo01So
oooo0P000009ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007o
oooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo02Wooooo
00<0001oooooooooool06_ooool00`00003oooooooooo`06ooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool05_ooool10000007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Wo
oooo00<0001oooooooooool06oooool2000000Kooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0B@0007l00`00
0000001o0000O`2c0000O`7o00000@000001ooooo`002?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Y
ooooo`030000Oooooooooooo01kooooo0P000003ooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool05_ooool10000007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Wooooo00<0
001oooooooooool08?ooool2000000?oo`009?ooool00`0007ooooooooooo`0Sooooo`030000Oooo
oooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo027ooooo1Ooo000Sooooo`030000
Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000Gooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`0Qooooo`Goo`008ooo
ool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08ooo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool0
0`0007ooooooooooo`0Qooooo`Goo`000P00000Qooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo01Gooooo0Ol00001
0000007ooooo000Kooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool08_ooool3ool0
00?ooooo0P00000Oooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0Yooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool01?ooool2000001go
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`06ooooo`<000006_ooool00`0007oooooo
ooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo00Wooooo0P00000Hooooo`030000Oooooooooooo00oooooo0ooo
000Aooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001_ooooo00<00000o`000?ooool0:Oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo00_ooooo0P000002ooooo`?oo`004Oooool00`0007ooooooooooo`0>
ooooo`Goo`004?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo02?ooooo00<0001o
ooooooooool05Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo00gooooo00<00000ool00?oo00000ooo000?oooo
o`?oo`003?ooool3000000Goo`004?ooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wo
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0>ooooo`Goo`0020000006ooooo`Go
o`000_ooool9000000?ooooo1Ooo0003000000gooooo00<0001oooooooooool08oooool00`0007oo
ooooooooo`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Yooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool03_ooool5ool000Sooooo
1P000005ool0008000003Oooool3ool000Cooooo0`00000:ooooo`030000Oooooooooooo02?ooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0:Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo00oooooo0ooo
000?ooooo`Goo`006Oooool3000000Oooooo00<0001oooooooooool08oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo01Kooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Y
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08_ooool3ool001gooooo0`000004
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0E
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo
02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Oooooo`<000000ooo000Toooo
o`030000Oooooooooooo02?ooooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`03
00000?oooooooooo02Wooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`03
0000Oooooooooooo027ooooo1Ooo00000`00003oooooooooo`0Pooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool05_ooool10000007ooooo000Kooooo`0300000?oooooooooo02Wooooo
00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo027ooooo
1Ooo00000oooool0000000000005000000Oooooo0ooo000@ooooo`?oo`009?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001_ooooo00<00000ooooooooool0:Oooool00`0007oooooooooo
o`0Sooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08Oooool5ool000Sooooo1P00
0005ool000kooooo1Ooo000?ooooo`?oo`004Oooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001_ooooo00<00000o`000?ooool0:Oooool00`0007ooooooooooo`0Sooooo`030000Oooooooo
oooo02?ooooo00<0001oooooooooool08_ooool3ool000oooooo1Ooo000>000000Goo`0020000006
ooooo`Goo`003oooool3ool0013ooooo0ooo0003ooooo`7o00000@000001ooooo`006oooool00`00
003oooooooooo`0Yooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`00
07ooooooooooo`0Sooooo`030000Oooooooooooo00kooooo1Ooo000>ooooo`Goo`002?ooool60000
00Goo`0020000006ooooo`Goo`003_ooool5ool000?ooooo0@000001ooooo`001_ooool5o`0000?o
oooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo02?o
oooo00<0001oooooooooool08oooool00`0007ooooooooooo`0Sooooo`030000Oooooooooooo00oo
oooo0ooo000@ooooo`?oo`003oooool5ool000Sooooo1P000005ool000h000001Ooo0003ooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo02?ooooo00<0001oooooooooool08oooool00`0007ooooooooooo`0S
ooooo`030000Oooooooooooo00oooooo0ooo000?ooooo`Goo`003_ooool5ool000?ooooo0@000001
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003o0000ooooo`03ooooo`0300000?oooooooooo02?ooooo00<0
0000ooooooooool08oooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo02?ooooo00<0
0000ooooooooool08oooool00`00003oooooooooo`0Rooooo`?oo`004?ooool3ool000?ooooo0Ol0
00010000007ooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00`00003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00`00003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool10000007ooooo
0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Coooooo`0000050000007ooooo0006ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_oo
ool000Oooooo0ol00004ooooo`;o00001?ooool2o`000?oooooo2oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.242501, -516.502, \
0.0525754, 4.16977}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Idealized plot (interlocking polygons)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot2;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.78571 .02381 m
.78571 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.21429 .59524 m
.21429 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.21429 .21429 m
.21429 .40476 L
.78571 .40476 L
.78571 .21429 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK
0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3o
oglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
f`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo
=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0
oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
om/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?oo
OcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg
0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3o
ogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomo
f`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0
oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
ocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?oo
OcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK
0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3o
oglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
f`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo
=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0
oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
ocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?oo
Om/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg
0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3o
ogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomo
f`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?o
oooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolg0?ooOm/0Oooo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooocL0oomof`1oool6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oogoK07ooo`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooolg0?ooOm/0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0
oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo0000
0`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0
Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`400000
0Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03oooo
om/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Ko
oooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?oo
OcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07oo
o`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK
0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6oooo
o`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg
07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool000030000
0?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3o
oglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1o
ool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
f`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0
000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00003oooooooooo`03ooooom/0oomo
=`1oool6ooooo`4000000Oooool0000300000?oooooooooo00?ooooof`3ooglg07ooo`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooK0?ooOcL0Oooo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooom/0oomo=`1oool6ooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the number of Gaussians (E-shaped region)", "Section"],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points for training and test data", "Subsubsection"],

Cell[BoxData[{
    \(\(n1 = 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2 = 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ region1Data[n1];\)\), "\n", 
    \(\(data2\  = \ region1Data[n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize training data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.4803 .19593 Mdot
.39924 .90947 Mdot
.5537 .97206 Mdot
.19525 .5676 Mdot
.26881 .03008 Mdot
.17754 .41558 Mdot
.16668 .71694 Mdot
.67658 .53081 Mdot
.58342 .45095 Mdot
.53818 .07188 Mdot
.32441 .43067 Mdot
.52783 .15406 Mdot
.21357 .91975 Mdot
.07151 .89661 Mdot
.51641 .15754 Mdot
.47828 .45547 Mdot
.16367 .0346 Mdot
.60778 .43917 Mdot
.62604 .87074 Mdot
.40401 .50961 Mdot
.12038 .18572 Mdot
.14215 .10005 Mdot
.13037 .15128 Mdot
.25354 .04042 Mdot
.50618 .52124 Mdot
.45812 .80349 Mdot
.37383 .431 Mdot
.19915 .15417 Mdot
.47516 .59802 Mdot
.05 .04675 Mdot
.16923 .53972 Mdot
.51196 .58206 Mdot
.13893 .17851 Mdot
.41024 .54007 Mdot
.14345 .54273 Mdot
.10326 .50578 Mdot
.08648 .05099 Mdot
.61693 .54423 Mdot
.75542 .43148 Mdot
.2165 .01396 Mdot
.62177 .87895 Mdot
.28142 .07191 Mdot
.20475 .03072 Mdot
.59428 .41691 Mdot
.37137 .18709 Mdot
.6506 .52953 Mdot
.10751 .10217 Mdot
.60958 .0359 Mdot
.7353 .82633 Mdot
.41463 .01498 Mdot
.15082 .41922 Mdot
.2295 .01903 Mdot
.12885 .7026 Mdot
.13179 .90705 Mdot
.24079 .81884 Mdot
.22495 .55913 Mdot
.08393 .14971 Mdot
.27243 .15154 Mdot
.30448 .89798 Mdot
.05274 .14232 Mdot
.18543 .20518 Mdot
.06857 .59427 Mdot
.69243 .49654 Mdot
.39776 .58875 Mdot
.53663 .52265 Mdot
.27886 .59718 Mdot
.50249 .95093 Mdot
.03456 .5092 Mdot
.4452 .84424 Mdot
.4123 .86564 Mdot
.19998 .48207 Mdot
.29288 .03421 Mdot
.35736 .12404 Mdot
.65075 .09215 Mdot
.4806 .79833 Mdot
.15806 .13141 Mdot
.02045 .44489 Mdot
.11188 .1233 Mdot
.46164 .96505 Mdot
.16517 .53804 Mdot
.01692 .41643 Mdot
.5252 .86779 Mdot
.51455 .43271 Mdot
.72342 .95744 Mdot
.18158 .04696 Mdot
.14164 .25528 Mdot
.02622 .49912 Mdot
.1606 .08856 Mdot
.0191 .09249 Mdot
.12084 .76846 Mdot
.69856 .45905 Mdot
.11489 .23872 Mdot
.44107 .17241 Mdot
.43177 .08972 Mdot
.19687 .69372 Mdot
.09139 .74645 Mdot
.08584 .91546 Mdot
.37747 .46622 Mdot
.37787 .02942 Mdot
.42345 .03064 Mdot
.13328 .93967 Mdot
.56371 .03647 Mdot
.7456 .92005 Mdot
.78792 .43346 Mdot
.30438 .06744 Mdot
.06221 .76477 Mdot
.63019 .98437 Mdot
.04973 .12126 Mdot
.03956 .71528 Mdot
.11844 .46735 Mdot
.56147 .91181 Mdot
.65689 .15462 Mdot
.25821 .98834 Mdot
.03651 .16044 Mdot
.02441 .30622 Mdot
.19424 .58991 Mdot
.09436 .90024 Mdot
.05444 .78878 Mdot
.26889 .18011 Mdot
.62538 .55851 Mdot
.6022 .0353 Mdot
.37697 .56036 Mdot
.57549 .86506 Mdot
.53094 .46796 Mdot
.23317 .55532 Mdot
.44149 .20573 Mdot
.29482 .11502 Mdot
.65465 .49718 Mdot
.3418 .55245 Mdot
.43129 .93206 Mdot
.63142 .18622 Mdot
.14393 .70797 Mdot
.19973 .97069 Mdot
.47215 .0522 Mdot
.36043 .80026 Mdot
.18713 .92737 Mdot
.10644 .5047 Mdot
.25468 .0959 Mdot
.23369 .4843 Mdot
.59022 .58892 Mdot
.16874 .64705 Mdot
.03461 .92928 Mdot
.07055 .76514 Mdot
.55266 .88688 Mdot
.70031 .95507 Mdot
.37533 .94971 Mdot
.60368 .46017 Mdot
.13046 .86361 Mdot
.37979 .96607 Mdot
.4879 .05383 Mdot
.17648 .52345 Mdot
.46636 .55857 Mdot
.4187 .83237 Mdot
.29805 .95895 Mdot
.48289 .13233 Mdot
.39611 .06642 Mdot
.05922 .36805 Mdot
.26519 .56637 Mdot
.13453 .69808 Mdot
.77915 .47715 Mdot
.78082 .081 Mdot
.39451 .02439 Mdot
.03621 .60875 Mdot
.08971 .08996 Mdot
.04855 .05434 Mdot
.68499 .5907 Mdot
.25959 .56738 Mdot
.46563 .17853 Mdot
.50967 .50492 Mdot
.43923 .55998 Mdot
.17438 .84859 Mdot
.01371 .21769 Mdot
.09448 .76843 Mdot
.69332 .56367 Mdot
.65457 .51914 Mdot
.16626 .82178 Mdot
.40478 .94195 Mdot
.74262 .79735 Mdot
.57804 .93896 Mdot
.49602 .01516 Mdot
.49336 .18034 Mdot
.7929 .44169 Mdot
.14813 .91275 Mdot
.48565 .91668 Mdot
.73354 .96099 Mdot
.48094 .80725 Mdot
.30427 .96472 Mdot
.01535 .52747 Mdot
.75762 .92988 Mdot
.28177 .02301 Mdot
.13367 .63413 Mdot
.05821 .3988 Mdot
.32948 .44637 Mdot
.56747 .58175 Mdot
.03502 .47185 Mdot
.22677 .50269 Mdot
.26483 .03533 Mdot
.22123 .96541 Mdot
.4974 .09564 Mdot
.22543 .08244 Mdot
.17703 .67383 Mdot
.59976 .10188 Mdot
.18276 .26725 Mdot
.09304 .95995 Mdot
.7803 .51098 Mdot
.19035 .4189 Mdot
.09662 .14545 Mdot
.25516 .05009 Mdot
.43815 .82038 Mdot
.0107 .49014 Mdot
.40203 .42976 Mdot
.06455 .28679 Mdot
.1023 .33319 Mdot
.01548 .19754 Mdot
.6439 .57775 Mdot
.56663 .86741 Mdot
.25167 .1578 Mdot
.59423 .07984 Mdot
.15238 .18871 Mdot
.66853 .86386 Mdot
.49606 .54911 Mdot
.55408 .86334 Mdot
.70311 .94771 Mdot
.7471 .95048 Mdot
.11869 .87767 Mdot
.60715 .15062 Mdot
.12089 .59171 Mdot
.19237 .40996 Mdot
.13632 .41453 Mdot
.12737 .1479 Mdot
.37941 .45425 Mdot
.01849 .26043 Mdot
.40154 .11961 Mdot
.29045 .51809 Mdot
.35256 .46615 Mdot
.10788 .11794 Mdot
.66216 .18828 Mdot
.2774 .02233 Mdot
.15983 .86462 Mdot
.16603 .31951 Mdot
.15115 .614 Mdot
.7398 .50419 Mdot
.55224 .86187 Mdot
.45916 .9763 Mdot
.20949 .40552 Mdot
.36108 .86816 Mdot
.09348 .85563 Mdot
.01169 .45329 Mdot
.45452 .49695 Mdot
.05251 .86301 Mdot
.58354 .87691 Mdot
.23227 .01855 Mdot
.16507 .01233 Mdot
.14859 .15312 Mdot
.16318 .54924 Mdot
.21494 .16211 Mdot
.31753 .41546 Mdot
.37993 .90248 Mdot
.78658 .03537 Mdot
.26794 .07346 Mdot
.56412 .02662 Mdot
.11268 .07094 Mdot
.42533 .8637 Mdot
.63197 .10625 Mdot
.78777 .9263 Mdot
.76896 .18774 Mdot
.41765 .03363 Mdot
.62126 .98846 Mdot
.55009 .82105 Mdot
.06695 .97164 Mdot
.63181 .11775 Mdot
.62384 .46045 Mdot
.09679 .96383 Mdot
.216 .43662 Mdot
.27876 .08892 Mdot
.58493 .43836 Mdot
.52778 .45691 Mdot
.28146 .48834 Mdot
.47455 .94261 Mdot
.63472 .06516 Mdot
.55225 .03601 Mdot
.05959 .61699 Mdot
.52201 .16989 Mdot
.62604 .81111 Mdot
.76818 .05908 Mdot
.16129 .8587 Mdot
.03878 .8552 Mdot
.47673 .82899 Mdot
.64334 .07065 Mdot
.10406 .5343 Mdot
.10122 .77124 Mdot
.31673 .84488 Mdot
.01596 .47815 Mdot
.43427 .88663 Mdot
.3401 .16678 Mdot
.71403 .4626 Mdot
.3142 .98699 Mdot
.61978 .9185 Mdot
.16137 .21493 Mdot
.01184 .83591 Mdot
.0543 .77827 Mdot
.16458 .33422 Mdot
.51731 .56573 Mdot
.01301 .1291 Mdot
.61775 .08174 Mdot
.16838 .75905 Mdot
.19125 .33958 Mdot
.3299 .87695 Mdot
.18922 .49387 Mdot
.14472 .70579 Mdot
.05696 .89911 Mdot
.40463 .91451 Mdot
.08812 .93726 Mdot
.40071 .7998 Mdot
.35936 .8133 Mdot
.62965 .16436 Mdot
.47203 .46451 Mdot
.21227 .18767 Mdot
.02947 .02242 Mdot
.13395 .2406 Mdot
.05957 .56485 Mdot
.47106 .04979 Mdot
.52773 .82579 Mdot
.12151 .22669 Mdot
.15761 .96227 Mdot
.43721 .57451 Mdot
.13794 .94965 Mdot
.08782 .55632 Mdot
.45942 .19159 Mdot
.60696 .51633 Mdot
.04342 .67496 Mdot
.41837 .95295 Mdot
.11511 .61904 Mdot
.24848 .98699 Mdot
.03709 .07253 Mdot
.77926 .8052 Mdot
.42033 .5464 Mdot
.07931 .70969 Mdot
.19009 .32793 Mdot
.54583 .1377 Mdot
.51855 .07497 Mdot
.16235 .51613 Mdot
.10802 .51877 Mdot
.30498 .06692 Mdot
.18294 .27182 Mdot
.11344 .55232 Mdot
.4525 .79558 Mdot
.36298 .87377 Mdot
.42137 .55244 Mdot
.26883 .04611 Mdot
.2899 .09355 Mdot
.11676 .81193 Mdot
.01312 .26941 Mdot
.55082 .46402 Mdot
.16481 .06841 Mdot
.26585 .19381 Mdot
.51013 .84235 Mdot
.31486 .55491 Mdot
.76894 .1825 Mdot
.40484 .57456 Mdot
.42888 .4743 Mdot
.55988 .19577 Mdot
.6942 .17684 Mdot
.06706 .67705 Mdot
.71845 .84375 Mdot
.28831 .50435 Mdot
.63065 .44188 Mdot
.25131 .81995 Mdot
.52306 .9664 Mdot
.22145 .03265 Mdot
.31492 .89253 Mdot
.34962 .84172 Mdot
.10811 .03158 Mdot
.57525 .05537 Mdot
.32727 .49347 Mdot
.11562 .47063 Mdot
.0705 .44602 Mdot
.09023 .16241 Mdot
.06706 .24354 Mdot
.68164 .88539 Mdot
.31859 .79904 Mdot
.62095 .44917 Mdot
.73705 .10596 Mdot
.17721 .69658 Mdot
.11995 .46284 Mdot
.57078 .06336 Mdot
.42851 .56765 Mdot
.29249 .14012 Mdot
.26703 .82191 Mdot
.45732 .83622 Mdot
.12226 .30459 Mdot
.28992 .14944 Mdot
.12708 .96177 Mdot
.17977 .6768 Mdot
.5465 .90821 Mdot
.74146 .11895 Mdot
.01161 .53318 Mdot
.67668 .16876 Mdot
.15231 .14223 Mdot
.03985 .82783 Mdot
.75946 .4965 Mdot
.36627 .93825 Mdot
.0278 .38735 Mdot
.08177 .28455 Mdot
.08409 .39668 Mdot
.07995 .74157 Mdot
.17825 .90519 Mdot
.61858 .95738 Mdot
.45175 .84805 Mdot
.37746 .46117 Mdot
.47647 .93125 Mdot
.65121 .55061 Mdot
.57239 .57655 Mdot
.11245 .34115 Mdot
.05759 .66819 Mdot
.6509 .4833 Mdot
.50117 .97576 Mdot
.28324 .03194 Mdot
.03451 .05431 Mdot
.49198 .48045 Mdot
.15831 .52661 Mdot
.11052 .84861 Mdot
.16605 .08925 Mdot
.59955 .86304 Mdot
.57484 .81853 Mdot
.10876 .11575 Mdot
.09724 .77817 Mdot
.28409 .93416 Mdot
.17765 .87427 Mdot
.13558 .41735 Mdot
.03487 .55894 Mdot
.20446 .24188 Mdot
.32166 .18457 Mdot
.73244 .90634 Mdot
.645 .13797 Mdot
.46763 .80785 Mdot
.12626 .92277 Mdot
.31679 .83156 Mdot
.60014 .51593 Mdot
.05041 .28772 Mdot
.29869 .5261 Mdot
.2227 .47161 Mdot
.18221 .47659 Mdot
.69748 .59445 Mdot
.10714 .08833 Mdot
.25033 .0532 Mdot
.23943 .47875 Mdot
.02653 .01694 Mdot
.13039 .79904 Mdot
.63138 .4909 Mdot
.6519 .49448 Mdot
.45898 .02411 Mdot
.17785 .6832 Mdot
.32973 .5462 Mdot
.22391 .82276 Mdot
.66802 .06152 Mdot
.75513 .80845 Mdot
.7136 .16149 Mdot
.58709 .13506 Mdot
.65957 .48546 Mdot
.24868 .98742 Mdot
.31804 .12521 Mdot
.64021 .07349 Mdot
.07008 .57202 Mdot
.18344 .90339 Mdot
.09059 .38532 Mdot
.4665 .17839 Mdot
.29859 .81229 Mdot
.34508 .5067 Mdot
.7328 .90881 Mdot
.37788 .9545 Mdot
.16249 .24001 Mdot
.65896 .9603 Mdot
.32369 .46341 Mdot
.62558 .17763 Mdot
.21848 .50235 Mdot
.75791 .44055 Mdot
.03491 .52194 Mdot
.44463 .54574 Mdot
.09985 .80181 Mdot
.58074 .13764 Mdot
.19487 .60372 Mdot
.73668 .45766 Mdot
.42716 .17297 Mdot
.17397 .92186 Mdot
.64324 .8595 Mdot
.55319 .06749 Mdot
.1486 .25808 Mdot
.19345 .29807 Mdot
.59196 .11557 Mdot
.44697 .8306 Mdot
.17461 .93279 Mdot
.67568 .1328 Mdot
.51152 .20114 Mdot
.12932 .43206 Mdot
.78219 .80542 Mdot
.64339 .55715 Mdot
.19735 .54932 Mdot
.02259 .42847 Mdot
.03254 .60672 Mdot
.14046 .87329 Mdot
.04339 .29891 Mdot
.56433 .50873 Mdot
.77502 .84385 Mdot
.18391 .49936 Mdot
.60978 .98082 Mdot
.41055 .14066 Mdot
.24727 .83264 Mdot
.49289 .09625 Mdot
.67272 .15464 Mdot
.15735 .7031 Mdot
.19386 .27283 Mdot
.09497 .75387 Mdot
.73952 .14522 Mdot
.19154 .53658 Mdot
.27921 .19887 Mdot
.13167 .48597 Mdot
.27731 .12273 Mdot
.6957 .12837 Mdot
.69323 .83073 Mdot
.45166 .40235 Mdot
.74437 .2051 Mdot
.47496 .01603 Mdot
.17076 .85866 Mdot
.3531 .52025 Mdot
.20021 .90519 Mdot
.04687 .0468 Mdot
.11096 .30513 Mdot
.78504 .80753 Mdot
.35678 .10984 Mdot
.17252 .56312 Mdot
.01157 .69466 Mdot
.52872 .57356 Mdot
.11812 .93913 Mdot
.6714 .81426 Mdot
.73311 .82974 Mdot
.71384 .44361 Mdot
.10427 .88067 Mdot
.02426 .93221 Mdot
.51729 .90625 Mdot
.1379 .92548 Mdot
.14097 .18634 Mdot
.41425 .49168 Mdot
.62686 .54064 Mdot
.65127 .4783 Mdot
.09841 .94272 Mdot
.55681 .58783 Mdot
.40275 .19625 Mdot
.30641 .83223 Mdot
.77931 .91617 Mdot
.03109 .2088 Mdot
.15358 .08454 Mdot
.06498 .13202 Mdot
.65242 .92596 Mdot
.02352 .37239 Mdot
.07935 .62523 Mdot
.17757 .54511 Mdot
.05806 .42623 Mdot
.03379 .47038 Mdot
.31639 .4124 Mdot
.05227 .72106 Mdot
.64051 .88757 Mdot
.03855 .35848 Mdot
.5227 .83611 Mdot
.55179 .58242 Mdot
.50933 .85156 Mdot
.48059 .50288 Mdot
.39015 .15555 Mdot
.03278 .16927 Mdot
.06314 .58196 Mdot
.49059 .84879 Mdot
.38253 .41484 Mdot
.11024 .70305 Mdot
.24279 .40321 Mdot
.05606 .01732 Mdot
.16647 .65198 Mdot
.22418 .52669 Mdot
.43798 .89588 Mdot
.12375 .81384 Mdot
.67506 .19015 Mdot
.70456 .81134 Mdot
.66115 .18649 Mdot
.6583 .80383 Mdot
.50449 .52471 Mdot
.78972 .14922 Mdot
.17379 .26467 Mdot
.06075 .17863 Mdot
.67827 .54386 Mdot
.69378 .95867 Mdot
.61528 .52783 Mdot
.04974 .9053 Mdot
.57853 .12602 Mdot
.74304 .1858 Mdot
.40647 .8185 Mdot
.08861 .5458 Mdot
.664 .86875 Mdot
.03441 .31597 Mdot
.05852 .35072 Mdot
.01859 .43562 Mdot
.43216 .57183 Mdot
.35336 .03583 Mdot
.67956 .15728 Mdot
.63084 .79675 Mdot
.3037 .06028 Mdot
.2016 .06134 Mdot
.75964 .4797 Mdot
.12322 .47777 Mdot
.41608 .45367 Mdot
.3001 .50898 Mdot
.50159 .84634 Mdot
.10569 .49964 Mdot
.20769 .79586 Mdot
.47383 .1385 Mdot
.595 .01272 Mdot
.28204 .08696 Mdot
.5126 .59746 Mdot
.10632 .15359 Mdot
.3698 .83759 Mdot
.03478 .43881 Mdot
.51804 .14189 Mdot
.01525 .53463 Mdot
.46533 .55439 Mdot
.53913 .54346 Mdot
.27502 .20551 Mdot
.09652 .19727 Mdot
.47495 .97665 Mdot
.11691 .64453 Mdot
.05233 .91908 Mdot
.17814 .3851 Mdot
.26435 .55468 Mdot
.23818 .18972 Mdot
.17764 .36721 Mdot
.75343 .20327 Mdot
.3132 .80016 Mdot
.62386 .94692 Mdot
.45552 .57162 Mdot
.20097 .02675 Mdot
.08057 .53495 Mdot
.03314 .64973 Mdot
.71013 .83977 Mdot
.511 .98278 Mdot
.65613 .95361 Mdot
.54465 .14825 Mdot
.67548 .0533 Mdot
.16636 .2718 Mdot
.14562 .45269 Mdot
.73107 .94383 Mdot
.04206 .2604 Mdot
.12709 .70095 Mdot
.39143 .02297 Mdot
.31518 .16955 Mdot
.40526 .06756 Mdot
.32577 .84394 Mdot
.18995 .40106 Mdot
.04332 .44031 Mdot
.58898 .09662 Mdot
.01106 .18971 Mdot
.64448 .96301 Mdot
.51097 .9371 Mdot
.26285 .94984 Mdot
.20559 .77736 Mdot
.09301 .50794 Mdot
.68987 .53236 Mdot
.0595 .07743 Mdot
.1107 .44554 Mdot
.05824 .87792 Mdot
.6292 .06949 Mdot
.40396 .90511 Mdot
.12804 .12258 Mdot
.15091 .94547 Mdot
.29332 .06319 Mdot
.05243 .402 Mdot
.21011 .54544 Mdot
.35276 .85984 Mdot
.16042 .47781 Mdot
.25186 .4241 Mdot
.11198 .59009 Mdot
.57218 .90641 Mdot
.52955 .51422 Mdot
.07329 .13088 Mdot
.18659 .64458 Mdot
.32187 .85606 Mdot
.11248 .37799 Mdot
.28178 .97196 Mdot
.71571 .1936 Mdot
.2183 .85088 Mdot
.53892 .53922 Mdot
.49474 .16424 Mdot
.29213 .45288 Mdot
.46489 .82884 Mdot
.21963 .14063 Mdot
.56471 .15621 Mdot
.49411 .93723 Mdot
.06059 .08791 Mdot
.351 .09887 Mdot
.55604 .91387 Mdot
.06868 .63619 Mdot
.17378 .14722 Mdot
.59399 .79755 Mdot
.32729 .01906 Mdot
.75278 .85305 Mdot
.40637 .56733 Mdot
.35559 .48923 Mdot
.78974 .56556 Mdot
.52498 .58663 Mdot
.62576 .42814 Mdot
.30827 .41888 Mdot
.54682 .12236 Mdot
.54569 .55602 Mdot
.14913 .97888 Mdot
.72192 .08099 Mdot
.78374 .49946 Mdot
.14786 .83856 Mdot
.36824 .50577 Mdot
.68209 .47265 Mdot
.06977 .0967 Mdot
.14508 .36009 Mdot
.51428 .53087 Mdot
.4785 .95741 Mdot
.37496 .54219 Mdot
.74678 .88623 Mdot
.58142 .05253 Mdot
.60872 .05748 Mdot
.58742 .11863 Mdot
.16902 .51617 Mdot
.17827 .9532 Mdot
.64493 .97549 Mdot
.68997 .98598 Mdot
.27977 .44311 Mdot
.33447 .06188 Mdot
.11093 .29155 Mdot
.03509 .93324 Mdot
.71293 .17232 Mdot
.0778 .18703 Mdot
.16686 .97445 Mdot
.22367 .8747 Mdot
.10948 .34354 Mdot
.55037 .56628 Mdot
.12641 .37331 Mdot
.33568 .03357 Mdot
.43797 .9363 Mdot
.40814 .94202 Mdot
.43942 .88431 Mdot
.32282 .5208 Mdot
.65462 .11911 Mdot
.15321 .45036 Mdot
.05562 .0162 Mdot
.60784 .07009 Mdot
.17822 .17598 Mdot
.26707 .57626 Mdot
.60265 .46696 Mdot
.3528 .04914 Mdot
.45925 .0264 Mdot
.30699 .04274 Mdot
.68934 .96285 Mdot
.16547 .62637 Mdot
.52093 .79667 Mdot
.66552 .16109 Mdot
.72926 .81591 Mdot
.08908 .74364 Mdot
.63336 .87751 Mdot
.20348 .81323 Mdot
.46441 .98751 Mdot
.08796 .22073 Mdot
.03745 .87232 Mdot
.54628 .88913 Mdot
.04423 .41583 Mdot
.09167 .89182 Mdot
.13668 .41841 Mdot
.01352 .68089 Mdot
.01464 .22341 Mdot
.39588 .52712 Mdot
.64612 .80515 Mdot
.25031 .48782 Mdot
.10964 .90621 Mdot
.21588 .08179 Mdot
.02777 .0242 Mdot
.08901 .65358 Mdot
.02405 .3335 Mdot
.61333 .01442 Mdot
.01922 .11989 Mdot
.18491 .23778 Mdot
.61353 .58297 Mdot
.29663 .09213 Mdot
.05613 .5945 Mdot
.75123 .85912 Mdot
.14771 .8545 Mdot
.21241 .81105 Mdot
.66616 .5442 Mdot
.24501 .05284 Mdot
.61984 .9399 Mdot
.37744 .19104 Mdot
.7796 .42719 Mdot
.03817 .55826 Mdot
.69248 .81992 Mdot
.2615 .52323 Mdot
.42873 .56201 Mdot
.63186 .57353 Mdot
.0611 .38078 Mdot
.52346 .04695 Mdot
.01557 .81688 Mdot
.2907 .18629 Mdot
.12222 .72012 Mdot
.26996 .57379 Mdot
.44606 .97591 Mdot
.45624 .97931 Mdot
.51263 .10141 Mdot
.22072 .0311 Mdot
.75279 .96147 Mdot
.35875 .40682 Mdot
.54808 .17313 Mdot
.27067 .95698 Mdot
.42153 .59024 Mdot
.1019 .7488 Mdot
.16188 .35404 Mdot
.51169 .11269 Mdot
.19507 .18846 Mdot
.14127 .43532 Mdot
.11977 .24401 Mdot
.77578 .16323 Mdot
.70904 .48387 Mdot
.77663 .18488 Mdot
.07568 .93586 Mdot
.09279 .04856 Mdot
.24006 .54955 Mdot
.26836 .19582 Mdot
.48192 .02075 Mdot
.61989 .05756 Mdot
.28827 .16919 Mdot
.07619 .94874 Mdot
.69245 .51414 Mdot
.26746 .88598 Mdot
.03744 .49566 Mdot
.45447 .93105 Mdot
.37791 .13812 Mdot
.52196 .86735 Mdot
.31152 .17958 Mdot
.73837 .9282 Mdot
.39561 .0447 Mdot
.48072 .05202 Mdot
.45309 .54656 Mdot
.12134 .4581 Mdot
.65707 .51725 Mdot
.4188 .13053 Mdot
.14492 .64009 Mdot
.11708 .94115 Mdot
.3689 .02276 Mdot
.47618 .52446 Mdot
.4351 .42418 Mdot
.36464 .07616 Mdot
.63839 .17513 Mdot
.69776 .54911 Mdot
.2294 .05441 Mdot
.56264 .89922 Mdot
.12213 .10345 Mdot
.74342 .0905 Mdot
.78175 .52045 Mdot
.56216 .47585 Mdot
.78071 .47339 Mdot
.41143 .49595 Mdot
.61987 .9657 Mdot
.49546 .45402 Mdot
.06752 .49965 Mdot
.26926 .13282 Mdot
.60787 .12726 Mdot
.29028 .42396 Mdot
.63872 .10487 Mdot
.07969 .63422 Mdot
.65846 .14807 Mdot
.56389 .92762 Mdot
.04839 .17257 Mdot
.07824 .48341 Mdot
.373 .54566 Mdot
.5187 .92663 Mdot
.39185 .09548 Mdot
.03178 .21969 Mdot
.72359 .9376 Mdot
.70412 .12152 Mdot
.58067 .43847 Mdot
.34092 .56606 Mdot
.07178 .50204 Mdot
.1918 .66067 Mdot
.16982 .45078 Mdot
.75395 .80328 Mdot
.70194 .17832 Mdot
.07875 .03825 Mdot
.36483 .90692 Mdot
.73161 .93118 Mdot
.03371 .35066 Mdot
.66964 .43894 Mdot
.15452 .5045 Mdot
.61589 .15897 Mdot
.46966 .98575 Mdot
.56219 .82873 Mdot
.30104 .15019 Mdot
.08707 .30365 Mdot
.73042 .45566 Mdot
.46138 .15448 Mdot
.16757 .37497 Mdot
.43608 .54783 Mdot
.59558 .53643 Mdot
.70304 .14664 Mdot
.30794 .51551 Mdot
.06523 .36618 Mdot
.325 .90072 Mdot
.7595 .07698 Mdot
.01595 .16559 Mdot
.30311 .02875 Mdot
.30357 .16361 Mdot
.0148 .2244 Mdot
.50388 .51977 Mdot
.40327 .52238 Mdot
.10382 .34766 Mdot
.10866 .83441 Mdot
.33436 .55264 Mdot
.0726 .94593 Mdot
.55892 .43596 Mdot
.04802 .7257 Mdot
.52897 .44905 Mdot
.51037 .9318 Mdot
.43495 .1112 Mdot
.30015 .46867 Mdot
.01154 .70454 Mdot
.23736 .51293 Mdot
.66864 .08677 Mdot
.74628 .56065 Mdot
.22712 .1214 Mdot
.12986 .40966 Mdot
.78236 .02 Mdot
.45433 .04847 Mdot
.31607 .12655 Mdot
.63763 .04959 Mdot
.03567 .11152 Mdot
.01701 .68851 Mdot
.02619 .97012 Mdot
.05318 .19031 Mdot
.49976 .55083 Mdot
.1158 .19804 Mdot
.19349 .43408 Mdot
.33385 .52587 Mdot
.30799 .42416 Mdot
.49943 .43405 Mdot
.65171 .41713 Mdot
.48304 .45413 Mdot
.11838 .67599 Mdot
.48286 .50331 Mdot
.37883 .84761 Mdot
.18468 .08895 Mdot
.18826 .7345 Mdot
.20221 .20078 Mdot
.57012 .50767 Mdot
.2795 .96375 Mdot
.46154 .82187 Mdot
.46278 .93457 Mdot
.53666 .57996 Mdot
.16764 .72255 Mdot
.32767 .57092 Mdot
.12959 .70701 Mdot
.14921 .82661 Mdot
.64788 .54249 Mdot
.11755 .49707 Mdot
.1949 .59812 Mdot
.57109 .9073 Mdot
.21498 .16686 Mdot
.41326 .19456 Mdot
.40994 .79514 Mdot
.09539 .61384 Mdot
.29016 .09793 Mdot
.36278 .57209 Mdot
.37689 .45848 Mdot
.7051 .03941 Mdot
.26915 .95161 Mdot
.52 .43148 Mdot
.68826 .05411 Mdot
.2848 .84975 Mdot
.19921 .24571 Mdot
.25303 .45849 Mdot
.26175 .79946 Mdot
.607 .04839 Mdot
.03665 .34818 Mdot
.71202 .08356 Mdot
.63394 .14453 Mdot
.44453 .88902 Mdot
.20221 .23272 Mdot
.2013 .44034 Mdot
.32515 .44033 Mdot
.78961 .40746 Mdot
.16548 .27273 Mdot
.51965 .92376 Mdot
.69515 .96142 Mdot
.20431 .49324 Mdot
.48615 .1013 Mdot
.53106 .42111 Mdot
.46183 .1826 Mdot
.30026 .12344 Mdot
.13106 .8069 Mdot
.10576 .6204 Mdot
.6098 .52891 Mdot
.39201 .42376 Mdot
.12346 .49426 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`0[ooooo`?oo`00kOooool10000007o
oooo00000`00003oooooooooo`0Zooooo`Goo`002_ooool3ool003Kooooo0ooo000Eooooo`?oo`00
6Oooool3ool000;ooooo0ooo001]ooooo`4000000Oooool0000300000?oooooooooo00?ooooo0ooo
0005ooooo`?oo`007?ooool5ool000Wooooo2Ooo000Hooooo`?oo`005Oooool5ool000kooooo0ooo
0002ooooo`Goo`005oooool:ool006cooooo0@000001ooooo`0000<00000ooooooooool00_ooool5
ool000?ooooo1Ooo000Kooooo`Goo`002Oooool:ool000Wooooo0ooo000:ooooo`Goo`002?ooool3
ool000Wooooo1Ooo000=ooooo`_oo`005oooool:ool002gooooo0ooo000looooo`4000000Oooool0
000300000?oooooooooo00;ooooo1_oo0002ooooo`Goo`007?ooool3ool000[ooooo2_oo0008oooo
o`Goo`002Oooool5ool000Oooooo1Ooo0003ooooo`?oo`000_ooool5ool000Wooooo0ooo00000ooo
ooooo`00ool00009ool001Oooooo2_oo000/ooooo`Goo`00>oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`Koo`000_ooool5ool002Kooooo0ooo00000oooooooo`00ool00007ool000So
oooo1_oo0002ooooo`?oo`000oooool5ool000Oooooo3?oo0002ooooo`?oo`002Oooool?ool0013o
oooo0ooo0006ooooo`?oo`000_ooool3ool002gooooo1Ooo000kooooo`4000000Oooool000030000
0?oooooooooo00;ooooo1_oo0003ooooo`?oo`003?ooool3ool001Oooooo1Ooo0002ooooo`Koo`00
1oooool8ool00003oooooooo003oo`0000?oo`000oooool3ool000Sooooo3?oo0005ooooo`?oo`00
1_ooool5ool00003oooooooo003oo`0000Coo`004_ooool5ool003[ooooo1Ooo000kooooo`400000
0Oooool0000300000?oooooooooo00;ooooo1Ooo000Booooo`Goo`003?ooool3ool000Oooooo2ooo
0008ooooo`ooo`001_ooool3ool000;ooooo0ooo00000oooooooo`00ool00009ool000?ooooo1_oo
0005ooooo`Goo`000oooool3ool0017ooooo1ooo0007ooooo`Goo`00;oooool4ool003_ooooo0@00
0001ooooo`0000<00000ooooooooool00oooool3ool000cooooo0ooo0004ooooo`Goo`002oooool5
ool000Kooooo2ooo0007oooooa3oo`001Oooool:ool000;ooooo2?oo0003ooooo`Ooo`001Oooool5
ool001Kooooo2?oo0006ooooo`Ooo`006?ooool3ool001?ooooo1Ooo000jooooo`4000000Oooool0
000300000?oooooooooo017ooooo1Ooo0003ooooo`Goo`002oooool5ool000Oooooo2_oo0005oooo
oa;oo`001Oooool:ool000?ooooo0ooo0007ooooo`Ooo`001_ooool3ool001Oooooo2?oo0006oooo
o`Ooo`005oooool5ool001;ooooo1Ooo000jooooo`4000000Oooool0000300000?oooooooooo00Wo
oooo1?oo0004ooooo`Goo`001?ooool3ool000cooooo1Ooo00001?ooooooo`00ool00?oo0004oooo
o`?oo`000_ooool3ool000Gooooo2?oo0002ooooo`[oo`001?ooool:ool000Sooooo0ooo0002oooo
o`Koo`006Oooool3ool000Gooooo2?oo0006ooooo`Ooo`005oooool5ool001;ooooo1Ooo000joooo
o`4000000Oooool0000300000?oooooooooo00Sooooo1_oo0003ooooo`Soo`004Oooool3ool00003
oooooooo003oo`0000?oo`004?ooool9ool000?ooooo2?oo0005ooooo`?oo`0000?oooooool00?oo
00000_oo0008ooooo`Goo`000_ooool3ool000Sooooo0ooo00001?ooooooo`00ool00?oo000;oooo
o`Goo`001Oooool6ool000Sooooo1Ooo0005ooooo`?oo`004?ooool5ool001?ooooo0ooo000koooo
o`4000000Oooool0000300000?oooooooooo00Sooooo1_oo0004ooooo`Soo`005?ooool5ool000oo
oooo2_oo0006ooooo`Goo`002?ooool5ool000Sooooo1Ooo000<ooooo`goo`001_ooool5ool000go
oooo0ooo0003ooooo`Goo`001?ooool5ool000Oooooo0ooo00001?ooooooo`00ool00?oo0002oooo
o`?oo`00D_ooool10000007ooooo00000`00003oooooooooo`05ooooo`Woo`001Oooool7ool001Co
oooo1Ooo000:ooooo`?oo`0000?oooooool00?oo00002Ooo0007ooooo`?oo`002Oooool5ool000So
oooo1Ooo000<ooooo`koo`001Oooool5ool000_ooooo1_oo0002ooooo`Soo`0000?oooooool00?oo
00000ooo0006ooooo`Woo`00E_ooool10000007ooooo00000`00003oooooooooo`04ooooo`Woo`00
1_ooool7ool001Gooooo0ooo000:ooooo`ooo`001oooool3ool000[ooooo1Ooo0009ooooo`?oo`00
3Oooool>ool000Kooooo0ooo000;ooooo`Ooo`000_ooool>ool000Kooooo2Ooo000Cooooo`?oo`00
@?ooool10000007ooooo00000`00003oooooooooo`04ooooo`Woo`001_ooool6ool001cooooo0ooo
0004ooooo`_oo`002?ooool7ool000Gooooo0ooo0002ooooo`?oo`006oooool3ool00003oooooooo
003oo`0000Ooo`005?ooool7ool000?ooooo2?oo00001?ooooooo`00ool00?oo0006ooooo`[oo`00
4_ooool5ool003oooooo0@000001ooooo`0000<00000ooooooooool01?ooool9ool000Oooooo0ooo
000Mooooo`Goo`000oooool5ool00003oooooooo003oo`0000;oo`002?ooool8ool000Cooooo1Ooo
000>ooooo`Koo`004?ooool7ool0013ooooo0ooo00000oooooooo`00ool00005ool000Cooooo2ooo
0006ooooo`Koo`0000Coooooool00?oo003oo`004oooool5ool003oooooo0@000001ooooo`0000<0
0000ooooooooool01Oooool3ool00004oooooooo003oo`00ool0013ooooo0ooo000<ooooo`?oo`00
1_ooool5ool000Cooooo0ooo000>ooooo`Woo`000oooool5ool000gooooo2?oo000Uooooo`[oo`00
1oooool=ool000?ooooo1Ooo000Hooooo`Goo`00?oooool10000007ooooo00000`00003ooooooooo
o`06ooooo`?oo`004_ooool5ool000[ooooo1Ooo0005ooooo`Goo`003oooool3ool00003oooooooo
003oo`0000Woo`000oooool5ool000gooooo2?oo000Looooo`?oo`000oooool=ool000Kooooo1Ooo
00000oooooooo`00ool00007ool000;ooooo1Ooo000Iooooo`?oo`00@?ooool10000007ooooo0000
0`00003oooooooooo`05ooooo`Goo`000_ooool3ool000cooooo1Ooo000:ooooo`Goo`001_ooool3
ool000oooooo4?oo0004ooooo`?oo`001_ooool3ool000Gooooo2?oo000Kooooo`Goo`0000?ooooo
ool00?oo00001ooo00001?ooooooo`00ool00?oo0007ooooo`Goo`0000?oooooool00?oo00001ooo
0003ooooo`?oo`005oooool3ool004?ooooo0@000001ooooo`0000<00000ooooooooool01Oooool5
ool00003oooooooo003oo`0000?oo`002oooool5ool000[ooooo1Ooo000:ooooo`?oo`002oooool9
ool000?ooooo0ooo000=ooooo`Goo`001Oooool6ool001cooooo1Ooo00000oooooooo`00ool00006
ool000Wooooo4_oo000Booooo`?oo`001oooool5ool000;ooooo0ooo000mooooo`4000000Oooool0
000300000?oooooooooo00Gooooo1Ooo00000oooooooo`00ool00003ool000cooooo0ooo0008oooo
o`?oo`0000Coooooool00?oo003oo`002_ooool7ool000Sooooo2Ooo000Cooooo`Goo`009oooool5
ool00003oooooooo003oo`0000?oo`002ooooolBool0013ooooo1ooo0006ooooo`Goo`0000?ooooo
ool00?oo00000ooo000looooo`4000000Oooool0000300000?oooooooooo00Kooooo0ooo0002oooo
o`Goo`002_ooool3ool000Wooooo1_oo0004ooooo`?oo`001Oooool8ool000Sooooo1ooo000Doooo
o`Goo`00:?ooool3ool000?ooooo0ooo000<ooooo`Goo`0000?oooooool00?oo00000ooo0003oooo
o`?oo`001Oooool3ool000Sooooo2?oo0006ooooo`Goo`0000?oooooool00?oo00000ooo000loooo
o`4000000Oooool0000400000?ooooooooooooooo`?oo`002?ooool5ool000Cooooo0ooo00000ooo
ooooo`00ool00003ool000Sooooo2?oo00000oooooooo`00ool00003ool000Cooooo2?oo000:oooo
o`Woo`004Oooool3ool0013ooooo0ooo000[ooooo`Goo`0000?oooooool00?oo00000ooo0006oooo
o`?oo`0000?oooooool00?oo00000ooo0007ooooo`Soo`000_ooool3ool000;ooooo0ooo0002oooo
o`Goo`00??ooool10000007ooooo00000`00003oooooooooo`05ool000Oooooo1Ooo0003ooooo`[o
o`002?ooool>ool000Gooooo1ooo0004ooooo`?oo`000oooool:ool001Sooooo0ooo0007ooooo`Go
o`003oooool3ool001Wooooo0ooo0003ooooo`?oo`001_ooool:ool000Oooooo1ooo0002ooooo`Go
o`001oooool3ool003gooooo0@000001ooooo`0000<00000ooooooooool01Ooo0007ooooo`Koo`00
0_ooool:ool000Wooooo3Ooo0008ooooo`?oo`001?ooool5ool000;ooooo2_oo000<ooooo`?oo`00
2?ooool5ool000Kooooo1Ooo000>ooooo`Goo`005_ooool3ool000kooooo2_oo0008ooooo`?oo`00
1Oooool5ool004Oooooo0@000001ooooo`0000<00000ooooooooool01Ooo0008ooooo`Koo`0000?o
ooooool00?oo00000ooo00001?ooooooo`00ool00?oo0007ooooo`?oo`000_ooool6ool00004oooo
oooo003oo`00ool0013ooooo1Ooo0003ooooo`Woo`002oooool5ool000Oooooo1Ooo0006ooooo`Go
o`003?ooool:ool001;ooooo1ooo000;ooooo`Goo`0000Coooooool00?oo003oo`004Oooool5ool0
04Oooooo0@000001ooooo`0000@00000oooooooooooooooo0ooo000:ooooo`Goo`000_ooool3ool0
0003oooooooo003oo`0000Koo`000_ooool5ool000?ooooo0ooo000Eooooo`Goo`001Oooool6ool0
00cooooo1Ooo0007ooooo`Goo`001oooool3ool000cooooo3?oo000Aooooo`Soo`001_ooool4ool0
0004oooooooo003oo`00ool001Kooooo1?oo0018ooooo`4000000Oooool0000300000?oooooooooo
00kooooo1Ooo0006ooooo`Woo`0000?oooooool00?oo00000ooo000Looooo`?oo`001oooool5ool0
00cooooo1_oo0007ooooo`?oo`005oooool<ool0017ooooo2?oo0005ooooo`Koo`006?ooool5ool0
04Sooooo0@000001ooooo`0000<00000ooooooooool01_ooool3ool000Kooooo0ooo0007ooooo`Wo
o`0000?oooooool00?oo00000ooo000Wooooo`?oo`003_ooool6ool001;ooooo0ooo000;ooooo`Ko
o`0000?oooooool00?oo00000ooo000Booooo`Ooo`001Oooool6ool001Sooooo1Ooo0018ooooo`40
00000Oooool0000300000?oooooooooo00Gooooo1Ooo000@ooooo`Soo`000_ooool3ool002Wooooo
0ooo000>ooooo`Goo`004Oooool5ool000_ooooo0ooo0003ooooo`Goo`004oooool5ool000Kooooo
1_oo000Hooooo`Goo`00B?ooool10000007ooooo00001000003oooooooooooooool3ool00003oooo
oooo003oo`0000?oo`004?ooool7ool002kooooo1Ooo000=ooooo`Goo`002?ooool3ool000Kooooo
1Ooo000Aooooo`Goo`004_ooool5ool000Oooooo1Ooo0002ooooo`?oo`005Oooool4ool004Sooooo
0@000001ooooo`0000<00000ooooooooool03Ooo000<ooooo`Koo`0000Coooooool00?oo003oo`00
6Oooool3ool000cooooo0ooo00000oooooooo`00ool00003ool000kooooo0ooo0008ooooo`Goo`00
1Oooool5ool0017ooooo1Ooo0006ooooo`?oo`002?ooool6ool000Kooooo1Ooo0002ooooo`Goo`00
2_ooool3ool000Oooooo1Ooo0017ooooo`4000000Oooool0000300000?oooooooooo00Goo`0000?o
ooooool00?oo00001_oo000;ooooo`_oo`005oooool5ool000[ooooo2ooo00000oooooooo`00ool0
0002ool000Sooooo0ooo0008ooooo`Goo`001_ooool3ool001?ooooo0ooo0006ooooo`Goo`001Ooo
ool8ool00004oooooooo003oo`00ool000;ooooo1Ooo0002ooooo`Goo`002Oooool5ool000Kooooo
1Ooo0017ooooo`4000000Oooool0000300000?ooooooo`0000Goo`001?ooool5ool000;ooooo0ooo
0006ooooo`_oo`005oooool5ool000[ooooo1Ooo00000oooooooo`00ool00009ool000Kooooo1Ooo
0007ooooo`Goo`0000Coooooool00?oo003oo`008Oooool5ool000Cooooo2?oo00000oooooooo`00
ool00003ool00003oooooooo003oo`0000?oo`000_ooool5ool000Sooooo1_oo0006ooooo`Goo`00
Aoooool10000007ooooo00000`00003oo`00ool00004ool000Gooooo2ooo0006ooooo`[oo`001Ooo
ool3ool000oooooo1Ooo0009ooooo`Koo`0000?oooooool00?oo00002Ooo0006ooooo`Goo`002?oo
ool3ool00003oooooooo003oo`0000?oo`003oooool3ool000kooooo1Ooo0004ooooo`Ooo`000_oo
ool5ool000;ooooo0ooo0004ooooo`?oo`000oooool3ool000;ooooo1ooo0007ooooo`?oo`00B?oo
ool10000007ooooo00000`00003oo`00ool00003ool000Oooooo2_oo0007ooooo`?oo`000_ooool3
ool000Gooooo1Ooo000?ooooo`?oo`002Oooool6ool000?ooooo0ooo00000oooooooo`00ool00004
ool000Kooooo1Ooo000<ooooo`Goo`003_ooool5ool000kooooo0ooo0005ooooo`Ooo`000_ooool5
ool000Kooooo0ooo0005ooooo`Goo`0000?oooooool00?oo00001?oo001Cooooo`4000000Oooool0
000300000?oo003oo`0000?oo`002_ooool7ool001Cooooo1Ooo000=ooooo`?oo`002oooool5ool0
00;ooooo0ooo0004ooooo`Coo`002?ooool3ool000?ooooo0ooo0006ooooo`Koo`003?ooool7ool0
00gooooo1Ooo0005ooooo`Ooo`000_ooool3ool000Kooooo1Ooo0004ooooo`Goo`0000?oooooool0
0?oo00000ooo001Dooooo`4000000Oooool0000300000?ooooooo`0000;oo`002?ooool9ool001Co
oooo1_oo000<ooooo`Goo`002_ooool5ool00003oooooooo003oo`0000?oo`005?ooool5ool000Co
oooo1_oo000<ooooo`Soo`001_ooool3ool000Cooooo1Ooo0005ooooo`Ooo`002Oooool7ool000Co
oooo1Ooo0002ooooo`?oo`00EOooool10000007ooooo00000`00003oooooooooo`09ooooo`Soo`00
1_ooool3ool000Kooooo0ooo0003ooooo`Koo`0000Coooooool00?oo003oo`002Oooool5ool000_o
oooo0ooo0002ooooo`Goo`005?ooool5ool000Cooooo1Ooo000=ooooo`Ooo`001_ooool5ool000?o
oooo1Ooo0005ooooo`Ooo`002?ooool;ool000;ooooo0ooo0005ooooo`?oo`001oooool3ool004Wo
oooo0@000001ooooo`0000<00000ooooooooool02Oooool5ool000Gooooo2?oo0004ooooo`Goo`00
0_ooool5ool00003oooooooo003oo`0000?oo`002?ooool5ool000_ooooo0ooo0002ooooo`Ooo`00
4_ooool5ool000Cooooo1Ooo000=ooooo`Goo`002?ooool5ool000;ooooo1Ooo0007ooooo`Goo`00
0_ooool3ool000Cooooo3?oo0008ooooo`Goo`001Oooool5ool000_ooooo0ooo000jooooo`400000
0Oooool0000300000?oooooooooo00Wooooo1Ooo0004ooooo`_oo`000_ooool6ool00003oooooooo
003oo`0000?oo`0000?oooooool00?oo00000ooo0003ooooo`?oo`000oooool3ool000_ooooo3_oo
000Booooo`?oo`001_ooool3ool000cooooo1_oo0009ooooo`coo`003Oooool5ool000?ooooo1Ooo
0002ooooo`Soo`001Oooool5ool000Gooooo1Ooo000:ooooo`Goo`00>Oooool10000007ooooo0000
0`00003oooooooooo`0:ooooo`?oo`001Oooool<ool00003oooooooo003oo`0000Woo`000_ooool5
ool000;ooooo1Ooo000;ooooo`?oo`000_ooool>ool001Gooooo0ooo000Aooooo`Goo`002oooool<
ool000;ooooo0ooo0008ooooo`Goo`001?ooool3ool000?ooooo2_oo0003ooooo`Goo`001Oooool5
ool000[ooooo1Ooo000iooooo`4000000Oooool0000300000?oooooooooo00Kooooo0ooo0009oooo
o`coo`000_ooool:ool000?ooooo0ooo0003ooooo`Goo`0000Coooooool00?oo003oo`001_ooool5
ool00003oooooooo003oo`0000coo`005?ooool5ool0013ooooo1Ooo000:ooooo`coo`000_ooool5
ool000Oooooo1ooo0008ooooo`_oo`000oooool6ool000Cooooo0ooo000;ooooo`Goo`00>Oooool1
0000007ooooo00000`00003oooooooooo`03ool000;ooooo1Ooo0009ooooo`Goo`0000?oooooool0
0?oo00000ooo0003ooooo`?oo`0000?oooooool00?oo00000ooo0009ooooo`[oo`001Oooool5ool0
00;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`005Oooool5ool0013ooooo1Ooo0005
ooooo`?oo`000_ooool9ool000Gooooo1Ooo0008ooooo`[oo`001?ooool;ool000Gooooo1Ooo000>
ooooo`?oo`0000Coooooool00?oo003oo`00>_ooool10000007ooooo00000`00003oooooool00004
ool00003oooooooo003oo`0000?oo`002_ooool5ool00004oooooooo003oo`00ool000Wooooo0ooo
000;ooooo`?oo`0000?oooooool00?oo00000ooo0005ooooo`Goo`001oooool8ool000Oooooo0ooo
000:ooooo`Goo`004Oooool3ool000Gooooo1Ooo00000oooooooo`00ool00006ool000Kooooo1Ooo
000:ooooo`Woo`001?ooool:ool000Gooooo1Ooo000=ooooo`Goo`00?Oooool10000007ooooo0000
0`00003oooooool0000<ool000Sooooo1Ooo000Oooooo`Goo`001_ooool3ool000Oooooo3?oo0003
ooooo`Goo`002_ooool3ool000cooooo0ooo000;ooooo`Goo`000_ooool5ool000Wooooo0ooo000;
ooooo`Woo`001Oooool8ool000Kooooo1Ooo000=ooooo`Goo`00?Oooool10000007ooooo00000`00
003oooooool0000=ool000Oooooo1Ooo000Eooooo`?oo`001oooool5ool0013ooooo3Ooo0002oooo
o`Goo`005Oooool8ool000[ooooo1Ooo0003ooooo`Goo`000oooool3ool0017ooooo2Ooo0005oooo
o`Ooo`001_ooool5ool000gooooo1Ooo000mooooo`4000000Oooool0000300000?oooooooooo00?o
o`0000?oooooool00?oo00002_oo0005ooooo`?oo`002oooool3ool000Oooooo1Ooo0006ooooo`Go
o`004?ooool=ool000;ooooo1Ooo000Dooooo`Woo`000oooool3ool000Gooooo0ooo0004ooooo`Go
o`000_ooool5ool001?ooooo1ooo0006ooooo`Goo`0000?oooooool00?oo00002?oo000>ooooo`?o
o`00?_ooool10000007ooooo00000`00003oooooooooo`05ooooo`coo`004Oooool5ool000Kooooo
1Ooo0007ooooo`?oo`003?ooool3ool000?ooooo0ooo0003ooooo`Koo`000oooool3ool001Gooooo
2Ooo0002ooooo`Goo`001?ooool3ool000Cooooo1Ooo0002ooooo`Goo`004_ooool8ool000Oooooo
0ooo00000oooooooo`00ool00009ool000cooooo0ooo0010ooooo`4000000Oooool0000300000?oo
oooooooo00Wooooo2?oo000=ooooo`?oo`0000?oooooool00?oo00000ooo0006ooooo`Goo`005Ooo
ool5ool000?ooooo0ooo0002ooooo`Ooo`006_ooool8ool000;ooooo1_oo0003ooooo`Goo`001?oo
ool3ool000?ooooo1Ooo000Booooo`Soo`000oooool3ool000Gooooo2_oo0005ooooo`?oo`001?oo
ool6ool003kooooo0@000001ooooo`0000@00000ool00?oo003oo`002oooool5ool00004oooooooo
003oo`00ool000Sooooo3Ooo0004ooooo`?oo`000_ooool3ool000;ooooo0ooo0005ooooo`?oo`00
1?ooool5ool000;ooooo1Ooo00000oooooooo`00ool00006ool000[ooooo0ooo000=ooooo`?oo`00
1_ooool6ool000?ooooo1Ooo000;ooooo`?oo`004oooool7ool000?ooooo2?oo00000oooooooo`00
ool00006ool000Kooooo1Ooo0003ooooo`Ooo`00?Oooool10000007ooooo0005ool000Wooooo1Ooo
00000oooooooo`00ool00003ool000Oooooo1Ooo00000oooooooo`00ool00006ool000Oooooo2_oo
0003ooooo`Goo`000oooool5ool000;ooooo1Ooo0002ooooo`Ooo`002Oooool6ool001Cooooo1Ooo
0004ooooo`Goo`008_ooool5ool000Cooooo2Ooo00000oooooooo`00ool00004ool00004oooooooo
003oo`00ool000?ooooo1Ooo0003ooooo`Ooo`00?Oooool10000007ooooo0005ool000Sooooo1Ooo
0002ooooo`Goo`001oooool5ool00003oooooooo003oo`0000Koo`001oooool:ool000?ooooo1Ooo
0004ooooo`?oo`000oooool5ool000Cooooo1Ooo0009ooooo`Ooo`000oooool6ool000Wooooo1Ooo
0002ooooo`?oo`0000Coooooool00?oo003oo`004?ooool3ool0013ooooo1Ooo0004ooooo`Woo`00
1oooool5ool000;ooooo1Ooo0003ooooo`Ooo`00?Oooool10000007ooooo0006ool000Oooooo1Ooo
0002ooooo`Goo`0000Coooooool00?oo003oo`000oooool4ool000?ooooo1ooo0007ooooo`[oo`00
0oooool5ool000?ooooo1ooo00001?ooooooo`00ool00?oo0006ooooo`?oo`002_ooool7ool000;o
oooo2?oo0008ooooo`Goo`0000?oooooool00?oo00000ooo000Booooo`Goo`004?ooool3ool000Go
oooo2Ooo0007ooooo`Goo`000oooool3ool000Cooooo1_oo000nooooo`4000000Oooool000030000
0?oo003oo`0000Coo`001_ooool5ool000?ooooo0ooo00000oooooooo`00ool00003ool00003oooo
oooo003oo`0000?oo`001_ooool3ool000Wooooo2?oo0005ooooo`?oo`001?ooool8ool001Oooooo
1_oo0002ooooo`Soo`002?ooool5ool00003oooooooo003oo`0000?oo`001Oooool3ool000[ooooo
1Ooo000Iooooo`?oo`0000Coooooool00?oo003oo`002?ooool5ool000Kooooo0ooo0002ooooo`?o
o`00@?ooool10000007ooooo00000`00003oooooool00004ool000Oooooo0ooo0008ooooo`Goo`00
00?oooooool00?oo00000ooo000?ooooo`?oo`0000?oooooool00?oo00000ooo000>ooooo`Soo`00
6Oooool3ool000?ooooo2?oo0004ooooo`?oo`000_ooool3ool000;ooooo1Ooo0004ooooo`Goo`00
2Oooool5ool002Wooooo0ooo0005ooooo`Koo`00A?ooool10000007ooooo00000`00003oooooool0
0007ool000oooooo1Ooo00000oooooooo`00ool00003ool000kooooo2_oo000?ooooo`Ooo`008?oo
ool6ool000Cooooo1Ooo0007ooooo`?oo`001Oooool5ool000[ooooo0ooo000aooooo`Ooo`00A?oo
ool10000007ooooo00000`00003oooooooooo`08ool000oooooo0ooo0003ooooo`?oo`003oooool:
ool0013ooooo1Ooo000[ooooo`Goo`003oooool5ool003kooooo1ooo0014ooooo`4000000Oooool0
000300000?ooooooo`0000;oo`0000?oooooool00?oo00000ooo000Rooooo`?oo`000_ooool5ool0
0004oooooooo003oo`00ool0017ooooo1Ooo000[ooooo`Goo`004?ooool3ool003oooooo1_oo0015
ooooo`4000000Oooool0000300000?oo003oo`0000Soo`003Oooool3ool0017ooooo1Ooo0002oooo
o`?oo`005oooool3ool002gooooo0ooo001Dooooo`?oo`00Aoooool10000007ooooo00000`00003o
o`00ool00008ool000cooooo1Ooo000@ooooo`Goo`00kOooool10000007ooooo00000`00003oo`00
ool00008ool000cooooo1Ooo0005ooooo`?oo`002?ooool5ool00>gooooo0@000001ooooo`0000<0
0000oooooooo00002?oo000<ooooo`Goo`001?ooool5ool000Sooooo0ooo003^ooooo`4000000Ooo
ool0000300000?ooooooo`0000Ooo`003_ooool3ool000Gooooo1Ooo000Cooooo`?oo`00hoooool1
0000007ooooo00000`00003oooooooooo`03ool001Wooooo1_oo000>ooooo`?oo`0000?oooooool0
0?oo00000ooo003Rooooo`4000000Oooool0000300000?oooooooooo01_ooooo1_oo00001?oooooo
o`00ool00?oo0005ooooo`?oo`000_ooool:ool00>;ooooo0@000001ooooo`0000<00000oooooooo
ool03oooool3ool000Wooooo2ooo0003ooooo`Goo`0000?oooooool00?oo00002Ooo003Qooooo`40
00000Oooool0000300000?oooooooooo00kooooo1Ooo0008ooooo`_oo`000oooool5ool00003oooo
oooo003oo`0000Woo`00hOooool10000007ooooo00000`00003oooooooooo`0>ooooo`Goo`002Ooo
ool:ool000?ooooo1Ooo0002ooooo`[oo`00hOooool10000007ooooo00000`00003oooooooooo`0>
ooooo`Goo`002_ooool:ool000?ooooo0ooo0006ooooo`Koo`00h_ooool10000007ooooo00000`00
003oooooooooo`0?ooooo`?oo`003?ooool3ool000;ooooo1_oo000;ooooo`?oo`00i?ooool10000
007ooooo00001000003oooooooooooooool3ool000?ooooo0ooo000Iooooo`Ooo`00lOooool10000
007ooooo00000`00003oooooooooo`05ool00003oooooooo003oo`0000?oo`006?ooool7ool000?o
oooo0ooo003[ooooo`4000000Oooool0000300000?ooooooo`0000Goo`0000?oooooool00?oo0000
0ooo000Iooooo`Koo`000_ooool7ool00>Sooooo0@000001ooooo`0000<00000ool00?oo00001Ooo
00000oooooooo`00ool00003ool001_ooooo0ooo0002ooooo`_oo`00iOooool10000007ooooo0000
0`00003oo`00ool00004ool000?ooooo0ooo000Pooooo`goo`00i?ooool10000007ooooo00000`00
003oo`00ool00003ool002Oooooo3Ooo003Tooooo`4000000Oooool0000300000?ooooooo`0000;o
o`00:?ooool=ool00>Cooooo0@000001ooooo`0000<00000ooooooooool02_ooool3ool00004oooo
oooo003oo`00ool000;ooooo0ooo000Eooooo`?oo`000_ooool6ool00>Gooooo0@000001ooooo`00
00<00000ooooooooool02Oooool>ool00?oooooo1Oooool10000007ooooo00000`00003ooooooooo
o`09ooooo`koo`001?ooool3ool00?gooooo0@000001ooooo`0000<00000ooooooooool02Oooool>
ool000?ooooo1Ooo000Dooooo`?oo`00iOooool10000007ooooo00000`00003oooooooooo`08oooo
o`Goo`0000Coooooool00?oo003oo`000_ooool3ool000Cooooo1Ooo000Cooooo`Goo`00i?ooool1
0000007ooooo00000`00003oooooooooo`07ooooo`Goo`002?ooool3ool000?ooooo1ooo000Aoooo
o`Goo`00i?ooool10000007ooooo00000`00003oooooooooo`02ooooo`?oo`000_ooool5ool000Oo
oooo1Ooo0002ooooo`Soo`004?ooool5ool00>Cooooo0@000001ooooo`0000@00000oooooooooooo
oooo1Ooo00000oooooooo`00ool00003ool000Oooooo1Ooo0002ooooo`Soo`004Oooool3ool00>Go
oooo0@000001ooooo`0000@00000oooooooooooooooo1Ooo0002ooooo`?oo`002?ooool5ool000;o
oooo2?oo003iooooo`4000000Oooool0000400000?ooooooooooooooo`Ooo`003?ooool3ool000Co
oooo1_oo003jooooo`4000000Oooool0000300000?oooooooooo00;ooooo1ooo000Rooooo`?oo`00
kOooool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`008Oooool5ool00>cooooo0@00
0001ooooo`0000<00000ooooooooool01?ooool5ool0027ooooo1Ooo0003ooooo`?oo`00i_ooool1
0000007ooooo00000`00003oooooooooo`05ooooo`?oo`004Oooool3ool000kooooo1Ooo0002oooo
o`Goo`00iOooool10000007ooooo00000`00003oooooooooo`02ooooo`?oo`004oooool5ool000ko
oooo0ooo0003ooooo`Goo`00iOooool10000007ooooo00001000003oooooooooooooool5ool001;o
oooo1Ooo000=ooooo`Goo`000_ooool5ool00>Gooooo0@000001ooooo`0000@00000oooooooooooo
oooo1Ooo000Booooo`Ooo`002oooool5ool000;ooooo1Ooo003Uooooo`4000000Oooool000040000
0?ooooooooooooooo`Goo`004oooool7ool000[ooooo1Ooo0002ooooo`Goo`00iOooool10000007o
oooo00000`00003oooooooooo`02ooooo`Ooo`004?ooool7ool000_ooooo0ooo0003ooooo`Goo`00
iOooool10000007ooooo00000`00003oooooooooo`04ooooo`Koo`000_ooool3ool000Wooooo2?oo
000:ooooo`?oo`001Oooool3ool00>Kooooo0@000001ooooo`0000<00000ooooooooool01?ooool6
ool00003oooooooo003oo`0000?oo`002?ooool7ool000[ooooo1Ooo003]ooooo`4000000Oooool0
000300000?oooooooooo00Cooooo1_oo00000oooooooo`00ool00003ool000Sooooo1Ooo0008oooo
o`?oo`0000?oooooool00?oo00000ooo003]ooooo`4000000Oooool0000300000?oooooooooo00Go
oooo1Ooo00000oooooooo`00ool00003ool000Wooooo0ooo0008ooooo`[oo`00kOooool10000007o
oooo00000`00003oooooooooo`05ooooo`Goo`000_ooool5ool001?ooooo1Ooo00001Oooooooo`00
ool00?oo003ooooo00?oo`00j_ooool10000007ooooo00000`00003oooooooooo`05ooooo`Goo`00
00?oooooool00?oo00001Ooo000Booooo`Goo`001?ooool5ool00>Wooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool3ool00004oooooooo003oo`00ool000;ooooo1ooo000>ooooo`?oo`00
0_ooool3ool000?ooooo1ooo003Yooooo`4000000Oooool0000400000?ooooooooooooooo`Goo`00
1Oooool7ool000[ooooo2?oo0006ooooo`Soo`00jOooool10000007ooooo00001000003ooooooooo
ooooool5ool000Kooooo1Ooo000:ooooo`Woo`001_ooool7ool00>[ooooo0@000001ooooo`0000@0
0000oooooooooooooooo1Ooo0006ooooo`Goo`001?ooool3ool000?ooooo2Ooo0006ooooo`Ooo`00
j_ooool10000007ooooo00000`00003oooooooooo`02ooooo`Coo`001_ooool5ool000?ooooo1Ooo
0002ooooo`Soo`002?ooool7ool00>Wooooo0@000001ooooo`0000<00000ooooooooool00_ooool5
ool000Gooooo1Ooo0003ooooo`Goo`000oooool3ool000kooooo1Ooo003Yooooo`4000000Oooool0
000300000?oooooooooo00;ooooo1Ooo0006ooooo`?oo`001?ooool5ool001Cooooo1Ooo003Yoooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1Ooo0005ooooo`?oo`001?ooool5ool001Ko
oooo0ooo003Zooooo`4000000Oooool0000300000?oooooooooo00?ooooo0ooo0004ooooo`Koo`00
0_ooool5ool001_ooooo0ooo0018ooooo`?oo`00Voooool10000007ooooo00000`00003ooooooooo
o`09ooooo`Ooo`000_ooool5ool001[ooooo1Ooo00001?ooooooo`00ool00?oo0007ooooo`?oo`00
>?ooool5ool009[ooooo0@000001ooooo`0000<00000ooooooooool02Oooool7ool000;ooooo1Ooo
000:ooooo`?oo`003Oooool:ool000Gooooo1Ooo000Mooooo`?oo`005oooool5ool005gooooo0ooo
000jooooo`4000000Oooool0000300000?oooooooooo00Wooooo1_oo0004ooooo`?oo`002_ooool5
ool000cooooo2_oo0005ooooo`Goo`004Oooool3ool000Sooooo1Ooo000Fooooo`Goo`00G?ooool5
ool003Wooooo0@000001ooooo`0000<00000ooooooooool00ooo0005ooooo`Goo`004oooool5ool0
00Wooooo3Ooo0005ooooo`Goo`004?ooool5ool000Oooooo1Ooo0003ooooo`?oo`004Oooool3ool0
02Kooooo0ooo000dooooo`Goo`00>Oooool10000007ooooo00000`00003oooooool00004ool000?o
oooo1Ooo000Dooooo`Koo`0000Coooooool00?oo003oo`000oooool9ool00004oooooooo003oo`00
ool000Oooooo0ooo000@ooooo`Koo`001oooool5ool000;ooooo1Ooo000hooooo`Goo`003?ooool3
ool002Cooooo1Ooo000iooooo`4000000Oooool0000300000?ooooooo`0000Coo`000oooool5ool0
01Gooooo2_oo0002ooooo`Woo`007Oooool7ool000Sooooo0ooo0003ooooo`Ooo`009Oooool3ool0
00kooooo1Ooo000;ooooo`Goo`009?ooool3ool003[ooooo0@000001ooooo`0000<00000oooooooo
00001?oo0003ooooo`Soo`004_ooool:ool000;ooooo2Ooo000>ooooo`?oo`002?ooool3ool00003
oooooooo003oo`0000Goo`003_ooool8ool000Sooooo0ooo000Hooooo`Goo`003Oooool5ool000_o
oooo1Ooo000Qooooo`?oo`00?Oooool10000007ooooo00000`00003oooooooooo`05ool000?ooooo
2?oo000Aooooo`[oo`000oooool8ool000gooooo1Ooo0006ooooo`goo`003_ooool9ool000Gooooo
1Ooo000Gooooo`Goo`003_ooool3ool000Kooooo0ooo0003ooooo`Goo`008?ooool5ool003cooooo
0@000001ooooo`0000@00000oooooooooooooooo1Ooo0005ooooo`Goo`004?ooool6ool00004oooo
oooo003oo`00ool000Sooooo1?oo000=ooooo`Goo`001_ooool>ool000_ooooo0ooo00000ooooooo
o`00ool00006ool000Cooooo1Ooo000?ooooo`?oo`0000?oooooool00?oo00001ooo000Fooooo`Go
o`000oooool3ool001_ooooo0ooo0003ooooo`Koo`00>oooool10000007ooooo00001000003ooooo
ooooooooool5ool000Gooooo1Ooo000?ooooo`Soo`002oooool5ool000;ooooo0ooo0007ooooo`Go
o`001_ooool>ool000[ooooo1Ooo00000oooooooo`00ool00005ool000Cooooo1Ooo000>ooooo`go
o`001Oooool3ool000oooooo1Ooo000Pooooo`Goo`000_ooool7ool003[ooooo0@000001ooooo`00
00<00000ooooooooool02ooo00001?ooooooo`00ool00?oo000@ooooo`Woo`002_ooool;ool000Oo
oooo0ooo0008ooooo`?oo`000_ooool8ool000[ooooo1Ooo0003ooooo`Goo`001Oooool3ool000oo
oooo2_oo0007ooooo`Goo`000_ooool4ool000Cooooo0ooo00000oooooooo`00ool00003ool000So
oooo0ooo000Eooooo`Goo`000oooool6ool003[ooooo0@000001ooooo`0000<00000ooooooooool0
3?oo000Cooooo`Woo`002_ooool;ool000oooooo0ooo0009ooooo`Goo`002Oooool5ool000Cooooo
0ooo000Hooooo`[oo`001oooool5ool00003oooooooo003oo`0000Coo`000_ooool5ool00003oooo
oooo003oo`0000;oo`001oooool5ool000Wooooo0ooo0008ooooo`Koo`000oooool6ool003Wooooo
0@000001ooooo`0000<00000ooooooooool03?oo0004ooooo`?oo`002?ooool3ool000;ooooo2?oo
000;ooooo`[oo`003_ooool5ool000Sooooo1Ooo000:ooooo`?oo`008Oooool3ool00003oooooooo
003oo`0000;oo`002?ooool5ool00003oooooooo003oo`0000Coo`000_ooool5ool00003oooooooo
003oo`0000?oo`001_ooool5ool000Sooooo1Ooo0008ooooo`Goo`001?ooool6ool003Sooooo0@00
0001ooooo`0000<00000ooooooooool03?oo0003ooooo`Goo`001_ooool5ool000Gooooo1_oo0002
ooooo`?oo`001Oooool8ool000oooooo1Ooo0008ooooo`Koo`00=Oooool3ool000Kooooo0ooo0002
ooooo`Koo`000_ooool;ool000Kooooo1Ooo0008ooooo`Goo`002?ooool5ool000Gooooo1Ooo000h
ooooo`4000000Oooool0000300000?ooooooo`0000_oo`001?ooool5ool000Kooooo1Ooo0006oooo
o`_oo`001Oooool3ool001?ooooo1ooo0007ooooo`Goo`002_ooool3ool000Sooooo0ooo000@oooo
o`Koo`001_ooool5ool000_ooooo1Ooo0003ooooo`[oo`001oooool3ool000Wooooo1Ooo0009oooo
o`?oo`001_ooool5ool003Sooooo0@000001ooooo`0000<00000ool00?oo00001Ooo000:ooooo`Go
o`001_ooool7ool000?ooooo3?oo000Dooooo`?oo`001Oooool7ool000Kooooo1Ooo0009ooooo`Go
o`001_ooool5ool000gooooo2Ooo0005ooooo`Goo`002oooool5ool000Gooooo1ooo000Eooooo`?o
o`000_ooool5ool000gooooo0ooo000iooooo`4000000Oooool0000300000?oo003oo`0000Coo`00
3?ooool3ool000Sooooo1ooo0002ooooo`coo`004oooool5ool000Kooooo1Ooo0007ooooo`?oo`00
2Oooool6ool000Kooooo1Ooo000<ooooo`[oo`001Oooool5ool000_ooooo1Ooo00001Oooooooo`00
ool00?oo003ooooo00Goo`004oooool3ool000Gooooo1ooo0018ooooo`4000000Oooool000030000
0?oo003oo`0000?oo`006_ooool5ool000;ooooo1_oo0002ooooo`?oo`005?ooool5ool000Kooooo
1Ooo0005ooooo`?oo`002oooool6ool000Kooooo1Ooo000<ooooo`[oo`001Oooool5ool000;ooooo
0ooo0007ooooo`?oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00003ool0017ooooo
2?oo00000oooooooo`00ool00005ool004Sooooo0@000001ooooo`0000<00000oooooooo00000_oo
000Kooooo`Goo`000oooool3ool001_ooooo1Ooo0007ooooo`Goo`000oooool5ool000Cooooo0ooo
0003ooooo`Koo`001oooool3ool000cooooo2_oo0006ooooo`Goo`0000?oooooool00?oo00000ooo
000:ooooo`Goo`0000?oooooool00?oo00000ooo000Aoooooa3oo`00B?ooool10000007ooooo0000
0`00003oooooooooo`05ooooo`?oo`005?ooool6ool001Wooooo0ooo0006ooooo`?oo`002Oooool5
ool000;ooooo1Ooo0003ooooo`Goo`000oooool5ool001Kooooo1Ooo000<ooooo`[oo`002_ooool5
ool00003oooooooo003oo`0000?oo`003Oooool3ool00003oooooooo003oo`0000Ooo`0000?ooooo
ool00?oo00000ooo0019ooooo`4000000Oooool0000300000?oooooooooo00Cooooo1Ooo000Boooo
o`Ooo`006?ooool5ool0017ooooo1Ooo0002ooooo`Goo`000oooool5ool000?ooooo1Ooo000:oooo
o`?oo`002Oooool5ool000cooooo3Ooo0007ooooo`Goo`000_ooool3ool000gooooo1Ooo00000ooo
ooooo`00ool00006ool000oooooo0ooo000mooooo`4000000Oooool0000300000?oooooooooo00?o
o`0000?oooooool00?oo00000ooo000Booooo`Ooo`001oooool3ool000Cooooo0ooo0007ooooo`Go
o`0000Coooooool00?oo003oo`003Oooool5ool000?ooooo0ooo0004ooooo`Goo`000oooool5ool0
00Wooooo1Ooo0009ooooo`?oo`003Oooool5ool00003oooooooo003oo`0000Koo`001_ooool5ool0
00[ooooo0ooo0005ooooo`Goo`001Oooool3ool000[ooooo0ooo0002ooooo`Goo`00??ooool10000
007ooooo00000`00003oooooool00009ool001;ooooo2?oo0005ooooo`Goo`000_ooool5ool00004
oooooooo003oo`00ool000;ooooo2_oo000=ooooo`?oo`003?ooool3ool000Gooooo0ooo000:oooo
o`Goo`003_ooool3ool000Wooooo0ooo0005ooooo`Goo`001oooool3ool000[ooooo1Ooo0004oooo
o`Goo`004Oooool5ool00003oooooooo003oo`0000?oo`00??ooool10000007ooooo00000`00003o
ooooool00004ool00004oooooooo003oo`00ool000[ooooo0ooo0007ooooo`Soo`001?ooool5ool0
00;ooooo2_oo0002ooooo`Woo`00<Oooool5ool000gooooo1Ooo000@ooooo`Goo`005?ooool6ool0
00Cooooo0ooo0005ooooo`?oo`002_ooool5ool00003oooooooo003oo`0000?oo`00??ooool10000
007ooooo00000`00003oo`00ool00004ool000gooooo1Ooo0008ooooo`Ooo`000oooool5ool000;o
oooo2_oo0004ooooo`Woo`001_ooool3ool001;ooooo0ooo000Booooo`?oo`003_ooool5ool0017o
oooo0ooo000Eooooo`Ooo`002_ooool5ool000Wooooo1Ooo00000oooooooo`00ool00003ool003co
oooo0@000001ooooo`001_oo000>ooooo`Goo`002Oooool6ool000Cooooo0ooo0004ooooo`?oo`00
00?oooooool00?oo00000ooo0004ooooo`[oo`001?ooool5ool000Wooooo0ooo0004ooooo`Goo`00
3Oooool3ool001;ooooo1Ooo000Tooooo`?oo`000_ooool7ool000[ooooo1Ooo000:ooooo`?oo`00
0oooool3ool003gooooo0@000001ooooo`001Ooo0004ooooo`?oo`002?ooool5ool000Oooooo2?oo
000=ooooo`Soo`000oooool:ool000Cooooo1Ooo0008ooooo`Goo`000oooool5ool000cooooo1Ooo
0008ooooo`?oo`001oooool3ool002Cooooo1Ooo00000oooooooo`00ool00005ool000Kooooo0ooo
00000oooooooo`00ool00003ool000[ooooo0ooo0013ooooo`4000000Oooool000Goo`0000?ooooo
ool00?oo00001Ooo0005ooooo`Koo`001Oooool:ool000cooooo2_oo0004ooooo`?oo`0000?ooooo
ool00?oo00000ooo0004ooooo`Goo`002?ooool5ool000?ooooo1Ooo000;ooooo`Koo`001oooool5
ool002gooooo1Ooo00000oooooooo`00ool00004ool000Kooooo1Ooo00001?ooooooo`00ool00?oo
000:ooooo`Goo`000oooool3ool003cooooo0@000001ooooo`0000D00000ool00?oo003oo`00oooo
o`08ool000Cooooo1Ooo0006ooooo`[oo`003?ooool@ool000Cooooo0ooo0006ooooo`?oo`002Ooo
ool5ool000Cooooo0ooo000<ooooo`Koo`001oooool5ool000?ooooo1?oo000Vooooo`Goo`0000?o
ooooool00?oo00001?oo0006ooooo`Goo`003_ooool5ool000;ooooo1Ooo000kooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo2?oo0004ooooo`Koo`001Oooool:ool000Gooooo0ooo0004
oooooa7oo`003_ooool3ool000Sooooo0ooo0002ooooo`?oo`001?ooool3ool000Sooooo1Ooo0008
ooooo`Goo`000_ooool6ool000?ooooo0ooo000Pooooo`?oo`000_ooool6ool000Kooooo1Ooo0009
ooooo`?oo`000_ooool5ool000;ooooo1Ooo000kooooo`4000000Oooool0000300000?oooooooooo
00;ooooo1ooo0005ooooo`Koo`000_ooool<ool000Gooooo1Ooo0003ooooo`Koo`001?ooool7ool0
00gooooo1ooo0009ooooo`Goo`000_ooool5ool000Kooooo1Ooo000:ooooo`?oo`000oooool6ool0
00;ooooo1Ooo000<ooooo`Goo`005?ooool5ool000Oooooo0ooo0009ooooo`Goo`000_ooool3ool0
00?ooooo1Ooo000kooooo`4000000Oooool0000300000?oooooooooo00?ooooo1_oo0006ooooo`Go
o`0000?oooooool00?oo00001ooo0009ooooo`Goo`001?ooool3ool000Kooooo2Ooo000;ooooo`So
o`002?ooool5ool000;ooooo1Ooo0005ooooo`Goo`004Oooool6ool000;ooooo1Ooo0002ooooo`?o
o`001_ooool7ool001Cooooo0ooo0008ooooo`?oo`002Oooool5ool000Oooooo1Ooo000looooo`40
00000Oooool0000300000?oooooooooo00Cooooo1Ooo0007ooooo`?oo`000_ooool9ool000Wooooo
2?oo000;ooooo`Woo`002_ooool:ool000Kooooo1Ooo0002ooooo`Goo`001Oooool5ool001;ooooo
1?oo0003ooooo`Goo`0000?oooooool00?oo00000ooo0005ooooo`Ooo`001?ooool5ool000cooooo
0ooo0006ooooo`Goo`002?ooool5ool000Oooooo1Ooo000looooo`4000000Oooool0000300000?oo
oooooooo00Cooooo1Ooo000<ooooo`Soo`002oooool8ool000kooooo1Ooo000;ooooo`goo`000ooo
ool6ool00004oooooooo003oo`00ool000Kooooo1Ooo000Iooooo`Coo`000_ooool5ool000Gooooo
1ooo0003ooooo`Ooo`002_ooool5ool000Gooooo1Ooo0009ooooo`?oo`002?ooool5ool003cooooo
0@000001ooooo`0000<00000ooooooooool01Oooool3ool000kooooo2?oo000;ooooo`Soo`003Ooo
ool5ool000?ooooo0ooo0005ooooo`koo`001?ooool5ool000[ooooo0ooo000Booooo`?oo`001?oo
ool5ool000;ooooo1_oo0005ooooo`Goo`001?ooool7ool000Wooooo1_oo0005ooooo`Goo`005?oo
ool5ool003cooooo0@000001ooooo`0000<00000ooooooooool00ooo00000oooooooo`00ool00003
ool0013ooooo1Ooo000;ooooo`Woo`002_ooool6ool000?ooooo1Ooo0004oooooa3oo`000_ooool5
ool000Sooooo1_oo000@ooooo`Goo`000oooool5ool000?ooooo1_oo000=ooooo`Woo`001oooool6
ool000Kooooo0ooo000Eooooo`Goo`00??ooool10000007ooooo00000`00003oooooool00009ool0
013ooooo1Ooo000:ooooo`[oo`002Oooool5ool000Gooooo1Ooo0005oooooa3oo`0000?oooooool0
0?oo00000ooo0007ooooo`Ooo`004?ooool5ool000?ooooo1ooo0002ooooo`Goo`003_ooool9ool0
00Kooooo1Ooo0002ooooo`?oo`006_ooool5ool003cooooo0@000001ooooo`0000<00000oooooooo
00002Ooo0009ooooo`?oo`001?ooool4ool000_ooooo2_oo0009ooooo`Goo`001Oooool5ool000Ko
oooo1Ooo0003ooooo`Ooo`000_ooool3ool000Sooooo1ooo000@ooooo`Goo`000oooool8ool00003
oooooooo003oo`0000?oo`004?ooool7ool000Gooooo1Ooo0002ooooo`Soo`005oooool3ool003go
oooo0@000001ooooo`0000<00000ool00?oo00001?oo00001?ooooooo`00ool00?oo0009ooooo`Go
o`000_ooool5ool000_ooooo2Ooo00001?ooooooo`00ool00?oo0006ooooo`Goo`001_ooool3ool0
00Oooooo1Ooo0005ooooo`Goo`003Oooool6ool001;ooooo0ooo0005ooooo`Ooo`000_ooool3ool0
00kooooo2_oo0005ooooo`Goo`000_ooool9ool005Kooooo0@000001ooooo`0000<00000ool00?oo
00001?oo000=ooooo`Goo`000_ooool5ool000cooooo1_oo0002ooooo`Goo`001_ooool3ool001;o
oooo0ooo0007ooooo`?oo`002Oooool3ool000?ooooo0ooo00001?ooooooo`00ool00?oo000Joooo
o`Goo`000oooool3ool000cooooo3Ooo0003ooooo`Goo`000_ooool9ool005Kooooo0@000001oooo
o`0000<00000ool00?oo00001?oo000=ooooo`coo`001oooool3ool000?ooooo3?oo0002ooooo`?o
o`00:oooool5ool000Gooooo1Ooo0006ooooo`?oo`004Oooool3ool000?ooooo1Ooo000;ooooo`ko
o`0000?oooooool00?oo00000ooo00000oooooooo`00ool00009ool005Kooooo0@000001ooooo`00
00<00000oooooooo00000ooo000?ooooo`[oo`001oooool5ool000;ooooo4_oo000Nooooo`?oo`00
2?ooool6ool000Gooooo1ooo00000oooooooo`00ool00006ool000[ooooo0ooo0008ooooo`Goo`00
2oooool5ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo00004?oo001Eooooo`400000
0Oooool0000300000?oooooooooo01Cooooo1Ooo0003ooooo`?oo`001?ooool5ool00003oooooooo
003oo`00017oo`001?ooool3ool001Kooooo1ooo0005ooooo`Koo`001OoooolAool000Sooooo1Ooo
0007ooooo`Goo`003?ooool3ool000;ooooo2?oo00000oooooooo`00ool0000Aool005Cooooo0@00
0001ooooo`0000<00000ooooooooool05?ooool5ool000;ooooo1Ooo0003ooooo`Goo`0000?ooooo
ool00?oo00001ooo00000oooooooo`00ool00007ool000;ooooo1_oo0003ooooo`?oo`003?ooool;
ool000Cooooo1Ooo0007oooooa?oo`001Oooool6ool000Kooooo1_oo000@ooooo`Ooo`000ooooolB
ool005Cooooo0@000001ooooo`0000<00000ooooooooool01Oooool4ool000[ooooo1Ooo0003oooo
o`Goo`001?ooool3ool000;ooooo2?oo0002ooooo`Soo`0000?oooooool00?oo00001_oo0002oooo
o`Goo`002_ooool<ool000Gooooo0ooo000:oooooa;oo`001?ooool6ool000Oooooo1_oo000@oooo
o`Koo`000_ooool9ool00005oooooooo003oo`00ool00?ooool01Ooo001Dooooo`4000000Oooool0
000300000?oooooooooo00Cooooo1_oo0009ooooo`Goo`000oooool5ool000[ooooo1_oo0004oooo
o`?oo`001?ooool9ool000;ooooo1Ooo000:ooooo`coo`001_ooool3ool000Wooooo2Ooo00000ooo
ooooo`00ool00006ool000Gooooo1Ooo0008ooooo`Goo`004_ooool<ool000Wooooo0ooo000;oooo
o`?oo`00Aoooool10000007ooooo00000`00003oooooooooo`04ooooo`Koo`000_ooool3ool000Co
oooo1Ooo0004ooooo`?oo`003Oooool5ool000[ooooo2?oo0003ooooo`Goo`002_ooool5ool00003
oooooooo003oo`0000?oo`001_ooool5ool000Wooooo2Ooo0003ooooo`Goo`001_ooool3ool000;o
oooo0ooo0004ooooo`Goo`004_ooool;ool000Wooooo0ooo000;ooooo`Goo`002Oooool3ool003[o
oooo0@000001ooooo`0000<00000ooooooooool01?ooool6ool00003oooooooo003oo`0000?oo`00
1?ooool3ool001Gooooo1Ooo0002ooooo`?oo`001Oooool6ool000Gooooo1Ooo000;ooooo`?oo`00
0oooool5ool000Gooooo1Ooo0005ooooo`?oo`000_ooool8ool000?ooooo1Ooo000:ooooo`Goo`00
1?ooool5ool0017ooooo2_oo0009ooooo`Goo`002_ooool5ool000Sooooo1Ooo000iooooo`400000
0Oooool0000300000?oooooooooo00Gooooo1?oo0002ooooo`Ooo`006_ooool5ool00003oooooooo
003oo`0000?oo`001Oooool3ool000Kooooo1ooo000=ooooo`Soo`000_ooool8ool000Cooooo1Ooo
00000oooooooo`00ool00006ool00003oooooooo003oo`0000Coo`002oooool7ool000;ooooo1Ooo
000Booooo`Coo`0000Coooooool00?oo003oo`002_ooool5ool000[ooooo1Ooo0008ooooo`Goo`00
>Oooool10000007ooooo00000`00003oooooooooo`0;ooooo`Soo`006_ooool3ool000;ooooo1Ooo
000>ooooo`Soo`002oooool9ool00003oooooooo003oo`0000Koo`001Oooool5ool00003oooooooo
003oo`0000Goo`0000?oooooool00?oo00000ooo000=ooooo`Soo`0000?oooooool00?oo00000ooo
0002ooooo`?oo`003Oooool5ool000gooooo1Ooo000;ooooo`?oo`002Oooool5ool003Wooooo0@00
0001ooooo`0000<00000ooooooooool03?ooool7ool001oooooo1Ooo000>ooooo`Soo`002oooool8
ool000;ooooo1Ooo0007ooooo`Koo`0000?oooooool00?oo00002ooo000>ooooo`Soo`0000Cooooo
ool00?oo003oo`000_ooool5ool000cooooo2?oo000;ooooo`?oo`006Oooool3ool003[ooooo0@00
0001ooooo`0000<00000ooooooooool03Oooool6ool0023ooooo0ooo000@ooooo`Ooo`002oooool5
ool000Gooooo1Ooo0007ooooo`Goo`000oooool<ool000cooooo0ooo00000oooooooo`00ool00005
ool00005oooooooo003oo`00ool00?ooool01Ooo0008ooooo`?oo`0000?oooooool00?oo00001ooo
001Sooooo`4000000Oooool0000300000?oooooooooo00cooooo1_oo000eooooo`Goo`003Oooool3
ool000Oooooo0ooo0008ooooo`Goo`001?ooool6ool00004oooooooo003oo`00ool000cooooo5_oo
0007ooooo`Goo`0000?oooooool00?oo00001_oo001Sooooo`4000000Oooool0000300000?oooooo
oooo00cooooo1Ooo000:ooooo`?oo`005Oooool3ool001;ooooo0ooo000Rooooo`Goo`000_ooool3
ool000;ooooo0ooo000AoooooaGoo`000oooool3ool000;ooooo1Ooo0004ooooo`Goo`002?ooool3
ool005Sooooo0@000001ooooo`0000<00000ooooooooool02oooool7ool000Sooooo1ooo000Aoooo
o`Goo`00=Oooool5ool000;ooooo1Ooo000Eooooo`_oo`0000?oooooool00?oo00001ooo0002oooo
o`Goo`0000?oooooool00?oo00000ooo0005ooooo`?oo`002?ooool7ool005Gooooo0@000001oooo
o`0000<00000ooooooooool02_ooool9ool000Oooooo2?oo000@ooooo`Goo`005?ooool3ool001ko
oooo1Ooo0002ooooo`Goo`003?ooool3ool000Oooooo2?oo0004ooooo`Ooo`000oooool5ool000;o
oooo0ooo000Aooooo`Soo`00E?ooool10000007ooooo00000`00003oooooooooo`0:ooooo`Woo`00
1oooool8ool0013ooooo1Ooo000Cooooo`Goo`007Oooool5ool000;ooooo1Ooo000;ooooo`Goo`00
1Oooool8ool000Kooooo0ooo0006ooooo`Goo`005_ooool8ool005Cooooo0@000001ooooo`0000<0
0000ooooooooool02_ooool9ool000Sooooo1ooo000@ooooo`Goo`004oooool5ool001kooooo0ooo
0004ooooo`?oo`003?ooool5ool000Gooooo1Ooo000Cooooo`?oo`006?ooool7ool005Cooooo0@00
0001ooooo`0000<00000ooooooooool01Oooool4ool000;ooooo0ooo00001?ooooooo`00ool00?oo
000<ooooo`?oo`004Oooool5ool001?ooooo1Ooo000dooooo`Goo`001Oooool5ool0037ooooo0ooo
001Eooooo`4000000Oooool0000300000?oooooooooo00Cooooo1_oo000Xooooo`Goo`005?ooool3
ool003Kooooo0ooo0007ooooo`?oo`00R_ooool10000007ooooo00000`00003oooooooooo`04oooo
o`Koo`003Oooool3ool000gooooo0ooo0008ooooo`Goo`00i?ooool10000007ooooo00000`00003o
ooooooooo`04ooooo`Koo`000_ooool3ool000Oooooo1Ooo00001?ooooooo`00ool00?oo0007oooo
o`Goo`002?ooool3ool00>Gooooo0@000001ooooo`0000<00000ooooooooool01Oooool4ool000;o
oooo1Ooo0006ooooo`[oo`001_ooool5ool00?3ooooo0@000001ooooo`0000<00000ooooooooool0
2oooool5ool000;ooooo0ooo00000oooooooo`00ool00008ool000Kooooo1Ooo003`ooooo`400000
0Oooool0000300000?oooooooooo00_ooooo1Ooo00000oooooooo`00ool00003ool00003oooooooo
003oo`0000Ooo`001oooool3ool00004oooooooo003oo`00ool00>gooooo0@000001ooooo`0000<0
0000ooooooooool03?ooool3ool000;ooooo1Ooo0003ooooo`Koo`002oooool5ool00>cooooo0@00
0001ooooo`0000<00000ooooooooool03oooool7ool000Cooooo0ooo0005ooooo`?oo`001Oooool5
ool00>cooooo0@000001ooooo`0000<00000ooooooooool03_ooool8ool000_ooooo1ooo0002oooo
o`Goo`00k?ooool10000007ooooo00000`00003oooooooooo`0>ooooo`Soo`002oooool8ool000;o
oooo0ooo003]ooooo`4000000Oooool0000300000?oooooooooo00kooooo2?oo0007ooooo`?oo`00
00?oooooool00?oo00001_oo0003ooooo`?oo`000_ooool3ool00>Oooooo0@000001ooooo`0000<0
0000ooooooooool01Oooool3ool000Oooooo1_oo0007ooooo`Goo`0000?oooooool00?oo00001Ooo
0002ooooo`[oo`00i_ooool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`003?ooool3
ool000Cooooo1Ooo0004ooooo`?oo`000oooool:ool00>Kooooo0@000001ooooo`0000<00000oooo
ooooool01?ooool5ool000_ooooo1Ooo0003ooooo`Goo`002Oooool;ool00>Kooooo0@000001oooo
o`0000<00000ooooooooool01?ooool5ool000_ooooo1Ooo0004ooooo`?oo`002_ooool5ool000;o
oooo1?oo003Vooooo`4000000Oooool0000300000?oooooooooo00Gooooo0ooo000<ooooo`Goo`00
4Oooool5ool000;ooooo1Ooo003Uooooo`4000000Oooool0000300000?oooooooooo01Gooooo0ooo
000Cooooo`?oo`000oooool5ool00>Gooooo0@000001ooooo`0000<00000ooooooooool03?ooool3
ool002;ooooo1Ooo003Uooooo`4000000Oooool0000300000?oooooooooo00Sooooo2?oo000Noooo
o`?oo`0000Coooooool00?oo003oo`00i_ooool10000007ooooo00000`00003oooooooooo`07oooo
o`_oo`002oooool3ool000gooooo1Ooo003Yooooo`4000000Oooool0000300000?ooooooo`0000;o
o`001Oooool<ool000Wooooo1Ooo000<ooooo`Koo`00j?ooool10000007ooooo00000`00003oo`00
ool00003ool000Cooooo3?oo0009ooooo`Goo`003?ooool6ool00>Sooooo0@000001ooooo`0000<0
0000ool00?oo00000ooo0005ooooo`?oo`000oooool5ool000Wooooo1Ooo000<ooooo`Koo`00j?oo
ool10000007ooooo00000`00003oo`00ool00004ool000_ooooo0ooo000;ooooo`?oo`003Oooool5
ool00>Wooooo0@000001ooooo`0000<00000oooooooo00001?oo000Yooooo`Goo`000_ooool3ool0
0>Cooooo0@000001ooooo`0000<00000ool00?oo00001?oo000Nooooo`?oo`002Oooool3ool000;o
oooo1Ooo003Sooooo`4000000Oooool0000300000?oo003oo`0000?oo`007Oooool6ool000Oooooo
1Ooo00000oooooooo`00ool00003ool00>?ooooo0@000001ooooo`0000<00000ool00?oo00000ooo
000Hooooo`?oo`0000?oooooool00?oo00002_oo0002ooooo`Goo`0000?oooooool00?oo00000ooo
003Sooooo`4000000Oooool0000300000?oo003oo`0000?oo`003oooool3ool000Gooooo4_oo0000
0oooooooo`00ool00003ool000;ooooo0ooo003Tooooo`4000000Oooool0000300000?oo003oo`00
00?oo`003_ooool5ool000Cooooo4_oo0002ooooo`?oo`00j_ooool10000007ooooo00000`00003o
o`00ool00003ool000Cooooo0ooo0007ooooo`Goo`001?oooolBool00>oooooo0@000001ooooo`00
00<00000oooooooo00000_oo0004ooooo`Goo`001_ooool5ool000Gooooo4ooo003]ooooo`400000
0Oooool0000300000?oooooooooo00Kooooo1ooo0005ooooo`?oo`002?ooool6ool000;ooooo0ooo
0002ooooo`Goo`00k?ooool10000007ooooo00000`00003oooooooooo`06ooooo`Soo`003oooool5
ool000Sooooo1Ooo003/ooooo`4000000Oooool0000300000?oooooooooo00Oooooo1ooo000?oooo
o`Goo`002?ooool5ool00>cooooo0@000001ooooo`0000<00000ooooooooool02?ooool6ool0013o
oooo0ooo0009ooooo`Goo`00k?ooool10000007ooooo00000`00003oooooooooo`08ooooo`Goo`00
7_ooool3ool000?ooooo0ooo003Wooooo`4000000Oooool0000300000?oooooooooo00Wooooo0ooo
000Tooooo`Goo`00i_ooool10000007ooooo00000`00003oooooooooo`0Booooo`Koo`006?ooool5
ool00>Kooooo0@000001ooooo`0000<00000ooooooooool04Oooool8ool001Oooooo1Ooo003Voooo
o`4000000Oooool0000300000?oooooooooo017ooooo2ooo000Eooooo`?oo`00ioooool10000007o
oooo00000`00003oooooooooo`0Aooooo`coo`00o_ooool10000007ooooo00000`00003ooooooooo
o`0Booooo`_oo`00o_ooool10000007ooooo00000`00003oooooooooo`0Fooooo`Ooo`003oooool3
ool00>cooooo0@000001ooooo`0000<00000ooooooooool03Oooool6ool000?ooooo1_oo000?oooo
o`Goo`00joooool10000007ooooo00000`00003oooooooooo`0<ooooo`Soo`000_ooool4ool000Co
oooo0ooo000:ooooo`Goo`00joooool10000007ooooo00000`00003oooooooooo`0<ooooo`Soo`00
00?oooooool00?oo00001?oo0002ooooo`Goo`002Oooool5ool00>_ooooo0@000001ooooo`0000<0
0000ooooooooool03?ooool8ool00003oooooooo003oo`0000Goo`0000?oooooool00?oo00000ooo
000:ooooo`?oo`00k?ooool10000007ooooo00000`00003oooooooooo`0;ooooo`Soo`000_ooool7
ool00003oooooooo003oo`0000?oo`005?ooool3ool00>;ooooo0@000001ooooo`0000<00000oooo
ooooool02_ooool5ool000Oooooo1_oo0002ooooo`?oo`005?ooool5ool00>7ooooo0@000001oooo
o`0000<00000ooooooooool02_ooool5ool000Oooooo1Ooo000Jooooo`Goo`00hOooool10000007o
oooo00000`00003oooooooooo`0:ooooo`Goo`001oooool5ool001[ooooo1Ooo003Qooooo`400000
0Oooool0000300000?oooooooooo00[ooooo1Ooo0008ooooo`?oo`007?ooool3ool00>;ooooo0@00
0001ooooo`0000<00000ooooooooool02_ooool5ool002Sooooo0ooo000gooooo`?oo`002Oooool3
ool0017ooooo0ooo000Looooo`?oo`00J?ooool10000007ooooo00000`00003oooooooooo`0:oooo
o`Goo`004_ooool3ool001;ooooo1Ooo000;ooooo`?oo`003?ooool5ool000Wooooo0ooo0008oooo
o`Ooo`001oooool5ool000Cooooo0ooo0008ooooo`Goo`004Oooool3ool000Kooooo1Ooo000Loooo
o`?oo`00B?ooool10000007ooooo00000`00003oooooooooo`0;ooooo`?oo`002_ooool3ool000Go
oooo1Ooo000Aooooo`Goo`002_ooool5ool000[ooooo1ooo0007ooooo`Goo`001_ooool8ool000Oo
oooo1_oo0002ooooo`Goo`001oooool5ool0013ooooo1Ooo0005ooooo`Goo`001?ooool3ool001Co
oooo2?oo0014ooooo`4000000Oooool0000300000?oooooooooo01Oooooo1Ooo0004ooooo`Goo`00
4Oooool5ool000[ooooo1Ooo000:ooooo`Ooo`001oooool5ool000Kooooo2?oo0007ooooo`Ooo`00
00?oooooool00?oo00000ooo0007ooooo`Goo`004?ooool5ool000Gooooo1Ooo00000oooooooo`00
ool00005ool001?ooooo2Ooo0003ooooo`Coo`00??ooool10000007ooooo00000`00003ooooooooo
o`0Gooooo`Goo`001?ooool5ool001;ooooo0ooo000;ooooo`Goo`002_ooool7ool000Oooooo1Ooo
0006ooooo`Ooo`002Oooool<ool000Sooooo0ooo000Aooooo`Goo`001_ooool3ool00003oooooooo
003oo`0000Koo`004oooool9ool000;ooooo1_oo000kooooo`4000000Oooool0000300000?oooooo
oooo01Oooooo1Ooo00000oooooooo`00ool00006ool0017ooooo1Ooo000;ooooo`?oo`002?ooool3
ool00003oooooooo003oo`0000?oo`002?ooool4ool000Sooooo0ooo000=ooooo`_oo`007Oooool3
ool000Kooooo0ooo0002ooooo`_oo`001_ooool3ool000Sooooo2?oo0002ooooo`Koo`00>oooool1
0000007ooooo00000`00003oooooooooo`03ool001Gooooo0ooo00000oooooooo`00ool00007ool0
013ooooo1ooo000Dooooo`Goo`003?ooool5ool001Wooooo2_oo000Uooooo`Goo`0000?oooooool0
0?oo00002_oo0004ooooo`Goo`000oooool3ool000Cooooo1Ooo0002ooooo`Koo`00>oooool10000
007ooooo00000`00003oooooool00004ool001Sooooo2?oo000Aooooo`Ooo`001?ooool6ool000[o
oooo1Ooo000<ooooo`Goo`002_ooool3ool000Kooooo0ooo0004ooooo`Soo`004Oooool3ool000Co
oooo0ooo000;ooooo`Goo`000_ooool3ool000?ooooo1Ooo0002ooooo`Ooo`000_ooool5ool000?o
oooo1Ooo0003ooooo`Coo`00??ooool10000007ooooo00000`00003oooooool00004ool001Sooooo
1ooo0008ooooo`?oo`001ooooolBool00004oooooooo003oo`00ool000Gooooo1Ooo000<ooooo`Go
o`002Oooool5ool000Cooooo1Ooo0003ooooo`Coo`005?ooool5ool000;ooooo1Ooo000:ooooo`Go
o`002?ooool5ool00003oooooooo003oo`0000Koo`000_ooool5ool000Cooooo0ooo0014ooooo`40
00000Oooool0000300000?ooooooo`0000Coo`000oooool3ool001?ooooo1Ooo0004ooooo`?oo`00
00?oooooool00?oo00000ooo0007oooooaKoo`001Oooool3ool000kooooo0ooo000:ooooo`Goo`00
1?ooool5ool000;ooooo1Ooo000?ooooo`?oo`000_ooool5ool000;ooooo1Ooo000;ooooo`?oo`00
2_ooool3ool000;ooooo1ooo0003ooooo`Koo`00B_ooool10000007ooooo00000`00003ooooooooo
o`03ool000?ooooo1Ooo000Jooooo`[oo`003?oooolAool000[ooooo0ooo000Fooooo`Goo`001?oo
ool6ool00003oooooooo003oo`0000Koo`002oooool5ool00003oooooooo003oo`0000[oo`007Ooo
ool5ool000Kooooo1_oo0019ooooo`4000000Oooool0000300000?oooooooooo00Kooooo1Ooo000?
ooooo`?oo`002?ooool:ool000cooooo2ooo00000oooooooo`00ool00003ool000Oooooo1ooo000F
ooooo`Koo`000oooool?ool000[ooooo1Ooo0002ooooo`[oo`007_ooool5ool000Oooooo1Ooo0019
ooooo`4000000Oooool0000300000?ooooooo`0000;oo`001?ooool5ool000kooooo1Ooo0007oooo
o`Goo`0000Coooooool00?oo003oo`003_ooool3ool000;ooooo1Ooo0002ooooo`?oo`001oooool8
ool000_ooooo0ooo000:ooooo`Goo`000oooool>ool000Wooooo1_oo0005ooooo`Goo`008?ooool5
ool000Oooooo1Ooo0019ooooo`4000000Oooool0000300000?oo003oo`0000?oo`001?ooool3ool0
00oooooo1Ooo0007ooooo`Goo`005oooool5ool000cooooo2?oo0006ooooo`?oo`0000?oooooool0
0?oo00000ooo0009ooooo`Goo`000oooool>ool000Kooooo2?oo0006ooooo`Goo`008?ooool5ool0
0004oooooooo003oo`00ool000?ooooo1Ooo0019ooooo`4000000Oooool0000300000?oo003oo`00
00?oo`005_ooool5ool000Oooooo1Ooo000Gooooo`Goo`003?ooool:ool000?ooooo2_oo0009oooo
o`Goo`001?ooool<ool000Kooooo2?oo0008ooooo`?oo`008_ooool3ool00003oooooooo003oo`00
00Coo`000_ooool3ool000Wooooo0ooo000nooooo`4000000Oooool0000300000?oo003oo`0000?o
o`005oooool4ool000Oooooo1Ooo0003ooooo`?oo`004_ooool3ool000kooooo2_oo0002ooooo`co
o`002?ooool3ool000Cooooo2?oo0006ooooo`goo`00<Oooool7ool000cooooo1Ooo000mooooo`40
00000Oooool0000300000?ooooooo`0000;oo`006?ooool5ool000Oooooo0ooo0003ooooo`Goo`00
2Oooool3ool0013ooooo0ooo0005ooooo`Soo`000_ooool5ool00003oooooooo003oo`0000Goo`00
3_ooool7ool000Kooooo3Ooo000booooo`Ooo`003?ooool5ool003gooooo0@000001ooooo`0000<0
0000ooooooooool01_ooool3ool000gooooo0ooo00000oooooooo`00ool00003ool000Oooooo0ooo
0003ooooo`Goo`002?ooool5ool000kooooo1Ooo0004ooooo`Soo`000oooool3ool000Cooooo1Ooo
000>ooooo`Ooo`001_ooool:ool003Kooooo1_oo0006ooooo`?oo`000oooool5ool003gooooo0@00
0001ooooo`0000<00000ooooooooool01Oooool5ool000_ooooo2_oo0006ooooo`coo`002?ooool5
ool000kooooo1Ooo0005ooooo`Koo`001?ooool3ool000Cooooo1Ooo000?ooooo`Koo`001_ooool:
ool002?ooooo0ooo000Booooo`?oo`001_ooool5ool000?ooooo0ooo000nooooo`4000000Oooool0
000300000?oooooooooo00Gooooo2?oo0008ooooo`Goo`0000Coooooool00?oo003oo`001oooool;
ool000Wooooo1Ooo000>ooooo`Goo`001_ooool5ool000?ooooo1Ooo0004ooooo`?oo`004_ooool3
ool000Sooooo2Ooo0009ooooo`?oo`002_ooool3ool000Wooooo1Ooo000Jooooo`Goo`00A?ooool1
0000007ooooo00000`00003oooooooooo`05ooooo`Woo`001oooool5ool000Oooooo0ooo00000ooo
ooooo`00ool00009ool000[ooooo0ooo000@ooooo`?oo`001oooool5ool000?ooooo1Ooo000>oooo
o`Koo`005Oooool3ool000Wooooo1Ooo0002ooooo`?oo`000oooool5ool000Sooooo1Ooo0003oooo
o`?oo`005?ooool5ool004Cooooo0@000001ooooo`0000<00000ooooooooool01_ooool8ool000So
oooo0ooo0007ooooo`Goo`0000?oooooool00?oo00002?oo000Xooooo`?oo`001?ooool7ool000_o
oooo2?oo000Hooooo`Coo`001?ooool;ool000;ooooo1Ooo0008ooooo`Goo`000_ooool5ool001?o
oooo1Ooo0014ooooo`4000000Oooool0000300000?oooooooooo00Kooooo2?oo000Booooo`Ooo`00
00?oooooool00?oo00001Ooo000aooooo`Ooo`002_ooool8ool001Oooooo1_oo0003ooooo`_oo`00
0_ooool5ool000Cooooo0ooo0002ooooo`?oo`000_ooool6ool001Cooooo0ooo0015ooooo`400000
0Oooool0000300000?oooooooooo00Gooooo2?oo000Cooooo`goo`0000Coooooool00?oo003oo`00
2_ooool3ool001cooooo0ooo0005ooooo`Goo`002_ooool8ool001Oooooo1_oo0004ooooo`coo`00
00Coooooool00?oo003oo`001?ooool5ool000Kooooo1_oo001Looooo`4000000Oooool000030000
0?oooooooooo00Gooooo1Ooo0002ooooo`?oo`002_ooool3ool00005oooooooo003oo`00ool00?oo
ool01ooo00001Oooooooo`00ool00?oo003ooooo00Goo`002?ooool5ool001[ooooo1Ooo0004oooo
o`Goo`002oooool6ool001Sooooo1_oo0007ooooo`[oo`001oooool6ool000Gooooo1Ooo001Moooo
o`4000000Oooool0000300000?oooooooooo00Gooooo1Ooo00000oooooooo`00ool00003ool000So
oooo2Ooo0002ooooo`Goo`001Oooool5ool000Sooooo1Ooo000Jooooo`Goo`001?ooool5ool002[o
oooo1?oo0009ooooo`?oo`0000?oooooool00?oo00000ooo0006ooooo`Soo`001Oooool3ool005ko
oooo0@000001ooooo`0000<00000ooooooooool01_ooool3ool000;ooooo1Ooo0008ooooo`Woo`00
0oooool3ool000Kooooo1Ooo0008ooooo`Goo`002Oooool3ool000kooooo1Ooo0005ooooo`?oo`00
4_ooool4ool001kooooo0ooo0005ooooo`Goo`001_ooool9ool000Wooooo0ooo000?ooooo`?oo`00
Aoooool10000007ooooo00000`00003oooooooooo`0;ooooo`Goo`002?ooool9ool000gooooo0ooo
000:ooooo`?oo`002Oooool5ool000kooooo0ooo000Jooooo`Ooo`006_ooool6ool000Gooooo0ooo
0007ooooo`[oo`001oooool5ool000gooooo1Ooo0016ooooo`4000000Oooool0000300000?oooooo
oooo00cooooo0ooo0007ooooo`Koo`0000Coooooool00?oo003oo`009oooool5ool000[ooooo0ooo
000Nooooo`Soo`006?ooool7ool0013ooooo2Ooo0007ooooo`Goo`003Oooool5ool004Kooooo0@00
0001ooooo`0000<00000ooooooooool04?ooool3ool000;ooooo1Ooo000]ooooo`Goo`001oooool7
ool001gooooo2?oo000Hooooo`Ooo`005?ooool5ool000Oooooo1Ooo000=ooooo`Goo`00A_ooool1
0000007ooooo00000`00003oooooooooo`0<ooooo`Soo`0000?oooooool00?oo00000ooo000^oooo
o`?oo`001oooool:ool001cooooo1ooo000Hooooo`Woo`004oooool3ool000Wooooo0ooo000?oooo
o`?oo`00Aoooool10000007ooooo00000`00003oooooooooo`0;ooooo`Woo`0000?oooooool00?oo
00000ooo000Dooooo`Goo`000_ooool3ool001[ooooo2ooo000;ooooo`?oo`001?ooool3ool000Ko
oooo1_oo000Jooooo`?oo`0000?oooooool00?oo00000ooo001jooooo`4000000Oooool000030000
0?oooooooooo00[ooooo2_oo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool000?o
oooo0ooo0009ooooo`coo`006Oooool;ool000Oooooo2?oo0002ooooo`Goo`001Oooool5ool001?o
oooo0ooo0005ooooo`?oo`0000?oooooool00?oo00001?oo000[ooooo`?oo`00Boooool10000007o
oooo00000`00003oooooooooo`09ooooo`[oo`000_ooool:ool00003oooooooo003oo`0000?oo`00
2?ooool<ool001[ooooo0ooo0002ooooo`Goo`001_ooool9ool000;ooooo1Ooo0006ooooo`?oo`00
4oooool5ool000?ooooo3?oo000Yooooo`Goo`00B_ooool10000007ooooo00000`00003ooooooooo
o`09ooooo`Koo`001Oooool5ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00000ooo
00001?ooooooo`00ool00?oo0004ooooo`coo`008?ooool3ool000Oooooo2Ooo00000oooooooo`00
ool00004ool001cooooo1Ooo0003ooooo`coo`00:Oooool5ool004[ooooo0@000001ooooo`0000<0
0000ooooooooool02Oooool5ool000Gooooo1Ooo0002ooooo`Goo`0000?oooooool00?oo00002?oo
0004ooooo`Goo`000_ooool3ool002_ooooo2?oo0002ooooo`Koo`005?ooool3ool000Gooooo1Ooo
0003ooooo`coo`002_ooool3ool001cooooo1Ooo000:ooooo`?oo`00?Oooool10000007ooooo0000
0`00003oooooooooo`09ooooo`Goo`001Oooool5ool000?ooooo0ooo0003ooooo`?oo`0000?ooooo
ool00?oo00000ooo0003ooooo`?oo`002Oooool3ool002Sooooo0ooo0006ooooo`Koo`004oooool5
ool000Gooooo0ooo0005ooooo`[oo`002_ooool5ool001_ooooo2?oo0006ooooo`Goo`00??ooool1
0000007ooooo00000`00003oooooooooo`09ooooo`Goo`001Oooool5ool000Sooooo2_oo0002oooo
o`Goo`001oooool5ool0037ooooo1Ooo000Cooooo`Goo`001Oooool3ool000Oooooo1Ooo000=oooo
o`Goo`001Oooool3ool001Cooooo2?oo0005ooooo`Goo`00??ooool10000007ooooo00000`00003o
ooooooooo`05ooooo`?oo`0000?oooooool00?oo00000ooo0006ooooo`?oo`002?ooool:ool000?o
oooo2?oo0004ooooo`Goo`00<_ooool3ool001Cooooo1Ooo0004ooooo`Goo`001oooool5ool000co
oooo1Ooo0004ooooo`Goo`005Oooool6ool000Gooooo1_oo000kooooo`4000000Oooool000030000
0?oooooooooo00;ooooo1ooo00001?ooooooo`00ool00?oo000Booooo`Soo`001Oooool9ool000?o
oooo1Ooo000jooooo`?oo`001?ooool3ool000?ooooo1_oo0004ooooo`Koo`002?ooool5ool000co
oooo0ooo0005ooooo`Goo`004oooool;ool000?ooooo1_oo000jooooo`4000000Oooool000040000
0?ooooooooooooooo`Soo`002?ooool3ool000_ooooo2?oo0005ooooo`Woo`001?ooool3ool0017o
oooo0ooo000Vooooo`Koo`0000?oooooool00?oo00002Ooo0005ooooo`Ooo`002?ooool5ool001Co
oooo1Ooo000Booooo`goo`000oooool5ool003[ooooo0@000001ooooo`0000@00000oooooooooooo
oooo2?oo0007ooooo`Soo`001Oooool9ool000Kooooo2Ooo000Gooooo`Goo`004oooool3ool000oo
oooo4_oo00001Oooooooo`00ool00?oo003ooooo00Ooo`002?ooool8ool000Wooooo0ooo0006oooo
o`?oo`004_ooool8ool00003oooooooo003oo`0000?oo`000oooool5ool003[ooooo0@000001oooo
o`0000@00000oooooooooooooooo2?oo0007ooooo`_oo`0000?oooooool00?oo00002?oo0006oooo
o`Soo`006?ooool5ool001;ooooo1Ooo0007ooooo`Coo`000ooooolMool000[ooooo2?oo0007oooo
o`Goo`006Oooool8ool000;ooooo1Ooo0004ooooo`?oo`00>oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`Ooo`001ooooolFool00004oooooooo003oo`00ool000?ooooo0ooo000Loooo
o`Goo`004_ooool5ool000Kooooo1_oo0003ooooo`Koo`0000?oooooool00?oo00001ooo00000ooo
ooooo`00ool00008ool000kooooo1Ooo0007ooooo`Goo`006Oooool6ool000Gooooo0ooo0013oooo
o`4000000Oooool0000300000?oooooooooo00Gooooo0ooo0007oooooacoo`007?ooool3ool000?o
oooo0ooo000Cooooo`Ooo`001?ooool6ool000Gooooo0ooo0004ooooo`Ooo`0000?oooooool00?oo
00002?oo000>ooooo`Goo`001oooool6ool001?ooooo0ooo0002ooooo`Ooo`0000Coooooool00?oo
003oo`00A_ooool10000007ooooo00000`00003oooooooooo`0?oooooa;oo`0000?oooooool00?oo
00001ooo0003ooooo`?oo`005Oooool5ool001Wooooo1ooo0003ooooo`Soo`003?ooool5ool000;o
oooo2?oo000@ooooo`?oo`002Oooool5ool000Gooooo0ooo000:ooooo`Goo`000_ooool;ool004Go
oooo0@000001ooooo`0000<00000ooooooooool03oooool6ool000?ooooo0ooo0002ooooo`?oo`00
0_ooool9ool000;ooooo1Ooo000Dooooo`Koo`006_ooool5ool000Cooooo2?oo000<ooooo`Goo`00
0_ooool5ool001kooooo1Ooo0004ooooo`Goo`002Oooool5ool000;ooooo2ooo0015ooooo`400000
0Oooool0000300000?oooooooooo013ooooo1Ooo00001?ooooooo`00ool00?oo0009ooooo`Soo`00
0oooool5ool001Cooooo1ooo0004ooooo`?oo`004_ooool6ool000Kooooo1Ooo000=ooooo`Goo`00
00?oooooool00?oo00000ooo000Mooooo`Goo`001Oooool5ool000Oooooo1ooo00000oooooooo`00
ool0000:ool004Gooooo0@000001ooooo`0000<00000ooooooooool04Oooool3ool00003oooooooo
003oo`0000?oo`001_ooool6ool000?ooooo0ooo00000oooooooo`00ool00003ool001Gooooo1ooo
0002ooooo`Goo`004_ooool5ool000Kooooo1Ooo000=ooooo`Goo`0000?oooooool00?oo00000ooo
000Mooooo`Goo`000oooool8ool000Gooooo1ooo0002ooooo`coo`00AOooool10000007ooooo0000
0`00003oooooooooo`0Eooooo`Koo`001?ooool5ool000Cooooo1Ooo00001?ooooooo`00ool00?oo
000:ooooo`?oo`002_ooool7ool00003oooooooo003oo`0000Coo`004Oooool5ool000Oooooo0ooo
000:ooooo`?oo`0000?oooooool00?oo00000ooo0002ooooo`?oo`000oooool3ool001Sooooo1Ooo
0002ooooo`Woo`001?ooool8ool000;ooooo3Ooo0014ooooo`4000000Oooool0000300000?oooooo
oooo00?ooooo0ooo000?ooooo`Koo`001?ooool5ool000Cooooo1Ooo0008ooooo`?oo`000_ooool5
ool000[ooooo1_oo00000oooooooo`00ool00005ool0013ooooo1Ooo000Cooooo`Goo`0000Cooooo
ool00?oo003oo`002?ooool5ool001Oooooo1Ooo0002ooooo`Woo`001?ooool7ool000Cooooo3?oo
0014ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1Ooo0008ooooo`?oo`001?ooool5
ool000Cooooo1Ooo0004ooooo`Koo`001_ooool5ool00003oooooooo003oo`0000?oo`002oooool5
ool000;ooooo1_oo000@ooooo`Goo`004oooool5ool000cooooo1Ooo0005ooooo`?oo`003oooool5
ool000;ooooo2?oo0005ooooo`Ooo`001oooool3ool00003oooooooo003oo`0000?oo`00A?ooool1
0000007ooooo00000`00003oooooooooo`02ooooo`Goo`001oooool5ool000Cooooo0ooo0006oooo
o`?oo`001_ooool6ool000Gooooo1Ooo00000oooooooo`00ool00003ool000cooooo1Ooo0002oooo
o`Goo`004?ooool5ool000oooooo0ooo00000oooooooo`00ool00006ool000Cooooo0ooo0002oooo
o`Goo`001?ooool5ool000kooooo1Ooo0003ooooo`?oo`002_ooool5ool000gooooo0ooo0015oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1Ooo0007ooooo`Goo`004oooool3ool00003
oooooooo003oo`0000?oo`001Oooool5ool000;ooooo0ooo000=ooooo`Goo`000oooool3ool001;o
oooo0ooo000?ooooo`koo`000_ooool5ool000;ooooo0ooo0005ooooo`Goo`003?ooool6ool000?o
oooo1Ooo001Sooooo`4000000Oooool0000300000?oooooooooo00?ooooo0ooo0008ooooo`Goo`00
4_ooool:ool000Kooooo0ooo000Cooooo`Goo`00:_ooool>ool000;ooooo1ooo0008ooooo`Goo`00
2oooool5ool000;ooooo2?oo001Sooooo`4000000Oooool0000300000?oooooooooo00oooooo0ooo
000Cooooo`Goo`0000Coooooool00?oo003oo`005Oooool5ool000Cooooo0ooo0006ooooo`?oo`00
8_ooool>ool000;ooooo2?oo0008ooooo`?oo`003?ooool?ool000Wooooo0ooo001Gooooo`400000
0Oooool0000300000?oooooooooo02Gooooo1Ooo000Hooooo`Ooo`002oooool5ool002;ooooo3?oo
0004ooooo`Ooo`005oooool>ool000Wooooo1Ooo001Fooooo`4000000Oooool0000300000?oooooo
oooo02Kooooo0ooo000Iooooo`Ooo`002oooool5ool002Gooooo2?oo0007ooooo`Goo`006?ooool:
ool000cooooo1Ooo001Fooooo`4000000Oooool0000300000?oooooooooo04;ooooo1ooo000;oooo
o`Goo`009_ooool7ool000Sooooo0ooo000Kooooo`Ooo`003Oooool5ool005Kooooo0@000001oooo
o`0000<00000ooooooooool0@oooool5ool000gooooo0ooo000Xooooo`Goo`00:?ooool3ool0017o
oooo0ooo001Gooooo`4000000Oooool00?l0000080000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generate sample EM results with varying number of component \
densities\
\>", "Subsection"],

Cell[BoxData[
    \(\(results = Table[EMAll2[data1, k], {k, 2, 15}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of training data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 0.061154 0.00127323 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06115 -6 -4.5 ]
[-0.0125 .06115 0 4.5 ]
[-0.0125 .18848 -18 -4.5 ]
[-0.0125 .18848 0 4.5 ]
[-0.0125 .3158 -18 -4.5 ]
[-0.0125 .3158 0 4.5 ]
[-0.0125 .44312 -18 -4.5 ]
[-0.0125 .44312 0 4.5 ]
[-0.0125 .57045 -18 -4.5 ]
[-0.0125 .57045 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .06115 m
1 .06115 L
s
0 .18848 m
1 .18848 L
s
0 .3158 m
1 .3158 L
s
0 .44312 m
1 .44312 L
s
0 .57045 m
1 .57045 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06115 m
.00625 .06115 L
s
[(0)] -0.0125 .06115 1 0 Mshowa
0 .18848 m
.00625 .18848 L
s
[(100)] -0.0125 .18848 1 0 Mshowa
0 .3158 m
.00625 .3158 L
s
[(200)] -0.0125 .3158 1 0 Mshowa
0 .44312 m
.00625 .44312 L
s
[(300)] -0.0125 .44312 1 0 Mshowa
0 .57045 m
.00625 .57045 L
s
[(400)] -0.0125 .57045 1 0 Mshowa
.125 Mabswid
0 .08662 m
.00375 .08662 L
s
0 .11208 m
.00375 .11208 L
s
0 .13755 m
.00375 .13755 L
s
0 .16301 m
.00375 .16301 L
s
0 .21394 m
.00375 .21394 L
s
0 .23941 m
.00375 .23941 L
s
0 .26487 m
.00375 .26487 L
s
0 .29034 m
.00375 .29034 L
s
0 .34126 m
.00375 .34126 L
s
0 .36673 m
.00375 .36673 L
s
0 .39219 m
.00375 .39219 L
s
0 .41766 m
.00375 .41766 L
s
0 .46859 m
.00375 .46859 L
s
0 .49405 m
.00375 .49405 L
s
0 .51952 m
.00375 .51952 L
s
0 .54498 m
.00375 .54498 L
s
0 .03569 m
.00375 .03569 L
s
0 .01022 m
.00375 .01022 L
s
0 .59591 m
.00375 .59591 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06115 m
1 .06115 L
s
.99375 .18848 m
1 .18848 L
s
.99375 .3158 m
1 .3158 L
s
.99375 .44312 m
1 .44312 L
s
.99375 .57045 m
1 .57045 L
s
.125 Mabswid
.99625 .08662 m
1 .08662 L
s
.99625 .11208 m
1 .11208 L
s
.99625 .13755 m
1 .13755 L
s
.99625 .16301 m
1 .16301 L
s
.99625 .21394 m
1 .21394 L
s
.99625 .23941 m
1 .23941 L
s
.99625 .26487 m
1 .26487 L
s
.99625 .29034 m
1 .29034 L
s
.99625 .34126 m
1 .34126 L
s
.99625 .36673 m
1 .36673 L
s
.99625 .39219 m
1 .39219 L
s
.99625 .41766 m
1 .41766 L
s
.99625 .46859 m
1 .46859 L
s
.99625 .49405 m
1 .49405 L
s
.99625 .51952 m
1 .51952 L
s
.99625 .54498 m
1 .54498 L
s
.99625 .03569 m
1 .03569 L
s
.99625 .01022 m
1 .01022 L
s
.99625 .59591 m
1 .59591 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .19098 L
.17033 .48784 L
.24359 .50168 L
.31685 .52767 L
.39011 .53737 L
.46337 .59116 L
.53663 .55044 L
.60989 .57173 L
.68315 .57778 L
.75641 .60332 L
.82967 .58624 L
.90293 .5924 L
.97619 .587 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .19098 Mdot
.17033 .48784 Mdot
.24359 .50168 Mdot
.31685 .52767 Mdot
.39011 .53737 Mdot
.46337 .59116 Mdot
.53663 .55044 Mdot
.60989 .57173 Mdot
.68315 .57778 Mdot
.75641 .60332 Mdot
.82967 .58624 Mdot
.90293 .5924 Mdot
.97619 .587 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0002Cooooo0ol0000Sooooo`?o00009?ooool3o`00027ooooo0ol00004oooo
o`;o00007_ooool3o`0000;ooooo1Ol0000Mooooo`?o00001?ooool3o`0001Kooooo000Iooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooo
ooooo`0Rooooo`Go00008_ooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooooooo
ooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`006oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0002?ooooo1?l0
000Tooooo`?o00008_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000002?o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`006?ooool01Ol0003ooooooooooooooooo000002Cooooo0_l0
000Tooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000
1?ooool01?l0003oooooooooool0000Mooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01gooooo0_l00005ooooo`;o00005oooool001Wooooo0ol0000Vooooo`03o`000?oooooooooo02?o
oooo0_l0000Tooooo`?o00008_ooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003o
ooooooooo`02ooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eooooo`03
00000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`02ooooo`?oo`009Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool10000007ooooo000E
ooooo`0400000?l0003oooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00@00000
oooooooooooooooo1Ooo000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00@00000oooooooooooooooo1Ooo
000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool00_ooool3ool002Gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003o0000ooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000E
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool08Oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool08Oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo00Oooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000>ooooo`;o0000
1Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`003Ooo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
8?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0
200007l00`000000001o0000O`3j0000O`7o00000@000001ooooo`003Oooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool07oooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000=ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02Oooool00`00003ooooo
ooooo`0Nooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool000gooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`09ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`003_ooool2o`0000Gooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool02_ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?oo
ool02oooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003ooooo
ooooo`0;ooooo`0300000?oooooooooo01cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0=oooo
o`0300000?oooooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0=ooooo`03
00000?oooooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0>ooooo`0300000?oo
oooooooo01Wooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool06Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool06?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool06?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool0
5oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool05ooo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool05oooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?l0003ooooo017ooooo00<00000ooooooooool05_ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00
004000000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Fooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Dooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01Gooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Go
oooo00<00000o`000?ooool04oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`00
5Oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Dooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Eooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Eooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Coooooo`000?l0
003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01Kooooo00<00000oooo
ooooool04Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01Gooooo0ooo000B
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0500007l5ool00>`0001o0Ol0
00010000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01Cooooo1Ooo000Aooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool05?ooool5ool0017ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
00?oooooo`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool05Oooool3ool001;ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`000_ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool06?ooool00`00003o
ooooooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool06?ooool00`00003ooooo
ooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool06?ooool00`00003ooooooooo
o`0?ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool06?ooool00`00003oooooooooo`0?
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0E
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo
00kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00ko
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00kooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00kooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo00gooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo00gooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003o0000ooooo`0Jooooo`0300000?oooooooooo00gooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool03Oooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool03Oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool03?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo01_ooooo00<00000ooooooooool03?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo01_ooooo00<00000ooooooooool03?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?l0003ooooo01_ooooo00<00000ooooooooool03?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool07?ooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool07?ooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool07?ooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
7Oooool00`00003oooooooooo`0:ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0:ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool07Oooool0
0`00003oooooooooo`0:ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Moooo
o`0300000?oooooooooo00[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Nooooo`03
00000?oooooooooo00Wooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Nooooo`030000
0?oooooooooo00Wooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`001Ol00003ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool07_ooool00`00003oooooooooo`09ooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00005ooooool0003o
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool07_ooool00`00003oooooooooo`09ooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool07oooool00`00003oooooooooo`08ooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00`00003o00000000O`0O0000O`030000000007l0001o0><0001o0Ol00001
0000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01oooooo00<00000ooooooooool0
2?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01oooooo00<00000oooo
ooooool02?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00Gooooo00<00000ooooooooool08?ooool00`00003oooooooooo`07ooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Go
oooo00<00000ooooooooool08?ooool00`00003oooooooooo`07ooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo
00<00000ooooooooool08?ooool00`00003oooooooooo`07ooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool08?ooool00`00003oooooooooo`07ooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
o`000?ooool08Oooool00`00003oooooooooo`06ooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00
003oooooooooo`0Qooooo`0300000?oooooooooo00Kooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0Qooooo`0300000?oooooooooo00Kooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0Qooooo`0300000?oooooooooo00Kooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0Qooooo`0300000?oooooooooo00Kooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0R
ooooo`0300000?oooooooooo00Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Roooo
o`0300000?oooooooooo00Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Rooooo`03
00000?oooooooooo00Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo02;ooooo
00<00000ooooooooool01Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02?ooooo00<0
0000ooooooooool01?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02?ooooo00<00000
ooooooooool01?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02?ooooo00<00000oooo
ooooool01?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02?ooooo00<00000oooooooo
ool01?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo02Cooooo00<00000ooooooooool0
0oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool09?ooool00`00003ooooooooo
o`03ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool09?ooool00`00003oooooooooo`03
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool09?ooool00`00003oooooooooo`03oooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000ooooooooool09Oooool00`00003oooooooooo`02ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000ooooooooool09Oooool00`00003oooooooooo`02ooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000ooooooooool09Oooool00`00003oooooooooo`02ooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001Gooooo00<00000o`000?ooool09Oooool00`00003oooooooooo`02ooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`0Vooooo`0500000?ooooooooooooooo`0007l09_ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Vooooo`0500000?ooooooooooooooo`0007l09_ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Voooo
o`0500000?ooooooooooooooo`0007l09_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005
ooooo`0300000?oooooooooo02Kooooo00D00000oooooooooooooooo0000O`0Vooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00001Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo02Oooooo00@00000ooooooooool0001o9_ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`001?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0W
ooooo`0400000?oooooooooo0000ObKooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003o00000000O`0W0000O`030000000007l0001o0=/0001o
0Ol000010000007ooooo0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo02Oooooo00@00000oooooooo
ool0001o9_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`0Wooooo`0400000?oooooooooo0000ObKooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00004ooooool0
003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Xooooo`030000
0?ooool0001o02Kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000ooooooooool0:?ooool00`00003ooooo0000O`0Vooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo02Sooooo00<00000ooooo`0007l09_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Xooooo`0300000?ooool0001o
02Kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Go
oooo00<00000o`000?ooool0:Oooool00`000000001oooooo`0Uooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0
:Oooool00`000000001oooooo`0Uooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo02Wooooo00<000000000Ooooool09Ooo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Yooooo`?oo`009Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Xooooo`Goo`009?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0Xooooo`Goo`0000<00000ooooooooool08Oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Xooooo`Goo`00
00?ooooo0000000000001@000007ooooo`?oo`004_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo02Wooooo0ooo
0009ooooo`H000001Ooo000Aooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool03_ooool5
ool0017ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0>ooooo`Goo`000`00000>oooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo02[ooooo00<0001oooooooooool03oooool3ool000Cooooo0`00000;ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo02[ooooo00<0001oooooooooool06Oooool3000000Sooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_oo
ool00`0007ooooooooooo`0Looooo`8000001_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Zooooo`030000Oooooooo
oooo01kooooo0`000002ooooo`?oo`009Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo027ooooo00<00000ool0
0?oo00000ooo000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0Zooooo`030000Oooooooooooo02;ooooo1Ooo00000`00003oooooooooo`0Qooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000
Oooooooooooo02;ooooo1Ooo00000oooool0000000000005000000Oooooo0ooo000Booooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooo
oooooooo02?ooooo0ooo0009ooooo`H000001Ooo000Aooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool03_ooool5ool0017ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0>oooo
o`Goo`004Oooool00`0007ooooooooooo`0?ooooo`?oo`004_ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?l0003ooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0?ooooo`?o
o`0000?ooooo0000000000003oooool00`0007ooooooooooo`0>ooooo`Goo`004Oooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`000040
00000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Gooooo00<00000ooooooooool03?ooool00`0007ooooooooooo`0>ooooo`Goo`00
4Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`0300000?oooooooooo00_ooooo00<0001oooooooooool03Ooo
ool00`00003oo`00ool00003ool000<000003_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Gooooo`8000002oooool0
0`0007ooooooooooo`0<ooooo`0300000?oooooooooo00?oo`001?ooool3000000_ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`000_ooool3o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Zoooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool06Oooool00`00003oooooooooo`08oooo
o`030000Oooooooooooo00[ooooo0P00000=ooooo`@000001oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0003ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01[ooooo0P000008ooooo`030000Oooooooooooo00Sooooo0P00000Cooooo`<000000oooool3
ool002Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
00Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01cooooo00<0
0000ooooooooool01Oooool00`0007ooooooooooo`06ooooo`8000006?ooool2000000Goo`009?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000o`00000007l0L@0007l2000000d0001o00<000000000O`0007l06P0007l5ool000<0
0000300007l3ool00540001o0Ol000010000007ooooo00001?oooooo0000ooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Z
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool07oooool00`00003oooooooooo`02
ooooo`030000Oooooooooooo00?ooooo0P00000Mooooo`Goo`000oooool9000000;ooooo1Ooo000A
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0002oooo
o`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo023ooooo00D0
0000oooooooooooooooo0000O`03ooooo`8000008?ooool3ool000gooooo0P000005ool0017ooooo
00<0001oooooooooool03oooool3ool001;ooooo00<0001oooooooooool03oooool3ool000Cooooo
0@000001ooooo`000oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo027ooooo0P00
0003ool00003ooooo`00003ooooo02;ooooo00<0001oooooooooool03_ooool5ool000<000003_oo
ool00`0007ooooooooooo`0>ooooo`Goo`004Oooool00`0007ooooooooooo`0>ooooo`Goo`000ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Rooooo`Goo`009?ooool00`0007ooooooooooo`0?ooooo`?oo`001?ooool3
000000_ooooo00<0001oooooooooool03_ooool5ool000P000001oooool3ool000Wooooo1`000005
ool000?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool08_ooool5ool002Cooooo00<0001oooooooooool06Oooool40000
00Oooooo00<0001oooooooooool02Oooool5000000Goo`002?ooool6000000Goo`0020000007oooo
o`Goo`000oooool10000007ooooo000Eooooo`0300000?l0003ooooo02[ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Rooooo`Goo`009?ooool00`0007ooooooooooo`0Mooooo`<0
00000oooool3ool000Gooooo1@000006ooooo`?oo`003oooool5ool0013ooooo0ooo0003ooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool08oooool3ool002Gooooo00<0001oooooooooool08?ooool2000000Goo`00
1000000Mooooo`Goo`005oooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool08_ooool5ool002;ooooo0ooo000Hooooo`4000000Oooool001Gooooo00<00000
ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Rooooo`Goo`009?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Soooo
o`?oo`009Oooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool10000007ooooo000Eooooool000002`000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.579071, -85.2038, \
0.0514022, 2.95762}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of test data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 0.131321 0.00132043 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13132 -6 -4.5 ]
[-0.0125 .13132 0 4.5 ]
[-0.0125 .26336 -18 -4.5 ]
[-0.0125 .26336 0 4.5 ]
[-0.0125 .39541 -18 -4.5 ]
[-0.0125 .39541 0 4.5 ]
[-0.0125 .52745 -18 -4.5 ]
[-0.0125 .52745 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .13132 m
1 .13132 L
s
0 .26336 m
1 .26336 L
s
0 .39541 m
1 .39541 L
s
0 .52745 m
1 .52745 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13132 m
.00625 .13132 L
s
[(0)] -0.0125 .13132 1 0 Mshowa
0 .26336 m
.00625 .26336 L
s
[(100)] -0.0125 .26336 1 0 Mshowa
0 .39541 m
.00625 .39541 L
s
[(200)] -0.0125 .39541 1 0 Mshowa
0 .52745 m
.00625 .52745 L
s
[(300)] -0.0125 .52745 1 0 Mshowa
.125 Mabswid
0 .02569 m
.00375 .02569 L
s
0 .0521 m
.00375 .0521 L
s
0 .0785 m
.00375 .0785 L
s
0 .10491 m
.00375 .10491 L
s
0 .15773 m
.00375 .15773 L
s
0 .18414 m
.00375 .18414 L
s
0 .21055 m
.00375 .21055 L
s
0 .23696 m
.00375 .23696 L
s
0 .28977 m
.00375 .28977 L
s
0 .31618 m
.00375 .31618 L
s
0 .34259 m
.00375 .34259 L
s
0 .369 m
.00375 .369 L
s
0 .42181 m
.00375 .42181 L
s
0 .44822 m
.00375 .44822 L
s
0 .47463 m
.00375 .47463 L
s
0 .50104 m
.00375 .50104 L
s
0 .55386 m
.00375 .55386 L
s
0 .58027 m
.00375 .58027 L
s
0 .60667 m
.00375 .60667 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .13132 m
1 .13132 L
s
.99375 .26336 m
1 .26336 L
s
.99375 .39541 m
1 .39541 L
s
.99375 .52745 m
1 .52745 L
s
.125 Mabswid
.99625 .02569 m
1 .02569 L
s
.99625 .0521 m
1 .0521 L
s
.99625 .0785 m
1 .0785 L
s
.99625 .10491 m
1 .10491 L
s
.99625 .15773 m
1 .15773 L
s
.99625 .18414 m
1 .18414 L
s
.99625 .21055 m
1 .21055 L
s
.99625 .23696 m
1 .23696 L
s
.99625 .28977 m
1 .28977 L
s
.99625 .31618 m
1 .31618 L
s
.99625 .34259 m
1 .34259 L
s
.99625 .369 m
1 .369 L
s
.99625 .42181 m
1 .42181 L
s
.99625 .44822 m
1 .44822 L
s
.99625 .47463 m
1 .47463 L
s
.99625 .50104 m
1 .50104 L
s
.99625 .55386 m
1 .55386 L
s
.99625 .58027 m
1 .58027 L
s
.99625 .60667 m
1 .60667 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .18166 L
.17033 .53422 L
.24359 .52424 L
.31685 .55672 L
.39011 .55551 L
.46337 .59038 L
.53663 .55213 L
.60989 .57815 L
.68315 .58604 L
.75641 .60332 L
.82967 .57732 L
.90293 .59153 L
.97619 .58828 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .18166 Mdot
.17033 .53422 Mdot
.24359 .52424 Mdot
.31685 .55672 Mdot
.39011 .55551 Mdot
.46337 .59038 Mdot
.53663 .55213 Mdot
.60989 .57815 Mdot
.68315 .58604 Mdot
.75641 .60332 Mdot
.82967 .57732 Mdot
.90293 .59153 Mdot
.97619 .58828 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0002Cooooo0ol0000Sooooo`?o00009?ooool3o`00027ooooo0ol00004oooo
o`;o00007_ooool3o`0000;ooooo1Ol0000Mooooo`?o00001?ooool3o`0001Kooooo000Iooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooo
ooooo`0Rooooo`Go00008_ooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooooooo
ooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`006oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0002?ooooo1?l0
000Tooooo`?o00008_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000002?o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`006?ooool01Ol0003ooooooooooooooooo000002Cooooo0_l0
000Tooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000
1?ooool01?l0003oooooooooool0000Mooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01gooooo0_l00005ooooo`;o00005oooool001Wooooo0ol0000Vooooo`03o`000?oooooooooo02?o
oooo0_l0000Tooooo`?o00008_ooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003o
ooooooooo`02ooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eooooo`03
00000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`02ooooo`?oo`009Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool10000007ooooo000E
ooooo`0400000?ooooooooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0400000?oooooo
ooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0400000?ooooooooooooooo`Goo`009?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo00;ooooo0ooo000Uooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
01Gooooo00<00000o`000?ooool01?ooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001oooo
o`005Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`06ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000
ooooo`07ooooo`0300000?oooooooooo023ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00Wooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Wo
oooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool07Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool07Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00_ooooo00<00000
ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool02oooool00`00
003oooooooooo`0Looooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`0Looooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool00`00003ooooo
ooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0J
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Joooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000o`000?ooool03_ooool00`00003oooooooooo`0Iooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo01Oooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`003_ooool2o`0000Gooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Gooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0@ooooo`03
00000?oooooooooo01Oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03
00000?l00000001o0140001o00<000000000O`0007l0l@0007l1o`00004000000Oooool000gooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Ko
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01;o
oooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000kooooo
0_l00005ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?l0003ooooo01Cooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Go
oooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo
00<00000ooooooooool05Oooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool05Oooool00`00003oooooooooo`0Booooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool05Oooool3ool001;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Doooo
o`Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Cooooo1Ooo000Aooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000o`000?ooool05?ooool5ool0017ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo
000Eooooo`0300000?oooooooooo01Gooooo0ooo000Booooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool06?ooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool06?ooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool06?ooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
6?ooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool06?oo
ool00`00003oooooooooo`0?ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool06Oooool0
0`00003oooooooooo`0>ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Ioooo
o`0300000?oooooooooo00kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`03
00000?oooooooooo00kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`030000
0?oooooooooo00kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Iooooo`0300000?oo
oooooooo00kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Jooooo`0300000?oooooo
oooo00gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo
00gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Jooooo`0300000?oooooooooo00go
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Go
oooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool0
3Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool03Ooo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool03?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool03?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000
007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000oooo
ooooool06oooool00`00003oooooooooo`0<ooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool06oooool00`00003oooooooooo`0<ooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000o`00000007l06`0007l00`000000001o0000O`3W0000O`7o00000@000001ooooo`000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo00_ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`000_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo00_ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
00?oooooo`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;o
oooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01co
oooo00<00000ooooooooool02oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01cooooo
00<00000ooooooooool02oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01gooooo00<0
0000ooooooooool02_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo01gooooo00<00000
ooooooooool02_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`0:ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool07Oooool00`00003o
ooooooooo`0:ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0:ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool07_ooool00`00003ooooooooo
o`09ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool07_ooool00`00003oooooooooo`09
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool07_ooool00`00003oooooooooo`09oooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000o`000?ooool07_ooool00`00003oooooooooo`09ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00Wooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Sooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003o0000ooooo`0Pooooo`0300000?oooooooooo00Oooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000E
ooooo`0300000?oooooooooo023ooooo00<00000ooooooooool01oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo023ooooo00<00000ooooooooool01oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo023ooooo00<00000ooooooooool01oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo023ooooo00<00000ooooooooool01oooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo027ooooo00<00000ooooooooool01_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo027ooooo00<00000ooooooooool01_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo
027ooooo00<00000ooooooooool01_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000oooooooo
ool08Oooool00`00003oooooooooo`06ooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
8Oooool00`00003oooooooooo`06ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool08_oo
ool00`00003oooooooooo`05ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool08_ooool0
0`00003oooooooooo`05ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool000Go00000oooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo02;ooooo00<00000ooooooooool01Oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00001Ooooooo
0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo02;ooooo00<00000ooooooooool01Oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0002
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?l00000001o0280001o00<000000000O`0007l0h00007l1o`0000400000
0Oooool000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo00Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Sooooo`0300000?oooooo
oooo00Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Sooooo`030000
0?oooooooooo00Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool00oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?l0003ooooo02Cooooo00<00000ooooooooool00oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Go
oooo00<00000ooooooooool09?ooool00`00003oooooooooo`03ooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo
00<00000ooooooooool09?ooool00`00003oooooooooo`03ooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<0
0000ooooooooool09?ooool00`00003oooooooooo`03ooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool09Oooool00`00003oooooooooo`02ooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool09Oooool00`00003oooooooooo`02ooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool09Oooool00`00003oooooooooo`02ooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool0
9Oooool00`00003oooooooooo`02ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003ooooooooo
o`0Uooooo`0300000?oooooooooo00;ooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0V
ooooo`0500000?ooooooooooooooo`0007l09_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Vooooo`0500000?oooooo
ooooooooo`0007l09_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Vooooo`0500000?ooooooooooooooo`0007l09_oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Vooooo`0500000?ooooooooooooooo`0007l09_ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0V
ooooo`0500000?ooooooooooooooo`0007l09_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Wooooo`0400000?oooooo
oooo0000ObKooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`0Wooooo`0400000?oooooooooo0000ObKooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool09oooool01000003oooooooooo`0007lVooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02Oooooo00@00000
ooooooooool0001o9_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Wooooo`0400000?oooooooooo0000ObKooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool0:?ooool00`00003ooooo0000O`0Vooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02Sooooo00<00000oooo
o`0007l09_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003o0000ooooo`0Xooooo`0300000?ooool0001o02Kooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003ooooo
ooooo`0Xooooo`0300000?ooool0001o02Kooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:?ooool00`00003ooooo0000
O`0Vooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo02Wooooo00<000000000Ooooool09Oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Yoooo
o`030000000007oooooo013ooooo0ooo000Booooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00Gooooo00<00000ooooooooool0:Oooool00`000000001oooooo`0?ooooo`Goo`004Oooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Yooooo`030000000007oooooo00oooooo1Ooo000Aooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`030000
0?l00000001o02T0001o0ooo00080000O`L000001Ooo000200000<<0001o0Ol000010000007ooooo
0002ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool0:?ooool5ool000L000002?ooool3ool000?ooooo0P00000=ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`0300000?oooooooooo02Sooooo1Ooo000Gooooo`8000002oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`0Xooooo`Goo`006Oooool3000000Sooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Ooo
ool00`00003oooooooooo`0Yooooo`?oo`007Oooool2000000Kooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool0
0`0007ooooooooooo`0Nooooo`8000001?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo00oooooo0ooo000Booooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`00
07ooooooooooo`0Pooooo`80000000Coooooool00?oo003oo`004?ooool3ool001;ooooo00<0001o
ooooooooool03_ooool5ool0017ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Zoooo
o`030000Oooooooooooo02;ooooo1Ooo000>ooooo`Goo`004Oooool00`0007ooooooooooo`0>oooo
o`Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oo
ooooooooo`0Rooooo`Goo`003P000005ool0017ooooo00<0001oooooooooool03Oooool00`00003o
o`00ool00003ool0008000003oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo
00<0001oooooooooool08_ooool5ool000kooooo1Ooo00000`00003oooooooooo`0>ooooo`030000
Oooooooooooo00_ooooo0P000002ooooo`?oo`000oooool3000000cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02?ooooo0ooo000@ooooo`?oo`000_oo
ool3000000gooooo00<0001oooooooooool02Oooool2000000gooooo0`000009ooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Oooooo0P00000;ooooo`030000Oooooooooooo00Oooooo0P00000Booooo`<000001_ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Iooooo`8000002Oooool00`0007ooooooooooo`06ooooo`0300000?oooooooooo
01Gooooo0`000002ooooo`?oo`009Oooool00`0007ooooooooooo`0?ooooo`?oo`004_ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01_ooooo0P000007ooooo`030000Oooooooooooo00Co
oooo0P00000Kooooo`0300000?oo003oo`0000?oo`009?ooool00`0007ooooooooooo`0>ooooo`Go
o`0000<00000ooooooooool03_ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo
00<00000o`000?ooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01gooooo
0P000005ooooo`030000Oooooooooooo00;ooooo0P00000Nooooo`Goo`000`00000<ooooo`?oo`00
4_ooool00`0007ooooooooooo`0<ooooo`8000001Ooo00000oooool0000000000003000000_ooooo
00<0001oooooooooool03oooool3ool000?ooooo0Ol000010000007ooooo000Eooooo`0300000?oo
oooooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Oooooo`<0000000Go
ooooool00?oo003oo`00ooooo`020000023ooooo1Ooo0003ooooo`T000000_ooool5ool0017ooooo
00<0001oooooooooool02Oooool3000000;ooooo1Ooo0006ooooo`D000001?ooool3ool0013ooooo
1Ooo0003ooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02;ooooo1Ooo000Sooooo`?oo`003Oooool2000000Goo`0000<0
0000ooooooooool03_ooool00`0007ooooooooooo`06ooooo`<000001_ooool3ool000cooooo0`00
0005ool000Sooooo1`000005ool000?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Z
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool08_ooool5ool002Cooooo00<0001o
ooooooooool03_ooool5ool00003ooooo`000000000000<000002oooool00`0007ooooooooooo`04
ooooo`8000006oooool5ool000P000001oooool5ool000?ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool08_ooool5ool0
02Cooooo00<0001oooooooooool03oooool3ool000Oooooo1@000005ooooo`?oo`000_ooool30000
01gooooo1Ooo000@ooooo`?oo`001?ooool10000007ooooo000Eooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Sooooo`?oo`009Oooool00`0007oo
ooooooooo`0Nooooo`@000001Ooo00000`00003oooooooooo`0Oooooo`?oo`006?ooool10000007o
oooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool08_ooool5ool002Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo02[ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool08_ooool5ool002Cooooo00<0001oooooooooool05Oooool1o`00004000000Ooo
ool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Sooooo`?oo`009Oooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool10000
007ooooo000Eooooool000002`000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.579071, -135.298, \
0.0514022, 2.8519}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the number of Gaussians (anti-E-shaped region)", "Section"],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points for training and test data", "Subsubsection"],

Cell[BoxData[{
    \(\(n1 = 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2 = 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ region2Data[n1];\)\), "\n", 
    \(\(data2\  = \ region2Data[n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize training data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.21327 .25758 Mdot
.60582 .31332 Mdot
.67236 .28642 Mdot
.51277 .30103 Mdot
.48517 .30914 Mdot
.38492 .211 Mdot
.91857 .77743 Mdot
.23011 .38797 Mdot
.54155 .63378 Mdot
.71948 .2991 Mdot
.32059 .36676 Mdot
.92587 .16557 Mdot
.70556 .7678 Mdot
.5303 .39143 Mdot
.92417 .58138 Mdot
.77224 .74978 Mdot
.29665 .63801 Mdot
.53293 .34567 Mdot
.81756 .56807 Mdot
.88359 .97688 Mdot
.72632 .27393 Mdot
.41073 .61029 Mdot
.93713 .40574 Mdot
.81765 .14671 Mdot
.93559 .55864 Mdot
.60287 .33653 Mdot
.90859 .90798 Mdot
.49831 .72997 Mdot
.55138 .33403 Mdot
.85211 .5741 Mdot
.80179 .09839 Mdot
.65244 .38289 Mdot
.2276 .30465 Mdot
.51514 .63131 Mdot
.58537 .23866 Mdot
.73014 .75469 Mdot
.45888 .21246 Mdot
.45326 .61785 Mdot
.81873 .68616 Mdot
.78607 .64455 Mdot
.83239 .89687 Mdot
.67989 .32783 Mdot
.63357 .33702 Mdot
.80504 .64106 Mdot
.50817 .73919 Mdot
.4336 .75786 Mdot
.31055 .67142 Mdot
.62085 .3534 Mdot
.97748 .02618 Mdot
.73883 .60766 Mdot
.55376 .37086 Mdot
.36294 .3022 Mdot
.98801 .16221 Mdot
.50099 .61713 Mdot
.72667 .68222 Mdot
.56643 .70639 Mdot
.78669 .2233 Mdot
.98896 .63005 Mdot
.73193 .23532 Mdot
.24075 .60839 Mdot
.27428 .78562 Mdot
.49475 .65567 Mdot
.23057 .75255 Mdot
.37361 .6763 Mdot
.52272 .67331 Mdot
.82386 .52141 Mdot
.39448 .70795 Mdot
.84713 .48375 Mdot
.76092 .33507 Mdot
.95393 .41396 Mdot
.56925 .6962 Mdot
.21338 .37694 Mdot
.87221 .5664 Mdot
.36288 .30272 Mdot
.79454 .91279 Mdot
.80001 .48502 Mdot
.56576 .64182 Mdot
.36219 .27469 Mdot
.59194 .31066 Mdot
.93067 .89451 Mdot
.75084 .69322 Mdot
.94103 .21801 Mdot
.93368 .35728 Mdot
.25622 .27893 Mdot
.80449 .36279 Mdot
.91051 .49453 Mdot
.88763 .20283 Mdot
.559 .70756 Mdot
.55194 .73541 Mdot
.42402 .76586 Mdot
.33761 .61178 Mdot
.33082 .78689 Mdot
.26752 .32909 Mdot
.76591 .78895 Mdot
.76577 .39338 Mdot
.50355 .76472 Mdot
.71657 .6638 Mdot
.87035 .76427 Mdot
.79891 .50903 Mdot
.26723 .32671 Mdot
.64114 .2821 Mdot
.86058 .33292 Mdot
.38887 .78654 Mdot
.57653 .30259 Mdot
.97977 .30587 Mdot
.86277 .74381 Mdot
.30735 .60871 Mdot
.5167 .66755 Mdot
.50335 .73124 Mdot
.90109 .01262 Mdot
.21004 .61714 Mdot
.44287 .33659 Mdot
.81097 .20578 Mdot
.36299 .30276 Mdot
.39272 .28779 Mdot
.84983 .56171 Mdot
.48182 .28497 Mdot
.94148 .66432 Mdot
.8101 .50074 Mdot
.21086 .71901 Mdot
.48243 .62741 Mdot
.75819 .39223 Mdot
.20931 .40122 Mdot
.76698 .7408 Mdot
.25802 .7271 Mdot
.94707 .24986 Mdot
.47445 .61264 Mdot
.28896 .61585 Mdot
.80298 .19102 Mdot
.87416 .52638 Mdot
.96033 .42829 Mdot
.87127 .8605 Mdot
.82411 .85241 Mdot
.54495 .24636 Mdot
.72603 .38458 Mdot
.66099 .71018 Mdot
.3322 .71156 Mdot
.48473 .73982 Mdot
.32185 .25366 Mdot
.48793 .39145 Mdot
.92285 .98579 Mdot
.93317 .15489 Mdot
.20663 .61102 Mdot
.93998 .71353 Mdot
.74686 .59937 Mdot
.43482 .35551 Mdot
.59376 .78489 Mdot
.93709 .95426 Mdot
.6611 .78929 Mdot
.72193 .38409 Mdot
.77215 .66075 Mdot
.89968 .80856 Mdot
.83445 .46229 Mdot
.59047 .70587 Mdot
.2505 .6676 Mdot
.64358 .7418 Mdot
.90793 .54853 Mdot
.65588 .77596 Mdot
.90214 .5051 Mdot
.86664 .36894 Mdot
.95672 .26898 Mdot
.97126 .18303 Mdot
.66651 .69392 Mdot
.88941 .22382 Mdot
.43953 .2674 Mdot
.92289 .94503 Mdot
.9372 .37961 Mdot
.87422 .20601 Mdot
.44401 .76203 Mdot
.98026 .13136 Mdot
.91267 .17558 Mdot
.28352 .22641 Mdot
.4974 .23052 Mdot
.93265 .09305 Mdot
.27771 .64381 Mdot
.88668 .31751 Mdot
.92815 .66955 Mdot
.89662 .19596 Mdot
.77041 .25673 Mdot
.97415 .03019 Mdot
.48656 .78986 Mdot
.43317 .34097 Mdot
.28633 .30326 Mdot
.91478 .43028 Mdot
.22779 .7656 Mdot
.30321 .34512 Mdot
.94458 .79307 Mdot
.27511 .23235 Mdot
.6487 .64094 Mdot
.35475 .29294 Mdot
.43168 .31829 Mdot
.82375 .18221 Mdot
.81879 .86467 Mdot
.4148 .64413 Mdot
.40889 .25442 Mdot
.60113 .26808 Mdot
.97143 .32524 Mdot
.91737 .44396 Mdot
.53519 .32168 Mdot
.25348 .61706 Mdot
.93717 .22985 Mdot
.95593 .89481 Mdot
.63656 .74614 Mdot
.97118 .75671 Mdot
.54232 .30094 Mdot
.26948 .34338 Mdot
.86233 .85424 Mdot
.22324 .27861 Mdot
.86954 .86267 Mdot
.2466 .78246 Mdot
.87394 .57375 Mdot
.64145 .71137 Mdot
.28143 .69202 Mdot
.7886 .27609 Mdot
.90926 .40362 Mdot
.89609 .13872 Mdot
.88354 .52794 Mdot
.24006 .27167 Mdot
.39245 .28155 Mdot
.49911 .7438 Mdot
.43964 .70241 Mdot
.57531 .66979 Mdot
.93089 .38137 Mdot
.82249 .13174 Mdot
.90414 .12525 Mdot
.99017 .72346 Mdot
.88718 .45008 Mdot
.89176 .05622 Mdot
.32168 .77049 Mdot
.95106 .66505 Mdot
.26897 .69266 Mdot
.5238 .71864 Mdot
.62682 .27836 Mdot
.21637 .66148 Mdot
.48553 .3465 Mdot
.84891 .07795 Mdot
.26402 .75119 Mdot
.49779 .76466 Mdot
.95985 .96154 Mdot
.40025 .39487 Mdot
.89001 .91479 Mdot
.69715 .38564 Mdot
.78679 .62015 Mdot
.56349 .38519 Mdot
.88698 .69555 Mdot
.22407 .7824 Mdot
.49171 .68909 Mdot
.86072 .78103 Mdot
.87704 .51342 Mdot
.31573 .20664 Mdot
.84814 .91108 Mdot
.36624 .23179 Mdot
.60637 .22777 Mdot
.47939 .70857 Mdot
.84031 .3835 Mdot
.83506 .72262 Mdot
.97711 .80173 Mdot
.96922 .94347 Mdot
.97545 .29084 Mdot
.49454 .30974 Mdot
.31316 .37319 Mdot
.83705 .93884 Mdot
.68267 .78364 Mdot
.85802 .98556 Mdot
.55613 .63143 Mdot
.42099 .72409 Mdot
.82559 .49479 Mdot
.40315 .3749 Mdot
.80776 .18579 Mdot
.27703 .33173 Mdot
.93729 .5272 Mdot
.70855 .6575 Mdot
.66809 .37958 Mdot
.94951 .51716 Mdot
.92195 .67852 Mdot
.82973 .02801 Mdot
.41942 .26131 Mdot
.61863 .65139 Mdot
.79357 .21993 Mdot
.60681 .7317 Mdot
.36714 .78048 Mdot
.80994 .61016 Mdot
.411 .22511 Mdot
.74921 .37976 Mdot
.97372 .10185 Mdot
.41088 .23812 Mdot
.72616 .37615 Mdot
.99008 .02282 Mdot
.28196 .75844 Mdot
.94119 .91436 Mdot
.30398 .71526 Mdot
.30409 .70225 Mdot
.6171 .36506 Mdot
.83824 .68635 Mdot
.59906 .24475 Mdot
.88724 .76218 Mdot
.6722 .22397 Mdot
.90423 .55449 Mdot
.90174 .32074 Mdot
.82067 .79437 Mdot
.98876 .87787 Mdot
.92362 .04199 Mdot
.69367 .36799 Mdot
.62068 .36562 Mdot
.60704 .27827 Mdot
.8673 .67533 Mdot
.92853 .77793 Mdot
.28092 .66503 Mdot
.57745 .30684 Mdot
.91321 .14315 Mdot
.87477 .74649 Mdot
.30233 .76773 Mdot
.74716 .71153 Mdot
.93933 .52238 Mdot
.6393 .72797 Mdot
.46486 .7766 Mdot
.54184 .64325 Mdot
.55402 .37626 Mdot
.88165 .95891 Mdot
.79706 .65493 Mdot
.93251 .44633 Mdot
.95754 .24426 Mdot
.90174 .62178 Mdot
.84726 .20046 Mdot
.35753 .25532 Mdot
.95581 .23175 Mdot
.3929 .66363 Mdot
.75125 .71324 Mdot
.76234 .70588 Mdot
.6363 .37138 Mdot
.43749 .37108 Mdot
.81937 .45737 Mdot
.2825 .25284 Mdot
.47033 .23492 Mdot
.40055 .62348 Mdot
.92116 .68184 Mdot
.87992 .2121 Mdot
.27092 .66374 Mdot
.37936 .66514 Mdot
.87234 .64723 Mdot
.62937 .36396 Mdot
.81262 .01019 Mdot
.23862 .73068 Mdot
.41966 .35579 Mdot
.53904 .78942 Mdot
.86394 .0298 Mdot
.45408 .66421 Mdot
.91434 .52052 Mdot
.95263 .2199 Mdot
.49532 .22047 Mdot
.71167 .69554 Mdot
.9242 .77428 Mdot
.25952 .29177 Mdot
.80439 .29272 Mdot
.26197 .23731 Mdot
.95729 .76576 Mdot
.7632 .69468 Mdot
.91267 .63946 Mdot
.97867 .85538 Mdot
.83827 .07346 Mdot
.25326 .62106 Mdot
.88816 .15646 Mdot
.98149 .39355 Mdot
.92107 .38089 Mdot
.22809 .68907 Mdot
.92041 .10382 Mdot
.29097 .30284 Mdot
.88653 .32308 Mdot
.64307 .69222 Mdot
.37014 .73592 Mdot
.65177 .30847 Mdot
.43927 .36484 Mdot
.43349 .6096 Mdot
.43087 .62341 Mdot
.41095 .74715 Mdot
.72499 .35792 Mdot
.82866 .04464 Mdot
.85186 .56174 Mdot
.71034 .61469 Mdot
.87188 .57986 Mdot
.68629 .24704 Mdot
.73727 .24875 Mdot
.68502 .77797 Mdot
.84341 .85978 Mdot
.88686 .20105 Mdot
.75296 .24308 Mdot
.3287 .37415 Mdot
.61062 .37571 Mdot
.59564 .75452 Mdot
.88829 .91042 Mdot
.27675 .39017 Mdot
.97642 .83642 Mdot
.98089 .64749 Mdot
.47894 .27926 Mdot
.80568 .32549 Mdot
.85851 .89375 Mdot
.39322 .23676 Mdot
.49513 .31654 Mdot
.98612 .74905 Mdot
.38394 .32588 Mdot
.88561 .52994 Mdot
.89939 .68372 Mdot
.29907 .37148 Mdot
.30314 .61262 Mdot
.29615 .63463 Mdot
.92153 .16744 Mdot
.49854 .39897 Mdot
.55721 .33793 Mdot
.98877 .8241 Mdot
.82336 .55685 Mdot
.90413 .48991 Mdot
.85693 .9519 Mdot
.9256 .79426 Mdot
.92959 .03336 Mdot
.37961 .63223 Mdot
.79582 .54987 Mdot
.59122 .71328 Mdot
.22284 .25695 Mdot
.84876 .51805 Mdot
.83342 .61491 Mdot
.89361 .07028 Mdot
.8879 .56437 Mdot
.8103 .46487 Mdot
.52911 .35798 Mdot
.91259 .89069 Mdot
.82052 .87619 Mdot
.80404 .41211 Mdot
.96077 .86283 Mdot
.49817 .23037 Mdot
.96197 .80746 Mdot
.88094 .35899 Mdot
.81975 .87726 Mdot
.91091 .30805 Mdot
.25999 .76364 Mdot
.94034 .43542 Mdot
.78025 .72581 Mdot
.88951 .37662 Mdot
.86075 .0607 Mdot
.81714 .07496 Mdot
.49108 .60954 Mdot
.89642 .75711 Mdot
.94627 .33148 Mdot
.47906 .30284 Mdot
.59993 .77388 Mdot
.71994 .70106 Mdot
.98798 .25542 Mdot
.87402 .71327 Mdot
.81991 .38536 Mdot
.84026 .02148 Mdot
.67707 .36098 Mdot
.34082 .76563 Mdot
.89118 .9372 Mdot
.53341 .72699 Mdot
.68334 .71531 Mdot
.69518 .61404 Mdot
.32312 .7378 Mdot
.76447 .6417 Mdot
.2493 .60087 Mdot
.81383 .46465 Mdot
.94921 .60773 Mdot
.85931 .85372 Mdot
.45876 .78669 Mdot
.38312 .73937 Mdot
.2589 .36398 Mdot
.53013 .6336 Mdot
.97433 .51769 Mdot
.87188 .24105 Mdot
.48269 .28258 Mdot
.82265 .30959 Mdot
.49855 .75509 Mdot
.81111 .75245 Mdot
.9384 .41797 Mdot
.80172 .2063 Mdot
.83819 .25589 Mdot
.52853 .72874 Mdot
.68148 .71458 Mdot
.98827 .28684 Mdot
.27038 .65101 Mdot
.65131 .73168 Mdot
.91113 .16982 Mdot
.87051 .39741 Mdot
.86845 .41525 Mdot
.69806 .29992 Mdot
.49914 .65993 Mdot
.83499 .52426 Mdot
.95468 .13666 Mdot
.54718 .22011 Mdot
.42216 .66961 Mdot
.59832 .74548 Mdot
.6294 .72664 Mdot
.89046 .45536 Mdot
.98236 .31064 Mdot
.26403 .37367 Mdot
.49303 .64091 Mdot
.45475 .71274 Mdot
.9237 .78525 Mdot
.96837 .55202 Mdot
.87213 .389 Mdot
.47958 .35118 Mdot
.87997 .08816 Mdot
.79633 .13791 Mdot
.90626 .43209 Mdot
.97276 .63704 Mdot
.98356 .06661 Mdot
.51378 .70563 Mdot
.29822 .72812 Mdot
.31257 .61662 Mdot
.49209 .60001 Mdot
.7675 .33111 Mdot
.93293 .03588 Mdot
.77414 .2743 Mdot
.96215 .82095 Mdot
.34135 .22299 Mdot
.47986 .23074 Mdot
.93504 .03846 Mdot
.56185 .70519 Mdot
.5906 .72184 Mdot
.72657 .78403 Mdot
.38682 .63815 Mdot
.94083 .97247 Mdot
.85948 .75633 Mdot
.36004 .26043 Mdot
.3237 .70527 Mdot
.78679 .27177 Mdot
.81812 .71941 Mdot
.96026 .37413 Mdot
.86749 .73713 Mdot
.41626 .73473 Mdot
.6064 .20963 Mdot
.90119 .73348 Mdot
.39374 .25678 Mdot
.96767 .51224 Mdot
.95332 .35922 Mdot
.91595 .63049 Mdot
.34617 .69823 Mdot
.65839 .36897 Mdot
.54367 .6687 Mdot
.27986 .65694 Mdot
.40744 .4011 Mdot
.6184 .61839 Mdot
.48169 .76081 Mdot
.89807 .63348 Mdot
.59184 .39388 Mdot
.22695 .77676 Mdot
.32179 .72714 Mdot
.88423 .9595 Mdot
.891 .75422 Mdot
.6843 .3733 Mdot
.21997 .72756 Mdot
.98321 .94099 Mdot
.97433 .25546 Mdot
.41606 .61946 Mdot
.8759 .59601 Mdot
.7896 .72404 Mdot
.96397 .23079 Mdot
.25428 .63864 Mdot
.42715 .2073 Mdot
.90307 .47731 Mdot
.8182 .69521 Mdot
.83376 .88909 Mdot
.84898 .72145 Mdot
.57486 .38925 Mdot
.56809 .77973 Mdot
.46048 .62114 Mdot
.92783 .87622 Mdot
.61692 .72225 Mdot
.64721 .63081 Mdot
.45914 .22987 Mdot
.82146 .28398 Mdot
.35663 .6902 Mdot
.30908 .31879 Mdot
.67775 .67928 Mdot
.80433 .3632 Mdot
.25681 .29363 Mdot
.76853 .37883 Mdot
.95787 .61443 Mdot
.93727 .10465 Mdot
.27568 .72194 Mdot
.46155 .36855 Mdot
.4362 .69609 Mdot
.48913 .60125 Mdot
.90437 .56052 Mdot
.26768 .7016 Mdot
.96241 .39511 Mdot
.25528 .26714 Mdot
.53601 .68922 Mdot
.49421 .68887 Mdot
.31727 .22865 Mdot
.81806 .51917 Mdot
.79924 .14432 Mdot
.84046 .55013 Mdot
.79302 .61726 Mdot
.80817 .60157 Mdot
.47292 .76804 Mdot
.89182 .32159 Mdot
.66387 .63353 Mdot
.2843 .23974 Mdot
.90171 .58698 Mdot
.43403 .67981 Mdot
.34846 .6361 Mdot
.86574 .85826 Mdot
.86605 .79503 Mdot
.21167 .23453 Mdot
.30016 .63775 Mdot
.85754 .31066 Mdot
.84185 .33219 Mdot
.37018 .35329 Mdot
.50319 .68629 Mdot
.59271 .23667 Mdot
.95798 .97166 Mdot
.73026 .32732 Mdot
.76248 .36741 Mdot
.42069 .65881 Mdot
.29539 .79206 Mdot
.46611 .60424 Mdot
.34956 .72183 Mdot
.29333 .64375 Mdot
.91907 .07282 Mdot
.57447 .69787 Mdot
.63349 .27095 Mdot
.98122 .70774 Mdot
.89632 .36982 Mdot
.26165 .75684 Mdot
.6128 .71626 Mdot
.33278 .69382 Mdot
.52239 .20715 Mdot
.29509 .67138 Mdot
.29179 .28437 Mdot
.40976 .29957 Mdot
.58355 .23908 Mdot
.73106 .63627 Mdot
.86325 .38755 Mdot
.90227 .54486 Mdot
.5159 .30485 Mdot
.68787 .76586 Mdot
.62671 .73393 Mdot
.75366 .35618 Mdot
.30174 .5982 Mdot
.27013 .69834 Mdot
.9791 .6934 Mdot
.96495 .57295 Mdot
.90106 .82763 Mdot
.6473 .35229 Mdot
.45692 .24271 Mdot
.82128 .71152 Mdot
.60301 .2439 Mdot
.4972 .78833 Mdot
.86454 .64967 Mdot
.84009 .44584 Mdot
.406 .76359 Mdot
.36348 .36941 Mdot
.91677 .58072 Mdot
.922 .55375 Mdot
.73837 .32538 Mdot
.47489 .32084 Mdot
.2343 .25385 Mdot
.6438 .59952 Mdot
.74715 .36029 Mdot
.30651 .36534 Mdot
.93323 .98613 Mdot
.6762 .6808 Mdot
.88274 .52183 Mdot
.8204 .42679 Mdot
.73613 .71065 Mdot
.43942 .3551 Mdot
.49639 .35917 Mdot
.62173 .78283 Mdot
.93901 .78583 Mdot
.87091 .20805 Mdot
.54426 .38299 Mdot
.88936 .9221 Mdot
.94055 .14607 Mdot
.44477 .76104 Mdot
.88428 .86247 Mdot
.57395 .31893 Mdot
.81878 .96934 Mdot
.31872 .2718 Mdot
.41956 .3399 Mdot
.96863 .79883 Mdot
.57512 .33136 Mdot
.87348 .95709 Mdot
.77038 .39159 Mdot
.9794 .62975 Mdot
.73238 .69519 Mdot
.56965 .29966 Mdot
.34055 .32669 Mdot
.52532 .76467 Mdot
.45727 .35979 Mdot
.52415 .75224 Mdot
.40257 .37204 Mdot
.23682 .23074 Mdot
.8802 .28525 Mdot
.50744 .30834 Mdot
.85825 .83552 Mdot
.39705 .29584 Mdot
.29703 .68559 Mdot
.83033 .46078 Mdot
.79873 .4002 Mdot
.28355 .38909 Mdot
.8933 .28787 Mdot
.94565 .4269 Mdot
.2868 .32178 Mdot
.97996 .62638 Mdot
.71828 .67028 Mdot
.92321 .76404 Mdot
.90975 .27989 Mdot
.64946 .38475 Mdot
.32431 .61781 Mdot
.37644 .30595 Mdot
.40153 .22739 Mdot
.82863 .83804 Mdot
.98611 .73595 Mdot
.22984 .31364 Mdot
.56691 .20634 Mdot
.47218 .2301 Mdot
.80041 .06003 Mdot
.59603 .39094 Mdot
.58037 .73659 Mdot
.54128 .31976 Mdot
.39539 .21909 Mdot
.44554 .39562 Mdot
.79689 .49754 Mdot
.98667 .44732 Mdot
.85359 .72192 Mdot
.4161 .70093 Mdot
.52103 .73093 Mdot
.85156 .84111 Mdot
.79392 .63884 Mdot
.93255 .78792 Mdot
.52653 .34243 Mdot
.37834 .75589 Mdot
.9076 .38468 Mdot
.89313 .85918 Mdot
.32468 .30955 Mdot
.36211 .62817 Mdot
.86226 .27177 Mdot
.82577 .29554 Mdot
.90837 .90106 Mdot
.728 .74026 Mdot
.82507 .87127 Mdot
.84847 .90803 Mdot
.63814 .30956 Mdot
.4911 .67479 Mdot
.96624 .70289 Mdot
.84151 .27274 Mdot
.34111 .69141 Mdot
.89738 .24885 Mdot
.69317 .39166 Mdot
.87468 .61676 Mdot
.28886 .23054 Mdot
.60688 .28713 Mdot
.54735 .36095 Mdot
.97572 .59001 Mdot
.87947 .9022 Mdot
.69666 .36928 Mdot
.43108 .36193 Mdot
.81439 .0846 Mdot
.8365 .49049 Mdot
.20614 .37839 Mdot
.96622 .29462 Mdot
.94238 .67873 Mdot
.45514 .29304 Mdot
.80763 .3398 Mdot
.32219 .21325 Mdot
.87172 .33021 Mdot
.63607 .68643 Mdot
.81863 .35644 Mdot
.47217 .2558 Mdot
.92622 .08146 Mdot
.49635 .76521 Mdot
.39891 .27467 Mdot
.91694 .02866 Mdot
.43133 .40135 Mdot
.48222 .70571 Mdot
.54716 .22859 Mdot
.90317 .79655 Mdot
.54562 .33335 Mdot
.82046 .32873 Mdot
.98293 .67445 Mdot
.6003 .35473 Mdot
.4404 .77716 Mdot
.77217 .66308 Mdot
.5289 .21805 Mdot
.84169 .49201 Mdot
.33559 .75252 Mdot
.58083 .38612 Mdot
.73123 .75628 Mdot
.26076 .69204 Mdot
.86798 .05922 Mdot
.78951 .61829 Mdot
.47997 .63919 Mdot
.94801 .72967 Mdot
.41603 .70397 Mdot
.32673 .71486 Mdot
.64917 .23544 Mdot
.26666 .62304 Mdot
.57427 .65724 Mdot
.75552 .77041 Mdot
.44994 .2743 Mdot
.61194 .61618 Mdot
.88232 .09938 Mdot
.77372 .3238 Mdot
.34992 .33531 Mdot
.72817 .70933 Mdot
.24493 .67906 Mdot
.9773 .96051 Mdot
.89114 .94841 Mdot
.35686 .3045 Mdot
.89867 .84117 Mdot
.91156 .87085 Mdot
.40624 .63292 Mdot
.36186 .60619 Mdot
.59798 .65255 Mdot
.93694 .46687 Mdot
.94231 .96844 Mdot
.87154 .46138 Mdot
.80536 .76047 Mdot
.68681 .62304 Mdot
.36128 .25122 Mdot
.20936 .33202 Mdot
.40917 .27298 Mdot
.26985 .75502 Mdot
.29443 .73423 Mdot
.75808 .37152 Mdot
.87184 .75326 Mdot
.80866 .87353 Mdot
.93543 .05306 Mdot
.86561 .93086 Mdot
.6508 .30903 Mdot
.283 .66898 Mdot
.63483 .36904 Mdot
.81636 .4857 Mdot
.6809 .78021 Mdot
.80548 .83954 Mdot
.88095 .14374 Mdot
.73191 .32865 Mdot
.84512 .30782 Mdot
.21329 .38956 Mdot
.59001 .6839 Mdot
.64826 .61247 Mdot
.95317 .34968 Mdot
.55118 .65286 Mdot
.89476 .6523 Mdot
.89592 .6507 Mdot
.92618 .19899 Mdot
.51575 .70958 Mdot
.36525 .38436 Mdot
.85768 .10692 Mdot
.38966 .34052 Mdot
.35558 .76045 Mdot
.98238 .20276 Mdot
.9243 .40018 Mdot
.69095 .61941 Mdot
.61459 .2612 Mdot
.90885 .71349 Mdot
.97475 .32312 Mdot
.86546 .43526 Mdot
.90813 .02986 Mdot
.57254 .2586 Mdot
.94814 .9876 Mdot
.88425 .44903 Mdot
.26368 .67804 Mdot
.31727 .59851 Mdot
.73493 .34971 Mdot
.77698 .35231 Mdot
.57751 .21435 Mdot
.97585 .7974 Mdot
.87979 .2904 Mdot
.23706 .34135 Mdot
.94889 .77949 Mdot
.50744 .37594 Mdot
.81571 .83707 Mdot
.97926 .45841 Mdot
.54743 .28533 Mdot
.80195 .15353 Mdot
.87675 .03906 Mdot
.84325 .36424 Mdot
.9886 .94881 Mdot
.49226 .38439 Mdot
.93503 .10886 Mdot
.88231 .47838 Mdot
.93442 .60278 Mdot
.92206 .08677 Mdot
.75509 .24886 Mdot
.97722 .96811 Mdot
.86298 .76067 Mdot
.84414 .03239 Mdot
.85742 .32135 Mdot
.2737 .29042 Mdot
.28667 .31251 Mdot
.9098 .08866 Mdot
.43273 .28993 Mdot
.85882 .84862 Mdot
.95392 .98301 Mdot
.76948 .38169 Mdot
.39573 .78998 Mdot
.94251 .89113 Mdot
.72441 .23309 Mdot
.89933 .23863 Mdot
.32095 .62646 Mdot
.63724 .77797 Mdot
.91541 .82667 Mdot
.21204 .75454 Mdot
.84153 .03595 Mdot
.53038 .39968 Mdot
.74778 .30342 Mdot
.78429 .2366 Mdot
.81127 .01447 Mdot
.8258 .13111 Mdot
.95174 .0574 Mdot
.68319 .73649 Mdot
.33307 .71538 Mdot
.71868 .2148 Mdot
.512 .71071 Mdot
.67682 .79002 Mdot
.71528 .74242 Mdot
.40862 .24766 Mdot
.36871 .26784 Mdot
.88604 .79625 Mdot
.79917 .44589 Mdot
.66828 .78503 Mdot
.9432 .05241 Mdot
.58429 .77477 Mdot
.8703 .39377 Mdot
.54865 .24191 Mdot
.70293 .79271 Mdot
.89396 .35663 Mdot
.67667 .30712 Mdot
.46453 .2129 Mdot
.79657 .90354 Mdot
.90608 .96118 Mdot
.88108 .56102 Mdot
.22078 .73591 Mdot
.21897 .70563 Mdot
.88905 .97307 Mdot
.34333 .24657 Mdot
.67807 .24696 Mdot
.60294 .29869 Mdot
.8132 .74499 Mdot
.91435 .76212 Mdot
.72462 .70143 Mdot
.94377 .29387 Mdot
.29241 .20856 Mdot
.85585 .88118 Mdot
.38556 .25144 Mdot
.87242 .8393 Mdot
.69756 .25614 Mdot
.63646 .666 Mdot
.7708 .77501 Mdot
.89702 .70975 Mdot
.72815 .63882 Mdot
.60965 .27455 Mdot
.86032 .91811 Mdot
.74781 .62419 Mdot
.9761 .89397 Mdot
.39729 .71501 Mdot
.9594 .53714 Mdot
.85769 .2154 Mdot
.92651 .92765 Mdot
.50789 .22018 Mdot
.52199 .3164 Mdot
.82975 .70748 Mdot
.96226 .50189 Mdot
.832 .71194 Mdot
.80211 .19498 Mdot
.65567 .29006 Mdot
.68361 .77836 Mdot
.84181 .07623 Mdot
.70579 .37968 Mdot
.74131 .24842 Mdot
.22037 .38214 Mdot
.71584 .23395 Mdot
.86148 .31372 Mdot
.55063 .72415 Mdot
.37549 .69195 Mdot
.50197 .67264 Mdot
.78638 .30276 Mdot
.55686 .60726 Mdot
.83121 .38312 Mdot
.8093 .12738 Mdot
.26847 .39343 Mdot
.88318 .69167 Mdot
.83181 .30193 Mdot
.2658 .38131 Mdot
.37784 .72805 Mdot
.94568 .76064 Mdot
.22618 .64294 Mdot
.41607 .71296 Mdot
.97519 .92974 Mdot
.88975 .89177 Mdot
.91907 .6405 Mdot
.93427 .14094 Mdot
.46811 .62221 Mdot
.90082 .59943 Mdot
.91582 .65989 Mdot
.38225 .28628 Mdot
.46543 .6618 Mdot
.83302 .46365 Mdot
.49847 .31073 Mdot
.76718 .63007 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`00000P00000040oooo00000`000000oooo0?ooo`3T0?ooo`?oo`00=03oool100000040
oooo00000`000000oooo0?ooo`3S0?ooo`Goo`005P3oool3ool001X0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0h`3oool5ool001D0oooo1Ooo000I0?ooo`4000000@3oool000030000003oool0
oooo0><0oooo1Ooo00040?ooo`?oo`003P3oool5ool001D0oooo0ooo00010?ooo`4000000@3oool0
00030000003oool0oooo0><0oooo1Ooo00030?ooo`Goo`003@3oool5ool00180oooo1ooo00010000
0040oooo00000`000000oooo0?ooo`3T0?ooo`?oo`000P3oool7ool000<0oooo0ooo00080?ooo`Oo
o`003P3oool8ool0004000000@3oool000030000003oool0oooo0>P0oooo2?oo00020?ooo`Goo`00
203oool7ool000d0oooo2?oo000100000040oooo00000`000000oooo0?ooo`3X0?ooo`Woo`0000<0
ooooool00?oo00000ooo00080?ooo`_oo`00203oool8ool00040oooo0@0000010?ooo`0000<00000
0?ooo`3oool0j03oool9ool000030?oooooo003oo`0000Koo`001@3oool<ool000L0oooo1Ooo0004
0?ooo`4000000@3oool000030000003oool0oooo0>T0oooo2?oo00020?ooo`Soo`001@3oool;ool0
00L0oooo1Ooo00040?ooo`4000000@3oool000030000003oool0oooo0>T0oooo2?oo00050?ooo`Go
o`00203oool8ool000P0oooo0ooo00050?ooo`4000000@3oool000030000003oool0oooo0>P0oooo
2?oo00060?ooo`Goo`00203oool8ool00100oooo0@0000010?ooo`0000<000000?ooo`3oool0j03o
ool5ool000X0oooo0ooo00090?ooo`[oo`003P3oool100000040oooo00000`000000oooo0?ooo`3X
0?ooo`Goo`003P3oool3ool000H0oooo2ooo000<0?ooo`4000000@3oool000030000003oool0oooo
0>40oooo0ooo00050?ooo`?oo`001P3oool5ool000<0oooo1Ooo00080?ooo`Woo`002`3oool10000
0040oooo00000`000000oooo0?ooo`3P0?ooo`Goo`00303oool7ool00080oooo1Ooo00080?ooo`Wo
o`002`3oool100000040oooo00000`000000oooo0?ooo`3P0?ooo`Goo`00303oool7ool00080oooo
1Ooo00090?ooo`Soo`001@3oool3ool000<0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03o
ool5ool000`0oooo1ooo00030?ooo`Coo`003@3oool3ool000D0oooo1Ooo00020?ooo`4000000@3o
ool000030000003oool0oooo0>40oooo0ooo00020?ooo`?oo`000`3oool3ool000<0oooo1Ooo0004
0?ooo`Goo`000`3oool3ool000h0oooo1Ooo00020?ooo`4000000@3oool000030000003oool0oooo
0>D0oooo1Ooo00000`3oooooo`00ool00005ool000T0oooo1Ooo00020?ooo`Goo`003@3oool5ool0
0080oooo0@0000010?ooo`0000<000000?ooo`3oool0i@3oool5ool000030?oooooo003oo`0000Ko
o`00203oool5ool00080oooo1_oo000=0?ooo`?oo`000`3oool100000040oooo00000`000000oooo
0?ooo`3U0?ooo`Goo`0000<0ooooool00?oo00001_oo00090?ooo`?oo`000`3oool7ool00180oooo
0@0000010?ooo`0000<000000?ooo`3oool0i03oool5ool000<0oooo1ooo00050?ooo`?oo`001@3o
ool9ool00180oooo0@0000010?ooo`0000<000000?ooo`3oool0i03oool5ool000@0oooo1Ooo0005
0?ooo`Goo`000`3oool:ool00180oooo0@0000010?ooo`0000<000000?ooo`3oool0i03oool5ool0
00h0oooo1Ooo00030?ooo`_oo`004@3oool100000040oooo00000`000000oooo0?ooo`3Q0?ooo`?o
o`0000@0ooooool00?oo003oo`003`3oool5ool000<0oooo3?oo000@0?ooo`4000000@3oool00003
0000003oool0oooo0>00oooo1Ooo000B0?ooo`Goo`00103oool3ool000030?oooooo003oo`0000Go
o`00203oool3ool000D0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool5ool00180oooo
1Ooo00070?ooo`Soo`001`3oool5ool000@0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03o
ool5ool000`0oooo0ooo00030?ooo`Goo`001P3oool:ool000H0oooo1Ooo00040?ooo`4000000@3o
ool000030000003oool0oooo0>40oooo0ooo000<0?ooo`Goo`000`3oool3ool000L0oooo2_oo0006
0?ooo`Goo`00103oool100000040oooo00000`000000oooo0?ooo`3`0?ooo`Goo`003@3oool:ool0
00L0oooo0ooo00050?ooo`4000000@3oool000030000003oool0oooo0?00oooo1Ooo000>0?ooo`So
o`00403oool100000040oooo00000`000000oooo0?ooo`3a0?ooo`?oo`004`3oool3ool00140oooo
0@0000010?ooo`0000<000000?ooo`3oool0h`3oool3ool001T0oooo0ooo000I0?ooo`4000000@3o
ool000030000003oool0oooo0>80oooo1Ooo000G0?ooo`Goo`00603oool100000040oooo00000`00
0000oooo0?ooo`3R0?ooo`Woo`004`3oool5ool00140oooo0ooo00040?ooo`4000000@3oool00003
0000003oool0oooo0>00oooo3?oo000B0?ooo`Goo`002P3oool3ool000<0oooo1Ooo00030?ooo`40
00000@3oool000030000003oool0oooo0=l0oooo3Ooo000@0?ooo`Koo`001@3oool3ool00080oooo
1Ooo00020?ooo`Goo`000`3oool100000040oooo00000`000000oooo0?ooo`3O0?ooo`Goo`000P3o
ool6ool000`0oooo2?oo0000103oooooo`00ool00?oo00020?ooo`Goo`0000<0ooooool00?oo0000
0ooo00020?ooo`Goo`000`3oool100000040oooo00000`000000oooo0?ooo`3O0?ooo`Goo`000P3o
ool5ool000`0oooo3_oo00000`3oooooo`00ool00009ool000<0oooo0ooo00040?ooo`4000000@3o
ool000030000003oool0oooo0=l0oooo1Ooo00000`3oooooo`00ool00003ool000d0oooo3_oo0000
0`3oooooo`00ool00008ool000/0oooo0@0000010?ooo`0000<000000?ooo`3oool0g`3oool5ool0
00030?oooooo003oo`0000?oo`003@3oool8ool000030?oooooo003oo`0000?oo`000P3oool6ool0
00h0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool:ool000h0oooo1Ooo00040?ooo`?o
o`000P3oool7ool000h0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool5ool000040?oo
oooo003oo`00ool00100oooo1Ooo00080?ooo`Koo`002`3oool3ool00040oooo0@0000010?ooo`00
00<000000?ooo`3oool0h03oool5ool001@0oooo1Ooo00070?ooo`Koo`002`3oool5ool000400000
0@3oool000030000003oool0oooo0>40oooo0ooo000E0?ooo`Goo`001P3oool6ool000`0oooo1Ooo
000100000040oooo00000`000000oooo0?ooo`3j0?ooo`?oo`00103oool8ool000d0oooo1Ooo0001
00000040oooo00000`000000oooo0?ooo`3o0?ooo`40oooo2Ooo000>0?ooo`?oo`000@3oool10000
0040oooo00000`000000oooo0?ooo`3o0?ooo`40oooo2?oo000C0?ooo`4000000@3oool000030000
003oool0oooo0>P0oooo0ooo000E0?ooo`Ooo`002`3oool3ool000H0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0h`3oool3ool000030?oooooo003oo`0000?oo`00503oool5ool000`0oooo1Ooo
00050?ooo`4000000@3oool000030000003oool0oooo0>80oooo2_oo000E0?ooo`?oo`003@3oool5
ool000D0oooo0@0000010?ooo`0000<000000?ooo`3oool0hP3oool:ool002D0oooo1Ooo00050?oo
o`4000000@3oool000030000003oool0oooo0>40oooo1_oo0000103oooooo`00ool00?oo000A0?oo
o`?oo`004`3oool3ool000H0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool6ool000P0
oooo0ooo000:0?ooo`Goo`001@3oool3ool001<0oooo0@0000010?ooo`0000<000000?ooo`3oool0
h03oool6ool000L0oooo1Ooo00080?ooo`Koo`00103oool5ool000`0oooo0ooo00030?ooo`400000
0@3oool000030000003oool0oooo05H0oooo0ooo000M0?ooo`?oo`00603oool3ool000X0oooo0ooo
000o0?ooo`Ooo`001P3oool5ool000@0oooo2_oo00040?ooo`Goo`002`3oool5ool00080oooo0@00
00010?ooo`0000<000000?ooo`3oool0C`3oool3ool000<0oooo1Ooo000@0?ooo`?oo`00203oool5
ool001H0oooo1Ooo00080?ooo`Goo`001`3oool3ool003@0oooo2?oo00050?ooo`Goo`000`3oool:
ool000D0oooo1Ooo000;0?ooo`Goo`000P3oool100000040oooo00000`000000oooo0?ooo`1>0?oo
o`Goo`000P3oool6ool000h0oooo1Ooo00070?ooo`Goo`001@3oool5ool000`0oooo1Ooo00080?oo
o`Ooo`00103oool5ool003<0oooo2?oo00060?ooo`?oo`000`3oool:ool000L0oooo0ooo000<0?oo
o`Goo`000P3oool100000040oooo00000`000000oooo0?ooo`1>0?ooo`Goo`000P3oool7ool000d0
oooo1Ooo00070?ooo`Goo`00103oool7ool000/0oooo1_oo00070?ooo`Soo`000`3oool5ool001`0
oooo0ooo000D0?ooo`Soo`002@3oool<ool000`0oooo0ooo00090?ooo`?oo`000`3oool100000040
oooo00000`000000oooo0?ooo`1>0?ooo`Goo`000`3oool6ool000d0oooo1ooo00060?ooo`?oo`00
1@3oool7ool000@0oooo0ooo00001@3oooooo`00ool00?oo0000oooo00Koo`0000@0ooooool00?oo
003oo`000`3oool7ool000<0oooo1Ooo000K0?ooo`Goo`004P3oool8ool000T0oooo3?oo000<0?oo
o`Ooo`00303oool100000040oooo00000`000000oooo0?ooo`1?0?ooo`?oo`001@3oool5ool00004
0?oooooo003oo`00ool000X0oooo2_oo000:0?ooo`Ooo`000`3oool9ool000030?oooooo003oo`00
00Soo`00103oool5ool000@0oooo0ooo000@0?ooo`?oo`002@3oool5ool00100oooo1_oo000=0?oo
o`goo`002`3oool8ool000/0oooo0@0000010?ooo`0000<000000?ooo`3oool0C@3oool3ool000P0
oooo0ooo00000`3oooooo`00ool00003ool000/0oooo2Ooo000:0?ooo`Goo`00103oool9ool00003
0?oooooo003oo`0000Soo`001@3oool3ool000D0oooo0ooo000?0?ooo`Goo`00203oool5ool000l0
oooo1ooo000=0?ooo`Goo`000`3oool6ool000X0oooo2?oo000;0?ooo`4000000@3oool000030000
003oool0oooo03l0oooo0ooo000:0?ooo`Goo`001@3oool3ool000<0oooo1Ooo00030?ooo`?oo`00
1@3oool9ool000X0oooo0ooo00000`3oooooo`00ool0000<ool00080oooo0ooo00000`3oooooo`00
ool00003ool000`0oooo1Ooo000>0?ooo`Goo`002@3oool3ool00100oooo1ooo000>0?ooo`?oo`00
1@3oool5ool000X0oooo2ooo00080?ooo`4000000@3oool000030000003oool0oooo03P0oooo0ooo
00030?ooo`Goo`001`3oool8ool000<0oooo1Ooo00020?ooo`Goo`000P3oool5ool000D0oooo2?oo
00090?oooa;oo`001`3oool5ool000`0oooo1Ooo00080?ooo`?oo`000`3oool5ool000T0oooo1ooo
000<0?ooo`Koo`005`3oool5ool000T0oooo3Ooo00070?ooo`4000000@3oool000030000003oool0
oooo03L0oooo1Ooo00020?ooo`Goo`000`3oool<ool000<0oooo1Ooo00030?ooo`?oo`000`3oool5
ool000@0oooo2?oo000:0?oooa3oo`002@3oool5ool000L0oooo2_oo00070?ooo`Goo`000`3oool3
ool000T0oooo2Ooo000;0?ooo`Coo`006P3oool6ool000L0oooo3Ooo00070?ooo`4000000@3oool0
00030000003oool0oooo03L0oooo1Ooo00020?ooo`Goo`000P3oool=ool000<0oooo1Ooo00090?oo
o`Goo`000`3oool:ool000T0oooo4?oo000:0?ooo`Coo`001P3oool:ool000P0oooo1Ooo000?0?oo
o`Woo`002P3oool5ool001D0oooo0ooo00040?ooo`Goo`001P3oool=ool000L0oooo0@0000010?oo
o`0000<000000?ooo`3oool0=`3oool5ool000<0oooo0ooo00030?ooo`coo`001@3oool3ool000/0
oooo0ooo00040?ooo`[oo`002@3oool:ool00080oooo0ooo000;0?ooo`Goo`001@3oool9ool000T0
oooo1Ooo000?0?ooo`Woo`000P3oool3ool000D0oooo1Ooo000D0?ooo`Goo`000`3oool5ool000L0
oooo0ooo00020?ooo`Koo`00203oool100000040oooo00000`000000oooo0?ooo`0h0?ooo`?oo`00
2P3oool<ool000d0oooo0ooo000:0?ooo`[oo`00203oool8ool001<0oooo1Ooo00050?ooo`[oo`00
2@3oool3ool000H0oooo1Ooo00060?ooo`koo`00103oool5ool001@0oooo1Ooo00030?ooo`Goo`00
303oool5ool000T0oooo0@0000010?ooo`0000<000000?ooo`3oool0AP3oool3ool000<0oooo1Ooo
000<0?ooo`Goo`0000@0ooooool00?oo003oo`00103oool:ool000T0oooo1Ooo000E0?ooo`Koo`00
1P3oool9ool00140oooo1ooo000:0?ooo`[oo`00103oool3ool001D0oooo1Ooo00030?ooo`Goo`00
2P3oool7ool000T0oooo0@0000010?ooo`0000<000000?ooo`3oool0?`3oool3ool000T0oooo1Ooo
00080?ooo`?oo`000P3oool:ool00080oooo1Ooo00000`3oooooo`00ool00003ool000T0oooo1Ooo
0000103oooooo`00ool00?oo000A0?ooo`Goo`002P3oool6ool00140oooo2Ooo00080?ooo`[oo`00
503oool3ool000H0oooo0ooo00040?ooo`Goo`002@3oool8ool000050?oooooo003oo`00ool0003o
ool00ooo00010?ooo`4000000@3oool000030000003oool0oooo03P0oooo2ooo00080?ooo`Goo`00
1`3oool5ool000030?oooooo003oo`0000Soo`000P3oool<ool000T0oooo0ooo00000`3oooooo`00
ool00003ool00100oooo1Ooo00030?ooo`?oo`001@3oool4ool00180oooo2_oo00070?ooo`goo`00
403oool5ool000`0oooo1Ooo00090?ooo`Ooo`0000<0ooooool00?oo00001ooo000100000040oooo
00000`000000oooo0?ooo`0g0?ooo`coo`00203oool5ool000L0oooo1Ooo00020?ooo`Woo`000P3o
ool>ool000/0oooo1Ooo000A0?ooo`?oo`000`3oool5ool000T0oooo0ooo000?0?ooo`Woo`00203o
ool4ool000030?oooooo003oo`0000Koo`003`3oool5ool000d0oooo0ooo000:0?ooo`Goo`000`3o
ool9ool0004000000@3oool000030000003oool0oooo03L0oooo3?oo00090?ooo`?oo`00203oool5
ool000D0oooo1_oo00030?ooo`koo`002P3oool5ool001L0oooo1Ooo00080?ooo`Goo`004P3oool5
ool00100oooo1Ooo000?0?ooo`Goo`006`3oool3ool000@0oooo2Ooo000100000040oooo00000`00
0000oooo0?ooo`0g0?ooo`_oo`000`3oool3ool00100oooo0ooo00070?ooo`Koo`000`3oool5ool0
00030?oooooo003oo`0000Goo`0000@0ooooool00?oo003oo`001`3oool3ool001P0oooo1Ooo0005
0?ooo`Soo`004`3oool3ool00140oooo1Ooo000@0?ooo`?oo`007`3oool3ool00080oooo0ooo0000
1P3oooooo`00ool00?oo0000oooo00000040oooo00000`000000oooo0?ooo`0h0?ooo`Koo`000P3o
ool3ool000030?oooooo003oo`0000?oo`003P3oool3ool000P0oooo1ooo00030?ooo`?oo`000P3o
ool<ool00280oooo0ooo00050?ooo`Woo`0000@0ooooool00?oo003oo`00603oool3ool000T0oooo
0ooo00020?ooo`?oo`003@3oool3ool000<0oooo0ooo000G0?ooo`Goo`002@3oool100000040oooo
00000`000000oooo0?ooo`0o0?ooo`[oo`003@3oool5ool000P0oooo1_oo00050?ooo`Woo`0000<0
ooooool00?oo00001Ooo000X0?ooo`Soo`0000<0ooooool00?oo00000ooo000F0?ooo`Goo`002@3o
ool8ool000/0oooo1Ooo00000`3oooooo`00ool00003ool001H0oooo1Ooo00090?ooo`4000000@3o
ool000030000003oool0oooo03/0oooo0ooo00000`3oooooo`00ool00008ool000d0oooo1Ooo0007
0?ooo`Ooo`00103oool8ool000<0oooo2?oo00050?ooo`?oo`007`3oool7ool000030?oooooo003o
o`0000Coo`005P3oool5ool000P0oooo2Ooo000;0?ooo`Goo`0000<0ooooool00?oo00000ooo0009
0?ooo`?oo`002P3oool5ool000T0oooo0@0000010?ooo`0000<000000?ooo`3oool0>P3oool?ool0
00H0oooo0ooo00040?ooo`Goo`001`3oool6ool000@0oooo2Ooo00040?ooo`Ooo`00103oool5ool0
01l0oooo3_oo000E0?ooo`Goo`00203oool9ool000H0oooo0ooo00020?ooo`Goo`0000<0ooooool0
0?oo00000ooo00080?ooo`Goo`002P3oool3ool000X0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0>P3oool5ool000050?oooooo003oo`00ool0003oool01Ooo00050?ooo`Goo`00103oool3ool0
00P0oooo1Ooo00020?ooo`_oo`001`3oool5ool000@0oooo1_oo000>0?ooo`?oo`003@3oool?ool0
00D0oooo0ooo000=0?ooo`?oo`002@3oool9ool000D0oooo1Ooo00020?ooo`?oo`000`3oool3ool0
0080oooo1_oo00000`3oooooo`00ool00003ool001<0oooo0ooo00010?ooo`4000000@3oool00003
0000003oool0oooo03X0oooo1Ooo00050?ooo`Goo`0000D0ooooool00?oo003oo`000?ooo`05ool0
0100oooo0ooo00020?ooo`Woo`001P3oool3ool00080oooo0ooo00050?ooo`Koo`003@3oool5ool0
00`0oooo1Ooo00000`3oooooo`00ool0000:ool000030?oooooo003oo`0000?oo`006@3oool3ool0
00040?oooooo003oo`00ool000H0oooo1Ooo000<0?ooo`goo`003`3oool8ool0004000000@3oool0
00030000003oool0oooo03/0oooo0ooo00070?ooo`koo`003P3oool3ool000@0oooo2?oo00060?oo
o`Goo`000`3oool3ool000<0oooo1_oo000=0?ooo`Goo`00303oool5ool00080oooo4Ooo000R0?oo
o`?oo`0000<0ooooool00?oo00000ooo000<0?ooo`Soo`0000@0ooooool00?oo003oo`001`3oool3
ool000<0oooo2ooo000100000040oooo00000`000000oooo0?ooo`140?ooo`[oo`0000@0ooooool0
0?oo003oo`003P3oool5ool000<0oooo2?oo00060?ooo`Goo`000P3oool5ool00080oooo1Ooo000>
0?ooo`Goo`00303oool5ool000H0oooo3Ooo000Q0?ooo`Goo`0000<0ooooool00?oo00000_oo000<
0?ooo`Soo`002P3oool5ool000030?oooooo003oo`0000[oo`000@0000010?ooo`0000<000000?oo
o`3oool0A03oool:ool00180oooo1Ooo00040?ooo`_oo`000P3oool5ool00080oooo1Ooo00030?oo
o`?oo`001P3oool3ool000H0oooo1?oo00040?ooo`?oo`001P3oool4ool000X0oooo1Ooo0000103o
ooooo`00ool00?oo00040?ooo`?oo`00103oool3ool001@0oooo1Ooo00000`3oooooo`00ool00003
ool000/0oooo1ooo000;0?ooo`Goo`0000<0ooooool00?oo00002Ooo00010?ooo`4000000@3oool0
00030000003oool0oooo03d0oooo0ooo00040?ooo`koo`003P3oool6ool000H0oooo2Ooo00020?oo
o`?oo`000`3oool5ool000<0oooo0ooo00050?ooo`Goo`00103oool5ool000<0oooo1_oo00030?oo
o`Goo`002`3oool3ool000P0oooo1Ooo00020?ooo`Goo`00103oool3ool000P0oooo0ooo00000`3o
ooooo`00ool00003ool000030?oooooo003oo`0000Coo`002`3oool3ool000h0oooo1Ooo00000`3o
ooooo`00ool00005ool000D0oooo0@0000010?ooo`0000<000000?ooo`3oool0?03oool5ool000@0
oooo1?oo00030?ooo`Ooo`003P3oool9ool00080oooo2Ooo00090?ooo`?oo`000`3oool5ool000@0
oooo1_oo00030?ooo`Goo`000`3oool7ool00080oooo1Ooo000:0?ooo`?oo`00103oool3ool00080
oooo1Ooo00020?ooo`Goo`000`3oool5ool000H0oooo1Ooo0000103oooooo`00ool00?oo00020?oo
o`[oo`00403oool3ool000H0oooo0ooo00030?ooo`?oo`0000@0ooooool00?oo003oo`00103oool1
00000040oooo00000`000000oooo0?ooo`0l0?ooo`Goo`002`3oool7ool000D0oooo0ooo00060?oo
o`[oo`000P3oool8ool000l0oooo3ooo00030?ooo`Goo`000`3oool>ool000H0oooo2?oo00020?oo
o`Goo`0000<0ooooool00?oo00000ooo00020?ooo`Goo`000`3oool5ool000H0oooo1Ooo00060?oo
o`goo`00303oool5ool000h0oooo1Ooo00030?ooo`4000000@3oool000030000003oool0oooo03`0
oooo1Ooo000;0?ooo`Ooo`00103oool5ool000D0oooo2_oo00060?ooo`?oo`00403oool?ool000@0
oooo0ooo00050?ooo`goo`001@3oool9ool00080oooo1Ooo00020?ooo`?oo`00103oool3ool000@0
oooo1Ooo00060?ooo`Goo`001@3oool?ool000/0oooo1Ooo000>0?ooo`Koo`000P3oool100000040
oooo00000`000000oooo0?ooo`0l0?ooo`Goo`00303oool5ool00080oooo2?oo00060?ooo`Woo`00
303oool3ool000/0oooo3ooo000<0?ooo`goo`00103oool9ool00080oooo1Ooo000A0?ooo`?oo`00
203oool3ool000H0oooo4?oo00040?ooo`?oo`000`3oool5ool000h0oooo1_oo00020?ooo`400000
0@3oool000030000003oool0oooo03`0oooo1Ooo000<0?ooo`Goo`0000<0ooooool00?oo00001ooo
000;0?ooo`?oo`00303oool5ool000P0oooo5ooo00050?ooo`koo`00103oool9ool000<0oooo0ooo
000V0?ooo`Goo`000`3oool8ool000<0oooo2ooo000@0?ooo`Goo`000P3oool100000040oooo0000
0`000000oooo0?ooo`0l0?ooo`Goo`00303oool5ool000030?oooooo003oo`0000Koo`003P3oool3
ool000X0oooo1Ooo00070?ooo`_oo`000`3oool;ool000@0oooo1Ooo00000`3oooooo`00ool00006
ool000D0oooo0ooo0000103oooooo`00ool00?oo000F0?ooo`?oo`001`3oool3ool000H0oooo0ooo
00020?ooo`?oo`001P3oool6ool000<0oooo2Ooo000@0?ooo`Koo`000`3oool100000040oooo0000
0`000000oooo0?ooo`0m0?ooo`?oo`00203oool3ool00080oooo1Ooo00000`3oooooo`00ool00003
ool000D0oooo0ooo00080?ooo`Goo`002@3oool5ool000L0oooo1Ooo00000`3oooooo`00ool00003
ool000<0oooo2ooo00040?ooo`Goo`001@3oool3ool00180oooo0ooo000<0?ooo`Koo`001@3oool5
ool000@0oooo1Ooo0000103oooooo`00ool00?oo00060?ooo`Goo`00103oool9ool000l0oooo1_oo
00040?ooo`4000000@3oool000030000003oool0oooo03L0oooo0ooo000=0?ooo`_oo`000P3oool3
ool000D0oooo1Ooo00070?ooo`Goo`002P3oool3ool000P0oooo1Ooo00020?ooo`?oo`001@3oool:
ool000D0oooo0ooo000J0?ooo`Goo`002P3oool7ool000@0oooo1_oo00040?ooo`[oo`000P3oool;
ool000030?oooooo003oo`0000Ooo`002@3oool3ool000<0oooo1_oo00040?ooo`4000000@3oool0
00030000003oool0oooo03H0oooo1Ooo000<0?ooo`[oo`002`3oool7ool000D0oooo1Ooo000=0?oo
o`?oo`001P3oool3ool000l0oooo1ooo00030?ooo`Goo`00103oool3ool00180oooo1Ooo000:0?oo
o`Ooo`000`3oool7ool000@0oooo2_oo00000`3oooooo`00ool0000Cool000T0oooo1Ooo00020?oo
o`Koo`00103oool100000040oooo00000`000000oooo0?ooo`0f0?ooo`Goo`00303oool8ool000d0
oooo2?oo00050?ooo`?oo`00203oool3ool00080oooo1Ooo000I0?ooo`Ooo`0000<0ooooool00?oo
00000ooo00030?ooo`Goo`001@3oool3ool000T0oooo1Ooo000:0?ooo`Koo`000`3oool7ool000H0
oooo2Ooo00000`3oooooo`00ool0000;ool000040?oooooo003oo`00ool000d0oooo1Ooo00030?oo
o`Coo`001@3oool100000040oooo00000`000000oooo0?ooo`0f0?ooo`Goo`00103oool3ool000H0
oooo1ooo000>0?ooo`Ooo`001`3oool3ool000D0oooo2ooo000D0?ooo`?oo`000P3oool=ool000<0
oooo1Ooo00040?ooo`Goo`002@3oool3ool000`0oooo0ooo00050?ooo`Koo`001`3oool8ool00080
oooo3Ooo000A0?ooo`Goo`00303oool100000040oooo00000`000000oooo0?ooo`0g0?ooo`?oo`00
103oool5ool000D0oooo1_oo00040?ooo`?oo`002P3oool5ool000H0oooo1Ooo00040?ooo`_oo`00
2@3oool3ool000L0oooo3_oo0000103oooooo`00ool00?oo00040?ooo`Goo`00103oool5ool00200
oooo1Ooo00080?ooo`Goo`001P3oool3ool00080oooo1_oo000C0?ooo`?oo`003@3oool100000040
oooo00000`000000oooo0?ooo`0n0?ooo`Goo`001@3oool5ool000@0oooo1Ooo000:0?ooo`?oo`00
1`3oool5ool000@0oooo2_oo00090?ooo`Goo`001P3oool>ool000T0oooo0ooo00050?ooo`Goo`00
6@3oool3ool000D0oooo0ooo00090?ooo`Goo`009P3oool3ool000/0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0?P3oool5ool000D0oooo1Ooo00040?ooo`Goo`003`3oool3ool00080oooo1Ooo
00050?ooo`Soo`002@3oool6ool000H0oooo1ooo00030?ooo`?oo`003`3oool3ool000050?oooooo
003oo`00ool0003oool00ooo000E0?ooo`Goo`00203oool3ool000H0oooo0ooo000V0?ooo`Goo`00
2P3oool100000040oooo00000`000000oooo0?ooo`0o0?ooo`?oo`001`3oool3ool000D0oooo1Ooo
000>0?ooo`Goo`000P3oool3ool000H0oooo0ooo00000`3oooooo`00ool00002ool000P0oooo1ooo
00070?ooo`Koo`003`3oool3ool00080oooo1Ooo00030?ooo`Goo`00503oool5ool000040?oooooo
003oo`00ool000<0oooo1Ooo00080?ooo`?oo`004`3oool3ool000P0oooo0ooo00020?ooo`Goo`00
2P3oool100000040oooo00000`000000oooo0?ooo`1B0?ooo`?oo`003`3oool5ool000X0oooo2_oo
0000103oooooo`00ool00?oo00030?ooo`Woo`001P3oool4ool000040?oooooo003oo`00ool000/0
oooo1Ooo00000`3oooooo`00ool00003ool000<0oooo1Ooo00040?ooo`?oo`002`3oool<ool00080
oooo1Ooo00070?ooo`Goo`003P3oool8ool000H0oooo1Ooo00000`3oooooo`00ool00003ool000X0
oooo0@0000010?ooo`0000<000000?ooo`3oool0AP3oool3ool001/0oooo1Ooo000:0?ooo`ooo`00
0P3oool:ool000@0oooo2_oo000:0?ooo`Goo`0000<0ooooool00?oo00001Ooo00000`3oooooo`00
ool00003ool000<0oooo1Ooo00090?ooo`goo`000P3oool5ool000@0oooo2?oo00030?ooo`?oo`00
1`3oool9ool000H0oooo1Ooo00000`3oooooo`00ool00003ool000X0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0A@3oool5ool000T0oooo0ooo0000103oooooo`00ool00?oo000;0?ooo`?oo`00
2`3oool?ool000<0oooo0ooo00000`3oooooo`00ool00003ool000@0oooo2_oo000:0?ooo`Goo`00
00<0ooooool00?oo00001_oo0000103oooooo`00ool00?oo00040?ooo`Goo`0000@0ooooool00?oo
003oo`001@3oool5ool00080oooo2?oo0000103oooooo`00ool00?oo00040?ooo`Woo`000P3oool5
ool000H0oooo2Ooo00060?ooo`Goo`0000<0ooooool00?oo00000ooo000:0?ooo`4000000@3oool0
00030000003oool0oooo04D0oooo1Ooo00070?ooo`[oo`002@3oool3ool000d0oooo3ooo00060?oo
o`Goo`00103oool;ool000X0oooo0ooo00000`3oooooo`00ool00008ool000<0oooo0ooo00000`3o
ooooo`00ool00008ool000@0oooo1Ooo00020?ooo`Woo`001`3oool8ool000<0oooo1Ooo00030?oo
o`_oo`00203oool3ool00080oooo1Ooo000:0?ooo`4000000@3oool000030000003oool0oooo04D0
oooo1Ooo00060?ooo`goo`001P3oool5ool000L0oooo0ooo00040?ooo`Ooo`0000<0ooooool00?oo
00001?oo00060?ooo`?oo`001P3oool3ool00080oooo1_oo000=0?ooo`_oo`0000<0ooooool00?oo
00000ooo00000`3oooooo`00ool00008ool000@0oooo0ooo00040?ooo`Soo`001`3oool5ool000H0
oooo1Ooo00020?ooo`goo`003@3oool5ool000T0oooo0@0000010?ooo`0000<000000?ooo`3oool0
=P3oool6ool000X0oooo1Ooo00050?ooo`koo`001@3oool5ool000H0oooo1Ooo00040?ooo`Koo`00
0P3oool5ool000T0oooo0ooo00090?ooo`Goo`00303oool<ool000030?oooooo003oo`0000?oo`00
0`3oool8ool000D0oooo0ooo00050?ooo`Koo`00203oool3ool000P0oooo0ooo00030?ooo`Goo`00
0P3oool6ool000h0oooo1Ooo00080?ooo`4000000@3oool000030000003oool0oooo03D0oooo2?oo
00090?ooo`Goo`001@3oool>ool000D0oooo1Ooo00060?ooo`Goo`001@3oool5ool00080oooo1Ooo
00080?ooo`Goo`00203oool5ool000/0oooo3Ooo00000`3oooooo`00ool00005ool000030?oooooo
003oo`0000Soo`000P3oool5ool00080oooo2Ooo000H0?ooo`Goo`0000<0ooooool00?oo00001Ooo
00030?ooo`Soo`000`3oool5ool000P0oooo0@0000010?ooo`0000<000000?ooo`3oool0=@3oool9
ool000P0oooo1_oo00050?ooo`goo`001P3oool3ool000L0oooo1Ooo00060?ooo`?oo`00103oool3
ool000D0oooo0ooo00000`3oooooo`00ool00003ool000H0oooo2Ooo00090?ooo`Goo`000`3oool4
ool000030?oooooo003oo`0001Soo`0000<0ooooool00?oo00002Ooo000:0?ooo`?oo`0000<0oooo
ool00?oo00000ooo00050?ooo`?oo`000P3oool6ool000030?oooooo003oo`0000[oo`000P3oool5
ool000P0oooo0@0000010?ooo`0000<000000?ooo`3oool0=@3oool;ool000L0oooo1Ooo00090?oo
o`?oo`000P3oool3ool000H0oooo1Ooo00070?ooo`?oo`005@3oool:ool000D0oooo2ooo0000103o
ooooo`00ool00?oo00040?ooo`Goo`001`3oool:ool000030?oooooo003oo`0000koo`0000<0oooo
ool00?oo00000ooo00000`3oooooo`00ool00003ool000T0oooo2ooo00030?ooo`Goo`0000<0oooo
ool00?oo00000ooo00000`3oooooo`00ool0000;ool000<0oooo0ooo00090?ooo`4000000@3oool0
00030000003oool0oooo03H0oooo2ooo00060?ooo`Woo`004`3oool5ool001l0oooo1Ooo0000103o
ooooo`00ool00?oo00030?oooaKoo`0000@0ooooool00?oo003oo`00203oool:ool000<0oooo3_oo
00000`3oooooo`00ool00009ool000T0oooo2ooo00020?ooo`Ooo`0000@0ooooool00?oo003oo`00
0P3oool=ool000l0oooo0@0000010?ooo`0000<000000?ooo`3oool0=`3oool:ool000L0oooo2Ooo
000B0?ooo`Goo`001P3oool3ool000X0oooo0ooo00080?ooo`Koo`001P3oool9ool000030?oooooo
003oo`0000coo`002`3oool5ool000040?oooooo003oo`00ool000<0oooo3ooo00020?ooo`[oo`00
2@3oool;ool00080oooo1ooo00060?ooo`coo`00103oool3ool000<0oooo0ooo00030?ooo`400000
0@3oool000030000003oool0oooo03L0oooo2_oo00060?ooo`[oo`004`3oool3ool000H0oooo1Ooo
00080?ooo`Goo`001`3oool7ool000D0oooo2?oo00030?ooo`goo`00303oool3ool000P0oooo1_oo
00030?ooo`Goo`001@3oool8ool000X0oooo0ooo00000`3oooooo`00ool00003ool000<0oooo1ooo
00070?ooo`?oo`002`3oool5ool000030?oooooo003oo`0000?oo`000P3oool100000040oooo0000
0`000000oooo0?ooo`0g0?ooo`Goo`0000@0ooooool00?oo003oo`001`3oool:ool001`0oooo1_oo
00040?ooo`Soo`001`3oool8ool000@0oooo1Ooo00080?ooo`_oo`005`3oool5ool000h0oooo2?oo
00040?ooo`?oo`00403oool6ool000/0oooo0ooo00070?ooo`Goo`0000<0ooooool00?oo00000ooo
00020?ooo`4000000@3oool000030000003oool0oooo03H0oooo1Ooo000<0?ooo`Woo`007@3oool7
ool00080oooo2Ooo00080?ooo`Ooo`00103oool5ool000T0oooo0ooo00000`3oooooo`00ool00003
ool001T0oooo0ooo000@0?ooo`Koo`00103oool5ool00100oooo1Ooo00070?ooo`_oo`000`3oool5
ool000030?oooooo003oo`0000?oo`000P3oool100000040oooo00000`000000oooo0?ooo`0f0?oo
o`Goo`003@3oool3ool002<0oooo1_oo00020?ooo`Soo`002`3oool5ool000@0oooo1Ooo000>0?oo
o`?oo`00;`3oool3ool000D0oooo1Ooo000@0?ooo`Goo`001P3oool=ool000<0oooo0ooo00030?oo
o`?oo`000`3oool100000040oooo00000`000000oooo0?ooo`0f0?ooo`Goo`00=03oool5ool00080
oooo1Ooo000?0?ooo`?oo`001@3oool5ool004P0oooo1_oo000@0?ooo`?oo`001`3oool=ool000l0
oooo0@0000010?ooo`0000<000000?ooo`3oool0=`3oool3ool003H0oooo0ooo00040?ooo`?oo`00
6@3oool3ool004X0oooo1_oo000>0?ooo`?oo`00203oool=ool000040?oooooo003oo`00ool000/0
oooo0@0000010?ooo`0000<000000?ooo`3oool0h@3oool5ool000d0oooo1Ooo00080?ooo`?oo`00
1@3oool3ool000030?oooooo003oo`0000?oo`002P3oool100000040oooo00000`000000oooo0?oo
o`3Q0?ooo`Goo`003@3oool5ool000l0oooo2_oo000:0?ooo`4000000@3oool000030000003oool0
oooo0>80oooo0ooo00020?ooo`?oo`002@3oool5ool000l0oooo2_oo000:0?ooo`4000000@3oool0
00030000003oool0oooo0>H0oooo1Ooo00090?ooo`?oo`002`3oool3ool00080oooo2ooo00090?oo
o`4000000@3oool000030000003oool0oooo0>H0oooo1Ooo000D0?ooo`Ooo`000P3oool;ool000P0
oooo0@0000010?ooo`0000<000000?ooo`3oool0iP3oool5ool000P0oooo0ooo00080?ooo`Soo`00
0`3oool:ool000P0oooo0@0000010?ooo`0000<000000?ooo`3oool0i`3oool3ool000P0oooo1Ooo
00070?ooo`Soo`000P3oool5ool000030?oooooo003oo`0000?oo`00203oool100000040oooo0000
0`000000oooo0?ooo`3b0?ooo`Goo`001`3oool7ool000<0oooo1Ooo00020?ooo`?oo`002@3oool1
00000040oooo00000`000000oooo0?ooo`3P0?ooo`?oo`002@3oool3ool000<0oooo1Ooo00080?oo
o`Ooo`0000<0ooooool00?oo00001?oo00090?ooo`?oo`000P3oool100000040oooo00000`000000
oooo0?ooo`3O0?ooo`Goo`001`3oool5ool000<0oooo0ooo00030?ooo`Coo`00103oool;ool000T0
oooo1Ooo00010?ooo`4000000@3oool000030000003oool0oooo0=l0oooo1Ooo00070?ooo`Goo`00
203oool6ool000<0oooo2_oo000:0?ooo`Goo`000@3oool100000040oooo00000`000000oooo0?oo
o`3O0?ooo`Goo`000P3oool3ool00080oooo1Ooo00080?ooo`Koo`00103oool3ool000030?oooooo
003oo`0000?oo`002@3oool6ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool3
ool00080oooo2_oo00060?ooo`[oo`00203oool3ool000T0oooo1_oo00020?ooo`4000000@3oool0
00030000003oool0oooo0>@0oooo2ooo00050?ooo`_oo`00503oool5ool000<0oooo0@0000010?oo
o`0000<000000?ooo`3oool0h`3oool<ool000D0oooo1Ooo00000`3oooooo`00ool00003ool000T0
oooo0ooo00080?ooo`Goo`000`3oool100000040oooo00000`000000oooo0?ooo`3S0?ooo`coo`00
1@3oool5ool00080oooo0ooo00090?ooo`Goo`00203oool3ool000@0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0h`3oool;ool000L0oooo0ooo000?0?ooo`Goo`003`3oool100000040oooo0000
0`000000oooo0?ooo`3T0?ooo`Coo`000P3oool3ool000/0oooo0ooo00030?ooo`?oo`001P3oool5
ool000l0oooo0@0000010?ooo`0000<000000?ooo`3oool0m`3oool5ool000030?oooooo003oo`00
00?oo`001P3oool3ool00100oooo0@0000010?ooo`0000<000000?ooo`3oool0h@3oool3ool00004
0?oooooo003oo`00ool000H0oooo0ooo00060?ooo`Goo`0000<0ooooool00?oo00000ooo000I0?oo
o`4000000@3oool000030000003oool0oooo0>00oooo2Ooo00040?ooo`Goo`001@3oool5ool00003
0?oooooo003oo`0000?oo`006@3oool100000040oooo00000`000000oooo0?ooo`3P0?ooo`Woo`00
0P3oool7ool000H0oooo0ooo00030?ooo`Goo`00603oool100000040oooo00000`000000oooo0?oo
o`3P0?oooa;oo`00303oool5ool001P0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool4
ool000030?oooooo003oo`0000[oo`003@3oool6ool001L0oooo0@0000010?ooo`0000<000000?oo
o`3oool0g`3ooolBool000h0oooo1Ooo000;0?ooo`?oo`002@3oool100000040oooo00000`000000
oooo0?ooo`3O0?oooa7oo`003P3oool6ool000X0oooo1Ooo00080?ooo`4000000@3oool000030000
003oool0oooo0=l0oooo3?oo000B0?ooo`Koo`002`3oool5ool000P0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0g`3oool9ool000l0oooo0ooo00030?ooo`Goo`00303oool6ool000L0oooo0@00
00010?ooo`0000<000000?ooo`3oool0g`3oool8ool000P0oooo0ooo00040?ooo`Goo`000P3oool5
ool000X0oooo2_oo00050?ooo`4000000@3oool000030000003oool0oooo0=l0oooo1Ooo00020?oo
o`Goo`000`3oool5ool000<0oooo1Ooo00030?ooo`?oo`0000@0ooooool00?oo003oo`001P3oool<
ool000@0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool3ool00080oooo3_oo00030?oo
o`Goo`001P3oool5ool000<0oooo3_oo00040?ooo`4000000@3oool000030000003oool0oooo0>D0
oooo3_oo00030?ooo`Koo`001@3oool5ool00080oooo2?oo00000`3oooooo`00ool00004ool000@0
oooo0@0000010?ooo`0000<000000?ooo`3oool0i@3oool=ool000<0oooo2?oo00040?ooo`Goo`00
00<0ooooool00?oo00001_oo00040?ooo`?oo`001@3oool100000040oooo00000`000000oooo0?oo
o`3V0?ooo`Woo`001P3oool8ool000D0oooo0ooo00020?ooo`Koo`003P3oool100000040oooo0000
0`000000oooo0?ooo`3[0?ooo`?oo`001`3oool8ool000X0oooo1Ooo00020?ooo`?oo`002P3oool1
00000040oooo00000`000000oooo0?ooo`3f0?ooo`Ooo`002`3oool3ool00080oooo1Ooo00090?oo
o`4000000@3oool000030000003oool0oooo0?T0oooo0ooo00020?ooo`?oo`00303oool5ool000T0
oooo0@0000010?ooo`0000<000000?ooo`3oool0o@3oool6ool000X0oooo1Ooo00090?ooo`400000
0@3oool000030000003oool0oooo0>00oooo0ooo00090?ooo`?oo`003P3oool7ool000X0oooo1_oo
00070?ooo`4000000@3oool000030000003oool0oooo0=l0oooo1Ooo00070?ooo`Goo`003@3oool:
ool000T0oooo1Ooo00060?ooo`4000000@3oool000030000003oool0oooo0=l0oooo1Ooo00030?oo
o`?oo`0000<0ooooool00?oo00000ooo000>0?ooo`goo`001@3oool5ool000H0oooo0@0000010?oo
o`0000<000000?ooo`3oool0g`3oool5ool00080oooo3Ooo00050?ooo`?oo`000`3oool>ool000@0
oooo1Ooo00060?ooo`4000000@3oool000030000003oool0oooo0>00oooo0ooo00030?ooo`Goo`00
00<0ooooool00?oo00001_oo00000`3oooooo`00ool00006ool000030?oooooo003oo`0000coo`00
1@3oool3ool000L0oooo0@0000010?ooo`0000<000000?ooo`3oool0iP3oool5ool000<0oooo5Ooo
00000`3oooooo`00ool00006ool000l0oooo0@0000010?ooo`0000<000000?ooo`3oool0i@3oool5
ool000@0oooo5Ooo00050?ooo`?oo`001@3oool3ool000P0oooo0@0000010?ooo`0000<000000?oo
o`3oool0i@3oool5ool000D0oooo1?oo00000`3oooooo`00ool00008ool000040?oooooo003oo`00
ool000d0oooo1Ooo00070?ooo`4000000@3oool000030000003oool0oooo0>D0oooo1Ooo00050?oo
o`Goo`0000<0ooooool00?oo00001_oo00050?ooo`?oo`002P3oool5ool000L0oooo0@0000010?oo
o`0000<000000?ooo`3oool0iP3oool3ool000H0oooo2ooo00070?ooo`Koo`00203oool5ool000L0
oooo0@0000010?ooo`0000<000000?ooo`3oool0k`3oool:ool000D0oooo2_oo00080?ooo`?oo`00
203oool100000040oooo00000`000000oooo0?ooo`3`0?ooo`?oo`0000<0ooooool00?oo00000ooo
00040?ooo`_oo`002`3oool3ool000D0oooo0@0000010?ooo`0000<000000?ooo`3oool0m@3oool3
ool000D0oooo2ooo000:0?ooo`Goo`00103oool100000040oooo00000`000000oooo0?ooo`1B0?oo
o`?oo`00X@3oool3ool000@0oooo1Ooo00020?ooo`?oo`002`3oool5ool000@0oooo0@0000010?oo
o`0000<000000?ooo`3oool0@`3oool3ool000/0oooo2?oo000_0?ooo`?oo`00:@3oool3ool001X0
oooo0ooo000?0?ooo`?oo`003`3oool5ool000@0oooo0ooo000A0?ooo`Goo`00103oool100000040
oooo00000`000000oooo0?ooo`120?ooo`Goo`002P3oool9ool002L0oooo0ooo00030?ooo`Goo`00
9`3oool5ool001P0oooo1Ooo000=0?ooo`Goo`003P3oool5ool000<0oooo1Ooo00050?ooo`?oo`00
2@3oool3ool000D0oooo0@0000010?ooo`0000<000000?ooo`3oool0@03oool7ool000X0oooo2Ooo
00090?ooo`?oo`006P3oool5ool00080oooo1Ooo000?0?ooo`?oo`005@3oool5ool001L0oooo1_oo
000=0?ooo`Goo`003P3oool5ool000<0oooo1Ooo00040?ooo`Soo`003@3oool100000040oooo0000
0`000000oooo0?ooo`0g0?ooo`?oo`001@3oool8ool000/0oooo2?oo00020?ooo`?oo`000`3oool5
ool000X0oooo0ooo00040?ooo`?oo`001@3oool5ool00080oooo1Ooo000>0?ooo`Goo`00503oool5
ool001H0oooo1ooo000=0?ooo`Goo`003`3oool3ool000@0oooo1Ooo00040?ooo`Woo`00303oool1
00000040oooo00000`000000oooo0?ooo`0f0?ooo`Goo`00103oool7ool000`0oooo1ooo00020?oo
o`Goo`000P3oool5ool000T0oooo1Ooo00020?ooo`Goo`00103oool6ool000030?oooooo003oo`00
00?oo`003P3oool5ool001D0oooo1?oo000;0?ooo`?oo`0000@0ooooool00?oo003oo`00103oool6
ool000l0oooo1Ooo00020?ooo`?oo`004@3oool3ool000D0oooo2ooo000:0?ooo`4000000@3oool0
00030000003oool0oooo03H0oooo1Ooo00040?ooo`Soo`001`3ooolBool00080oooo1Ooo00090?oo
o`Goo`000P3oool5ool000050?oooooo003oo`00ool0003oool03Ooo000<0?ooo`Goo`00303oool5
ool000@0oooo1Ooo00090?ooo`Woo`000`3oool5ool000/0oooo1?oo00000`3oooooo`00ool00003
ool000030?oooooo003oo`0000?oo`00203oool3ool000h0oooo2ooo00090?ooo`4000000@3oool0
00030000003oool0oooo03H0oooo1_oo00040?ooo`Soo`001@3ooolCool000<0oooo0ooo000:0?oo
o`Koo`0000<0ooooool00?oo00005_oo000<0?ooo`?oo`00303oool7ool000<0oooo1Ooo00080?oo
o`[oo`00103oool3ool000/0oooo2ooo00000`3oooooo`00ool00003ool000L0oooo1Ooo00040?oo
o`?oo`002P3oool7ool000T0oooo0@0000010?ooo`0000<000000?ooo`3oool0=`3oool5ool000L0
oooo2?oo00020?oooa;oo`003`3oool=ool000030?oooooo003oo`0000Woo`0000<0ooooool00?oo
00001Ooo000K0?ooo`Ooo`000`3oool5ool000L0oooo2ooo00070?ooo`?oo`001`3oool7ool00004
0?oooooo003oo`00ool00080oooo1Ooo00070?ooo`Goo`000`3oool5ool000/0oooo1Ooo00090?oo
o`4000000@3oool000030000003oool0oooo03L0oooo1Ooo00070?ooo`Woo`0000<0ooooool00?oo
00003Ooo00070?ooo`?oo`001`3oool>ool000030?oooooo003oo`0000_oo`0000<0ooooool00?oo
00000ooo000K0?ooo`Ooo`00103oool3ool000L0oooo1ooo0000103oooooo`00ool00?oo00070?oo
o`Goo`001P3oool7ool000L0oooo0ooo00080?ooo`Goo`000`3oool5ool000`0oooo0ooo00030?oo
o`?oo`00103oool100000040oooo00000`000000oooo0?ooo`0h0?ooo`?oo`00203oool9ool00080
oooo0ooo00040?ooo`Koo`001`3oool5ool000040?oooooo003oo`00ool00080oooo3_oo00020?oo
o`goo`0000D0ooooool00?oo003oo`000?ooo`03ool000T0oooo0ooo000=0?ooo`Goo`001@3oool3
ool000L0oooo1_oo000<0?ooo`Goo`0000@0ooooool00?oo003oo`000P3oool6ool001@0oooo0ooo
00040?ooo`Soo`003P3oool7ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool0A03oool8
ool000@0oooo0ooo00030?ooo`Goo`00103oool=ool000030?oooooo003oo`0000coo`00103oool;
ool000@0oooo2?oo00000`3oooooo`00ool00006ool001D0oooo1Ooo0000103oooooo`00ool00?oo
00020?ooo`Goo`002@3oool3ool000030?oooooo003oo`0000Soo`000P3oool3ool001d0oooo2Ooo
000=0?ooo`Soo`000@0000010?ooo`0000<000000?ooo`3oool0A03oool3ool000040?oooooo003o
o`00ool000@0oooo1Ooo00020?ooo`Goo`000`3oool?ool000030?oooooo003oo`0000Coo`000`3o
ool3ool000/0oooo1Ooo00040?oooa7oo`005@3oool:ool00080oooo0ooo00090?ooo`Goo`0000D0
ooooool00?oo003oo`000?ooo`05ool000@0oooo0ooo000J0?ooo`[oo`00303oool9ool000400000
0@3oool000030000003oool0oooo03`0oooo0ooo00040?ooo`Goo`001`3oool6ool00080oooo0ooo
00040?ooo`Soo`0000<0ooooool00?oo00001Ooo00000`3oooooo`00ool00003ool00100oooo2?oo
00020?oooa?oo`004`3oool:ool000d0oooo1_oo00050?ooo`Goo`000`3oool7ool001L0oooo2_oo
000;0?ooo`[oo`000@0000010?ooo`0000<000000?ooo`3oool0>`3oool5ool000<0oooo1Ooo0003
0?ooo`?oo`0000<0ooooool00?oo00001?oo00090?ooo`Goo`001@3oool6ool00080oooo1Ooo000?
0?ooo`Woo`000P3ooolCool00180oooo2_oo000=0?ooo`Koo`001@3oool5ool00080oooo2Ooo000F
0?ooo`_oo`002P3oool9ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool0>`3oool5ool0
00<0oooo1Ooo00020?ooo`_oo`002P3oool3ool000L0oooo1Ooo00030?ooo`Goo`003P3oool9ool0
00H0oooo2?oo00020?ooo`Goo`004P3oool5ool000040?oooooo003oo`00ool000h0oooo1Ooo0006
0?ooo`Goo`0000<0ooooool00?oo00002?oo000=0?ooo`Goo`001@3oool:ool000X0oooo1ooo0003
0?ooo`4000000@3oool000030000003oool0oooo03/0oooo1Ooo00040?ooo`?oo`000P3oool;ool0
01H0oooo0ooo00040?ooo`Goo`003`3oool8ool000T0oooo1_oo00000`3oooooo`00ool00003ool0
00D0oooo0ooo00030?ooo`?oo`00103oool5ool001<0oooo0ooo00070?ooo`Goo`0000<0ooooool0
0?oo00002?oo000<0?ooo`Ooo`000`3oool3ool00080oooo1_oo000;0?ooo`Ooo`000P3oool10000
0040oooo00000`000000oooo0?ooo`0l0?ooo`?oo`002@3oool;ool001h0oooo1Ooo000C0?ooo`?o
o`002`3oool6ool000030?oooooo003oo`0000?oo`000`3oool5ool000030?oooooo003oo`0000?o
o`00103oool3ool000h0oooo0ooo000>0?ooo`?oo`000P3oool9ool000d0oooo1ooo00020?ooo`Go
o`000`3oool3ool000h0oooo1Ooo00020?ooo`4000000@3oool000030000003oool0oooo04P0oooo
2_oo000P0?ooo`Goo`004@3oool5ool000/0oooo1Ooo00020?ooo`Goo`000P3oool5ool000030?oo
oooo003oo`0000?oo`00503oool5ool000l0oooo0ooo00000`3oooooo`00ool00005ool000h0oooo
1ooo00020?ooo`Goo`000P3oool3ool000l0oooo1Ooo00020?ooo`4000000@3oool000030000003o
ool0oooo03T0oooo0ooo000<0?ooo`Soo`00703oool3ool000@0oooo1Ooo00060?ooo`Koo`00103o
ool6ool000X0oooo1Ooo00020?ooo`Goo`000P3oool5ool000030?oooooo003oo`0000?oo`00503o
ool7ool000`0oooo1Ooo00020?ooo`Goo`003`3oool5ool000<0oooo1Ooo00000`3oooooo`00ool0
0003ool000<0oooo0ooo00090?ooo`?oo`000`3oool100000040oooo00000`000000oooo0?ooo`0h
0?ooo`Goo`001P3oool3ool00080oooo2?oo000H0?ooo`Soo`000`3oool5ool000D0oooo2?oo0003
0?ooo`Koo`0000@0ooooool00?oo003oo`001`3oool3ool000<0oooo1Ooo00030?ooo`?oo`000`3o
ool3ool00080oooo0ooo000@0?ooo`Soo`002`3oool5ool00080oooo1Ooo000H0?ooo`?oo`000P3o
ool5ool00080oooo1ooo000<0?ooo`4000000@3oool000030000003oool0oooo03P0oooo1Ooo0005
0?ooo`Goo`0000<0ooooool00?oo00002Ooo0000103oooooo`00ool00?oo000@0?ooo`Woo`000`3o
ool5ool000D0oooo2?oo00040?ooo`[oo`00103oool3ool000H0oooo0ooo000>0?ooo`Goo`00403o
ool7ool000/0oooo1Ooo00030?ooo`?oo`007P3oool?ool000/0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0>03oool5ool000D0oooo1Ooo00000`3oooooo`00ool0000>ool000l0oooo2Ooo0003
0?ooo`Goo`001@3oool8ool000<0oooo3?oo00020?ooo`Goo`00103oool5ool000d0oooo1Ooo000B
0?ooo`Goo`002`3oool5ool002D0oooo3_oo00050?ooo`?oo`000`3oool100000040oooo00000`00
0000oooo0?ooo`0i0?ooo`?oo`001P3ooolFool000h0oooo2Ooo00040?ooo`Goo`001P3oool6ool0
00<0oooo3_oo00000`3oooooo`00ool00003ool000@0oooo1Ooo000=0?ooo`Goo`004P3oool5ool0
00`0oooo0ooo000H0?ooo`?oo`003@3oool<ool000@0oooo1Ooo00020?ooo`4000000@3oool00003
0000003oool0oooo0480oooo5_oo000=0?ooo`Koo`00203oool8ool000`0oooo3_oo00000`3ooooo
o`00ool00003ool000@0oooo1Ooo000>0?ooo`?oo`00203oool4ool000L0oooo1Ooo000V0?ooo`Go
o`002`3oool6ool000030?oooooo003oo`0000?oo`001@3oool5ool00080oooo0@0000010?ooo`00
00<000000?ooo`3oool0@@3oool:ool000050?oooooo003oo`00ool0003oool00ooo0000103ooooo
o`00ool00?oo000>0?ooo`Goo`002P3oool8ool000/0oooo2?oo00000`3oooooo`00ool00003ool0
0080oooo0ooo00060?ooo`?oo`0000@0ooooool00?oo003oo`005@3oool6ool000L0oooo1_oo000T
0?ooo`Goo`001@3oool3ool00080oooo1_oo00000`3oooooo`00ool00003ool000H0oooo1Ooo0002
0?ooo`4000000@3oool000030000003oool0oooo0440oooo2_oo00050?ooo`?oo`004P3oool5ool0
00d0oooo1Ooo000<0?ooo`Ooo`000P3oool3ool000l0oooo1Ooo000:0?ooo`?oo`001`3oool6ool0
00T0oooo1Ooo000F0?ooo`?oo`000`3oool3ool000@0oooo1Ooo00040?ooo`Goo`0000<0ooooool0
0?oo00001?oo00000`3oooooo`00ool00003ool000L0oooo0ooo00030?ooo`4000000@3oool00003
0000003oool0oooo03d0oooo0ooo00000`3oooooo`00ool00007ool00080oooo2?oo00090?ooo`?o
o`000P3oool3ool000030?oooooo003oo`0000;oo`003@3oool5ool000`0oooo2?oo00050?ooo`?o
o`002`3oool5ool000T0oooo1_oo00050?ooo`Koo`002@3oool5ool001D0oooo1Ooo00000`3ooooo
o`00ool00003ool000@0oooo0ooo00020?ooo`Soo`0000<0ooooool00?oo00001?oo00000`3ooooo
o`00ool00003ool000d0oooo0@0000010?ooo`0000<000000?ooo`3oool0?03oool5ool000030?oo
oooo003oo`00013oo`001`3oool@ool000d0oooo0ooo000<0?ooo`Woo`00103oool5ool000X0oooo
1Ooo00090?ooo`Ooo`000P3oool7ool000H0oooo0ooo00000`3oooooo`00ool00003ool000<0oooo
1_oo000<0?ooo`Goo`0000<0ooooool00?oo00000ooo00080?ooo`Woo`000P3oool4ool000<0oooo
0ooo00070?ooo`?oo`00103oool100000040oooo00000`000000oooo0?ooo`0l0?ooo`Goo`00103o
ool?ool000H0oooo4Ooo000=0?ooo`?oo`00303oool9ool000@0oooo1Ooo00060?ooo`Coo`0000@0
ooooool00?oo003oo`002P3oool7ool000030?oooooo003oo`0000?oo`00203oool5ool000030?oo
oooo003oo`0000?oo`0000<0ooooool00?oo00001_oo000;0?ooo`Goo`0000<0ooooool00?oo0000
0ooo00080?ooo`Soo`004`3oool5ool000<0oooo0@0000010?ooo`0000<000000?ooo`3oool0?03o
ool5ool000@0oooo4Ooo00040?oooa7oo`00203oool3ool000030?oooooo003oo`0000?oo`002`3o
ool8ool000D0oooo1Ooo00050?ooo`Koo`003P3oool6ool000030?oooooo003oo`0000?oo`00203o
ool;ool000030?oooooo003oo`0000Koo`002`3oool5ool00080oooo0ooo00090?ooo`Koo`004P3o
ool8ool000<0oooo0@0000010?ooo`0000<000000?ooo`3oool0>P3oool6ool000H0oooo2Ooo0003
0?ooo`Goo`0000<0ooooool00?oo00002ooo00020?ooo`?oo`00203oool;ool000T0oooo1Ooo0004
0?ooo`?oo`000`3oool3ool000@0oooo2?oo0000103oooooo`00ool00?oo000<0?ooo`?oo`000P3o
ool5ool000P0oooo2ooo00000`3oooooo`00ool00006ool000/0oooo1Ooo000?0?ooo`Goo`004@3o
ool9ool000<0oooo0@0000010?ooo`0000<000000?ooo`3oool0>@3oool5ool000T0oooo1_oo0005
0?oooa7oo`002@3oool3ool000<0oooo2ooo00080?ooo`Goo`00103oool5ool000P0oooo3_oo000A
0?ooo`?oo`002P3oool9ool000<0oooo1ooo000<0?ooo`Koo`003P3oool6ool000l0oooo2Ooo0003
0?ooo`4000000@3oool000030000003oool0oooo03T0oooo1Ooo00090?ooo`Goo`001P3oool<ool0
00040?oooooo003oo`00ool000T0oooo1Ooo00020?ooo`Goo`0000<0ooooool00?oo00000ooo0000
103oooooo`00ool00?oo00030?ooo`Koo`00103oool5ool000P0oooo2?oo00000`3oooooo`00ool0
0003ool000X0oooo0ooo00030?ooo`?oo`003@3oool8ool000030?oooooo003oo`0000Koo`003@3o
ool6ool000T0oooo0ooo00030?ooo`Goo`003P3oool:ool00080oooo0@0000010?ooo`0000<00000
0?ooo`3oool0>@3oool5ool000X0oooo0ooo00070?ooo`Coo`0000<0ooooool00?oo00001_oo000<
0?ooo`Goo`000P3oool5ool00080oooo0ooo00000`3oooooo`00ool00003ool00080oooo1_oo0003
0?ooo`Koo`00203oool7ool00080oooo1Ooo00020?ooo`?oo`00103oool5ool000030?oooooo003o
o`0000?oo`000P3oool3ool000P0oooo4?oo000<0?ooo`Soo`001`3oool5ool00080oooo1ooo0006
0?ooo`?oo`00103oool3ool000030?oooooo003oo`0000?oo`000P3oool100000040oooo00000`00
0000oooo0?ooo`0h0?ooo`Goo`00503oool5ool00080oooo1ooo000<0?ooo`Koo`0000<0ooooool0
0?oo00000ooo00060?ooo`Goo`000P3oool5ool000@0oooo2?oo00060?ooo`Koo`000`3oool5ool0
00030?oooooo003oo`0000?oo`000`3oool5ool000030?oooooo003oo`0000?oo`0000<0ooooool0
0?oo00000ooo00080?ooo`koo`003@3oool8ool000L0oooo1Ooo00020?ooo`Soo`00103oool5ool0
00L0oooo1Ooo00020?ooo`4000000@3oool000030000003oool0oooo03L0oooo1Ooo000>0?ooo`?o
o`00103oool5ool00080oooo1ooo0000103oooooo`00ool00?oo00090?ooo`Goo`0000<0ooooool0
0?oo00000ooo00060?ooo`Goo`000`3oool3ool000D0oooo2Ooo00060?ooo`?oo`001@3oool5ool0
00030?oooooo003oo`0000?oo`000`3oool5ool000030?oooooo003oo`0000?oo`0000<0ooooool0
0?oo00000ooo00090?ooo`_oo`003P3oool9ool000030?oooooo003oo`0000;oo`000P3oool5ool0
00<0oooo1ooo00040?ooo`Goo`00203oool5ool00040oooo0@0000010?ooo`0000<000000?ooo`3o
ool0=`3oool5ool000T0oooo0ooo00000`3oooooo`00ool00003ool000<0oooo1Ooo00020?ooo`co
o`00203oool5ool00080oooo1?oo00070?ooo`?oo`003@3oool9ool00080oooo0ooo00080?ooo`Go
o`0000<0ooooool00?oo00002_oo00030?ooo`?oo`000P3oool5ool000/0oooo0ooo00000`3ooooo
o`00ool00002ool000D0oooo1_oo00040?ooo`ooo`000P3oool3ool000H0oooo1Ooo00040?ooo`Go
o`002@3oool5ool0004000000@3oool000030000003oool0oooo03L0oooo1_oo00030?ooo`?oo`00
00<0ooooool00?oo00002?oo00030?ooo`Coo`000P3oool7ool000030?oooooo003oo`0000?oo`00
103oool3ool00080oooo0ooo00030?ooo`Goo`004P3oool3ool000@0oooo3?oo00070?ooo`Goo`00
0P3oool;ool000T0oooo0ooo000H0?ooo`Soo`000`3oool?ool000`0oooo0ooo00060?ooo`Goo`00
203oool5ool0004000000@3oool000030000003oool0oooo03P0oooo1_oo00000`3oooooo`00ool0
000=ool00080oooo1Ooo00020?ooo`Goo`000`3oool5ool000<0oooo1Ooo00070?ooo`Goo`004@3o
ool6ool00080oooo3?oo00070?oooaGoo`008@3oool8ool000@0oooo0ooo00000`3oooooo`00ool0
0008ool000X0oooo0ooo00090?ooo`Goo`001`3oool5ool0004000000@3oool000030000003oool0
oooo03T0oooo1Ooo00000`3oooooo`00ool00008ool000040?oooooo003oo`00ool00080oooo1_oo
00020?ooo`Goo`00103oool3ool00080oooo1ooo00070?ooo`Goo`004@3ooolDool000D0oooo6?oo
00050?ooo`?oo`00603oool8ool000T0oooo0ooo00000`3oooooo`00ool00002ool000040?oooooo
003oo`00ool000H0oooo1Ooo00080?ooo`Goo`001`3oool4ool00040oooo0@0000010?ooo`0000<0
00000?ooo`3oool0>@3oool;ool000040?oooooo003oo`00ool000L0oooo1_oo00020?ooo`Goo`00
203oool8ool000H0oooo1Ooo000?0?oooa7oo`000P3oool5ool000<0oooo1Ooo00020?ooo`Goo`00
00<0ooooool00?oo00002_oo00040?ooo`Goo`002@3oool3ool000P0oooo0ooo00000`3oooooo`00
ool00004ool00180oooo1Ooo00050?ooo`Goo`00203oool5ool000H0oooo1Ooo00010?ooo`400000
0@3oool000030000003oool0oooo03X0oooo1Ooo0000103oooooo`00ool00?oo000<0?ooo`Goo`00
0`3oool5ool000P0oooo2Ooo00050?ooo`Goo`003P3ooolAool000<0oooo1Ooo00030?ooo`Goo`00
0P3oool5ool000030?oooooo003oo`0000[oo`00103oool5ool000D0oooo2?oo00060?ooo`Goo`00
603oool5ool000D0oooo1Ooo00090?ooo`?oo`001`3oool5ool00040oooo0@0000010?ooo`0000<0
00000?ooo`3oool0>P3oool5ool00140oooo0ooo00040?ooo`Goo`00203oool9ool000@0oooo1_oo
000>0?ooo`ooo`001@3oool5ool000<0oooo1Ooo00000`3oooooo`00ool00003ool000<0oooo2_oo
00050?ooo`Goo`00103oool9ool000H0oooo1Ooo00090?ooo`?oo`002`3oool7ool000D0oooo0ooo
000D0?ooo`Goo`000@3oool100000040oooo00000`000000oooo0?ooo`0k0?ooo`?oo`002@3oool3
ool000h0oooo0ooo000:0?ooo`Soo`000`3oool6ool000l0oooo3?oo00090?ooo`?oo`001@3oool3
ool000030?oooooo003oo`0000?oo`001P3oool7ool000L0oooo0ooo00050?ooo`Woo`001P3oool6
ool000L0oooo1Ooo000:0?ooo`Soo`00703oool3ool00080oooo0@0000010?ooo`0000<000000?oo
o`3oool0>03oool3ool00080oooo0ooo00060?ooo`Koo`00403oool3ool000X0oooo0ooo00040?oo
o`Goo`004@3oool:ool00080oooo0ooo000A0?ooo`Goo`001P3oool7ool000l0oooo2Ooo00070?oo
o`Koo`001P3oool5ool000X0oooo2?oo0000103oooooo`00ool00?oo000G0?ooo`Goo`000@3oool1
00000040oooo00000`000000oooo0?ooo`0g0?ooo`[oo`001@3oool9ool000`0oooo1Ooo00080?oo
o`?oo`001@3oool5ool000<0oooo0ooo000>0?ooo`Goo`000`3oool5ool000l0oooo1_oo00060?oo
o`Koo`004@3oool3ool000030?oooooo003oo`0000?oo`001`3oool5ool000H0oooo1Ooo000:0?oo
o`goo`004`3oool8ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool0=`3oool:ool000@0
oooo2ooo000;0?ooo`Goo`0000@0ooooool00?oo003oo`000`3oool5ool000D0oooo0ooo00030?oo
o`Ooo`001`3oool3ool000030?oooooo003oo`0000?oo`000`3oool5ool000l0oooo1Ooo00080?oo
o`?oo`005`3oool5ool000L0oooo1Ooo00050?ooo`Koo`002@3oool8ool000030?oooooo003oo`00
00Coo`000P3oool3ool000D0oooo0ooo00040?ooo`Woo`000@3oool100000040oooo00000`000000
oooo0?ooo`0g0?ooo`[oo`00103oool;ool000/0oooo2_oo00020?ooo`Goo`00103oool3ool000@0
oooo2?oo00050?ooo`_oo`000P3oool5ool000l0oooo1Ooo000R0?ooo`Goo`00203oool3ool000D0
oooo1ooo00090?ooo`ooo`0000<0ooooool00?oo00001?oo00020?ooo`Goo`000`3oool8ool00080
oooo0@0000010?ooo`0000<000000?ooo`3oool0>03oool3ool000030?oooooo003oo`0000?oo`00
103oool;ool00080oooo0ooo00070?ooo`Woo`000P3oool5ool000<0oooo1Ooo00000`3oooooo`00
ool00008ool000@0oooo3Ooo00000`3oooooo`00ool00003ool00100oooo0ooo000H0?ooo`?oo`00
0P3oool3ool000<0oooo1Ooo000@0?ooo`Koo`002P3oool?ool000030?oooooo003oo`0000Goo`00
00<0ooooool00?oo00002ooo00050?ooo`4000000@3oool000030000003oool0oooo03`0oooo1Ooo
00040?ooo`Goo`000P3oool3ool00080oooo1Ooo00020?ooo`?oo`0000<0ooooool00?oo00001ooo
00030?ooo`?oo`00103oool@ool000<0oooo3_oo00000`3oooooo`00ool00003ool002X0oooo2_oo
00030?ooo`?oo`00103oool3ool000X0oooo1Ooo000<0?ooo`goo`000P3oool7ool000030?oooooo
003oo`0000[oo`001P3oool100000040oooo00000`000000oooo0?ooo`0l0?ooo`Goo`00103oool5
ool000L0oooo1Ooo00000`3oooooo`00ool0000;ool000/0oooo2_oo00020?ooo`?oo`00103oool6
ool000030?oooooo003oo`0000Goo`0000<0ooooool00?oo00000ooo000=0?ooo`?oo`0000@0oooo
ool00?oo003oo`003@3oool3ool000H0oooo2_oo00090?ooo`Soo`001`3oool3ool000h0oooo1_oo
0000103oooooo`00ool00?oo00050?ooo`Koo`000P3oool8ool000T0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0?03oool4ool000H0oooo0ooo00080?ooo`Goo`0000<0ooooool00?oo00000ooo
0000103oooooo`00ool00?oo000@0?ooo`?oo`0000<0ooooool00?oo00000ooo0000103oooooo`00
ool00?oo00040?ooo`Koo`000`3oool5ool000<0oooo0ooo000=0?ooo`Woo`001`3oool3ool00003
0?oooooo003oo`0000?oo`00103oool;ool000T0oooo2Ooo000I0?ooo`?oo`002`3oool6ool00080
oooo1ooo00090?ooo`4000000@3oool000030000003oool0oooo03/0oooo1Ooo00020?ooo`?oo`00
3@3oool3ool00080oooo1Ooo00090?ooo`?oo`003@3oool3ool000030?oooooo003oo`0000?oo`00
0P3oool6ool001P0oooo0ooo00000`3oooooo`00ool00007ool000<0oooo3Ooo00030?ooo`Koo`00
0P3oool3ool000X0oooo2Ooo000F0?ooo`?oo`003@3oool?ool000X0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0>`3oool5ool000030?oooooo003oo`0000?oo`00103oool3ool000/0oooo0ooo
00090?ooo`Goo`000P3oool3ool000/0oooo1Ooo00020?ooo`Goo`00603oool>ool00080oooo5ooo
00080?ooo`?oo`001@3oool8ool001D0oooo1Ooo000<0?ooo`goo`00303oool100000040oooo0000
0`000000oooo0?ooo`0k0?ooo`Goo`0000<0ooooool00?oo00000ooo00030?ooo`Goo`00303oool3
ool000L0oooo1Ooo00000`3oooooo`00ool00004ool000T0oooo1Ooo00000`3oooooo`00ool00004
ool00080oooo1_oo00090?ooo`?oo`00103oool5ool000030?oooooo003oo`0000Goo`000`3oool9
ool000030?oooooo003oo`0000_oo`001`3oool5ool000L0oooo1?oo000F0?ooo`Goo`00303oool=
ool000`0oooo0@0000010?ooo`0000<000000?ooo`3oool0>`3oool5ool000030?oooooo003oo`00
00?oo`000`3oool5ool00080oooo0ooo00060?ooo`Goo`001P3oool5ool000030?oooooo003oo`00
00Goo`002@3oool3ool000030?oooooo003oo`0000Coo`000P3oool8ool000L0oooo1Ooo00030?oo
o`Goo`000`3oool5ool000<0oooo2?oo00030?ooo`_oo`000P3oool3ool000<0oooo1Ooo00060?oo
o`Goo`005P3oool5ool000d0oooo2ooo000=0?ooo`4000000@3oool000030000003oool0oooo03`0
oooo0ooo00030?ooo`?oo`00103oool5ool000030?oooooo003oo`0000?oo`001@3oool5ool000L0
oooo0ooo00020?ooo`Ooo`003@3oool5ool000<0oooo2?oo00070?ooo`Goo`00103oool3ool000@0
oooo1Ooo00040?ooo`?oo`001`3oool;ool000030?oooooo003oo`0000?oo`000P3oool5ool000H0
oooo1Ooo000<0?ooo`?oo`00203oool5ool00080oooo0ooo00020?ooo`?oo`000P3oool;ool000d0
oooo0@0000010?ooo`0000<000000?ooo`3oool0BP3oool3ool00080oooo1Ooo00050?ooo`Goo`00
3@3oool6ool000d0oooo1Ooo00030?ooo`Soo`001`3oool5ool000`0oooo0ooo000?0?ooo`[oo`00
0P3oool5ool000<0oooo0ooo00070?ooo`Goo`002`3oool5ool000P0oooo3ooo00020?ooo`[oo`00
0`3oool5ool000D0oooo0@0000010?ooo`0000<000000?ooo`3oool0C`3oool5ool000H0oooo0ooo
000@0?ooo`?oo`003`3oool3ool000D0oooo1_oo00090?ooo`?oo`00803oool3ool000040?oooooo
003oo`00ool000@0oooo1Ooo000>0?ooo`?oo`00303oool5ool000P0oooo3ooo00020?ooo`[oo`00
0P3oool7ool000@0oooo0@0000010?ooo`0000<000000?ooo`3oool0D03oool3ool00780oooo0ooo
000N0?ooo`Goo`00203oool?ool00080oooo1Ooo0000103oooooo`00ool00?oo00020?ooo`Soo`00
103oool100000040oooo00000`000000oooo0?ooo`3W0?ooo`?oo`002P3oool3ool00080oooo0ooo
00000`3oooooo`00ool00002ool000@0oooo0ooo00060?ooo`Woo`00103oool100000040oooo0000
0`000000oooo0?ooo`3l0?ooo`Goo`003@3oool9ool000@0oooo0@0000010?ooo`0000<000000?oo
o`3oool0o03oool5ool000d0oooo2?oo00050?ooo`4000000@3oool000030000003oool0oooo0?`0
oooo1Ooo000>0?ooo`?oo`002@3oool100000040oooo00000`000000oooo0?ooo`3m0?ooo`?oo`00
3P3oool5ool000@0oooo0ooo00010?ooo`4000000@3oool000030000003oool0oooo0?h0oooo0ooo
0000103oooooo`00ool00?oo00090?ooo`Goo`000`3oool5ool0004000000@3oool000030000003o
ool0oooo0?d0oooo2Ooo00080?ooo`Goo`000`3oool5ool0004000000@3oool000030000003oool0
oooo0?d0oooo2Ooo00090?ooo`?oo`00103oool5ool0004000000@3oool000030000003oool0oooo
0>D0oooo0ooo0000103oooooo`00ool00?oo00050?ooo`?oo`002@3oool9ool000d0oooo0ooo0000
1P3oooooo`00ool00?oo0000oooo00000040oooo00000`000000oooo0?ooo`3R0?ooo`_oo`000P3o
ool9ool000D0oooo1?oo0000103oooooo`00ool00?oo000=0?ooo`Goo`00103oool100000040oooo
00000`000000oooo0?ooo`3Q0?ooo`coo`0000<0ooooool00?oo00002Ooo00030?ooo`Goo`004@3o
ool5ool000@0oooo0@0000010?ooo`0000<000000?ooo`3oool0h@3oool<ool000030?oooooo003o
o`0000Woo`000`3oool5ool00140oooo1Ooo00040?ooo`4000000@3oool000030000003oool0oooo
0>40oooo2ooo00020?ooo`_oo`000`3oool5ool00180oooo0ooo00050?ooo`4000000@3oool00003
0000003oool0oooo0>80oooo0ooo00020?ooo`Goo`000`3oool9ool000D0oooo0ooo000D0?ooo`?o
o`00103oool100000040oooo00000`000000oooo0?ooo`3W0?ooo`Goo`0000D0ooooool00?oo003o
o`000?ooo`06ool000@0oooo0ooo000E0?ooo`Goo`000`3oool100000040oooo00000`000000oooo
0?ooo`3W0?oooa7oo`0000<0ooooool00?oo00001?oo000@0?ooo`?oo`0000<0ooooool00?oo0000
0ooo00030?ooo`4000000@3oool000030000003oool0oooo0>H0oooo1Ooo00000`3oooooo`00ool0
000Aool000l0oooo2_oo00030?ooo`4000000@3oool000030000003oool0oooo0>D0oooo1Ooo0002
0?ooo`Goo`0000<0ooooool00?oo00002ooo000?0?ooo`Goo`0000@0ooooool00?oo003oo`00103o
ool100000040oooo00000`000000oooo0?ooo`3S0?ooo`Soo`000P3oool3ool000@0oooo2_oo0003
0?ooo`?oo`002P3oool5ool000P0oooo0@0000010?ooo`0000<000000?ooo`3oool0hP3oool:ool0
00T0oooo0ooo0000103oooooo`00ool00?oo00040?ooo`Soo`001`3oool3ool000T0oooo0@000001
0?ooo`0000<000000?ooo`3oool0hP3oool:ool001@0oooo2Ooo000>0?ooo`?oo`000@3oool10000
0040oooo00000`000000oooo0?ooo`3R0?ooo`[oo`001@3oool3ool000`0oooo2Ooo000=0?ooo`Go
o`000@0000010?ooo`0000<000000?ooo`3oool0h`3oool8ool000D0oooo1Ooo000<0?ooo`Soo`00
3@3oool5ool0004000000@3oool000030000003oool0oooo0>H0oooo1ooo00030?ooo`Goo`00303o
ool3ool000040?oooooo003oo`00ool00080oooo0ooo00090?ooo`Goo`000@0000010?ooo`0000<0
00000?ooo`3oool0j@3oool5ool00080oooo1Ooo00050?ooo`?oo`000`3oool5ool000030?oooooo
003oo`0000Koo`001@3oool3ool000060?oooooo003oo`00ool0003oool000000@3oool000030000
003oool0oooo0>T0oooo1Ooo00020?ooo`Goo`00103oool5ool00080oooo4?oo00020?ooo`Goo`00
103oool100000040oooo00000`000000oooo0?ooo`3Y0?ooo`Goo`000P3oool5ool000@0oooo1Ooo
00020?oooa7oo`0000<0ooooool00?oo00000ooo00040?ooo`4000000@3oool000030000003oool0
oooo0>00oooo0ooo00060?ooo`Goo`000P3oool5ool000<0oooo1_oo00000`3oooooo`00ool00003
ool000030?oooooo003oo`0000[oo`0000<0ooooool00?oo00000ooo00040?ooo`4000000@3oool0
00030000003oool0oooo0=l0oooo1Ooo00050?ooo`Goo`0000<0ooooool00?oo00000ooo00030?oo
o`Koo`000P3oool5ool00080oooo0ooo00030?ooo`Goo`000P3oool3ool000D0oooo0@0000010?oo
o`0000<000000?ooo`3oool0g`3oool5ool000H0oooo0ooo00000`3oooooo`00ool00003ool000@0
oooo1_oo00020?ooo`Goo`002@3oool3ool000/0oooo0@0000010?ooo`0000<000000?ooo`3oool0
g`3oool5ool000X0oooo1Ooo00040?ooo`Ooo`0000<0ooooool00?oo00000ooo00050?ooo`?oo`00
3`3oool100000040oooo00000`000000oooo0?ooo`3N0?ooo`Goo`002`3oool7ool000<0oooo3?oo
00040?ooo`Goo`003P3oool100000040oooo00000`000000oooo0?ooo`3N0?ooo`Goo`002`3oool8
ool000<0oooo1_oo0000103oooooo`00ool00?oo00050?ooo`Goo`003P3oool100000040oooo0000
0`000000oooo0?ooo`3N0?ooo`Goo`00303oool7ool000<0oooo1_oo00090?ooo`Goo`003P3oool1
00000040oooo00000`000000oooo0?ooo`3O0?ooo`?oo`003`3oool5ool000<0oooo1Ooo00070?oo
o`?oo`0000@0ooooool00?oo003oo`003`3oool100000040oooo00000`000000oooo0?ooo`3b0?oo
o`Goo`000P3oool5ool000H0oooo1Ooo000:0?ooo`?oo`001@3oool100000040oooo00000`000000
oooo0?ooo`3c0?ooo`Goo`000P3oool3ool000L0oooo1Ooo00090?ooo`Goo`00103oool100000040
oooo00000`000000oooo0?ooo`3[0?ooo`?oo`001@3oool5ool000<0oooo0ooo00060?ooo`Goo`00
2@3oool5ool000@0oooo0@0000010?ooo`0000<000000?ooo`3oool0jP3oool5ool000@0oooo1Ooo
00020?ooo`Goo`001P3oool3ool000T0oooo1ooo00030?ooo`4000000@3oool000030000003oool0
oooo0>X0oooo1Ooo00050?ooo`?oo`000`3oool5ool000D0oooo0ooo00090?ooo`Woo`000P3oool1
00000040oooo00000`000000oooo0?ooo`3Z0?ooo`Goo`002`3oool5ool000@0oooo1Ooo00080?oo
o`[oo`000@3oool100000040oooo00000`000000oooo0?ooo`3[0?ooo`?oo`000`3oool3ool000H0
oooo1Ooo00040?ooo`Goo`00203oool;ool0004000000@3oool000030000003oool0oooo0?00oooo
1Ooo00001@3oooooo`00ool00?oo0000oooo00Goo`00103oool8ool000H0oooo0ooo00000`3ooooo
o`00ool00004ool0004000000@3oool000030000003oool0oooo0?00oooo3ooo00050?ooo`Soo`00
203oool7ool0004000000@3oool000030000003oool0oooo0?00oooo3_oo0000103oooooo`00ool0
0?oo00050?ooo`Goo`000`3oool3ool000030?oooooo003oo`0000Goo`000@3oool100000040oooo
00000`000000oooo0?ooo`3a0?ooo`?oo`0000<0ooooool00?oo00001_oo00000`3oooooo`00ool0
0003ool000@0oooo1Ooo00020?ooo`[oo`000`3oool100000040oooo00000`000000oooo0?ooo`3V
0?ooo`?oo`003@3oool7ool000030?oooooo003oo`0000?oo`001@3oool5ool000030?oooooo003o
o`0000Soo`000`3oool100000040oooo00000`000000oooo0?ooo`3U0?ooo`Goo`003P3oool5ool0
00030?oooooo003oo`0000?oo`001P3oool?ool000<0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0i@3oool5ool000l0oooo1Ooo0000103oooooo`00ool00?oo00060?ooo`[oo`0000<0ooooool0
0?oo00000ooo00030?ooo`4000000@3oool000030000003oool0oooo0>D0oooo1Ooo000>0?ooo`Ko
o`002P3oool:ool000030?oooooo003oo`0000?oo`000`3oool100000040oooo00000`000000oooo
0?ooo`3V0?ooo`?oo`003`3oool6ool000X0oooo2_oo00020?ooo`?oo`00103oool100000040oooo
00000`000000oooo0?ooo`3a0?ooo`?oo`00103oool5ool000L0oooo3Ooo000:0?ooo`4000000@3o
ool000030000003oool0oooo0?00oooo1Ooo00040?ooo`?oo`001`3oool>ool000X0oooo0@000001
0?ooo`0000<000000?ooo`3oool0l03oool5ool000h0oooo3_oo000:0?ooo`4000000@3oool00003
0000003oool0oooo0?00oooo1Ooo000>0?ooo`goo`002`3oool100000040oooo00000`000000oooo
0?ooo`3a0?ooo`?oo`00403oool6ool000040?oooooo003oo`00ool000d0oooo0@0000010?ooo`00
o`00000P00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generate sample EM results with varying number of component \
densities\
\>", "Subsection"],

Cell[BoxData[
    \(\(results = Table[EMAll3[data1, k], {k, 2, 15}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of training data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 -0.27138 0.00132793 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .127 -18 -4.5 ]
[-0.0125 .127 0 4.5 ]
[-0.0125 .25979 -18 -4.5 ]
[-0.0125 .25979 0 4.5 ]
[-0.0125 .39259 -18 -4.5 ]
[-0.0125 .39259 0 4.5 ]
[-0.0125 .52538 -18 -4.5 ]
[-0.0125 .52538 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .127 m
1 .127 L
s
0 .25979 m
1 .25979 L
s
0 .39259 m
1 .39259 L
s
0 .52538 m
1 .52538 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .127 m
.00625 .127 L
s
[(300)] -0.0125 .127 1 0 Mshowa
0 .25979 m
.00625 .25979 L
s
[(400)] -0.0125 .25979 1 0 Mshowa
0 .39259 m
.00625 .39259 L
s
[(500)] -0.0125 .39259 1 0 Mshowa
0 .52538 m
.00625 .52538 L
s
[(600)] -0.0125 .52538 1 0 Mshowa
.125 Mabswid
0 .02076 m
.00375 .02076 L
s
0 .04732 m
.00375 .04732 L
s
0 .07388 m
.00375 .07388 L
s
0 .10044 m
.00375 .10044 L
s
0 .15356 m
.00375 .15356 L
s
0 .18012 m
.00375 .18012 L
s
0 .20668 m
.00375 .20668 L
s
0 .23323 m
.00375 .23323 L
s
0 .28635 m
.00375 .28635 L
s
0 .31291 m
.00375 .31291 L
s
0 .33947 m
.00375 .33947 L
s
0 .36603 m
.00375 .36603 L
s
0 .41914 m
.00375 .41914 L
s
0 .4457 m
.00375 .4457 L
s
0 .47226 m
.00375 .47226 L
s
0 .49882 m
.00375 .49882 L
s
0 .55194 m
.00375 .55194 L
s
0 .5785 m
.00375 .5785 L
s
0 .60506 m
.00375 .60506 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .127 m
1 .127 L
s
.99375 .25979 m
1 .25979 L
s
.99375 .39259 m
1 .39259 L
s
.99375 .52538 m
1 .52538 L
s
.125 Mabswid
.99625 .02076 m
1 .02076 L
s
.99625 .04732 m
1 .04732 L
s
.99625 .07388 m
1 .07388 L
s
.99625 .10044 m
1 .10044 L
s
.99625 .15356 m
1 .15356 L
s
.99625 .18012 m
1 .18012 L
s
.99625 .20668 m
1 .20668 L
s
.99625 .23323 m
1 .23323 L
s
.99625 .28635 m
1 .28635 L
s
.99625 .31291 m
1 .31291 L
s
.99625 .33947 m
1 .33947 L
s
.99625 .36603 m
1 .36603 L
s
.99625 .41914 m
1 .41914 L
s
.99625 .4457 m
1 .4457 L
s
.99625 .47226 m
1 .47226 L
s
.99625 .49882 m
1 .49882 L
s
.99625 .55194 m
1 .55194 L
s
.99625 .5785 m
1 .5785 L
s
.99625 .60506 m
1 .60506 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .43863 L
.17033 .47952 L
.24359 .50935 L
.31685 .50054 L
.39011 .55435 L
.46337 .56593 L
.53663 .5424 L
.60989 .56228 L
.68315 .59869 L
.75641 .57745 L
.82967 .59587 L
.90293 .5814 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .43863 Mdot
.17033 .47952 Mdot
.24359 .50935 Mdot
.31685 .50054 Mdot
.39011 .55435 Mdot
.46337 .56593 Mdot
.53663 .5424 Mdot
.60989 .56228 Mdot
.68315 .59869 Mdot
.75641 .57745 Mdot
.82967 .59587 Mdot
.90293 .5814 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0002Cooooo0ol0000Sooooo`?o00009?ooool3o`00027ooooo0ol00004oooo
o`;o00007_ooool3o`0000;ooooo1Ol0000Mooooo`?o00001?ooool3o`0001Kooooo000Iooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooo
ooooo`0Rooooo`Go00008_ooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooooooo
ooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`006oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0002?ooooo1?l0
000Tooooo`?o00008_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000002?o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`006?ooool01Ol0003ooooooooooooooooo000002Cooooo0_l0
000Tooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000
1?ooool01?l0003oooooooooool0000Mooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01gooooo0_l00005ooooo`;o00005oooool001Wooooo0ol0000Vooooo`03o`000?oooooooooo02?o
oooo0_l0000Tooooo`?o00008_ooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003o
ooooooooo`02ooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eooooo`03
00000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`02ooooo`?oo`009Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool10000007ooooo000E
ooooo`0400000?ooooooooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0400000?oooooo
ooooooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0400000?ooooooooooooooo`Goo`009?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?l0003ooooo00;ooooo0ooo000Uooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o
0000ooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool08Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00Kooooo00<0
0000ooooooooool08Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0Pooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0P
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000o`000?ooool01oooool00`00003oooooooooo`0Poooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eoooo
o`7o00000@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo023ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01oooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00001Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool07oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0002ooooo`;o
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
o`00000007l0200007l00`000000001o0000O`3j0000O`7o00000@000001ooooo`001?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo01oooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01kooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
00Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Wo
oooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<0
0000ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00Wooooo00<00000oooo
ooooool07_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`0Mooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003ooooo
ooooo`0Mooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003ooooooooo
o`0Mooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0M
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Moooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000ooooooooool02oooool00`00003oooooooooo`0Looooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000o`000?ooool02oooool00`00003oooooooooo`0Looooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o0000
0@000001ooooo`005Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool0
0`00003o0000ooooo`0<ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eoooo
o`0300000?oooooooooo00cooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo00cooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo
00gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo00go
oooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0
3Oooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03_oo
ool00`00003oooooooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03_ooool0
0`00003oooooooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03_ooool00`00
003oooooooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool000;ooooo0ol00003ooooo`;o00001?ooool2o`0000Go
oooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Wooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`001Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0`00003o00000000O`0>0000O`030000000007l0001o0?@0001o0Ol000010000007ooooo00001?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Co
ooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Hooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`000oooool00ol0
003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Hooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0Hooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0Hooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool04?ooool00`00003ooooooooo
o`0Gooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooo
oooo01Oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo
01Oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo01Oo
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo01Oooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Kooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Kooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003o0000ooooo`0Aooooo`0300000?oooooooooo01Kooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000
007ooooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool05_ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007o
oooo000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool05_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo017ooooo00<00000ooooooooool05_ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo01;ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo01;ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?l0003ooooo01;ooooo00<00000ooooooooool05Oooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool04_ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooo
ooooool04oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool04oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
4oooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04ooo
ool00`00003oooooooooo`0Dooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool04oooool0
0`00003oooooooooo`0Dooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Doooo
o`0300000?oooooooooo01?ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Dooooo`03
00000?oooooooooo01?ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Dooooo`030000
0?oooooooooo01?ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Dooooo`0300000?oo
oooooooo01?ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0000
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04oooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007o
oooo0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`0300000?l00000001o01D0001o00<000000000O`0007l0k@0007l1o`00
004000000Oooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0B
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Booooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool00003o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool04_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
0005o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Eooooo`0300000?oo
oooooooo01;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Eooooo`0300000?oooooo
oooo01;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo
017ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Fooooo`0300000?oooooooooo017o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Go
oooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool0
4Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool04Ooo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool04Oooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo01Gooooo0ooo000Booooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Go
oooo00<00000ooooooooool05?ooool5ool0017ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0Dooooo`Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo01Cooooo1Ooo
0002000000oooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo01Gooooo0ooo0003
ooooo`8000003Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01gooooo0P00000;oooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000ooooooooool07oooool2000000Wooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo00Kooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Rooooo`8000001_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo02Cooooo0P000004ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool09_ooool20000
00;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Xooooo`0400000?oo003oo`00ool0
02Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@000001oooo
o`005Oooool00`00003oooooooooo`0Xooooo`Goo`009?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Xooooo`Goo`00
0P00000Rooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo02Sooooo1Ooo0002ooooo`8000008?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Y
ooooo`?oo`001Oooool3000001gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`07oooo
o`8000006_ooool3ool002Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?oooooooooo02[ooooo00<0001oooooooooool02Oooool3000001Kooooo1Ooo000Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Zooooo`030000
Oooooooooooo00cooooo0P00000Aooooo`<000001Ooo000Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo
0Ol000010000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool03_oo
ool01000003oo`00ool00?oo0004ooooo`T000000oooool5ool002Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool03_oo
ool5ool000<000003Oooool3ool00003ooooo`00003ooooo02;ooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool03_ooool5
ool0017ooooo00@0001ooooooooooooooooo0P00000Qooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oo
oooooooo02[ooooo00<0001oooooooooool03_ooool5ool0017ooooo00<0001oooooooooool00ooo
ool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo00oooooo0ooo000Booooo`03
0000Oooooooooooo00Cooooo00<00000ooooooooool07Oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo00Gooooo0P00000Mooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`001?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003o00000000O`1K0000O`030000000007l0001o0:L0001o0Ol000010000007ooooo0000
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
2?ooool2000001[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00000ooooooo0000oooo
o`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool02_ooool00`00003o
ooooooooo`0Gooooo`030000Oooooooooooo00oooooo0ooo000Booooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000;ooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0:_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo00_ooooo00<00000ooooooooool05_ooool00`0007oooooo
ooooo`0>ooooo`Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0<ooooo`8000005_ooool00`0007oooooooooo
o`0>ooooo`Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0>ooooo`0400000?oo003oo`00ool001;ooooo00<0
001oooooooooool02oooool3000000Goo`001000000=ooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000
ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo00kooooo1Ooo000A
ooooo`030000Oooooooooooo00Sooooo0`000004ooooo`?oo`001Oooool4000000Wooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003o0000ooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool03_ooool5ool0000300000?oooooooooo00kooooo00<0001oooooooooool01Oooool30000
01?ooooo10000005ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool03_ooool5ool00003ooooo`000000000000D0
00002Oooool00`0007ooooooooooo`02ooooo`<000006_ooool4000000?oo`009Oooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool03oooool3ool000Wooooo
1`0000001?ooooooo`00ool00?oo00030000023ooooo1Ooo000Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Rooooo`Goo`008_ooool5ool000030000
0?oooooooooo027ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02;ooooo1Ooo000Rooooo`Goo`0000?ooooo0000000000008Oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Z
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool08_ooool5ool002?ooooo0ooo0004
ooooo`8000007_ooool3ool002Gooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Soooo
o`?oo`009Oooool00`0007ooooooooooo`05ooooo`8000006oooool5ool002;ooooo0ooo000Hoooo
o`4000000Oooool001Gooooo00<00000o`000?ooool0:_ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`07ooooo`03
00000?oooooooooo01Gooooo0`000005ool000@000007Oooool5ool001Kooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool02?ooool2000001;ooooo
0`000003ooooo`Goo`001?ooool4000001Wooooo1Ooo00000`00003oooooooooo`0Dooooo`400000
0Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0:ooooo`8000003?oo
ool4000000Oooooo0ooo0009ooooo`<000001?ooool3ool000Sooooo1`000005ool00003ooooo`00
00000000008000004_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool03?ooool200000004oooooooo003oo`00ool000?ooooo0`00000<ooooo`030000Oooo
oooooooo00_ooooo0`000005ool000L000002?ooool3ool000Kooooo1000000>ooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`Goo`000P00000?
ooooo`030000Oooooooooooo00kooooo1Ooo000Aooooo`030000Oooooooooooo00Sooooo0`000004
ooooo`?oo`001?ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool03_ooool5ool0017ooooo00<0001oooooooooool03_ooool5ool0017ooooo00<0001ooooo
ooooool02oooool3000000Goo`000oooool10000007ooooo000Eooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool03_ooool5ool0017ooooo00<0001oooooooooool03oooool3ool001;o
oooo00<0001oooooooooool03_ooool5ool000?ooooo0@000001ooooo`005Oooool00`00003o0000
ooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo00oooooo0ooo000Booooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool03_ooool5ool000;ooooo0Ol000010000007ooooo000Eooooo`0300000?oo
oooooooo02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo00oooooo0ooo0004ooooo`4000000Oooool001Gooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool1
0000007ooooo000Eooooool000002`000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.579071, 168.721, \
0.0514022, 2.83579}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot log-likelihood of test data as a function of k", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood2[Last\  /@ \ results, data2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.122711 0.0732601 -0.398269 0.0016166 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17033 -0.0125 -3 -9 ]
[.17033 -0.0125 3 0 ]
[.31685 -0.0125 -3 -9 ]
[.31685 -0.0125 3 0 ]
[.46337 -0.0125 -3 -9 ]
[.46337 -0.0125 3 0 ]
[.60989 -0.0125 -6 -9 ]
[.60989 -0.0125 6 0 ]
[.75641 -0.0125 -6 -9 ]
[.75641 -0.0125 6 0 ]
[.90293 -0.0125 -6 -9 ]
[.90293 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00588 -18 -4.5 ]
[-0.0125 .00588 0 4.5 ]
[-0.0125 .08671 -18 -4.5 ]
[-0.0125 .08671 0 4.5 ]
[-0.0125 .16754 -18 -4.5 ]
[-0.0125 .16754 0 4.5 ]
[-0.0125 .24837 -18 -4.5 ]
[-0.0125 .24837 0 4.5 ]
[-0.0125 .3292 -18 -4.5 ]
[-0.0125 .3292 0 4.5 ]
[-0.0125 .41003 -18 -4.5 ]
[-0.0125 .41003 0 4.5 ]
[-0.0125 .49086 -18 -4.5 ]
[-0.0125 .49086 0 4.5 ]
[-0.0125 .57169 -18 -4.5 ]
[-0.0125 .57169 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17033 0 m
.17033 .61803 L
s
.31685 0 m
.31685 .61803 L
s
.46337 0 m
.46337 .61803 L
s
.60989 0 m
.60989 .61803 L
s
.75641 0 m
.75641 .61803 L
s
.90293 0 m
.90293 .61803 L
s
0 .08671 m
1 .08671 L
s
0 .16754 m
1 .16754 L
s
0 .24837 m
1 .24837 L
s
0 .3292 m
1 .3292 L
s
0 .41003 m
1 .41003 L
s
0 .49086 m
1 .49086 L
s
0 .57169 m
1 .57169 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.17033 0 m
.17033 .00625 L
s
[(4)] .17033 -0.0125 0 1 Mshowa
.31685 0 m
.31685 .00625 L
s
[(6)] .31685 -0.0125 0 1 Mshowa
.46337 0 m
.46337 .00625 L
s
[(8)] .46337 -0.0125 0 1 Mshowa
.60989 0 m
.60989 .00625 L
s
[(10)] .60989 -0.0125 0 1 Mshowa
.75641 0 m
.75641 .00625 L
s
[(12)] .75641 -0.0125 0 1 Mshowa
.90293 0 m
.90293 .00625 L
s
[(14)] .90293 -0.0125 0 1 Mshowa
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.20696 0 m
.20696 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00588 m
.00625 .00588 L
s
[(250)] -0.0125 .00588 1 0 Mshowa
0 .08671 m
.00625 .08671 L
s
[(300)] -0.0125 .08671 1 0 Mshowa
0 .16754 m
.00625 .16754 L
s
[(350)] -0.0125 .16754 1 0 Mshowa
0 .24837 m
.00625 .24837 L
s
[(400)] -0.0125 .24837 1 0 Mshowa
0 .3292 m
.00625 .3292 L
s
[(450)] -0.0125 .3292 1 0 Mshowa
0 .41003 m
.00625 .41003 L
s
[(500)] -0.0125 .41003 1 0 Mshowa
0 .49086 m
.00625 .49086 L
s
[(550)] -0.0125 .49086 1 0 Mshowa
0 .57169 m
.00625 .57169 L
s
[(600)] -0.0125 .57169 1 0 Mshowa
.125 Mabswid
0 .02205 m
.00375 .02205 L
s
0 .03821 m
.00375 .03821 L
s
0 .05438 m
.00375 .05438 L
s
0 .07055 m
.00375 .07055 L
s
0 .10288 m
.00375 .10288 L
s
0 .11904 m
.00375 .11904 L
s
0 .13521 m
.00375 .13521 L
s
0 .15138 m
.00375 .15138 L
s
0 .18371 m
.00375 .18371 L
s
0 .19987 m
.00375 .19987 L
s
0 .21604 m
.00375 .21604 L
s
0 .23221 m
.00375 .23221 L
s
0 .26454 m
.00375 .26454 L
s
0 .2807 m
.00375 .2807 L
s
0 .29687 m
.00375 .29687 L
s
0 .31304 m
.00375 .31304 L
s
0 .34537 m
.00375 .34537 L
s
0 .36153 m
.00375 .36153 L
s
0 .3777 m
.00375 .3777 L
s
0 .39387 m
.00375 .39387 L
s
0 .4262 m
.00375 .4262 L
s
0 .44236 m
.00375 .44236 L
s
0 .45853 m
.00375 .45853 L
s
0 .4747 m
.00375 .4747 L
s
0 .50703 m
.00375 .50703 L
s
0 .52319 m
.00375 .52319 L
s
0 .53936 m
.00375 .53936 L
s
0 .55553 m
.00375 .55553 L
s
0 .58786 m
.00375 .58786 L
s
0 .60402 m
.00375 .60402 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17033 .61178 m
.17033 .61803 L
s
.31685 .61178 m
.31685 .61803 L
s
.46337 .61178 m
.46337 .61803 L
s
.60989 .61178 m
.60989 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.90293 .61178 m
.90293 .61803 L
s
.125 Mabswid
.06044 .61428 m
.06044 .61803 L
s
.09707 .61428 m
.09707 .61803 L
s
.1337 .61428 m
.1337 .61803 L
s
.20696 .61428 m
.20696 .61803 L
s
.24359 .61428 m
.24359 .61803 L
s
.28022 .61428 m
.28022 .61803 L
s
.35348 .61428 m
.35348 .61803 L
s
.39011 .61428 m
.39011 .61803 L
s
.42674 .61428 m
.42674 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53663 .61428 m
.53663 .61803 L
s
.57326 .61428 m
.57326 .61803 L
s
.64652 .61428 m
.64652 .61803 L
s
.68315 .61428 m
.68315 .61803 L
s
.71978 .61428 m
.71978 .61803 L
s
.79304 .61428 m
.79304 .61803 L
s
.82967 .61428 m
.82967 .61803 L
s
.8663 .61428 m
.8663 .61803 L
s
.93956 .61428 m
.93956 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00588 m
1 .00588 L
s
.99375 .08671 m
1 .08671 L
s
.99375 .16754 m
1 .16754 L
s
.99375 .24837 m
1 .24837 L
s
.99375 .3292 m
1 .3292 L
s
.99375 .41003 m
1 .41003 L
s
.99375 .49086 m
1 .49086 L
s
.99375 .57169 m
1 .57169 L
s
.125 Mabswid
.99625 .02205 m
1 .02205 L
s
.99625 .03821 m
1 .03821 L
s
.99625 .05438 m
1 .05438 L
s
.99625 .07055 m
1 .07055 L
s
.99625 .10288 m
1 .10288 L
s
.99625 .11904 m
1 .11904 L
s
.99625 .13521 m
1 .13521 L
s
.99625 .15138 m
1 .15138 L
s
.99625 .18371 m
1 .18371 L
s
.99625 .19987 m
1 .19987 L
s
.99625 .21604 m
1 .21604 L
s
.99625 .23221 m
1 .23221 L
s
.99625 .26454 m
1 .26454 L
s
.99625 .2807 m
1 .2807 L
s
.99625 .29687 m
1 .29687 L
s
.99625 .31304 m
1 .31304 L
s
.99625 .34537 m
1 .34537 L
s
.99625 .36153 m
1 .36153 L
s
.99625 .3777 m
1 .3777 L
s
.99625 .39387 m
1 .39387 L
s
.99625 .4262 m
1 .4262 L
s
.99625 .44236 m
1 .44236 L
s
.99625 .45853 m
1 .45853 L
s
.99625 .4747 m
1 .4747 L
s
.99625 .50703 m
1 .50703 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .53936 m
1 .53936 L
s
.99625 .55553 m
1 .55553 L
s
.99625 .58786 m
1 .58786 L
s
.99625 .60402 m
1 .60402 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.09707 .46919 L
.17033 .4983 L
.24359 .50103 L
.31685 .52848 L
.39011 .55049 L
.46337 .56449 L
.53663 .55575 L
.60989 .58418 L
.68315 .60332 L
.75641 .55653 L
.82967 .58471 L
.90293 .57605 L
.97619 .59867 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.09707 .46919 Mdot
.17033 .4983 Mdot
.24359 .50103 Mdot
.31685 .52848 Mdot
.39011 .55049 Mdot
.46337 .56449 Mdot
.53663 .55575 Mdot
.60989 .58418 Mdot
.68315 .60332 Mdot
.75641 .55653 Mdot
.82967 .58471 Mdot
.90293 .57605 Mdot
.97619 .59867 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0002Cooooo0ol0000Sooooo`?o00009?ooool3o`00027ooooo0ol00004oooo
o`;o00007_ooool3o`0000;ooooo1Ol0000Mooooo`?o00001?ooool3o`0001Kooooo000Iooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooo
ooooo`0Rooooo`Go00008_ooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooooooo
ooooooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol0
000Fooooo`006oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0002?ooooo1?l0
000Tooooo`?o00008_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000002?o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Gooooo`006?ooool01Ol0003ooooooooooooooooo000002Cooooo0_l0
000Tooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000
1?ooool01?l0003oooooooooool0000Mooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01gooooo0_l00005ooooo`;o00005oooool001Wooooo0ol0000Vooooo`03o`000?oooooooooo02?o
oooo0_l0000Tooooo`?o00008_ooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003o
ooooooooo`02ooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0005o`0000;ooooo0ol00004oooo
o`;o0000oooooolAooooo`0000Ooooooo`000?ooooooooooo`000?oooooo000000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l0003o00000?oo00001ol0
00010000007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`000oooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00`00003o0000ooooo`02ooooo`?oo`009Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool05Oooool1o`00004000000Oooool00006o`000?oooooo
ooooooooool0003ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00@00000oooooooo
oooooooo1Ooo000Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool00007o`000?ooooooooooooooool0003oooooo`000006
ooooo`04o`000?ooooooooooo`0000Cooooo00@00000oooooooooooooooo1Ooo000Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool00004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`;o00001Oooool01000003ooooo
ooooooooool5ool002Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`02ooooo`?oo`00
9Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0S
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Soooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000o`000?ooool01?ooool00`00003oooooooooo`0Sooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003o0000ooooo`05ooooo`0300000?oooooooooo02;ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo
000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?l0003ooooo00Gooooo00<00000ooooooooool08_ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Go
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00004oooo
ool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo027ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo027ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o00000000
O`060000O`030000000007l0001o0?`0001o0Ol000010000007ooooo0002ooooo`;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000Cooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool01_ooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00005o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool01oooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00004ooooool0003o0000
o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003o0000ooooo`07ooooo`0300000?oooooo
oooo023ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool08?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool08?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
8?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool08?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?l0003ooooo00Sooooo00<00000ooooooooool07oooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1
o`00004000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Ooooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Foooo
o`4000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Oooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Oooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool001Gooooo00<00000o`000?ooool02?ooool00`00003oooooooooo`0Oooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01oooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01kooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01kooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`09ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo
000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool07_ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0000
1?oooooo0000o`000?l00003ooooo`?o00001?ooool2o`0000Gooooo00<00000ooooooooool02Ooo
ool00`00003oooooooooo`0Nooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool00007o`000?ooooooooooooooool0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001?ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o
ooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`000_ooool2o`0000Kooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o00X0
001o00<000000000O`0007l0n00007l1o`00004000000Oooool000Cooooo00?o0000ooooool00000
0ol00003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`0Mooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool00007o`000?ooooooooooooooool0003oooooo`000006oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0M
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool00004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`;o00001Oooool0
0`00003oooooooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003o0000ooooo`0:ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`03
00000?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003o
oooo00_ooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`0Looooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0
3?ooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool03?oo
ool00`00003oooooooooo`0Kooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0<oooo
o`0300000?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0<ooooo`03
00000?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo01_ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0=ooooo`0300000?oo
oooooooo01[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00gooooo00<00000
ooooooooool06_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05_ooool10000007ooooo0002ooooo`?o00000oooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo00gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0003ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Jooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool0
00Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000o`00000007l03@0007l00`000000001o0000O`3e0000O`7o00000@000001ooooo`0000Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool00004oooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0002oooo
o`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool03_ooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool000?ooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo0_l00005ooooo`0300000?l0003ooooo00kooooo00<00000
ooooooooool06Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool03_ooool00`00
003oooooooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03_ooool00`00003o
ooooooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03_ooool00`00003ooooo
ooooo`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool03_ooool00`00003ooooooooo
o`0Iooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool03oooool00`00003oooooooooo`0H
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0E
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01Sooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01So
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Ko
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003o0000ooooo`0?ooooo`0300000?oooooooooo01Sooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol0
00010000007ooooo000Eooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool05oooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000
007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool05oooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007o
oooo000Eooooo`0300000?l0003ooooo013ooooo00<00000ooooooooool05oooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`0000400000
0Oooool001Gooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Gooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Ooo
ool000;ooooo0ol00002ooooo`?o00001?ooool2o`0000Gooooo00<00000ooooooooool04?ooool0
0`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool04?oo
ool00`00003oooooooooo`0Gooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Fooooo`4000000Oooool000Go00001Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool04Oooool00`00003ooooooooo
o`0Fooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Fooooo`4000000Oooool00004o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o0140001o00<000000000O`0007l0
l@0007l1o`00004000000Oooool00004ooooool0003oooooo`0000;ooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Fooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool000;ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Kooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
0oooool00ol0003oooooooooo`05o`0000?ooooo0_l00005ooooo`0300000?oooooooooo017ooooo
00<00000ooooooooool05_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?l0003ooooo017ooooo00<0
0000ooooooooool05_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool04_ooool0
0`00003oooooooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04_ooool00`00
003oooooooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool04_ooool00`00003o
ooooooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`000?ooool04_ooool00`00003ooooo
ooooo`0Eooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Eooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oo
oooooooo01Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooo
oooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`0300000?oooooo
oooo01Gooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo
01Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Cooooo`0300000?oooooooooo01Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Go
oooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0
5?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
5_ooool10000007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000
007ooooo000Eooooo`0300000?l0003ooooo01Cooooo00<00000ooooooooool04oooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`000040
00000Oooool001Gooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0Cooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`400000
0Oooool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooo
ooooo`0Dooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`0Dooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0`00003o00000000O`0D0000O`030000000007l0001o0>h0001o0Ol000010000007ooooo0004oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool04oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo0004
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo01Gooooo00<00000ooooooooool04_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo00000ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0Eooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oo
ooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001Ol00003ooooo`;o0000
1?ooool2o`0000Gooooo00<00000o`000?ooool05Oooool00`00003oooooooooo`0Booooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Eooooo`7o0000
0@000001ooooo`005Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01;ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01;ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01;ooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooo
ooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo017ooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`0Fooooo`0300000?oooooooooo017ooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool0
9?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo
000Eooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool04Oooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo01Kooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`03
00000?l0003ooooo01Kooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00004000000Oooool001Gooooo
00<00000ooooooooool05Oooool3ool001;ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0Dooooo`Goo`004Oooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0
001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo01Cooooo1Ooo000A
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool001Gooooo00<00000o`000?ooool05?ooool5ool000<000003_ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`00
07ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05Oooool1o`00
004000000Oooool001Gooooo00<00000ooooooooool05Oooool3ool000Cooooo0`00000;ooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Fooooo`40
00000Oooool00004ooooool0003o0000o`0000?ooooo0ol00004ooooo`;o00001Oooool00`00003o
ooooooooo`0Oooooo`<000002?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Co
oooo00<0001oooooooooool05_ooool10000007ooooo00001ol0003ooooooooooooooooo0000oooo
ool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000
ooooooooool08_ooool2000000Kooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`001?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o00000000O`0T
0000O`<00000gP0007l1o`00004000000Oooool000Cooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool09oooool2
000000?oo`004?ooool3ool001;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000Co00000_ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0`00003oooooooooo`0Xooooo`Goo`0020000006ooooo`Goo`004Oooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Kooooo0@000001ooooo`0000?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0:?ooool5
ool000Sooooo1P000005ool0017ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0F
ooooo`4000000Oooool000Go000000?oooooo`000?l000000ol00003ooooo`;o00001Oooool00`00
003oooooooooo`0Xooooo`Goo`003_ooool5ool000<000003_ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Yooooo`?o
o`004?ooool3ool000Cooooo0`00000;ooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool05Oooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooo
ooooo`0Iooooo`<000002?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo01cooooo0P00
0006ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool07_ooool3000000?ooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001o
ooooooooool09?ooool00`0007ooooooooooo`0Fooooo`4000000Oooool001Gooooo00<00000o`00
0?ooool0:_ooool00`0007ooooooooooo`0Qooooo`8000000ooo000Uooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0001ooooooooo
ool08_ooool5ool002Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`030000
0?oooooooooo02[ooooo00<0001oooooooooool08_ooool5ool000<000008Oooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Fooooo`4000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007oooooooooo
o`0Rooooo`Goo`000oooool3000001kooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool05_ooool10000007ooooo000E
ooooo`0300000?l0003ooooo02[ooooo00<0001oooooooooool08oooool3ool000Oooooo0`00000K
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo01Gooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo
02[ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`09ooooo`<000000oooool3ool0
01;ooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo
02Cooooo00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0<ooooo`8000001Ooo000Aooooo`03
0000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Tooooo`03
0000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool03_ooool5ool0000300000?oooooooooo00kooooo
00<0001oooooooooool03oooool3ool001;ooooo00<0001oooooooooool08oooool3ool002Gooooo
00<0001oooooooooool05_ooool10000007ooooo000Eooooo`0300000?oooooooooo02[ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`Goo`0000?ooooo0000000000000`00
000;ooooo`030000Oooooooooooo00kooooo1Ooo000Aooooo`030000Oooooooooooo02;ooooo1Ooo
000Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Z
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool03oooool3ool000Oooooo1@000005
ooooo`?oo`003?ooool3000000Goo`004Oooool00`0007ooooooooooo`0Rooooo`Goo`009?ooool0
0`0007ooooooooooo`0Eooooo`7o00000@000001ooooo`0000Coooooo`000?l0003o00001?ooool2
o`0000Cooooo0_l00005ooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool0
0`0007ooooooooooo`0Nooooo`@000001Ooo0002ooooo`T000000oooool5ool0008000003oooool0
0`0007ooooooooooo`0Qooooo`0300000?oo003oo`0000?oo`000P00000Rooooo`030000Oooooooo
oooo01Kooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Zooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool08_ooool5ool0008000003Oooool3ool000?ooooo
0`00000<ooooo`030000Oooooooooooo023ooooo00<00000ooooooooool00ooo0003ooooo`<00000
7oooool00`0007ooooooooooo`0Fooooo`4000000Oooool00005o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo02;ooooo1Ooo000Hoooo
o`<000002Oooool00`0007ooooooooooo`0Nooooo`8000001?ooool00`0007ooooooooooo`05oooo
o`<000006_ooool3ool001Sooooo0@000001ooooo`001?l00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`1g0000O`?oo`00700007l3
000002D0001o0P00000A0000O`8000005`0007l5ool001H0001o0Ol000010000007ooooo00000ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool09?oo
ool00`0007ooooooooooo`0Nooooo`<000000_ooool3ool001cooooo00<00000ooooooooool01_oo
ool00`0007ooooooooooo`0:ooooo`<000004_ooool2000000Goo`0000<00000ooooooooool05?oo
ool10000007ooooo00000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0Qooooo`0300000?oo003oo`0000?oo`00
6Oooool2000000Wooooo00<0001oooooooooool03Oooool2000000?oo`000oooool:000000;ooooo
1Ooo00001?ooool0000000000000000Cooooo`4000000Oooool000;ooooo0_l00004ooooo`;o0000
1?ooool2o`0000Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000
Oooooooooooo02Cooooo00<0001oooooooooool08_ooool5ool001Oooooo0P00000;ooooo`030000
Oooooooooooo00kooooo1Ooo0002000000gooooo0ooo0005ooooo`<000004?ooool10000007ooooo
000Eooooo`0300000?l0003ooooo02[ooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02;ooooo1Ooo0004000001;ooooo00<00000ooooooooool02ooo
ool00`0007ooooooooooo`0>ooooo`Goo`004Oooool00`0007ooooooooooo`06ooooo`<000003?oo
ool1o`00004000000Oooool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0T
ooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool08oooool3ool000Gooooo1000000<
ooooo`8000003_ooool00`0007ooooooooooo`0>ooooo`Goo`004Oooool00`0007ooooooooooo`09
ooooo`<000000oooool3ool000Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Zoooo
o`030000Oooooooooooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0Toooo
o`030000Oooooooooooo00Sooooo0`000004ooooo`?oo`000P00000@ooooo`030000Oooooooooooo
00oooooo0ooo000Booooo`030000Oooooooooooo00cooooo0P000005ool000?ooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0Zooooo`030000Oooooooooooo02Cooooo00<0001ooooooooo
ool09?ooool00`0007ooooooooooo`0Tooooo`030000Oooooooooooo00_ooooo0`000005ool0017o
oooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`Goo`000oooool10000007o
oooo000Eooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool09?ooool00`0007oooooo
ooooo`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool03_ooool5ool0017ooooo
00<0001oooooooooool09?ooool00`0007ooooooooooo`0>ooooo`Goo`000oooool10000007ooooo
000Eooooo`0300000?l0003ooooo02[ooooo00<0001oooooooooool09?ooool00`0007oooooooooo
o`0Tooooo`030000Oooooooooooo02Cooooo00<0001oooooooooool03_ooool5ool0017ooooo00<0
001oooooooooool09?ooool00`0007ooooooooooo`0?ooooo`?oo`000oooool1o`00004000000Ooo
ool001Gooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0Tooooo`030000Oooooooo
oooo02Cooooo00<0001oooooooooool09?ooool00`0007ooooooooooo`0?ooooo`?oo`004_ooool0
0`0007ooooooooooo`0Tooooo`030000Oooooooooooo01Kooooo0@000001ooooo`005Oooool00`00
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`4000000Oooool001Goooooo`00000;0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.579071, 217.085, \
0.0514022, 2.32941}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{675, 713},
WindowMargins->{{29, Automatic}, {Automatic, 35}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 58, 0, 62, "Title"],
Cell[1815, 53, 275, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2115, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2182, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2260, 71, 36, 0, 43, "Subsubsection"],
Cell[2299, 73, 166, 4, 63, "Input"],
Cell[2468, 79, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2679, 87, 53, 0, 43, "Subsubsection"],
Cell[2735, 89, 207, 4, 63, "Input"],
Cell[2945, 95, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3078, 102, 40, 0, 49, "Subsection"],
Cell[3121, 104, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3221, 110, 36, 0, 49, "Subsection"],
Cell[3260, 112, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3439, 120, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3500, 124, 77, 0, 49, "Subsection"],
Cell[3580, 126, 893, 17, 255, "Input"],
Cell[4476, 145, 857, 17, 255, "Input"],

Cell[CellGroupData[{
Cell[5358, 166, 43, 0, 43, "Subsubsection"],
Cell[5404, 168, 299, 6, 79, "Input"],
Cell[5706, 176, 628, 10, 175, "Input"],
Cell[6337, 188, 296, 5, 95, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6682, 199, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[6759, 203, 50, 0, 43, "Subsubsection"],
Cell[6812, 205, 613, 9, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7462, 219, 65, 0, 43, "Subsubsection"],
Cell[7530, 221, 1145, 19, 223, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8724, 246, 61, 0, 33, "Subsection"],
Cell[8788, 248, 778, 13, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9603, 266, 50, 0, 33, "Subsection"],
Cell[9656, 268, 982, 16, 207, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10675, 289, 98, 3, 33, "Subsection"],
Cell[10776, 294, 325, 6, 127, "Input"],
Cell[11104, 302, 291, 5, 127, "Input"],
Cell[11398, 309, 441, 9, 175, "Input"],
Cell[11842, 320, 433, 8, 175, "Input"],
Cell[12278, 330, 76, 1, 47, "Input"],
Cell[12357, 333, 267, 5, 95, "Input"],
Cell[12627, 340, 275, 5, 111, "Input"],
Cell[12905, 347, 393, 6, 159, "Input"],
Cell[13301, 355, 387, 7, 127, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13725, 367, 58, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[13808, 371, 46, 0, 43, "Subsubsection"],
Cell[13857, 373, 161, 2, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14055, 380, 46, 0, 35, "Subsubsection"],
Cell[14104, 382, 522, 8, 143, "Input"],
Cell[14629, 392, 725, 13, 207, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15391, 410, 67, 0, 35, "Subsubsection"],
Cell[15461, 412, 1108, 18, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16606, 435, 67, 0, 43, "Subsubsection"],
Cell[16676, 437, 1110, 18, 223, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17835, 461, 77, 0, 49, "Subsection"],
Cell[17915, 463, 774, 13, 223, "Input"],
Cell[18692, 478, 778, 13, 223, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19519, 497, 50, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[19594, 501, 70, 1, 47, "Input"],
Cell[19667, 504, 21391, 327, 296, 893, 69, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[41107, 837, 67, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[41199, 841, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[41284, 845, 68, 0, 43, "Subsubsection"],
Cell[41355, 847, 151, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41543, 856, 39, 0, 43, "Subsubsection"],
Cell[41585, 858, 182, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41804, 866, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[41877, 870, 155, 3, 63, "Input"],
Cell[42035, 875, 65430, 1628, 296, 19540, 1057, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[107526, 2510, 101, 3, 49, "Subsection"],
Cell[107630, 2515, 83, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107750, 2521, 77, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[107852, 2525, 84, 1, 47, "Input"],
Cell[107939, 2528, 49713, 1003, 186, 5500, 453, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[157701, 3537, 73, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[157799, 3541, 84, 1, 47, "Input"],
Cell[157886, 3544, 49146, 988, 186, 5419, 444, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[207093, 4539, 72, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[207190, 4543, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[207275, 4547, 68, 0, 43, "Subsubsection"],
Cell[207346, 4549, 151, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207534, 4558, 39, 0, 43, "Subsubsection"],
Cell[207576, 4560, 201, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207814, 4569, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[207887, 4573, 155, 3, 63, "Input"],
Cell[208045, 4578, 77860, 1782, 296, 19516, 1057, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[285966, 6367, 101, 3, 49, "Subsection"],
Cell[286070, 6372, 83, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286190, 6378, 77, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[286292, 6382, 84, 1, 47, "Input"],
Cell[286379, 6385, 49530, 1094, 186, 6689, 561, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[335958, 7485, 73, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[336056, 7489, 84, 1, 47, "Input"],
Cell[336143, 7492, 49823, 1080, 186, 6491, 540, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[386027, 8579, 57, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[386109, 8583, 71, 1, 47, "Input"],
Cell[386183, 8586, 19321, 308, 296, 1010, 77, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[405553, 8900, 68, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[405646, 8904, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[405731, 8908, 68, 0, 43, "Subsubsection"],
Cell[405802, 8910, 151, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405990, 8919, 39, 0, 43, "Subsubsection"],
Cell[406032, 8921, 116, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[406185, 8928, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[406258, 8932, 155, 3, 63, "Input"],
Cell[406416, 8937, 75306, 1750, 296, 19526, 1057, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[481783, 10694, 101, 3, 49, "Subsection"],
Cell[481887, 10699, 83, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[482007, 10705, 77, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[482109, 10709, 84, 1, 47, "Input"],
Cell[482196, 10712, 49027, 1010, 186, 5720, 471, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[531272, 11728, 73, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[531370, 11732, 84, 1, 47, "Input"],
Cell[531457, 11735, 48680, 996, 186, 5552, 459, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[580198, 12738, 73, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[580296, 12742, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[580381, 12746, 68, 0, 43, "Subsubsection"],
Cell[580452, 12748, 151, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580640, 12757, 39, 0, 43, "Subsubsection"],
Cell[580682, 12759, 116, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580835, 12766, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[580908, 12770, 155, 3, 63, "Input"],
Cell[581066, 12775, 72305, 1713, 296, 19554, 1057, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[653432, 14495, 101, 3, 49, "Subsection"],
Cell[653536, 14500, 83, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[653656, 14506, 77, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[653758, 14510, 84, 1, 47, "Input"],
Cell[653845, 14513, 49078, 1001, 186, 5541, 459, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[702972, 15520, 73, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[703070, 15524, 84, 1, 47, "Input"],
Cell[703157, 15527, 52007, 1132, 186, 6826, 570, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

